/* SerializableBasicTypesTest.c generated by valac 0.44.3, the Vala compiler
 * generated from SerializableBasicTypesTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */

#include <glib-object.h>
#include <glib.h>
#include <gxml/gxml.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <float.h>
#include <math.h>

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_SERIALIZABLE_BASIC_TYPE_TEST (serializable_basic_type_test_get_type ())
#define SERIALIZABLE_BASIC_TYPE_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_BASIC_TYPE_TEST, SerializableBasicTypeTest))
#define SERIALIZABLE_BASIC_TYPE_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_BASIC_TYPE_TEST, SerializableBasicTypeTestClass))
#define IS_SERIALIZABLE_BASIC_TYPE_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_BASIC_TYPE_TEST))
#define IS_SERIALIZABLE_BASIC_TYPE_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_BASIC_TYPE_TEST))
#define SERIALIZABLE_BASIC_TYPE_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_BASIC_TYPE_TEST, SerializableBasicTypeTestClass))

typedef struct _SerializableBasicTypeTest SerializableBasicTypeTest;
typedef struct _SerializableBasicTypeTestClass SerializableBasicTypeTestClass;
typedef struct _SerializableBasicTypeTestPrivate SerializableBasicTypeTestPrivate;

#define SERIALIZABLE_BASIC_TYPE_TEST_TYPE_BASIC_TYPE (serializable_basic_type_test_basic_type_get_type ())
#define SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_BASIC_TYPE_TEST_TYPE_BASIC_TYPE, SerializableBasicTypeTestBasicType))
#define SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_BASIC_TYPE_TEST_TYPE_BASIC_TYPE, SerializableBasicTypeTestBasicTypeClass))
#define SERIALIZABLE_BASIC_TYPE_TEST_IS_BASIC_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_BASIC_TYPE_TEST_TYPE_BASIC_TYPE))
#define SERIALIZABLE_BASIC_TYPE_TEST_IS_BASIC_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_BASIC_TYPE_TEST_TYPE_BASIC_TYPE))
#define SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_BASIC_TYPE_TEST_TYPE_BASIC_TYPE, SerializableBasicTypeTestBasicTypeClass))

typedef struct _SerializableBasicTypeTestBasicType SerializableBasicTypeTestBasicType;
typedef struct _SerializableBasicTypeTestBasicTypeClass SerializableBasicTypeTestBasicTypeClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _SerializableBasicTypeTestBasicTypePrivate SerializableBasicTypeTestBasicTypePrivate;
enum  {
	SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_0_PROPERTY,
	SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_BOOLEAN_PROPERTY,
	SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_INTEGER_PROPERTY,
	SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_FLOATVAL_PROPERTY,
	SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_DOUBLEVAL_PROPERTY,
	SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_NUM_PROPERTIES
};
static GParamSpec* serializable_basic_type_test_basic_type_properties[SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_NUM_PROPERTIES];
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _SerializableBasicTypeTest {
	GXmlTest parent_instance;
	SerializableBasicTypeTestPrivate * priv;
};

struct _SerializableBasicTypeTestClass {
	GXmlTestClass parent_class;
};

struct _SerializableBasicTypeTestBasicType {
	GXmlSerializableObjectModel parent_instance;
	SerializableBasicTypeTestBasicTypePrivate * priv;
};

struct _SerializableBasicTypeTestBasicTypeClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableBasicTypeTestBasicTypePrivate {
	gboolean _boolean;
	gint _integer;
	gfloat _floatval;
	gdouble _doubleval;
};

static gpointer serializable_basic_type_test_parent_class = NULL;
static gint SerializableBasicTypeTestBasicType_private_offset;
static gpointer serializable_basic_type_test_basic_type_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType serializable_basic_type_test_get_type (void) G_GNUC_CONST;
void serializable_basic_type_test_add_tests (void);
static void __lambda325_ (void);
GType serializable_basic_type_test_basic_type_get_type (void) G_GNUC_CONST;
SerializableBasicTypeTestBasicType* serializable_basic_type_test_basic_type_new (void);
SerializableBasicTypeTestBasicType* serializable_basic_type_test_basic_type_construct (GType object_type);
void serializable_basic_type_test_basic_type_set_boolean (SerializableBasicTypeTestBasicType* self,
                                                          gboolean value);
static void ___lambda325__gtest_func (void);
static void __lambda326_ (void);
gboolean serializable_basic_type_test_basic_type_get_boolean (SerializableBasicTypeTestBasicType* self);
static void ___lambda326__gtest_func (void);
static void __lambda327_ (void);
gint serializable_basic_type_test_basic_type_get_integer (SerializableBasicTypeTestBasicType* self);
static void ___lambda327__gtest_func (void);
static void __lambda328_ (void);
gfloat serializable_basic_type_test_basic_type_get_floatval (SerializableBasicTypeTestBasicType* self);
void serializable_basic_type_test_basic_type_set_floatval (SerializableBasicTypeTestBasicType* self,
                                                           gfloat value);
static void ___lambda328__gtest_func (void);
static void __lambda329_ (void);
gdouble serializable_basic_type_test_basic_type_get_doubleval (SerializableBasicTypeTestBasicType* self);
void serializable_basic_type_test_basic_type_set_doubleval (SerializableBasicTypeTestBasicType* self,
                                                            gdouble value);
static void ___lambda329__gtest_func (void);
SerializableBasicTypeTest* serializable_basic_type_test_new (void);
SerializableBasicTypeTest* serializable_basic_type_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static gchar* serializable_basic_type_test_basic_type_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_basic_type_test_basic_type_real_to_string (GXmlSerializableObjectModel* base);
void serializable_basic_type_test_basic_type_set_integer (SerializableBasicTypeTestBasicType* self,
                                                          gint value);
static void serializable_basic_type_test_basic_type_finalize (GObject * obj);
static void _vala_serializable_basic_type_test_basic_type_get_property (GObject * object,
                                                                 guint property_id,
                                                                 GValue * value,
                                                                 GParamSpec * pspec);
static void _vala_serializable_basic_type_test_basic_type_set_property (GObject * object,
                                                                 guint property_id,
                                                                 const GValue * value,
                                                                 GParamSpec * pspec);

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result = NULL;
#line 1516 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1517 "glib-2.0.vapi"
	result = self;
#line 1517 "glib-2.0.vapi"
	return result;
#line 171 "SerializableBasicTypesTest.c"
}

static void
__lambda325_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		SerializableBasicTypeTestBasicType* bt = NULL;
		SerializableBasicTypeTestBasicType* _tmp0_;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_;
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlElement* element = NULL;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlElement* _tmp6_;
		GXmlNode* b = NULL;
		GXmlNode* _tmp7_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		gboolean _tmp14_;
#line 41 "SerializableBasicTypesTest.vala"
		_tmp0_ = serializable_basic_type_test_basic_type_new ();
#line 41 "SerializableBasicTypesTest.vala"
		bt = _tmp0_;
#line 42 "SerializableBasicTypesTest.vala"
		serializable_basic_type_test_basic_type_set_boolean (bt, TRUE);
#line 43 "SerializableBasicTypesTest.vala"
		_tmp1_ = gxml_gdocument_new ();
#line 43 "SerializableBasicTypesTest.vala"
		doc = _tmp1_;
#line 44 "SerializableBasicTypesTest.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) bt, (GXmlNode*) doc, &_inner_error0_);
#line 44 "SerializableBasicTypesTest.vala"
		_tmp3_ = _tmp2_;
#line 44 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (_tmp3_);
#line 44 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 44 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 44 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 219 "SerializableBasicTypesTest.c"
			goto __catch375_g_error;
		}
#line 45 "SerializableBasicTypesTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 45 "SerializableBasicTypesTest.vala"
		_tmp5_ = _tmp4_;
#line 45 "SerializableBasicTypesTest.vala"
		_tmp6_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp5_) : NULL;
#line 45 "SerializableBasicTypesTest.vala"
		if (_tmp6_ == NULL) {
#line 45 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (_tmp5_);
#line 232 "SerializableBasicTypesTest.c"
		}
#line 45 "SerializableBasicTypesTest.vala"
		element = _tmp6_;
#line 46 "SerializableBasicTypesTest.vala"
		_tmp7_ = gxml_element_get_attr (element, "boolean");
#line 46 "SerializableBasicTypesTest.vala"
		b = _tmp7_;
#line 47 "SerializableBasicTypesTest.vala"
		if (b == NULL) {
#line 242 "SerializableBasicTypesTest.c"
			FILE* _tmp8_;
#line 48 "SerializableBasicTypesTest.vala"
			_tmp8_ = stdout;
#line 48 "SerializableBasicTypesTest.vala"
			fprintf (_tmp8_, "%s", "ERROR: No boolean exists\n");
#line 49 "SerializableBasicTypesTest.vala"
			g_assert_not_reached ();
#line 250 "SerializableBasicTypesTest.c"
		}
#line 51 "SerializableBasicTypesTest.vala"
		_tmp9_ = gxml_node_get_value (b);
#line 51 "SerializableBasicTypesTest.vala"
		_tmp10_ = _tmp9_;
#line 51 "SerializableBasicTypesTest.vala"
		_tmp11_ = _tmp10_;
#line 51 "SerializableBasicTypesTest.vala"
		_tmp12_ = g_utf8_strdown (_tmp11_, (gssize) -1);
#line 51 "SerializableBasicTypesTest.vala"
		_tmp13_ = _tmp12_;
#line 51 "SerializableBasicTypesTest.vala"
		_tmp14_ = g_strcmp0 (_tmp13_, "true") != 0;
#line 51 "SerializableBasicTypesTest.vala"
		_g_free0 (_tmp13_);
#line 51 "SerializableBasicTypesTest.vala"
		_g_free0 (_tmp11_);
#line 51 "SerializableBasicTypesTest.vala"
		if (_tmp14_) {
#line 270 "SerializableBasicTypesTest.c"
			FILE* _tmp15_;
			gchar* _tmp16_;
			gchar* _tmp17_;
			gchar* _tmp18_;
			gchar* _tmp19_;
			gchar* _tmp20_;
			const gchar* _tmp21_;
			gchar* _tmp22_;
			gchar* _tmp23_;
			gchar* _tmp24_;
			const gchar* _tmp25_;
			gchar* _tmp26_;
			gchar* _tmp27_;
#line 52 "SerializableBasicTypesTest.vala"
			_tmp15_ = stdout;
#line 52 "SerializableBasicTypesTest.vala"
			_tmp16_ = gxml_node_get_value (b);
#line 52 "SerializableBasicTypesTest.vala"
			_tmp17_ = _tmp16_;
#line 52 "SerializableBasicTypesTest.vala"
			_tmp18_ = _tmp17_;
#line 52 "SerializableBasicTypesTest.vala"
			_tmp19_ = g_utf8_strdown (_tmp18_, (gssize) -1);
#line 52 "SerializableBasicTypesTest.vala"
			_tmp20_ = _tmp19_;
#line 52 "SerializableBasicTypesTest.vala"
			_tmp21_ = string_to_string (_tmp20_);
#line 52 "SerializableBasicTypesTest.vala"
			_tmp22_ = gxml_node_get_value (b);
#line 52 "SerializableBasicTypesTest.vala"
			_tmp23_ = _tmp22_;
#line 52 "SerializableBasicTypesTest.vala"
			_tmp24_ = _tmp23_;
#line 52 "SerializableBasicTypesTest.vala"
			_tmp25_ = string_to_string (_tmp24_);
#line 52 "SerializableBasicTypesTest.vala"
			_tmp26_ = g_strconcat ("ERROR: Wrong boolean value. Expected true got: ", _tmp21_, " : ", _tmp25_, "\n", NULL);
#line 52 "SerializableBasicTypesTest.vala"
			_tmp27_ = _tmp26_;
#line 52 "SerializableBasicTypesTest.vala"
			fprintf (_tmp15_, "%s", _tmp27_);
#line 52 "SerializableBasicTypesTest.vala"
			_g_free0 (_tmp27_);
#line 52 "SerializableBasicTypesTest.vala"
			_g_free0 (_tmp24_);
#line 52 "SerializableBasicTypesTest.vala"
			_g_free0 (_tmp20_);
#line 52 "SerializableBasicTypesTest.vala"
			_g_free0 (_tmp18_);
#line 53 "SerializableBasicTypesTest.vala"
			g_assert_not_reached ();
#line 322 "SerializableBasicTypesTest.c"
		}
#line 40 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (b);
#line 40 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (element);
#line 40 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc);
#line 40 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (bt);
#line 332 "SerializableBasicTypesTest.c"
	}
	goto __finally375;
	__catch375_g_error:
	{
		GError* e = NULL;
		FILE* _tmp28_;
		const gchar* _tmp29_;
		const gchar* _tmp30_;
		gchar* _tmp31_;
		gchar* _tmp32_;
#line 40 "SerializableBasicTypesTest.vala"
		e = _inner_error0_;
#line 40 "SerializableBasicTypesTest.vala"
		_inner_error0_ = NULL;
#line 57 "SerializableBasicTypesTest.vala"
		_tmp28_ = stdout;
#line 57 "SerializableBasicTypesTest.vala"
		_tmp29_ = e->message;
#line 57 "SerializableBasicTypesTest.vala"
		_tmp30_ = string_to_string (_tmp29_);
#line 57 "SerializableBasicTypesTest.vala"
		_tmp31_ = g_strconcat ("ERROR: ", _tmp30_, NULL);
#line 57 "SerializableBasicTypesTest.vala"
		_tmp32_ = _tmp31_;
#line 57 "SerializableBasicTypesTest.vala"
		fprintf (_tmp28_, "%s", _tmp32_);
#line 57 "SerializableBasicTypesTest.vala"
		_g_free0 (_tmp32_);
#line 58 "SerializableBasicTypesTest.vala"
		g_assert_not_reached ();
#line 40 "SerializableBasicTypesTest.vala"
		_g_error_free0 (e);
#line 365 "SerializableBasicTypesTest.c"
	}
	__finally375:
#line 40 "SerializableBasicTypesTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 40 "SerializableBasicTypesTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 40 "SerializableBasicTypesTest.vala"
		g_clear_error (&_inner_error0_);
#line 40 "SerializableBasicTypesTest.vala"
		return;
#line 376 "SerializableBasicTypesTest.c"
	}
}

static void
___lambda325__gtest_func (void)
{
#line 38 "SerializableBasicTypesTest.vala"
	__lambda325_ ();
#line 385 "SerializableBasicTypesTest.c"
}

static gchar*
bool_to_string (gboolean self)
{
	gchar* result = NULL;
#line 37 "glib-2.0.vapi"
	if (self) {
#line 394 "SerializableBasicTypesTest.c"
		gchar* _tmp0_;
#line 38 "glib-2.0.vapi"
		_tmp0_ = g_strdup ("true");
#line 38 "glib-2.0.vapi"
		result = _tmp0_;
#line 38 "glib-2.0.vapi"
		return result;
#line 402 "SerializableBasicTypesTest.c"
	} else {
		gchar* _tmp1_;
#line 40 "glib-2.0.vapi"
		_tmp1_ = g_strdup ("false");
#line 40 "glib-2.0.vapi"
		result = _tmp1_;
#line 40 "glib-2.0.vapi"
		return result;
#line 411 "SerializableBasicTypesTest.c"
	}
}

static void
__lambda326_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		SerializableBasicTypeTestBasicType* bt = NULL;
		SerializableBasicTypeTestBasicType* _tmp0_;
		SerializableBasicTypeTestBasicType* _tmp1_;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp2_;
		SerializableBasicTypeTestBasicType* _tmp3_;
		GXmlGDocument* _tmp4_;
		SerializableBasicTypeTestBasicType* _tmp5_;
		gboolean _tmp6_;
		gboolean _tmp7_;
#line 64 "SerializableBasicTypesTest.vala"
		_tmp0_ = serializable_basic_type_test_basic_type_new ();
#line 64 "SerializableBasicTypesTest.vala"
		bt = _tmp0_;
#line 65 "SerializableBasicTypesTest.vala"
		_tmp1_ = bt;
#line 65 "SerializableBasicTypesTest.vala"
		serializable_basic_type_test_basic_type_set_boolean (_tmp1_, TRUE);
#line 66 "SerializableBasicTypesTest.vala"
		_tmp2_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype boolean=\"true\"/>", 0, &_inner_error0_);
#line 66 "SerializableBasicTypesTest.vala"
		doc = _tmp2_;
#line 66 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 66 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 446 "SerializableBasicTypesTest.c"
			goto __catch376_g_error;
		}
#line 68 "SerializableBasicTypesTest.vala"
		_tmp3_ = bt;
#line 68 "SerializableBasicTypesTest.vala"
		_tmp4_ = doc;
#line 68 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp3_, (GXmlNode*) _tmp4_, &_inner_error0_);
#line 68 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 68 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 68 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 461 "SerializableBasicTypesTest.c"
			goto __catch376_g_error;
		}
#line 69 "SerializableBasicTypesTest.vala"
		_tmp5_ = bt;
#line 69 "SerializableBasicTypesTest.vala"
		_tmp6_ = serializable_basic_type_test_basic_type_get_boolean (_tmp5_);
#line 69 "SerializableBasicTypesTest.vala"
		_tmp7_ = _tmp6_;
#line 69 "SerializableBasicTypesTest.vala"
		if (_tmp7_ != TRUE) {
#line 472 "SerializableBasicTypesTest.c"
			FILE* _tmp8_;
			SerializableBasicTypeTestBasicType* _tmp9_;
			gboolean _tmp10_;
			gboolean _tmp11_;
			gchar* _tmp12_;
			gchar* _tmp13_;
			GXmlGDocument* _tmp14_;
			gchar* _tmp15_;
			gchar* _tmp16_;
			gchar* _tmp17_;
			gchar* _tmp18_;
#line 70 "SerializableBasicTypesTest.vala"
			_tmp8_ = stdout;
#line 70 "SerializableBasicTypesTest.vala"
			_tmp9_ = bt;
#line 70 "SerializableBasicTypesTest.vala"
			_tmp10_ = serializable_basic_type_test_basic_type_get_boolean (_tmp9_);
#line 70 "SerializableBasicTypesTest.vala"
			_tmp11_ = _tmp10_;
#line 70 "SerializableBasicTypesTest.vala"
			_tmp12_ = bool_to_string (_tmp11_);
#line 70 "SerializableBasicTypesTest.vala"
			_tmp13_ = _tmp12_;
#line 70 "SerializableBasicTypesTest.vala"
			_tmp14_ = doc;
#line 70 "SerializableBasicTypesTest.vala"
			_tmp15_ = gxml_gnode_to_string ((GXmlGNode*) _tmp14_);
#line 70 "SerializableBasicTypesTest.vala"
			_tmp16_ = _tmp15_;
#line 70 "SerializableBasicTypesTest.vala"
			_tmp17_ = g_strconcat ("ERROR: Wrong boolean value. Expected true got: ", _tmp13_, "\n", _tmp16_, "\n", NULL);
#line 70 "SerializableBasicTypesTest.vala"
			_tmp18_ = _tmp17_;
#line 70 "SerializableBasicTypesTest.vala"
			fprintf (_tmp8_, "%s", _tmp18_);
#line 70 "SerializableBasicTypesTest.vala"
			_g_free0 (_tmp18_);
#line 70 "SerializableBasicTypesTest.vala"
			_g_free0 (_tmp16_);
#line 70 "SerializableBasicTypesTest.vala"
			_g_free0 (_tmp13_);
#line 71 "SerializableBasicTypesTest.vala"
			g_assert_not_reached ();
#line 516 "SerializableBasicTypesTest.c"
		}
#line 63 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc);
#line 63 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (bt);
#line 522 "SerializableBasicTypesTest.c"
	}
	goto __finally376;
	__catch376_g_error:
	{
		GError* e = NULL;
		FILE* _tmp19_;
		const gchar* _tmp20_;
		const gchar* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
#line 63 "SerializableBasicTypesTest.vala"
		e = _inner_error0_;
#line 63 "SerializableBasicTypesTest.vala"
		_inner_error0_ = NULL;
#line 75 "SerializableBasicTypesTest.vala"
		_tmp19_ = stdout;
#line 75 "SerializableBasicTypesTest.vala"
		_tmp20_ = e->message;
#line 75 "SerializableBasicTypesTest.vala"
		_tmp21_ = string_to_string (_tmp20_);
#line 75 "SerializableBasicTypesTest.vala"
		_tmp22_ = g_strconcat ("ERROR: ", _tmp21_, NULL);
#line 75 "SerializableBasicTypesTest.vala"
		_tmp23_ = _tmp22_;
#line 75 "SerializableBasicTypesTest.vala"
		fprintf (_tmp19_, "%s", _tmp23_);
#line 75 "SerializableBasicTypesTest.vala"
		_g_free0 (_tmp23_);
#line 76 "SerializableBasicTypesTest.vala"
		g_assert_not_reached ();
#line 63 "SerializableBasicTypesTest.vala"
		_g_error_free0 (e);
#line 555 "SerializableBasicTypesTest.c"
	}
	__finally376:
#line 63 "SerializableBasicTypesTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 63 "SerializableBasicTypesTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 63 "SerializableBasicTypesTest.vala"
		g_clear_error (&_inner_error0_);
#line 63 "SerializableBasicTypesTest.vala"
		return;
#line 566 "SerializableBasicTypesTest.c"
	}
}

static void
___lambda326__gtest_func (void)
{
#line 61 "SerializableBasicTypesTest.vala"
	__lambda326_ ();
#line 575 "SerializableBasicTypesTest.c"
}

static void
__lambda327_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		SerializableBasicTypeTestBasicType* bt = NULL;
		SerializableBasicTypeTestBasicType* _tmp0_;
		SerializableBasicTypeTestBasicType* _tmp1_;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp2_;
		SerializableBasicTypeTestBasicType* _tmp3_;
		GXmlGDocument* _tmp4_;
		SerializableBasicTypeTestBasicType* _tmp5_;
		gint _tmp6_;
		gint _tmp7_;
		GXmlGDocument* doc1 = NULL;
		GXmlGDocument* _tmp8_;
		SerializableBasicTypeTestBasicType* _tmp9_;
		GXmlGDocument* _tmp10_;
		SerializableBasicTypeTestBasicType* _tmp11_;
		gint _tmp12_;
		gint _tmp13_;
		GXmlGDocument* doc2 = NULL;
		GXmlGDocument* _tmp14_;
		SerializableBasicTypeTestBasicType* _tmp15_;
		GXmlGDocument* _tmp16_;
		SerializableBasicTypeTestBasicType* _tmp17_;
		gint _tmp18_;
		gint _tmp19_;
		GXmlGDocument* doc3 = NULL;
		GXmlGDocument* _tmp20_;
		SerializableBasicTypeTestBasicType* _tmp21_;
		GXmlGDocument* _tmp22_;
		SerializableBasicTypeTestBasicType* _tmp23_;
		gint _tmp24_;
		gint _tmp25_;
		GXmlGDocument* doc4 = NULL;
		GXmlGDocument* _tmp26_;
		SerializableBasicTypeTestBasicType* _tmp27_;
		GXmlGDocument* _tmp28_;
		SerializableBasicTypeTestBasicType* _tmp29_;
		gint _tmp30_;
		gint _tmp31_;
		GXmlGDocument* doc5 = NULL;
		GXmlGDocument* _tmp32_;
		SerializableBasicTypeTestBasicType* _tmp33_;
		GXmlGDocument* _tmp34_;
		SerializableBasicTypeTestBasicType* _tmp35_;
		gint _tmp36_;
		gint _tmp37_;
		GXmlGDocument* doc6 = NULL;
		GXmlGDocument* _tmp38_;
		SerializableBasicTypeTestBasicType* _tmp39_;
		GXmlGDocument* _tmp40_;
		SerializableBasicTypeTestBasicType* _tmp41_;
		gint _tmp42_;
		gint _tmp43_;
#line 82 "SerializableBasicTypesTest.vala"
		_tmp0_ = serializable_basic_type_test_basic_type_new ();
#line 82 "SerializableBasicTypesTest.vala"
		bt = _tmp0_;
#line 83 "SerializableBasicTypesTest.vala"
		_tmp1_ = bt;
#line 83 "SerializableBasicTypesTest.vala"
		serializable_basic_type_test_basic_type_set_boolean (_tmp1_, TRUE);
#line 84 "SerializableBasicTypesTest.vala"
		_tmp2_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype integer=\"156\"/>", 0, &_inner_error0_);
#line 84 "SerializableBasicTypesTest.vala"
		doc = _tmp2_;
#line 84 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 84 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 651 "SerializableBasicTypesTest.c"
			goto __catch377_g_error;
		}
#line 86 "SerializableBasicTypesTest.vala"
		_tmp3_ = bt;
#line 86 "SerializableBasicTypesTest.vala"
		_tmp4_ = doc;
#line 86 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp3_, (GXmlNode*) _tmp4_, &_inner_error0_);
#line 86 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 86 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 86 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 666 "SerializableBasicTypesTest.c"
			goto __catch377_g_error;
		}
#line 87 "SerializableBasicTypesTest.vala"
		_tmp5_ = bt;
#line 87 "SerializableBasicTypesTest.vala"
		_tmp6_ = serializable_basic_type_test_basic_type_get_integer (_tmp5_);
#line 87 "SerializableBasicTypesTest.vala"
		_tmp7_ = _tmp6_;
#line 87 "SerializableBasicTypesTest.vala"
		_vala_assert (_tmp7_ == 156, "bt.integer == 156");
#line 88 "SerializableBasicTypesTest.vala"
		_tmp8_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype integer=\"a156\"/>", 0, &_inner_error0_);
#line 88 "SerializableBasicTypesTest.vala"
		doc1 = _tmp8_;
#line 88 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 88 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 88 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 687 "SerializableBasicTypesTest.c"
			goto __catch377_g_error;
		}
#line 90 "SerializableBasicTypesTest.vala"
		_tmp9_ = bt;
#line 90 "SerializableBasicTypesTest.vala"
		_tmp10_ = doc1;
#line 90 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp9_, (GXmlNode*) _tmp10_, &_inner_error0_);
#line 90 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 90 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 90 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 90 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 704 "SerializableBasicTypesTest.c"
			goto __catch377_g_error;
		}
#line 91 "SerializableBasicTypesTest.vala"
		_tmp11_ = bt;
#line 91 "SerializableBasicTypesTest.vala"
		_tmp12_ = serializable_basic_type_test_basic_type_get_integer (_tmp11_);
#line 91 "SerializableBasicTypesTest.vala"
		_tmp13_ = _tmp12_;
#line 91 "SerializableBasicTypesTest.vala"
		_vala_assert (_tmp13_ == 0, "bt.integer == 0");
#line 92 "SerializableBasicTypesTest.vala"
		_tmp14_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype integer=\"156b\"/>", 0, &_inner_error0_);
#line 92 "SerializableBasicTypesTest.vala"
		doc2 = _tmp14_;
#line 92 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 92 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 92 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 92 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 727 "SerializableBasicTypesTest.c"
			goto __catch377_g_error;
		}
#line 94 "SerializableBasicTypesTest.vala"
		_tmp15_ = bt;
#line 94 "SerializableBasicTypesTest.vala"
		_tmp16_ = doc2;
#line 94 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp15_, (GXmlNode*) _tmp16_, &_inner_error0_);
#line 94 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 94 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 94 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 94 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 94 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 746 "SerializableBasicTypesTest.c"
			goto __catch377_g_error;
		}
#line 95 "SerializableBasicTypesTest.vala"
		_tmp17_ = bt;
#line 95 "SerializableBasicTypesTest.vala"
		_tmp18_ = serializable_basic_type_test_basic_type_get_integer (_tmp17_);
#line 95 "SerializableBasicTypesTest.vala"
		_tmp19_ = _tmp18_;
#line 95 "SerializableBasicTypesTest.vala"
		_vala_assert (_tmp19_ == 156, "bt.integer == 156");
#line 96 "SerializableBasicTypesTest.vala"
		_tmp20_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype integer=\"156.0\"/>", 0, &_inner_error0_);
#line 96 "SerializableBasicTypesTest.vala"
		doc3 = _tmp20_;
#line 96 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 96 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 96 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 96 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 96 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 771 "SerializableBasicTypesTest.c"
			goto __catch377_g_error;
		}
#line 98 "SerializableBasicTypesTest.vala"
		_tmp21_ = bt;
#line 98 "SerializableBasicTypesTest.vala"
		_tmp22_ = doc3;
#line 98 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp21_, (GXmlNode*) _tmp22_, &_inner_error0_);
#line 98 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 98 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 98 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 98 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 98 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 98 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 792 "SerializableBasicTypesTest.c"
			goto __catch377_g_error;
		}
#line 99 "SerializableBasicTypesTest.vala"
		_tmp23_ = bt;
#line 99 "SerializableBasicTypesTest.vala"
		_tmp24_ = serializable_basic_type_test_basic_type_get_integer (_tmp23_);
#line 99 "SerializableBasicTypesTest.vala"
		_tmp25_ = _tmp24_;
#line 99 "SerializableBasicTypesTest.vala"
		_vala_assert (_tmp25_ == 156, "bt.integer == 156");
#line 100 "SerializableBasicTypesTest.vala"
		_tmp26_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype integer=\"0.156\"/>", 0, &_inner_error0_);
#line 100 "SerializableBasicTypesTest.vala"
		doc4 = _tmp26_;
#line 100 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 100 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 100 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 100 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 100 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 100 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 819 "SerializableBasicTypesTest.c"
			goto __catch377_g_error;
		}
#line 102 "SerializableBasicTypesTest.vala"
		_tmp27_ = bt;
#line 102 "SerializableBasicTypesTest.vala"
		_tmp28_ = doc4;
#line 102 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp27_, (GXmlNode*) _tmp28_, &_inner_error0_);
#line 102 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 102 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 102 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 102 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 102 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 102 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 102 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 842 "SerializableBasicTypesTest.c"
			goto __catch377_g_error;
		}
#line 103 "SerializableBasicTypesTest.vala"
		_tmp29_ = bt;
#line 103 "SerializableBasicTypesTest.vala"
		_tmp30_ = serializable_basic_type_test_basic_type_get_integer (_tmp29_);
#line 103 "SerializableBasicTypesTest.vala"
		_tmp31_ = _tmp30_;
#line 103 "SerializableBasicTypesTest.vala"
		_vala_assert (_tmp31_ == 0, "bt.integer == 0");
#line 104 "SerializableBasicTypesTest.vala"
		_tmp32_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype integer=\"a156.156\"/>", 0, &_inner_error0_);
#line 104 "SerializableBasicTypesTest.vala"
		doc5 = _tmp32_;
#line 104 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 104 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 104 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 104 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 104 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 104 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 104 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 871 "SerializableBasicTypesTest.c"
			goto __catch377_g_error;
		}
#line 106 "SerializableBasicTypesTest.vala"
		_tmp33_ = bt;
#line 106 "SerializableBasicTypesTest.vala"
		_tmp34_ = doc5;
#line 106 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp33_, (GXmlNode*) _tmp34_, &_inner_error0_);
#line 106 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 106 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 106 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 106 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 106 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 106 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 106 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 106 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 896 "SerializableBasicTypesTest.c"
			goto __catch377_g_error;
		}
#line 107 "SerializableBasicTypesTest.vala"
		_tmp35_ = bt;
#line 107 "SerializableBasicTypesTest.vala"
		_tmp36_ = serializable_basic_type_test_basic_type_get_integer (_tmp35_);
#line 107 "SerializableBasicTypesTest.vala"
		_tmp37_ = _tmp36_;
#line 107 "SerializableBasicTypesTest.vala"
		_vala_assert (_tmp37_ == 0, "bt.integer == 0");
#line 108 "SerializableBasicTypesTest.vala"
		_tmp38_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype integer=\"156.156b\"/>", 0, &_inner_error0_);
#line 108 "SerializableBasicTypesTest.vala"
		doc6 = _tmp38_;
#line 108 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 108 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 108 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 108 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 108 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 108 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 108 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 108 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 927 "SerializableBasicTypesTest.c"
			goto __catch377_g_error;
		}
#line 110 "SerializableBasicTypesTest.vala"
		_tmp39_ = bt;
#line 110 "SerializableBasicTypesTest.vala"
		_tmp40_ = doc6;
#line 110 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp39_, (GXmlNode*) _tmp40_, &_inner_error0_);
#line 110 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 110 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc6);
#line 110 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 110 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 110 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 110 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 110 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 110 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 110 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 954 "SerializableBasicTypesTest.c"
			goto __catch377_g_error;
		}
#line 111 "SerializableBasicTypesTest.vala"
		_tmp41_ = bt;
#line 111 "SerializableBasicTypesTest.vala"
		_tmp42_ = serializable_basic_type_test_basic_type_get_integer (_tmp41_);
#line 111 "SerializableBasicTypesTest.vala"
		_tmp43_ = _tmp42_;
#line 111 "SerializableBasicTypesTest.vala"
		_vala_assert (_tmp43_ == 156, "bt.integer == 156");
#line 81 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc6);
#line 81 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc5);
#line 81 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc4);
#line 81 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc3);
#line 81 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc2);
#line 81 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc1);
#line 81 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc);
#line 81 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (bt);
#line 981 "SerializableBasicTypesTest.c"
	}
	goto __finally377;
	__catch377_g_error:
	{
		GError* e = NULL;
		FILE* _tmp44_;
		const gchar* _tmp45_;
		const gchar* _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
#line 81 "SerializableBasicTypesTest.vala"
		e = _inner_error0_;
#line 81 "SerializableBasicTypesTest.vala"
		_inner_error0_ = NULL;
#line 113 "SerializableBasicTypesTest.vala"
		_tmp44_ = stdout;
#line 113 "SerializableBasicTypesTest.vala"
		_tmp45_ = e->message;
#line 113 "SerializableBasicTypesTest.vala"
		_tmp46_ = string_to_string (_tmp45_);
#line 113 "SerializableBasicTypesTest.vala"
		_tmp47_ = g_strconcat ("ERROR: ", _tmp46_, NULL);
#line 113 "SerializableBasicTypesTest.vala"
		_tmp48_ = _tmp47_;
#line 113 "SerializableBasicTypesTest.vala"
		fprintf (_tmp44_, "%s", _tmp48_);
#line 113 "SerializableBasicTypesTest.vala"
		_g_free0 (_tmp48_);
#line 114 "SerializableBasicTypesTest.vala"
		g_assert_not_reached ();
#line 81 "SerializableBasicTypesTest.vala"
		_g_error_free0 (e);
#line 1014 "SerializableBasicTypesTest.c"
	}
	__finally377:
#line 81 "SerializableBasicTypesTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 81 "SerializableBasicTypesTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 81 "SerializableBasicTypesTest.vala"
		g_clear_error (&_inner_error0_);
#line 81 "SerializableBasicTypesTest.vala"
		return;
#line 1025 "SerializableBasicTypesTest.c"
	}
}

static void
___lambda327__gtest_func (void)
{
#line 79 "SerializableBasicTypesTest.vala"
	__lambda327_ ();
#line 1034 "SerializableBasicTypesTest.c"
}

static void
__lambda328_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		SerializableBasicTypeTestBasicType* bt = NULL;
		SerializableBasicTypeTestBasicType* _tmp0_;
		SerializableBasicTypeTestBasicType* _tmp1_;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp2_;
		SerializableBasicTypeTestBasicType* _tmp3_;
		GXmlGDocument* _tmp4_;
		SerializableBasicTypeTestBasicType* _tmp5_;
		gfloat _tmp6_;
		gfloat _tmp7_;
		GXmlGDocument* doc1 = NULL;
		GXmlGDocument* _tmp8_;
		SerializableBasicTypeTestBasicType* _tmp9_;
		GXmlGDocument* _tmp10_;
		SerializableBasicTypeTestBasicType* _tmp11_;
		gfloat _tmp12_;
		gfloat _tmp13_;
		GXmlGDocument* doc2 = NULL;
		GXmlGDocument* _tmp14_;
		SerializableBasicTypeTestBasicType* _tmp15_;
		GXmlGDocument* _tmp16_;
		SerializableBasicTypeTestBasicType* _tmp17_;
		gfloat _tmp18_;
		gfloat _tmp19_;
		GXmlGDocument* doc3 = NULL;
		GXmlGDocument* _tmp20_;
		SerializableBasicTypeTestBasicType* _tmp21_;
		GXmlGDocument* _tmp22_;
		SerializableBasicTypeTestBasicType* _tmp23_;
		gfloat _tmp24_;
		gfloat _tmp25_;
		GXmlGDocument* doc4 = NULL;
		GXmlGDocument* _tmp26_;
		SerializableBasicTypeTestBasicType* _tmp27_;
		GXmlGDocument* _tmp28_;
		SerializableBasicTypeTestBasicType* _tmp29_;
		gfloat _tmp30_;
		gfloat _tmp31_;
		GXmlGDocument* doc5 = NULL;
		GXmlGDocument* _tmp32_;
		SerializableBasicTypeTestBasicType* _tmp33_;
		GXmlGDocument* _tmp34_;
		SerializableBasicTypeTestBasicType* _tmp35_;
		gfloat _tmp36_;
		gfloat _tmp37_;
		GXmlGDocument* doc6 = NULL;
		GXmlGDocument* _tmp38_;
		SerializableBasicTypeTestBasicType* _tmp39_;
		GXmlGDocument* _tmp40_;
		SerializableBasicTypeTestBasicType* _tmp41_;
		gfloat _tmp42_;
		gfloat _tmp43_;
		GXmlGDocument* doc7 = NULL;
		GXmlGDocument* _tmp44_;
		SerializableBasicTypeTestBasicType* _tmp45_;
		SerializableBasicTypeTestBasicType* _tmp46_;
		GXmlGDocument* _tmp47_;
		SerializableBasicTypeTestBasicType* _tmp48_;
		gfloat _tmp49_;
		gfloat _tmp50_;
#line 120 "SerializableBasicTypesTest.vala"
		_tmp0_ = serializable_basic_type_test_basic_type_new ();
#line 120 "SerializableBasicTypesTest.vala"
		bt = _tmp0_;
#line 121 "SerializableBasicTypesTest.vala"
		_tmp1_ = bt;
#line 121 "SerializableBasicTypesTest.vala"
		serializable_basic_type_test_basic_type_set_boolean (_tmp1_, TRUE);
#line 122 "SerializableBasicTypesTest.vala"
		_tmp2_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype floatval=\"156\"/>", 0, &_inner_error0_);
#line 122 "SerializableBasicTypesTest.vala"
		doc = _tmp2_;
#line 122 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 122 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1118 "SerializableBasicTypesTest.c"
			goto __catch378_g_error;
		}
#line 124 "SerializableBasicTypesTest.vala"
		_tmp3_ = bt;
#line 124 "SerializableBasicTypesTest.vala"
		_tmp4_ = doc;
#line 124 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp3_, (GXmlNode*) _tmp4_, &_inner_error0_);
#line 124 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 124 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 124 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1133 "SerializableBasicTypesTest.c"
			goto __catch378_g_error;
		}
#line 125 "SerializableBasicTypesTest.vala"
		_tmp5_ = bt;
#line 125 "SerializableBasicTypesTest.vala"
		_tmp6_ = serializable_basic_type_test_basic_type_get_floatval (_tmp5_);
#line 125 "SerializableBasicTypesTest.vala"
		_tmp7_ = _tmp6_;
#line 125 "SerializableBasicTypesTest.vala"
		_vala_assert (((gdouble) _tmp7_) == 156.0, "bt.floatval == 156.0");
#line 126 "SerializableBasicTypesTest.vala"
		_tmp8_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype floatval=\"a156\"/>", 0, &_inner_error0_);
#line 126 "SerializableBasicTypesTest.vala"
		doc1 = _tmp8_;
#line 126 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 126 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 126 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1154 "SerializableBasicTypesTest.c"
			goto __catch378_g_error;
		}
#line 128 "SerializableBasicTypesTest.vala"
		_tmp9_ = bt;
#line 128 "SerializableBasicTypesTest.vala"
		_tmp10_ = doc1;
#line 128 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp9_, (GXmlNode*) _tmp10_, &_inner_error0_);
#line 128 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 128 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 128 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 128 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1171 "SerializableBasicTypesTest.c"
			goto __catch378_g_error;
		}
#line 129 "SerializableBasicTypesTest.vala"
		_tmp11_ = bt;
#line 129 "SerializableBasicTypesTest.vala"
		_tmp12_ = serializable_basic_type_test_basic_type_get_floatval (_tmp11_);
#line 129 "SerializableBasicTypesTest.vala"
		_tmp13_ = _tmp12_;
#line 129 "SerializableBasicTypesTest.vala"
		_vala_assert (((gdouble) _tmp13_) == 0.0, "bt.floatval == 0.0");
#line 130 "SerializableBasicTypesTest.vala"
		_tmp14_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype floatval=\"156b\"/>", 0, &_inner_error0_);
#line 130 "SerializableBasicTypesTest.vala"
		doc2 = _tmp14_;
#line 130 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 130 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 130 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 130 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1194 "SerializableBasicTypesTest.c"
			goto __catch378_g_error;
		}
#line 132 "SerializableBasicTypesTest.vala"
		_tmp15_ = bt;
#line 132 "SerializableBasicTypesTest.vala"
		_tmp16_ = doc2;
#line 132 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp15_, (GXmlNode*) _tmp16_, &_inner_error0_);
#line 132 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 132 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 132 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 132 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 132 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1213 "SerializableBasicTypesTest.c"
			goto __catch378_g_error;
		}
#line 133 "SerializableBasicTypesTest.vala"
		_tmp17_ = bt;
#line 133 "SerializableBasicTypesTest.vala"
		_tmp18_ = serializable_basic_type_test_basic_type_get_floatval (_tmp17_);
#line 133 "SerializableBasicTypesTest.vala"
		_tmp19_ = _tmp18_;
#line 133 "SerializableBasicTypesTest.vala"
		_vala_assert (((gdouble) _tmp19_) == 156.0, "bt.floatval == 156.0");
#line 134 "SerializableBasicTypesTest.vala"
		_tmp20_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype floatval=\"156.0\"/>", 0, &_inner_error0_);
#line 134 "SerializableBasicTypesTest.vala"
		doc3 = _tmp20_;
#line 134 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 134 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 134 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 134 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 134 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1238 "SerializableBasicTypesTest.c"
			goto __catch378_g_error;
		}
#line 136 "SerializableBasicTypesTest.vala"
		_tmp21_ = bt;
#line 136 "SerializableBasicTypesTest.vala"
		_tmp22_ = doc3;
#line 136 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp21_, (GXmlNode*) _tmp22_, &_inner_error0_);
#line 136 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 136 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 136 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 136 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 136 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 136 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1259 "SerializableBasicTypesTest.c"
			goto __catch378_g_error;
		}
#line 137 "SerializableBasicTypesTest.vala"
		_tmp23_ = bt;
#line 137 "SerializableBasicTypesTest.vala"
		_tmp24_ = serializable_basic_type_test_basic_type_get_floatval (_tmp23_);
#line 137 "SerializableBasicTypesTest.vala"
		_tmp25_ = _tmp24_;
#line 137 "SerializableBasicTypesTest.vala"
		_vala_assert (((gdouble) _tmp25_) == 156.0, "bt.floatval == 156.0");
#line 138 "SerializableBasicTypesTest.vala"
		_tmp26_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype floatval=\"0.156\"/>", 0, &_inner_error0_);
#line 138 "SerializableBasicTypesTest.vala"
		doc4 = _tmp26_;
#line 138 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 138 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 138 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 138 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 138 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 138 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1286 "SerializableBasicTypesTest.c"
			goto __catch378_g_error;
		}
#line 140 "SerializableBasicTypesTest.vala"
		_tmp27_ = bt;
#line 140 "SerializableBasicTypesTest.vala"
		_tmp28_ = doc4;
#line 140 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp27_, (GXmlNode*) _tmp28_, &_inner_error0_);
#line 140 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 140 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 140 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 140 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 140 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 140 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 140 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1309 "SerializableBasicTypesTest.c"
			goto __catch378_g_error;
		}
#line 141 "SerializableBasicTypesTest.vala"
		_tmp29_ = bt;
#line 141 "SerializableBasicTypesTest.vala"
		_tmp30_ = serializable_basic_type_test_basic_type_get_floatval (_tmp29_);
#line 141 "SerializableBasicTypesTest.vala"
		_tmp31_ = _tmp30_;
#line 141 "SerializableBasicTypesTest.vala"
		_vala_assert (_tmp31_ == ((gfloat) 0.156), "bt.floatval == (float) 0.156");
#line 142 "SerializableBasicTypesTest.vala"
		_tmp32_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype floatval=\"a156.156\"/>", 0, &_inner_error0_);
#line 142 "SerializableBasicTypesTest.vala"
		doc5 = _tmp32_;
#line 142 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 142 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 142 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 142 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 142 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 142 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 142 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1338 "SerializableBasicTypesTest.c"
			goto __catch378_g_error;
		}
#line 144 "SerializableBasicTypesTest.vala"
		_tmp33_ = bt;
#line 144 "SerializableBasicTypesTest.vala"
		_tmp34_ = doc5;
#line 144 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp33_, (GXmlNode*) _tmp34_, &_inner_error0_);
#line 144 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 144 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 144 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 144 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 144 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 144 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 144 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 144 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1363 "SerializableBasicTypesTest.c"
			goto __catch378_g_error;
		}
#line 145 "SerializableBasicTypesTest.vala"
		_tmp35_ = bt;
#line 145 "SerializableBasicTypesTest.vala"
		_tmp36_ = serializable_basic_type_test_basic_type_get_floatval (_tmp35_);
#line 145 "SerializableBasicTypesTest.vala"
		_tmp37_ = _tmp36_;
#line 145 "SerializableBasicTypesTest.vala"
		_vala_assert (((gdouble) _tmp37_) == 0.0, "bt.floatval == 0.0");
#line 146 "SerializableBasicTypesTest.vala"
		_tmp38_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype floatval=\"156.156b\"/>", 0, &_inner_error0_);
#line 146 "SerializableBasicTypesTest.vala"
		doc6 = _tmp38_;
#line 146 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 146 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 146 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 146 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 146 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 146 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 146 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 146 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1394 "SerializableBasicTypesTest.c"
			goto __catch378_g_error;
		}
#line 148 "SerializableBasicTypesTest.vala"
		_tmp39_ = bt;
#line 148 "SerializableBasicTypesTest.vala"
		_tmp40_ = doc6;
#line 148 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp39_, (GXmlNode*) _tmp40_, &_inner_error0_);
#line 148 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 148 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc6);
#line 148 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 148 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 148 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 148 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 148 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 148 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 148 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1421 "SerializableBasicTypesTest.c"
			goto __catch378_g_error;
		}
#line 149 "SerializableBasicTypesTest.vala"
		_tmp41_ = bt;
#line 149 "SerializableBasicTypesTest.vala"
		_tmp42_ = serializable_basic_type_test_basic_type_get_floatval (_tmp41_);
#line 149 "SerializableBasicTypesTest.vala"
		_tmp43_ = _tmp42_;
#line 149 "SerializableBasicTypesTest.vala"
		_vala_assert (_tmp43_ == ((gfloat) 156.156), "bt.floatval == (float) 156.156");
#line 150 "SerializableBasicTypesTest.vala"
		_tmp44_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype boolean=\"true\"/>", 0, &_inner_error0_);
#line 150 "SerializableBasicTypesTest.vala"
		doc7 = _tmp44_;
#line 150 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 150 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc6);
#line 150 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 150 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 150 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 150 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 150 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 150 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 150 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1454 "SerializableBasicTypesTest.c"
			goto __catch378_g_error;
		}
#line 152 "SerializableBasicTypesTest.vala"
		_tmp45_ = bt;
#line 152 "SerializableBasicTypesTest.vala"
		serializable_basic_type_test_basic_type_set_floatval (_tmp45_, (gfloat) 0.0);
#line 153 "SerializableBasicTypesTest.vala"
		_tmp46_ = bt;
#line 153 "SerializableBasicTypesTest.vala"
		_tmp47_ = doc7;
#line 153 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp46_, (GXmlNode*) _tmp47_, &_inner_error0_);
#line 153 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 153 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc7);
#line 153 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc6);
#line 153 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 153 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 153 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 153 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 153 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 153 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 153 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1487 "SerializableBasicTypesTest.c"
			goto __catch378_g_error;
		}
#line 154 "SerializableBasicTypesTest.vala"
		_tmp48_ = bt;
#line 154 "SerializableBasicTypesTest.vala"
		_tmp49_ = serializable_basic_type_test_basic_type_get_floatval (_tmp48_);
#line 154 "SerializableBasicTypesTest.vala"
		_tmp50_ = _tmp49_;
#line 154 "SerializableBasicTypesTest.vala"
		_vala_assert (((gdouble) _tmp50_) == 0.0, "bt.floatval == 0.0");
#line 119 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc7);
#line 119 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc6);
#line 119 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc5);
#line 119 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc4);
#line 119 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc3);
#line 119 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc2);
#line 119 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc1);
#line 119 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc);
#line 119 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (bt);
#line 1516 "SerializableBasicTypesTest.c"
	}
	goto __finally378;
	__catch378_g_error:
	{
		GError* e = NULL;
		FILE* _tmp51_;
		const gchar* _tmp52_;
		const gchar* _tmp53_;
		gchar* _tmp54_;
		gchar* _tmp55_;
#line 119 "SerializableBasicTypesTest.vala"
		e = _inner_error0_;
#line 119 "SerializableBasicTypesTest.vala"
		_inner_error0_ = NULL;
#line 156 "SerializableBasicTypesTest.vala"
		_tmp51_ = stdout;
#line 156 "SerializableBasicTypesTest.vala"
		_tmp52_ = e->message;
#line 156 "SerializableBasicTypesTest.vala"
		_tmp53_ = string_to_string (_tmp52_);
#line 156 "SerializableBasicTypesTest.vala"
		_tmp54_ = g_strconcat ("ERROR: ", _tmp53_, NULL);
#line 156 "SerializableBasicTypesTest.vala"
		_tmp55_ = _tmp54_;
#line 156 "SerializableBasicTypesTest.vala"
		fprintf (_tmp51_, "%s", _tmp55_);
#line 156 "SerializableBasicTypesTest.vala"
		_g_free0 (_tmp55_);
#line 157 "SerializableBasicTypesTest.vala"
		g_assert_not_reached ();
#line 119 "SerializableBasicTypesTest.vala"
		_g_error_free0 (e);
#line 1549 "SerializableBasicTypesTest.c"
	}
	__finally378:
#line 119 "SerializableBasicTypesTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 119 "SerializableBasicTypesTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 119 "SerializableBasicTypesTest.vala"
		g_clear_error (&_inner_error0_);
#line 119 "SerializableBasicTypesTest.vala"
		return;
#line 1560 "SerializableBasicTypesTest.c"
	}
}

static void
___lambda328__gtest_func (void)
{
#line 117 "SerializableBasicTypesTest.vala"
	__lambda328_ ();
#line 1569 "SerializableBasicTypesTest.c"
}

static void
__lambda329_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		SerializableBasicTypeTestBasicType* bt = NULL;
		SerializableBasicTypeTestBasicType* _tmp0_;
		SerializableBasicTypeTestBasicType* _tmp1_;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp2_;
		SerializableBasicTypeTestBasicType* _tmp3_;
		GXmlGDocument* _tmp4_;
		SerializableBasicTypeTestBasicType* _tmp5_;
		gdouble _tmp6_;
		gdouble _tmp7_;
		GXmlGDocument* doc1 = NULL;
		GXmlGDocument* _tmp8_;
		SerializableBasicTypeTestBasicType* _tmp9_;
		GXmlGDocument* _tmp10_;
		SerializableBasicTypeTestBasicType* _tmp11_;
		gdouble _tmp12_;
		gdouble _tmp13_;
		GXmlGDocument* doc2 = NULL;
		GXmlGDocument* _tmp14_;
		SerializableBasicTypeTestBasicType* _tmp15_;
		GXmlGDocument* _tmp16_;
		SerializableBasicTypeTestBasicType* _tmp17_;
		gdouble _tmp18_;
		gdouble _tmp19_;
		GXmlGDocument* doc3 = NULL;
		GXmlGDocument* _tmp20_;
		SerializableBasicTypeTestBasicType* _tmp21_;
		GXmlGDocument* _tmp22_;
		SerializableBasicTypeTestBasicType* _tmp23_;
		gdouble _tmp24_;
		gdouble _tmp25_;
		GXmlGDocument* doc4 = NULL;
		GXmlGDocument* _tmp26_;
		SerializableBasicTypeTestBasicType* _tmp27_;
		GXmlGDocument* _tmp28_;
		SerializableBasicTypeTestBasicType* _tmp29_;
		gdouble _tmp30_;
		gdouble _tmp31_;
		GXmlGDocument* doc5 = NULL;
		GXmlGDocument* _tmp32_;
		SerializableBasicTypeTestBasicType* _tmp33_;
		GXmlGDocument* _tmp34_;
		SerializableBasicTypeTestBasicType* _tmp35_;
		gdouble _tmp36_;
		gdouble _tmp37_;
		GXmlGDocument* doc6 = NULL;
		GXmlGDocument* _tmp38_;
		SerializableBasicTypeTestBasicType* _tmp39_;
		GXmlGDocument* _tmp40_;
		SerializableBasicTypeTestBasicType* _tmp41_;
		gdouble _tmp42_;
		gdouble _tmp43_;
		GXmlGDocument* doc7 = NULL;
		GXmlGDocument* _tmp44_;
		SerializableBasicTypeTestBasicType* _tmp45_;
		SerializableBasicTypeTestBasicType* _tmp46_;
		GXmlGDocument* _tmp47_;
		SerializableBasicTypeTestBasicType* _tmp48_;
		gdouble _tmp49_;
		gdouble _tmp50_;
#line 163 "SerializableBasicTypesTest.vala"
		_tmp0_ = serializable_basic_type_test_basic_type_new ();
#line 163 "SerializableBasicTypesTest.vala"
		bt = _tmp0_;
#line 164 "SerializableBasicTypesTest.vala"
		_tmp1_ = bt;
#line 164 "SerializableBasicTypesTest.vala"
		serializable_basic_type_test_basic_type_set_boolean (_tmp1_, TRUE);
#line 165 "SerializableBasicTypesTest.vala"
		_tmp2_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype doubleval=\"156\"/>", 0, &_inner_error0_);
#line 165 "SerializableBasicTypesTest.vala"
		doc = _tmp2_;
#line 165 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 165 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1653 "SerializableBasicTypesTest.c"
			goto __catch379_g_error;
		}
#line 167 "SerializableBasicTypesTest.vala"
		_tmp3_ = bt;
#line 167 "SerializableBasicTypesTest.vala"
		_tmp4_ = doc;
#line 167 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp3_, (GXmlNode*) _tmp4_, &_inner_error0_);
#line 167 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 167 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 167 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1668 "SerializableBasicTypesTest.c"
			goto __catch379_g_error;
		}
#line 168 "SerializableBasicTypesTest.vala"
		_tmp5_ = bt;
#line 168 "SerializableBasicTypesTest.vala"
		_tmp6_ = serializable_basic_type_test_basic_type_get_doubleval (_tmp5_);
#line 168 "SerializableBasicTypesTest.vala"
		_tmp7_ = _tmp6_;
#line 168 "SerializableBasicTypesTest.vala"
		_vala_assert (_tmp7_ == 156.0, "bt.doubleval == 156.0");
#line 169 "SerializableBasicTypesTest.vala"
		_tmp8_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype doubleval=\"a156\"/>", 0, &_inner_error0_);
#line 169 "SerializableBasicTypesTest.vala"
		doc1 = _tmp8_;
#line 169 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 169 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 169 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1689 "SerializableBasicTypesTest.c"
			goto __catch379_g_error;
		}
#line 171 "SerializableBasicTypesTest.vala"
		_tmp9_ = bt;
#line 171 "SerializableBasicTypesTest.vala"
		_tmp10_ = doc1;
#line 171 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp9_, (GXmlNode*) _tmp10_, &_inner_error0_);
#line 171 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 171 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 171 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 171 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1706 "SerializableBasicTypesTest.c"
			goto __catch379_g_error;
		}
#line 172 "SerializableBasicTypesTest.vala"
		_tmp11_ = bt;
#line 172 "SerializableBasicTypesTest.vala"
		_tmp12_ = serializable_basic_type_test_basic_type_get_doubleval (_tmp11_);
#line 172 "SerializableBasicTypesTest.vala"
		_tmp13_ = _tmp12_;
#line 172 "SerializableBasicTypesTest.vala"
		_vala_assert (_tmp13_ == 0.0, "bt.doubleval == 0.0");
#line 173 "SerializableBasicTypesTest.vala"
		_tmp14_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype doubleval=\"156b\"/>", 0, &_inner_error0_);
#line 173 "SerializableBasicTypesTest.vala"
		doc2 = _tmp14_;
#line 173 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 173 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 173 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 173 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1729 "SerializableBasicTypesTest.c"
			goto __catch379_g_error;
		}
#line 175 "SerializableBasicTypesTest.vala"
		_tmp15_ = bt;
#line 175 "SerializableBasicTypesTest.vala"
		_tmp16_ = doc2;
#line 175 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp15_, (GXmlNode*) _tmp16_, &_inner_error0_);
#line 175 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 175 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 175 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 175 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 175 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1748 "SerializableBasicTypesTest.c"
			goto __catch379_g_error;
		}
#line 176 "SerializableBasicTypesTest.vala"
		_tmp17_ = bt;
#line 176 "SerializableBasicTypesTest.vala"
		_tmp18_ = serializable_basic_type_test_basic_type_get_doubleval (_tmp17_);
#line 176 "SerializableBasicTypesTest.vala"
		_tmp19_ = _tmp18_;
#line 176 "SerializableBasicTypesTest.vala"
		_vala_assert (_tmp19_ == 156.0, "bt.doubleval == 156.0");
#line 177 "SerializableBasicTypesTest.vala"
		_tmp20_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype doubleval=\"156.0\"/>", 0, &_inner_error0_);
#line 177 "SerializableBasicTypesTest.vala"
		doc3 = _tmp20_;
#line 177 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 177 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 177 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 177 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 177 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1773 "SerializableBasicTypesTest.c"
			goto __catch379_g_error;
		}
#line 179 "SerializableBasicTypesTest.vala"
		_tmp21_ = bt;
#line 179 "SerializableBasicTypesTest.vala"
		_tmp22_ = doc3;
#line 179 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp21_, (GXmlNode*) _tmp22_, &_inner_error0_);
#line 179 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 179 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 179 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 179 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 179 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 179 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1794 "SerializableBasicTypesTest.c"
			goto __catch379_g_error;
		}
#line 180 "SerializableBasicTypesTest.vala"
		_tmp23_ = bt;
#line 180 "SerializableBasicTypesTest.vala"
		_tmp24_ = serializable_basic_type_test_basic_type_get_doubleval (_tmp23_);
#line 180 "SerializableBasicTypesTest.vala"
		_tmp25_ = _tmp24_;
#line 180 "SerializableBasicTypesTest.vala"
		_vala_assert (_tmp25_ == 156.0, "bt.doubleval == 156.0");
#line 181 "SerializableBasicTypesTest.vala"
		_tmp26_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype doubleval=\"0.156\"/>", 0, &_inner_error0_);
#line 181 "SerializableBasicTypesTest.vala"
		doc4 = _tmp26_;
#line 181 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 181 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 181 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 181 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 181 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 181 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1821 "SerializableBasicTypesTest.c"
			goto __catch379_g_error;
		}
#line 183 "SerializableBasicTypesTest.vala"
		_tmp27_ = bt;
#line 183 "SerializableBasicTypesTest.vala"
		_tmp28_ = doc4;
#line 183 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp27_, (GXmlNode*) _tmp28_, &_inner_error0_);
#line 183 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 183 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 183 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 183 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 183 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 183 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 183 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1844 "SerializableBasicTypesTest.c"
			goto __catch379_g_error;
		}
#line 184 "SerializableBasicTypesTest.vala"
		_tmp29_ = bt;
#line 184 "SerializableBasicTypesTest.vala"
		_tmp30_ = serializable_basic_type_test_basic_type_get_doubleval (_tmp29_);
#line 184 "SerializableBasicTypesTest.vala"
		_tmp31_ = _tmp30_;
#line 184 "SerializableBasicTypesTest.vala"
		_vala_assert (_tmp31_ == 0.156, "bt.doubleval == 0.156");
#line 185 "SerializableBasicTypesTest.vala"
		_tmp32_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype doubleval=\"a156.156\"/>", 0, &_inner_error0_);
#line 185 "SerializableBasicTypesTest.vala"
		doc5 = _tmp32_;
#line 185 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 185 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 185 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 185 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 185 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 185 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 185 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1873 "SerializableBasicTypesTest.c"
			goto __catch379_g_error;
		}
#line 187 "SerializableBasicTypesTest.vala"
		_tmp33_ = bt;
#line 187 "SerializableBasicTypesTest.vala"
		_tmp34_ = doc5;
#line 187 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp33_, (GXmlNode*) _tmp34_, &_inner_error0_);
#line 187 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 187 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 187 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 187 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 187 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 187 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 187 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 187 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1898 "SerializableBasicTypesTest.c"
			goto __catch379_g_error;
		}
#line 188 "SerializableBasicTypesTest.vala"
		_tmp35_ = bt;
#line 188 "SerializableBasicTypesTest.vala"
		_tmp36_ = serializable_basic_type_test_basic_type_get_doubleval (_tmp35_);
#line 188 "SerializableBasicTypesTest.vala"
		_tmp37_ = _tmp36_;
#line 188 "SerializableBasicTypesTest.vala"
		_vala_assert (_tmp37_ == 0.0, "bt.doubleval == 0.0");
#line 189 "SerializableBasicTypesTest.vala"
		_tmp38_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype doubleval=\"156.156b\"/>", 0, &_inner_error0_);
#line 189 "SerializableBasicTypesTest.vala"
		doc6 = _tmp38_;
#line 189 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 189 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 189 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 189 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 189 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 189 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 189 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 189 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1929 "SerializableBasicTypesTest.c"
			goto __catch379_g_error;
		}
#line 191 "SerializableBasicTypesTest.vala"
		_tmp39_ = bt;
#line 191 "SerializableBasicTypesTest.vala"
		_tmp40_ = doc6;
#line 191 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp39_, (GXmlNode*) _tmp40_, &_inner_error0_);
#line 191 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 191 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc6);
#line 191 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 191 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 191 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 191 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 191 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 191 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 191 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1956 "SerializableBasicTypesTest.c"
			goto __catch379_g_error;
		}
#line 192 "SerializableBasicTypesTest.vala"
		_tmp41_ = bt;
#line 192 "SerializableBasicTypesTest.vala"
		_tmp42_ = serializable_basic_type_test_basic_type_get_doubleval (_tmp41_);
#line 192 "SerializableBasicTypesTest.vala"
		_tmp43_ = _tmp42_;
#line 192 "SerializableBasicTypesTest.vala"
		_vala_assert (_tmp43_ == 156.156, "bt.doubleval == 156.156");
#line 193 "SerializableBasicTypesTest.vala"
		_tmp44_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<basictype boolean=\"true\"/>", 0, &_inner_error0_);
#line 193 "SerializableBasicTypesTest.vala"
		doc7 = _tmp44_;
#line 193 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 193 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc6);
#line 193 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 193 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 193 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 193 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 193 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 193 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 193 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 1989 "SerializableBasicTypesTest.c"
			goto __catch379_g_error;
		}
#line 195 "SerializableBasicTypesTest.vala"
		_tmp45_ = bt;
#line 195 "SerializableBasicTypesTest.vala"
		serializable_basic_type_test_basic_type_set_doubleval (_tmp45_, 0.0);
#line 196 "SerializableBasicTypesTest.vala"
		_tmp46_ = bt;
#line 196 "SerializableBasicTypesTest.vala"
		_tmp47_ = doc7;
#line 196 "SerializableBasicTypesTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp46_, (GXmlNode*) _tmp47_, &_inner_error0_);
#line 196 "SerializableBasicTypesTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 196 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc7);
#line 196 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc6);
#line 196 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc5);
#line 196 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc4);
#line 196 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc3);
#line 196 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc2);
#line 196 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc1);
#line 196 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (doc);
#line 196 "SerializableBasicTypesTest.vala"
			_g_object_unref0 (bt);
#line 2022 "SerializableBasicTypesTest.c"
			goto __catch379_g_error;
		}
#line 197 "SerializableBasicTypesTest.vala"
		_tmp48_ = bt;
#line 197 "SerializableBasicTypesTest.vala"
		_tmp49_ = serializable_basic_type_test_basic_type_get_doubleval (_tmp48_);
#line 197 "SerializableBasicTypesTest.vala"
		_tmp50_ = _tmp49_;
#line 197 "SerializableBasicTypesTest.vala"
		_vala_assert (_tmp50_ == 0.0, "bt.doubleval == 0.0");
#line 162 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc7);
#line 162 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc6);
#line 162 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc5);
#line 162 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc4);
#line 162 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc3);
#line 162 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc2);
#line 162 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc1);
#line 162 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (doc);
#line 162 "SerializableBasicTypesTest.vala"
		_g_object_unref0 (bt);
#line 2051 "SerializableBasicTypesTest.c"
	}
	goto __finally379;
	__catch379_g_error:
	{
		GError* e = NULL;
		FILE* _tmp51_;
		const gchar* _tmp52_;
		const gchar* _tmp53_;
		gchar* _tmp54_;
		gchar* _tmp55_;
#line 162 "SerializableBasicTypesTest.vala"
		e = _inner_error0_;
#line 162 "SerializableBasicTypesTest.vala"
		_inner_error0_ = NULL;
#line 199 "SerializableBasicTypesTest.vala"
		_tmp51_ = stdout;
#line 199 "SerializableBasicTypesTest.vala"
		_tmp52_ = e->message;
#line 199 "SerializableBasicTypesTest.vala"
		_tmp53_ = string_to_string (_tmp52_);
#line 199 "SerializableBasicTypesTest.vala"
		_tmp54_ = g_strconcat ("ERROR: ", _tmp53_, NULL);
#line 199 "SerializableBasicTypesTest.vala"
		_tmp55_ = _tmp54_;
#line 199 "SerializableBasicTypesTest.vala"
		fprintf (_tmp51_, "%s", _tmp55_);
#line 199 "SerializableBasicTypesTest.vala"
		_g_free0 (_tmp55_);
#line 200 "SerializableBasicTypesTest.vala"
		g_assert_not_reached ();
#line 162 "SerializableBasicTypesTest.vala"
		_g_error_free0 (e);
#line 2084 "SerializableBasicTypesTest.c"
	}
	__finally379:
#line 162 "SerializableBasicTypesTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 162 "SerializableBasicTypesTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 162 "SerializableBasicTypesTest.vala"
		g_clear_error (&_inner_error0_);
#line 162 "SerializableBasicTypesTest.vala"
		return;
#line 2095 "SerializableBasicTypesTest.c"
	}
}

static void
___lambda329__gtest_func (void)
{
#line 160 "SerializableBasicTypesTest.vala"
	__lambda329_ ();
#line 2104 "SerializableBasicTypesTest.c"
}

void
serializable_basic_type_test_add_tests (void)
{
#line 38 "SerializableBasicTypesTest.vala"
	g_test_add_func ("/gxml/serializable/basic_types/boolean/serialize", ___lambda325__gtest_func);
#line 61 "SerializableBasicTypesTest.vala"
	g_test_add_func ("/gxml/serializable/basic_types/boolean/deserialize", ___lambda326__gtest_func);
#line 79 "SerializableBasicTypesTest.vala"
	g_test_add_func ("/gxml/serializable/basic_types/integer", ___lambda327__gtest_func);
#line 117 "SerializableBasicTypesTest.vala"
	g_test_add_func ("/gxml/serializable/basic_types/float", ___lambda328__gtest_func);
#line 160 "SerializableBasicTypesTest.vala"
	g_test_add_func ("/gxml/serializable/basic_types/double", ___lambda329__gtest_func);
#line 2120 "SerializableBasicTypesTest.c"
}

SerializableBasicTypeTest*
serializable_basic_type_test_construct (GType object_type)
{
	SerializableBasicTypeTest* self = NULL;
#line 27 "SerializableBasicTypesTest.vala"
	self = (SerializableBasicTypeTest*) gxml_test_construct (object_type);
#line 27 "SerializableBasicTypesTest.vala"
	return self;
#line 2131 "SerializableBasicTypesTest.c"
}

SerializableBasicTypeTest*
serializable_basic_type_test_new (void)
{
#line 27 "SerializableBasicTypesTest.vala"
	return serializable_basic_type_test_construct (TYPE_SERIALIZABLE_BASIC_TYPE_TEST);
#line 2139 "SerializableBasicTypesTest.c"
}

static inline gpointer
serializable_basic_type_test_basic_type_get_instance_private (SerializableBasicTypeTestBasicType* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableBasicTypeTestBasicType_private_offset);
}

static gchar*
serializable_basic_type_test_basic_type_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableBasicTypeTestBasicType * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 34 "SerializableBasicTypesTest.vala"
	self = (SerializableBasicTypeTestBasicType*) base;
#line 34 "SerializableBasicTypesTest.vala"
	_tmp0_ = g_strdup ("basictype");
#line 34 "SerializableBasicTypesTest.vala"
	result = _tmp0_;
#line 34 "SerializableBasicTypesTest.vala"
	return result;
#line 2162 "SerializableBasicTypesTest.c"
}

static gchar*
serializable_basic_type_test_basic_type_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableBasicTypeTestBasicType * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 35 "SerializableBasicTypesTest.vala"
	self = (SerializableBasicTypeTestBasicType*) base;
#line 35 "SerializableBasicTypesTest.vala"
	_tmp0_ = g_type_name (G_TYPE_FROM_INSTANCE ((GObject*) self));
#line 35 "SerializableBasicTypesTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 35 "SerializableBasicTypesTest.vala"
	result = _tmp1_;
#line 35 "SerializableBasicTypesTest.vala"
	return result;
#line 2182 "SerializableBasicTypesTest.c"
}

SerializableBasicTypeTestBasicType*
serializable_basic_type_test_basic_type_construct (GType object_type)
{
	SerializableBasicTypeTestBasicType * self = NULL;
#line 28 "SerializableBasicTypesTest.vala"
	self = (SerializableBasicTypeTestBasicType*) gxml_serializable_object_model_construct (object_type);
#line 28 "SerializableBasicTypesTest.vala"
	return self;
#line 2193 "SerializableBasicTypesTest.c"
}

SerializableBasicTypeTestBasicType*
serializable_basic_type_test_basic_type_new (void)
{
#line 28 "SerializableBasicTypesTest.vala"
	return serializable_basic_type_test_basic_type_construct (SERIALIZABLE_BASIC_TYPE_TEST_TYPE_BASIC_TYPE);
#line 2201 "SerializableBasicTypesTest.c"
}

gboolean
serializable_basic_type_test_basic_type_get_boolean (SerializableBasicTypeTestBasicType* self)
{
	gboolean result;
#line 30 "SerializableBasicTypesTest.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 30 "SerializableBasicTypesTest.vala"
	result = self->priv->_boolean;
#line 30 "SerializableBasicTypesTest.vala"
	return result;
#line 2214 "SerializableBasicTypesTest.c"
}

void
serializable_basic_type_test_basic_type_set_boolean (SerializableBasicTypeTestBasicType* self,
                                                     gboolean value)
{
#line 30 "SerializableBasicTypesTest.vala"
	g_return_if_fail (self != NULL);
#line 30 "SerializableBasicTypesTest.vala"
	if (serializable_basic_type_test_basic_type_get_boolean (self) != value) {
#line 30 "SerializableBasicTypesTest.vala"
		self->priv->_boolean = value;
#line 30 "SerializableBasicTypesTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_basic_type_test_basic_type_properties[SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_BOOLEAN_PROPERTY]);
#line 2229 "SerializableBasicTypesTest.c"
	}
}

gint
serializable_basic_type_test_basic_type_get_integer (SerializableBasicTypeTestBasicType* self)
{
	gint result;
#line 31 "SerializableBasicTypesTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 31 "SerializableBasicTypesTest.vala"
	result = self->priv->_integer;
#line 31 "SerializableBasicTypesTest.vala"
	return result;
#line 2243 "SerializableBasicTypesTest.c"
}

void
serializable_basic_type_test_basic_type_set_integer (SerializableBasicTypeTestBasicType* self,
                                                     gint value)
{
#line 31 "SerializableBasicTypesTest.vala"
	g_return_if_fail (self != NULL);
#line 31 "SerializableBasicTypesTest.vala"
	if (serializable_basic_type_test_basic_type_get_integer (self) != value) {
#line 31 "SerializableBasicTypesTest.vala"
		self->priv->_integer = value;
#line 31 "SerializableBasicTypesTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_basic_type_test_basic_type_properties[SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_INTEGER_PROPERTY]);
#line 2258 "SerializableBasicTypesTest.c"
	}
}

gfloat
serializable_basic_type_test_basic_type_get_floatval (SerializableBasicTypeTestBasicType* self)
{
	gfloat result;
#line 32 "SerializableBasicTypesTest.vala"
	g_return_val_if_fail (self != NULL, 0.0F);
#line 32 "SerializableBasicTypesTest.vala"
	result = self->priv->_floatval;
#line 32 "SerializableBasicTypesTest.vala"
	return result;
#line 2272 "SerializableBasicTypesTest.c"
}

void
serializable_basic_type_test_basic_type_set_floatval (SerializableBasicTypeTestBasicType* self,
                                                      gfloat value)
{
#line 32 "SerializableBasicTypesTest.vala"
	g_return_if_fail (self != NULL);
#line 32 "SerializableBasicTypesTest.vala"
	if (serializable_basic_type_test_basic_type_get_floatval (self) != value) {
#line 32 "SerializableBasicTypesTest.vala"
		self->priv->_floatval = value;
#line 32 "SerializableBasicTypesTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_basic_type_test_basic_type_properties[SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_FLOATVAL_PROPERTY]);
#line 2287 "SerializableBasicTypesTest.c"
	}
}

gdouble
serializable_basic_type_test_basic_type_get_doubleval (SerializableBasicTypeTestBasicType* self)
{
	gdouble result;
#line 33 "SerializableBasicTypesTest.vala"
	g_return_val_if_fail (self != NULL, 0.0);
#line 33 "SerializableBasicTypesTest.vala"
	result = self->priv->_doubleval;
#line 33 "SerializableBasicTypesTest.vala"
	return result;
#line 2301 "SerializableBasicTypesTest.c"
}

void
serializable_basic_type_test_basic_type_set_doubleval (SerializableBasicTypeTestBasicType* self,
                                                       gdouble value)
{
#line 33 "SerializableBasicTypesTest.vala"
	g_return_if_fail (self != NULL);
#line 33 "SerializableBasicTypesTest.vala"
	if (serializable_basic_type_test_basic_type_get_doubleval (self) != value) {
#line 33 "SerializableBasicTypesTest.vala"
		self->priv->_doubleval = value;
#line 33 "SerializableBasicTypesTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_basic_type_test_basic_type_properties[SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_DOUBLEVAL_PROPERTY]);
#line 2316 "SerializableBasicTypesTest.c"
	}
}

static void
serializable_basic_type_test_basic_type_class_init (SerializableBasicTypeTestBasicTypeClass * klass,
                                                    gpointer klass_data)
{
#line 28 "SerializableBasicTypesTest.vala"
	serializable_basic_type_test_basic_type_parent_class = g_type_class_peek_parent (klass);
#line 28 "SerializableBasicTypesTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableBasicTypeTestBasicType_private_offset);
#line 28 "SerializableBasicTypesTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_basic_type_test_basic_type_real_node_name;
#line 28 "SerializableBasicTypesTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_basic_type_test_basic_type_real_to_string;
#line 28 "SerializableBasicTypesTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_basic_type_test_basic_type_get_property;
#line 28 "SerializableBasicTypesTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_basic_type_test_basic_type_set_property;
#line 28 "SerializableBasicTypesTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_basic_type_test_basic_type_finalize;
#line 28 "SerializableBasicTypesTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_BOOLEAN_PROPERTY, serializable_basic_type_test_basic_type_properties[SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_BOOLEAN_PROPERTY] = g_param_spec_boolean ("boolean", "boolean", "boolean", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 28 "SerializableBasicTypesTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_INTEGER_PROPERTY, serializable_basic_type_test_basic_type_properties[SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_INTEGER_PROPERTY] = g_param_spec_int ("integer", "integer", "integer", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 28 "SerializableBasicTypesTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_FLOATVAL_PROPERTY, serializable_basic_type_test_basic_type_properties[SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_FLOATVAL_PROPERTY] = g_param_spec_float ("floatval", "floatval", "floatval", -G_MAXFLOAT, G_MAXFLOAT, (gfloat) 0.0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 28 "SerializableBasicTypesTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_DOUBLEVAL_PROPERTY, serializable_basic_type_test_basic_type_properties[SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_DOUBLEVAL_PROPERTY] = g_param_spec_double ("doubleval", "doubleval", "doubleval", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2346 "SerializableBasicTypesTest.c"
}

static void
serializable_basic_type_test_basic_type_instance_init (SerializableBasicTypeTestBasicType * self,
                                                       gpointer klass)
{
#line 28 "SerializableBasicTypesTest.vala"
	self->priv = serializable_basic_type_test_basic_type_get_instance_private (self);
#line 31 "SerializableBasicTypesTest.vala"
	self->priv->_integer = 0;
#line 32 "SerializableBasicTypesTest.vala"
	self->priv->_floatval = (gfloat) 0.0;
#line 33 "SerializableBasicTypesTest.vala"
	self->priv->_doubleval = 0.0;
#line 2361 "SerializableBasicTypesTest.c"
}

static void
serializable_basic_type_test_basic_type_finalize (GObject * obj)
{
	SerializableBasicTypeTestBasicType * self;
#line 28 "SerializableBasicTypesTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_BASIC_TYPE_TEST_TYPE_BASIC_TYPE, SerializableBasicTypeTestBasicType);
#line 28 "SerializableBasicTypesTest.vala"
	G_OBJECT_CLASS (serializable_basic_type_test_basic_type_parent_class)->finalize (obj);
#line 2372 "SerializableBasicTypesTest.c"
}

GType
serializable_basic_type_test_basic_type_get_type (void)
{
	static volatile gsize serializable_basic_type_test_basic_type_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_basic_type_test_basic_type_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableBasicTypeTestBasicTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_basic_type_test_basic_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableBasicTypeTestBasicType), 0, (GInstanceInitFunc) serializable_basic_type_test_basic_type_instance_init, NULL };
		GType serializable_basic_type_test_basic_type_type_id;
		serializable_basic_type_test_basic_type_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableBasicTypeTestBasicType", &g_define_type_info, 0);
		SerializableBasicTypeTestBasicType_private_offset = g_type_add_instance_private (serializable_basic_type_test_basic_type_type_id, sizeof (SerializableBasicTypeTestBasicTypePrivate));
		g_once_init_leave (&serializable_basic_type_test_basic_type_type_id__volatile, serializable_basic_type_test_basic_type_type_id);
	}
	return serializable_basic_type_test_basic_type_type_id__volatile;
}

static void
_vala_serializable_basic_type_test_basic_type_get_property (GObject * object,
                                                            guint property_id,
                                                            GValue * value,
                                                            GParamSpec * pspec)
{
	SerializableBasicTypeTestBasicType * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_BASIC_TYPE_TEST_TYPE_BASIC_TYPE, SerializableBasicTypeTestBasicType);
#line 28 "SerializableBasicTypesTest.vala"
	switch (property_id) {
#line 28 "SerializableBasicTypesTest.vala"
		case SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_BOOLEAN_PROPERTY:
#line 28 "SerializableBasicTypesTest.vala"
		g_value_set_boolean (value, serializable_basic_type_test_basic_type_get_boolean (self));
#line 28 "SerializableBasicTypesTest.vala"
		break;
#line 28 "SerializableBasicTypesTest.vala"
		case SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_INTEGER_PROPERTY:
#line 28 "SerializableBasicTypesTest.vala"
		g_value_set_int (value, serializable_basic_type_test_basic_type_get_integer (self));
#line 28 "SerializableBasicTypesTest.vala"
		break;
#line 28 "SerializableBasicTypesTest.vala"
		case SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_FLOATVAL_PROPERTY:
#line 28 "SerializableBasicTypesTest.vala"
		g_value_set_float (value, serializable_basic_type_test_basic_type_get_floatval (self));
#line 28 "SerializableBasicTypesTest.vala"
		break;
#line 28 "SerializableBasicTypesTest.vala"
		case SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_DOUBLEVAL_PROPERTY:
#line 28 "SerializableBasicTypesTest.vala"
		g_value_set_double (value, serializable_basic_type_test_basic_type_get_doubleval (self));
#line 28 "SerializableBasicTypesTest.vala"
		break;
#line 2423 "SerializableBasicTypesTest.c"
		default:
#line 28 "SerializableBasicTypesTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 28 "SerializableBasicTypesTest.vala"
		break;
#line 2429 "SerializableBasicTypesTest.c"
	}
}

static void
_vala_serializable_basic_type_test_basic_type_set_property (GObject * object,
                                                            guint property_id,
                                                            const GValue * value,
                                                            GParamSpec * pspec)
{
	SerializableBasicTypeTestBasicType * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_BASIC_TYPE_TEST_TYPE_BASIC_TYPE, SerializableBasicTypeTestBasicType);
#line 28 "SerializableBasicTypesTest.vala"
	switch (property_id) {
#line 28 "SerializableBasicTypesTest.vala"
		case SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_BOOLEAN_PROPERTY:
#line 28 "SerializableBasicTypesTest.vala"
		serializable_basic_type_test_basic_type_set_boolean (self, g_value_get_boolean (value));
#line 28 "SerializableBasicTypesTest.vala"
		break;
#line 28 "SerializableBasicTypesTest.vala"
		case SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_INTEGER_PROPERTY:
#line 28 "SerializableBasicTypesTest.vala"
		serializable_basic_type_test_basic_type_set_integer (self, g_value_get_int (value));
#line 28 "SerializableBasicTypesTest.vala"
		break;
#line 28 "SerializableBasicTypesTest.vala"
		case SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_FLOATVAL_PROPERTY:
#line 28 "SerializableBasicTypesTest.vala"
		serializable_basic_type_test_basic_type_set_floatval (self, g_value_get_float (value));
#line 28 "SerializableBasicTypesTest.vala"
		break;
#line 28 "SerializableBasicTypesTest.vala"
		case SERIALIZABLE_BASIC_TYPE_TEST_BASIC_TYPE_DOUBLEVAL_PROPERTY:
#line 28 "SerializableBasicTypesTest.vala"
		serializable_basic_type_test_basic_type_set_doubleval (self, g_value_get_double (value));
#line 28 "SerializableBasicTypesTest.vala"
		break;
#line 2467 "SerializableBasicTypesTest.c"
		default:
#line 28 "SerializableBasicTypesTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 28 "SerializableBasicTypesTest.vala"
		break;
#line 2473 "SerializableBasicTypesTest.c"
	}
}

static void
serializable_basic_type_test_class_init (SerializableBasicTypeTestClass * klass,
                                         gpointer klass_data)
{
#line 27 "SerializableBasicTypesTest.vala"
	serializable_basic_type_test_parent_class = g_type_class_peek_parent (klass);
#line 2483 "SerializableBasicTypesTest.c"
}

static void
serializable_basic_type_test_instance_init (SerializableBasicTypeTest * self,
                                            gpointer klass)
{
}

/**
 *
 *  GXml.Serializable.BasicTypeTest
 *
 *  Authors:
 *
 *       Daniel Espinosa <esodan@gmail.com>
 *
 *
 *  Copyright (c) 2013-2015 Daniel Espinosa
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
GType
serializable_basic_type_test_get_type (void)
{
	static volatile gsize serializable_basic_type_test_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_basic_type_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableBasicTypeTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_basic_type_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableBasicTypeTest), 0, (GInstanceInitFunc) serializable_basic_type_test_instance_init, NULL };
		GType serializable_basic_type_test_type_id;
		serializable_basic_type_test_type_id = g_type_register_static (TYPE_GXML_TEST, "SerializableBasicTypeTest", &g_define_type_info, 0);
		g_once_init_leave (&serializable_basic_type_test_type_id__volatile, serializable_basic_type_test_type_id);
	}
	return serializable_basic_type_test_type_id__volatile;
}

