/* GomAttr.c generated by valac 0.44.3, the Vala compiler
 * generated from GomAttr.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */
/*
 *
 * Copyright (C) 2016  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gee.h>
#include <gio/gio.h>

#define GXML_TYPE_DOM_EVENT_TARGET (gxml_dom_event_target_get_type ())
#define GXML_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTarget))
#define GXML_IS_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_TARGET))
#define GXML_DOM_EVENT_TARGET_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTargetIface))

typedef struct _GXmlDomEventTarget GXmlDomEventTarget;
typedef struct _GXmlDomEventTargetIface GXmlDomEventTargetIface;

#define GXML_TYPE_DOM_EVENT_LISTENER (gxml_dom_event_listener_get_type ())
#define GXML_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListener))
#define GXML_IS_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_LISTENER))
#define GXML_DOM_EVENT_LISTENER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListenerIface))

typedef struct _GXmlDomEventListener GXmlDomEventListener;
typedef struct _GXmlDomEventListenerIface GXmlDomEventListenerIface;

#define GXML_TYPE_DOM_EVENT (gxml_dom_event_get_type ())
#define GXML_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEvent))
#define GXML_IS_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT))
#define GXML_DOM_EVENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEventIface))

typedef struct _GXmlDomEvent GXmlDomEvent;
typedef struct _GXmlDomEventIface GXmlDomEventIface;

#define GXML_TYPE_DOM_TIME_STAMP (gxml_dom_time_stamp_get_type ())
#define GXML_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStamp))
#define GXML_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))
#define GXML_IS_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_IS_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_DOM_TIME_STAMP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))

typedef struct _GXmlDomTimeStamp GXmlDomTimeStamp;
typedef struct _GXmlDomTimeStampClass GXmlDomTimeStampClass;
typedef enum  {
	GXML_DOM_EVENT_PHASE_NONE = 0,
	GXML_DOM_EVENT_PHASE_CAPTURING_PHASE,
	GXML_DOM_EVENT_PHASE_AT_TARGET,
	GXML_DOM_EVENT_PHASE_BUBBLING_PHASE
} GXmlDomEventPhase;

#define GXML_DOM_EVENT_TYPE_PHASE (gxml_dom_event_phase_get_type ())

#define GXML_TYPE_DOM_NODE (gxml_dom_node_get_type ())
#define GXML_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE, GXmlDomNode))
#define GXML_IS_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE))
#define GXML_DOM_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE, GXmlDomNodeIface))

typedef struct _GXmlDomNode GXmlDomNode;
typedef struct _GXmlDomNodeIface GXmlDomNodeIface;
typedef enum  {
	GXML_DOM_NODE_DOCUMENT_POSITION_NONE = 1 << 0,
	GXML_DOM_NODE_DOCUMENT_POSITION_DISCONNECTED = 1 << 1,
	GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING = 1 << 2,
	GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING = 1 << 3,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINS = 1 << 4,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINED_BY = 1 << 5,
	GXML_DOM_NODE_DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC = 1 << 6
} GXmlDomNodeDocumentPosition;

#define GXML_DOM_NODE_TYPE_DOCUMENT_POSITION (gxml_dom_node_document_position_get_type ())
typedef enum  {
	GXML_DOM_NODE_NODE_TYPE_INVALID = 0,
	GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE = 1,
	GXML_DOM_NODE_NODE_TYPE_ATTRIBUTE_NODE,
	GXML_DOM_NODE_NODE_TYPE_TEXT_NODE,
	GXML_DOM_NODE_NODE_TYPE_CDATA_SECTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_REFERENCE_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_NODE,
	GXML_DOM_NODE_NODE_TYPE_PROCESSING_INSTRUCTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_COMMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_FRAGMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_NOTATION_NODE
} GXmlDomNodeNodeType;

#define GXML_DOM_NODE_TYPE_NODE_TYPE (gxml_dom_node_node_type_get_type ())

#define GXML_TYPE_DOM_DOCUMENT (gxml_dom_document_get_type ())
#define GXML_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocument))
#define GXML_IS_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT))
#define GXML_DOM_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocumentIface))

typedef struct _GXmlDomDocument GXmlDomDocument;
typedef struct _GXmlDomDocumentIface GXmlDomDocumentIface;

#define GXML_TYPE_DOM_PARENT_NODE (gxml_dom_parent_node_get_type ())
#define GXML_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNode))
#define GXML_IS_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PARENT_NODE))
#define GXML_DOM_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNodeIface))

typedef struct _GXmlDomParentNode GXmlDomParentNode;
typedef struct _GXmlDomParentNodeIface GXmlDomParentNodeIface;

#define GXML_TYPE_DOM_ELEMENT (gxml_dom_element_get_type ())
#define GXML_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElement))
#define GXML_IS_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT))
#define GXML_DOM_ELEMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElementIface))

typedef struct _GXmlDomElement GXmlDomElement;
typedef struct _GXmlDomElementIface GXmlDomElementIface;

#define GXML_TYPE_DOM_CHILD_NODE (gxml_dom_child_node_get_type ())
#define GXML_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNode))
#define GXML_IS_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHILD_NODE))
#define GXML_DOM_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNodeIface))

typedef struct _GXmlDomChildNode GXmlDomChildNode;
typedef struct _GXmlDomChildNodeIface GXmlDomChildNodeIface;

#define GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE (gxml_dom_non_document_type_child_node_get_type ())
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNode))
#define GXML_IS_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE))
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNodeIface))

typedef struct _GXmlDomNonDocumentTypeChildNode GXmlDomNonDocumentTypeChildNode;
typedef struct _GXmlDomNonDocumentTypeChildNodeIface GXmlDomNonDocumentTypeChildNodeIface;

#define GXML_TYPE_DOM_HTML_COLLECTION (gxml_dom_html_collection_get_type ())
#define GXML_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollection))
#define GXML_IS_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_HTML_COLLECTION))
#define GXML_DOM_HTML_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollectionIface))

typedef struct _GXmlDomHTMLCollection GXmlDomHTMLCollection;
typedef struct _GXmlDomHTMLCollectionIface GXmlDomHTMLCollectionIface;

#define GXML_TYPE_DOM_TOKEN_LIST (gxml_dom_token_list_get_type ())
#define GXML_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenList))
#define GXML_IS_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TOKEN_LIST))
#define GXML_DOM_TOKEN_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenListIface))

typedef struct _GXmlDomTokenList GXmlDomTokenList;
typedef struct _GXmlDomTokenListIface GXmlDomTokenListIface;

#define GXML_TYPE_DOM_NAMED_NODE_MAP (gxml_dom_named_node_map_get_type ())
#define GXML_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMap))
#define GXML_IS_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP))
#define GXML_DOM_NAMED_NODE_MAP_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMapIface))

typedef struct _GXmlDomNamedNodeMap GXmlDomNamedNodeMap;
typedef struct _GXmlDomNamedNodeMapIface GXmlDomNamedNodeMapIface;

#define GXML_TYPE_DOM_NODE_LIST (gxml_dom_node_list_get_type ())
#define GXML_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeList))
#define GXML_IS_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_LIST))
#define GXML_DOM_NODE_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeListIface))

typedef struct _GXmlDomNodeList GXmlDomNodeList;
typedef struct _GXmlDomNodeListIface GXmlDomNodeListIface;

#define GXML_TYPE_DOM_ELEMENT_LIST (gxml_dom_element_list_get_type ())
#define GXML_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementList))
#define GXML_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))
#define GXML_IS_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_IS_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_DOM_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))

typedef struct _GXmlDomElementList GXmlDomElementList;
typedef struct _GXmlDomElementListClass GXmlDomElementListClass;

#define GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE (gxml_dom_non_element_parent_node_get_type ())
#define GXML_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNode))
#define GXML_IS_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE))
#define GXML_DOM_NON_ELEMENT_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNodeIface))

typedef struct _GXmlDomNonElementParentNode GXmlDomNonElementParentNode;
typedef struct _GXmlDomNonElementParentNodeIface GXmlDomNonElementParentNodeIface;

#define GXML_TYPE_DOM_DOCUMENT_FRAGMENT (gxml_dom_document_fragment_get_type ())
#define GXML_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragment))
#define GXML_IS_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT))
#define GXML_DOM_DOCUMENT_FRAGMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragmentIface))

typedef struct _GXmlDomDocumentFragment GXmlDomDocumentFragment;
typedef struct _GXmlDomDocumentFragmentIface GXmlDomDocumentFragmentIface;

#define GXML_TYPE_DOM_TEXT (gxml_dom_text_get_type ())
#define GXML_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TEXT, GXmlDomText))
#define GXML_IS_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TEXT))
#define GXML_DOM_TEXT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TEXT, GXmlDomTextIface))

typedef struct _GXmlDomText GXmlDomText;
typedef struct _GXmlDomTextIface GXmlDomTextIface;

#define GXML_TYPE_DOM_CHARACTER_DATA (gxml_dom_character_data_get_type ())
#define GXML_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterData))
#define GXML_IS_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHARACTER_DATA))
#define GXML_DOM_CHARACTER_DATA_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterDataIface))

typedef struct _GXmlDomCharacterData GXmlDomCharacterData;
typedef struct _GXmlDomCharacterDataIface GXmlDomCharacterDataIface;

#define GXML_TYPE_DOM_COMMENT (gxml_dom_comment_get_type ())
#define GXML_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomComment))
#define GXML_IS_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_COMMENT))
#define GXML_DOM_COMMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomCommentIface))

typedef struct _GXmlDomComment GXmlDomComment;
typedef struct _GXmlDomCommentIface GXmlDomCommentIface;

#define GXML_TYPE_DOM_PROCESSING_INSTRUCTION (gxml_dom_processing_instruction_get_type ())
#define GXML_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstruction))
#define GXML_IS_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION))
#define GXML_DOM_PROCESSING_INSTRUCTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstructionIface))

typedef struct _GXmlDomProcessingInstruction GXmlDomProcessingInstruction;
typedef struct _GXmlDomProcessingInstructionIface GXmlDomProcessingInstructionIface;

#define GXML_TYPE_DOM_RANGE (gxml_dom_range_get_type ())
#define GXML_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRange))
#define GXML_IS_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_RANGE))
#define GXML_DOM_RANGE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRangeIface))

typedef struct _GXmlDomRange GXmlDomRange;
typedef struct _GXmlDomRangeIface GXmlDomRangeIface;
typedef enum  {
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_START = 0,
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_START
} GXmlDomRangeBoundaryPoints;

#define GXML_DOM_RANGE_TYPE_BOUNDARY_POINTS (gxml_dom_range_boundary_points_get_type ())

#define GXML_TYPE_DOM_NODE_FILTER (gxml_dom_node_filter_get_type ())
#define GXML_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilter))
#define GXML_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))
#define GXML_IS_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_IS_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_DOM_NODE_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))

typedef struct _GXmlDomNodeFilter GXmlDomNodeFilter;
typedef struct _GXmlDomNodeFilterClass GXmlDomNodeFilterClass;

#define GXML_TYPE_DOM_NODE_ITERATOR (gxml_dom_node_iterator_get_type ())
#define GXML_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIterator))
#define GXML_IS_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_ITERATOR))
#define GXML_DOM_NODE_ITERATOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIteratorIface))

typedef struct _GXmlDomNodeIterator GXmlDomNodeIterator;
typedef struct _GXmlDomNodeIteratorIface GXmlDomNodeIteratorIface;

#define GXML_TYPE_DOM_TREE_WALKER (gxml_dom_tree_walker_get_type ())
#define GXML_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalker))
#define GXML_IS_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TREE_WALKER))
#define GXML_DOM_TREE_WALKER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalkerIface))

typedef struct _GXmlDomTreeWalker GXmlDomTreeWalker;
typedef struct _GXmlDomTreeWalkerIface GXmlDomTreeWalkerIface;

#define GXML_TYPE_PARSER (gxml_parser_get_type ())
#define GXML_PARSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_PARSER, GXmlParser))
#define GXML_IS_PARSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_PARSER))
#define GXML_PARSER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_PARSER, GXmlParserIface))

typedef struct _GXmlParser GXmlParser;
typedef struct _GXmlParserIface GXmlParserIface;

#define GXML_TYPE_DOM_IMPLEMENTATION (gxml_dom_implementation_get_type ())
#define GXML_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementation))
#define GXML_IS_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_IMPLEMENTATION))
#define GXML_DOM_IMPLEMENTATION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementationIface))

typedef struct _GXmlDomImplementation GXmlDomImplementation;
typedef struct _GXmlDomImplementationIface GXmlDomImplementationIface;

#define GXML_TYPE_DOM_DOCUMENT_TYPE (gxml_dom_document_type_get_type ())
#define GXML_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentType))
#define GXML_IS_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE))
#define GXML_DOM_DOCUMENT_TYPE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentTypeIface))

typedef struct _GXmlDomDocumentType GXmlDomDocumentType;
typedef struct _GXmlDomDocumentTypeIface GXmlDomDocumentTypeIface;

#define GXML_TYPE_DOM_XML_DOCUMENT (gxml_dom_xml_document_get_type ())
#define GXML_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocument))
#define GXML_IS_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_XML_DOCUMENT))
#define GXML_DOM_XML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocumentIface))

typedef struct _GXmlDomXMLDocument GXmlDomXMLDocument;
typedef struct _GXmlDomXMLDocumentIface GXmlDomXMLDocumentIface;

#define GXML_TYPE_DOCUMENT (gxml_document_get_type ())
#define GXML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOCUMENT, GXmlDocument))
#define GXML_IS_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOCUMENT))
#define GXML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOCUMENT, GXmlDocumentIface))

typedef struct _GXmlDocument GXmlDocument;
typedef struct _GXmlDocumentIface GXmlDocumentIface;

#define GXML_TYPE_NODE (gxml_node_get_type ())
#define GXML_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NODE, GXmlNode))
#define GXML_IS_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NODE))
#define GXML_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NODE, GXmlNodeIface))

typedef struct _GXmlNode GXmlNode;
typedef struct _GXmlNodeIface GXmlNodeIface;

#define GXML_TYPE_ELEMENT_LIST (gxml_element_list_get_type ())
#define GXML_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementList))
#define GXML_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))
#define GXML_IS_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_ELEMENT_LIST))
#define GXML_IS_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_ELEMENT_LIST))
#define GXML_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))

typedef struct _GXmlElementList GXmlElementList;
typedef struct _GXmlElementListClass GXmlElementListClass;

#define GXML_TYPE_NAMESPACE (gxml_namespace_get_type ())
#define GXML_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NAMESPACE, GXmlNamespace))
#define GXML_IS_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NAMESPACE))
#define GXML_NAMESPACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NAMESPACE, GXmlNamespaceIface))

typedef struct _GXmlNamespace GXmlNamespace;
typedef struct _GXmlNamespaceIface GXmlNamespaceIface;
typedef enum  {
	GXML_NODE_TYPE_INVALID = 0,
	GXML_NODE_TYPE_ELEMENT = 1,
	GXML_NODE_TYPE_ATTRIBUTE,
	GXML_NODE_TYPE_TEXT,
	GXML_NODE_TYPE_CDATA_SECTION,
	GXML_NODE_TYPE_ENTITY_REFERENCE,
	GXML_NODE_TYPE_ENTITY,
	GXML_NODE_TYPE_PROCESSING_INSTRUCTION,
	GXML_NODE_TYPE_COMMENT,
	GXML_NODE_TYPE_DOCUMENT,
	GXML_NODE_TYPE_DOCUMENT_TYPE,
	GXML_NODE_TYPE_DOCUMENT_FRAGMENT,
	GXML_NODE_TYPE_NOTATION
} GXmlNodeType;

#define GXML_TYPE_NODE_TYPE (gxml_node_type_get_type ())

#define GXML_TYPE_GOM_NODE (gxml_gom_node_get_type ())
#define GXML_GOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_NODE, GXmlGomNode))
#define GXML_GOM_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_NODE, GXmlGomNodeClass))
#define GXML_IS_GOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_NODE))
#define GXML_IS_GOM_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_NODE))
#define GXML_GOM_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_NODE, GXmlGomNodeClass))

typedef struct _GXmlGomNode GXmlGomNode;
typedef struct _GXmlGomNodeClass GXmlGomNodeClass;
typedef struct _GXmlGomNodePrivate GXmlGomNodePrivate;

#define GXML_TYPE_GOM_NODE_LIST (gxml_gom_node_list_get_type ())
#define GXML_GOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_NODE_LIST, GXmlGomNodeList))
#define GXML_GOM_NODE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_NODE_LIST, GXmlGomNodeListClass))
#define GXML_IS_GOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_NODE_LIST))
#define GXML_IS_GOM_NODE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_NODE_LIST))
#define GXML_GOM_NODE_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_NODE_LIST, GXmlGomNodeListClass))

typedef struct _GXmlGomNodeList GXmlGomNodeList;
typedef struct _GXmlGomNodeListClass GXmlGomNodeListClass;

#define GXML_TYPE_DOM_ATTR (gxml_dom_attr_get_type ())
#define GXML_DOM_ATTR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ATTR, GXmlDomAttr))
#define GXML_IS_DOM_ATTR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ATTR))
#define GXML_DOM_ATTR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_ATTR, GXmlDomAttrIface))

typedef struct _GXmlDomAttr GXmlDomAttr;
typedef struct _GXmlDomAttrIface GXmlDomAttrIface;

#define GXML_TYPE_GOM_ATTR (gxml_gom_attr_get_type ())
#define GXML_GOM_ATTR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_ATTR, GXmlGomAttr))
#define GXML_GOM_ATTR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_ATTR, GXmlGomAttrClass))
#define GXML_IS_GOM_ATTR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_ATTR))
#define GXML_IS_GOM_ATTR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_ATTR))
#define GXML_GOM_ATTR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_ATTR, GXmlGomAttrClass))

typedef struct _GXmlGomAttr GXmlGomAttr;
typedef struct _GXmlGomAttrClass GXmlGomAttrClass;
typedef struct _GXmlGomAttrPrivate GXmlGomAttrPrivate;

#define GXML_TYPE_GOM_PROPERTY (gxml_gom_property_get_type ())
#define GXML_GOM_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_PROPERTY, GXmlGomProperty))
#define GXML_IS_GOM_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_PROPERTY))
#define GXML_GOM_PROPERTY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_GOM_PROPERTY, GXmlGomPropertyIface))

typedef struct _GXmlGomProperty GXmlGomProperty;
typedef struct _GXmlGomPropertyIface GXmlGomPropertyIface;
enum  {
	GXML_GOM_ATTR_0_PROPERTY,
	GXML_GOM_ATTR_LOCAL_NAME_PROPERTY,
	GXML_GOM_ATTR_NAME_PROPERTY,
	GXML_GOM_ATTR_NAMESPACE_URI_PROPERTY,
	GXML_GOM_ATTR_PREFIX_PROPERTY,
	GXML_GOM_ATTR_VALUE_PROPERTY,
	GXML_GOM_ATTR_IS_REFERENCED_PROPERTY,
	GXML_GOM_ATTR_NUM_PROPERTIES
};
static GParamSpec* gxml_gom_attr_properties[GXML_GOM_ATTR_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define GXML_TYPE_GOM_OBJECT (gxml_gom_object_get_type ())
#define GXML_GOM_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_OBJECT, GXmlGomObject))
#define GXML_IS_GOM_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_OBJECT))
#define GXML_GOM_OBJECT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_GOM_OBJECT, GXmlGomObjectIface))

typedef struct _GXmlGomObject GXmlGomObject;
typedef struct _GXmlGomObjectIface GXmlGomObjectIface;

#define GXML_TYPE_GOM_STRING_REF (gxml_gom_string_ref_get_type ())
#define GXML_GOM_STRING_REF(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_STRING_REF, GXmlGomStringRef))
#define GXML_GOM_STRING_REF_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_STRING_REF, GXmlGomStringRefClass))
#define GXML_IS_GOM_STRING_REF(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_STRING_REF))
#define GXML_IS_GOM_STRING_REF_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_STRING_REF))
#define GXML_GOM_STRING_REF_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_STRING_REF, GXmlGomStringRefClass))

typedef struct _GXmlGomStringRef GXmlGomStringRef;
typedef struct _GXmlGomStringRefClass GXmlGomStringRefClass;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlDomEventIface {
	GTypeInterface parent_iface;
	void (*stop_propagation) (GXmlDomEvent* self);
	void (*stop_immediate_propagation) (GXmlDomEvent* self);
	void (*prevent_default) (GXmlDomEvent* self);
	void (*init_event) (GXmlDomEvent* self, const gchar* type, gboolean bubbles, gboolean cancelable);
	const gchar* (*get_etype) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_event_target) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_current_target) (GXmlDomEvent* self);
	gboolean (*get_bubbles) (GXmlDomEvent* self);
	gboolean (*get_cancelable) (GXmlDomEvent* self);
	gboolean (*get_is_trusted) (GXmlDomEvent* self);
	GXmlDomTimeStamp* (*get_time_stamp) (GXmlDomEvent* self);
	gboolean (*get_default_prevented) (GXmlDomEvent* self);
	GXmlDomEventPhase (*get_event_phase) (GXmlDomEvent* self);
};

struct _GXmlDomEventListenerIface {
	GTypeInterface parent_iface;
	void (*handle_event) (GXmlDomEventListener* self, GXmlDomEvent* event);
};

struct _GXmlDomEventTargetIface {
	GTypeInterface parent_iface;
	void (*add_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	void (*remove_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	gboolean (*dispatch_event) (GXmlDomEventTarget* self, GXmlDomEvent* event, GError** error);
};

struct _GXmlDomChildNodeIface {
	GTypeInterface parent_iface;
	void (*remove) (GXmlDomChildNode* self);
};

struct _GXmlDomNonDocumentTypeChildNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_previous_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
	GXmlDomElement* (*get_next_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
};

struct _GXmlDomHTMLCollectionIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement** (*to_array) (GXmlDomHTMLCollection* self, gint* result_length1);
	GXmlDomElement* (*item) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement* (*named_item) (GXmlDomHTMLCollection* self, const gchar* name);
	gint (*get_length) (GXmlDomHTMLCollection* self);
};

struct _GXmlDomTokenListIface {
	GTypeInterface parent_iface;
	gchar* (*item) (GXmlDomTokenList* self, gint index);
	gboolean (*contains) (GXmlDomTokenList* self, const gchar* token, GError** error);
	void (*add) (GXmlDomTokenList* self, gchar** tokens, gint tokens_length1, GError** error);
	void (*remove) (GXmlDomTokenList* self, gchar** tokens, gint tokens_length1);
	gboolean (*toggle) (GXmlDomTokenList* self, const gchar* token, gboolean force, gboolean _auto_, GError** error);
	gchar* (*to_string) (GXmlDomTokenList* self);
	gint (*get_length) (GXmlDomTokenList* self);
};

struct _GXmlDomNamedNodeMapIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNamedNodeMap* self, gint index);
	GXmlDomNode* (*get_named_item) (GXmlDomNamedNodeMap* self, const gchar* name);
	GXmlDomNode* (*set_named_item) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*remove_named_item) (GXmlDomNamedNodeMap* self, const gchar* name, GError** error);
	GXmlDomNode* (*remove_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* localName, GError** error);
	GXmlDomNode* (*get_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* local_name, GError** error);
	GXmlDomNode* (*set_named_item_ns) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	gint (*get_length) (GXmlDomNamedNodeMap* self);
};

struct _GXmlDomElementIface {
	GTypeInterface parent_iface;
	gchar* (*get_attribute) (GXmlDomElement* self, const gchar* name);
	gchar* (*get_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	void (*set_attribute) (GXmlDomElement* self, const gchar* name, const gchar* value, GError** error);
	void (*set_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* name, const gchar* value, GError** error);
	void (*remove_attribute) (GXmlDomElement* self, const gchar* name);
	void (*remove_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	gboolean (*has_attribute) (GXmlDomElement* self, const gchar* name);
	gboolean (*has_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomElement* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomElement* self, const gchar* class_names);
	gboolean (*matches) (GXmlDomElement* self, const gchar* selectors, GError** error);
	void (*read_from_uri) (GXmlDomElement* self, const gchar* uri, GError** error);
	void (*read_from_uri_async) (GXmlDomElement* self, const gchar* uri, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_uri_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*read_from_file) (GXmlDomElement* self, GFile* f, GCancellable* cancellable, GError** error);
	void (*read_from_file_async) (GXmlDomElement* self, GFile* f, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_file_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*read_from_stream) (GXmlDomElement* self, GInputStream* istream, GCancellable* cancellable, GError** error);
	void (*read_from_stream_async) (GXmlDomElement* self, GInputStream* istream, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_stream_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*read_from_string) (GXmlDomElement* self, const gchar* str, GCancellable* cancellable, GError** error);
	void (*read_from_string_async) (GXmlDomElement* self, const gchar* str, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_string_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	gchar* (*write_string) (GXmlDomElement* self, GCancellable* cancellable, GError** error);
	void (*write_string_async) (GXmlDomElement* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gchar* (*write_string_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*write_file) (GXmlDomElement* self, GFile* f, GCancellable* cancellable, GError** error);
	void (*write_file_async) (GXmlDomElement* self, GFile* f, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_file_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*write_stream) (GXmlDomElement* self, GOutputStream* stream, GError** error);
	void (*write_stream_async) (GXmlDomElement* self, GOutputStream* stream, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_stream_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	GInputStream* (*create_stream) (GXmlDomElement* self, GError** error);
	void (*create_stream_async) (GXmlDomElement* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GInputStream* (*create_stream_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	gchar* (*get_namespace_uri) (GXmlDomElement* self);
	gchar* (*get_prefix) (GXmlDomElement* self);
	gchar* (*get_local_name) (GXmlDomElement* self);
	gchar* (*get_tag_name) (GXmlDomElement* self);
	gchar* (*get_id) (GXmlDomElement* self);
	void (*set_id) (GXmlDomElement* self, const gchar* value);
	gchar* (*get_class_name) (GXmlDomElement* self);
	void (*set_class_name) (GXmlDomElement* self, const gchar* value);
	GXmlDomTokenList* (*get_class_list) (GXmlDomElement* self);
	GXmlDomNamedNodeMap* (*get_attributes) (GXmlDomElement* self);
};

struct _GXmlDomNodeListIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNodeList* self, gint index);
	gint (*get_length) (GXmlDomNodeList* self);
};

struct _GXmlDomParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*query_selector) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomNodeList* (*query_selector_all) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomElementList* (*get_elements_by_property_value) (GXmlDomParentNode* self, const gchar* property, const gchar* value);
	GXmlDomHTMLCollection* (*get_children) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_first_element_child) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_last_element_child) (GXmlDomParentNode* self);
	gint (*get_child_element_count) (GXmlDomParentNode* self);
};

struct _GXmlDomNonElementParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element_by_id) (GXmlDomNonElementParentNode* self, const gchar* element_id, GError** error);
};

struct _GXmlDomDocumentFragmentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomCharacterDataIface {
	GTypeInterface parent_iface;
	gchar* (*substring_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*append_data) (GXmlDomCharacterData* self, const gchar* data);
	void (*insert_data) (GXmlDomCharacterData* self, gint offset, const gchar* data, GError** error);
	void (*delete_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*replace_data) (GXmlDomCharacterData* self, gint offset, gint count, const gchar* data, GError** error);
	gchar* (*get_data) (GXmlDomCharacterData* self);
	void (*set_data) (GXmlDomCharacterData* self, const gchar* value);
	gint (*get_length) (GXmlDomCharacterData* self);
};

struct _GXmlDomTextIface {
	GTypeInterface parent_iface;
	GXmlDomText* (*split_text) (GXmlDomText* self, gint offset, GError** error);
	gchar* (*get_whole_text) (GXmlDomText* self);
};

struct _GXmlDomCommentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomProcessingInstructionIface {
	GTypeInterface parent_iface;
	gchar* (*get_target) (GXmlDomProcessingInstruction* self);
};

struct _GXmlDomRangeIface {
	GTypeInterface parent_iface;
	void (*set_start) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_end) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_start_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_start_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*collapse) (GXmlDomRange* self, gboolean to_start, GError** error);
	void (*select_node) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*select_node_contents) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	gint (*compare_boundary_points) (GXmlDomRange* self, GXmlDomRangeBoundaryPoints how, GXmlDomRange* sourceRange, GError** error);
	void (*delete_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*extract_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*clone_contents) (GXmlDomRange* self, GError** error);
	void (*insert_node) (GXmlDomRange* self, GXmlDomNode* node);
	void (*surround_contents) (GXmlDomRange* self, GXmlDomNode* newParent);
	GXmlDomRange* (*clone_range) (GXmlDomRange* self);
	void (*detach) (GXmlDomRange* self);
	gboolean (*is_point_in_range) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gshort (*compare_point) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gboolean (*intersects_node) (GXmlDomRange* self, GXmlDomNode* node);
	gchar* (*to_string) (GXmlDomRange* self);
	GXmlDomNode* (*get_start_container) (GXmlDomRange* self);
	gint (*get_start_offset) (GXmlDomRange* self);
	GXmlDomNode* (*get_end_container) (GXmlDomRange* self);
	gint (*get_end_offset) (GXmlDomRange* self);
	gboolean (*get_collapsed) (GXmlDomRange* self);
	GXmlDomNode* (*get_common_ancestor_container) (GXmlDomRange* self);
};

struct _GXmlDomNodeIteratorIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*next_node) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*previous_node) (GXmlDomNodeIterator* self);
	void (*detach) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_root) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_reference_node) (GXmlDomNodeIterator* self);
	gboolean (*get_pointer_before_reference_node) (GXmlDomNodeIterator* self);
	gint (*get_what_to_show) (GXmlDomNodeIterator* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomNodeIterator* self);
};

struct _GXmlDomTreeWalkerIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*parent_node) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*first_child) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*last_child) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previous_sibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*next_sibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previous_node) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*next_node) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_root) (GXmlDomTreeWalker* self);
	gint (*get_what_to_show) (GXmlDomTreeWalker* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_current_node) (GXmlDomTreeWalker* self);
};

struct _GXmlParserIface {
	GTypeInterface parent_iface;
	void (*write_file) (GXmlParser* self, GFile* file, GError** error);
	void (*write_file_async) (GXmlParser* self, GFile* file, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_file_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	gchar* (*write_string) (GXmlParser* self, GError** error);
	void (*write_string_async) (GXmlParser* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gchar* (*write_string_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*write_stream) (GXmlParser* self, GOutputStream* stream, GError** error);
	void (*write_stream_async) (GXmlParser* self, GOutputStream* stream, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_stream_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*read_file) (GXmlParser* self, GFile* file, GError** error);
	void (*read_file_async) (GXmlParser* self, GFile* file, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_file_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*read_stream) (GXmlParser* self, GInputStream* stream, GError** error);
	void (*read_stream_async) (GXmlParser* self, GInputStream* stream, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_stream_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*read_string) (GXmlParser* self, const gchar* str, GError** error);
	void (*read_string_async) (GXmlParser* self, const gchar* str, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_string_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	GInputStream* (*create_stream) (GXmlParser* self, GError** error);
	void (*create_stream_async) (GXmlParser* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GInputStream* (*create_stream_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*read_child_nodes) (GXmlParser* self, GXmlDomNode* parent, GError** error);
	void (*read_child_nodes_async) (GXmlParser* self, GXmlDomNode* parent, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_child_nodes_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	gboolean (*read_child_node) (GXmlParser* self, GXmlDomNode* parent, GError** error);
	gboolean (*read_child_element) (GXmlParser* self, GXmlDomNode* parent, GError** error);
	gboolean (*read_element_property) (GXmlParser* self, GXmlDomNode* parent, GXmlDomNode* * element, GError** error);
	gboolean (*add_element_collection) (GXmlParser* self, GXmlDomNode* parent, GXmlDomNode* * element, GError** error);
	void (*read_child_nodes_stream) (GXmlParser* self, GInputStream* istream, GError** error);
	void (*read_child_nodes_string) (GXmlParser* self, const gchar* str, GError** error);
	gchar* (*read_unparsed) (GXmlParser* self, GError** error);
	gboolean (*move_next_node) (GXmlParser* self, GError** error);
	gboolean (*current_is_empty_element) (GXmlParser* self);
	gboolean (*current_is_element) (GXmlParser* self);
	gboolean (*current_is_document) (GXmlParser* self);
	gchar* (*current_node_name) (GXmlParser* self);
	GXmlDomElement* (*create_element) (GXmlParser* self, GXmlDomNode* parent, GError** error);
	void (*read_element) (GXmlParser* self, GXmlDomElement* element, GError** error);
	gboolean (*get_backup) (GXmlParser* self);
	void (*set_backup) (GXmlParser* self, gboolean value);
	gboolean (*get_indent) (GXmlParser* self);
	void (*set_indent) (GXmlParser* self, gboolean value);
	GCancellable* (*get_cancellable) (GXmlParser* self);
	void (*set_cancellable) (GXmlParser* self, GCancellable* value);
	GXmlDomNode* (*get_node) (GXmlParser* self);
};

struct _GXmlDomDocumentTypeIface {
	GTypeInterface parent_iface;
	const gchar* (*get_name) (GXmlDomDocumentType* self);
	const gchar* (*get_public_id) (GXmlDomDocumentType* self);
	const gchar* (*get_system_id) (GXmlDomDocumentType* self);
};

struct _GXmlDomXMLDocumentIface {
	GTypeInterface parent_iface;
};

struct _GXmlNamespaceIface {
	GTypeInterface parent_iface;
	gchar* (*get_uri) (GXmlNamespace* self);
	gchar* (*get_prefix) (GXmlNamespace* self);
};

struct _GXmlNodeIface {
	GTypeInterface parent_iface;
	GXmlNode* (*get) (GXmlNode* self, const gchar* key);
	GXmlElementList* (*get_elements_by_property_value) (GXmlNode* self, const gchar* property, const gchar* value);
	GXmlElementList* (*get_elements_by_name) (GXmlNode* self, const gchar* name);
	GXmlElementList* (*get_elements_by_name_ns) (GXmlNode* self, const gchar* name, const gchar* ns);
	gchar* (*to_string) (GXmlNode* self);
	gboolean (*set_namespace) (GXmlNode* self, const gchar* uri, const gchar* prefix);
	gchar* (*ns_prefix) (GXmlNode* self);
	gchar* (*ns_uri) (GXmlNode* self);
	GeeList* (*get_namespaces) (GXmlNode* self);
	GeeBidirList* (*get_children_nodes) (GXmlNode* self);
	GeeMap* (*get_attrs) (GXmlNode* self);
	gchar* (*get_name) (GXmlNode* self);
	gchar* (*get_value) (GXmlNode* self);
	void (*set_value) (GXmlNode* self, const gchar* value);
	GXmlNodeType (*get_type_node) (GXmlNode* self);
	GXmlDocument* (*get_document) (GXmlNode* self);
	GXmlNode* (*get_parent) (GXmlNode* self);
};

struct _GXmlDocumentIface {
	GTypeInterface parent_iface;
	GXmlNode* (*create_element) (GXmlDocument* self, const gchar* name, GError** error);
	GXmlNode* (*create_text) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_comment) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_cdata) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_pi) (GXmlDocument* self, const gchar* target, const gchar* data);
	gboolean (*save) (GXmlDocument* self, GCancellable* cancellable, GError** error);
	gboolean (*save_as) (GXmlDocument* self, GFile* f, GCancellable* cancellable, GError** error);
	gboolean (*get_indent) (GXmlDocument* self);
	void (*set_indent) (GXmlDocument* self, gboolean value);
	gboolean (*get_ns_top) (GXmlDocument* self);
	void (*set_ns_top) (GXmlDocument* self, gboolean value);
	gboolean (*get_prefix_default_ns) (GXmlDocument* self);
	void (*set_prefix_default_ns) (GXmlDocument* self, gboolean value);
	gboolean (*get_backup) (GXmlDocument* self);
	void (*set_backup) (GXmlDocument* self, gboolean value);
	GXmlNode* (*get_root) (GXmlDocument* self);
	GFile* (*get_file) (GXmlDocument* self);
	void (*set_file) (GXmlDocument* self, GFile* value);
};

struct _GXmlDomImplementationIface {
	GTypeInterface parent_iface;
	GXmlDomDocumentType* (*create_document_type) (GXmlDomImplementation* self, const gchar* qualified_name, const gchar* public_id, const gchar* system_id, GError** error);
	GXmlDomXMLDocument* (*create_document) (GXmlDomImplementation* self, const gchar* nspace, const gchar* qualified_name, GXmlDomDocumentType* doctype, GError** error);
	GXmlDocument* (*create_html_document) (GXmlDomImplementation* self, const gchar* title);
	gboolean (*has_feature) (GXmlDomImplementation* self);
};

struct _GXmlDomDocumentIface {
	GTypeInterface parent_iface;
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomDocument* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomDocument* self, const gchar* classNames);
	GXmlDomElement* (*create_element) (GXmlDomDocument* self, const gchar* local_name, GError** error);
	GXmlDomElement* (*create_element_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* qualified_name, GError** error);
	GXmlDomDocumentFragment* (*create_document_fragment) (GXmlDomDocument* self);
	GXmlDomText* (*create_text_node) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomComment* (*create_comment) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomProcessingInstruction* (*create_processing_instruction) (GXmlDomDocument* self, const gchar* target, const gchar* data, GError** error);
	GXmlDomNode* (*import_node) (GXmlDomDocument* self, GXmlDomNode* node, gboolean deep, GError** error);
	GXmlDomNode* (*adopt_node) (GXmlDomDocument* self, GXmlDomNode* node, GError** error);
	GXmlDomEvent* (*create_event) (GXmlDomDocument* self, const gchar* interface, GError** error);
	GXmlDomRange* (*create_range) (GXmlDomDocument* self);
	GXmlDomNodeIterator* (*create_node_iterator) (GXmlDomDocument* self, GXmlDomNode* root, gint whatToShow, GXmlDomNodeFilter* filter);
	GXmlDomTreeWalker* (*create_tree_walker) (GXmlDomDocument* self, GXmlDomNode* root, gint what_to_show, GXmlDomNodeFilter* filter);
	void (*write_file) (GXmlDomDocument* self, GFile* file, GCancellable* cancellable, GError** error);
	void (*write_file_async) (GXmlDomDocument* self, GFile* file, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_file_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	void (*write_stream) (GXmlDomDocument* self, GOutputStream* stream, GCancellable* cancellable, GError** error);
	void (*write_stream_async) (GXmlDomDocument* self, GOutputStream* stream, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_stream_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	GInputStream* (*create_stream) (GXmlDomDocument* self, GError** error);
	void (*create_stream_async) (GXmlDomDocument* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GInputStream* (*create_stream_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	gchar* (*write_string) (GXmlDomDocument* self, GCancellable* cancellable, GError** error);
	void (*write_string_async) (GXmlDomDocument* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gchar* (*write_string_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	void (*read_from_file) (GXmlDomDocument* self, GFile* file, GCancellable* cancellable, GError** error);
	void (*read_from_file_async) (GXmlDomDocument* self, GFile* file, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_file_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	void (*read_from_string) (GXmlDomDocument* self, const gchar* str, GCancellable* cancellable, GError** error);
	void (*read_from_string_async) (GXmlDomDocument* self, const gchar* str, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_string_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	void (*read_from_stream) (GXmlDomDocument* self, GInputStream* stream, GCancellable* cancellable, GError** error);
	void (*read_from_stream_async) (GXmlDomDocument* self, GInputStream* stream, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_stream_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	GXmlParser* (*get_xml_parser) (GXmlDomDocument* self);
	void (*set_xml_parser) (GXmlDomDocument* self, GXmlParser* parser);
	GXmlDomImplementation* (*get_implementation) (GXmlDomDocument* self);
	const gchar* (*get_url) (GXmlDomDocument* self);
	const gchar* (*get_document_uri) (GXmlDomDocument* self);
	const gchar* (*get_origin) (GXmlDomDocument* self);
	const gchar* (*get_compat_mode) (GXmlDomDocument* self);
	const gchar* (*get_character_set) (GXmlDomDocument* self);
	const gchar* (*get_content_type) (GXmlDomDocument* self);
	GXmlDomDocumentType* (*get_doctype) (GXmlDomDocument* self);
	GXmlDomElement* (*get_document_element) (GXmlDomDocument* self);
};

struct _GXmlDomNodeIface {
	GTypeInterface parent_iface;
	gboolean (*has_child_nodes) (GXmlDomNode* self);
	void (*normalize) (GXmlDomNode* self);
	gboolean (*is_equal_node) (GXmlDomNode* self, GXmlDomNode* node);
	GXmlDomNodeDocumentPosition (*compare_document_position) (GXmlDomNode* self, GXmlDomNode* other);
	gboolean (*contains) (GXmlDomNode* self, GXmlDomNode* other);
	gchar* (*lookup_prefix) (GXmlDomNode* self, const gchar* nspace);
	gchar* (*lookup_namespace_uri) (GXmlDomNode* self, const gchar* prefix);
	gboolean (*is_default_namespace) (GXmlDomNode* self, const gchar* nspace);
	GXmlDomNode* (*insert_before) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*append_child) (GXmlDomNode* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*replace_child) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*remove_child) (GXmlDomNode* self, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*clone_node) (GXmlDomNode* self, gboolean deep, GError** error);
	GXmlDomNodeNodeType (*get_node_type) (GXmlDomNode* self);
	gchar* (*get_node_name) (GXmlDomNode* self);
	const gchar* (*get_base_uri) (GXmlDomNode* self);
	GXmlDomDocument* (*get_owner_document) (GXmlDomNode* self);
	void (*set_owner_document) (GXmlDomNode* self, GXmlDomDocument* value);
	GXmlDomNode* (*get_parent_node) (GXmlDomNode* self);
	GXmlDomElement* (*get_parent_element) (GXmlDomNode* self);
	GXmlDomNodeList* (*get_child_nodes) (GXmlDomNode* self);
	GXmlDomNode* (*get_first_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_last_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_previous_sibling) (GXmlDomNode* self);
	GXmlDomNode* (*get_next_sibling) (GXmlDomNode* self);
	gchar* (*get_node_value) (GXmlDomNode* self);
	void (*set_node_value) (GXmlDomNode* self, const gchar* value);
	gchar* (*get_text_content) (GXmlDomNode* self);
	void (*set_text_content) (GXmlDomNode* self, const gchar* value);
};

struct _GXmlGomNode {
	GObject parent_instance;
	GXmlGomNodePrivate * priv;
	gchar* _local_name;
	gchar* _prefix;
	gchar* _base_uri;
	gchar* _node_value;
	GXmlDomNode* _parent;
	GXmlDomNodeNodeType _node_type;
	GXmlGomNodeList* _child_nodes;
	GXmlDomDocument* _document;
};

struct _GXmlGomNodeClass {
	GObjectClass parent_class;
};

struct _GXmlDomAttrIface {
	GTypeInterface parent_iface;
	gchar* (*get_namespace_uri) (GXmlDomAttr* self);
	gchar* (*get_prefix) (GXmlDomAttr* self);
	gchar* (*get_local_name) (GXmlDomAttr* self);
	gchar* (*get_name) (GXmlDomAttr* self);
	gchar* (*get_value) (GXmlDomAttr* self);
	void (*set_value) (GXmlDomAttr* self, const gchar* value);
	gboolean (*get_specified) (GXmlDomAttr* self);
};

struct _GXmlGomPropertyIface {
	GTypeInterface parent_iface;
	gboolean (*validate_value) (GXmlGomProperty* self, const gchar* val);
	gchar* (*get_value) (GXmlGomProperty* self);
	void (*set_value) (GXmlGomProperty* self, const gchar* value);
};

struct _GXmlGomAttr {
	GXmlGomNode parent_instance;
	GXmlGomAttrPrivate * priv;
	gchar* _namespace_uri;
	GXmlGomProperty* prop;
};

struct _GXmlGomAttrClass {
	GXmlGomNodeClass parent_class;
};

struct _GXmlGomObjectIface {
	GTypeInterface parent_iface;
	GList* (*get_properties_list) (GXmlGomObject* self);
	GParamSpec* (*find_property_name) (GXmlGomObject* self, const gchar* nick);
	GParamSpec* (*find_object_property_name) (GXmlGomObject* self, const gchar* pname);
	GList* (*get_property_element_list) (GXmlGomObject* self);
	gchar* (*get_property_string) (GXmlGomObject* self, GParamSpec* prop);
	gchar* (*get_attribute) (GXmlGomObject* self, const gchar* name);
	GXmlGomProperty* (*find_property) (GXmlGomObject* self, const gchar* name);
	gboolean (*set_attribute) (GXmlGomObject* self, const gchar* name, const gchar* val);
	GXmlDomElement* (*get_child) (GXmlGomObject* self, const gchar* name);
	GXmlDomElementList* (*find_elements) (GXmlGomObject* self, const gchar* name);
	gboolean (*remove_attribute) (GXmlGomObject* self, const gchar* name);
	gboolean (*set_instance_property) (GXmlGomObject* self, const gchar* name);
	void (*clean_property_elements) (GXmlGomObject* self, const gchar* name, GError** error);
};

static gpointer gxml_gom_attr_parent_class = NULL;
static GXmlDomAttrIface * gxml_gom_attr_gxml_dom_attr_parent_iface = NULL;

GType gxml_dom_time_stamp_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_phase_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_listener_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_target_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_document_position_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_node_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_document_type_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_html_collection_get_type (void) G_GNUC_CONST;
GType gxml_dom_token_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_named_node_map_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_element_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_fragment_get_type (void) G_GNUC_CONST;
GType gxml_dom_character_data_get_type (void) G_GNUC_CONST;
GType gxml_dom_text_get_type (void) G_GNUC_CONST;
GType gxml_dom_comment_get_type (void) G_GNUC_CONST;
GType gxml_dom_processing_instruction_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_boundary_points_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_filter_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_iterator_get_type (void) G_GNUC_CONST;
GType gxml_dom_tree_walker_get_type (void) G_GNUC_CONST;
GType gxml_parser_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_xml_document_get_type (void) G_GNUC_CONST;
GType gxml_element_list_get_type (void) G_GNUC_CONST;
GType gxml_namespace_get_type (void) G_GNUC_CONST;
GType gxml_node_type_get_type (void) G_GNUC_CONST;
GType gxml_node_get_type (void) G_GNUC_CONST;
GType gxml_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_implementation_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_get_type (void) G_GNUC_CONST;
GType gxml_gom_node_get_type (void) G_GNUC_CONST;
GType gxml_gom_node_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_attr_get_type (void) G_GNUC_CONST;
GType gxml_gom_attr_get_type (void) G_GNUC_CONST;
GType gxml_gom_property_get_type (void) G_GNUC_CONST;
GXmlGomAttr* gxml_gom_attr_new (GXmlDomElement* element,
                                const gchar* name,
                                const gchar* val);
GXmlGomAttr* gxml_gom_attr_construct (GType object_type,
                                      GXmlDomElement* element,
                                      const gchar* name,
                                      const gchar* val);
GXmlGomNode* gxml_gom_node_new (void);
GXmlGomNode* gxml_gom_node_construct (GType object_type);
GXmlDomDocument* gxml_dom_node_get_owner_document (GXmlDomNode* self);
gchar* gxml_dom_node_get_node_value (GXmlDomNode* self);
GXmlGomAttr* gxml_gom_attr_new_namespace (GXmlDomElement* element,
                                          const gchar* namespace_uri,
                                          const gchar* prefix,
                                          const gchar* name,
                                          const gchar* val);
GXmlGomAttr* gxml_gom_attr_construct_namespace (GType object_type,
                                                GXmlDomElement* element,
                                                const gchar* namespace_uri,
                                                const gchar* prefix,
                                                const gchar* name,
                                                const gchar* val);
GXmlGomAttr* gxml_gom_attr_new_reference (GXmlDomElement* element,
                                          const gchar* name);
GXmlGomAttr* gxml_gom_attr_construct_reference (GType object_type,
                                                GXmlDomElement* element,
                                                const gchar* name);
GType gxml_gom_object_get_type (void) G_GNUC_CONST;
GXmlGomStringRef* gxml_gom_string_ref_new (GXmlGomObject* obj,
                                           const gchar* name);
GXmlGomStringRef* gxml_gom_string_ref_construct (GType object_type,
                                                 GXmlGomObject* obj,
                                                 const gchar* name);
GType gxml_gom_string_ref_get_type (void) G_GNUC_CONST;
gchar* gxml_gom_property_get_value (GXmlGomProperty* self);
void gxml_gom_property_set_value (GXmlGomProperty* self,
                                  const gchar* value);
gboolean gxml_gom_attr_get_is_referenced (GXmlGomAttr* self);
static GObject * gxml_gom_attr_constructor (GType type,
                                     guint n_construct_properties,
                                     GObjectConstructParam * construct_properties);
static void gxml_gom_attr_finalize (GObject * obj);
gchar* gxml_dom_attr_get_local_name (GXmlDomAttr* self);
gchar* gxml_dom_attr_get_name (GXmlDomAttr* self);
gchar* gxml_dom_attr_get_namespace_uri (GXmlDomAttr* self);
gchar* gxml_dom_attr_get_prefix (GXmlDomAttr* self);
gchar* gxml_dom_attr_get_value (GXmlDomAttr* self);
static void _vala_gxml_gom_attr_get_property (GObject * object,
                                       guint property_id,
                                       GValue * value,
                                       GParamSpec * pspec);
void gxml_dom_attr_set_value (GXmlDomAttr* self,
                              const gchar* value);
static void _vala_gxml_gom_attr_set_property (GObject * object,
                                       guint property_id,
                                       const GValue * value,
                                       GParamSpec * pspec);

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

GXmlGomAttr*
gxml_gom_attr_construct (GType object_type,
                         GXmlDomElement* element,
                         const gchar* name,
                         const gchar* val)
{
	GXmlGomAttr * self = NULL;
	GXmlDomDocument* _tmp0_;
	GXmlDomDocument* _tmp1_;
	GXmlDomDocument* _tmp2_;
	GXmlDomNode* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	g_return_val_if_fail (element != NULL, NULL);
	g_return_val_if_fail (name != NULL, NULL);
	g_return_val_if_fail (val != NULL, NULL);
	self = (GXmlGomAttr*) gxml_gom_node_construct (object_type);
	_tmp0_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) element);
	_tmp1_ = _tmp0_;
	_tmp2_ = _g_object_ref0 (_tmp1_);
	_g_object_unref0 (((GXmlGomNode*) self)->_document);
	((GXmlGomNode*) self)->_document = _tmp2_;
	_tmp3_ = _g_object_ref0 ((GXmlDomNode*) element);
	_g_object_unref0 (((GXmlGomNode*) self)->_parent);
	((GXmlGomNode*) self)->_parent = _tmp3_;
	_tmp4_ = g_strdup (name);
	_g_free0 (((GXmlGomNode*) self)->_local_name);
	((GXmlGomNode*) self)->_local_name = _tmp4_;
	_tmp5_ = g_strdup (val);
	_g_free0 (((GXmlGomNode*) self)->_node_value);
	((GXmlGomNode*) self)->_node_value = _tmp5_;
	_tmp6_ = gxml_dom_node_get_node_value ((GXmlDomNode*) self);
	_tmp7_ = _tmp6_;
	_tmp8_ = _tmp7_;
	_vala_assert (g_strcmp0 (_tmp8_, val) == 0, "node_value == val");
	_g_free0 (_tmp8_);
	_g_object_unref0 (self->prop);
	self->prop = NULL;
	return self;
}

GXmlGomAttr*
gxml_gom_attr_new (GXmlDomElement* element,
                   const gchar* name,
                   const gchar* val)
{
	return gxml_gom_attr_construct (GXML_TYPE_GOM_ATTR, element, name, val);
}

GXmlGomAttr*
gxml_gom_attr_construct_namespace (GType object_type,
                                   GXmlDomElement* element,
                                   const gchar* namespace_uri,
                                   const gchar* prefix,
                                   const gchar* name,
                                   const gchar* val)
{
	GXmlGomAttr * self = NULL;
	GXmlDomDocument* _tmp0_;
	GXmlDomDocument* _tmp1_;
	GXmlDomDocument* _tmp2_;
	GXmlDomNode* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	g_return_val_if_fail (element != NULL, NULL);
	g_return_val_if_fail (namespace_uri != NULL, NULL);
	g_return_val_if_fail (name != NULL, NULL);
	g_return_val_if_fail (val != NULL, NULL);
	self = (GXmlGomAttr*) gxml_gom_node_construct (object_type);
	_tmp0_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) element);
	_tmp1_ = _tmp0_;
	_tmp2_ = _g_object_ref0 (_tmp1_);
	_g_object_unref0 (((GXmlGomNode*) self)->_document);
	((GXmlGomNode*) self)->_document = _tmp2_;
	_tmp3_ = _g_object_ref0 ((GXmlDomNode*) element);
	_g_object_unref0 (((GXmlGomNode*) self)->_parent);
	((GXmlGomNode*) self)->_parent = _tmp3_;
	_tmp4_ = g_strdup (name);
	_g_free0 (((GXmlGomNode*) self)->_local_name);
	((GXmlGomNode*) self)->_local_name = _tmp4_;
	_tmp5_ = g_strdup (val);
	_g_free0 (((GXmlGomNode*) self)->_node_value);
	((GXmlGomNode*) self)->_node_value = _tmp5_;
	_tmp6_ = g_strdup (namespace_uri);
	_g_free0 (self->_namespace_uri);
	self->_namespace_uri = _tmp6_;
	_tmp7_ = g_strdup (prefix);
	_g_free0 (((GXmlGomNode*) self)->_prefix);
	((GXmlGomNode*) self)->_prefix = _tmp7_;
	_g_object_unref0 (self->prop);
	self->prop = NULL;
	return self;
}

GXmlGomAttr*
gxml_gom_attr_new_namespace (GXmlDomElement* element,
                             const gchar* namespace_uri,
                             const gchar* prefix,
                             const gchar* name,
                             const gchar* val)
{
	return gxml_gom_attr_construct_namespace (GXML_TYPE_GOM_ATTR, element, namespace_uri, prefix, name, val);
}

GXmlGomAttr*
gxml_gom_attr_construct_reference (GType object_type,
                                   GXmlDomElement* element,
                                   const gchar* name)
{
	GXmlGomAttr * self = NULL;
	GXmlDomDocument* _tmp0_;
	GXmlDomDocument* _tmp1_;
	GXmlDomDocument* _tmp2_;
	GXmlDomNode* _tmp3_;
	gchar* _tmp4_;
	GXmlGomStringRef* _tmp5_;
	g_return_val_if_fail (element != NULL, NULL);
	g_return_val_if_fail (name != NULL, NULL);
	self = (GXmlGomAttr*) gxml_gom_node_construct (object_type);
	_tmp0_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) element);
	_tmp1_ = _tmp0_;
	_tmp2_ = _g_object_ref0 (_tmp1_);
	_g_object_unref0 (((GXmlGomNode*) self)->_document);
	((GXmlGomNode*) self)->_document = _tmp2_;
	_tmp3_ = _g_object_ref0 ((GXmlDomNode*) element);
	_g_object_unref0 (((GXmlGomNode*) self)->_parent);
	((GXmlGomNode*) self)->_parent = _tmp3_;
	_tmp4_ = g_strdup (name);
	_g_free0 (((GXmlGomNode*) self)->_local_name);
	((GXmlGomNode*) self)->_local_name = _tmp4_;
	_g_free0 (((GXmlGomNode*) self)->_node_value);
	((GXmlGomNode*) self)->_node_value = NULL;
	_tmp5_ = gxml_gom_string_ref_new (G_TYPE_CHECK_INSTANCE_TYPE (element, GXML_TYPE_GOM_OBJECT) ? ((GXmlGomObject*) element) : NULL, name);
	_g_object_unref0 (self->prop);
	self->prop = (GXmlGomProperty*) _tmp5_;
	return self;
}

GXmlGomAttr*
gxml_gom_attr_new_reference (GXmlDomElement* element,
                             const gchar* name)
{
	return gxml_gom_attr_construct_reference (GXML_TYPE_GOM_ATTR, element, name);
}

static gchar*
gxml_gom_attr_real_get_local_name (GXmlDomAttr* base)
{
	gchar* result;
	GXmlGomAttr* self;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	self = (GXmlGomAttr*) base;
	_tmp0_ = ((GXmlGomNode*) self)->_local_name;
	_tmp1_ = g_strdup (_tmp0_);
	result = _tmp1_;
	return result;
}

static gchar*
gxml_gom_attr_real_get_name (GXmlDomAttr* base)
{
	gchar* result;
	GXmlGomAttr* self;
	gchar* s = NULL;
	gchar* _tmp0_;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	gchar* _tmp8_;
	self = (GXmlGomAttr*) base;
	_tmp0_ = g_strdup ("");
	s = _tmp0_;
	_tmp2_ = ((GXmlGomNode*) self)->_prefix;
	if (_tmp2_ != NULL) {
		const gchar* _tmp3_;
		_tmp3_ = ((GXmlGomNode*) self)->_prefix;
		_tmp1_ = g_strcmp0 (_tmp3_, "") != 0;
	} else {
		_tmp1_ = FALSE;
	}
	if (_tmp1_) {
		const gchar* _tmp4_;
		gchar* _tmp5_;
		_tmp4_ = ((GXmlGomNode*) self)->_prefix;
		_tmp5_ = g_strconcat (_tmp4_, ":", NULL);
		_g_free0 (s);
		s = _tmp5_;
	}
	_tmp6_ = s;
	_tmp7_ = ((GXmlGomNode*) self)->_local_name;
	_tmp8_ = g_strconcat (_tmp6_, _tmp7_, NULL);
	result = _tmp8_;
	_g_free0 (s);
	return result;
}

static gchar*
gxml_gom_attr_real_get_namespace_uri (GXmlDomAttr* base)
{
	gchar* result;
	GXmlGomAttr* self;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	self = (GXmlGomAttr*) base;
	_tmp0_ = self->_namespace_uri;
	_tmp1_ = g_strdup (_tmp0_);
	result = _tmp1_;
	return result;
}

static gchar*
gxml_gom_attr_real_get_prefix (GXmlDomAttr* base)
{
	gchar* result;
	GXmlGomAttr* self;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	self = (GXmlGomAttr*) base;
	_tmp0_ = ((GXmlGomNode*) self)->_prefix;
	if (g_strcmp0 (_tmp0_, "") == 0) {
		result = NULL;
		return result;
	}
	_tmp1_ = ((GXmlGomNode*) self)->_prefix;
	_tmp2_ = g_strdup (_tmp1_);
	result = _tmp2_;
	return result;
}

static gchar*
gxml_gom_attr_real_get_value (GXmlDomAttr* base)
{
	gchar* result;
	GXmlGomAttr* self;
	GXmlGomProperty* _tmp0_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	self = (GXmlGomAttr*) base;
	_tmp0_ = self->prop;
	if (_tmp0_ != NULL) {
		GXmlGomProperty* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
		_tmp1_ = self->prop;
		_tmp2_ = gxml_gom_property_get_value (_tmp1_);
		_tmp3_ = _tmp2_;
		result = _tmp3_;
		return result;
	}
	_tmp4_ = ((GXmlGomNode*) self)->_node_value;
	_tmp5_ = g_strdup (_tmp4_);
	result = _tmp5_;
	return result;
}

static void
gxml_gom_attr_real_set_value (GXmlDomAttr* base,
                              const gchar* value)
{
	GXmlGomAttr* self;
	GXmlGomProperty* _tmp0_;
	self = (GXmlGomAttr*) base;
	_tmp0_ = self->prop;
	if (_tmp0_ != NULL) {
		GXmlGomProperty* _tmp1_;
		_tmp1_ = self->prop;
		gxml_gom_property_set_value (_tmp1_, value);
	} else {
		gchar* _tmp2_;
		_tmp2_ = g_strdup (value);
		_g_free0 (((GXmlGomNode*) self)->_node_value);
		((GXmlGomNode*) self)->_node_value = _tmp2_;
	}
	g_object_notify_by_pspec ((GObject *) self, gxml_gom_attr_properties[GXML_GOM_ATTR_VALUE_PROPERTY]);
}

gboolean
gxml_gom_attr_get_is_referenced (GXmlGomAttr* self)
{
	gboolean result;
	GXmlGomProperty* _tmp0_;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = self->prop;
	result = _tmp0_ != NULL;
	return result;
}

static GObject *
gxml_gom_attr_constructor (GType type,
                           guint n_construct_properties,
                           GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GXmlGomAttr * self;
	parent_class = G_OBJECT_CLASS (gxml_gom_attr_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GOM_ATTR, GXmlGomAttr);
	_g_object_unref0 (((GXmlGomNode*) self)->_child_nodes);
	((GXmlGomNode*) self)->_child_nodes = NULL;
	return obj;
}

static void
gxml_gom_attr_class_init (GXmlGomAttrClass * klass,
                          gpointer klass_data)
{
	gxml_gom_attr_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gom_attr_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gxml_gom_attr_set_property;
	G_OBJECT_CLASS (klass)->constructor = gxml_gom_attr_constructor;
	G_OBJECT_CLASS (klass)->finalize = gxml_gom_attr_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ATTR_LOCAL_NAME_PROPERTY, gxml_gom_attr_properties[GXML_GOM_ATTR_LOCAL_NAME_PROPERTY] = g_param_spec_string ("local-name", "local-name", "local-name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ATTR_NAME_PROPERTY, gxml_gom_attr_properties[GXML_GOM_ATTR_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ATTR_NAMESPACE_URI_PROPERTY, gxml_gom_attr_properties[GXML_GOM_ATTR_NAMESPACE_URI_PROPERTY] = g_param_spec_string ("namespace-uri", "namespace-uri", "namespace-uri", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ATTR_PREFIX_PROPERTY, gxml_gom_attr_properties[GXML_GOM_ATTR_PREFIX_PROPERTY] = g_param_spec_string ("prefix", "prefix", "prefix", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ATTR_VALUE_PROPERTY, gxml_gom_attr_properties[GXML_GOM_ATTR_VALUE_PROPERTY] = g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ATTR_IS_REFERENCED_PROPERTY, gxml_gom_attr_properties[GXML_GOM_ATTR_IS_REFERENCED_PROPERTY] = g_param_spec_boolean ("is-referenced", "is-referenced", "is-referenced", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
gxml_gom_attr_gxml_dom_attr_interface_init (GXmlDomAttrIface * iface,
                                            gpointer iface_data)
{
	gxml_gom_attr_gxml_dom_attr_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_local_name = gxml_gom_attr_real_get_local_name;
	iface->get_name = gxml_gom_attr_real_get_name;
	iface->get_namespace_uri = gxml_gom_attr_real_get_namespace_uri;
	iface->get_prefix = gxml_gom_attr_real_get_prefix;
	iface->get_value = gxml_gom_attr_real_get_value;
	iface->set_value = gxml_gom_attr_real_set_value;
}

static void
gxml_gom_attr_instance_init (GXmlGomAttr * self,
                             gpointer klass)
{
	self->prop = NULL;
}

static void
gxml_gom_attr_finalize (GObject * obj)
{
	GXmlGomAttr * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GOM_ATTR, GXmlGomAttr);
	_g_free0 (self->_namespace_uri);
	_g_object_unref0 (self->prop);
	G_OBJECT_CLASS (gxml_gom_attr_parent_class)->finalize (obj);
}

/**
 * DOM4 implemenation of {@link DomAttr}.
 */
GType
gxml_gom_attr_get_type (void)
{
	static volatile gsize gxml_gom_attr_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_attr_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomAttrClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gom_attr_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGomAttr), 0, (GInstanceInitFunc) gxml_gom_attr_instance_init, NULL };
		static const GInterfaceInfo gxml_dom_attr_info = { (GInterfaceInitFunc) gxml_gom_attr_gxml_dom_attr_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_gom_attr_type_id;
		gxml_gom_attr_type_id = g_type_register_static (GXML_TYPE_GOM_NODE, "GXmlGomAttr", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_gom_attr_type_id, GXML_TYPE_DOM_ATTR, &gxml_dom_attr_info);
		g_once_init_leave (&gxml_gom_attr_type_id__volatile, gxml_gom_attr_type_id);
	}
	return gxml_gom_attr_type_id__volatile;
}

static void
_vala_gxml_gom_attr_get_property (GObject * object,
                                  guint property_id,
                                  GValue * value,
                                  GParamSpec * pspec)
{
	GXmlGomAttr * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_ATTR, GXmlGomAttr);
	switch (property_id) {
		case GXML_GOM_ATTR_LOCAL_NAME_PROPERTY:
		g_value_take_string (value, gxml_dom_attr_get_local_name ((GXmlDomAttr*) self));
		break;
		case GXML_GOM_ATTR_NAME_PROPERTY:
		g_value_take_string (value, gxml_dom_attr_get_name ((GXmlDomAttr*) self));
		break;
		case GXML_GOM_ATTR_NAMESPACE_URI_PROPERTY:
		g_value_take_string (value, gxml_dom_attr_get_namespace_uri ((GXmlDomAttr*) self));
		break;
		case GXML_GOM_ATTR_PREFIX_PROPERTY:
		g_value_take_string (value, gxml_dom_attr_get_prefix ((GXmlDomAttr*) self));
		break;
		case GXML_GOM_ATTR_VALUE_PROPERTY:
		g_value_take_string (value, gxml_dom_attr_get_value ((GXmlDomAttr*) self));
		break;
		case GXML_GOM_ATTR_IS_REFERENCED_PROPERTY:
		g_value_set_boolean (value, gxml_gom_attr_get_is_referenced (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_gxml_gom_attr_set_property (GObject * object,
                                  guint property_id,
                                  const GValue * value,
                                  GParamSpec * pspec)
{
	GXmlGomAttr * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_ATTR, GXmlGomAttr);
	switch (property_id) {
		case GXML_GOM_ATTR_VALUE_PROPERTY:
		gxml_dom_attr_set_value ((GXmlDomAttr*) self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

