/* EnumerationTest.c generated by valac 0.44.3, the Vala compiler
 * generated from EnumerationTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */

#include <glib-object.h>
#include <gxml/gxml.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <stdio.h>

typedef enum  {
	OPTIONS_ENUM_SelectBefore,
	OPTIONS_ENUM_HoldOn,
	OPTIONS_ENUM_LeaveHeare,
	OPTIONS_ENUM_NORMAL_OPERATION
} OptionsEnum;

#define TYPE_OPTIONS_ENUM (options_enum_get_type ())

#define TYPE_OBJECT_MODEL (object_model_get_type ())
#define OBJECT_MODEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_OBJECT_MODEL, ObjectModel))
#define OBJECT_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_OBJECT_MODEL, ObjectModelClass))
#define IS_OBJECT_MODEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_OBJECT_MODEL))
#define IS_OBJECT_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_OBJECT_MODEL))
#define OBJECT_MODEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_OBJECT_MODEL, ObjectModelClass))

typedef struct _ObjectModel ObjectModel;
typedef struct _ObjectModelClass ObjectModelClass;
typedef struct _ObjectModelPrivate ObjectModelPrivate;

#define TYPE_OPTIONS (options_get_type ())
#define OPTIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_OPTIONS, Options))
#define OPTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_OPTIONS, OptionsClass))
#define IS_OPTIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_OPTIONS))
#define IS_OPTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_OPTIONS))
#define OPTIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_OPTIONS, OptionsClass))

typedef struct _Options Options;
typedef struct _OptionsClass OptionsClass;
typedef struct _OptionsPrivate OptionsPrivate;
typedef enum  {
	OPTIONS_VALUES_AP,
	OPTIONS_VALUES_KP_VALUE,
	OPTIONS_VALUES_EXTERNAL_VALUE_VISION
} OptionsValues;

#define OPTIONS_TYPE_VALUES (options_values_get_type ())
enum  {
	OPTIONS_0_PROPERTY,
	OPTIONS_TEST_PROPERTY,
	OPTIONS_OPTIONS_PROPERTY,
	OPTIONS_VALS_PROPERTY,
	OPTIONS_NUM_PROPERTIES
};
static GParamSpec* options_properties[OPTIONS_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_SERIALIZABLE_ENUMERATION_TEST (serializable_enumeration_test_get_type ())
#define SERIALIZABLE_ENUMERATION_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_ENUMERATION_TEST, SerializableEnumerationTest))
#define SERIALIZABLE_ENUMERATION_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_ENUMERATION_TEST, SerializableEnumerationTestClass))
#define IS_SERIALIZABLE_ENUMERATION_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_ENUMERATION_TEST))
#define IS_SERIALIZABLE_ENUMERATION_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_ENUMERATION_TEST))
#define SERIALIZABLE_ENUMERATION_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_ENUMERATION_TEST, SerializableEnumerationTestClass))

typedef struct _SerializableEnumerationTest SerializableEnumerationTest;
typedef struct _SerializableEnumerationTestClass SerializableEnumerationTestClass;
typedef struct _SerializableEnumerationTestPrivate SerializableEnumerationTestPrivate;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _ObjectModel {
	GXmlSerializableObjectModel parent_instance;
	ObjectModelPrivate * priv;
};

struct _ObjectModelClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _Options {
	ObjectModel parent_instance;
	OptionsPrivate * priv;
};

struct _OptionsClass {
	ObjectModelClass parent_class;
};

struct _OptionsPrivate {
	gchar* _test;
	OptionsEnum _options;
	OptionsValues _vals;
};

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _SerializableEnumerationTest {
	GXmlTest parent_instance;
	SerializableEnumerationTestPrivate * priv;
};

struct _SerializableEnumerationTestClass {
	GXmlTestClass parent_class;
};

static gint Options_private_offset;
static gpointer options_parent_class = NULL;
static gpointer serializable_enumeration_test_parent_class = NULL;

GType options_enum_get_type (void) G_GNUC_CONST;
GType object_model_get_type (void) G_GNUC_CONST;
GType options_get_type (void) G_GNUC_CONST;
GType options_values_get_type (void) G_GNUC_CONST;
Options* options_new (void);
Options* options_construct (GType object_type);
ObjectModel* object_model_new (void);
ObjectModel* object_model_construct (GType object_type);
const gchar* options_get_test (Options* self);
void options_set_test (Options* self,
                       const gchar* value);
OptionsEnum options_get_options (Options* self);
void options_set_options (Options* self,
                          OptionsEnum value);
OptionsValues options_get_vals (Options* self);
void options_set_vals (Options* self,
                       OptionsValues value);
static void options_finalize (GObject * obj);
static void _vala_options_get_property (GObject * object,
                                 guint property_id,
                                 GValue * value,
                                 GParamSpec * pspec);
static void _vala_options_set_property (GObject * object,
                                 guint property_id,
                                 const GValue * value,
                                 GParamSpec * pspec);
gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType serializable_enumeration_test_get_type (void) G_GNUC_CONST;
void serializable_enumeration_test_add_tests (void);
static void __lambda165_ (void);
const gchar* options_enum_to_string (OptionsEnum self);
static void ___lambda165__gtest_func (void);
static void __lambda166_ (void);
static void ___lambda166__gtest_func (void);
static void __lambda167_ (void);
static void ___lambda167__gtest_func (void);
static void __lambda168_ (void);
static void ___lambda168__gtest_func (void);
static void __lambda169_ (void);
static void ___lambda169__gtest_func (void);
SerializableEnumerationTest* serializable_enumeration_test_new (void);
SerializableEnumerationTest* serializable_enumeration_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static void _vala_array_destroy (gpointer array,
                          gint array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gint array_length,
                       GDestroyNotify destroy_func);

/**
 *
 *  GXml.EnumerationTest
 *
 *  Authors:
 *
 *       Daniel Espinosa <esodan@gmail.com>
 *
 *
 *  Copyright (c) 2013-2015 Daniel Espinosa
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
GType
options_enum_get_type (void)
{
	static volatile gsize options_enum_type_id__volatile = 0;
	if (g_once_init_enter (&options_enum_type_id__volatile)) {
		static const GEnumValue values[] = {{OPTIONS_ENUM_SelectBefore, "OPTIONS_ENUM_SelectBefore", "selectbefore"}, {OPTIONS_ENUM_HoldOn, "OPTIONS_ENUM_HoldOn", "holdon"}, {OPTIONS_ENUM_LeaveHeare, "OPTIONS_ENUM_LeaveHeare", "leaveheare"}, {OPTIONS_ENUM_NORMAL_OPERATION, "OPTIONS_ENUM_NORMAL_OPERATION", "normal-operation"}, {0, NULL, NULL}};
		GType options_enum_type_id;
		options_enum_type_id = g_enum_register_static ("OptionsEnum", values);
		g_once_init_leave (&options_enum_type_id__volatile, options_enum_type_id);
	}
	return options_enum_type_id__volatile;
}

static inline gpointer
options_get_instance_private (Options* self)
{
	return G_STRUCT_MEMBER_P (self, Options_private_offset);
}

GType
options_values_get_type (void)
{
	static volatile gsize options_values_type_id__volatile = 0;
	if (g_once_init_enter (&options_values_type_id__volatile)) {
		static const GEnumValue values[] = {{OPTIONS_VALUES_AP, "OPTIONS_VALUES_AP", "ap"}, {OPTIONS_VALUES_KP_VALUE, "OPTIONS_VALUES_KP_VALUE", "kp-value"}, {OPTIONS_VALUES_EXTERNAL_VALUE_VISION, "OPTIONS_VALUES_EXTERNAL_VALUE_VISION", "external-value-vision"}, {0, NULL, NULL}};
		GType options_values_type_id;
		options_values_type_id = g_enum_register_static ("OptionsValues", values);
		g_once_init_leave (&options_values_type_id__volatile, options_values_type_id);
	}
	return options_values_type_id__volatile;
}

Options*
options_construct (GType object_type)
{
	Options * self = NULL;
#line 37 "EnumerationTest.vala"
	self = (Options*) object_model_construct (object_type);
#line 37 "EnumerationTest.vala"
	return self;
#line 264 "EnumerationTest.c"
}

Options*
options_new (void)
{
#line 37 "EnumerationTest.vala"
	return options_construct (TYPE_OPTIONS);
#line 272 "EnumerationTest.c"
}

const gchar*
options_get_test (Options* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 39 "EnumerationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 39 "EnumerationTest.vala"
	_tmp0_ = self->priv->_test;
#line 39 "EnumerationTest.vala"
	result = _tmp0_;
#line 39 "EnumerationTest.vala"
	return result;
#line 288 "EnumerationTest.c"
}

void
options_set_test (Options* self,
                  const gchar* value)
{
#line 39 "EnumerationTest.vala"
	g_return_if_fail (self != NULL);
#line 39 "EnumerationTest.vala"
	if (g_strcmp0 (value, options_get_test (self)) != 0) {
#line 299 "EnumerationTest.c"
		gchar* _tmp0_;
#line 39 "EnumerationTest.vala"
		_tmp0_ = g_strdup (value);
#line 39 "EnumerationTest.vala"
		_g_free0 (self->priv->_test);
#line 39 "EnumerationTest.vala"
		self->priv->_test = _tmp0_;
#line 39 "EnumerationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, options_properties[OPTIONS_TEST_PROPERTY]);
#line 309 "EnumerationTest.c"
	}
}

OptionsEnum
options_get_options (Options* self)
{
	OptionsEnum result;
	OptionsEnum _tmp0_;
#line 40 "EnumerationTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 40 "EnumerationTest.vala"
	_tmp0_ = self->priv->_options;
#line 40 "EnumerationTest.vala"
	result = _tmp0_;
#line 40 "EnumerationTest.vala"
	return result;
#line 326 "EnumerationTest.c"
}

void
options_set_options (Options* self,
                     OptionsEnum value)
{
#line 40 "EnumerationTest.vala"
	g_return_if_fail (self != NULL);
#line 40 "EnumerationTest.vala"
	if (options_get_options (self) != value) {
#line 40 "EnumerationTest.vala"
		self->priv->_options = value;
#line 40 "EnumerationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, options_properties[OPTIONS_OPTIONS_PROPERTY]);
#line 341 "EnumerationTest.c"
	}
}

OptionsValues
options_get_vals (Options* self)
{
	OptionsValues result;
	OptionsValues _tmp0_;
#line 41 "EnumerationTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 41 "EnumerationTest.vala"
	_tmp0_ = self->priv->_vals;
#line 41 "EnumerationTest.vala"
	result = _tmp0_;
#line 41 "EnumerationTest.vala"
	return result;
#line 358 "EnumerationTest.c"
}

void
options_set_vals (Options* self,
                  OptionsValues value)
{
#line 41 "EnumerationTest.vala"
	g_return_if_fail (self != NULL);
#line 41 "EnumerationTest.vala"
	if (options_get_vals (self) != value) {
#line 41 "EnumerationTest.vala"
		self->priv->_vals = value;
#line 41 "EnumerationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, options_properties[OPTIONS_VALS_PROPERTY]);
#line 373 "EnumerationTest.c"
	}
}

static void
options_class_init (OptionsClass * klass,
                    gpointer klass_data)
{
#line 37 "EnumerationTest.vala"
	options_parent_class = g_type_class_peek_parent (klass);
#line 37 "EnumerationTest.vala"
	g_type_class_adjust_private_offset (klass, &Options_private_offset);
#line 37 "EnumerationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_options_get_property;
#line 37 "EnumerationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_options_set_property;
#line 37 "EnumerationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = options_finalize;
#line 37 "EnumerationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), OPTIONS_TEST_PROPERTY, options_properties[OPTIONS_TEST_PROPERTY] = g_param_spec_string ("test", "test", "test", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 37 "EnumerationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), OPTIONS_OPTIONS_PROPERTY, options_properties[OPTIONS_OPTIONS_PROPERTY] = g_param_spec_enum ("options", "options", "options", TYPE_OPTIONS_ENUM, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 37 "EnumerationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), OPTIONS_VALS_PROPERTY, options_properties[OPTIONS_VALS_PROPERTY] = g_param_spec_enum ("vals", "vals", "vals", OPTIONS_TYPE_VALUES, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 397 "EnumerationTest.c"
}

static void
options_instance_init (Options * self,
                       gpointer klass)
{
#line 37 "EnumerationTest.vala"
	self->priv = options_get_instance_private (self);
#line 406 "EnumerationTest.c"
}

static void
options_finalize (GObject * obj)
{
	Options * self;
#line 37 "EnumerationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_OPTIONS, Options);
#line 39 "EnumerationTest.vala"
	_g_free0 (self->priv->_test);
#line 37 "EnumerationTest.vala"
	G_OBJECT_CLASS (options_parent_class)->finalize (obj);
#line 419 "EnumerationTest.c"
}

GType
options_get_type (void)
{
	static volatile gsize options_type_id__volatile = 0;
	if (g_once_init_enter (&options_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (OptionsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) options_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Options), 0, (GInstanceInitFunc) options_instance_init, NULL };
		GType options_type_id;
		options_type_id = g_type_register_static (TYPE_OBJECT_MODEL, "Options", &g_define_type_info, 0);
		Options_private_offset = g_type_add_instance_private (options_type_id, sizeof (OptionsPrivate));
		g_once_init_leave (&options_type_id__volatile, options_type_id);
	}
	return options_type_id__volatile;
}

static void
_vala_options_get_property (GObject * object,
                            guint property_id,
                            GValue * value,
                            GParamSpec * pspec)
{
	Options * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_OPTIONS, Options);
#line 37 "EnumerationTest.vala"
	switch (property_id) {
#line 37 "EnumerationTest.vala"
		case OPTIONS_TEST_PROPERTY:
#line 37 "EnumerationTest.vala"
		g_value_set_string (value, options_get_test (self));
#line 37 "EnumerationTest.vala"
		break;
#line 37 "EnumerationTest.vala"
		case OPTIONS_OPTIONS_PROPERTY:
#line 37 "EnumerationTest.vala"
		g_value_set_enum (value, options_get_options (self));
#line 37 "EnumerationTest.vala"
		break;
#line 37 "EnumerationTest.vala"
		case OPTIONS_VALS_PROPERTY:
#line 37 "EnumerationTest.vala"
		g_value_set_enum (value, options_get_vals (self));
#line 37 "EnumerationTest.vala"
		break;
#line 464 "EnumerationTest.c"
		default:
#line 37 "EnumerationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 37 "EnumerationTest.vala"
		break;
#line 470 "EnumerationTest.c"
	}
}

static void
_vala_options_set_property (GObject * object,
                            guint property_id,
                            const GValue * value,
                            GParamSpec * pspec)
{
	Options * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_OPTIONS, Options);
#line 37 "EnumerationTest.vala"
	switch (property_id) {
#line 37 "EnumerationTest.vala"
		case OPTIONS_TEST_PROPERTY:
#line 37 "EnumerationTest.vala"
		options_set_test (self, g_value_get_string (value));
#line 37 "EnumerationTest.vala"
		break;
#line 37 "EnumerationTest.vala"
		case OPTIONS_OPTIONS_PROPERTY:
#line 37 "EnumerationTest.vala"
		options_set_options (self, g_value_get_enum (value));
#line 37 "EnumerationTest.vala"
		break;
#line 37 "EnumerationTest.vala"
		case OPTIONS_VALS_PROPERTY:
#line 37 "EnumerationTest.vala"
		options_set_vals (self, g_value_get_enum (value));
#line 37 "EnumerationTest.vala"
		break;
#line 502 "EnumerationTest.c"
		default:
#line 37 "EnumerationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 37 "EnumerationTest.vala"
		break;
#line 508 "EnumerationTest.c"
	}
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result = NULL;
#line 1516 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1517 "glib-2.0.vapi"
	result = self;
#line 1517 "glib-2.0.vapi"
	return result;
#line 522 "EnumerationTest.c"
}

static void
__lambda165_ (void)
{
	Options* e = NULL;
	Options* _tmp0_;
	GError* _inner_error0_ = NULL;
#line 54 "EnumerationTest.vala"
	_tmp0_ = options_new ();
#line 54 "EnumerationTest.vala"
	e = _tmp0_;
#line 535 "EnumerationTest.c"
	{
		Options* _tmp1_;
		Options* _tmp2_;
		gchar* s = NULL;
		Options* _tmp3_;
		OptionsEnum _tmp4_;
		OptionsEnum _tmp5_;
		gchar* _tmp6_;
		const gchar* _tmp7_;
		gchar* _tmp13_ = NULL;
		Options* _tmp14_;
		OptionsEnum _tmp15_;
		OptionsEnum _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_;
		const gchar* _tmp19_;
		gchar* _tmp25_ = NULL;
		gchar* _tmp26_;
		gchar* _tmp27_;
		const gchar* _tmp28_;
		gchar* _tmp34_ = NULL;
		gchar* _tmp35_;
		gchar* _tmp36_;
		const gchar* _tmp37_;
		GEnumValue* env = NULL;
		GEnumValue* _tmp64_;
		GValue v = {0};
		GValue _tmp65_ = {0};
		GEnumValue* _tmp66_;
		Options* _tmp67_;
		Options* _tmp68_;
		OptionsEnum _tmp69_;
		OptionsEnum _tmp70_;
#line 56 "EnumerationTest.vala"
		_tmp1_ = e;
#line 56 "EnumerationTest.vala"
		options_set_test (_tmp1_, "t1");
#line 57 "EnumerationTest.vala"
		_tmp2_ = e;
#line 57 "EnumerationTest.vala"
		options_set_options (_tmp2_, OPTIONS_ENUM_SelectBefore);
#line 58 "EnumerationTest.vala"
		_tmp3_ = e;
#line 58 "EnumerationTest.vala"
		_tmp4_ = options_get_options (_tmp3_);
#line 58 "EnumerationTest.vala"
		_tmp5_ = _tmp4_;
#line 58 "EnumerationTest.vala"
		_tmp6_ = gxml_enumeration_get_string (TYPE_OPTIONS_ENUM, (gint) _tmp5_, FALSE, FALSE, &_inner_error0_);
#line 58 "EnumerationTest.vala"
		s = _tmp6_;
#line 58 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 589 "EnumerationTest.c"
			goto __catch219_g_error;
		}
#line 59 "EnumerationTest.vala"
		_tmp7_ = s;
#line 59 "EnumerationTest.vala"
		if (g_strcmp0 (_tmp7_, "OPTIONS_ENUM_SelectBefore") != 0) {
#line 596 "EnumerationTest.c"
			FILE* _tmp8_;
			const gchar* _tmp9_;
			const gchar* _tmp10_;
			gchar* _tmp11_;
			gchar* _tmp12_;
#line 60 "EnumerationTest.vala"
			_tmp8_ = stdout;
#line 60 "EnumerationTest.vala"
			_tmp9_ = s;
#line 60 "EnumerationTest.vala"
			_tmp10_ = string_to_string (_tmp9_);
#line 60 "EnumerationTest.vala"
			_tmp11_ = g_strconcat ("ERROR: Bad Enum stringification: ", _tmp10_, NULL);
#line 60 "EnumerationTest.vala"
			_tmp12_ = _tmp11_;
#line 60 "EnumerationTest.vala"
			fprintf (_tmp8_, "%s", _tmp12_);
#line 60 "EnumerationTest.vala"
			_g_free0 (_tmp12_);
#line 61 "EnumerationTest.vala"
			g_assert_not_reached ();
#line 618 "EnumerationTest.c"
		}
#line 63 "EnumerationTest.vala"
		_tmp14_ = e;
#line 63 "EnumerationTest.vala"
		_tmp15_ = options_get_options (_tmp14_);
#line 63 "EnumerationTest.vala"
		_tmp16_ = _tmp15_;
#line 63 "EnumerationTest.vala"
		_tmp17_ = gxml_enumeration_get_nick (TYPE_OPTIONS_ENUM, (gint) _tmp16_, &_inner_error0_);
#line 63 "EnumerationTest.vala"
		_tmp13_ = _tmp17_;
#line 63 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 63 "EnumerationTest.vala"
			_g_free0 (s);
#line 634 "EnumerationTest.c"
			goto __catch219_g_error;
		}
#line 63 "EnumerationTest.vala"
		_tmp18_ = _tmp13_;
#line 63 "EnumerationTest.vala"
		_tmp13_ = NULL;
#line 63 "EnumerationTest.vala"
		_g_free0 (s);
#line 63 "EnumerationTest.vala"
		s = _tmp18_;
#line 64 "EnumerationTest.vala"
		_tmp19_ = s;
#line 64 "EnumerationTest.vala"
		if (g_strcmp0 (_tmp19_, "selectbefore") != 0) {
#line 649 "EnumerationTest.c"
			FILE* _tmp20_;
			const gchar* _tmp21_;
			const gchar* _tmp22_;
			gchar* _tmp23_;
			gchar* _tmp24_;
#line 65 "EnumerationTest.vala"
			_tmp20_ = stdout;
#line 65 "EnumerationTest.vala"
			_tmp21_ = s;
#line 65 "EnumerationTest.vala"
			_tmp22_ = string_to_string (_tmp21_);
#line 65 "EnumerationTest.vala"
			_tmp23_ = g_strconcat ("ERROR: Bad Enum nick name: ", _tmp22_, NULL);
#line 65 "EnumerationTest.vala"
			_tmp24_ = _tmp23_;
#line 65 "EnumerationTest.vala"
			fprintf (_tmp20_, "%s", _tmp24_);
#line 65 "EnumerationTest.vala"
			_g_free0 (_tmp24_);
#line 66 "EnumerationTest.vala"
			g_assert_not_reached ();
#line 671 "EnumerationTest.c"
		}
#line 68 "EnumerationTest.vala"
		_tmp26_ = gxml_enumeration_get_nick (TYPE_OPTIONS_ENUM, (gint) OPTIONS_ENUM_NORMAL_OPERATION, &_inner_error0_);
#line 68 "EnumerationTest.vala"
		_tmp25_ = _tmp26_;
#line 68 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 68 "EnumerationTest.vala"
			_g_free0 (_tmp13_);
#line 68 "EnumerationTest.vala"
			_g_free0 (s);
#line 683 "EnumerationTest.c"
			goto __catch219_g_error;
		}
#line 68 "EnumerationTest.vala"
		_tmp27_ = _tmp25_;
#line 68 "EnumerationTest.vala"
		_tmp25_ = NULL;
#line 68 "EnumerationTest.vala"
		_g_free0 (s);
#line 68 "EnumerationTest.vala"
		s = _tmp27_;
#line 69 "EnumerationTest.vala"
		_tmp28_ = s;
#line 69 "EnumerationTest.vala"
		if (g_strcmp0 (_tmp28_, "normal-operation") != 0) {
#line 698 "EnumerationTest.c"
			FILE* _tmp29_;
			const gchar* _tmp30_;
			const gchar* _tmp31_;
			gchar* _tmp32_;
			gchar* _tmp33_;
#line 70 "EnumerationTest.vala"
			_tmp29_ = stdout;
#line 70 "EnumerationTest.vala"
			_tmp30_ = s;
#line 70 "EnumerationTest.vala"
			_tmp31_ = string_to_string (_tmp30_);
#line 70 "EnumerationTest.vala"
			_tmp32_ = g_strconcat ("ERROR: Bad Enum nick name: ", _tmp31_, NULL);
#line 70 "EnumerationTest.vala"
			_tmp33_ = _tmp32_;
#line 70 "EnumerationTest.vala"
			fprintf (_tmp29_, "%s", _tmp33_);
#line 70 "EnumerationTest.vala"
			_g_free0 (_tmp33_);
#line 71 "EnumerationTest.vala"
			g_assert_not_reached ();
#line 720 "EnumerationTest.c"
		}
#line 73 "EnumerationTest.vala"
		_tmp35_ = gxml_enumeration_get_nick_camelcase (TYPE_OPTIONS_ENUM, (gint) OPTIONS_ENUM_NORMAL_OPERATION, &_inner_error0_);
#line 73 "EnumerationTest.vala"
		_tmp34_ = _tmp35_;
#line 73 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 73 "EnumerationTest.vala"
			_g_free0 (_tmp25_);
#line 73 "EnumerationTest.vala"
			_g_free0 (_tmp13_);
#line 73 "EnumerationTest.vala"
			_g_free0 (s);
#line 734 "EnumerationTest.c"
			goto __catch219_g_error;
		}
#line 73 "EnumerationTest.vala"
		_tmp36_ = _tmp34_;
#line 73 "EnumerationTest.vala"
		_tmp34_ = NULL;
#line 73 "EnumerationTest.vala"
		_g_free0 (s);
#line 73 "EnumerationTest.vala"
		s = _tmp36_;
#line 74 "EnumerationTest.vala"
		_tmp37_ = s;
#line 74 "EnumerationTest.vala"
		if (g_strcmp0 (_tmp37_, "NormalOperation") != 0) {
#line 749 "EnumerationTest.c"
			FILE* _tmp38_;
			const gchar* _tmp39_;
			const gchar* _tmp40_;
			gchar* _tmp41_;
			gchar* _tmp42_;
#line 75 "EnumerationTest.vala"
			_tmp38_ = stdout;
#line 75 "EnumerationTest.vala"
			_tmp39_ = s;
#line 75 "EnumerationTest.vala"
			_tmp40_ = string_to_string (_tmp39_);
#line 75 "EnumerationTest.vala"
			_tmp41_ = g_strconcat ("ERROR: Bad Enum nick name: ", _tmp40_, NULL);
#line 75 "EnumerationTest.vala"
			_tmp42_ = _tmp41_;
#line 75 "EnumerationTest.vala"
			fprintf (_tmp38_, "%s", _tmp42_);
#line 75 "EnumerationTest.vala"
			_g_free0 (_tmp42_);
#line 76 "EnumerationTest.vala"
			g_assert_not_reached ();
#line 771 "EnumerationTest.c"
		}
		{
			GEnumValue* _tmp43_;
			GEnumValue* _tmp44_;
#line 79 "EnumerationTest.vala"
			_tmp43_ = gxml_enumeration_parse (TYPE_OPTIONS_ENUM, "selectbefore", &_inner_error0_);
#line 79 "EnumerationTest.vala"
			_tmp44_ = _tmp43_;
#line 79 "EnumerationTest.vala"
			_g_free0 (_tmp44_);
#line 79 "EnumerationTest.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 784 "EnumerationTest.c"
				goto __catch220_g_error;
			}
		}
		goto __finally220;
		__catch220_g_error:
		{
			GError* e = NULL;
			FILE* _tmp45_;
			const gchar* _tmp46_;
			const gchar* _tmp47_;
			gchar* _tmp48_;
			gchar* _tmp49_;
#line 78 "EnumerationTest.vala"
			e = _inner_error0_;
#line 78 "EnumerationTest.vala"
			_inner_error0_ = NULL;
#line 82 "EnumerationTest.vala"
			_tmp45_ = stdout;
#line 82 "EnumerationTest.vala"
			_tmp46_ = e->message;
#line 82 "EnumerationTest.vala"
			_tmp47_ = string_to_string (_tmp46_);
#line 82 "EnumerationTest.vala"
			_tmp48_ = g_strconcat ("ERROR PARSING selectbefore: ", _tmp47_, NULL);
#line 82 "EnumerationTest.vala"
			_tmp49_ = _tmp48_;
#line 82 "EnumerationTest.vala"
			fprintf (_tmp45_, "%s", _tmp49_);
#line 82 "EnumerationTest.vala"
			_g_free0 (_tmp49_);
#line 83 "EnumerationTest.vala"
			g_assert_not_reached ();
#line 78 "EnumerationTest.vala"
			_g_error_free0 (e);
#line 819 "EnumerationTest.c"
		}
		__finally220:
#line 78 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 78 "EnumerationTest.vala"
			_g_free0 (_tmp34_);
#line 78 "EnumerationTest.vala"
			_g_free0 (_tmp25_);
#line 78 "EnumerationTest.vala"
			_g_free0 (_tmp13_);
#line 78 "EnumerationTest.vala"
			_g_free0 (s);
#line 832 "EnumerationTest.c"
			goto __catch219_g_error;
		}
		{
			GEnumValue* _tmp50_;
			GEnumValue* _tmp51_;
#line 86 "EnumerationTest.vala"
			_tmp50_ = gxml_enumeration_parse (TYPE_OPTIONS_ENUM, "normal-operation", &_inner_error0_);
#line 86 "EnumerationTest.vala"
			_tmp51_ = _tmp50_;
#line 86 "EnumerationTest.vala"
			_g_free0 (_tmp51_);
#line 86 "EnumerationTest.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 846 "EnumerationTest.c"
				goto __catch221_g_error;
			}
		}
		goto __finally221;
		__catch221_g_error:
		{
			GError* e = NULL;
			FILE* _tmp52_;
			const gchar* _tmp53_;
			const gchar* _tmp54_;
			gchar* _tmp55_;
			gchar* _tmp56_;
#line 85 "EnumerationTest.vala"
			e = _inner_error0_;
#line 85 "EnumerationTest.vala"
			_inner_error0_ = NULL;
#line 89 "EnumerationTest.vala"
			_tmp52_ = stdout;
#line 89 "EnumerationTest.vala"
			_tmp53_ = e->message;
#line 89 "EnumerationTest.vala"
			_tmp54_ = string_to_string (_tmp53_);
#line 89 "EnumerationTest.vala"
			_tmp55_ = g_strconcat ("ERROR PARSING normal-operation: ", _tmp54_, NULL);
#line 89 "EnumerationTest.vala"
			_tmp56_ = _tmp55_;
#line 89 "EnumerationTest.vala"
			fprintf (_tmp52_, "%s", _tmp56_);
#line 89 "EnumerationTest.vala"
			_g_free0 (_tmp56_);
#line 90 "EnumerationTest.vala"
			g_assert_not_reached ();
#line 85 "EnumerationTest.vala"
			_g_error_free0 (e);
#line 881 "EnumerationTest.c"
		}
		__finally221:
#line 85 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 85 "EnumerationTest.vala"
			_g_free0 (_tmp34_);
#line 85 "EnumerationTest.vala"
			_g_free0 (_tmp25_);
#line 85 "EnumerationTest.vala"
			_g_free0 (_tmp13_);
#line 85 "EnumerationTest.vala"
			_g_free0 (s);
#line 894 "EnumerationTest.c"
			goto __catch219_g_error;
		}
		{
			GEnumValue* _tmp57_;
			GEnumValue* _tmp58_;
#line 93 "EnumerationTest.vala"
			_tmp57_ = gxml_enumeration_parse (TYPE_OPTIONS_ENUM, "NormalOperation", &_inner_error0_);
#line 93 "EnumerationTest.vala"
			_tmp58_ = _tmp57_;
#line 93 "EnumerationTest.vala"
			_g_free0 (_tmp58_);
#line 93 "EnumerationTest.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 908 "EnumerationTest.c"
				goto __catch222_g_error;
			}
		}
		goto __finally222;
		__catch222_g_error:
		{
			GError* e = NULL;
			FILE* _tmp59_;
			const gchar* _tmp60_;
			const gchar* _tmp61_;
			gchar* _tmp62_;
			gchar* _tmp63_;
#line 92 "EnumerationTest.vala"
			e = _inner_error0_;
#line 92 "EnumerationTest.vala"
			_inner_error0_ = NULL;
#line 96 "EnumerationTest.vala"
			_tmp59_ = stdout;
#line 96 "EnumerationTest.vala"
			_tmp60_ = e->message;
#line 96 "EnumerationTest.vala"
			_tmp61_ = string_to_string (_tmp60_);
#line 96 "EnumerationTest.vala"
			_tmp62_ = g_strconcat ("ERROR PARSING NormalOperation: ", _tmp61_, NULL);
#line 96 "EnumerationTest.vala"
			_tmp63_ = _tmp62_;
#line 96 "EnumerationTest.vala"
			fprintf (_tmp59_, "%s", _tmp63_);
#line 96 "EnumerationTest.vala"
			_g_free0 (_tmp63_);
#line 97 "EnumerationTest.vala"
			g_assert_not_reached ();
#line 92 "EnumerationTest.vala"
			_g_error_free0 (e);
#line 943 "EnumerationTest.c"
		}
		__finally222:
#line 92 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 92 "EnumerationTest.vala"
			_g_free0 (_tmp34_);
#line 92 "EnumerationTest.vala"
			_g_free0 (_tmp25_);
#line 92 "EnumerationTest.vala"
			_g_free0 (_tmp13_);
#line 92 "EnumerationTest.vala"
			_g_free0 (s);
#line 956 "EnumerationTest.c"
			goto __catch219_g_error;
		}
#line 99 "EnumerationTest.vala"
		_tmp64_ = gxml_enumeration_parse (TYPE_OPTIONS_ENUM, "NormalOperation", &_inner_error0_);
#line 99 "EnumerationTest.vala"
		env = _tmp64_;
#line 99 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 99 "EnumerationTest.vala"
			_g_free0 (_tmp34_);
#line 99 "EnumerationTest.vala"
			_g_free0 (_tmp25_);
#line 99 "EnumerationTest.vala"
			_g_free0 (_tmp13_);
#line 99 "EnumerationTest.vala"
			_g_free0 (s);
#line 973 "EnumerationTest.c"
			goto __catch219_g_error;
		}
#line 100 "EnumerationTest.vala"
		g_value_init (&_tmp65_, G_TYPE_INT);
#line 100 "EnumerationTest.vala"
		v = _tmp65_;
#line 101 "EnumerationTest.vala"
		_tmp66_ = env;
#line 101 "EnumerationTest.vala"
		g_value_set_int (&v, (*_tmp66_).value);
#line 102 "EnumerationTest.vala"
		_tmp67_ = e;
#line 102 "EnumerationTest.vala"
		options_set_options (_tmp67_, (OptionsEnum) g_value_get_int (&v));
#line 103 "EnumerationTest.vala"
		_tmp68_ = e;
#line 103 "EnumerationTest.vala"
		_tmp69_ = options_get_options (_tmp68_);
#line 103 "EnumerationTest.vala"
		_tmp70_ = _tmp69_;
#line 103 "EnumerationTest.vala"
		if (_tmp70_ != OPTIONS_ENUM_NORMAL_OPERATION) {
#line 996 "EnumerationTest.c"
			FILE* _tmp71_;
			Options* _tmp72_;
			OptionsEnum _tmp73_;
			OptionsEnum _tmp74_;
			GEnumValue* _tmp75_;
			gchar* _tmp76_;
			gchar* _tmp77_;
#line 104 "EnumerationTest.vala"
			_tmp71_ = stdout;
#line 104 "EnumerationTest.vala"
			_tmp72_ = e;
#line 104 "EnumerationTest.vala"
			_tmp73_ = options_get_options (_tmp72_);
#line 104 "EnumerationTest.vala"
			_tmp74_ = _tmp73_;
#line 104 "EnumerationTest.vala"
			_tmp75_ = g_enum_get_value (g_type_class_ref (TYPE_OPTIONS_ENUM), _tmp74_);
#line 104 "EnumerationTest.vala"
			_tmp76_ = g_strconcat ("ERROR: setting NormalOperation: ", (_tmp75_ != NULL) ? _tmp75_->value_name : NULL, NULL);
#line 104 "EnumerationTest.vala"
			_tmp77_ = _tmp76_;
#line 104 "EnumerationTest.vala"
			fprintf (_tmp71_, "%s", _tmp77_);
#line 104 "EnumerationTest.vala"
			_g_free0 (_tmp77_);
#line 105 "EnumerationTest.vala"
			g_assert_not_reached ();
#line 1024 "EnumerationTest.c"
		}
#line 55 "EnumerationTest.vala"
		G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
#line 55 "EnumerationTest.vala"
		_g_free0 (env);
#line 55 "EnumerationTest.vala"
		_g_free0 (_tmp34_);
#line 55 "EnumerationTest.vala"
		_g_free0 (_tmp25_);
#line 55 "EnumerationTest.vala"
		_g_free0 (_tmp13_);
#line 55 "EnumerationTest.vala"
		_g_free0 (s);
#line 1038 "EnumerationTest.c"
	}
	goto __finally219;
	__catch219_g_error:
	{
		GError* e = NULL;
		FILE* _tmp78_;
		const gchar* _tmp79_;
		const gchar* _tmp80_;
		gchar* _tmp81_;
		gchar* _tmp82_;
#line 55 "EnumerationTest.vala"
		e = _inner_error0_;
#line 55 "EnumerationTest.vala"
		_inner_error0_ = NULL;
#line 109 "EnumerationTest.vala"
		_tmp78_ = stdout;
#line 109 "EnumerationTest.vala"
		_tmp79_ = e->message;
#line 109 "EnumerationTest.vala"
		_tmp80_ = string_to_string (_tmp79_);
#line 109 "EnumerationTest.vala"
		_tmp81_ = g_strconcat ("Error: ", _tmp80_, NULL);
#line 109 "EnumerationTest.vala"
		_tmp82_ = _tmp81_;
#line 109 "EnumerationTest.vala"
		fprintf (_tmp78_, "%s", _tmp82_);
#line 109 "EnumerationTest.vala"
		_g_free0 (_tmp82_);
#line 110 "EnumerationTest.vala"
		g_assert_not_reached ();
#line 55 "EnumerationTest.vala"
		_g_error_free0 (e);
#line 1071 "EnumerationTest.c"
	}
	__finally219:
#line 55 "EnumerationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 55 "EnumerationTest.vala"
		_g_object_unref0 (e);
#line 55 "EnumerationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 55 "EnumerationTest.vala"
		g_clear_error (&_inner_error0_);
#line 55 "EnumerationTest.vala"
		return;
#line 1084 "EnumerationTest.c"
	}
#line 53 "EnumerationTest.vala"
	_g_object_unref0 (e);
#line 1088 "EnumerationTest.c"
}

static void
___lambda165__gtest_func (void)
{
#line 52 "EnumerationTest.vala"
	__lambda165_ ();
#line 1096 "EnumerationTest.c"
}

static gchar*
bool_to_string (gboolean self)
{
	gchar* result = NULL;
#line 37 "glib-2.0.vapi"
	if (self) {
#line 1105 "EnumerationTest.c"
		gchar* _tmp0_;
#line 38 "glib-2.0.vapi"
		_tmp0_ = g_strdup ("true");
#line 38 "glib-2.0.vapi"
		result = _tmp0_;
#line 38 "glib-2.0.vapi"
		return result;
#line 1113 "EnumerationTest.c"
	} else {
		gchar* _tmp1_;
#line 40 "glib-2.0.vapi"
		_tmp1_ = g_strdup ("false");
#line 40 "glib-2.0.vapi"
		result = _tmp1_;
#line 40 "glib-2.0.vapi"
		return result;
#line 1122 "EnumerationTest.c"
	}
}

static void
__lambda166_ (void)
{
	GXmlGDocument* doc = NULL;
	GXmlGDocument* _tmp0_;
	Options* options = NULL;
	Options* _tmp1_;
	Options* _tmp2_;
	GError* _inner_error0_ = NULL;
#line 115 "EnumerationTest.vala"
	_tmp0_ = gxml_gdocument_new ();
#line 115 "EnumerationTest.vala"
	doc = _tmp0_;
#line 116 "EnumerationTest.vala"
	_tmp1_ = options_new ();
#line 116 "EnumerationTest.vala"
	options = _tmp1_;
#line 117 "EnumerationTest.vala"
	_tmp2_ = options;
#line 117 "EnumerationTest.vala"
	options_set_options (_tmp2_, OPTIONS_ENUM_NORMAL_OPERATION);
#line 1147 "EnumerationTest.c"
	{
		Options* _tmp3_;
		GXmlGDocument* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		GXmlGDocument* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		GXmlGDocument* _tmp14_;
		GXmlNode* _tmp15_;
		GXmlNode* _tmp16_;
		GXmlNode* _tmp17_;
		gchar* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		GXmlGDocument* _tmp22_;
		GXmlNode* _tmp23_;
		GXmlNode* _tmp24_;
		GXmlNode* _tmp25_;
		GXmlGDocument* _tmp26_;
		GXmlNode* _tmp27_;
		GXmlNode* _tmp28_;
		GXmlNode* _tmp29_;
		gchar* _tmp30_;
		gchar* _tmp31_;
		gchar* _tmp32_;
		GXmlElement* element = NULL;
		GXmlGDocument* _tmp33_;
		GXmlNode* _tmp34_;
		GXmlNode* _tmp35_;
		GXmlNode* op = NULL;
		GXmlElement* _tmp36_;
		GXmlNode* _tmp37_;
		GXmlNode* _tmp38_;
		GXmlNode* _tmp39_;
		gchar* _tmp40_;
		gchar* _tmp41_;
		gchar* _tmp42_;
		Options* _tmp43_;
		GXmlGDocument* doc2 = NULL;
		GXmlGDocument* _tmp44_;
		GXmlGDocument* _tmp45_;
		GXmlNode* _tmp46_;
		GXmlNode* _tmp47_;
		GXmlNode* _tmp48_;
		Options* _tmp49_;
		GXmlGDocument* _tmp50_;
		GXmlNode* _tmp51_;
		GXmlNode* _tmp52_;
		GXmlNode* opts = NULL;
		GXmlGDocument* _tmp53_;
		GXmlNode* _tmp54_;
		GXmlNode* _tmp55_;
		GXmlElement* _tmp56_;
		GXmlElement* _tmp57_;
		GXmlNode* _tmp58_;
		GXmlNode* _tmp59_;
#line 119 "EnumerationTest.vala"
		g_test_message ("Before serialize...");
#line 120 "EnumerationTest.vala"
		_tmp3_ = options;
#line 120 "EnumerationTest.vala"
		_tmp4_ = doc;
#line 120 "EnumerationTest.vala"
		_tmp5_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp3_, (GXmlNode*) _tmp4_, &_inner_error0_);
#line 120 "EnumerationTest.vala"
		_tmp6_ = _tmp5_;
#line 120 "EnumerationTest.vala"
		_g_object_unref0 (_tmp6_);
#line 120 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1224 "EnumerationTest.c"
			goto __catch223_g_error;
		}
#line 121 "EnumerationTest.vala"
		_tmp7_ = doc;
#line 121 "EnumerationTest.vala"
		_tmp8_ = gxml_gnode_to_string ((GXmlGNode*) _tmp7_);
#line 121 "EnumerationTest.vala"
		_tmp9_ = _tmp8_;
#line 121 "EnumerationTest.vala"
		_tmp10_ = g_strconcat ("doc: ", _tmp9_, NULL);
#line 121 "EnumerationTest.vala"
		_tmp11_ = _tmp10_;
#line 121 "EnumerationTest.vala"
		_tmp12_ = g_strconcat (_tmp11_, " Root?", NULL);
#line 121 "EnumerationTest.vala"
		_tmp13_ = _tmp12_;
#line 121 "EnumerationTest.vala"
		_tmp14_ = doc;
#line 121 "EnumerationTest.vala"
		_tmp15_ = gxml_document_get_root ((GXmlDocument*) _tmp14_);
#line 121 "EnumerationTest.vala"
		_tmp16_ = _tmp15_;
#line 121 "EnumerationTest.vala"
		_tmp17_ = _tmp16_;
#line 121 "EnumerationTest.vala"
		_tmp18_ = bool_to_string (_tmp17_ != NULL);
#line 121 "EnumerationTest.vala"
		_tmp19_ = _tmp18_;
#line 121 "EnumerationTest.vala"
		_tmp20_ = g_strconcat (_tmp13_, _tmp19_, NULL);
#line 121 "EnumerationTest.vala"
		_tmp21_ = _tmp20_;
#line 121 "EnumerationTest.vala"
		g_test_message ("%s", _tmp21_);
#line 121 "EnumerationTest.vala"
		_g_free0 (_tmp21_);
#line 121 "EnumerationTest.vala"
		_g_free0 (_tmp19_);
#line 121 "EnumerationTest.vala"
		_g_object_unref0 (_tmp17_);
#line 121 "EnumerationTest.vala"
		_g_free0 (_tmp13_);
#line 121 "EnumerationTest.vala"
		_g_free0 (_tmp11_);
#line 121 "EnumerationTest.vala"
		_g_free0 (_tmp9_);
#line 122 "EnumerationTest.vala"
		_tmp22_ = doc;
#line 122 "EnumerationTest.vala"
		_tmp23_ = gxml_document_get_root ((GXmlDocument*) _tmp22_);
#line 122 "EnumerationTest.vala"
		_tmp24_ = _tmp23_;
#line 122 "EnumerationTest.vala"
		_tmp25_ = _tmp24_;
#line 122 "EnumerationTest.vala"
		_vala_assert (_tmp25_ != NULL, "doc.root != null");
#line 122 "EnumerationTest.vala"
		_g_object_unref0 (_tmp25_);
#line 123 "EnumerationTest.vala"
		_tmp26_ = doc;
#line 123 "EnumerationTest.vala"
		_tmp27_ = gxml_document_get_root ((GXmlDocument*) _tmp26_);
#line 123 "EnumerationTest.vala"
		_tmp28_ = _tmp27_;
#line 123 "EnumerationTest.vala"
		_tmp29_ = _tmp28_;
#line 123 "EnumerationTest.vala"
		_tmp30_ = gxml_node_get_name (_tmp29_);
#line 123 "EnumerationTest.vala"
		_tmp31_ = _tmp30_;
#line 123 "EnumerationTest.vala"
		_tmp32_ = _tmp31_;
#line 123 "EnumerationTest.vala"
		_vala_assert (g_strcmp0 (_tmp32_, "options") == 0, "doc.root.name == \"options\"");
#line 123 "EnumerationTest.vala"
		_g_free0 (_tmp32_);
#line 123 "EnumerationTest.vala"
		_g_object_unref0 (_tmp29_);
#line 124 "EnumerationTest.vala"
		_tmp33_ = doc;
#line 124 "EnumerationTest.vala"
		_tmp34_ = gxml_document_get_root ((GXmlDocument*) _tmp33_);
#line 124 "EnumerationTest.vala"
		_tmp35_ = _tmp34_;
#line 124 "EnumerationTest.vala"
		element = G_TYPE_CHECK_INSTANCE_CAST (_tmp35_, GXML_TYPE_ELEMENT, GXmlElement);
#line 125 "EnumerationTest.vala"
		_tmp36_ = element;
#line 125 "EnumerationTest.vala"
		_tmp37_ = gxml_element_get_attr (_tmp36_, "options");
#line 125 "EnumerationTest.vala"
		op = _tmp37_;
#line 126 "EnumerationTest.vala"
		_tmp38_ = op;
#line 126 "EnumerationTest.vala"
		_vala_assert (_tmp38_ != NULL, "op != null");
#line 127 "EnumerationTest.vala"
		_tmp39_ = op;
#line 127 "EnumerationTest.vala"
		_tmp40_ = gxml_node_get_value (_tmp39_);
#line 127 "EnumerationTest.vala"
		_tmp41_ = _tmp40_;
#line 127 "EnumerationTest.vala"
		_tmp42_ = _tmp41_;
#line 127 "EnumerationTest.vala"
		_vala_assert (g_strcmp0 (_tmp42_, "NormalOperation") == 0, "op.value == \"NormalOperation\"");
#line 127 "EnumerationTest.vala"
		_g_free0 (_tmp42_);
#line 128 "EnumerationTest.vala"
		_tmp43_ = options;
#line 128 "EnumerationTest.vala"
		options_set_options (_tmp43_, (OptionsEnum) -1);
#line 129 "EnumerationTest.vala"
		_tmp44_ = gxml_gdocument_new ();
#line 129 "EnumerationTest.vala"
		doc2 = _tmp44_;
#line 130 "EnumerationTest.vala"
		_tmp45_ = doc;
#line 130 "EnumerationTest.vala"
		_tmp46_ = gxml_document_get_root ((GXmlDocument*) _tmp45_);
#line 130 "EnumerationTest.vala"
		_tmp47_ = _tmp46_;
#line 130 "EnumerationTest.vala"
		_tmp48_ = _tmp47_;
#line 130 "EnumerationTest.vala"
		_vala_assert (_tmp48_ != NULL, "doc.root != null");
#line 130 "EnumerationTest.vala"
		_g_object_unref0 (_tmp48_);
#line 131 "EnumerationTest.vala"
		_tmp49_ = options;
#line 131 "EnumerationTest.vala"
		_tmp50_ = doc2;
#line 131 "EnumerationTest.vala"
		_tmp51_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp49_, (GXmlNode*) _tmp50_, &_inner_error0_);
#line 131 "EnumerationTest.vala"
		_tmp52_ = _tmp51_;
#line 131 "EnumerationTest.vala"
		_g_object_unref0 (_tmp52_);
#line 131 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 131 "EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 131 "EnumerationTest.vala"
			_g_object_unref0 (op);
#line 131 "EnumerationTest.vala"
			_g_object_unref0 (element);
#line 1371 "EnumerationTest.c"
			goto __catch223_g_error;
		}
#line 132 "EnumerationTest.vala"
		_tmp53_ = doc2;
#line 132 "EnumerationTest.vala"
		_tmp54_ = gxml_document_get_root ((GXmlDocument*) _tmp53_);
#line 132 "EnumerationTest.vala"
		_tmp55_ = _tmp54_;
#line 132 "EnumerationTest.vala"
		_tmp56_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp55_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp55_) : NULL;
#line 132 "EnumerationTest.vala"
		if (_tmp56_ == NULL) {
#line 132 "EnumerationTest.vala"
			_g_object_unref0 (_tmp55_);
#line 1386 "EnumerationTest.c"
		}
#line 132 "EnumerationTest.vala"
		_tmp57_ = _tmp56_;
#line 132 "EnumerationTest.vala"
		_tmp58_ = gxml_element_get_attr (_tmp57_, "options");
#line 132 "EnumerationTest.vala"
		_tmp59_ = _tmp58_;
#line 132 "EnumerationTest.vala"
		_g_object_unref0 (_tmp57_);
#line 132 "EnumerationTest.vala"
		opts = _tmp59_;
#line 133 "EnumerationTest.vala"
		_vala_assert (opts == NULL, "opts == null");
#line 118 "EnumerationTest.vala"
		_g_object_unref0 (opts);
#line 118 "EnumerationTest.vala"
		_g_object_unref0 (doc2);
#line 118 "EnumerationTest.vala"
		_g_object_unref0 (op);
#line 118 "EnumerationTest.vala"
		_g_object_unref0 (element);
#line 1408 "EnumerationTest.c"
	}
	goto __finally223;
	__catch223_g_error:
	{
		GError* e = NULL;
		FILE* _tmp60_;
		const gchar* _tmp61_;
		const gchar* _tmp62_;
		gchar* _tmp63_;
		gchar* _tmp64_;
#line 118 "EnumerationTest.vala"
		e = _inner_error0_;
#line 118 "EnumerationTest.vala"
		_inner_error0_ = NULL;
#line 136 "EnumerationTest.vala"
		_tmp60_ = stdout;
#line 136 "EnumerationTest.vala"
		_tmp61_ = e->message;
#line 136 "EnumerationTest.vala"
		_tmp62_ = string_to_string (_tmp61_);
#line 136 "EnumerationTest.vala"
		_tmp63_ = g_strconcat ("Error: ", _tmp62_, NULL);
#line 136 "EnumerationTest.vala"
		_tmp64_ = _tmp63_;
#line 136 "EnumerationTest.vala"
		fprintf (_tmp60_, "%s", _tmp64_);
#line 136 "EnumerationTest.vala"
		_g_free0 (_tmp64_);
#line 137 "EnumerationTest.vala"
		g_assert_not_reached ();
#line 118 "EnumerationTest.vala"
		_g_error_free0 (e);
#line 1441 "EnumerationTest.c"
	}
	__finally223:
#line 118 "EnumerationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 118 "EnumerationTest.vala"
		_g_object_unref0 (options);
#line 118 "EnumerationTest.vala"
		_g_object_unref0 (doc);
#line 118 "EnumerationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 118 "EnumerationTest.vala"
		g_clear_error (&_inner_error0_);
#line 118 "EnumerationTest.vala"
		return;
#line 1456 "EnumerationTest.c"
	}
#line 114 "EnumerationTest.vala"
	_g_object_unref0 (options);
#line 114 "EnumerationTest.vala"
	_g_object_unref0 (doc);
#line 1462 "EnumerationTest.c"
}

static void
___lambda166__gtest_func (void)
{
#line 113 "EnumerationTest.vala"
	__lambda166_ ();
#line 1470 "EnumerationTest.c"
}

static void
__lambda167_ (void)
{
	Options* options = NULL;
	Options* _tmp0_;
	GError* _inner_error0_ = NULL;
#line 142 "EnumerationTest.vala"
	_tmp0_ = options_new ();
#line 142 "EnumerationTest.vala"
	options = _tmp0_;
#line 1483 "EnumerationTest.c"
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_;
		Options* _tmp2_;
		GXmlGDocument* _tmp3_;
		Options* _tmp4_;
		OptionsEnum _tmp5_;
		OptionsEnum _tmp6_;
		GXmlGDocument* doc2 = NULL;
		GXmlGDocument* _tmp17_;
		Options* _tmp18_;
		GXmlGDocument* _tmp19_;
		Options* _tmp20_;
		OptionsEnum _tmp21_;
		OptionsEnum _tmp22_;
		GXmlGDocument* doc3 = NULL;
		GXmlGDocument* _tmp33_;
		Options* _tmp34_;
		GXmlGDocument* _tmp35_;
		Options* _tmp36_;
		OptionsEnum _tmp37_;
		OptionsEnum _tmp38_;
		GXmlGDocument* doc4 = NULL;
		GXmlGDocument* _tmp49_;
		Options* _tmp50_;
		GXmlGDocument* _tmp51_;
		Options* _tmp52_;
		OptionsEnum _tmp53_;
		OptionsEnum _tmp54_;
		GXmlGDocument* doc5 = NULL;
		GXmlGDocument* _tmp65_;
		Options* _tmp66_;
		GXmlGDocument* _tmp67_;
		Options* _tmp68_;
		OptionsEnum _tmp69_;
		OptionsEnum _tmp70_;
		GXmlGDocument* doc6 = NULL;
		GXmlGDocument* _tmp81_;
		Options* _tmp82_;
		GXmlGDocument* _tmp83_;
		Options* _tmp84_;
		OptionsEnum _tmp85_;
		OptionsEnum _tmp86_;
		GXmlGDocument* doc7 = NULL;
		GXmlGDocument* _tmp87_;
		Options* _tmp88_;
		GXmlGDocument* _tmp89_;
		Options* _tmp90_;
		OptionsEnum _tmp91_;
		OptionsEnum _tmp92_;
		Options* op2 = NULL;
		Options* _tmp103_;
		GXmlGDocument* doc8 = NULL;
		GXmlGDocument* _tmp104_;
		Options* _tmp105_;
		GXmlGDocument* _tmp106_;
		Options* _tmp107_;
		OptionsEnum _tmp108_;
		OptionsEnum _tmp109_;
#line 144 "EnumerationTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <options options=\"NormalOperation\"/>", 0, &_inner_error0_);
#line 144 "EnumerationTest.vala"
		doc = _tmp1_;
#line 144 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1549 "EnumerationTest.c"
			goto __catch224_g_error;
		}
#line 146 "EnumerationTest.vala"
		_tmp2_ = options;
#line 146 "EnumerationTest.vala"
		_tmp3_ = doc;
#line 146 "EnumerationTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 146 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 146 "EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1562 "EnumerationTest.c"
			goto __catch224_g_error;
		}
#line 147 "EnumerationTest.vala"
		_tmp4_ = options;
#line 147 "EnumerationTest.vala"
		_tmp5_ = options_get_options (_tmp4_);
#line 147 "EnumerationTest.vala"
		_tmp6_ = _tmp5_;
#line 147 "EnumerationTest.vala"
		if (_tmp6_ != OPTIONS_ENUM_NORMAL_OPERATION) {
#line 1573 "EnumerationTest.c"
			FILE* _tmp7_;
			Options* _tmp8_;
			OptionsEnum _tmp9_;
			OptionsEnum _tmp10_;
			GEnumValue* _tmp11_;
			GXmlGDocument* _tmp12_;
			gchar* _tmp13_;
			gchar* _tmp14_;
			gchar* _tmp15_;
			gchar* _tmp16_;
#line 148 "EnumerationTest.vala"
			_tmp7_ = stdout;
#line 148 "EnumerationTest.vala"
			_tmp8_ = options;
#line 148 "EnumerationTest.vala"
			_tmp9_ = options_get_options (_tmp8_);
#line 148 "EnumerationTest.vala"
			_tmp10_ = _tmp9_;
#line 148 "EnumerationTest.vala"
			_tmp11_ = g_enum_get_value (g_type_class_ref (TYPE_OPTIONS_ENUM), _tmp10_);
#line 148 "EnumerationTest.vala"
			_tmp12_ = doc;
#line 148 "EnumerationTest.vala"
			_tmp13_ = gxml_gnode_to_string ((GXmlGNode*) _tmp12_);
#line 148 "EnumerationTest.vala"
			_tmp14_ = _tmp13_;
#line 148 "EnumerationTest.vala"
			_tmp15_ = g_strconcat ("ERROR: Bad value to options property: ", (_tmp11_ != NULL) ? _tmp11_->value_name : NULL, "\n", _tmp14_, NULL);
#line 148 "EnumerationTest.vala"
			_tmp16_ = _tmp15_;
#line 148 "EnumerationTest.vala"
			fprintf (_tmp7_, "%s", _tmp16_);
#line 148 "EnumerationTest.vala"
			_g_free0 (_tmp16_);
#line 148 "EnumerationTest.vala"
			_g_free0 (_tmp14_);
#line 149 "EnumerationTest.vala"
			g_assert_not_reached ();
#line 1612 "EnumerationTest.c"
		}
#line 151 "EnumerationTest.vala"
		_tmp17_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <options options=\"normal-operation\"/>", 0, &_inner_error0_);
#line 151 "EnumerationTest.vala"
		doc2 = _tmp17_;
#line 151 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 151 "EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1622 "EnumerationTest.c"
			goto __catch224_g_error;
		}
#line 153 "EnumerationTest.vala"
		_tmp18_ = options;
#line 153 "EnumerationTest.vala"
		_tmp19_ = doc2;
#line 153 "EnumerationTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp18_, (GXmlNode*) _tmp19_, &_inner_error0_);
#line 153 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 153 "EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 153 "EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1637 "EnumerationTest.c"
			goto __catch224_g_error;
		}
#line 154 "EnumerationTest.vala"
		_tmp20_ = options;
#line 154 "EnumerationTest.vala"
		_tmp21_ = options_get_options (_tmp20_);
#line 154 "EnumerationTest.vala"
		_tmp22_ = _tmp21_;
#line 154 "EnumerationTest.vala"
		if (_tmp22_ != OPTIONS_ENUM_NORMAL_OPERATION) {
#line 1648 "EnumerationTest.c"
			FILE* _tmp23_;
			Options* _tmp24_;
			OptionsEnum _tmp25_;
			OptionsEnum _tmp26_;
			GEnumValue* _tmp27_;
			GXmlGDocument* _tmp28_;
			gchar* _tmp29_;
			gchar* _tmp30_;
			gchar* _tmp31_;
			gchar* _tmp32_;
#line 155 "EnumerationTest.vala"
			_tmp23_ = stdout;
#line 155 "EnumerationTest.vala"
			_tmp24_ = options;
#line 155 "EnumerationTest.vala"
			_tmp25_ = options_get_options (_tmp24_);
#line 155 "EnumerationTest.vala"
			_tmp26_ = _tmp25_;
#line 155 "EnumerationTest.vala"
			_tmp27_ = g_enum_get_value (g_type_class_ref (TYPE_OPTIONS_ENUM), _tmp26_);
#line 155 "EnumerationTest.vala"
			_tmp28_ = doc2;
#line 155 "EnumerationTest.vala"
			_tmp29_ = gxml_gnode_to_string ((GXmlGNode*) _tmp28_);
#line 155 "EnumerationTest.vala"
			_tmp30_ = _tmp29_;
#line 155 "EnumerationTest.vala"
			_tmp31_ = g_strconcat ("ERROR: Bad value to options property: ", (_tmp27_ != NULL) ? _tmp27_->value_name : NULL, "\n", _tmp30_, NULL);
#line 155 "EnumerationTest.vala"
			_tmp32_ = _tmp31_;
#line 155 "EnumerationTest.vala"
			fprintf (_tmp23_, "%s", _tmp32_);
#line 155 "EnumerationTest.vala"
			_g_free0 (_tmp32_);
#line 155 "EnumerationTest.vala"
			_g_free0 (_tmp30_);
#line 156 "EnumerationTest.vala"
			g_assert_not_reached ();
#line 1687 "EnumerationTest.c"
		}
#line 158 "EnumerationTest.vala"
		_tmp33_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <options options=\"selectbefore\"/>", 0, &_inner_error0_);
#line 158 "EnumerationTest.vala"
		doc3 = _tmp33_;
#line 158 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 158 "EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 158 "EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1699 "EnumerationTest.c"
			goto __catch224_g_error;
		}
#line 160 "EnumerationTest.vala"
		_tmp34_ = options;
#line 160 "EnumerationTest.vala"
		_tmp35_ = doc3;
#line 160 "EnumerationTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp34_, (GXmlNode*) _tmp35_, &_inner_error0_);
#line 160 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 160 "EnumerationTest.vala"
			_g_object_unref0 (doc3);
#line 160 "EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 160 "EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1716 "EnumerationTest.c"
			goto __catch224_g_error;
		}
#line 161 "EnumerationTest.vala"
		_tmp36_ = options;
#line 161 "EnumerationTest.vala"
		_tmp37_ = options_get_options (_tmp36_);
#line 161 "EnumerationTest.vala"
		_tmp38_ = _tmp37_;
#line 161 "EnumerationTest.vala"
		if (_tmp38_ != OPTIONS_ENUM_SelectBefore) {
#line 1727 "EnumerationTest.c"
			FILE* _tmp39_;
			Options* _tmp40_;
			OptionsEnum _tmp41_;
			OptionsEnum _tmp42_;
			GEnumValue* _tmp43_;
			GXmlGDocument* _tmp44_;
			gchar* _tmp45_;
			gchar* _tmp46_;
			gchar* _tmp47_;
			gchar* _tmp48_;
#line 162 "EnumerationTest.vala"
			_tmp39_ = stdout;
#line 162 "EnumerationTest.vala"
			_tmp40_ = options;
#line 162 "EnumerationTest.vala"
			_tmp41_ = options_get_options (_tmp40_);
#line 162 "EnumerationTest.vala"
			_tmp42_ = _tmp41_;
#line 162 "EnumerationTest.vala"
			_tmp43_ = g_enum_get_value (g_type_class_ref (TYPE_OPTIONS_ENUM), _tmp42_);
#line 162 "EnumerationTest.vala"
			_tmp44_ = doc3;
#line 162 "EnumerationTest.vala"
			_tmp45_ = gxml_gnode_to_string ((GXmlGNode*) _tmp44_);
#line 162 "EnumerationTest.vala"
			_tmp46_ = _tmp45_;
#line 162 "EnumerationTest.vala"
			_tmp47_ = g_strconcat ("ERROR: Bad value to options property: ", (_tmp43_ != NULL) ? _tmp43_->value_name : NULL, "\n", _tmp46_, NULL);
#line 162 "EnumerationTest.vala"
			_tmp48_ = _tmp47_;
#line 162 "EnumerationTest.vala"
			fprintf (_tmp39_, "%s", _tmp48_);
#line 162 "EnumerationTest.vala"
			_g_free0 (_tmp48_);
#line 162 "EnumerationTest.vala"
			_g_free0 (_tmp46_);
#line 163 "EnumerationTest.vala"
			g_assert_not_reached ();
#line 1766 "EnumerationTest.c"
		}
#line 165 "EnumerationTest.vala"
		_tmp49_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <options options=\"OPTIONS_ENUM_SelectBefore\"/" \
">", 0, &_inner_error0_);
#line 165 "EnumerationTest.vala"
		doc4 = _tmp49_;
#line 165 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 165 "EnumerationTest.vala"
			_g_object_unref0 (doc3);
#line 165 "EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 165 "EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1780 "EnumerationTest.c"
			goto __catch224_g_error;
		}
#line 167 "EnumerationTest.vala"
		_tmp50_ = options;
#line 167 "EnumerationTest.vala"
		_tmp51_ = doc4;
#line 167 "EnumerationTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp50_, (GXmlNode*) _tmp51_, &_inner_error0_);
#line 167 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 167 "EnumerationTest.vala"
			_g_object_unref0 (doc4);
#line 167 "EnumerationTest.vala"
			_g_object_unref0 (doc3);
#line 167 "EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 167 "EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1799 "EnumerationTest.c"
			goto __catch224_g_error;
		}
#line 168 "EnumerationTest.vala"
		_tmp52_ = options;
#line 168 "EnumerationTest.vala"
		_tmp53_ = options_get_options (_tmp52_);
#line 168 "EnumerationTest.vala"
		_tmp54_ = _tmp53_;
#line 168 "EnumerationTest.vala"
		if (_tmp54_ != OPTIONS_ENUM_SelectBefore) {
#line 1810 "EnumerationTest.c"
			FILE* _tmp55_;
			Options* _tmp56_;
			OptionsEnum _tmp57_;
			OptionsEnum _tmp58_;
			GEnumValue* _tmp59_;
			GXmlGDocument* _tmp60_;
			gchar* _tmp61_;
			gchar* _tmp62_;
			gchar* _tmp63_;
			gchar* _tmp64_;
#line 169 "EnumerationTest.vala"
			_tmp55_ = stdout;
#line 169 "EnumerationTest.vala"
			_tmp56_ = options;
#line 169 "EnumerationTest.vala"
			_tmp57_ = options_get_options (_tmp56_);
#line 169 "EnumerationTest.vala"
			_tmp58_ = _tmp57_;
#line 169 "EnumerationTest.vala"
			_tmp59_ = g_enum_get_value (g_type_class_ref (TYPE_OPTIONS_ENUM), _tmp58_);
#line 169 "EnumerationTest.vala"
			_tmp60_ = doc4;
#line 169 "EnumerationTest.vala"
			_tmp61_ = gxml_gnode_to_string ((GXmlGNode*) _tmp60_);
#line 169 "EnumerationTest.vala"
			_tmp62_ = _tmp61_;
#line 169 "EnumerationTest.vala"
			_tmp63_ = g_strconcat ("ERROR: Bad value to options property: ", (_tmp59_ != NULL) ? _tmp59_->value_name : NULL, "\n", _tmp62_, NULL);
#line 169 "EnumerationTest.vala"
			_tmp64_ = _tmp63_;
#line 169 "EnumerationTest.vala"
			fprintf (_tmp55_, "%s", _tmp64_);
#line 169 "EnumerationTest.vala"
			_g_free0 (_tmp64_);
#line 169 "EnumerationTest.vala"
			_g_free0 (_tmp62_);
#line 170 "EnumerationTest.vala"
			g_assert_not_reached ();
#line 1849 "EnumerationTest.c"
		}
#line 172 "EnumerationTest.vala"
		_tmp65_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <options options=\"SelectBefore\"/>", 0, &_inner_error0_);
#line 172 "EnumerationTest.vala"
		doc5 = _tmp65_;
#line 172 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 172 "EnumerationTest.vala"
			_g_object_unref0 (doc4);
#line 172 "EnumerationTest.vala"
			_g_object_unref0 (doc3);
#line 172 "EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 172 "EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1865 "EnumerationTest.c"
			goto __catch224_g_error;
		}
#line 174 "EnumerationTest.vala"
		_tmp66_ = options;
#line 174 "EnumerationTest.vala"
		_tmp67_ = doc5;
#line 174 "EnumerationTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp66_, (GXmlNode*) _tmp67_, &_inner_error0_);
#line 174 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 174 "EnumerationTest.vala"
			_g_object_unref0 (doc5);
#line 174 "EnumerationTest.vala"
			_g_object_unref0 (doc4);
#line 174 "EnumerationTest.vala"
			_g_object_unref0 (doc3);
#line 174 "EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 174 "EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1886 "EnumerationTest.c"
			goto __catch224_g_error;
		}
#line 175 "EnumerationTest.vala"
		_tmp68_ = options;
#line 175 "EnumerationTest.vala"
		_tmp69_ = options_get_options (_tmp68_);
#line 175 "EnumerationTest.vala"
		_tmp70_ = _tmp69_;
#line 175 "EnumerationTest.vala"
		if (_tmp70_ != OPTIONS_ENUM_SelectBefore) {
#line 1897 "EnumerationTest.c"
			FILE* _tmp71_;
			Options* _tmp72_;
			OptionsEnum _tmp73_;
			OptionsEnum _tmp74_;
			GEnumValue* _tmp75_;
			GXmlGDocument* _tmp76_;
			gchar* _tmp77_;
			gchar* _tmp78_;
			gchar* _tmp79_;
			gchar* _tmp80_;
#line 176 "EnumerationTest.vala"
			_tmp71_ = stdout;
#line 176 "EnumerationTest.vala"
			_tmp72_ = options;
#line 176 "EnumerationTest.vala"
			_tmp73_ = options_get_options (_tmp72_);
#line 176 "EnumerationTest.vala"
			_tmp74_ = _tmp73_;
#line 176 "EnumerationTest.vala"
			_tmp75_ = g_enum_get_value (g_type_class_ref (TYPE_OPTIONS_ENUM), _tmp74_);
#line 176 "EnumerationTest.vala"
			_tmp76_ = doc5;
#line 176 "EnumerationTest.vala"
			_tmp77_ = gxml_gnode_to_string ((GXmlGNode*) _tmp76_);
#line 176 "EnumerationTest.vala"
			_tmp78_ = _tmp77_;
#line 176 "EnumerationTest.vala"
			_tmp79_ = g_strconcat ("ERROR: Bad value to options property: ", (_tmp75_ != NULL) ? _tmp75_->value_name : NULL, "\n", _tmp78_, NULL);
#line 176 "EnumerationTest.vala"
			_tmp80_ = _tmp79_;
#line 176 "EnumerationTest.vala"
			fprintf (_tmp71_, "%s", _tmp80_);
#line 176 "EnumerationTest.vala"
			_g_free0 (_tmp80_);
#line 176 "EnumerationTest.vala"
			_g_free0 (_tmp78_);
#line 177 "EnumerationTest.vala"
			g_assert_not_reached ();
#line 1936 "EnumerationTest.c"
		}
#line 179 "EnumerationTest.vala"
		_tmp81_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <options options=\"SELECTBEFORE\"/>", 0, &_inner_error0_);
#line 179 "EnumerationTest.vala"
		doc6 = _tmp81_;
#line 179 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 179 "EnumerationTest.vala"
			_g_object_unref0 (doc5);
#line 179 "EnumerationTest.vala"
			_g_object_unref0 (doc4);
#line 179 "EnumerationTest.vala"
			_g_object_unref0 (doc3);
#line 179 "EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 179 "EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1954 "EnumerationTest.c"
			goto __catch224_g_error;
		}
#line 181 "EnumerationTest.vala"
		_tmp82_ = options;
#line 181 "EnumerationTest.vala"
		_tmp83_ = doc6;
#line 181 "EnumerationTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp82_, (GXmlNode*) _tmp83_, &_inner_error0_);
#line 181 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 181 "EnumerationTest.vala"
			_g_object_unref0 (doc6);
#line 181 "EnumerationTest.vala"
			_g_object_unref0 (doc5);
#line 181 "EnumerationTest.vala"
			_g_object_unref0 (doc4);
#line 181 "EnumerationTest.vala"
			_g_object_unref0 (doc3);
#line 181 "EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 181 "EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 1977 "EnumerationTest.c"
			goto __catch224_g_error;
		}
#line 182 "EnumerationTest.vala"
		_tmp84_ = options;
#line 182 "EnumerationTest.vala"
		_tmp85_ = options_get_options (_tmp84_);
#line 182 "EnumerationTest.vala"
		_tmp86_ = _tmp85_;
#line 182 "EnumerationTest.vala"
		_vala_assert (_tmp86_ == OPTIONS_ENUM_SelectBefore, "options.options == OptionsEnum.SelectBefore");
#line 183 "EnumerationTest.vala"
		_tmp87_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <options options=\"NORMAL_OPERATION\"/>", 0, &_inner_error0_);
#line 183 "EnumerationTest.vala"
		doc7 = _tmp87_;
#line 183 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 183 "EnumerationTest.vala"
			_g_object_unref0 (doc6);
#line 183 "EnumerationTest.vala"
			_g_object_unref0 (doc5);
#line 183 "EnumerationTest.vala"
			_g_object_unref0 (doc4);
#line 183 "EnumerationTest.vala"
			_g_object_unref0 (doc3);
#line 183 "EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 183 "EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 2006 "EnumerationTest.c"
			goto __catch224_g_error;
		}
#line 185 "EnumerationTest.vala"
		_tmp88_ = options;
#line 185 "EnumerationTest.vala"
		_tmp89_ = doc7;
#line 185 "EnumerationTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp88_, (GXmlNode*) _tmp89_, &_inner_error0_);
#line 185 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 185 "EnumerationTest.vala"
			_g_object_unref0 (doc7);
#line 185 "EnumerationTest.vala"
			_g_object_unref0 (doc6);
#line 185 "EnumerationTest.vala"
			_g_object_unref0 (doc5);
#line 185 "EnumerationTest.vala"
			_g_object_unref0 (doc4);
#line 185 "EnumerationTest.vala"
			_g_object_unref0 (doc3);
#line 185 "EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 185 "EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 2031 "EnumerationTest.c"
			goto __catch224_g_error;
		}
#line 186 "EnumerationTest.vala"
		_tmp90_ = options;
#line 186 "EnumerationTest.vala"
		_tmp91_ = options_get_options (_tmp90_);
#line 186 "EnumerationTest.vala"
		_tmp92_ = _tmp91_;
#line 186 "EnumerationTest.vala"
		if (_tmp92_ != OPTIONS_ENUM_SelectBefore) {
#line 2042 "EnumerationTest.c"
			FILE* _tmp93_;
			Options* _tmp94_;
			OptionsEnum _tmp95_;
			OptionsEnum _tmp96_;
			GEnumValue* _tmp97_;
			GXmlGDocument* _tmp98_;
			gchar* _tmp99_;
			gchar* _tmp100_;
			gchar* _tmp101_;
			gchar* _tmp102_;
#line 187 "EnumerationTest.vala"
			_tmp93_ = stdout;
#line 187 "EnumerationTest.vala"
			_tmp94_ = options;
#line 187 "EnumerationTest.vala"
			_tmp95_ = options_get_options (_tmp94_);
#line 187 "EnumerationTest.vala"
			_tmp96_ = _tmp95_;
#line 187 "EnumerationTest.vala"
			_tmp97_ = g_enum_get_value (g_type_class_ref (TYPE_OPTIONS_ENUM), _tmp96_);
#line 187 "EnumerationTest.vala"
			_tmp98_ = doc7;
#line 187 "EnumerationTest.vala"
			_tmp99_ = gxml_gnode_to_string ((GXmlGNode*) _tmp98_);
#line 187 "EnumerationTest.vala"
			_tmp100_ = _tmp99_;
#line 187 "EnumerationTest.vala"
			_tmp101_ = g_strconcat ("ERROR: Bad value to options property: ", (_tmp97_ != NULL) ? _tmp97_->value_name : NULL, "\n", _tmp100_, NULL);
#line 187 "EnumerationTest.vala"
			_tmp102_ = _tmp101_;
#line 187 "EnumerationTest.vala"
			fprintf (_tmp93_, "%s", _tmp102_);
#line 187 "EnumerationTest.vala"
			_g_free0 (_tmp102_);
#line 187 "EnumerationTest.vala"
			_g_free0 (_tmp100_);
#line 188 "EnumerationTest.vala"
			g_assert_not_reached ();
#line 2081 "EnumerationTest.c"
		}
#line 190 "EnumerationTest.vala"
		_tmp103_ = options_new ();
#line 190 "EnumerationTest.vala"
		op2 = _tmp103_;
#line 191 "EnumerationTest.vala"
		_tmp104_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <options options=\"INVALID\"/>", 0, &_inner_error0_);
#line 191 "EnumerationTest.vala"
		doc8 = _tmp104_;
#line 191 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 191 "EnumerationTest.vala"
			_g_object_unref0 (op2);
#line 191 "EnumerationTest.vala"
			_g_object_unref0 (doc7);
#line 191 "EnumerationTest.vala"
			_g_object_unref0 (doc6);
#line 191 "EnumerationTest.vala"
			_g_object_unref0 (doc5);
#line 191 "EnumerationTest.vala"
			_g_object_unref0 (doc4);
#line 191 "EnumerationTest.vala"
			_g_object_unref0 (doc3);
#line 191 "EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 191 "EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 2109 "EnumerationTest.c"
			goto __catch224_g_error;
		}
#line 193 "EnumerationTest.vala"
		_tmp105_ = op2;
#line 193 "EnumerationTest.vala"
		_tmp106_ = doc8;
#line 193 "EnumerationTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp105_, (GXmlNode*) _tmp106_, &_inner_error0_);
#line 193 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 193 "EnumerationTest.vala"
			_g_object_unref0 (doc8);
#line 193 "EnumerationTest.vala"
			_g_object_unref0 (op2);
#line 193 "EnumerationTest.vala"
			_g_object_unref0 (doc7);
#line 193 "EnumerationTest.vala"
			_g_object_unref0 (doc6);
#line 193 "EnumerationTest.vala"
			_g_object_unref0 (doc5);
#line 193 "EnumerationTest.vala"
			_g_object_unref0 (doc4);
#line 193 "EnumerationTest.vala"
			_g_object_unref0 (doc3);
#line 193 "EnumerationTest.vala"
			_g_object_unref0 (doc2);
#line 193 "EnumerationTest.vala"
			_g_object_unref0 (doc);
#line 2138 "EnumerationTest.c"
			goto __catch224_g_error;
		}
#line 194 "EnumerationTest.vala"
		_tmp107_ = op2;
#line 194 "EnumerationTest.vala"
		_tmp108_ = options_get_options (_tmp107_);
#line 194 "EnumerationTest.vala"
		_tmp109_ = _tmp108_;
#line 194 "EnumerationTest.vala"
		if (_tmp109_ != OPTIONS_ENUM_SelectBefore) {
#line 2149 "EnumerationTest.c"
			FILE* _tmp110_;
			Options* _tmp111_;
			OptionsEnum _tmp112_;
			OptionsEnum _tmp113_;
			GEnumValue* _tmp114_;
			GXmlGDocument* _tmp115_;
			gchar* _tmp116_;
			gchar* _tmp117_;
			gchar* _tmp118_;
			gchar* _tmp119_;
#line 195 "EnumerationTest.vala"
			_tmp110_ = stdout;
#line 195 "EnumerationTest.vala"
			_tmp111_ = op2;
#line 195 "EnumerationTest.vala"
			_tmp112_ = options_get_options (_tmp111_);
#line 195 "EnumerationTest.vala"
			_tmp113_ = _tmp112_;
#line 195 "EnumerationTest.vala"
			_tmp114_ = g_enum_get_value (g_type_class_ref (TYPE_OPTIONS_ENUM), _tmp113_);
#line 195 "EnumerationTest.vala"
			_tmp115_ = doc8;
#line 195 "EnumerationTest.vala"
			_tmp116_ = gxml_gnode_to_string ((GXmlGNode*) _tmp115_);
#line 195 "EnumerationTest.vala"
			_tmp117_ = _tmp116_;
#line 195 "EnumerationTest.vala"
			_tmp118_ = g_strconcat ("ERROR: Bad value to options property: ", (_tmp114_ != NULL) ? _tmp114_->value_name : NULL, "\n", _tmp117_, NULL);
#line 195 "EnumerationTest.vala"
			_tmp119_ = _tmp118_;
#line 195 "EnumerationTest.vala"
			fprintf (_tmp110_, "%s", _tmp119_);
#line 195 "EnumerationTest.vala"
			_g_free0 (_tmp119_);
#line 195 "EnumerationTest.vala"
			_g_free0 (_tmp117_);
#line 196 "EnumerationTest.vala"
			g_assert_not_reached ();
#line 2188 "EnumerationTest.c"
		}
#line 143 "EnumerationTest.vala"
		_g_object_unref0 (doc8);
#line 143 "EnumerationTest.vala"
		_g_object_unref0 (op2);
#line 143 "EnumerationTest.vala"
		_g_object_unref0 (doc7);
#line 143 "EnumerationTest.vala"
		_g_object_unref0 (doc6);
#line 143 "EnumerationTest.vala"
		_g_object_unref0 (doc5);
#line 143 "EnumerationTest.vala"
		_g_object_unref0 (doc4);
#line 143 "EnumerationTest.vala"
		_g_object_unref0 (doc3);
#line 143 "EnumerationTest.vala"
		_g_object_unref0 (doc2);
#line 143 "EnumerationTest.vala"
		_g_object_unref0 (doc);
#line 2208 "EnumerationTest.c"
	}
	goto __finally224;
	__catch224_g_error:
	{
		GError* e = NULL;
		FILE* _tmp120_;
		const gchar* _tmp121_;
		const gchar* _tmp122_;
		gchar* _tmp123_;
		gchar* _tmp124_;
#line 143 "EnumerationTest.vala"
		e = _inner_error0_;
#line 143 "EnumerationTest.vala"
		_inner_error0_ = NULL;
#line 200 "EnumerationTest.vala"
		_tmp120_ = stdout;
#line 200 "EnumerationTest.vala"
		_tmp121_ = e->message;
#line 200 "EnumerationTest.vala"
		_tmp122_ = string_to_string (_tmp121_);
#line 200 "EnumerationTest.vala"
		_tmp123_ = g_strconcat ("Error: ", _tmp122_, NULL);
#line 200 "EnumerationTest.vala"
		_tmp124_ = _tmp123_;
#line 200 "EnumerationTest.vala"
		fprintf (_tmp120_, "%s", _tmp124_);
#line 200 "EnumerationTest.vala"
		_g_free0 (_tmp124_);
#line 201 "EnumerationTest.vala"
		g_assert_not_reached ();
#line 143 "EnumerationTest.vala"
		_g_error_free0 (e);
#line 2241 "EnumerationTest.c"
	}
	__finally224:
#line 143 "EnumerationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 143 "EnumerationTest.vala"
		_g_object_unref0 (options);
#line 143 "EnumerationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 143 "EnumerationTest.vala"
		g_clear_error (&_inner_error0_);
#line 143 "EnumerationTest.vala"
		return;
#line 2254 "EnumerationTest.c"
	}
#line 141 "EnumerationTest.vala"
	_g_object_unref0 (options);
#line 2258 "EnumerationTest.c"
}

static void
___lambda167__gtest_func (void)
{
#line 140 "EnumerationTest.vala"
	__lambda167_ ();
#line 2266 "EnumerationTest.c"
}

static void
__lambda168_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GEnumValue* v1 = NULL;
		GEnumValue* _tmp0_;
		GEnumValue* _tmp1_;
		GEnumValue* v2 = NULL;
		GEnumValue* _tmp2_;
		GEnumValue* _tmp3_;
		GEnumValue* v3 = NULL;
		GEnumValue* _tmp4_;
		GEnumValue* _tmp5_;
		GEnumValue* v4 = NULL;
		GEnumValue* _tmp6_;
		GEnumValue* _tmp7_;
		GEnumValue* v5 = NULL;
		GEnumValue* _tmp8_;
		GEnumValue* _tmp9_;
		GEnumValue* v6 = NULL;
		GEnumValue* _tmp10_;
		GEnumValue* _tmp11_;
		GEnumValue* v7 = NULL;
		GEnumValue* _tmp12_;
		GEnumValue* _tmp13_;
		GEnumValue* v8 = NULL;
		GEnumValue* _tmp14_;
		GEnumValue* _tmp15_;
		GEnumValue* v9 = NULL;
		GEnumValue* _tmp16_;
		GEnumValue* _tmp17_;
#line 206 "EnumerationTest.vala"
		_tmp0_ = gxml_enumeration_parse (OPTIONS_TYPE_VALUES, "AP", &_inner_error0_);
#line 206 "EnumerationTest.vala"
		v1 = _tmp0_;
#line 206 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2307 "EnumerationTest.c"
			goto __catch225_g_error;
		}
#line 207 "EnumerationTest.vala"
		_tmp1_ = v1;
#line 207 "EnumerationTest.vala"
		_vala_assert ((*_tmp1_).value == ((gint) OPTIONS_VALUES_AP), "v1.value == (int) Options.Values.AP");
#line 208 "EnumerationTest.vala"
		_tmp2_ = gxml_enumeration_parse (OPTIONS_TYPE_VALUES, "Ap", &_inner_error0_);
#line 208 "EnumerationTest.vala"
		v2 = _tmp2_;
#line 208 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 208 "EnumerationTest.vala"
			_g_free0 (v1);
#line 2322 "EnumerationTest.c"
			goto __catch225_g_error;
		}
#line 209 "EnumerationTest.vala"
		_tmp3_ = v2;
#line 209 "EnumerationTest.vala"
		_vala_assert ((*_tmp3_).value == ((gint) OPTIONS_VALUES_AP), "v2.value == (int) Options.Values.AP");
#line 210 "EnumerationTest.vala"
		_tmp4_ = gxml_enumeration_parse (OPTIONS_TYPE_VALUES, "ap", &_inner_error0_);
#line 210 "EnumerationTest.vala"
		v3 = _tmp4_;
#line 210 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 210 "EnumerationTest.vala"
			_g_free0 (v2);
#line 210 "EnumerationTest.vala"
			_g_free0 (v1);
#line 2339 "EnumerationTest.c"
			goto __catch225_g_error;
		}
#line 211 "EnumerationTest.vala"
		_tmp5_ = v3;
#line 211 "EnumerationTest.vala"
		_vala_assert ((*_tmp5_).value == ((gint) OPTIONS_VALUES_AP), "v3.value == (int) Options.Values.AP");
#line 212 "EnumerationTest.vala"
		_tmp6_ = gxml_enumeration_parse (OPTIONS_TYPE_VALUES, "KPVALUE", &_inner_error0_);
#line 212 "EnumerationTest.vala"
		v4 = _tmp6_;
#line 212 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 212 "EnumerationTest.vala"
			_g_free0 (v3);
#line 212 "EnumerationTest.vala"
			_g_free0 (v2);
#line 212 "EnumerationTest.vala"
			_g_free0 (v1);
#line 2358 "EnumerationTest.c"
			goto __catch225_g_error;
		}
#line 213 "EnumerationTest.vala"
		_tmp7_ = v4;
#line 213 "EnumerationTest.vala"
		_vala_assert ((*_tmp7_).value == ((gint) OPTIONS_VALUES_KP_VALUE), "v4.value == (int) Options.Values.KP_VALUE");
#line 214 "EnumerationTest.vala"
		_tmp8_ = gxml_enumeration_parse (OPTIONS_TYPE_VALUES, "KpValue", &_inner_error0_);
#line 214 "EnumerationTest.vala"
		v5 = _tmp8_;
#line 214 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 214 "EnumerationTest.vala"
			_g_free0 (v4);
#line 214 "EnumerationTest.vala"
			_g_free0 (v3);
#line 214 "EnumerationTest.vala"
			_g_free0 (v2);
#line 214 "EnumerationTest.vala"
			_g_free0 (v1);
#line 2379 "EnumerationTest.c"
			goto __catch225_g_error;
		}
#line 215 "EnumerationTest.vala"
		_tmp9_ = v5;
#line 215 "EnumerationTest.vala"
		_vala_assert ((*_tmp9_).value == ((gint) OPTIONS_VALUES_KP_VALUE), "v5.value == (int) Options.Values.KP_VALUE");
#line 216 "EnumerationTest.vala"
		_tmp10_ = gxml_enumeration_parse (OPTIONS_TYPE_VALUES, "kpvalue", &_inner_error0_);
#line 216 "EnumerationTest.vala"
		v6 = _tmp10_;
#line 216 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 216 "EnumerationTest.vala"
			_g_free0 (v5);
#line 216 "EnumerationTest.vala"
			_g_free0 (v4);
#line 216 "EnumerationTest.vala"
			_g_free0 (v3);
#line 216 "EnumerationTest.vala"
			_g_free0 (v2);
#line 216 "EnumerationTest.vala"
			_g_free0 (v1);
#line 2402 "EnumerationTest.c"
			goto __catch225_g_error;
		}
#line 217 "EnumerationTest.vala"
		_tmp11_ = v6;
#line 217 "EnumerationTest.vala"
		_vala_assert ((*_tmp11_).value == ((gint) OPTIONS_VALUES_KP_VALUE), "v6.value == (int) Options.Values.KP_VALUE");
#line 218 "EnumerationTest.vala"
		_tmp12_ = gxml_enumeration_parse (OPTIONS_TYPE_VALUES, "EXTERNALVALUEVISION", &_inner_error0_);
#line 218 "EnumerationTest.vala"
		v7 = _tmp12_;
#line 218 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 218 "EnumerationTest.vala"
			_g_free0 (v6);
#line 218 "EnumerationTest.vala"
			_g_free0 (v5);
#line 218 "EnumerationTest.vala"
			_g_free0 (v4);
#line 218 "EnumerationTest.vala"
			_g_free0 (v3);
#line 218 "EnumerationTest.vala"
			_g_free0 (v2);
#line 218 "EnumerationTest.vala"
			_g_free0 (v1);
#line 2427 "EnumerationTest.c"
			goto __catch225_g_error;
		}
#line 219 "EnumerationTest.vala"
		_tmp13_ = v7;
#line 219 "EnumerationTest.vala"
		_vala_assert ((*_tmp13_).value == ((gint) OPTIONS_VALUES_EXTERNAL_VALUE_VISION), "v7.value == (int) Options.Values.EXTERNAL_VALUE_VISION");
#line 220 "EnumerationTest.vala"
		_tmp14_ = gxml_enumeration_parse (OPTIONS_TYPE_VALUES, "ExternalValueVision", &_inner_error0_);
#line 220 "EnumerationTest.vala"
		v8 = _tmp14_;
#line 220 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 220 "EnumerationTest.vala"
			_g_free0 (v7);
#line 220 "EnumerationTest.vala"
			_g_free0 (v6);
#line 220 "EnumerationTest.vala"
			_g_free0 (v5);
#line 220 "EnumerationTest.vala"
			_g_free0 (v4);
#line 220 "EnumerationTest.vala"
			_g_free0 (v3);
#line 220 "EnumerationTest.vala"
			_g_free0 (v2);
#line 220 "EnumerationTest.vala"
			_g_free0 (v1);
#line 2454 "EnumerationTest.c"
			goto __catch225_g_error;
		}
#line 221 "EnumerationTest.vala"
		_tmp15_ = v8;
#line 221 "EnumerationTest.vala"
		_vala_assert ((*_tmp15_).value == ((gint) OPTIONS_VALUES_EXTERNAL_VALUE_VISION), "v8.value == (int) Options.Values.EXTERNAL_VALUE_VISION");
#line 222 "EnumerationTest.vala"
		_tmp16_ = gxml_enumeration_parse (OPTIONS_TYPE_VALUES, "externalvaluevision", &_inner_error0_);
#line 222 "EnumerationTest.vala"
		v9 = _tmp16_;
#line 222 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 222 "EnumerationTest.vala"
			_g_free0 (v8);
#line 222 "EnumerationTest.vala"
			_g_free0 (v7);
#line 222 "EnumerationTest.vala"
			_g_free0 (v6);
#line 222 "EnumerationTest.vala"
			_g_free0 (v5);
#line 222 "EnumerationTest.vala"
			_g_free0 (v4);
#line 222 "EnumerationTest.vala"
			_g_free0 (v3);
#line 222 "EnumerationTest.vala"
			_g_free0 (v2);
#line 222 "EnumerationTest.vala"
			_g_free0 (v1);
#line 2483 "EnumerationTest.c"
			goto __catch225_g_error;
		}
#line 223 "EnumerationTest.vala"
		_tmp17_ = v9;
#line 223 "EnumerationTest.vala"
		_vala_assert ((*_tmp17_).value == ((gint) OPTIONS_VALUES_EXTERNAL_VALUE_VISION), "v9.value == (int) Options.Values.EXTERNAL_VALUE_VISION");
#line 205 "EnumerationTest.vala"
		_g_free0 (v9);
#line 205 "EnumerationTest.vala"
		_g_free0 (v8);
#line 205 "EnumerationTest.vala"
		_g_free0 (v7);
#line 205 "EnumerationTest.vala"
		_g_free0 (v6);
#line 205 "EnumerationTest.vala"
		_g_free0 (v5);
#line 205 "EnumerationTest.vala"
		_g_free0 (v4);
#line 205 "EnumerationTest.vala"
		_g_free0 (v3);
#line 205 "EnumerationTest.vala"
		_g_free0 (v2);
#line 205 "EnumerationTest.vala"
		_g_free0 (v1);
#line 2508 "EnumerationTest.c"
	}
	goto __finally225;
	__catch225_g_error:
	{
		GError* e = NULL;
		GError* _tmp18_;
		const gchar* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
#line 205 "EnumerationTest.vala"
		e = _inner_error0_;
#line 205 "EnumerationTest.vala"
		_inner_error0_ = NULL;
#line 225 "EnumerationTest.vala"
		_tmp18_ = e;
#line 225 "EnumerationTest.vala"
		_tmp19_ = _tmp18_->message;
#line 225 "EnumerationTest.vala"
		_tmp20_ = g_strconcat ("Parse error: ", _tmp19_, NULL);
#line 225 "EnumerationTest.vala"
		_tmp21_ = _tmp20_;
#line 225 "EnumerationTest.vala"
		g_test_message ("%s", _tmp21_);
#line 225 "EnumerationTest.vala"
		_g_free0 (_tmp21_);
#line 205 "EnumerationTest.vala"
		_g_error_free0 (e);
#line 2536 "EnumerationTest.c"
	}
	__finally225:
#line 205 "EnumerationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 205 "EnumerationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 205 "EnumerationTest.vala"
		g_clear_error (&_inner_error0_);
#line 205 "EnumerationTest.vala"
		return;
#line 2547 "EnumerationTest.c"
	}
}

static void
___lambda168__gtest_func (void)
{
#line 204 "EnumerationTest.vala"
	__lambda168_ ();
#line 2556 "EnumerationTest.c"
}

static void
__lambda169_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		gchar** options = NULL;
		gint _tmp0_ = 0;
		gchar** _tmp1_;
		gint options_length1;
		gint _options_size_;
		const gchar* _tmp2_;
		const gchar* _tmp3_;
		const gchar* _tmp4_;
#line 230 "EnumerationTest.vala"
		_tmp1_ = gxml_enumeration_to_string_array (OPTIONS_TYPE_VALUES, &_tmp0_, &_inner_error0_);
#line 230 "EnumerationTest.vala"
		options = _tmp1_;
#line 230 "EnumerationTest.vala"
		options_length1 = _tmp0_;
#line 230 "EnumerationTest.vala"
		_options_size_ = options_length1;
#line 230 "EnumerationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2582 "EnumerationTest.c"
			goto __catch226_g_error;
		}
#line 231 "EnumerationTest.vala"
		_vala_assert (options != NULL, "options != null");
#line 232 "EnumerationTest.vala"
		_vala_assert (options_length1 == 3, "options.length == 3");
#line 233 "EnumerationTest.vala"
		_tmp2_ = options[0];
#line 233 "EnumerationTest.vala"
		_vala_assert (g_strcmp0 (_tmp2_, "Ap") == 0, "options[0] == \"Ap\"");
#line 234 "EnumerationTest.vala"
		_tmp3_ = options[1];
#line 234 "EnumerationTest.vala"
		_vala_assert (g_strcmp0 (_tmp3_, "KpValue") == 0, "options[1] == \"KpValue\"");
#line 235 "EnumerationTest.vala"
		_tmp4_ = options[2];
#line 235 "EnumerationTest.vala"
		_vala_assert (g_strcmp0 (_tmp4_, "ExternalValueVision") == 0, "options[2] == \"ExternalValueVision\"");
#line 229 "EnumerationTest.vala"
		options = (_vala_array_free (options, options_length1, (GDestroyNotify) g_free), NULL);
#line 2603 "EnumerationTest.c"
	}
	goto __finally226;
	__catch226_g_error:
	{
		GError* e = NULL;
		GError* _tmp5_;
		const gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
#line 229 "EnumerationTest.vala"
		e = _inner_error0_;
#line 229 "EnumerationTest.vala"
		_inner_error0_ = NULL;
#line 237 "EnumerationTest.vala"
		_tmp5_ = e;
#line 237 "EnumerationTest.vala"
		_tmp6_ = _tmp5_->message;
#line 237 "EnumerationTest.vala"
		_tmp7_ = g_strconcat ("Parse error: ", _tmp6_, NULL);
#line 237 "EnumerationTest.vala"
		_tmp8_ = _tmp7_;
#line 237 "EnumerationTest.vala"
		g_test_message ("%s", _tmp8_);
#line 237 "EnumerationTest.vala"
		_g_free0 (_tmp8_);
#line 229 "EnumerationTest.vala"
		_g_error_free0 (e);
#line 2631 "EnumerationTest.c"
	}
	__finally226:
#line 229 "EnumerationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 229 "EnumerationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 229 "EnumerationTest.vala"
		g_clear_error (&_inner_error0_);
#line 229 "EnumerationTest.vala"
		return;
#line 2642 "EnumerationTest.c"
	}
}

static void
___lambda169__gtest_func (void)
{
#line 228 "EnumerationTest.vala"
	__lambda169_ ();
#line 2651 "EnumerationTest.c"
}

void
serializable_enumeration_test_add_tests (void)
{
#line 52 "EnumerationTest.vala"
	g_test_add_func ("/gxml/serializable/enumeration", ___lambda165__gtest_func);
#line 113 "EnumerationTest.vala"
	g_test_add_func ("/gxml/serializable/enumeration-serialize", ___lambda166__gtest_func);
#line 140 "EnumerationTest.vala"
	g_test_add_func ("/gxml/serializable/enumeration-deserialize", ___lambda167__gtest_func);
#line 204 "EnumerationTest.vala"
	g_test_add_func ("/gxml/serializable/enumeration/parse", ___lambda168__gtest_func);
#line 228 "EnumerationTest.vala"
	g_test_add_func ("/gxml/serializable/enumeration/to_string_array", ___lambda169__gtest_func);
#line 2667 "EnumerationTest.c"
}

SerializableEnumerationTest*
serializable_enumeration_test_construct (GType object_type)
{
	SerializableEnumerationTest* self = NULL;
#line 48 "EnumerationTest.vala"
	self = (SerializableEnumerationTest*) gxml_test_construct (object_type);
#line 48 "EnumerationTest.vala"
	return self;
#line 2678 "EnumerationTest.c"
}

SerializableEnumerationTest*
serializable_enumeration_test_new (void)
{
#line 48 "EnumerationTest.vala"
	return serializable_enumeration_test_construct (TYPE_SERIALIZABLE_ENUMERATION_TEST);
#line 2686 "EnumerationTest.c"
}

static void
serializable_enumeration_test_class_init (SerializableEnumerationTestClass * klass,
                                          gpointer klass_data)
{
#line 48 "EnumerationTest.vala"
	serializable_enumeration_test_parent_class = g_type_class_peek_parent (klass);
#line 2695 "EnumerationTest.c"
}

static void
serializable_enumeration_test_instance_init (SerializableEnumerationTest * self,
                                             gpointer klass)
{
}

GType
serializable_enumeration_test_get_type (void)
{
	static volatile gsize serializable_enumeration_test_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_enumeration_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableEnumerationTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_enumeration_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableEnumerationTest), 0, (GInstanceInitFunc) serializable_enumeration_test_instance_init, NULL };
		GType serializable_enumeration_test_type_id;
		serializable_enumeration_test_type_id = g_type_register_static (TYPE_GXML_TEST, "SerializableEnumerationTest", &g_define_type_info, 0);
		g_once_init_leave (&serializable_enumeration_test_type_id__volatile, serializable_enumeration_test_type_id);
	}
	return serializable_enumeration_test_type_id__volatile;
}

static void
_vala_array_destroy (gpointer array,
                     gint array_length,
                     GDestroyNotify destroy_func)
{
#line 356 "GomSerializationTest.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 2724 "EnumerationTest.c"
		int i;
#line 356 "GomSerializationTest.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 356 "GomSerializationTest.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 356 "GomSerializationTest.vala"
				destroy_func (((gpointer*) array)[i]);
#line 2732 "EnumerationTest.c"
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gint array_length,
                  GDestroyNotify destroy_func)
{
#line 356 "GomSerializationTest.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 356 "GomSerializationTest.vala"
	g_free (array);
#line 2747 "EnumerationTest.c"
}

