/* GomSchemaTest.c generated by valac 0.44.3, the Vala compiler
 * generated from GomSchemaTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* GomSchema.vala
 *
 * Copyright (C) 2017  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib-object.h>
#include <glib.h>
#include <gio/gio.h>
#include <gxml/gxml.h>

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_GOM_SCHEMA_TEST (gom_schema_test_get_type ())
#define GOM_SCHEMA_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_SCHEMA_TEST, GomSchemaTest))
#define GOM_SCHEMA_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_SCHEMA_TEST, GomSchemaTestClass))
#define IS_GOM_SCHEMA_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_SCHEMA_TEST))
#define IS_GOM_SCHEMA_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_SCHEMA_TEST))
#define GOM_SCHEMA_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_SCHEMA_TEST, GomSchemaTestClass))

typedef struct _GomSchemaTest GomSchemaTest;
typedef struct _GomSchemaTestClass GomSchemaTestClass;
typedef struct _GomSchemaTestPrivate GomSchemaTestPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _GomSchemaTest {
	GXmlTest parent_instance;
	GomSchemaTestPrivate * priv;
};

struct _GomSchemaTestClass {
	GXmlTestClass parent_class;
};

static gpointer gom_schema_test_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType gom_schema_test_get_type (void) G_GNUC_CONST;
void gom_schema_test_add_tests (void);
static void __lambda143_ (void);
static void ___lambda143__gtest_func (void);
static void __lambda144_ (void);
static void ___lambda144__gtest_func (void);
GomSchemaTest* gom_schema_test_new (void);
GomSchemaTest* gom_schema_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);

static gpointer
_g_object_ref0 (gpointer self)
{
#line 42 "GomSchemaTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 112 "GomSchemaTest.c"
}

static void
__lambda143_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GFile* f = NULL;
		GFile* _tmp0_;
		GFile* _tmp1_;
		GXmlGomXsdSchema* sch = NULL;
		GXmlGomXsdSchema* _tmp2_;
		GXmlGomXsdSchema* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		GXmlGomXsdSchema* _tmp7_;
		GFile* _tmp8_;
		GXmlGomXsdSchema* _tmp9_;
		GXmlGomXsdListSimpleTypes* _tmp10_;
		GXmlGomXsdListSimpleTypes* _tmp11_;
		GXmlDomElement* _tmp12_ = NULL;
		GXmlGomXsdSchema* _tmp13_;
		GXmlGomXsdListSimpleTypes* _tmp14_;
		GXmlGomXsdListSimpleTypes* _tmp15_;
		GXmlDomElement* _tmp16_;
		GXmlGomXsdSimpleType* st = NULL;
		GXmlGomXsdSimpleType* _tmp17_;
		GXmlGomXsdSimpleType* _tmp18_;
		GXmlGomXsdSimpleType* _tmp19_;
		GXmlGomXsdTypeRestriction* _tmp20_;
		GXmlGomXsdTypeRestriction* _tmp21_;
		GXmlGomXsdSimpleType* _tmp22_;
		GXmlGomXsdTypeRestriction* _tmp23_;
		GXmlGomXsdTypeRestriction* _tmp24_;
		const gchar* _tmp25_;
		const gchar* _tmp26_;
		GXmlGomXsdSimpleType* _tmp27_;
		GXmlGomXsdTypeRestriction* _tmp28_;
		GXmlGomXsdTypeRestriction* _tmp29_;
		const gchar* _tmp30_;
		const gchar* _tmp31_;
		GXmlGomXsdSimpleType* _tmp32_;
		GXmlGomXsdTypeRestriction* _tmp33_;
		GXmlGomXsdTypeRestriction* _tmp34_;
		GXmlGomXsdListTypeRestrictionEnumerations* _tmp35_;
		GXmlGomXsdListTypeRestrictionEnumerations* _tmp36_;
		GXmlGomXsdSimpleType* _tmp37_;
		GXmlGomXsdTypeRestriction* _tmp38_;
		GXmlGomXsdTypeRestriction* _tmp39_;
		GXmlGomXsdListTypeRestrictionEnumerations* _tmp40_;
		GXmlGomXsdListTypeRestrictionEnumerations* _tmp41_;
		gint _tmp42_;
		gint _tmp43_;
		GXmlDomElement* _tmp44_ = NULL;
		GXmlGomXsdSimpleType* _tmp45_;
		GXmlGomXsdTypeRestriction* _tmp46_;
		GXmlGomXsdTypeRestriction* _tmp47_;
		GXmlGomXsdListTypeRestrictionEnumerations* _tmp48_;
		GXmlGomXsdListTypeRestrictionEnumerations* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlGomXsdTypeRestrictionEnumeration* enumt1 = NULL;
		GXmlGomXsdTypeRestrictionEnumeration* _tmp51_;
		GXmlGomXsdTypeRestrictionEnumeration* _tmp52_;
		GXmlGomXsdTypeRestrictionEnumeration* _tmp53_;
		const gchar* _tmp54_;
		const gchar* _tmp55_;
		GXmlGomXsdTypeRestrictionEnumeration* _tmp56_;
		const gchar* _tmp57_;
		const gchar* _tmp58_;
		GXmlDomElement* _tmp59_ = NULL;
		GXmlGomXsdSimpleType* _tmp60_;
		GXmlGomXsdTypeRestriction* _tmp61_;
		GXmlGomXsdTypeRestriction* _tmp62_;
		GXmlGomXsdListTypeRestrictionEnumerations* _tmp63_;
		GXmlGomXsdListTypeRestrictionEnumerations* _tmp64_;
		GXmlDomElement* _tmp65_;
		GXmlGomXsdTypeRestrictionEnumeration* enumt20 = NULL;
		GXmlGomXsdTypeRestrictionEnumeration* _tmp66_;
		const gchar* _tmp67_;
		const gchar* _tmp68_;
		const gchar* _tmp69_;
		const gchar* _tmp70_;
#line 29 "GomSchemaTest.vala"
		_tmp0_ = g_file_new_for_path (TEST_DIR "/schema-test.xsd");
#line 29 "GomSchemaTest.vala"
		f = _tmp0_;
#line 30 "GomSchemaTest.vala"
		_tmp1_ = f;
#line 30 "GomSchemaTest.vala"
		_vala_assert (g_file_query_exists (_tmp1_, NULL), "f.query_exists ()");
#line 31 "GomSchemaTest.vala"
		_tmp2_ = gxml_gom_xsd_schema_new ();
#line 31 "GomSchemaTest.vala"
		sch = _tmp2_;
#line 36 "GomSchemaTest.vala"
		_tmp3_ = sch;
#line 36 "GomSchemaTest.vala"
		_tmp4_ = gxml_dom_element_get_local_name ((GXmlDomElement*) _tmp3_);
#line 36 "GomSchemaTest.vala"
		_tmp5_ = _tmp4_;
#line 36 "GomSchemaTest.vala"
		_tmp6_ = _tmp5_;
#line 36 "GomSchemaTest.vala"
		_vala_assert (g_strcmp0 (_tmp6_, "schema") == 0, "sch.local_name == \"schema\"");
#line 36 "GomSchemaTest.vala"
		_g_free0 (_tmp6_);
#line 37 "GomSchemaTest.vala"
		_tmp7_ = sch;
#line 37 "GomSchemaTest.vala"
		_tmp8_ = f;
#line 37 "GomSchemaTest.vala"
		gxml_dom_element_read_from_file ((GXmlDomElement*) _tmp7_, _tmp8_, NULL, &_inner_error0_);
#line 37 "GomSchemaTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 37 "GomSchemaTest.vala"
			_g_object_unref0 (sch);
#line 37 "GomSchemaTest.vala"
			_g_object_unref0 (f);
#line 232 "GomSchemaTest.c"
			goto __catch217_g_error;
		}
#line 41 "GomSchemaTest.vala"
		_tmp9_ = sch;
#line 41 "GomSchemaTest.vala"
		_tmp10_ = gxml_gom_xsd_schema_get_simple_type_definitions (_tmp9_);
#line 41 "GomSchemaTest.vala"
		_tmp11_ = _tmp10_;
#line 41 "GomSchemaTest.vala"
		_vala_assert (_tmp11_ != NULL, "sch.simple_type_definitions != null");
#line 42 "GomSchemaTest.vala"
		_tmp13_ = sch;
#line 42 "GomSchemaTest.vala"
		_tmp14_ = gxml_gom_xsd_schema_get_simple_type_definitions (_tmp13_);
#line 42 "GomSchemaTest.vala"
		_tmp15_ = _tmp14_;
#line 42 "GomSchemaTest.vala"
		_tmp16_ = gxml_collection_get_item ((GXmlCollection*) _tmp15_, 0, &_inner_error0_);
#line 42 "GomSchemaTest.vala"
		_tmp12_ = _tmp16_;
#line 42 "GomSchemaTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 42 "GomSchemaTest.vala"
			_g_object_unref0 (sch);
#line 42 "GomSchemaTest.vala"
			_g_object_unref0 (f);
#line 259 "GomSchemaTest.c"
			goto __catch217_g_error;
		}
#line 42 "GomSchemaTest.vala"
		_tmp17_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, GXML_TYPE_GOM_XSD_SIMPLE_TYPE) ? ((GXmlGomXsdSimpleType*) _tmp12_) : NULL);
#line 42 "GomSchemaTest.vala"
		st = _tmp17_;
#line 43 "GomSchemaTest.vala"
		_tmp18_ = st;
#line 43 "GomSchemaTest.vala"
		_vala_assert (_tmp18_ != NULL, "st != null");
#line 44 "GomSchemaTest.vala"
		_tmp19_ = st;
#line 44 "GomSchemaTest.vala"
		_tmp20_ = gxml_gom_xsd_simple_type_get_restriction (_tmp19_);
#line 44 "GomSchemaTest.vala"
		_tmp21_ = _tmp20_;
#line 44 "GomSchemaTest.vala"
		_vala_assert (_tmp21_ != NULL, "st.restriction != null");
#line 45 "GomSchemaTest.vala"
		_tmp22_ = st;
#line 45 "GomSchemaTest.vala"
		_tmp23_ = gxml_gom_xsd_simple_type_get_restriction (_tmp22_);
#line 45 "GomSchemaTest.vala"
		_tmp24_ = _tmp23_;
#line 45 "GomSchemaTest.vala"
		_tmp25_ = gxml_gom_xsd_type_restriction_get_base (_tmp24_);
#line 45 "GomSchemaTest.vala"
		_tmp26_ = _tmp25_;
#line 45 "GomSchemaTest.vala"
		_vala_assert (_tmp26_ != NULL, "st.restriction.base != null");
#line 46 "GomSchemaTest.vala"
		_tmp27_ = st;
#line 46 "GomSchemaTest.vala"
		_tmp28_ = gxml_gom_xsd_simple_type_get_restriction (_tmp27_);
#line 46 "GomSchemaTest.vala"
		_tmp29_ = _tmp28_;
#line 46 "GomSchemaTest.vala"
		_tmp30_ = gxml_gom_xsd_type_restriction_get_base (_tmp29_);
#line 46 "GomSchemaTest.vala"
		_tmp31_ = _tmp30_;
#line 46 "GomSchemaTest.vala"
		_vala_assert (g_strcmp0 (_tmp31_, "xs:string") == 0, "st.restriction.base == \"xs:string\"");
#line 47 "GomSchemaTest.vala"
		_tmp32_ = st;
#line 47 "GomSchemaTest.vala"
		_tmp33_ = gxml_gom_xsd_simple_type_get_restriction (_tmp32_);
#line 47 "GomSchemaTest.vala"
		_tmp34_ = _tmp33_;
#line 47 "GomSchemaTest.vala"
		_tmp35_ = gxml_gom_xsd_type_restriction_get_enumerations (_tmp34_);
#line 47 "GomSchemaTest.vala"
		_tmp36_ = _tmp35_;
#line 47 "GomSchemaTest.vala"
		_vala_assert (_tmp36_ != NULL, "st.restriction.enumerations != null");
#line 48 "GomSchemaTest.vala"
		_tmp37_ = st;
#line 48 "GomSchemaTest.vala"
		_tmp38_ = gxml_gom_xsd_simple_type_get_restriction (_tmp37_);
#line 48 "GomSchemaTest.vala"
		_tmp39_ = _tmp38_;
#line 48 "GomSchemaTest.vala"
		_tmp40_ = gxml_gom_xsd_type_restriction_get_enumerations (_tmp39_);
#line 48 "GomSchemaTest.vala"
		_tmp41_ = _tmp40_;
#line 48 "GomSchemaTest.vala"
		_tmp42_ = gxml_gom_xsd_list_get_length ((GXmlGomXsdList*) _tmp41_);
#line 48 "GomSchemaTest.vala"
		_tmp43_ = _tmp42_;
#line 48 "GomSchemaTest.vala"
		_vala_assert (_tmp43_ == 20, "st.restriction.enumerations.length == 20");
#line 49 "GomSchemaTest.vala"
		_tmp45_ = st;
#line 49 "GomSchemaTest.vala"
		_tmp46_ = gxml_gom_xsd_simple_type_get_restriction (_tmp45_);
#line 49 "GomSchemaTest.vala"
		_tmp47_ = _tmp46_;
#line 49 "GomSchemaTest.vala"
		_tmp48_ = gxml_gom_xsd_type_restriction_get_enumerations (_tmp47_);
#line 49 "GomSchemaTest.vala"
		_tmp49_ = _tmp48_;
#line 49 "GomSchemaTest.vala"
		_tmp50_ = gxml_collection_get_item ((GXmlCollection*) _tmp49_, 0, &_inner_error0_);
#line 49 "GomSchemaTest.vala"
		_tmp44_ = _tmp50_;
#line 49 "GomSchemaTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 49 "GomSchemaTest.vala"
			_g_object_unref0 (st);
#line 49 "GomSchemaTest.vala"
			_g_object_unref0 (_tmp12_);
#line 49 "GomSchemaTest.vala"
			_g_object_unref0 (sch);
#line 49 "GomSchemaTest.vala"
			_g_object_unref0 (f);
#line 354 "GomSchemaTest.c"
			goto __catch217_g_error;
		}
#line 49 "GomSchemaTest.vala"
		_tmp51_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp44_, GXML_TYPE_GOM_XSD_TYPE_RESTRICTION_ENUMERATION) ? ((GXmlGomXsdTypeRestrictionEnumeration*) _tmp44_) : NULL);
#line 49 "GomSchemaTest.vala"
		enumt1 = _tmp51_;
#line 50 "GomSchemaTest.vala"
		_tmp52_ = enumt1;
#line 50 "GomSchemaTest.vala"
		_vala_assert (_tmp52_ != NULL, "enumt1 != null");
#line 51 "GomSchemaTest.vala"
		_tmp53_ = enumt1;
#line 51 "GomSchemaTest.vala"
		_tmp54_ = gxml_gom_xsd_type_restriction_enumeration_get_value (_tmp53_);
#line 51 "GomSchemaTest.vala"
		_tmp55_ = _tmp54_;
#line 51 "GomSchemaTest.vala"
		_vala_assert (_tmp55_ != NULL, "enumt1.value != null");
#line 52 "GomSchemaTest.vala"
		_tmp56_ = enumt1;
#line 52 "GomSchemaTest.vala"
		_tmp57_ = gxml_gom_xsd_type_restriction_enumeration_get_value (_tmp56_);
#line 52 "GomSchemaTest.vala"
		_tmp58_ = _tmp57_;
#line 52 "GomSchemaTest.vala"
		_vala_assert (g_strcmp0 (_tmp58_, "01") == 0, "enumt1.value == \"01\"");
#line 53 "GomSchemaTest.vala"
		_tmp60_ = st;
#line 53 "GomSchemaTest.vala"
		_tmp61_ = gxml_gom_xsd_simple_type_get_restriction (_tmp60_);
#line 53 "GomSchemaTest.vala"
		_tmp62_ = _tmp61_;
#line 53 "GomSchemaTest.vala"
		_tmp63_ = gxml_gom_xsd_type_restriction_get_enumerations (_tmp62_);
#line 53 "GomSchemaTest.vala"
		_tmp64_ = _tmp63_;
#line 53 "GomSchemaTest.vala"
		_tmp65_ = gxml_collection_get_item ((GXmlCollection*) _tmp64_, 19, &_inner_error0_);
#line 53 "GomSchemaTest.vala"
		_tmp59_ = _tmp65_;
#line 53 "GomSchemaTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 53 "GomSchemaTest.vala"
			_g_object_unref0 (enumt1);
#line 53 "GomSchemaTest.vala"
			_g_object_unref0 (_tmp44_);
#line 53 "GomSchemaTest.vala"
			_g_object_unref0 (st);
#line 53 "GomSchemaTest.vala"
			_g_object_unref0 (_tmp12_);
#line 53 "GomSchemaTest.vala"
			_g_object_unref0 (sch);
#line 53 "GomSchemaTest.vala"
			_g_object_unref0 (f);
#line 409 "GomSchemaTest.c"
			goto __catch217_g_error;
		}
#line 53 "GomSchemaTest.vala"
		_tmp66_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp59_, GXML_TYPE_GOM_XSD_TYPE_RESTRICTION_ENUMERATION) ? ((GXmlGomXsdTypeRestrictionEnumeration*) _tmp59_) : NULL);
#line 53 "GomSchemaTest.vala"
		enumt20 = _tmp66_;
#line 54 "GomSchemaTest.vala"
		_vala_assert (enumt20 != NULL, "enumt20 != null");
#line 55 "GomSchemaTest.vala"
		_tmp67_ = gxml_gom_xsd_type_restriction_enumeration_get_value (enumt20);
#line 55 "GomSchemaTest.vala"
		_tmp68_ = _tmp67_;
#line 55 "GomSchemaTest.vala"
		_vala_assert (_tmp68_ != NULL, "enumt20.value != null");
#line 56 "GomSchemaTest.vala"
		_tmp69_ = gxml_gom_xsd_type_restriction_enumeration_get_value (enumt20);
#line 56 "GomSchemaTest.vala"
		_tmp70_ = _tmp69_;
#line 56 "GomSchemaTest.vala"
		_vala_assert (g_strcmp0 (_tmp70_, "99") == 0, "enumt20.value == \"99\"");
#line 28 "GomSchemaTest.vala"
		_g_object_unref0 (enumt20);
#line 28 "GomSchemaTest.vala"
		_g_object_unref0 (_tmp59_);
#line 28 "GomSchemaTest.vala"
		_g_object_unref0 (enumt1);
#line 28 "GomSchemaTest.vala"
		_g_object_unref0 (_tmp44_);
#line 28 "GomSchemaTest.vala"
		_g_object_unref0 (st);
#line 28 "GomSchemaTest.vala"
		_g_object_unref0 (_tmp12_);
#line 28 "GomSchemaTest.vala"
		_g_object_unref0 (sch);
#line 28 "GomSchemaTest.vala"
		_g_object_unref0 (f);
#line 446 "GomSchemaTest.c"
	}
	goto __finally217;
	__catch217_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp71_;
		gchar* _tmp72_;
		gchar* _tmp73_;
#line 28 "GomSchemaTest.vala"
		e = _inner_error0_;
#line 28 "GomSchemaTest.vala"
		_inner_error0_ = NULL;
#line 58 "GomSchemaTest.vala"
		_tmp71_ = e->message;
#line 58 "GomSchemaTest.vala"
		_tmp72_ = g_strconcat ("Error: ", _tmp71_, NULL);
#line 58 "GomSchemaTest.vala"
		_tmp73_ = _tmp72_;
#line 58 "GomSchemaTest.vala"
		g_message ("GomSchemaTest.vala:58: %s", _tmp73_);
#line 58 "GomSchemaTest.vala"
		_g_free0 (_tmp73_);
#line 59 "GomSchemaTest.vala"
		g_assert_not_reached ();
#line 28 "GomSchemaTest.vala"
		_g_error_free0 (e);
#line 473 "GomSchemaTest.c"
	}
	__finally217:
#line 28 "GomSchemaTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 28 "GomSchemaTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 28 "GomSchemaTest.vala"
		g_clear_error (&_inner_error0_);
#line 28 "GomSchemaTest.vala"
		return;
#line 484 "GomSchemaTest.c"
	}
}

static void
___lambda143__gtest_func (void)
{
#line 27 "GomSchemaTest.vala"
	__lambda143_ ();
#line 493 "GomSchemaTest.c"
}

static void
__lambda144_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GFile* f = NULL;
		GFile* _tmp0_;
		GXmlGomXsdArrayString* ars = NULL;
		GXmlGomXsdArrayString* _tmp1_;
#line 64 "GomSchemaTest.vala"
		_tmp0_ = g_file_new_for_path (TEST_DIR "/schema-test.xsd");
#line 64 "GomSchemaTest.vala"
		f = _tmp0_;
#line 65 "GomSchemaTest.vala"
		_vala_assert (g_file_query_exists (f, NULL), "f.query_exists ()");
#line 66 "GomSchemaTest.vala"
		_tmp1_ = gxml_gom_xsd_array_string_new ();
#line 66 "GomSchemaTest.vala"
		ars = _tmp1_;
#line 67 "GomSchemaTest.vala"
		gxml_gom_xsd_array_string_set_simple_type (ars, "MethodCode");
#line 68 "GomSchemaTest.vala"
		gxml_gom_xsd_array_string_set_source (ars, f);
#line 69 "GomSchemaTest.vala"
		gxml_gom_xsd_array_string_load (ars, &_inner_error0_);
#line 69 "GomSchemaTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 69 "GomSchemaTest.vala"
			_g_object_unref0 (ars);
#line 69 "GomSchemaTest.vala"
			_g_object_unref0 (f);
#line 527 "GomSchemaTest.c"
			goto __catch218_g_error;
		}
#line 70 "GomSchemaTest.vala"
		_vala_assert (gxml_gom_array_string_search ((GXmlGomArrayString*) ars, "01"), "ars.search (\"01\")");
#line 71 "GomSchemaTest.vala"
		_vala_assert (gxml_gom_array_string_search ((GXmlGomArrayString*) ars, "02"), "ars.search (\"02\")");
#line 72 "GomSchemaTest.vala"
		_vala_assert (gxml_gom_array_string_search ((GXmlGomArrayString*) ars, "03"), "ars.search (\"03\")");
#line 73 "GomSchemaTest.vala"
		_vala_assert (gxml_gom_array_string_search ((GXmlGomArrayString*) ars, "04"), "ars.search (\"04\")");
#line 74 "GomSchemaTest.vala"
		_vala_assert (gxml_gom_array_string_search ((GXmlGomArrayString*) ars, "05"), "ars.search (\"05\")");
#line 75 "GomSchemaTest.vala"
		_vala_assert (gxml_gom_array_string_search ((GXmlGomArrayString*) ars, "06"), "ars.search (\"06\")");
#line 76 "GomSchemaTest.vala"
		_vala_assert (!gxml_gom_array_string_search ((GXmlGomArrayString*) ars, "07"), "!ars.search (\"07\")");
#line 77 "GomSchemaTest.vala"
		_vala_assert (gxml_gom_array_string_search ((GXmlGomArrayString*) ars, "99"), "ars.search (\"99\")");
#line 63 "GomSchemaTest.vala"
		_g_object_unref0 (ars);
#line 63 "GomSchemaTest.vala"
		_g_object_unref0 (f);
#line 550 "GomSchemaTest.c"
	}
	goto __finally218;
	__catch218_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
#line 63 "GomSchemaTest.vala"
		e = _inner_error0_;
#line 63 "GomSchemaTest.vala"
		_inner_error0_ = NULL;
#line 79 "GomSchemaTest.vala"
		_tmp2_ = e->message;
#line 79 "GomSchemaTest.vala"
		_tmp3_ = g_strconcat ("Error: ", _tmp2_, NULL);
#line 79 "GomSchemaTest.vala"
		_tmp4_ = _tmp3_;
#line 79 "GomSchemaTest.vala"
		g_message ("GomSchemaTest.vala:79: %s", _tmp4_);
#line 79 "GomSchemaTest.vala"
		_g_free0 (_tmp4_);
#line 80 "GomSchemaTest.vala"
		g_assert_not_reached ();
#line 63 "GomSchemaTest.vala"
		_g_error_free0 (e);
#line 577 "GomSchemaTest.c"
	}
	__finally218:
#line 63 "GomSchemaTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 63 "GomSchemaTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 63 "GomSchemaTest.vala"
		g_clear_error (&_inner_error0_);
#line 63 "GomSchemaTest.vala"
		return;
#line 588 "GomSchemaTest.c"
	}
}

static void
___lambda144__gtest_func (void)
{
#line 62 "GomSchemaTest.vala"
	__lambda144_ ();
#line 597 "GomSchemaTest.c"
}

void
gom_schema_test_add_tests (void)
{
#line 27 "GomSchemaTest.vala"
	g_test_add_func ("/gxml/gom-schema/read", ___lambda143__gtest_func);
#line 62 "GomSchemaTest.vala"
	g_test_add_func ("/gxml/xsd-array-string/attribute-enumeration", ___lambda144__gtest_func);
#line 607 "GomSchemaTest.c"
}

GomSchemaTest*
gom_schema_test_construct (GType object_type)
{
	GomSchemaTest* self = NULL;
#line 25 "GomSchemaTest.vala"
	self = (GomSchemaTest*) gxml_test_construct (object_type);
#line 25 "GomSchemaTest.vala"
	return self;
#line 618 "GomSchemaTest.c"
}

GomSchemaTest*
gom_schema_test_new (void)
{
#line 25 "GomSchemaTest.vala"
	return gom_schema_test_construct (TYPE_GOM_SCHEMA_TEST);
#line 626 "GomSchemaTest.c"
}

static void
gom_schema_test_class_init (GomSchemaTestClass * klass,
                            gpointer klass_data)
{
#line 25 "GomSchemaTest.vala"
	gom_schema_test_parent_class = g_type_class_peek_parent (klass);
#line 635 "GomSchemaTest.c"
}

static void
gom_schema_test_instance_init (GomSchemaTest * self,
                               gpointer klass)
{
}

GType
gom_schema_test_get_type (void)
{
	static volatile gsize gom_schema_test_type_id__volatile = 0;
	if (g_once_init_enter (&gom_schema_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSchemaTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_schema_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSchemaTest), 0, (GInstanceInitFunc) gom_schema_test_instance_init, NULL };
		GType gom_schema_test_type_id;
		gom_schema_test_type_id = g_type_register_static (TYPE_GXML_TEST, "GomSchemaTest", &g_define_type_info, 0);
		g_once_init_leave (&gom_schema_test_type_id__volatile, gom_schema_test_type_id);
	}
	return gom_schema_test_type_id__volatile;
}

