/* SerializablePropertyEnumTest.c generated by valac 0.44.3, the Vala compiler
 * generated from SerializablePropertyEnumTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; tab-width: 2 -*- */

#include <glib-object.h>
#include <glib.h>
#include <gxml/gxml.h>
#include <stdlib.h>
#include <string.h>

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_SERIALIZABLE_PROPERTY_ENUM_TEST (serializable_property_enum_test_get_type ())
#define SERIALIZABLE_PROPERTY_ENUM_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_PROPERTY_ENUM_TEST, SerializablePropertyEnumTest))
#define SERIALIZABLE_PROPERTY_ENUM_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_PROPERTY_ENUM_TEST, SerializablePropertyEnumTestClass))
#define IS_SERIALIZABLE_PROPERTY_ENUM_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_PROPERTY_ENUM_TEST))
#define IS_SERIALIZABLE_PROPERTY_ENUM_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_PROPERTY_ENUM_TEST))
#define SERIALIZABLE_PROPERTY_ENUM_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_PROPERTY_ENUM_TEST, SerializablePropertyEnumTestClass))

typedef struct _SerializablePropertyEnumTest SerializablePropertyEnumTest;
typedef struct _SerializablePropertyEnumTestClass SerializablePropertyEnumTestClass;
typedef struct _SerializablePropertyEnumTestPrivate SerializablePropertyEnumTestPrivate;

#define SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUMERATION_VALUES (serializable_property_enum_test_enumeration_values_get_type ())
#define SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUMERATION_VALUES, SerializablePropertyEnumTestEnumerationValues))
#define SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUMERATION_VALUES, SerializablePropertyEnumTestEnumerationValuesClass))
#define SERIALIZABLE_PROPERTY_ENUM_TEST_IS_ENUMERATION_VALUES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUMERATION_VALUES))
#define SERIALIZABLE_PROPERTY_ENUM_TEST_IS_ENUMERATION_VALUES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUMERATION_VALUES))
#define SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUMERATION_VALUES, SerializablePropertyEnumTestEnumerationValuesClass))

typedef struct _SerializablePropertyEnumTestEnumerationValues SerializablePropertyEnumTestEnumerationValues;
typedef struct _SerializablePropertyEnumTestEnumerationValuesClass SerializablePropertyEnumTestEnumerationValuesClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef enum  {
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_ONE,
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_TWO,
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_THREE,
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_AP,
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_EXTENSION
} SerializablePropertyEnumTestEnumValues;

#define SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_TYPE_VALUES (serializable_property_enum_test_enum_values_get_type ())

#define SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUM (serializable_property_enum_test_enum_get_type ())
#define SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUM, SerializablePropertyEnumTestEnum))
#define SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUM, SerializablePropertyEnumTestEnumClass))
#define SERIALIZABLE_PROPERTY_ENUM_TEST_IS_ENUM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUM))
#define SERIALIZABLE_PROPERTY_ENUM_TEST_IS_ENUM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUM))
#define SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUM, SerializablePropertyEnumTestEnumClass))

typedef struct _SerializablePropertyEnumTestEnum SerializablePropertyEnumTestEnum;
typedef struct _SerializablePropertyEnumTestEnumClass SerializablePropertyEnumTestEnumClass;
typedef struct _SerializablePropertyEnumTestEnumPrivate SerializablePropertyEnumTestEnumPrivate;
enum  {
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_0_PROPERTY,
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_NUM_PROPERTIES
};
static GParamSpec* serializable_property_enum_test_enum_properties[SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_NUM_PROPERTIES];
typedef struct _SerializablePropertyEnumTestEnumerationValuesPrivate SerializablePropertyEnumTestEnumerationValuesPrivate;
enum  {
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_0_PROPERTY,
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_VALUES_PROPERTY,
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_OPTIONAL_VALUES_PROPERTY,
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_INTEGER_PROPERTY,
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_NAME_PROPERTY,
	SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_NUM_PROPERTIES
};
static GParamSpec* serializable_property_enum_test_enumeration_values_properties[SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_NUM_PROPERTIES];
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _SerializablePropertyEnumTest {
	GXmlTest parent_instance;
	SerializablePropertyEnumTestPrivate * priv;
};

struct _SerializablePropertyEnumTestClass {
	GXmlTestClass parent_class;
};

struct _SerializablePropertyEnumTestEnum {
	GXmlSerializableEnum parent_instance;
	SerializablePropertyEnumTestEnumPrivate * priv;
};

struct _SerializablePropertyEnumTestEnumClass {
	GXmlSerializableEnumClass parent_class;
};

struct _SerializablePropertyEnumTestEnumerationValues {
	GXmlSerializableObjectModel parent_instance;
	SerializablePropertyEnumTestEnumerationValuesPrivate * priv;
};

struct _SerializablePropertyEnumTestEnumerationValuesClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializablePropertyEnumTestEnumerationValuesPrivate {
	SerializablePropertyEnumTestEnum* _values;
	SerializablePropertyEnumTestEnum* _optional_values;
	gint _integer;
	gchar* _name;
};

static gpointer serializable_property_enum_test_parent_class = NULL;
static gpointer serializable_property_enum_test_enum_parent_class = NULL;
static gint SerializablePropertyEnumTestEnumerationValues_private_offset;
static gpointer serializable_property_enum_test_enumeration_values_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType serializable_property_enum_test_get_type (void) G_GNUC_CONST;
void serializable_property_enum_test_add_tests (void);
static void __lambda248_ (void);
GType serializable_property_enum_test_enumeration_values_get_type (void) G_GNUC_CONST;
SerializablePropertyEnumTestEnumerationValues* serializable_property_enum_test_enumeration_values_new (void);
SerializablePropertyEnumTestEnumerationValues* serializable_property_enum_test_enumeration_values_construct (GType object_type);
static void ___lambda248__gtest_func (void);
static void __lambda249_ (void);
GType serializable_property_enum_test_enum_values_get_type (void) G_GNUC_CONST;
SerializablePropertyEnumTestEnum* serializable_property_enum_test_enum_new (void);
SerializablePropertyEnumTestEnum* serializable_property_enum_test_enum_construct (GType object_type);
GType serializable_property_enum_test_enum_get_type (void) G_GNUC_CONST;
void serializable_property_enum_test_enumeration_values_set_values (SerializablePropertyEnumTestEnumerationValues* self,
                                                                    SerializablePropertyEnumTestEnum* value);
SerializablePropertyEnumTestEnum* serializable_property_enum_test_enumeration_values_get_values (SerializablePropertyEnumTestEnumerationValues* self);
SerializablePropertyEnumTestEnumValues serializable_property_enum_test_enum_get_value (SerializablePropertyEnumTestEnum* self,
                                                                                       GError** error);
void serializable_property_enum_test_enum_set_value (SerializablePropertyEnumTestEnum* self,
                                                     SerializablePropertyEnumTestEnumValues val,
                                                     GError** error);
void serializable_property_enum_test_enum_set_string (SerializablePropertyEnumTestEnum* self,
                                                      const gchar* str,
                                                      GError** error);
static void ___lambda249__gtest_func (void);
static void __lambda250_ (void);
static void ___lambda250__gtest_func (void);
static void __lambda251_ (void);
SerializablePropertyEnumTestEnum* serializable_property_enum_test_enumeration_values_get_optional_values (SerializablePropertyEnumTestEnumerationValues* self);
static void ___lambda251__gtest_func (void);
SerializablePropertyEnumTest* serializable_property_enum_test_new (void);
SerializablePropertyEnumTest* serializable_property_enum_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static GObject * serializable_property_enum_test_enum_constructor (GType type,
                                                            guint n_construct_properties,
                                                            GObjectConstructParam * construct_properties);
static gchar* serializable_property_enum_test_enumeration_values_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_property_enum_test_enumeration_values_real_to_string (GXmlSerializableObjectModel* base);
static gboolean serializable_property_enum_test_enumeration_values_real_property_use_nick (GXmlSerializableObjectModel* base);
void serializable_property_enum_test_enumeration_values_set_optional_values (SerializablePropertyEnumTestEnumerationValues* self,
                                                                             SerializablePropertyEnumTestEnum* value);
gint serializable_property_enum_test_enumeration_values_get_integer (SerializablePropertyEnumTestEnumerationValues* self);
void serializable_property_enum_test_enumeration_values_set_integer (SerializablePropertyEnumTestEnumerationValues* self,
                                                                     gint value);
const gchar* serializable_property_enum_test_enumeration_values_get_name (SerializablePropertyEnumTestEnumerationValues* self);
void serializable_property_enum_test_enumeration_values_set_name (SerializablePropertyEnumTestEnumerationValues* self,
                                                                  const gchar* value);
static void serializable_property_enum_test_enumeration_values_finalize (GObject * obj);
static void _vala_serializable_property_enum_test_enumeration_values_get_property (GObject * object,
                                                                            guint property_id,
                                                                            GValue * value,
                                                                            GParamSpec * pspec);
static void _vala_serializable_property_enum_test_enumeration_values_set_property (GObject * object,
                                                                            guint property_id,
                                                                            const GValue * value,
                                                                            GParamSpec * pspec);

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result = NULL;
#line 1516 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1517 "glib-2.0.vapi"
	result = self;
#line 1517 "glib-2.0.vapi"
	return result;
#line 217 "SerializablePropertyEnumTest.c"
}

static void
__lambda248_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		SerializablePropertyEnumTestEnumerationValues* e = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp0_;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_;
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		GXmlElement* element = NULL;
		GXmlNode* _tmp8_;
		GXmlNode* _tmp9_;
		GXmlElement* _tmp10_;
		GXmlNode* ee1 = NULL;
		GXmlNode* _tmp11_;
		GXmlNode* s = NULL;
		GXmlNode* _tmp12_;
		GXmlNode* i = NULL;
		GXmlNode* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		gchar* _tmp16_;
#line 60 "SerializablePropertyEnumTest.vala"
		_tmp0_ = serializable_property_enum_test_enumeration_values_new ();
#line 60 "SerializablePropertyEnumTest.vala"
		e = _tmp0_;
#line 61 "SerializablePropertyEnumTest.vala"
		_tmp1_ = gxml_gdocument_new ();
#line 61 "SerializablePropertyEnumTest.vala"
		doc = _tmp1_;
#line 62 "SerializablePropertyEnumTest.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) e, (GXmlNode*) doc, &_inner_error0_);
#line 62 "SerializablePropertyEnumTest.vala"
		_tmp3_ = _tmp2_;
#line 62 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (_tmp3_);
#line 62 "SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 62 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (doc);
#line 62 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 268 "SerializablePropertyEnumTest.c"
			goto __catch302_g_error;
		}
#line 63 "SerializablePropertyEnumTest.vala"
		_tmp4_ = gxml_gnode_to_string ((GXmlGNode*) doc);
#line 63 "SerializablePropertyEnumTest.vala"
		_tmp5_ = _tmp4_;
#line 63 "SerializablePropertyEnumTest.vala"
		_tmp6_ = g_strconcat ("XML:\n", _tmp5_, NULL);
#line 63 "SerializablePropertyEnumTest.vala"
		_tmp7_ = _tmp6_;
#line 63 "SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp7_);
#line 63 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp7_);
#line 63 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp5_);
#line 64 "SerializablePropertyEnumTest.vala"
		_tmp8_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 64 "SerializablePropertyEnumTest.vala"
		_tmp9_ = _tmp8_;
#line 64 "SerializablePropertyEnumTest.vala"
		_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp9_) : NULL;
#line 64 "SerializablePropertyEnumTest.vala"
		if (_tmp10_ == NULL) {
#line 64 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (_tmp9_);
#line 295 "SerializablePropertyEnumTest.c"
		}
#line 64 "SerializablePropertyEnumTest.vala"
		element = _tmp10_;
#line 65 "SerializablePropertyEnumTest.vala"
		_tmp11_ = gxml_element_get_attr (element, "values");
#line 65 "SerializablePropertyEnumTest.vala"
		ee1 = _tmp11_;
#line 66 "SerializablePropertyEnumTest.vala"
		_vala_assert (ee1 == NULL, "ee1 == null");
#line 67 "SerializablePropertyEnumTest.vala"
		_tmp12_ = gxml_element_get_attr (element, "name");
#line 67 "SerializablePropertyEnumTest.vala"
		s = _tmp12_;
#line 68 "SerializablePropertyEnumTest.vala"
		_vala_assert (s == NULL, "s == null");
#line 69 "SerializablePropertyEnumTest.vala"
		_tmp13_ = gxml_element_get_attr (element, "integer");
#line 69 "SerializablePropertyEnumTest.vala"
		i = _tmp13_;
#line 70 "SerializablePropertyEnumTest.vala"
		_tmp14_ = gxml_node_get_value (i);
#line 70 "SerializablePropertyEnumTest.vala"
		_tmp15_ = _tmp14_;
#line 70 "SerializablePropertyEnumTest.vala"
		_tmp16_ = _tmp15_;
#line 70 "SerializablePropertyEnumTest.vala"
		_vala_assert (g_strcmp0 (_tmp16_, "0") == 0, "i.value == \"0\"");
#line 70 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp16_);
#line 59 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (i);
#line 59 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (s);
#line 59 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (ee1);
#line 59 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (element);
#line 59 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (doc);
#line 59 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (e);
#line 337 "SerializablePropertyEnumTest.c"
	}
	goto __finally302;
	__catch302_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp17_;
		const gchar* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
#line 59 "SerializablePropertyEnumTest.vala"
		e = _inner_error0_;
#line 59 "SerializablePropertyEnumTest.vala"
		_inner_error0_ = NULL;
#line 72 "SerializablePropertyEnumTest.vala"
		_tmp17_ = e->message;
#line 72 "SerializablePropertyEnumTest.vala"
		_tmp18_ = string_to_string (_tmp17_);
#line 72 "SerializablePropertyEnumTest.vala"
		_tmp19_ = g_strconcat ("ERROR: ", _tmp18_, NULL);
#line 72 "SerializablePropertyEnumTest.vala"
		_tmp20_ = _tmp19_;
#line 72 "SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp20_);
#line 72 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp20_);
#line 73 "SerializablePropertyEnumTest.vala"
		g_assert_not_reached ();
#line 59 "SerializablePropertyEnumTest.vala"
		_g_error_free0 (e);
#line 367 "SerializablePropertyEnumTest.c"
	}
	__finally302:
#line 59 "SerializablePropertyEnumTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 59 "SerializablePropertyEnumTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 59 "SerializablePropertyEnumTest.vala"
		g_clear_error (&_inner_error0_);
#line 59 "SerializablePropertyEnumTest.vala"
		return;
#line 378 "SerializablePropertyEnumTest.c"
	}
}

static void
___lambda248__gtest_func (void)
{
#line 57 "SerializablePropertyEnumTest.vala"
	__lambda248_ ();
#line 387 "SerializablePropertyEnumTest.c"
}

static void
__lambda249_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		SerializablePropertyEnumTestEnumerationValues* e = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp0_;
		GXmlGDocument* doc1 = NULL;
		GXmlGDocument* _tmp1_;
		SerializablePropertyEnumTestEnumerationValues* _tmp2_;
		GXmlGDocument* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlGDocument* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		GXmlElement* element1 = NULL;
		GXmlGDocument* _tmp11_;
		GXmlNode* _tmp12_;
		GXmlNode* _tmp13_;
		GXmlElement* _tmp14_;
		GXmlNode* ee1 = NULL;
		GXmlElement* _tmp15_;
		GXmlNode* _tmp16_;
		GXmlNode* _tmp17_;
		GXmlNode* s1 = NULL;
		GXmlElement* _tmp18_;
		GXmlNode* _tmp19_;
		GXmlNode* _tmp20_;
		GXmlNode* i1 = NULL;
		GXmlElement* _tmp21_;
		GXmlNode* _tmp22_;
		GXmlNode* _tmp23_;
		gchar* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		SerializablePropertyEnumTestEnumValues v = 0;
		SerializablePropertyEnumTestEnumerationValues* _tmp27_;
		SerializablePropertyEnumTestEnum* _tmp28_;
		SerializablePropertyEnumTestEnum* _tmp29_;
		SerializablePropertyEnumTestEnumerationValues* _tmp38_;
		SerializablePropertyEnumTestEnum* _tmp39_;
		SerializablePropertyEnumTestEnum* _tmp40_;
		SerializablePropertyEnumTestEnumValues _tmp41_ = 0;
		SerializablePropertyEnumTestEnumerationValues* _tmp42_;
		SerializablePropertyEnumTestEnum* _tmp43_;
		SerializablePropertyEnumTestEnum* _tmp44_;
		SerializablePropertyEnumTestEnumerationValues* _tmp45_;
		SerializablePropertyEnumTestEnum* _tmp46_;
		SerializablePropertyEnumTestEnum* _tmp47_;
		gchar* _tmp48_;
		gchar* _tmp49_;
		gchar* _tmp50_;
		gchar* _tmp51_;
		SerializablePropertyEnumTestEnumerationValues* _tmp52_;
		SerializablePropertyEnumTestEnum* _tmp53_;
		SerializablePropertyEnumTestEnum* _tmp54_;
		gchar* _tmp55_;
		gchar* _tmp56_;
		GXmlGDocument* d2 = NULL;
		GXmlGDocument* _tmp57_;
		SerializablePropertyEnumTestEnumerationValues* _tmp58_;
		GXmlGDocument* _tmp59_;
		GXmlNode* _tmp60_;
		GXmlNode* _tmp61_;
		GXmlGDocument* _tmp62_;
		gchar* _tmp63_;
		gchar* _tmp64_;
		gchar* _tmp65_;
		gchar* _tmp66_;
		GXmlElement* element2 = NULL;
		GXmlGDocument* _tmp67_;
		GXmlNode* _tmp68_;
		GXmlNode* _tmp69_;
		GXmlElement* _tmp70_;
		GXmlNode* ee2 = NULL;
		GXmlElement* _tmp71_;
		GXmlNode* _tmp72_;
		GXmlNode* _tmp73_;
		GXmlNode* _tmp74_;
		gchar* _tmp75_;
		gchar* _tmp76_;
		gchar* _tmp77_;
		SerializablePropertyEnumTestEnumerationValues* _tmp78_;
		SerializablePropertyEnumTestEnum* _tmp79_;
		SerializablePropertyEnumTestEnum* _tmp80_;
		SerializablePropertyEnumTestEnumValues _tmp81_ = 0;
		SerializablePropertyEnumTestEnumerationValues* _tmp82_;
		SerializablePropertyEnumTestEnum* _tmp83_;
		SerializablePropertyEnumTestEnum* _tmp84_;
		SerializablePropertyEnumTestEnumerationValues* _tmp85_;
		SerializablePropertyEnumTestEnum* _tmp86_;
		SerializablePropertyEnumTestEnum* _tmp87_;
		gchar* _tmp88_;
		gchar* _tmp89_;
		gchar* _tmp90_;
		gchar* _tmp91_;
		SerializablePropertyEnumTestEnumerationValues* _tmp92_;
		SerializablePropertyEnumTestEnum* _tmp93_;
		SerializablePropertyEnumTestEnum* _tmp94_;
		gchar* _tmp95_;
		gchar* _tmp96_;
		GXmlGDocument* d3 = NULL;
		GXmlGDocument* _tmp97_;
		SerializablePropertyEnumTestEnumerationValues* _tmp98_;
		GXmlGDocument* _tmp99_;
		GXmlNode* _tmp100_;
		GXmlNode* _tmp101_;
		GXmlGDocument* _tmp102_;
		gchar* _tmp103_;
		gchar* _tmp104_;
		gchar* _tmp105_;
		gchar* _tmp106_;
		GXmlElement* element3 = NULL;
		GXmlGDocument* _tmp107_;
		GXmlNode* _tmp108_;
		GXmlNode* _tmp109_;
		GXmlElement* _tmp110_;
		GXmlNode* ee3 = NULL;
		GXmlElement* _tmp111_;
		GXmlNode* _tmp112_;
		GXmlNode* _tmp113_;
		GXmlNode* _tmp114_;
		gchar* _tmp115_;
		gchar* _tmp116_;
		gchar* _tmp117_;
		SerializablePropertyEnumTestEnumerationValues* _tmp118_;
		SerializablePropertyEnumTestEnum* _tmp119_;
		SerializablePropertyEnumTestEnum* _tmp120_;
		GXmlGDocument* d4 = NULL;
		GXmlGDocument* _tmp121_;
		SerializablePropertyEnumTestEnumerationValues* _tmp122_;
		GXmlGDocument* _tmp123_;
		GXmlNode* _tmp124_;
		GXmlNode* _tmp125_;
		GXmlGDocument* _tmp126_;
		gchar* _tmp127_;
		gchar* _tmp128_;
		gchar* _tmp129_;
		gchar* _tmp130_;
		GXmlElement* element4 = NULL;
		GXmlGDocument* _tmp131_;
		GXmlNode* _tmp132_;
		GXmlNode* _tmp133_;
		GXmlElement* _tmp134_;
		GXmlNode* ee4 = NULL;
		GXmlNode* _tmp135_;
#line 79 "SerializablePropertyEnumTest.vala"
		_tmp0_ = serializable_property_enum_test_enumeration_values_new ();
#line 79 "SerializablePropertyEnumTest.vala"
		e = _tmp0_;
#line 80 "SerializablePropertyEnumTest.vala"
		_tmp1_ = gxml_gdocument_new ();
#line 80 "SerializablePropertyEnumTest.vala"
		doc1 = _tmp1_;
#line 81 "SerializablePropertyEnumTest.vala"
		_tmp2_ = e;
#line 81 "SerializablePropertyEnumTest.vala"
		_tmp3_ = doc1;
#line 81 "SerializablePropertyEnumTest.vala"
		_tmp4_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 81 "SerializablePropertyEnumTest.vala"
		_tmp5_ = _tmp4_;
#line 81 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (_tmp5_);
#line 81 "SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 81 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (doc1);
#line 81 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 563 "SerializablePropertyEnumTest.c"
			goto __catch303_g_error;
		}
#line 82 "SerializablePropertyEnumTest.vala"
		_tmp6_ = doc1;
#line 82 "SerializablePropertyEnumTest.vala"
		_tmp7_ = gxml_gnode_to_string ((GXmlGNode*) _tmp6_);
#line 82 "SerializablePropertyEnumTest.vala"
		_tmp8_ = _tmp7_;
#line 82 "SerializablePropertyEnumTest.vala"
		_tmp9_ = g_strconcat ("XML1:\n", _tmp8_, NULL);
#line 82 "SerializablePropertyEnumTest.vala"
		_tmp10_ = _tmp9_;
#line 82 "SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp10_);
#line 82 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp10_);
#line 82 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp8_);
#line 83 "SerializablePropertyEnumTest.vala"
		_tmp11_ = doc1;
#line 83 "SerializablePropertyEnumTest.vala"
		_tmp12_ = gxml_document_get_root ((GXmlDocument*) _tmp11_);
#line 83 "SerializablePropertyEnumTest.vala"
		_tmp13_ = _tmp12_;
#line 83 "SerializablePropertyEnumTest.vala"
		_tmp14_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp13_) : NULL;
#line 83 "SerializablePropertyEnumTest.vala"
		if (_tmp14_ == NULL) {
#line 83 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (_tmp13_);
#line 594 "SerializablePropertyEnumTest.c"
		}
#line 83 "SerializablePropertyEnumTest.vala"
		element1 = _tmp14_;
#line 84 "SerializablePropertyEnumTest.vala"
		_tmp15_ = element1;
#line 84 "SerializablePropertyEnumTest.vala"
		_tmp16_ = gxml_element_get_attr (_tmp15_, "values");
#line 84 "SerializablePropertyEnumTest.vala"
		ee1 = _tmp16_;
#line 85 "SerializablePropertyEnumTest.vala"
		_tmp17_ = ee1;
#line 85 "SerializablePropertyEnumTest.vala"
		_vala_assert (_tmp17_ == NULL, "ee1 == null");
#line 86 "SerializablePropertyEnumTest.vala"
		_tmp18_ = element1;
#line 86 "SerializablePropertyEnumTest.vala"
		_tmp19_ = gxml_element_get_attr (_tmp18_, "name");
#line 86 "SerializablePropertyEnumTest.vala"
		s1 = _tmp19_;
#line 87 "SerializablePropertyEnumTest.vala"
		_tmp20_ = s1;
#line 87 "SerializablePropertyEnumTest.vala"
		_vala_assert (_tmp20_ == NULL, "s1 == null");
#line 88 "SerializablePropertyEnumTest.vala"
		_tmp21_ = element1;
#line 88 "SerializablePropertyEnumTest.vala"
		_tmp22_ = gxml_element_get_attr (_tmp21_, "integer");
#line 88 "SerializablePropertyEnumTest.vala"
		i1 = _tmp22_;
#line 89 "SerializablePropertyEnumTest.vala"
		_tmp23_ = i1;
#line 89 "SerializablePropertyEnumTest.vala"
		_tmp24_ = gxml_node_get_value (_tmp23_);
#line 89 "SerializablePropertyEnumTest.vala"
		_tmp25_ = _tmp24_;
#line 89 "SerializablePropertyEnumTest.vala"
		_tmp26_ = _tmp25_;
#line 89 "SerializablePropertyEnumTest.vala"
		_vala_assert (g_strcmp0 (_tmp26_, "0") == 0, "i1.value == \"0\"");
#line 89 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp26_);
#line 91 "SerializablePropertyEnumTest.vala"
		v = SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_ONE;
#line 92 "SerializablePropertyEnumTest.vala"
		_tmp27_ = e;
#line 92 "SerializablePropertyEnumTest.vala"
		_tmp28_ = serializable_property_enum_test_enum_new ();
#line 92 "SerializablePropertyEnumTest.vala"
		_tmp29_ = _tmp28_;
#line 92 "SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enumeration_values_set_values (_tmp27_, _tmp29_);
#line 92 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (_tmp29_);
#line 648 "SerializablePropertyEnumTest.c"
		{
			SerializablePropertyEnumTestEnumValues _tmp30_ = 0;
			SerializablePropertyEnumTestEnumerationValues* _tmp31_;
			SerializablePropertyEnumTestEnum* _tmp32_;
			SerializablePropertyEnumTestEnum* _tmp33_;
#line 93 "SerializablePropertyEnumTest.vala"
			_tmp31_ = e;
#line 93 "SerializablePropertyEnumTest.vala"
			_tmp32_ = serializable_property_enum_test_enumeration_values_get_values (_tmp31_);
#line 93 "SerializablePropertyEnumTest.vala"
			_tmp33_ = _tmp32_;
#line 93 "SerializablePropertyEnumTest.vala"
			_tmp30_ = serializable_property_enum_test_enum_get_value (_tmp33_, &_inner_error0_);
#line 93 "SerializablePropertyEnumTest.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 664 "SerializablePropertyEnumTest.c"
				goto __catch304_g_error;
			}
#line 93 "SerializablePropertyEnumTest.vala"
			v = _tmp30_;
#line 669 "SerializablePropertyEnumTest.c"
		}
		goto __finally304;
		__catch304_g_error:
		{
			GError* e = NULL;
			GError* _tmp34_;
			const gchar* _tmp35_;
			gchar* _tmp36_;
			gchar* _tmp37_;
#line 93 "SerializablePropertyEnumTest.vala"
			e = _inner_error0_;
#line 93 "SerializablePropertyEnumTest.vala"
			_inner_error0_ = NULL;
#line 95 "SerializablePropertyEnumTest.vala"
			_tmp34_ = e;
#line 95 "SerializablePropertyEnumTest.vala"
			_tmp35_ = _tmp34_->message;
#line 95 "SerializablePropertyEnumTest.vala"
			_tmp36_ = g_strconcat ("Error cough correctly: ", _tmp35_, NULL);
#line 95 "SerializablePropertyEnumTest.vala"
			_tmp37_ = _tmp36_;
#line 95 "SerializablePropertyEnumTest.vala"
			g_test_message ("%s", _tmp37_);
#line 95 "SerializablePropertyEnumTest.vala"
			_g_free0 (_tmp37_);
#line 93 "SerializablePropertyEnumTest.vala"
			_g_error_free0 (e);
#line 697 "SerializablePropertyEnumTest.c"
		}
		__finally304:
#line 93 "SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 93 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (i1);
#line 93 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (s1);
#line 93 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee1);
#line 93 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element1);
#line 93 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (doc1);
#line 93 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 714 "SerializablePropertyEnumTest.c"
			goto __catch303_g_error;
		}
#line 97 "SerializablePropertyEnumTest.vala"
		_tmp38_ = e;
#line 97 "SerializablePropertyEnumTest.vala"
		_tmp39_ = serializable_property_enum_test_enumeration_values_get_values (_tmp38_);
#line 97 "SerializablePropertyEnumTest.vala"
		_tmp40_ = _tmp39_;
#line 97 "SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enum_set_value (_tmp40_, SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_THREE, &_inner_error0_);
#line 97 "SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 97 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (i1);
#line 97 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (s1);
#line 97 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee1);
#line 97 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element1);
#line 97 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (doc1);
#line 97 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 739 "SerializablePropertyEnumTest.c"
			goto __catch303_g_error;
		}
#line 98 "SerializablePropertyEnumTest.vala"
		_tmp42_ = e;
#line 98 "SerializablePropertyEnumTest.vala"
		_tmp43_ = serializable_property_enum_test_enumeration_values_get_values (_tmp42_);
#line 98 "SerializablePropertyEnumTest.vala"
		_tmp44_ = _tmp43_;
#line 98 "SerializablePropertyEnumTest.vala"
		_tmp41_ = serializable_property_enum_test_enum_get_value (_tmp44_, &_inner_error0_);
#line 98 "SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 98 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (i1);
#line 98 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (s1);
#line 98 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee1);
#line 98 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element1);
#line 98 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (doc1);
#line 98 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 764 "SerializablePropertyEnumTest.c"
			goto __catch303_g_error;
		}
#line 98 "SerializablePropertyEnumTest.vala"
		_vala_assert (_tmp41_ == SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_THREE, "e.values.get_value () == Enum.Values.SER_THREE");
#line 99 "SerializablePropertyEnumTest.vala"
		_tmp45_ = e;
#line 99 "SerializablePropertyEnumTest.vala"
		_tmp46_ = serializable_property_enum_test_enumeration_values_get_values (_tmp45_);
#line 99 "SerializablePropertyEnumTest.vala"
		_tmp47_ = _tmp46_;
#line 99 "SerializablePropertyEnumTest.vala"
		_tmp48_ = gxml_serializable_enum_to_string ((GXmlSerializableEnum*) _tmp47_);
#line 99 "SerializablePropertyEnumTest.vala"
		_tmp49_ = _tmp48_;
#line 99 "SerializablePropertyEnumTest.vala"
		_tmp50_ = g_strconcat ("Actual value= ", _tmp49_, NULL);
#line 99 "SerializablePropertyEnumTest.vala"
		_tmp51_ = _tmp50_;
#line 99 "SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp51_);
#line 99 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp51_);
#line 99 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp49_);
#line 100 "SerializablePropertyEnumTest.vala"
		_tmp52_ = e;
#line 100 "SerializablePropertyEnumTest.vala"
		_tmp53_ = serializable_property_enum_test_enumeration_values_get_values (_tmp52_);
#line 100 "SerializablePropertyEnumTest.vala"
		_tmp54_ = _tmp53_;
#line 100 "SerializablePropertyEnumTest.vala"
		_tmp55_ = gxml_serializable_enum_to_string ((GXmlSerializableEnum*) _tmp54_);
#line 100 "SerializablePropertyEnumTest.vala"
		_tmp56_ = _tmp55_;
#line 100 "SerializablePropertyEnumTest.vala"
		_vala_assert (g_strcmp0 (_tmp56_, "SerThree") == 0, "e.values.to_string () == \"SerThree\"");
#line 100 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp56_);
#line 101 "SerializablePropertyEnumTest.vala"
		_tmp57_ = gxml_gdocument_new ();
#line 101 "SerializablePropertyEnumTest.vala"
		d2 = _tmp57_;
#line 102 "SerializablePropertyEnumTest.vala"
		_tmp58_ = e;
#line 102 "SerializablePropertyEnumTest.vala"
		_tmp59_ = d2;
#line 102 "SerializablePropertyEnumTest.vala"
		_tmp60_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp58_, (GXmlNode*) _tmp59_, &_inner_error0_);
#line 102 "SerializablePropertyEnumTest.vala"
		_tmp61_ = _tmp60_;
#line 102 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (_tmp61_);
#line 102 "SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 102 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 102 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (i1);
#line 102 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (s1);
#line 102 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee1);
#line 102 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element1);
#line 102 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (doc1);
#line 102 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 833 "SerializablePropertyEnumTest.c"
			goto __catch303_g_error;
		}
#line 103 "SerializablePropertyEnumTest.vala"
		_tmp62_ = d2;
#line 103 "SerializablePropertyEnumTest.vala"
		_tmp63_ = gxml_gnode_to_string ((GXmlGNode*) _tmp62_);
#line 103 "SerializablePropertyEnumTest.vala"
		_tmp64_ = _tmp63_;
#line 103 "SerializablePropertyEnumTest.vala"
		_tmp65_ = g_strconcat ("XML2:\n", _tmp64_, NULL);
#line 103 "SerializablePropertyEnumTest.vala"
		_tmp66_ = _tmp65_;
#line 103 "SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp66_);
#line 103 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp66_);
#line 103 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp64_);
#line 104 "SerializablePropertyEnumTest.vala"
		_tmp67_ = d2;
#line 104 "SerializablePropertyEnumTest.vala"
		_tmp68_ = gxml_document_get_root ((GXmlDocument*) _tmp67_);
#line 104 "SerializablePropertyEnumTest.vala"
		_tmp69_ = _tmp68_;
#line 104 "SerializablePropertyEnumTest.vala"
		_tmp70_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp69_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp69_) : NULL;
#line 104 "SerializablePropertyEnumTest.vala"
		if (_tmp70_ == NULL) {
#line 104 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (_tmp69_);
#line 864 "SerializablePropertyEnumTest.c"
		}
#line 104 "SerializablePropertyEnumTest.vala"
		element2 = _tmp70_;
#line 105 "SerializablePropertyEnumTest.vala"
		_tmp71_ = element2;
#line 105 "SerializablePropertyEnumTest.vala"
		_tmp72_ = gxml_element_get_attr (_tmp71_, "values");
#line 105 "SerializablePropertyEnumTest.vala"
		ee2 = _tmp72_;
#line 106 "SerializablePropertyEnumTest.vala"
		_tmp73_ = ee2;
#line 106 "SerializablePropertyEnumTest.vala"
		_vala_assert (_tmp73_ != NULL, "ee2 != null");
#line 107 "SerializablePropertyEnumTest.vala"
		_tmp74_ = ee2;
#line 107 "SerializablePropertyEnumTest.vala"
		_tmp75_ = gxml_node_get_value (_tmp74_);
#line 107 "SerializablePropertyEnumTest.vala"
		_tmp76_ = _tmp75_;
#line 107 "SerializablePropertyEnumTest.vala"
		_tmp77_ = _tmp76_;
#line 107 "SerializablePropertyEnumTest.vala"
		_vala_assert (g_strcmp0 (_tmp77_, "SerThree") == 0, "ee2.value == \"SerThree\"");
#line 107 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp77_);
#line 108 "SerializablePropertyEnumTest.vala"
		_tmp78_ = e;
#line 108 "SerializablePropertyEnumTest.vala"
		_tmp79_ = serializable_property_enum_test_enumeration_values_get_values (_tmp78_);
#line 108 "SerializablePropertyEnumTest.vala"
		_tmp80_ = _tmp79_;
#line 108 "SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enum_set_value (_tmp80_, SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_TWO, &_inner_error0_);
#line 108 "SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 108 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee2);
#line 108 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element2);
#line 108 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 108 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (i1);
#line 108 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (s1);
#line 108 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee1);
#line 108 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element1);
#line 108 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (doc1);
#line 108 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 918 "SerializablePropertyEnumTest.c"
			goto __catch303_g_error;
		}
#line 109 "SerializablePropertyEnumTest.vala"
		_tmp82_ = e;
#line 109 "SerializablePropertyEnumTest.vala"
		_tmp83_ = serializable_property_enum_test_enumeration_values_get_values (_tmp82_);
#line 109 "SerializablePropertyEnumTest.vala"
		_tmp84_ = _tmp83_;
#line 109 "SerializablePropertyEnumTest.vala"
		_tmp81_ = serializable_property_enum_test_enum_get_value (_tmp84_, &_inner_error0_);
#line 109 "SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 109 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee2);
#line 109 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element2);
#line 109 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 109 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (i1);
#line 109 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (s1);
#line 109 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee1);
#line 109 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element1);
#line 109 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (doc1);
#line 109 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 949 "SerializablePropertyEnumTest.c"
			goto __catch303_g_error;
		}
#line 109 "SerializablePropertyEnumTest.vala"
		_vala_assert (_tmp81_ == SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_TWO, "e.values.get_value () == Enum.Values.SER_TWO");
#line 110 "SerializablePropertyEnumTest.vala"
		_tmp85_ = e;
#line 110 "SerializablePropertyEnumTest.vala"
		_tmp86_ = serializable_property_enum_test_enumeration_values_get_values (_tmp85_);
#line 110 "SerializablePropertyEnumTest.vala"
		_tmp87_ = _tmp86_;
#line 110 "SerializablePropertyEnumTest.vala"
		_tmp88_ = gxml_serializable_enum_to_string ((GXmlSerializableEnum*) _tmp87_);
#line 110 "SerializablePropertyEnumTest.vala"
		_tmp89_ = _tmp88_;
#line 110 "SerializablePropertyEnumTest.vala"
		_tmp90_ = g_strconcat ("Actual value= ", _tmp89_, NULL);
#line 110 "SerializablePropertyEnumTest.vala"
		_tmp91_ = _tmp90_;
#line 110 "SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp91_);
#line 110 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp91_);
#line 110 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp89_);
#line 111 "SerializablePropertyEnumTest.vala"
		_tmp92_ = e;
#line 111 "SerializablePropertyEnumTest.vala"
		_tmp93_ = serializable_property_enum_test_enumeration_values_get_values (_tmp92_);
#line 111 "SerializablePropertyEnumTest.vala"
		_tmp94_ = _tmp93_;
#line 111 "SerializablePropertyEnumTest.vala"
		_tmp95_ = gxml_serializable_enum_to_string ((GXmlSerializableEnum*) _tmp94_);
#line 111 "SerializablePropertyEnumTest.vala"
		_tmp96_ = _tmp95_;
#line 111 "SerializablePropertyEnumTest.vala"
		_vala_assert (g_strcmp0 (_tmp96_, "SerTwo") == 0, "e.values.to_string () == \"SerTwo\"");
#line 111 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp96_);
#line 112 "SerializablePropertyEnumTest.vala"
		_tmp97_ = gxml_gdocument_new ();
#line 112 "SerializablePropertyEnumTest.vala"
		d3 = _tmp97_;
#line 113 "SerializablePropertyEnumTest.vala"
		_tmp98_ = e;
#line 113 "SerializablePropertyEnumTest.vala"
		_tmp99_ = d3;
#line 113 "SerializablePropertyEnumTest.vala"
		_tmp100_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp98_, (GXmlNode*) _tmp99_, &_inner_error0_);
#line 113 "SerializablePropertyEnumTest.vala"
		_tmp101_ = _tmp100_;
#line 113 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (_tmp101_);
#line 113 "SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 113 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d3);
#line 113 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee2);
#line 113 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element2);
#line 113 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 113 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (i1);
#line 113 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (s1);
#line 113 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee1);
#line 113 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element1);
#line 113 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (doc1);
#line 113 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1024 "SerializablePropertyEnumTest.c"
			goto __catch303_g_error;
		}
#line 114 "SerializablePropertyEnumTest.vala"
		_tmp102_ = d3;
#line 114 "SerializablePropertyEnumTest.vala"
		_tmp103_ = gxml_gnode_to_string ((GXmlGNode*) _tmp102_);
#line 114 "SerializablePropertyEnumTest.vala"
		_tmp104_ = _tmp103_;
#line 114 "SerializablePropertyEnumTest.vala"
		_tmp105_ = g_strconcat ("XML3:\n", _tmp104_, NULL);
#line 114 "SerializablePropertyEnumTest.vala"
		_tmp106_ = _tmp105_;
#line 114 "SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp106_);
#line 114 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp106_);
#line 114 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp104_);
#line 115 "SerializablePropertyEnumTest.vala"
		_tmp107_ = d3;
#line 115 "SerializablePropertyEnumTest.vala"
		_tmp108_ = gxml_document_get_root ((GXmlDocument*) _tmp107_);
#line 115 "SerializablePropertyEnumTest.vala"
		_tmp109_ = _tmp108_;
#line 115 "SerializablePropertyEnumTest.vala"
		_tmp110_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp109_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp109_) : NULL;
#line 115 "SerializablePropertyEnumTest.vala"
		if (_tmp110_ == NULL) {
#line 115 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (_tmp109_);
#line 1055 "SerializablePropertyEnumTest.c"
		}
#line 115 "SerializablePropertyEnumTest.vala"
		element3 = _tmp110_;
#line 116 "SerializablePropertyEnumTest.vala"
		_tmp111_ = element3;
#line 116 "SerializablePropertyEnumTest.vala"
		_tmp112_ = gxml_element_get_attr (_tmp111_, "values");
#line 116 "SerializablePropertyEnumTest.vala"
		ee3 = _tmp112_;
#line 117 "SerializablePropertyEnumTest.vala"
		_tmp113_ = ee3;
#line 117 "SerializablePropertyEnumTest.vala"
		_vala_assert (_tmp113_ != NULL, "ee3 != null");
#line 118 "SerializablePropertyEnumTest.vala"
		_tmp114_ = ee3;
#line 118 "SerializablePropertyEnumTest.vala"
		_tmp115_ = gxml_node_get_value (_tmp114_);
#line 118 "SerializablePropertyEnumTest.vala"
		_tmp116_ = _tmp115_;
#line 118 "SerializablePropertyEnumTest.vala"
		_tmp117_ = _tmp116_;
#line 118 "SerializablePropertyEnumTest.vala"
		_vala_assert (g_strcmp0 (_tmp117_, "SerTwo") == 0, "ee3.value == \"SerTwo\"");
#line 118 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp117_);
#line 120 "SerializablePropertyEnumTest.vala"
		_tmp118_ = e;
#line 120 "SerializablePropertyEnumTest.vala"
		_tmp119_ = serializable_property_enum_test_enumeration_values_get_values (_tmp118_);
#line 120 "SerializablePropertyEnumTest.vala"
		_tmp120_ = _tmp119_;
#line 120 "SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enum_set_string (_tmp120_, NULL, &_inner_error0_);
#line 120 "SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 120 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee3);
#line 120 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element3);
#line 120 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d3);
#line 120 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee2);
#line 120 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element2);
#line 120 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 120 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (i1);
#line 120 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (s1);
#line 120 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee1);
#line 120 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element1);
#line 120 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (doc1);
#line 120 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1115 "SerializablePropertyEnumTest.c"
			goto __catch303_g_error;
		}
#line 121 "SerializablePropertyEnumTest.vala"
		_tmp121_ = gxml_gdocument_new ();
#line 121 "SerializablePropertyEnumTest.vala"
		d4 = _tmp121_;
#line 122 "SerializablePropertyEnumTest.vala"
		_tmp122_ = e;
#line 122 "SerializablePropertyEnumTest.vala"
		_tmp123_ = d4;
#line 122 "SerializablePropertyEnumTest.vala"
		_tmp124_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp122_, (GXmlNode*) _tmp123_, &_inner_error0_);
#line 122 "SerializablePropertyEnumTest.vala"
		_tmp125_ = _tmp124_;
#line 122 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (_tmp125_);
#line 122 "SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 122 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d4);
#line 122 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee3);
#line 122 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element3);
#line 122 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d3);
#line 122 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee2);
#line 122 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element2);
#line 122 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 122 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (i1);
#line 122 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (s1);
#line 122 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (ee1);
#line 122 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (element1);
#line 122 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (doc1);
#line 122 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1160 "SerializablePropertyEnumTest.c"
			goto __catch303_g_error;
		}
#line 123 "SerializablePropertyEnumTest.vala"
		_tmp126_ = d4;
#line 123 "SerializablePropertyEnumTest.vala"
		_tmp127_ = gxml_gnode_to_string ((GXmlGNode*) _tmp126_);
#line 123 "SerializablePropertyEnumTest.vala"
		_tmp128_ = _tmp127_;
#line 123 "SerializablePropertyEnumTest.vala"
		_tmp129_ = g_strconcat ("XML4:\n", _tmp128_, NULL);
#line 123 "SerializablePropertyEnumTest.vala"
		_tmp130_ = _tmp129_;
#line 123 "SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp130_);
#line 123 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp130_);
#line 123 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp128_);
#line 124 "SerializablePropertyEnumTest.vala"
		_tmp131_ = d4;
#line 124 "SerializablePropertyEnumTest.vala"
		_tmp132_ = gxml_document_get_root ((GXmlDocument*) _tmp131_);
#line 124 "SerializablePropertyEnumTest.vala"
		_tmp133_ = _tmp132_;
#line 124 "SerializablePropertyEnumTest.vala"
		_tmp134_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp133_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp133_) : NULL;
#line 124 "SerializablePropertyEnumTest.vala"
		if (_tmp134_ == NULL) {
#line 124 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (_tmp133_);
#line 1191 "SerializablePropertyEnumTest.c"
		}
#line 124 "SerializablePropertyEnumTest.vala"
		element4 = _tmp134_;
#line 125 "SerializablePropertyEnumTest.vala"
		_tmp135_ = gxml_element_get_attr (element4, "values");
#line 125 "SerializablePropertyEnumTest.vala"
		ee4 = _tmp135_;
#line 126 "SerializablePropertyEnumTest.vala"
		_vala_assert (ee4 == NULL, "ee4 == null");
#line 78 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (ee4);
#line 78 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (element4);
#line 78 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (d4);
#line 78 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (ee3);
#line 78 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (element3);
#line 78 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (d3);
#line 78 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (ee2);
#line 78 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (element2);
#line 78 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (d2);
#line 78 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (i1);
#line 78 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (s1);
#line 78 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (ee1);
#line 78 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (element1);
#line 78 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (doc1);
#line 78 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (e);
#line 1231 "SerializablePropertyEnumTest.c"
	}
	goto __finally303;
	__catch303_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp136_;
		const gchar* _tmp137_;
		gchar* _tmp138_;
		gchar* _tmp139_;
#line 78 "SerializablePropertyEnumTest.vala"
		e = _inner_error0_;
#line 78 "SerializablePropertyEnumTest.vala"
		_inner_error0_ = NULL;
#line 128 "SerializablePropertyEnumTest.vala"
		_tmp136_ = e->message;
#line 128 "SerializablePropertyEnumTest.vala"
		_tmp137_ = string_to_string (_tmp136_);
#line 128 "SerializablePropertyEnumTest.vala"
		_tmp138_ = g_strconcat ("ERROR: ", _tmp137_, NULL);
#line 128 "SerializablePropertyEnumTest.vala"
		_tmp139_ = _tmp138_;
#line 128 "SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp139_);
#line 128 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp139_);
#line 129 "SerializablePropertyEnumTest.vala"
		g_assert_not_reached ();
#line 78 "SerializablePropertyEnumTest.vala"
		_g_error_free0 (e);
#line 1261 "SerializablePropertyEnumTest.c"
	}
	__finally303:
#line 78 "SerializablePropertyEnumTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 78 "SerializablePropertyEnumTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 78 "SerializablePropertyEnumTest.vala"
		g_clear_error (&_inner_error0_);
#line 78 "SerializablePropertyEnumTest.vala"
		return;
#line 1272 "SerializablePropertyEnumTest.c"
	}
}

static void
___lambda249__gtest_func (void)
{
#line 76 "SerializablePropertyEnumTest.vala"
	__lambda249_ ();
#line 1281 "SerializablePropertyEnumTest.c"
}

static void
__lambda250_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		SerializablePropertyEnumTestEnumerationValues* e = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp0_;
		SerializablePropertyEnumTestEnumerationValues* _tmp1_;
		SerializablePropertyEnumTestEnum* _tmp2_;
		SerializablePropertyEnumTestEnum* _tmp3_;
		SerializablePropertyEnumTestEnumerationValues* _tmp4_;
		SerializablePropertyEnumTestEnum* _tmp5_;
		SerializablePropertyEnumTestEnum* _tmp6_;
		SerializablePropertyEnumTestEnumValues _tmp7_ = 0;
		SerializablePropertyEnumTestEnumerationValues* _tmp8_;
		SerializablePropertyEnumTestEnum* _tmp9_;
		SerializablePropertyEnumTestEnum* _tmp10_;
#line 135 "SerializablePropertyEnumTest.vala"
		_tmp0_ = serializable_property_enum_test_enumeration_values_new ();
#line 135 "SerializablePropertyEnumTest.vala"
		e = _tmp0_;
#line 136 "SerializablePropertyEnumTest.vala"
		_tmp1_ = e;
#line 136 "SerializablePropertyEnumTest.vala"
		_tmp2_ = serializable_property_enum_test_enum_new ();
#line 136 "SerializablePropertyEnumTest.vala"
		_tmp3_ = _tmp2_;
#line 136 "SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enumeration_values_set_values (_tmp1_, _tmp3_);
#line 136 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (_tmp3_);
#line 137 "SerializablePropertyEnumTest.vala"
		_tmp4_ = e;
#line 137 "SerializablePropertyEnumTest.vala"
		_tmp5_ = serializable_property_enum_test_enumeration_values_get_values (_tmp4_);
#line 137 "SerializablePropertyEnumTest.vala"
		_tmp6_ = _tmp5_;
#line 137 "SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enum_set_string (_tmp6_, "SERONE", &_inner_error0_);
#line 137 "SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 137 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1327 "SerializablePropertyEnumTest.c"
			goto __catch305_g_error;
		}
#line 138 "SerializablePropertyEnumTest.vala"
		_tmp8_ = e;
#line 138 "SerializablePropertyEnumTest.vala"
		_tmp9_ = serializable_property_enum_test_enumeration_values_get_values (_tmp8_);
#line 138 "SerializablePropertyEnumTest.vala"
		_tmp10_ = _tmp9_;
#line 138 "SerializablePropertyEnumTest.vala"
		_tmp7_ = serializable_property_enum_test_enum_get_value (_tmp10_, &_inner_error0_);
#line 138 "SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 138 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1342 "SerializablePropertyEnumTest.c"
			goto __catch305_g_error;
		}
#line 138 "SerializablePropertyEnumTest.vala"
		_vala_assert (_tmp7_ == SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_ONE, "e.values.get_value () == Enum.Values.SER_ONE");
#line 134 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (e);
#line 1349 "SerializablePropertyEnumTest.c"
	}
	goto __finally305;
	__catch305_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp11_;
		const gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
#line 134 "SerializablePropertyEnumTest.vala"
		e = _inner_error0_;
#line 134 "SerializablePropertyEnumTest.vala"
		_inner_error0_ = NULL;
#line 140 "SerializablePropertyEnumTest.vala"
		_tmp11_ = e->message;
#line 140 "SerializablePropertyEnumTest.vala"
		_tmp12_ = string_to_string (_tmp11_);
#line 140 "SerializablePropertyEnumTest.vala"
		_tmp13_ = g_strconcat ("ERROR: ", _tmp12_, NULL);
#line 140 "SerializablePropertyEnumTest.vala"
		_tmp14_ = _tmp13_;
#line 140 "SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp14_);
#line 140 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp14_);
#line 141 "SerializablePropertyEnumTest.vala"
		g_assert_not_reached ();
#line 134 "SerializablePropertyEnumTest.vala"
		_g_error_free0 (e);
#line 1379 "SerializablePropertyEnumTest.c"
	}
	__finally305:
#line 134 "SerializablePropertyEnumTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 134 "SerializablePropertyEnumTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 134 "SerializablePropertyEnumTest.vala"
		g_clear_error (&_inner_error0_);
#line 134 "SerializablePropertyEnumTest.vala"
		return;
#line 1390 "SerializablePropertyEnumTest.c"
	}
}

static void
___lambda250__gtest_func (void)
{
#line 132 "SerializablePropertyEnumTest.vala"
	__lambda250_ ();
#line 1399 "SerializablePropertyEnumTest.c"
}

static void
__lambda251_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		SerializablePropertyEnumTestEnumerationValues* e = NULL;
		SerializablePropertyEnumTestEnumerationValues* _tmp0_;
		SerializablePropertyEnumTestEnumerationValues* _tmp1_;
		SerializablePropertyEnumTestEnum* _tmp2_;
		SerializablePropertyEnumTestEnum* _tmp3_;
		SerializablePropertyEnumTestEnumerationValues* _tmp4_;
		SerializablePropertyEnumTestEnum* _tmp5_;
		SerializablePropertyEnumTestEnum* _tmp6_;
		GXmlGDocument* d1 = NULL;
		GXmlGDocument* _tmp7_;
		SerializablePropertyEnumTestEnumerationValues* _tmp8_;
		GXmlGDocument* _tmp9_;
		GXmlNode* _tmp10_;
		GXmlNode* _tmp11_;
		GXmlGDocument* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		gchar* _tmp16_;
		GXmlGDocument* d2 = NULL;
		GXmlGDocument* _tmp17_;
		SerializablePropertyEnumTestEnumerationValues* _tmp18_;
		GXmlGDocument* _tmp19_;
		SerializablePropertyEnumTestEnumValues _tmp20_ = 0;
		SerializablePropertyEnumTestEnumerationValues* _tmp21_;
		SerializablePropertyEnumTestEnum* _tmp22_;
		SerializablePropertyEnumTestEnum* _tmp23_;
		GXmlGDocument* d3 = NULL;
		GXmlGDocument* _tmp24_;
		SerializablePropertyEnumTestEnumerationValues* _tmp25_;
		GXmlGDocument* _tmp26_;
		GXmlNode* _tmp27_;
		GXmlNode* _tmp28_;
		GXmlGDocument* _tmp29_;
		gchar* _tmp30_;
		gchar* _tmp31_;
		gchar* _tmp32_;
		gchar* _tmp33_;
		GXmlGDocument* d4 = NULL;
		GXmlGDocument* _tmp34_;
		SerializablePropertyEnumTestEnumerationValues* _tmp35_;
		GXmlGDocument* _tmp36_;
		SerializablePropertyEnumTestEnumValues _tmp37_ = 0;
		SerializablePropertyEnumTestEnumerationValues* _tmp38_;
		SerializablePropertyEnumTestEnum* _tmp39_;
		SerializablePropertyEnumTestEnum* _tmp40_;
		GXmlGDocument* d5 = NULL;
		GXmlGDocument* _tmp41_;
		SerializablePropertyEnumTestEnumerationValues* _tmp42_;
		GXmlGDocument* _tmp43_;
		GXmlNode* _tmp44_;
		GXmlNode* _tmp45_;
		GXmlGDocument* _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
		gchar* _tmp49_;
		gchar* _tmp50_;
#line 147 "SerializablePropertyEnumTest.vala"
		_tmp0_ = serializable_property_enum_test_enumeration_values_new ();
#line 147 "SerializablePropertyEnumTest.vala"
		e = _tmp0_;
#line 148 "SerializablePropertyEnumTest.vala"
		_tmp1_ = e;
#line 148 "SerializablePropertyEnumTest.vala"
		_tmp2_ = serializable_property_enum_test_enum_new ();
#line 148 "SerializablePropertyEnumTest.vala"
		_tmp3_ = _tmp2_;
#line 148 "SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enumeration_values_set_values (_tmp1_, _tmp3_);
#line 148 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (_tmp3_);
#line 149 "SerializablePropertyEnumTest.vala"
		_tmp4_ = e;
#line 149 "SerializablePropertyEnumTest.vala"
		_tmp5_ = serializable_property_enum_test_enumeration_values_get_values (_tmp4_);
#line 149 "SerializablePropertyEnumTest.vala"
		_tmp6_ = _tmp5_;
#line 149 "SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enum_set_value (_tmp6_, SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_AP, &_inner_error0_);
#line 149 "SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 149 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1490 "SerializablePropertyEnumTest.c"
			goto __catch306_g_error;
		}
#line 150 "SerializablePropertyEnumTest.vala"
		_tmp7_ = gxml_gdocument_new ();
#line 150 "SerializablePropertyEnumTest.vala"
		d1 = _tmp7_;
#line 151 "SerializablePropertyEnumTest.vala"
		_tmp8_ = e;
#line 151 "SerializablePropertyEnumTest.vala"
		_tmp9_ = d1;
#line 151 "SerializablePropertyEnumTest.vala"
		_tmp10_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp8_, (GXmlNode*) _tmp9_, &_inner_error0_);
#line 151 "SerializablePropertyEnumTest.vala"
		_tmp11_ = _tmp10_;
#line 151 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (_tmp11_);
#line 151 "SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 151 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d1);
#line 151 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1513 "SerializablePropertyEnumTest.c"
			goto __catch306_g_error;
		}
#line 152 "SerializablePropertyEnumTest.vala"
		_tmp12_ = d1;
#line 152 "SerializablePropertyEnumTest.vala"
		_tmp13_ = gxml_gnode_to_string ((GXmlGNode*) _tmp12_);
#line 152 "SerializablePropertyEnumTest.vala"
		_tmp14_ = _tmp13_;
#line 152 "SerializablePropertyEnumTest.vala"
		_tmp15_ = g_strconcat ("XML1: ", _tmp14_, NULL);
#line 152 "SerializablePropertyEnumTest.vala"
		_tmp16_ = _tmp15_;
#line 152 "SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp16_);
#line 152 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp16_);
#line 152 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp14_);
#line 153 "SerializablePropertyEnumTest.vala"
		_tmp17_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <Enum optionalvalues=\"SerExtension\"/>", 0, &_inner_error0_);
#line 153 "SerializablePropertyEnumTest.vala"
		d2 = _tmp17_;
#line 153 "SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 153 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d1);
#line 153 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1542 "SerializablePropertyEnumTest.c"
			goto __catch306_g_error;
		}
#line 155 "SerializablePropertyEnumTest.vala"
		_tmp18_ = e;
#line 155 "SerializablePropertyEnumTest.vala"
		_tmp19_ = d2;
#line 155 "SerializablePropertyEnumTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp18_, (GXmlNode*) _tmp19_, &_inner_error0_);
#line 155 "SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 155 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 155 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d1);
#line 155 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1559 "SerializablePropertyEnumTest.c"
			goto __catch306_g_error;
		}
#line 156 "SerializablePropertyEnumTest.vala"
		_tmp21_ = e;
#line 156 "SerializablePropertyEnumTest.vala"
		_tmp22_ = serializable_property_enum_test_enumeration_values_get_optional_values (_tmp21_);
#line 156 "SerializablePropertyEnumTest.vala"
		_tmp23_ = _tmp22_;
#line 156 "SerializablePropertyEnumTest.vala"
		_tmp20_ = serializable_property_enum_test_enum_get_value (_tmp23_, &_inner_error0_);
#line 156 "SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 156 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 156 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d1);
#line 156 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1578 "SerializablePropertyEnumTest.c"
			goto __catch306_g_error;
		}
#line 156 "SerializablePropertyEnumTest.vala"
		_vala_assert (_tmp20_ == SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_EXTENSION, "e.optional_values.get_value () == Enum.Values.SER_EXTENSION");
#line 157 "SerializablePropertyEnumTest.vala"
		_tmp24_ = gxml_gdocument_new ();
#line 157 "SerializablePropertyEnumTest.vala"
		d3 = _tmp24_;
#line 158 "SerializablePropertyEnumTest.vala"
		_tmp25_ = e;
#line 158 "SerializablePropertyEnumTest.vala"
		_tmp26_ = d3;
#line 158 "SerializablePropertyEnumTest.vala"
		_tmp27_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp25_, (GXmlNode*) _tmp26_, &_inner_error0_);
#line 158 "SerializablePropertyEnumTest.vala"
		_tmp28_ = _tmp27_;
#line 158 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (_tmp28_);
#line 158 "SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 158 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d3);
#line 158 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 158 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d1);
#line 158 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1607 "SerializablePropertyEnumTest.c"
			goto __catch306_g_error;
		}
#line 159 "SerializablePropertyEnumTest.vala"
		_tmp29_ = d3;
#line 159 "SerializablePropertyEnumTest.vala"
		_tmp30_ = gxml_gnode_to_string ((GXmlGNode*) _tmp29_);
#line 159 "SerializablePropertyEnumTest.vala"
		_tmp31_ = _tmp30_;
#line 159 "SerializablePropertyEnumTest.vala"
		_tmp32_ = g_strconcat ("XML2: ", _tmp31_, NULL);
#line 159 "SerializablePropertyEnumTest.vala"
		_tmp33_ = _tmp32_;
#line 159 "SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp33_);
#line 159 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp33_);
#line 159 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp31_);
#line 160 "SerializablePropertyEnumTest.vala"
		_tmp34_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <Enum OPTIONALVALUES=\"SERTHREE\"/>", 0, &_inner_error0_);
#line 160 "SerializablePropertyEnumTest.vala"
		d4 = _tmp34_;
#line 160 "SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 160 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d3);
#line 160 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 160 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d1);
#line 160 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1640 "SerializablePropertyEnumTest.c"
			goto __catch306_g_error;
		}
#line 162 "SerializablePropertyEnumTest.vala"
		_tmp35_ = e;
#line 162 "SerializablePropertyEnumTest.vala"
		_tmp36_ = d4;
#line 162 "SerializablePropertyEnumTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp35_, (GXmlNode*) _tmp36_, &_inner_error0_);
#line 162 "SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 162 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d4);
#line 162 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d3);
#line 162 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 162 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d1);
#line 162 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1661 "SerializablePropertyEnumTest.c"
			goto __catch306_g_error;
		}
#line 163 "SerializablePropertyEnumTest.vala"
		_tmp38_ = e;
#line 163 "SerializablePropertyEnumTest.vala"
		_tmp39_ = serializable_property_enum_test_enumeration_values_get_optional_values (_tmp38_);
#line 163 "SerializablePropertyEnumTest.vala"
		_tmp40_ = _tmp39_;
#line 163 "SerializablePropertyEnumTest.vala"
		_tmp37_ = serializable_property_enum_test_enum_get_value (_tmp40_, &_inner_error0_);
#line 163 "SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 163 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d4);
#line 163 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d3);
#line 163 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 163 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d1);
#line 163 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1684 "SerializablePropertyEnumTest.c"
			goto __catch306_g_error;
		}
#line 163 "SerializablePropertyEnumTest.vala"
		_vala_assert (_tmp37_ == SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_THREE, "e.optional_values.get_value () == Enum.Values.SER_THREE");
#line 164 "SerializablePropertyEnumTest.vala"
		_tmp41_ = gxml_gdocument_new ();
#line 164 "SerializablePropertyEnumTest.vala"
		d5 = _tmp41_;
#line 165 "SerializablePropertyEnumTest.vala"
		_tmp42_ = e;
#line 165 "SerializablePropertyEnumTest.vala"
		_tmp43_ = d5;
#line 165 "SerializablePropertyEnumTest.vala"
		_tmp44_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp42_, (GXmlNode*) _tmp43_, &_inner_error0_);
#line 165 "SerializablePropertyEnumTest.vala"
		_tmp45_ = _tmp44_;
#line 165 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (_tmp45_);
#line 165 "SerializablePropertyEnumTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 165 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d5);
#line 165 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d4);
#line 165 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d3);
#line 165 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d2);
#line 165 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (d1);
#line 165 "SerializablePropertyEnumTest.vala"
			_g_object_unref0 (e);
#line 1717 "SerializablePropertyEnumTest.c"
			goto __catch306_g_error;
		}
#line 166 "SerializablePropertyEnumTest.vala"
		_tmp46_ = d5;
#line 166 "SerializablePropertyEnumTest.vala"
		_tmp47_ = gxml_gnode_to_string ((GXmlGNode*) _tmp46_);
#line 166 "SerializablePropertyEnumTest.vala"
		_tmp48_ = _tmp47_;
#line 166 "SerializablePropertyEnumTest.vala"
		_tmp49_ = g_strconcat ("XML3: ", _tmp48_, NULL);
#line 166 "SerializablePropertyEnumTest.vala"
		_tmp50_ = _tmp49_;
#line 166 "SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp50_);
#line 166 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp50_);
#line 166 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp48_);
#line 146 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (d5);
#line 146 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (d4);
#line 146 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (d3);
#line 146 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (d2);
#line 146 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (d1);
#line 146 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (e);
#line 1748 "SerializablePropertyEnumTest.c"
	}
	goto __finally306;
	__catch306_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp51_;
		const gchar* _tmp52_;
		gchar* _tmp53_;
		gchar* _tmp54_;
#line 146 "SerializablePropertyEnumTest.vala"
		e = _inner_error0_;
#line 146 "SerializablePropertyEnumTest.vala"
		_inner_error0_ = NULL;
#line 168 "SerializablePropertyEnumTest.vala"
		_tmp51_ = e->message;
#line 168 "SerializablePropertyEnumTest.vala"
		_tmp52_ = string_to_string (_tmp51_);
#line 168 "SerializablePropertyEnumTest.vala"
		_tmp53_ = g_strconcat ("ERROR: ", _tmp52_, NULL);
#line 168 "SerializablePropertyEnumTest.vala"
		_tmp54_ = _tmp53_;
#line 168 "SerializablePropertyEnumTest.vala"
		g_test_message ("%s", _tmp54_);
#line 168 "SerializablePropertyEnumTest.vala"
		_g_free0 (_tmp54_);
#line 169 "SerializablePropertyEnumTest.vala"
		g_assert_not_reached ();
#line 146 "SerializablePropertyEnumTest.vala"
		_g_error_free0 (e);
#line 1778 "SerializablePropertyEnumTest.c"
	}
	__finally306:
#line 146 "SerializablePropertyEnumTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 146 "SerializablePropertyEnumTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 146 "SerializablePropertyEnumTest.vala"
		g_clear_error (&_inner_error0_);
#line 146 "SerializablePropertyEnumTest.vala"
		return;
#line 1789 "SerializablePropertyEnumTest.c"
	}
}

static void
___lambda251__gtest_func (void)
{
#line 144 "SerializablePropertyEnumTest.vala"
	__lambda251_ ();
#line 1798 "SerializablePropertyEnumTest.c"
}

void
serializable_property_enum_test_add_tests (void)
{
#line 57 "SerializablePropertyEnumTest.vala"
	g_test_add_func ("/gxml/serializable/Enum/basic", ___lambda248__gtest_func);
#line 76 "SerializablePropertyEnumTest.vala"
	g_test_add_func ("/gxml/serializable/Enum/changes", ___lambda249__gtest_func);
#line 132 "SerializablePropertyEnumTest.vala"
	g_test_add_func ("/gxml/serializable/Enum/string", ___lambda250__gtest_func);
#line 144 "SerializablePropertyEnumTest.vala"
	g_test_add_func ("/gxml/serializable/Enum/property_name", ___lambda251__gtest_func);
#line 1812 "SerializablePropertyEnumTest.c"
}

SerializablePropertyEnumTest*
serializable_property_enum_test_construct (GType object_type)
{
	SerializablePropertyEnumTest* self = NULL;
#line 27 "SerializablePropertyEnumTest.vala"
	self = (SerializablePropertyEnumTest*) gxml_test_construct (object_type);
#line 27 "SerializablePropertyEnumTest.vala"
	return self;
#line 1823 "SerializablePropertyEnumTest.c"
}

SerializablePropertyEnumTest*
serializable_property_enum_test_new (void)
{
#line 27 "SerializablePropertyEnumTest.vala"
	return serializable_property_enum_test_construct (TYPE_SERIALIZABLE_PROPERTY_ENUM_TEST);
#line 1831 "SerializablePropertyEnumTest.c"
}

GType
serializable_property_enum_test_enum_values_get_type (void)
{
	static volatile gsize serializable_property_enum_test_enum_values_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_property_enum_test_enum_values_type_id__volatile)) {
		static const GEnumValue values[] = {{SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_ONE, "SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_ONE", "ser-one"}, {SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_TWO, "SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_TWO", "ser-two"}, {SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_THREE, "SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_THREE", "ser-three"}, {SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_AP, "SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_AP", "ap"}, {SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_EXTENSION, "SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_VALUES_SER_EXTENSION", "ser-extension"}, {0, NULL, NULL}};
		GType serializable_property_enum_test_enum_values_type_id;
		serializable_property_enum_test_enum_values_type_id = g_enum_register_static ("SerializablePropertyEnumTestEnumValues", values);
		g_once_init_leave (&serializable_property_enum_test_enum_values_type_id__volatile, serializable_property_enum_test_enum_values_type_id);
	}
	return serializable_property_enum_test_enum_values_type_id__volatile;
}

SerializablePropertyEnumTestEnumValues
serializable_property_enum_test_enum_get_value (SerializablePropertyEnumTestEnum* self,
                                                GError** error)
{
	SerializablePropertyEnumTestEnumValues result = 0;
	gint _tmp0_ = 0;
	GError* _inner_error0_ = NULL;
#line 33 "SerializablePropertyEnumTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 33 "SerializablePropertyEnumTest.vala"
	_tmp0_ = gxml_serializable_enum_to_integer ((GXmlSerializableEnum*) self, &_inner_error0_);
#line 33 "SerializablePropertyEnumTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 33 "SerializablePropertyEnumTest.vala"
		g_propagate_error (error, _inner_error0_);
#line 33 "SerializablePropertyEnumTest.vala"
		return 0;
#line 1864 "SerializablePropertyEnumTest.c"
	}
#line 33 "SerializablePropertyEnumTest.vala"
	result = (SerializablePropertyEnumTestEnumValues) _tmp0_;
#line 33 "SerializablePropertyEnumTest.vala"
	return result;
#line 1870 "SerializablePropertyEnumTest.c"
}

void
serializable_property_enum_test_enum_set_value (SerializablePropertyEnumTestEnum* self,
                                                SerializablePropertyEnumTestEnumValues val,
                                                GError** error)
{
	GError* _inner_error0_ = NULL;
#line 34 "SerializablePropertyEnumTest.vala"
	g_return_if_fail (self != NULL);
#line 34 "SerializablePropertyEnumTest.vala"
	gxml_serializable_enum_parse_integer ((GXmlSerializableEnum*) self, (gint) val, &_inner_error0_);
#line 34 "SerializablePropertyEnumTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 34 "SerializablePropertyEnumTest.vala"
		g_propagate_error (error, _inner_error0_);
#line 34 "SerializablePropertyEnumTest.vala"
		return;
#line 1889 "SerializablePropertyEnumTest.c"
	}
}

void
serializable_property_enum_test_enum_set_string (SerializablePropertyEnumTestEnum* self,
                                                 const gchar* str,
                                                 GError** error)
{
#line 36 "SerializablePropertyEnumTest.vala"
	g_return_if_fail (self != NULL);
#line 36 "SerializablePropertyEnumTest.vala"
	gxml_serializable_property_set_serializable_property_value ((GXmlSerializableProperty*) self, str);
#line 1902 "SerializablePropertyEnumTest.c"
}

SerializablePropertyEnumTestEnum*
serializable_property_enum_test_enum_construct (GType object_type)
{
	SerializablePropertyEnumTestEnum * self = NULL;
#line 28 "SerializablePropertyEnumTest.vala"
	self = (SerializablePropertyEnumTestEnum*) gxml_serializable_enum_construct (object_type);
#line 28 "SerializablePropertyEnumTest.vala"
	return self;
#line 1913 "SerializablePropertyEnumTest.c"
}

SerializablePropertyEnumTestEnum*
serializable_property_enum_test_enum_new (void)
{
#line 28 "SerializablePropertyEnumTest.vala"
	return serializable_property_enum_test_enum_construct (SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUM);
#line 1921 "SerializablePropertyEnumTest.c"
}

static GObject *
serializable_property_enum_test_enum_constructor (GType type,
                                                  guint n_construct_properties,
                                                  GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	SerializablePropertyEnumTestEnum * self;
#line 30 "SerializablePropertyEnumTest.vala"
	parent_class = G_OBJECT_CLASS (serializable_property_enum_test_enum_parent_class);
#line 30 "SerializablePropertyEnumTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 30 "SerializablePropertyEnumTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUM, SerializablePropertyEnumTestEnum);
#line 31 "SerializablePropertyEnumTest.vala"
	((GXmlSerializableEnum*) self)->_enumtype = SERIALIZABLE_PROPERTY_ENUM_TEST_ENUM_TYPE_VALUES;
#line 30 "SerializablePropertyEnumTest.vala"
	return obj;
#line 1942 "SerializablePropertyEnumTest.c"
}

static void
serializable_property_enum_test_enum_class_init (SerializablePropertyEnumTestEnumClass * klass,
                                                 gpointer klass_data)
{
#line 28 "SerializablePropertyEnumTest.vala"
	serializable_property_enum_test_enum_parent_class = g_type_class_peek_parent (klass);
#line 28 "SerializablePropertyEnumTest.vala"
	G_OBJECT_CLASS (klass)->constructor = serializable_property_enum_test_enum_constructor;
#line 1953 "SerializablePropertyEnumTest.c"
}

static void
serializable_property_enum_test_enum_instance_init (SerializablePropertyEnumTestEnum * self,
                                                    gpointer klass)
{
}

GType
serializable_property_enum_test_enum_get_type (void)
{
	static volatile gsize serializable_property_enum_test_enum_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_property_enum_test_enum_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializablePropertyEnumTestEnumClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_property_enum_test_enum_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializablePropertyEnumTestEnum), 0, (GInstanceInitFunc) serializable_property_enum_test_enum_instance_init, NULL };
		GType serializable_property_enum_test_enum_type_id;
		serializable_property_enum_test_enum_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_ENUM, "SerializablePropertyEnumTestEnum", &g_define_type_info, 0);
		g_once_init_leave (&serializable_property_enum_test_enum_type_id__volatile, serializable_property_enum_test_enum_type_id);
	}
	return serializable_property_enum_test_enum_type_id__volatile;
}

static inline gpointer
serializable_property_enum_test_enumeration_values_get_instance_private (SerializablePropertyEnumTestEnumerationValues* self)
{
	return G_STRUCT_MEMBER_P (self, SerializablePropertyEnumTestEnumerationValues_private_offset);
}

static gchar*
serializable_property_enum_test_enumeration_values_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializablePropertyEnumTestEnumerationValues * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 52 "SerializablePropertyEnumTest.vala"
	self = (SerializablePropertyEnumTestEnumerationValues*) base;
#line 52 "SerializablePropertyEnumTest.vala"
	_tmp0_ = g_strdup ("Enum");
#line 52 "SerializablePropertyEnumTest.vala"
	result = _tmp0_;
#line 52 "SerializablePropertyEnumTest.vala"
	return result;
#line 1995 "SerializablePropertyEnumTest.c"
}

static gchar*
serializable_property_enum_test_enumeration_values_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializablePropertyEnumTestEnumerationValues * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 53 "SerializablePropertyEnumTest.vala"
	self = (SerializablePropertyEnumTestEnumerationValues*) base;
#line 53 "SerializablePropertyEnumTest.vala"
	_tmp0_ = g_type_name (G_TYPE_FROM_INSTANCE ((GObject*) self));
#line 53 "SerializablePropertyEnumTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 53 "SerializablePropertyEnumTest.vala"
	result = _tmp1_;
#line 53 "SerializablePropertyEnumTest.vala"
	return result;
#line 2015 "SerializablePropertyEnumTest.c"
}

static gboolean
serializable_property_enum_test_enumeration_values_real_property_use_nick (GXmlSerializableObjectModel* base)
{
	SerializablePropertyEnumTestEnumerationValues * self;
	gboolean result = FALSE;
#line 54 "SerializablePropertyEnumTest.vala"
	self = (SerializablePropertyEnumTestEnumerationValues*) base;
#line 54 "SerializablePropertyEnumTest.vala"
	result = TRUE;
#line 54 "SerializablePropertyEnumTest.vala"
	return result;
#line 2029 "SerializablePropertyEnumTest.c"
}

SerializablePropertyEnumTestEnumerationValues*
serializable_property_enum_test_enumeration_values_construct (GType object_type)
{
	SerializablePropertyEnumTestEnumerationValues * self = NULL;
#line 45 "SerializablePropertyEnumTest.vala"
	self = (SerializablePropertyEnumTestEnumerationValues*) gxml_serializable_object_model_construct (object_type);
#line 45 "SerializablePropertyEnumTest.vala"
	return self;
#line 2040 "SerializablePropertyEnumTest.c"
}

SerializablePropertyEnumTestEnumerationValues*
serializable_property_enum_test_enumeration_values_new (void)
{
#line 45 "SerializablePropertyEnumTest.vala"
	return serializable_property_enum_test_enumeration_values_construct (SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUMERATION_VALUES);
#line 2048 "SerializablePropertyEnumTest.c"
}

SerializablePropertyEnumTestEnum*
serializable_property_enum_test_enumeration_values_get_values (SerializablePropertyEnumTestEnumerationValues* self)
{
	SerializablePropertyEnumTestEnum* result;
	SerializablePropertyEnumTestEnum* _tmp0_;
#line 47 "SerializablePropertyEnumTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 47 "SerializablePropertyEnumTest.vala"
	_tmp0_ = self->priv->_values;
#line 47 "SerializablePropertyEnumTest.vala"
	result = _tmp0_;
#line 47 "SerializablePropertyEnumTest.vala"
	return result;
#line 2064 "SerializablePropertyEnumTest.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 47 "SerializablePropertyEnumTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 2072 "SerializablePropertyEnumTest.c"
}

void
serializable_property_enum_test_enumeration_values_set_values (SerializablePropertyEnumTestEnumerationValues* self,
                                                               SerializablePropertyEnumTestEnum* value)
{
#line 47 "SerializablePropertyEnumTest.vala"
	g_return_if_fail (self != NULL);
#line 47 "SerializablePropertyEnumTest.vala"
	if (serializable_property_enum_test_enumeration_values_get_values (self) != value) {
#line 2083 "SerializablePropertyEnumTest.c"
		SerializablePropertyEnumTestEnum* _tmp0_;
#line 47 "SerializablePropertyEnumTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 47 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (self->priv->_values);
#line 47 "SerializablePropertyEnumTest.vala"
		self->priv->_values = _tmp0_;
#line 47 "SerializablePropertyEnumTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_property_enum_test_enumeration_values_properties[SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_VALUES_PROPERTY]);
#line 2093 "SerializablePropertyEnumTest.c"
	}
}

SerializablePropertyEnumTestEnum*
serializable_property_enum_test_enumeration_values_get_optional_values (SerializablePropertyEnumTestEnumerationValues* self)
{
	SerializablePropertyEnumTestEnum* result;
	SerializablePropertyEnumTestEnum* _tmp0_;
#line 49 "SerializablePropertyEnumTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 49 "SerializablePropertyEnumTest.vala"
	_tmp0_ = self->priv->_optional_values;
#line 49 "SerializablePropertyEnumTest.vala"
	result = _tmp0_;
#line 49 "SerializablePropertyEnumTest.vala"
	return result;
#line 2110 "SerializablePropertyEnumTest.c"
}

void
serializable_property_enum_test_enumeration_values_set_optional_values (SerializablePropertyEnumTestEnumerationValues* self,
                                                                        SerializablePropertyEnumTestEnum* value)
{
#line 49 "SerializablePropertyEnumTest.vala"
	g_return_if_fail (self != NULL);
#line 49 "SerializablePropertyEnumTest.vala"
	if (serializable_property_enum_test_enumeration_values_get_optional_values (self) != value) {
#line 2121 "SerializablePropertyEnumTest.c"
		SerializablePropertyEnumTestEnum* _tmp0_;
#line 49 "SerializablePropertyEnumTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 49 "SerializablePropertyEnumTest.vala"
		_g_object_unref0 (self->priv->_optional_values);
#line 49 "SerializablePropertyEnumTest.vala"
		self->priv->_optional_values = _tmp0_;
#line 49 "SerializablePropertyEnumTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_property_enum_test_enumeration_values_properties[SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_OPTIONAL_VALUES_PROPERTY]);
#line 2131 "SerializablePropertyEnumTest.c"
	}
}

gint
serializable_property_enum_test_enumeration_values_get_integer (SerializablePropertyEnumTestEnumerationValues* self)
{
	gint result;
#line 50 "SerializablePropertyEnumTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 50 "SerializablePropertyEnumTest.vala"
	result = self->priv->_integer;
#line 50 "SerializablePropertyEnumTest.vala"
	return result;
#line 2145 "SerializablePropertyEnumTest.c"
}

void
serializable_property_enum_test_enumeration_values_set_integer (SerializablePropertyEnumTestEnumerationValues* self,
                                                                gint value)
{
#line 50 "SerializablePropertyEnumTest.vala"
	g_return_if_fail (self != NULL);
#line 50 "SerializablePropertyEnumTest.vala"
	if (serializable_property_enum_test_enumeration_values_get_integer (self) != value) {
#line 50 "SerializablePropertyEnumTest.vala"
		self->priv->_integer = value;
#line 50 "SerializablePropertyEnumTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_property_enum_test_enumeration_values_properties[SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_INTEGER_PROPERTY]);
#line 2160 "SerializablePropertyEnumTest.c"
	}
}

const gchar*
serializable_property_enum_test_enumeration_values_get_name (SerializablePropertyEnumTestEnumerationValues* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 51 "SerializablePropertyEnumTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 51 "SerializablePropertyEnumTest.vala"
	_tmp0_ = self->priv->_name;
#line 51 "SerializablePropertyEnumTest.vala"
	result = _tmp0_;
#line 51 "SerializablePropertyEnumTest.vala"
	return result;
#line 2177 "SerializablePropertyEnumTest.c"
}

void
serializable_property_enum_test_enumeration_values_set_name (SerializablePropertyEnumTestEnumerationValues* self,
                                                             const gchar* value)
{
#line 51 "SerializablePropertyEnumTest.vala"
	g_return_if_fail (self != NULL);
#line 51 "SerializablePropertyEnumTest.vala"
	if (g_strcmp0 (value, serializable_property_enum_test_enumeration_values_get_name (self)) != 0) {
#line 2188 "SerializablePropertyEnumTest.c"
		gchar* _tmp0_;
#line 51 "SerializablePropertyEnumTest.vala"
		_tmp0_ = g_strdup (value);
#line 51 "SerializablePropertyEnumTest.vala"
		_g_free0 (self->priv->_name);
#line 51 "SerializablePropertyEnumTest.vala"
		self->priv->_name = _tmp0_;
#line 51 "SerializablePropertyEnumTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_property_enum_test_enumeration_values_properties[SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_NAME_PROPERTY]);
#line 2198 "SerializablePropertyEnumTest.c"
	}
}

static void
serializable_property_enum_test_enumeration_values_class_init (SerializablePropertyEnumTestEnumerationValuesClass * klass,
                                                               gpointer klass_data)
{
#line 45 "SerializablePropertyEnumTest.vala"
	serializable_property_enum_test_enumeration_values_parent_class = g_type_class_peek_parent (klass);
#line 45 "SerializablePropertyEnumTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializablePropertyEnumTestEnumerationValues_private_offset);
#line 45 "SerializablePropertyEnumTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_property_enum_test_enumeration_values_real_node_name;
#line 45 "SerializablePropertyEnumTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_property_enum_test_enumeration_values_real_to_string;
#line 45 "SerializablePropertyEnumTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->property_use_nick = (gboolean (*) (GXmlSerializableObjectModel*)) serializable_property_enum_test_enumeration_values_real_property_use_nick;
#line 45 "SerializablePropertyEnumTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_property_enum_test_enumeration_values_get_property;
#line 45 "SerializablePropertyEnumTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_property_enum_test_enumeration_values_set_property;
#line 45 "SerializablePropertyEnumTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_property_enum_test_enumeration_values_finalize;
#line 45 "SerializablePropertyEnumTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_VALUES_PROPERTY, serializable_property_enum_test_enumeration_values_properties[SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_VALUES_PROPERTY] = g_param_spec_object ("values", "values", "values", SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUM, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 45 "SerializablePropertyEnumTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_OPTIONAL_VALUES_PROPERTY, serializable_property_enum_test_enumeration_values_properties[SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_OPTIONAL_VALUES_PROPERTY] = g_param_spec_object ("optional-values", "OptionalValues", "Optional values", SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUM, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 45 "SerializablePropertyEnumTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_INTEGER_PROPERTY, serializable_property_enum_test_enumeration_values_properties[SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_INTEGER_PROPERTY] = g_param_spec_int ("integer", "integer", "integer", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 45 "SerializablePropertyEnumTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_NAME_PROPERTY, serializable_property_enum_test_enumeration_values_properties[SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2230 "SerializablePropertyEnumTest.c"
}

static void
serializable_property_enum_test_enumeration_values_instance_init (SerializablePropertyEnumTestEnumerationValues * self,
                                                                  gpointer klass)
{
#line 45 "SerializablePropertyEnumTest.vala"
	self->priv = serializable_property_enum_test_enumeration_values_get_instance_private (self);
#line 50 "SerializablePropertyEnumTest.vala"
	self->priv->_integer = 0;
#line 2241 "SerializablePropertyEnumTest.c"
}

static void
serializable_property_enum_test_enumeration_values_finalize (GObject * obj)
{
	SerializablePropertyEnumTestEnumerationValues * self;
#line 45 "SerializablePropertyEnumTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUMERATION_VALUES, SerializablePropertyEnumTestEnumerationValues);
#line 47 "SerializablePropertyEnumTest.vala"
	_g_object_unref0 (self->priv->_values);
#line 49 "SerializablePropertyEnumTest.vala"
	_g_object_unref0 (self->priv->_optional_values);
#line 51 "SerializablePropertyEnumTest.vala"
	_g_free0 (self->priv->_name);
#line 45 "SerializablePropertyEnumTest.vala"
	G_OBJECT_CLASS (serializable_property_enum_test_enumeration_values_parent_class)->finalize (obj);
#line 2258 "SerializablePropertyEnumTest.c"
}

GType
serializable_property_enum_test_enumeration_values_get_type (void)
{
	static volatile gsize serializable_property_enum_test_enumeration_values_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_property_enum_test_enumeration_values_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializablePropertyEnumTestEnumerationValuesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_property_enum_test_enumeration_values_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializablePropertyEnumTestEnumerationValues), 0, (GInstanceInitFunc) serializable_property_enum_test_enumeration_values_instance_init, NULL };
		GType serializable_property_enum_test_enumeration_values_type_id;
		serializable_property_enum_test_enumeration_values_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializablePropertyEnumTestEnumerationValues", &g_define_type_info, 0);
		SerializablePropertyEnumTestEnumerationValues_private_offset = g_type_add_instance_private (serializable_property_enum_test_enumeration_values_type_id, sizeof (SerializablePropertyEnumTestEnumerationValuesPrivate));
		g_once_init_leave (&serializable_property_enum_test_enumeration_values_type_id__volatile, serializable_property_enum_test_enumeration_values_type_id);
	}
	return serializable_property_enum_test_enumeration_values_type_id__volatile;
}

static void
_vala_serializable_property_enum_test_enumeration_values_get_property (GObject * object,
                                                                       guint property_id,
                                                                       GValue * value,
                                                                       GParamSpec * pspec)
{
	SerializablePropertyEnumTestEnumerationValues * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUMERATION_VALUES, SerializablePropertyEnumTestEnumerationValues);
#line 45 "SerializablePropertyEnumTest.vala"
	switch (property_id) {
#line 45 "SerializablePropertyEnumTest.vala"
		case SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_VALUES_PROPERTY:
#line 45 "SerializablePropertyEnumTest.vala"
		g_value_set_object (value, serializable_property_enum_test_enumeration_values_get_values (self));
#line 45 "SerializablePropertyEnumTest.vala"
		break;
#line 45 "SerializablePropertyEnumTest.vala"
		case SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_OPTIONAL_VALUES_PROPERTY:
#line 45 "SerializablePropertyEnumTest.vala"
		g_value_set_object (value, serializable_property_enum_test_enumeration_values_get_optional_values (self));
#line 45 "SerializablePropertyEnumTest.vala"
		break;
#line 45 "SerializablePropertyEnumTest.vala"
		case SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_INTEGER_PROPERTY:
#line 45 "SerializablePropertyEnumTest.vala"
		g_value_set_int (value, serializable_property_enum_test_enumeration_values_get_integer (self));
#line 45 "SerializablePropertyEnumTest.vala"
		break;
#line 45 "SerializablePropertyEnumTest.vala"
		case SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_NAME_PROPERTY:
#line 45 "SerializablePropertyEnumTest.vala"
		g_value_set_string (value, serializable_property_enum_test_enumeration_values_get_name (self));
#line 45 "SerializablePropertyEnumTest.vala"
		break;
#line 2309 "SerializablePropertyEnumTest.c"
		default:
#line 45 "SerializablePropertyEnumTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 45 "SerializablePropertyEnumTest.vala"
		break;
#line 2315 "SerializablePropertyEnumTest.c"
	}
}

static void
_vala_serializable_property_enum_test_enumeration_values_set_property (GObject * object,
                                                                       guint property_id,
                                                                       const GValue * value,
                                                                       GParamSpec * pspec)
{
	SerializablePropertyEnumTestEnumerationValues * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_PROPERTY_ENUM_TEST_TYPE_ENUMERATION_VALUES, SerializablePropertyEnumTestEnumerationValues);
#line 45 "SerializablePropertyEnumTest.vala"
	switch (property_id) {
#line 45 "SerializablePropertyEnumTest.vala"
		case SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_VALUES_PROPERTY:
#line 45 "SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enumeration_values_set_values (self, g_value_get_object (value));
#line 45 "SerializablePropertyEnumTest.vala"
		break;
#line 45 "SerializablePropertyEnumTest.vala"
		case SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_OPTIONAL_VALUES_PROPERTY:
#line 45 "SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enumeration_values_set_optional_values (self, g_value_get_object (value));
#line 45 "SerializablePropertyEnumTest.vala"
		break;
#line 45 "SerializablePropertyEnumTest.vala"
		case SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_INTEGER_PROPERTY:
#line 45 "SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enumeration_values_set_integer (self, g_value_get_int (value));
#line 45 "SerializablePropertyEnumTest.vala"
		break;
#line 45 "SerializablePropertyEnumTest.vala"
		case SERIALIZABLE_PROPERTY_ENUM_TEST_ENUMERATION_VALUES_NAME_PROPERTY:
#line 45 "SerializablePropertyEnumTest.vala"
		serializable_property_enum_test_enumeration_values_set_name (self, g_value_get_string (value));
#line 45 "SerializablePropertyEnumTest.vala"
		break;
#line 2353 "SerializablePropertyEnumTest.c"
		default:
#line 45 "SerializablePropertyEnumTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 45 "SerializablePropertyEnumTest.vala"
		break;
#line 2359 "SerializablePropertyEnumTest.c"
	}
}

static void
serializable_property_enum_test_class_init (SerializablePropertyEnumTestClass * klass,
                                            gpointer klass_data)
{
#line 27 "SerializablePropertyEnumTest.vala"
	serializable_property_enum_test_parent_class = g_type_class_peek_parent (klass);
#line 2369 "SerializablePropertyEnumTest.c"
}

static void
serializable_property_enum_test_instance_init (SerializablePropertyEnumTest * self,
                                               gpointer klass)
{
}

/**
 *
 *  SerializablePropertyEnumTest.vala
 *
 *  Authors:
 *
 *       Daniel Espinosa <esodan@gmail.com>
 *
 *
 *  Copyright (c) 2015 Daniel Espinosa
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
GType
serializable_property_enum_test_get_type (void)
{
	static volatile gsize serializable_property_enum_test_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_property_enum_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializablePropertyEnumTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_property_enum_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializablePropertyEnumTest), 0, (GInstanceInitFunc) serializable_property_enum_test_instance_init, NULL };
		GType serializable_property_enum_test_type_id;
		serializable_property_enum_test_type_id = g_type_register_static (TYPE_GXML_TEST, "SerializablePropertyEnumTest", &g_define_type_info, 0);
		g_once_init_leave (&serializable_property_enum_test_type_id__volatile, serializable_property_enum_test_type_id);
	}
	return serializable_property_enum_test_type_id__volatile;
}

