/* NodeListTest.c generated by valac 0.44.3, the Vala compiler
 * generated from NodeListTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */

#include <glib-object.h>
#include <glib.h>

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_NODE_LIST_TEST (node_list_test_get_type ())
#define NODE_LIST_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_NODE_LIST_TEST, NodeListTest))
#define NODE_LIST_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_NODE_LIST_TEST, NodeListTestClass))
#define IS_NODE_LIST_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_NODE_LIST_TEST))
#define IS_NODE_LIST_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_NODE_LIST_TEST))
#define NODE_LIST_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_NODE_LIST_TEST, NodeListTestClass))

typedef struct _NodeListTest NodeListTest;
typedef struct _NodeListTestClass NodeListTestClass;
typedef struct _NodeListTestPrivate NodeListTestPrivate;

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _NodeListTest {
	GXmlTest parent_instance;
	NodeListTestPrivate * priv;
};

struct _NodeListTestClass {
	GXmlTestClass parent_class;
};

static gpointer node_list_test_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType node_list_test_get_type (void) G_GNUC_CONST;
void node_list_test_add_tests (void);
static void __lambda164_ (void);
static void ___lambda164__gtest_func (void);
NodeListTest* node_list_test_new (void);
NodeListTest* node_list_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);

static void
__lambda164_ (void)
{
}

static void
___lambda164__gtest_func (void)
{
#line 6 "NodeListTest.vala"
	__lambda164_ ();
#line 86 "NodeListTest.c"
}

void
node_list_test_add_tests (void)
{
#line 6 "NodeListTest.vala"
	g_test_add_func ("/gxml/nodelist/length", ___lambda164__gtest_func);
#line 94 "NodeListTest.c"
}

NodeListTest*
node_list_test_construct (GType object_type)
{
	NodeListTest* self = NULL;
#line 4 "NodeListTest.vala"
	self = (NodeListTest*) gxml_test_construct (object_type);
#line 4 "NodeListTest.vala"
	return self;
#line 105 "NodeListTest.c"
}

NodeListTest*
node_list_test_new (void)
{
#line 4 "NodeListTest.vala"
	return node_list_test_construct (TYPE_NODE_LIST_TEST);
#line 113 "NodeListTest.c"
}

static void
node_list_test_class_init (NodeListTestClass * klass,
                           gpointer klass_data)
{
#line 4 "NodeListTest.vala"
	node_list_test_parent_class = g_type_class_peek_parent (klass);
#line 122 "NodeListTest.c"
}

static void
node_list_test_instance_init (NodeListTest * self,
                              gpointer klass)
{
}

GType
node_list_test_get_type (void)
{
	static volatile gsize node_list_test_type_id__volatile = 0;
	if (g_once_init_enter (&node_list_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (NodeListTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) node_list_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (NodeListTest), 0, (GInstanceInitFunc) node_list_test_instance_init, NULL };
		GType node_list_test_type_id;
		node_list_test_type_id = g_type_register_static (TYPE_GXML_TEST, "NodeListTest", &g_define_type_info, 0);
		g_once_init_leave (&node_list_test_type_id__volatile, node_list_test_type_id);
	}
	return node_list_test_type_id__volatile;
}

