/* SerializablePropertyBoolTest.c generated by valac 0.44.3, the Vala compiler
 * generated from SerializablePropertyBoolTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; tab-width: 2 -*- */

#include <glib-object.h>
#include <glib.h>
#include <gxml/gxml.h>
#include <stdlib.h>
#include <string.h>

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_SERIALIZABLE_PROPERTY_BOOL_TEST (serializable_property_bool_test_get_type ())
#define SERIALIZABLE_PROPERTY_BOOL_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_PROPERTY_BOOL_TEST, SerializablePropertyBoolTest))
#define SERIALIZABLE_PROPERTY_BOOL_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_PROPERTY_BOOL_TEST, SerializablePropertyBoolTestClass))
#define IS_SERIALIZABLE_PROPERTY_BOOL_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_PROPERTY_BOOL_TEST))
#define IS_SERIALIZABLE_PROPERTY_BOOL_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_PROPERTY_BOOL_TEST))
#define SERIALIZABLE_PROPERTY_BOOL_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_PROPERTY_BOOL_TEST, SerializablePropertyBoolTestClass))

typedef struct _SerializablePropertyBoolTest SerializablePropertyBoolTest;
typedef struct _SerializablePropertyBoolTestClass SerializablePropertyBoolTestClass;
typedef struct _SerializablePropertyBoolTestPrivate SerializablePropertyBoolTestPrivate;

#define SERIALIZABLE_PROPERTY_BOOL_TEST_TYPE_BOOL_NODE (serializable_property_bool_test_bool_node_get_type ())
#define SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_PROPERTY_BOOL_TEST_TYPE_BOOL_NODE, SerializablePropertyBoolTestBoolNode))
#define SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_PROPERTY_BOOL_TEST_TYPE_BOOL_NODE, SerializablePropertyBoolTestBoolNodeClass))
#define SERIALIZABLE_PROPERTY_BOOL_TEST_IS_BOOL_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_PROPERTY_BOOL_TEST_TYPE_BOOL_NODE))
#define SERIALIZABLE_PROPERTY_BOOL_TEST_IS_BOOL_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_PROPERTY_BOOL_TEST_TYPE_BOOL_NODE))
#define SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_PROPERTY_BOOL_TEST_TYPE_BOOL_NODE, SerializablePropertyBoolTestBoolNodeClass))

typedef struct _SerializablePropertyBoolTestBoolNode SerializablePropertyBoolTestBoolNode;
typedef struct _SerializablePropertyBoolTestBoolNodeClass SerializablePropertyBoolTestBoolNodeClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _SerializablePropertyBoolTestBoolNodePrivate SerializablePropertyBoolTestBoolNodePrivate;
enum  {
	SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE_0_PROPERTY,
	SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE_BOOLEAN_PROPERTY,
	SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE_INTEGER_PROPERTY,
	SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE_NAME_PROPERTY,
	SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE_NUM_PROPERTIES
};
static GParamSpec* serializable_property_bool_test_bool_node_properties[SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE_NUM_PROPERTIES];
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _SerializablePropertyBoolTest {
	GXmlTest parent_instance;
	SerializablePropertyBoolTestPrivate * priv;
};

struct _SerializablePropertyBoolTestClass {
	GXmlTestClass parent_class;
};

struct _SerializablePropertyBoolTestBoolNode {
	GXmlSerializableObjectModel parent_instance;
	SerializablePropertyBoolTestBoolNodePrivate * priv;
};

struct _SerializablePropertyBoolTestBoolNodeClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializablePropertyBoolTestBoolNodePrivate {
	GXmlSerializableBool* _boolean;
	gint _integer;
	gchar* _name;
};

static gpointer serializable_property_bool_test_parent_class = NULL;
static gint SerializablePropertyBoolTestBoolNode_private_offset;
static gpointer serializable_property_bool_test_bool_node_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType serializable_property_bool_test_get_type (void) G_GNUC_CONST;
void serializable_property_bool_test_add_tests (void);
static void __lambda234_ (void);
GType serializable_property_bool_test_bool_node_get_type (void) G_GNUC_CONST;
SerializablePropertyBoolTestBoolNode* serializable_property_bool_test_bool_node_new (void);
SerializablePropertyBoolTestBoolNode* serializable_property_bool_test_bool_node_construct (GType object_type);
static void ___lambda234__gtest_func (void);
static void __lambda235_ (void);
void serializable_property_bool_test_bool_node_set_boolean (SerializablePropertyBoolTestBoolNode* self,
                                                            GXmlSerializableBool* value);
GXmlSerializableBool* serializable_property_bool_test_bool_node_get_boolean (SerializablePropertyBoolTestBoolNode* self);
static void ___lambda235__gtest_func (void);
static void __lambda236_ (void);
static void ___lambda236__gtest_func (void);
static void __lambda237_ (void);
static void ___lambda237__gtest_func (void);
SerializablePropertyBoolTest* serializable_property_bool_test_new (void);
SerializablePropertyBoolTest* serializable_property_bool_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static gchar* serializable_property_bool_test_bool_node_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_property_bool_test_bool_node_real_to_string (GXmlSerializableObjectModel* base);
gint serializable_property_bool_test_bool_node_get_integer (SerializablePropertyBoolTestBoolNode* self);
void serializable_property_bool_test_bool_node_set_integer (SerializablePropertyBoolTestBoolNode* self,
                                                            gint value);
const gchar* serializable_property_bool_test_bool_node_get_name (SerializablePropertyBoolTestBoolNode* self);
void serializable_property_bool_test_bool_node_set_name (SerializablePropertyBoolTestBoolNode* self,
                                                         const gchar* value);
static void serializable_property_bool_test_bool_node_finalize (GObject * obj);
static void _vala_serializable_property_bool_test_bool_node_get_property (GObject * object,
                                                                   guint property_id,
                                                                   GValue * value,
                                                                   GParamSpec * pspec);
static void _vala_serializable_property_bool_test_bool_node_set_property (GObject * object,
                                                                   guint property_id,
                                                                   const GValue * value,
                                                                   GParamSpec * pspec);

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result = NULL;
#line 1516 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1517 "glib-2.0.vapi"
	result = self;
#line 1517 "glib-2.0.vapi"
	return result;
#line 161 "SerializablePropertyBoolTest.c"
}

static void
__lambda234_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		SerializablePropertyBoolTestBoolNode* bn = NULL;
		SerializablePropertyBoolTestBoolNode* _tmp0_;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_;
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		GXmlElement* element = NULL;
		GXmlNode* _tmp8_;
		GXmlNode* _tmp9_;
		GXmlElement* _tmp10_;
		GXmlNode* b = NULL;
		GXmlNode* _tmp11_;
		GXmlNode* s = NULL;
		GXmlNode* _tmp12_;
		GXmlNode* i = NULL;
		GXmlNode* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		gchar* _tmp16_;
#line 40 "SerializablePropertyBoolTest.vala"
		_tmp0_ = serializable_property_bool_test_bool_node_new ();
#line 40 "SerializablePropertyBoolTest.vala"
		bn = _tmp0_;
#line 41 "SerializablePropertyBoolTest.vala"
		_tmp1_ = gxml_gdocument_new ();
#line 41 "SerializablePropertyBoolTest.vala"
		doc = _tmp1_;
#line 42 "SerializablePropertyBoolTest.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) bn, (GXmlNode*) doc, &_inner_error0_);
#line 42 "SerializablePropertyBoolTest.vala"
		_tmp3_ = _tmp2_;
#line 42 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (_tmp3_);
#line 42 "SerializablePropertyBoolTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 42 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (doc);
#line 42 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (bn);
#line 212 "SerializablePropertyBoolTest.c"
			goto __catch288_g_error;
		}
#line 43 "SerializablePropertyBoolTest.vala"
		_tmp4_ = gxml_gnode_to_string ((GXmlGNode*) doc);
#line 43 "SerializablePropertyBoolTest.vala"
		_tmp5_ = _tmp4_;
#line 43 "SerializablePropertyBoolTest.vala"
		_tmp6_ = g_strconcat ("XML:\n", _tmp5_, NULL);
#line 43 "SerializablePropertyBoolTest.vala"
		_tmp7_ = _tmp6_;
#line 43 "SerializablePropertyBoolTest.vala"
		g_test_message ("%s", _tmp7_);
#line 43 "SerializablePropertyBoolTest.vala"
		_g_free0 (_tmp7_);
#line 43 "SerializablePropertyBoolTest.vala"
		_g_free0 (_tmp5_);
#line 44 "SerializablePropertyBoolTest.vala"
		_tmp8_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 44 "SerializablePropertyBoolTest.vala"
		_tmp9_ = _tmp8_;
#line 44 "SerializablePropertyBoolTest.vala"
		_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp9_) : NULL;
#line 44 "SerializablePropertyBoolTest.vala"
		if (_tmp10_ == NULL) {
#line 44 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (_tmp9_);
#line 239 "SerializablePropertyBoolTest.c"
		}
#line 44 "SerializablePropertyBoolTest.vala"
		element = _tmp10_;
#line 45 "SerializablePropertyBoolTest.vala"
		_tmp11_ = gxml_element_get_attr (element, "boolean");
#line 45 "SerializablePropertyBoolTest.vala"
		b = _tmp11_;
#line 46 "SerializablePropertyBoolTest.vala"
		_vala_assert (b == NULL, "b == null");
#line 47 "SerializablePropertyBoolTest.vala"
		_tmp12_ = gxml_element_get_attr (element, "name");
#line 47 "SerializablePropertyBoolTest.vala"
		s = _tmp12_;
#line 48 "SerializablePropertyBoolTest.vala"
		_vala_assert (s == NULL, "s == null");
#line 49 "SerializablePropertyBoolTest.vala"
		_tmp13_ = gxml_element_get_attr (element, "integer");
#line 49 "SerializablePropertyBoolTest.vala"
		i = _tmp13_;
#line 50 "SerializablePropertyBoolTest.vala"
		_tmp14_ = gxml_node_get_value (i);
#line 50 "SerializablePropertyBoolTest.vala"
		_tmp15_ = _tmp14_;
#line 50 "SerializablePropertyBoolTest.vala"
		_tmp16_ = _tmp15_;
#line 50 "SerializablePropertyBoolTest.vala"
		_vala_assert (g_strcmp0 (_tmp16_, "0") == 0, "i.value == \"0\"");
#line 50 "SerializablePropertyBoolTest.vala"
		_g_free0 (_tmp16_);
#line 39 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (i);
#line 39 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (s);
#line 39 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (b);
#line 39 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (element);
#line 39 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (doc);
#line 39 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (bn);
#line 281 "SerializablePropertyBoolTest.c"
	}
	goto __finally288;
	__catch288_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp17_;
		const gchar* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
#line 39 "SerializablePropertyBoolTest.vala"
		e = _inner_error0_;
#line 39 "SerializablePropertyBoolTest.vala"
		_inner_error0_ = NULL;
#line 52 "SerializablePropertyBoolTest.vala"
		_tmp17_ = e->message;
#line 52 "SerializablePropertyBoolTest.vala"
		_tmp18_ = string_to_string (_tmp17_);
#line 52 "SerializablePropertyBoolTest.vala"
		_tmp19_ = g_strconcat ("ERROR: ", _tmp18_, NULL);
#line 52 "SerializablePropertyBoolTest.vala"
		_tmp20_ = _tmp19_;
#line 52 "SerializablePropertyBoolTest.vala"
		g_test_message ("%s", _tmp20_);
#line 52 "SerializablePropertyBoolTest.vala"
		_g_free0 (_tmp20_);
#line 53 "SerializablePropertyBoolTest.vala"
		g_assert_not_reached ();
#line 39 "SerializablePropertyBoolTest.vala"
		_g_error_free0 (e);
#line 311 "SerializablePropertyBoolTest.c"
	}
	__finally288:
#line 39 "SerializablePropertyBoolTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 39 "SerializablePropertyBoolTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 39 "SerializablePropertyBoolTest.vala"
		g_clear_error (&_inner_error0_);
#line 39 "SerializablePropertyBoolTest.vala"
		return;
#line 322 "SerializablePropertyBoolTest.c"
	}
}

static void
___lambda234__gtest_func (void)
{
#line 37 "SerializablePropertyBoolTest.vala"
	__lambda234_ ();
#line 331 "SerializablePropertyBoolTest.c"
}

static void
__lambda235_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		SerializablePropertyBoolTestBoolNode* bn = NULL;
		SerializablePropertyBoolTestBoolNode* _tmp0_;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_;
		SerializablePropertyBoolTestBoolNode* _tmp2_;
		GXmlGDocument* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlGDocument* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		GXmlElement* element = NULL;
		GXmlGDocument* _tmp11_;
		GXmlNode* _tmp12_;
		GXmlNode* _tmp13_;
		GXmlElement* _tmp14_;
		GXmlNode* b = NULL;
		GXmlElement* _tmp15_;
		GXmlNode* _tmp16_;
		GXmlNode* _tmp17_;
		GXmlNode* s = NULL;
		GXmlElement* _tmp18_;
		GXmlNode* _tmp19_;
		GXmlNode* _tmp20_;
		GXmlNode* i = NULL;
		GXmlElement* _tmp21_;
		GXmlNode* _tmp22_;
		GXmlNode* _tmp23_;
		gchar* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		SerializablePropertyBoolTestBoolNode* _tmp27_;
		GXmlSerializableBool* _tmp28_;
		GXmlSerializableBool* _tmp29_;
		SerializablePropertyBoolTestBoolNode* _tmp30_;
		GXmlSerializableBool* _tmp31_;
		GXmlSerializableBool* _tmp32_;
		GXmlGDocument* doc2 = NULL;
		GXmlGDocument* _tmp33_;
		SerializablePropertyBoolTestBoolNode* _tmp34_;
		GXmlGDocument* _tmp35_;
		GXmlNode* _tmp36_;
		GXmlNode* _tmp37_;
		GXmlGDocument* _tmp38_;
		gchar* _tmp39_;
		gchar* _tmp40_;
		gchar* _tmp41_;
		gchar* _tmp42_;
		GXmlElement* element2 = NULL;
		GXmlGDocument* _tmp43_;
		GXmlNode* _tmp44_;
		GXmlNode* _tmp45_;
		GXmlElement* _tmp46_;
		GXmlNode* b2 = NULL;
		GXmlElement* _tmp47_;
		GXmlNode* _tmp48_;
		GXmlNode* _tmp49_;
		GXmlNode* _tmp50_;
		gchar* _tmp51_;
		gchar* _tmp52_;
		gchar* _tmp53_;
		SerializablePropertyBoolTestBoolNode* _tmp54_;
		GXmlSerializableBool* _tmp55_;
		GXmlSerializableBool* _tmp56_;
		GXmlGDocument* doc3 = NULL;
		GXmlGDocument* _tmp57_;
		SerializablePropertyBoolTestBoolNode* _tmp58_;
		GXmlGDocument* _tmp59_;
		GXmlNode* _tmp60_;
		GXmlNode* _tmp61_;
		GXmlGDocument* _tmp62_;
		gchar* _tmp63_;
		gchar* _tmp64_;
		gchar* _tmp65_;
		gchar* _tmp66_;
		GXmlElement* element3 = NULL;
		GXmlGDocument* _tmp67_;
		GXmlNode* _tmp68_;
		GXmlNode* _tmp69_;
		GXmlElement* _tmp70_;
		GXmlNode* b3 = NULL;
		GXmlElement* _tmp71_;
		GXmlNode* _tmp72_;
		GXmlNode* _tmp73_;
		GXmlNode* _tmp74_;
		gchar* _tmp75_;
		gchar* _tmp76_;
		gchar* _tmp77_;
		SerializablePropertyBoolTestBoolNode* _tmp78_;
		GXmlSerializableBool* _tmp79_;
		GXmlSerializableBool* _tmp80_;
		GXmlGDocument* doc4 = NULL;
		GXmlGDocument* _tmp81_;
		SerializablePropertyBoolTestBoolNode* _tmp82_;
		GXmlGDocument* _tmp83_;
		GXmlNode* _tmp84_;
		GXmlNode* _tmp85_;
		GXmlGDocument* _tmp86_;
		gchar* _tmp87_;
		gchar* _tmp88_;
		gchar* _tmp89_;
		gchar* _tmp90_;
		GXmlElement* element4 = NULL;
		GXmlGDocument* _tmp91_;
		GXmlNode* _tmp92_;
		GXmlNode* _tmp93_;
		GXmlElement* _tmp94_;
		GXmlNode* b4 = NULL;
		GXmlNode* _tmp95_;
#line 59 "SerializablePropertyBoolTest.vala"
		_tmp0_ = serializable_property_bool_test_bool_node_new ();
#line 59 "SerializablePropertyBoolTest.vala"
		bn = _tmp0_;
#line 60 "SerializablePropertyBoolTest.vala"
		_tmp1_ = gxml_gdocument_new ();
#line 60 "SerializablePropertyBoolTest.vala"
		doc = _tmp1_;
#line 61 "SerializablePropertyBoolTest.vala"
		_tmp2_ = bn;
#line 61 "SerializablePropertyBoolTest.vala"
		_tmp3_ = doc;
#line 61 "SerializablePropertyBoolTest.vala"
		_tmp4_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 61 "SerializablePropertyBoolTest.vala"
		_tmp5_ = _tmp4_;
#line 61 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (_tmp5_);
#line 61 "SerializablePropertyBoolTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 61 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (doc);
#line 61 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (bn);
#line 474 "SerializablePropertyBoolTest.c"
			goto __catch289_g_error;
		}
#line 62 "SerializablePropertyBoolTest.vala"
		_tmp6_ = doc;
#line 62 "SerializablePropertyBoolTest.vala"
		_tmp7_ = gxml_gnode_to_string ((GXmlGNode*) _tmp6_);
#line 62 "SerializablePropertyBoolTest.vala"
		_tmp8_ = _tmp7_;
#line 62 "SerializablePropertyBoolTest.vala"
		_tmp9_ = g_strconcat ("XML:\n", _tmp8_, NULL);
#line 62 "SerializablePropertyBoolTest.vala"
		_tmp10_ = _tmp9_;
#line 62 "SerializablePropertyBoolTest.vala"
		g_test_message ("%s", _tmp10_);
#line 62 "SerializablePropertyBoolTest.vala"
		_g_free0 (_tmp10_);
#line 62 "SerializablePropertyBoolTest.vala"
		_g_free0 (_tmp8_);
#line 63 "SerializablePropertyBoolTest.vala"
		_tmp11_ = doc;
#line 63 "SerializablePropertyBoolTest.vala"
		_tmp12_ = gxml_document_get_root ((GXmlDocument*) _tmp11_);
#line 63 "SerializablePropertyBoolTest.vala"
		_tmp13_ = _tmp12_;
#line 63 "SerializablePropertyBoolTest.vala"
		_tmp14_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp13_) : NULL;
#line 63 "SerializablePropertyBoolTest.vala"
		if (_tmp14_ == NULL) {
#line 63 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (_tmp13_);
#line 505 "SerializablePropertyBoolTest.c"
		}
#line 63 "SerializablePropertyBoolTest.vala"
		element = _tmp14_;
#line 64 "SerializablePropertyBoolTest.vala"
		_tmp15_ = element;
#line 64 "SerializablePropertyBoolTest.vala"
		_tmp16_ = gxml_element_get_attr (_tmp15_, "boolean");
#line 64 "SerializablePropertyBoolTest.vala"
		b = _tmp16_;
#line 65 "SerializablePropertyBoolTest.vala"
		_tmp17_ = b;
#line 65 "SerializablePropertyBoolTest.vala"
		_vala_assert (_tmp17_ == NULL, "b == null");
#line 66 "SerializablePropertyBoolTest.vala"
		_tmp18_ = element;
#line 66 "SerializablePropertyBoolTest.vala"
		_tmp19_ = gxml_element_get_attr (_tmp18_, "name");
#line 66 "SerializablePropertyBoolTest.vala"
		s = _tmp19_;
#line 67 "SerializablePropertyBoolTest.vala"
		_tmp20_ = s;
#line 67 "SerializablePropertyBoolTest.vala"
		_vala_assert (_tmp20_ == NULL, "s == null");
#line 68 "SerializablePropertyBoolTest.vala"
		_tmp21_ = element;
#line 68 "SerializablePropertyBoolTest.vala"
		_tmp22_ = gxml_element_get_attr (_tmp21_, "integer");
#line 68 "SerializablePropertyBoolTest.vala"
		i = _tmp22_;
#line 69 "SerializablePropertyBoolTest.vala"
		_tmp23_ = i;
#line 69 "SerializablePropertyBoolTest.vala"
		_tmp24_ = gxml_node_get_value (_tmp23_);
#line 69 "SerializablePropertyBoolTest.vala"
		_tmp25_ = _tmp24_;
#line 69 "SerializablePropertyBoolTest.vala"
		_tmp26_ = _tmp25_;
#line 69 "SerializablePropertyBoolTest.vala"
		_vala_assert (g_strcmp0 (_tmp26_, "0") == 0, "i.value == \"0\"");
#line 69 "SerializablePropertyBoolTest.vala"
		_g_free0 (_tmp26_);
#line 71 "SerializablePropertyBoolTest.vala"
		_tmp27_ = bn;
#line 71 "SerializablePropertyBoolTest.vala"
		_tmp28_ = gxml_serializable_bool_new ();
#line 71 "SerializablePropertyBoolTest.vala"
		_tmp29_ = _tmp28_;
#line 71 "SerializablePropertyBoolTest.vala"
		serializable_property_bool_test_bool_node_set_boolean (_tmp27_, _tmp29_);
#line 71 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (_tmp29_);
#line 73 "SerializablePropertyBoolTest.vala"
		_tmp30_ = bn;
#line 73 "SerializablePropertyBoolTest.vala"
		_tmp31_ = serializable_property_bool_test_bool_node_get_boolean (_tmp30_);
#line 73 "SerializablePropertyBoolTest.vala"
		_tmp32_ = _tmp31_;
#line 73 "SerializablePropertyBoolTest.vala"
		gxml_serializable_bool_set_value (_tmp32_, TRUE);
#line 74 "SerializablePropertyBoolTest.vala"
		_tmp33_ = gxml_gdocument_new ();
#line 74 "SerializablePropertyBoolTest.vala"
		doc2 = _tmp33_;
#line 75 "SerializablePropertyBoolTest.vala"
		_tmp34_ = bn;
#line 75 "SerializablePropertyBoolTest.vala"
		_tmp35_ = doc2;
#line 75 "SerializablePropertyBoolTest.vala"
		_tmp36_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp34_, (GXmlNode*) _tmp35_, &_inner_error0_);
#line 75 "SerializablePropertyBoolTest.vala"
		_tmp37_ = _tmp36_;
#line 75 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (_tmp37_);
#line 75 "SerializablePropertyBoolTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 75 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (doc2);
#line 75 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (i);
#line 75 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (s);
#line 75 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (b);
#line 75 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (element);
#line 75 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (doc);
#line 75 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (bn);
#line 595 "SerializablePropertyBoolTest.c"
			goto __catch289_g_error;
		}
#line 76 "SerializablePropertyBoolTest.vala"
		_tmp38_ = doc2;
#line 76 "SerializablePropertyBoolTest.vala"
		_tmp39_ = gxml_gnode_to_string ((GXmlGNode*) _tmp38_);
#line 76 "SerializablePropertyBoolTest.vala"
		_tmp40_ = _tmp39_;
#line 76 "SerializablePropertyBoolTest.vala"
		_tmp41_ = g_strconcat ("XML2:\n", _tmp40_, NULL);
#line 76 "SerializablePropertyBoolTest.vala"
		_tmp42_ = _tmp41_;
#line 76 "SerializablePropertyBoolTest.vala"
		g_test_message ("%s", _tmp42_);
#line 76 "SerializablePropertyBoolTest.vala"
		_g_free0 (_tmp42_);
#line 76 "SerializablePropertyBoolTest.vala"
		_g_free0 (_tmp40_);
#line 77 "SerializablePropertyBoolTest.vala"
		_tmp43_ = doc2;
#line 77 "SerializablePropertyBoolTest.vala"
		_tmp44_ = gxml_document_get_root ((GXmlDocument*) _tmp43_);
#line 77 "SerializablePropertyBoolTest.vala"
		_tmp45_ = _tmp44_;
#line 77 "SerializablePropertyBoolTest.vala"
		_tmp46_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp45_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp45_) : NULL;
#line 77 "SerializablePropertyBoolTest.vala"
		if (_tmp46_ == NULL) {
#line 77 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (_tmp45_);
#line 626 "SerializablePropertyBoolTest.c"
		}
#line 77 "SerializablePropertyBoolTest.vala"
		element2 = _tmp46_;
#line 78 "SerializablePropertyBoolTest.vala"
		_tmp47_ = element2;
#line 78 "SerializablePropertyBoolTest.vala"
		_tmp48_ = gxml_element_get_attr (_tmp47_, "boolean");
#line 78 "SerializablePropertyBoolTest.vala"
		b2 = _tmp48_;
#line 79 "SerializablePropertyBoolTest.vala"
		_tmp49_ = b2;
#line 79 "SerializablePropertyBoolTest.vala"
		_vala_assert (_tmp49_ != NULL, "b2 != null");
#line 80 "SerializablePropertyBoolTest.vala"
		_tmp50_ = b2;
#line 80 "SerializablePropertyBoolTest.vala"
		_tmp51_ = gxml_node_get_value (_tmp50_);
#line 80 "SerializablePropertyBoolTest.vala"
		_tmp52_ = _tmp51_;
#line 80 "SerializablePropertyBoolTest.vala"
		_tmp53_ = _tmp52_;
#line 80 "SerializablePropertyBoolTest.vala"
		_vala_assert (g_strcmp0 (_tmp53_, "true") == 0, "b2.value == \"true\"");
#line 80 "SerializablePropertyBoolTest.vala"
		_g_free0 (_tmp53_);
#line 82 "SerializablePropertyBoolTest.vala"
		_tmp54_ = bn;
#line 82 "SerializablePropertyBoolTest.vala"
		_tmp55_ = serializable_property_bool_test_bool_node_get_boolean (_tmp54_);
#line 82 "SerializablePropertyBoolTest.vala"
		_tmp56_ = _tmp55_;
#line 82 "SerializablePropertyBoolTest.vala"
		gxml_serializable_bool_set_value (_tmp56_, FALSE);
#line 83 "SerializablePropertyBoolTest.vala"
		_tmp57_ = gxml_gdocument_new ();
#line 83 "SerializablePropertyBoolTest.vala"
		doc3 = _tmp57_;
#line 84 "SerializablePropertyBoolTest.vala"
		_tmp58_ = bn;
#line 84 "SerializablePropertyBoolTest.vala"
		_tmp59_ = doc3;
#line 84 "SerializablePropertyBoolTest.vala"
		_tmp60_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp58_, (GXmlNode*) _tmp59_, &_inner_error0_);
#line 84 "SerializablePropertyBoolTest.vala"
		_tmp61_ = _tmp60_;
#line 84 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (_tmp61_);
#line 84 "SerializablePropertyBoolTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 84 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (doc3);
#line 84 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (b2);
#line 84 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (element2);
#line 84 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (doc2);
#line 84 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (i);
#line 84 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (s);
#line 84 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (b);
#line 84 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (element);
#line 84 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (doc);
#line 84 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (bn);
#line 696 "SerializablePropertyBoolTest.c"
			goto __catch289_g_error;
		}
#line 85 "SerializablePropertyBoolTest.vala"
		_tmp62_ = doc3;
#line 85 "SerializablePropertyBoolTest.vala"
		_tmp63_ = gxml_gnode_to_string ((GXmlGNode*) _tmp62_);
#line 85 "SerializablePropertyBoolTest.vala"
		_tmp64_ = _tmp63_;
#line 85 "SerializablePropertyBoolTest.vala"
		_tmp65_ = g_strconcat ("XML3:\n", _tmp64_, NULL);
#line 85 "SerializablePropertyBoolTest.vala"
		_tmp66_ = _tmp65_;
#line 85 "SerializablePropertyBoolTest.vala"
		g_test_message ("%s", _tmp66_);
#line 85 "SerializablePropertyBoolTest.vala"
		_g_free0 (_tmp66_);
#line 85 "SerializablePropertyBoolTest.vala"
		_g_free0 (_tmp64_);
#line 86 "SerializablePropertyBoolTest.vala"
		_tmp67_ = doc3;
#line 86 "SerializablePropertyBoolTest.vala"
		_tmp68_ = gxml_document_get_root ((GXmlDocument*) _tmp67_);
#line 86 "SerializablePropertyBoolTest.vala"
		_tmp69_ = _tmp68_;
#line 86 "SerializablePropertyBoolTest.vala"
		_tmp70_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp69_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp69_) : NULL;
#line 86 "SerializablePropertyBoolTest.vala"
		if (_tmp70_ == NULL) {
#line 86 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (_tmp69_);
#line 727 "SerializablePropertyBoolTest.c"
		}
#line 86 "SerializablePropertyBoolTest.vala"
		element3 = _tmp70_;
#line 87 "SerializablePropertyBoolTest.vala"
		_tmp71_ = element3;
#line 87 "SerializablePropertyBoolTest.vala"
		_tmp72_ = gxml_element_get_attr (_tmp71_, "boolean");
#line 87 "SerializablePropertyBoolTest.vala"
		b3 = _tmp72_;
#line 88 "SerializablePropertyBoolTest.vala"
		_tmp73_ = b3;
#line 88 "SerializablePropertyBoolTest.vala"
		_vala_assert (_tmp73_ != NULL, "b3 != null");
#line 89 "SerializablePropertyBoolTest.vala"
		_tmp74_ = b3;
#line 89 "SerializablePropertyBoolTest.vala"
		_tmp75_ = gxml_node_get_value (_tmp74_);
#line 89 "SerializablePropertyBoolTest.vala"
		_tmp76_ = _tmp75_;
#line 89 "SerializablePropertyBoolTest.vala"
		_tmp77_ = _tmp76_;
#line 89 "SerializablePropertyBoolTest.vala"
		_vala_assert (g_strcmp0 (_tmp77_, "false") == 0, "b3.value == \"false\"");
#line 89 "SerializablePropertyBoolTest.vala"
		_g_free0 (_tmp77_);
#line 91 "SerializablePropertyBoolTest.vala"
		_tmp78_ = bn;
#line 91 "SerializablePropertyBoolTest.vala"
		_tmp79_ = serializable_property_bool_test_bool_node_get_boolean (_tmp78_);
#line 91 "SerializablePropertyBoolTest.vala"
		_tmp80_ = _tmp79_;
#line 91 "SerializablePropertyBoolTest.vala"
		gxml_serializable_property_set_serializable_property_value ((GXmlSerializableProperty*) _tmp80_, NULL);
#line 92 "SerializablePropertyBoolTest.vala"
		_tmp81_ = gxml_gdocument_new ();
#line 92 "SerializablePropertyBoolTest.vala"
		doc4 = _tmp81_;
#line 93 "SerializablePropertyBoolTest.vala"
		_tmp82_ = bn;
#line 93 "SerializablePropertyBoolTest.vala"
		_tmp83_ = doc4;
#line 93 "SerializablePropertyBoolTest.vala"
		_tmp84_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp82_, (GXmlNode*) _tmp83_, &_inner_error0_);
#line 93 "SerializablePropertyBoolTest.vala"
		_tmp85_ = _tmp84_;
#line 93 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (_tmp85_);
#line 93 "SerializablePropertyBoolTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 93 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (doc4);
#line 93 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (b3);
#line 93 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (element3);
#line 93 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (doc3);
#line 93 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (b2);
#line 93 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (element2);
#line 93 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (doc2);
#line 93 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (i);
#line 93 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (s);
#line 93 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (b);
#line 93 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (element);
#line 93 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (doc);
#line 93 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (bn);
#line 803 "SerializablePropertyBoolTest.c"
			goto __catch289_g_error;
		}
#line 94 "SerializablePropertyBoolTest.vala"
		_tmp86_ = doc4;
#line 94 "SerializablePropertyBoolTest.vala"
		_tmp87_ = gxml_gnode_to_string ((GXmlGNode*) _tmp86_);
#line 94 "SerializablePropertyBoolTest.vala"
		_tmp88_ = _tmp87_;
#line 94 "SerializablePropertyBoolTest.vala"
		_tmp89_ = g_strconcat ("XML3:\n", _tmp88_, NULL);
#line 94 "SerializablePropertyBoolTest.vala"
		_tmp90_ = _tmp89_;
#line 94 "SerializablePropertyBoolTest.vala"
		g_test_message ("%s", _tmp90_);
#line 94 "SerializablePropertyBoolTest.vala"
		_g_free0 (_tmp90_);
#line 94 "SerializablePropertyBoolTest.vala"
		_g_free0 (_tmp88_);
#line 95 "SerializablePropertyBoolTest.vala"
		_tmp91_ = doc4;
#line 95 "SerializablePropertyBoolTest.vala"
		_tmp92_ = gxml_document_get_root ((GXmlDocument*) _tmp91_);
#line 95 "SerializablePropertyBoolTest.vala"
		_tmp93_ = _tmp92_;
#line 95 "SerializablePropertyBoolTest.vala"
		_tmp94_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp93_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp93_) : NULL;
#line 95 "SerializablePropertyBoolTest.vala"
		if (_tmp94_ == NULL) {
#line 95 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (_tmp93_);
#line 834 "SerializablePropertyBoolTest.c"
		}
#line 95 "SerializablePropertyBoolTest.vala"
		element4 = _tmp94_;
#line 96 "SerializablePropertyBoolTest.vala"
		_tmp95_ = gxml_element_get_attr (element4, "boolean");
#line 96 "SerializablePropertyBoolTest.vala"
		b4 = _tmp95_;
#line 97 "SerializablePropertyBoolTest.vala"
		_vala_assert (b4 == NULL, "b4 == null");
#line 58 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (b4);
#line 58 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (element4);
#line 58 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (doc4);
#line 58 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (b3);
#line 58 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (element3);
#line 58 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (doc3);
#line 58 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (b2);
#line 58 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (element2);
#line 58 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (doc2);
#line 58 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (i);
#line 58 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (s);
#line 58 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (b);
#line 58 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (element);
#line 58 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (doc);
#line 58 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (bn);
#line 874 "SerializablePropertyBoolTest.c"
	}
	goto __finally289;
	__catch289_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp96_;
		const gchar* _tmp97_;
		gchar* _tmp98_;
		gchar* _tmp99_;
#line 58 "SerializablePropertyBoolTest.vala"
		e = _inner_error0_;
#line 58 "SerializablePropertyBoolTest.vala"
		_inner_error0_ = NULL;
#line 99 "SerializablePropertyBoolTest.vala"
		_tmp96_ = e->message;
#line 99 "SerializablePropertyBoolTest.vala"
		_tmp97_ = string_to_string (_tmp96_);
#line 99 "SerializablePropertyBoolTest.vala"
		_tmp98_ = g_strconcat ("ERROR: ", _tmp97_, NULL);
#line 99 "SerializablePropertyBoolTest.vala"
		_tmp99_ = _tmp98_;
#line 99 "SerializablePropertyBoolTest.vala"
		g_test_message ("%s", _tmp99_);
#line 99 "SerializablePropertyBoolTest.vala"
		_g_free0 (_tmp99_);
#line 100 "SerializablePropertyBoolTest.vala"
		g_assert_not_reached ();
#line 58 "SerializablePropertyBoolTest.vala"
		_g_error_free0 (e);
#line 904 "SerializablePropertyBoolTest.c"
	}
	__finally289:
#line 58 "SerializablePropertyBoolTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 58 "SerializablePropertyBoolTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 58 "SerializablePropertyBoolTest.vala"
		g_clear_error (&_inner_error0_);
#line 58 "SerializablePropertyBoolTest.vala"
		return;
#line 915 "SerializablePropertyBoolTest.c"
	}
}

static void
___lambda235__gtest_func (void)
{
#line 56 "SerializablePropertyBoolTest.vala"
	__lambda235_ ();
#line 924 "SerializablePropertyBoolTest.c"
}

static void
__lambda236_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc1 = NULL;
		GXmlGDocument* _tmp0_;
		SerializablePropertyBoolTestBoolNode* b = NULL;
		SerializablePropertyBoolTestBoolNode* _tmp1_;
		SerializablePropertyBoolTestBoolNode* _tmp2_;
		GXmlGDocument* _tmp3_;
		SerializablePropertyBoolTestBoolNode* _tmp4_;
		GXmlSerializableBool* _tmp5_;
		GXmlSerializableBool* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		SerializablePropertyBoolTestBoolNode* _tmp9_;
		GXmlSerializableBool* _tmp10_;
		GXmlSerializableBool* _tmp11_;
#line 106 "SerializablePropertyBoolTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <BooleanNode boolean=\"true\"/>", 0, &_inner_error0_);
#line 106 "SerializablePropertyBoolTest.vala"
		doc1 = _tmp0_;
#line 106 "SerializablePropertyBoolTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 952 "SerializablePropertyBoolTest.c"
			goto __catch290_g_error;
		}
#line 108 "SerializablePropertyBoolTest.vala"
		_tmp1_ = serializable_property_bool_test_bool_node_new ();
#line 108 "SerializablePropertyBoolTest.vala"
		b = _tmp1_;
#line 109 "SerializablePropertyBoolTest.vala"
		_tmp2_ = b;
#line 109 "SerializablePropertyBoolTest.vala"
		_tmp3_ = doc1;
#line 109 "SerializablePropertyBoolTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 109 "SerializablePropertyBoolTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 109 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (b);
#line 109 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (doc1);
#line 971 "SerializablePropertyBoolTest.c"
			goto __catch290_g_error;
		}
#line 110 "SerializablePropertyBoolTest.vala"
		_tmp4_ = b;
#line 110 "SerializablePropertyBoolTest.vala"
		_tmp5_ = serializable_property_bool_test_bool_node_get_boolean (_tmp4_);
#line 110 "SerializablePropertyBoolTest.vala"
		_tmp6_ = _tmp5_;
#line 110 "SerializablePropertyBoolTest.vala"
		_tmp7_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp6_);
#line 110 "SerializablePropertyBoolTest.vala"
		_tmp8_ = _tmp7_;
#line 110 "SerializablePropertyBoolTest.vala"
		_vala_assert (g_strcmp0 (_tmp8_, "true") == 0, "b.boolean.get_serializable_property_value () == \"true\"");
#line 110 "SerializablePropertyBoolTest.vala"
		_g_free0 (_tmp8_);
#line 111 "SerializablePropertyBoolTest.vala"
		_tmp9_ = b;
#line 111 "SerializablePropertyBoolTest.vala"
		_tmp10_ = serializable_property_bool_test_bool_node_get_boolean (_tmp9_);
#line 111 "SerializablePropertyBoolTest.vala"
		_tmp11_ = _tmp10_;
#line 111 "SerializablePropertyBoolTest.vala"
		_vala_assert (gxml_serializable_bool_get_value (_tmp11_) == TRUE, "b.boolean.get_value () == true");
#line 105 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (b);
#line 105 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (doc1);
#line 1000 "SerializablePropertyBoolTest.c"
	}
	goto __finally290;
	__catch290_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp12_;
		const gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
#line 105 "SerializablePropertyBoolTest.vala"
		e = _inner_error0_;
#line 105 "SerializablePropertyBoolTest.vala"
		_inner_error0_ = NULL;
#line 113 "SerializablePropertyBoolTest.vala"
		_tmp12_ = e->message;
#line 113 "SerializablePropertyBoolTest.vala"
		_tmp13_ = string_to_string (_tmp12_);
#line 113 "SerializablePropertyBoolTest.vala"
		_tmp14_ = g_strconcat ("ERROR: ", _tmp13_, NULL);
#line 113 "SerializablePropertyBoolTest.vala"
		_tmp15_ = _tmp14_;
#line 113 "SerializablePropertyBoolTest.vala"
		g_test_message ("%s", _tmp15_);
#line 113 "SerializablePropertyBoolTest.vala"
		_g_free0 (_tmp15_);
#line 114 "SerializablePropertyBoolTest.vala"
		g_assert_not_reached ();
#line 105 "SerializablePropertyBoolTest.vala"
		_g_error_free0 (e);
#line 1030 "SerializablePropertyBoolTest.c"
	}
	__finally290:
#line 105 "SerializablePropertyBoolTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 105 "SerializablePropertyBoolTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 105 "SerializablePropertyBoolTest.vala"
		g_clear_error (&_inner_error0_);
#line 105 "SerializablePropertyBoolTest.vala"
		return;
#line 1041 "SerializablePropertyBoolTest.c"
	}
}

static void
___lambda236__gtest_func (void)
{
#line 103 "SerializablePropertyBoolTest.vala"
	__lambda236_ ();
#line 1050 "SerializablePropertyBoolTest.c"
}

static void
__lambda237_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc1 = NULL;
		GXmlGDocument* _tmp0_;
		SerializablePropertyBoolTestBoolNode* b1 = NULL;
		SerializablePropertyBoolTestBoolNode* _tmp1_;
		SerializablePropertyBoolTestBoolNode* _tmp2_;
		GXmlGDocument* _tmp3_;
		SerializablePropertyBoolTestBoolNode* _tmp4_;
		GXmlSerializableBool* _tmp5_;
		GXmlSerializableBool* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		SerializablePropertyBoolTestBoolNode* _tmp9_;
		GXmlSerializableBool* _tmp10_;
		GXmlSerializableBool* _tmp11_;
		GXmlGDocument* doc2 = NULL;
		GXmlGDocument* _tmp12_;
		SerializablePropertyBoolTestBoolNode* b2 = NULL;
		SerializablePropertyBoolTestBoolNode* _tmp13_;
		SerializablePropertyBoolTestBoolNode* _tmp14_;
		GXmlGDocument* _tmp15_;
		SerializablePropertyBoolTestBoolNode* _tmp16_;
		GXmlSerializableBool* _tmp17_;
		GXmlSerializableBool* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		SerializablePropertyBoolTestBoolNode* _tmp21_;
		GXmlSerializableBool* _tmp22_;
		GXmlSerializableBool* _tmp23_;
		GXmlGDocument* doc3 = NULL;
		GXmlGDocument* _tmp24_;
		SerializablePropertyBoolTestBoolNode* b3 = NULL;
		SerializablePropertyBoolTestBoolNode* _tmp25_;
		SerializablePropertyBoolTestBoolNode* _tmp26_;
		GXmlGDocument* _tmp27_;
		SerializablePropertyBoolTestBoolNode* _tmp28_;
		GXmlSerializableBool* _tmp29_;
		GXmlSerializableBool* _tmp30_;
		gchar* _tmp31_;
		gchar* _tmp32_;
		SerializablePropertyBoolTestBoolNode* _tmp33_;
		GXmlSerializableBool* _tmp34_;
		GXmlSerializableBool* _tmp35_;
#line 120 "SerializablePropertyBoolTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <BooleanNode boolean=\"c\"/>", 0, &_inner_error0_);
#line 120 "SerializablePropertyBoolTest.vala"
		doc1 = _tmp0_;
#line 120 "SerializablePropertyBoolTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1106 "SerializablePropertyBoolTest.c"
			goto __catch291_g_error;
		}
#line 122 "SerializablePropertyBoolTest.vala"
		_tmp1_ = serializable_property_bool_test_bool_node_new ();
#line 122 "SerializablePropertyBoolTest.vala"
		b1 = _tmp1_;
#line 123 "SerializablePropertyBoolTest.vala"
		_tmp2_ = b1;
#line 123 "SerializablePropertyBoolTest.vala"
		_tmp3_ = doc1;
#line 123 "SerializablePropertyBoolTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 123 "SerializablePropertyBoolTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 123 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (b1);
#line 123 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (doc1);
#line 1125 "SerializablePropertyBoolTest.c"
			goto __catch291_g_error;
		}
#line 124 "SerializablePropertyBoolTest.vala"
		_tmp4_ = b1;
#line 124 "SerializablePropertyBoolTest.vala"
		_tmp5_ = serializable_property_bool_test_bool_node_get_boolean (_tmp4_);
#line 124 "SerializablePropertyBoolTest.vala"
		_tmp6_ = _tmp5_;
#line 124 "SerializablePropertyBoolTest.vala"
		_tmp7_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp6_);
#line 124 "SerializablePropertyBoolTest.vala"
		_tmp8_ = _tmp7_;
#line 124 "SerializablePropertyBoolTest.vala"
		_vala_assert (g_strcmp0 (_tmp8_, "c") == 0, "b1.boolean.get_serializable_property_value () == \"c\"");
#line 124 "SerializablePropertyBoolTest.vala"
		_g_free0 (_tmp8_);
#line 125 "SerializablePropertyBoolTest.vala"
		_tmp9_ = b1;
#line 125 "SerializablePropertyBoolTest.vala"
		_tmp10_ = serializable_property_bool_test_bool_node_get_boolean (_tmp9_);
#line 125 "SerializablePropertyBoolTest.vala"
		_tmp11_ = _tmp10_;
#line 125 "SerializablePropertyBoolTest.vala"
		_vala_assert (gxml_serializable_bool_get_value (_tmp11_) == FALSE, "b1.boolean.get_value () == false");
#line 126 "SerializablePropertyBoolTest.vala"
		_tmp12_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <BooleanNode boolean=\"TRUE\"/>", 0, &_inner_error0_);
#line 126 "SerializablePropertyBoolTest.vala"
		doc2 = _tmp12_;
#line 126 "SerializablePropertyBoolTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 126 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (b1);
#line 126 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (doc1);
#line 1160 "SerializablePropertyBoolTest.c"
			goto __catch291_g_error;
		}
#line 128 "SerializablePropertyBoolTest.vala"
		_tmp13_ = serializable_property_bool_test_bool_node_new ();
#line 128 "SerializablePropertyBoolTest.vala"
		b2 = _tmp13_;
#line 129 "SerializablePropertyBoolTest.vala"
		_tmp14_ = b2;
#line 129 "SerializablePropertyBoolTest.vala"
		_tmp15_ = doc2;
#line 129 "SerializablePropertyBoolTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp14_, (GXmlNode*) _tmp15_, &_inner_error0_);
#line 129 "SerializablePropertyBoolTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 129 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (b2);
#line 129 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (doc2);
#line 129 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (b1);
#line 129 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (doc1);
#line 1183 "SerializablePropertyBoolTest.c"
			goto __catch291_g_error;
		}
#line 130 "SerializablePropertyBoolTest.vala"
		_tmp16_ = b2;
#line 130 "SerializablePropertyBoolTest.vala"
		_tmp17_ = serializable_property_bool_test_bool_node_get_boolean (_tmp16_);
#line 130 "SerializablePropertyBoolTest.vala"
		_tmp18_ = _tmp17_;
#line 130 "SerializablePropertyBoolTest.vala"
		_tmp19_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp18_);
#line 130 "SerializablePropertyBoolTest.vala"
		_tmp20_ = _tmp19_;
#line 130 "SerializablePropertyBoolTest.vala"
		_vala_assert (g_strcmp0 (_tmp20_, "TRUE") == 0, "b2.boolean.get_serializable_property_value () == \"TRUE\"");
#line 130 "SerializablePropertyBoolTest.vala"
		_g_free0 (_tmp20_);
#line 131 "SerializablePropertyBoolTest.vala"
		_tmp21_ = b2;
#line 131 "SerializablePropertyBoolTest.vala"
		_tmp22_ = serializable_property_bool_test_bool_node_get_boolean (_tmp21_);
#line 131 "SerializablePropertyBoolTest.vala"
		_tmp23_ = _tmp22_;
#line 131 "SerializablePropertyBoolTest.vala"
		_vala_assert (gxml_serializable_bool_get_value (_tmp23_) == TRUE, "b2.boolean.get_value () == true");
#line 132 "SerializablePropertyBoolTest.vala"
		_tmp24_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <BooleanNode boolean=\"FALSE\"/>", 0, &_inner_error0_);
#line 132 "SerializablePropertyBoolTest.vala"
		doc3 = _tmp24_;
#line 132 "SerializablePropertyBoolTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 132 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (b2);
#line 132 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (doc2);
#line 132 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (b1);
#line 132 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (doc1);
#line 1222 "SerializablePropertyBoolTest.c"
			goto __catch291_g_error;
		}
#line 134 "SerializablePropertyBoolTest.vala"
		_tmp25_ = serializable_property_bool_test_bool_node_new ();
#line 134 "SerializablePropertyBoolTest.vala"
		b3 = _tmp25_;
#line 135 "SerializablePropertyBoolTest.vala"
		_tmp26_ = b3;
#line 135 "SerializablePropertyBoolTest.vala"
		_tmp27_ = doc3;
#line 135 "SerializablePropertyBoolTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp26_, (GXmlNode*) _tmp27_, &_inner_error0_);
#line 135 "SerializablePropertyBoolTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 135 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (b3);
#line 135 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (doc3);
#line 135 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (b2);
#line 135 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (doc2);
#line 135 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (b1);
#line 135 "SerializablePropertyBoolTest.vala"
			_g_object_unref0 (doc1);
#line 1249 "SerializablePropertyBoolTest.c"
			goto __catch291_g_error;
		}
#line 136 "SerializablePropertyBoolTest.vala"
		_tmp28_ = b3;
#line 136 "SerializablePropertyBoolTest.vala"
		_tmp29_ = serializable_property_bool_test_bool_node_get_boolean (_tmp28_);
#line 136 "SerializablePropertyBoolTest.vala"
		_tmp30_ = _tmp29_;
#line 136 "SerializablePropertyBoolTest.vala"
		_tmp31_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp30_);
#line 136 "SerializablePropertyBoolTest.vala"
		_tmp32_ = _tmp31_;
#line 136 "SerializablePropertyBoolTest.vala"
		_vala_assert (g_strcmp0 (_tmp32_, "FALSE") == 0, "b3.boolean.get_serializable_property_value () == \"FALSE\"");
#line 136 "SerializablePropertyBoolTest.vala"
		_g_free0 (_tmp32_);
#line 137 "SerializablePropertyBoolTest.vala"
		_tmp33_ = b3;
#line 137 "SerializablePropertyBoolTest.vala"
		_tmp34_ = serializable_property_bool_test_bool_node_get_boolean (_tmp33_);
#line 137 "SerializablePropertyBoolTest.vala"
		_tmp35_ = _tmp34_;
#line 137 "SerializablePropertyBoolTest.vala"
		_vala_assert (gxml_serializable_bool_get_value (_tmp35_) == FALSE, "b3.boolean.get_value () == false");
#line 119 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (b3);
#line 119 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (doc3);
#line 119 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (b2);
#line 119 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (doc2);
#line 119 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (b1);
#line 119 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (doc1);
#line 1286 "SerializablePropertyBoolTest.c"
	}
	goto __finally291;
	__catch291_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp36_;
		const gchar* _tmp37_;
		gchar* _tmp38_;
		gchar* _tmp39_;
#line 119 "SerializablePropertyBoolTest.vala"
		e = _inner_error0_;
#line 119 "SerializablePropertyBoolTest.vala"
		_inner_error0_ = NULL;
#line 139 "SerializablePropertyBoolTest.vala"
		_tmp36_ = e->message;
#line 139 "SerializablePropertyBoolTest.vala"
		_tmp37_ = string_to_string (_tmp36_);
#line 139 "SerializablePropertyBoolTest.vala"
		_tmp38_ = g_strconcat ("ERROR: ", _tmp37_, NULL);
#line 139 "SerializablePropertyBoolTest.vala"
		_tmp39_ = _tmp38_;
#line 139 "SerializablePropertyBoolTest.vala"
		g_test_message ("%s", _tmp39_);
#line 139 "SerializablePropertyBoolTest.vala"
		_g_free0 (_tmp39_);
#line 140 "SerializablePropertyBoolTest.vala"
		g_assert_not_reached ();
#line 119 "SerializablePropertyBoolTest.vala"
		_g_error_free0 (e);
#line 1316 "SerializablePropertyBoolTest.c"
	}
	__finally291:
#line 119 "SerializablePropertyBoolTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 119 "SerializablePropertyBoolTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 119 "SerializablePropertyBoolTest.vala"
		g_clear_error (&_inner_error0_);
#line 119 "SerializablePropertyBoolTest.vala"
		return;
#line 1327 "SerializablePropertyBoolTest.c"
	}
}

static void
___lambda237__gtest_func (void)
{
#line 117 "SerializablePropertyBoolTest.vala"
	__lambda237_ ();
#line 1336 "SerializablePropertyBoolTest.c"
}

void
serializable_property_bool_test_add_tests (void)
{
#line 37 "SerializablePropertyBoolTest.vala"
	g_test_add_func ("/gxml/serializable/Bool/basic", ___lambda234__gtest_func);
#line 56 "SerializablePropertyBoolTest.vala"
	g_test_add_func ("/gxml/serializable/Bool/changes", ___lambda235__gtest_func);
#line 103 "SerializablePropertyBoolTest.vala"
	g_test_add_func ("/gxml/serializable/Bool/deserialize/basic", ___lambda236__gtest_func);
#line 117 "SerializablePropertyBoolTest.vala"
	g_test_add_func ("/gxml/serializable/Bool/deserialize/invalid", ___lambda237__gtest_func);
#line 1350 "SerializablePropertyBoolTest.c"
}

SerializablePropertyBoolTest*
serializable_property_bool_test_construct (GType object_type)
{
	SerializablePropertyBoolTest* self = NULL;
#line 27 "SerializablePropertyBoolTest.vala"
	self = (SerializablePropertyBoolTest*) gxml_test_construct (object_type);
#line 27 "SerializablePropertyBoolTest.vala"
	return self;
#line 1361 "SerializablePropertyBoolTest.c"
}

SerializablePropertyBoolTest*
serializable_property_bool_test_new (void)
{
#line 27 "SerializablePropertyBoolTest.vala"
	return serializable_property_bool_test_construct (TYPE_SERIALIZABLE_PROPERTY_BOOL_TEST);
#line 1369 "SerializablePropertyBoolTest.c"
}

static inline gpointer
serializable_property_bool_test_bool_node_get_instance_private (SerializablePropertyBoolTestBoolNode* self)
{
	return G_STRUCT_MEMBER_P (self, SerializablePropertyBoolTestBoolNode_private_offset);
}

static gchar*
serializable_property_bool_test_bool_node_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializablePropertyBoolTestBoolNode * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 33 "SerializablePropertyBoolTest.vala"
	self = (SerializablePropertyBoolTestBoolNode*) base;
#line 33 "SerializablePropertyBoolTest.vala"
	_tmp0_ = g_strdup ("BooleanNode");
#line 33 "SerializablePropertyBoolTest.vala"
	result = _tmp0_;
#line 33 "SerializablePropertyBoolTest.vala"
	return result;
#line 1392 "SerializablePropertyBoolTest.c"
}

static gchar*
serializable_property_bool_test_bool_node_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializablePropertyBoolTestBoolNode * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 34 "SerializablePropertyBoolTest.vala"
	self = (SerializablePropertyBoolTestBoolNode*) base;
#line 34 "SerializablePropertyBoolTest.vala"
	_tmp0_ = g_type_name (G_TYPE_FROM_INSTANCE ((GObject*) self));
#line 34 "SerializablePropertyBoolTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 34 "SerializablePropertyBoolTest.vala"
	result = _tmp1_;
#line 34 "SerializablePropertyBoolTest.vala"
	return result;
#line 1412 "SerializablePropertyBoolTest.c"
}

SerializablePropertyBoolTestBoolNode*
serializable_property_bool_test_bool_node_construct (GType object_type)
{
	SerializablePropertyBoolTestBoolNode * self = NULL;
#line 28 "SerializablePropertyBoolTest.vala"
	self = (SerializablePropertyBoolTestBoolNode*) gxml_serializable_object_model_construct (object_type);
#line 28 "SerializablePropertyBoolTest.vala"
	return self;
#line 1423 "SerializablePropertyBoolTest.c"
}

SerializablePropertyBoolTestBoolNode*
serializable_property_bool_test_bool_node_new (void)
{
#line 28 "SerializablePropertyBoolTest.vala"
	return serializable_property_bool_test_bool_node_construct (SERIALIZABLE_PROPERTY_BOOL_TEST_TYPE_BOOL_NODE);
#line 1431 "SerializablePropertyBoolTest.c"
}

GXmlSerializableBool*
serializable_property_bool_test_bool_node_get_boolean (SerializablePropertyBoolTestBoolNode* self)
{
	GXmlSerializableBool* result;
	GXmlSerializableBool* _tmp0_;
#line 30 "SerializablePropertyBoolTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 30 "SerializablePropertyBoolTest.vala"
	_tmp0_ = self->priv->_boolean;
#line 30 "SerializablePropertyBoolTest.vala"
	result = _tmp0_;
#line 30 "SerializablePropertyBoolTest.vala"
	return result;
#line 1447 "SerializablePropertyBoolTest.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 30 "SerializablePropertyBoolTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 1455 "SerializablePropertyBoolTest.c"
}

void
serializable_property_bool_test_bool_node_set_boolean (SerializablePropertyBoolTestBoolNode* self,
                                                       GXmlSerializableBool* value)
{
#line 30 "SerializablePropertyBoolTest.vala"
	g_return_if_fail (self != NULL);
#line 30 "SerializablePropertyBoolTest.vala"
	if (serializable_property_bool_test_bool_node_get_boolean (self) != value) {
#line 1466 "SerializablePropertyBoolTest.c"
		GXmlSerializableBool* _tmp0_;
#line 30 "SerializablePropertyBoolTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 30 "SerializablePropertyBoolTest.vala"
		_g_object_unref0 (self->priv->_boolean);
#line 30 "SerializablePropertyBoolTest.vala"
		self->priv->_boolean = _tmp0_;
#line 30 "SerializablePropertyBoolTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_property_bool_test_bool_node_properties[SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE_BOOLEAN_PROPERTY]);
#line 1476 "SerializablePropertyBoolTest.c"
	}
}

gint
serializable_property_bool_test_bool_node_get_integer (SerializablePropertyBoolTestBoolNode* self)
{
	gint result;
#line 31 "SerializablePropertyBoolTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 31 "SerializablePropertyBoolTest.vala"
	result = self->priv->_integer;
#line 31 "SerializablePropertyBoolTest.vala"
	return result;
#line 1490 "SerializablePropertyBoolTest.c"
}

void
serializable_property_bool_test_bool_node_set_integer (SerializablePropertyBoolTestBoolNode* self,
                                                       gint value)
{
#line 31 "SerializablePropertyBoolTest.vala"
	g_return_if_fail (self != NULL);
#line 31 "SerializablePropertyBoolTest.vala"
	if (serializable_property_bool_test_bool_node_get_integer (self) != value) {
#line 31 "SerializablePropertyBoolTest.vala"
		self->priv->_integer = value;
#line 31 "SerializablePropertyBoolTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_property_bool_test_bool_node_properties[SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE_INTEGER_PROPERTY]);
#line 1505 "SerializablePropertyBoolTest.c"
	}
}

const gchar*
serializable_property_bool_test_bool_node_get_name (SerializablePropertyBoolTestBoolNode* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 32 "SerializablePropertyBoolTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 32 "SerializablePropertyBoolTest.vala"
	_tmp0_ = self->priv->_name;
#line 32 "SerializablePropertyBoolTest.vala"
	result = _tmp0_;
#line 32 "SerializablePropertyBoolTest.vala"
	return result;
#line 1522 "SerializablePropertyBoolTest.c"
}

void
serializable_property_bool_test_bool_node_set_name (SerializablePropertyBoolTestBoolNode* self,
                                                    const gchar* value)
{
#line 32 "SerializablePropertyBoolTest.vala"
	g_return_if_fail (self != NULL);
#line 32 "SerializablePropertyBoolTest.vala"
	if (g_strcmp0 (value, serializable_property_bool_test_bool_node_get_name (self)) != 0) {
#line 1533 "SerializablePropertyBoolTest.c"
		gchar* _tmp0_;
#line 32 "SerializablePropertyBoolTest.vala"
		_tmp0_ = g_strdup (value);
#line 32 "SerializablePropertyBoolTest.vala"
		_g_free0 (self->priv->_name);
#line 32 "SerializablePropertyBoolTest.vala"
		self->priv->_name = _tmp0_;
#line 32 "SerializablePropertyBoolTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_property_bool_test_bool_node_properties[SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE_NAME_PROPERTY]);
#line 1543 "SerializablePropertyBoolTest.c"
	}
}

static void
serializable_property_bool_test_bool_node_class_init (SerializablePropertyBoolTestBoolNodeClass * klass,
                                                      gpointer klass_data)
{
#line 28 "SerializablePropertyBoolTest.vala"
	serializable_property_bool_test_bool_node_parent_class = g_type_class_peek_parent (klass);
#line 28 "SerializablePropertyBoolTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializablePropertyBoolTestBoolNode_private_offset);
#line 28 "SerializablePropertyBoolTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_property_bool_test_bool_node_real_node_name;
#line 28 "SerializablePropertyBoolTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_property_bool_test_bool_node_real_to_string;
#line 28 "SerializablePropertyBoolTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_property_bool_test_bool_node_get_property;
#line 28 "SerializablePropertyBoolTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_property_bool_test_bool_node_set_property;
#line 28 "SerializablePropertyBoolTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_property_bool_test_bool_node_finalize;
#line 28 "SerializablePropertyBoolTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE_BOOLEAN_PROPERTY, serializable_property_bool_test_bool_node_properties[SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE_BOOLEAN_PROPERTY] = g_param_spec_object ("boolean", "boolean", "boolean", GXML_TYPE_SERIALIZABLE_BOOL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 28 "SerializablePropertyBoolTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE_INTEGER_PROPERTY, serializable_property_bool_test_bool_node_properties[SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE_INTEGER_PROPERTY] = g_param_spec_int ("integer", "integer", "integer", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 28 "SerializablePropertyBoolTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE_NAME_PROPERTY, serializable_property_bool_test_bool_node_properties[SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1571 "SerializablePropertyBoolTest.c"
}

static void
serializable_property_bool_test_bool_node_instance_init (SerializablePropertyBoolTestBoolNode * self,
                                                         gpointer klass)
{
#line 28 "SerializablePropertyBoolTest.vala"
	self->priv = serializable_property_bool_test_bool_node_get_instance_private (self);
#line 31 "SerializablePropertyBoolTest.vala"
	self->priv->_integer = 0;
#line 1582 "SerializablePropertyBoolTest.c"
}

static void
serializable_property_bool_test_bool_node_finalize (GObject * obj)
{
	SerializablePropertyBoolTestBoolNode * self;
#line 28 "SerializablePropertyBoolTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_PROPERTY_BOOL_TEST_TYPE_BOOL_NODE, SerializablePropertyBoolTestBoolNode);
#line 30 "SerializablePropertyBoolTest.vala"
	_g_object_unref0 (self->priv->_boolean);
#line 32 "SerializablePropertyBoolTest.vala"
	_g_free0 (self->priv->_name);
#line 28 "SerializablePropertyBoolTest.vala"
	G_OBJECT_CLASS (serializable_property_bool_test_bool_node_parent_class)->finalize (obj);
#line 1597 "SerializablePropertyBoolTest.c"
}

GType
serializable_property_bool_test_bool_node_get_type (void)
{
	static volatile gsize serializable_property_bool_test_bool_node_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_property_bool_test_bool_node_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializablePropertyBoolTestBoolNodeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_property_bool_test_bool_node_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializablePropertyBoolTestBoolNode), 0, (GInstanceInitFunc) serializable_property_bool_test_bool_node_instance_init, NULL };
		GType serializable_property_bool_test_bool_node_type_id;
		serializable_property_bool_test_bool_node_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializablePropertyBoolTestBoolNode", &g_define_type_info, 0);
		SerializablePropertyBoolTestBoolNode_private_offset = g_type_add_instance_private (serializable_property_bool_test_bool_node_type_id, sizeof (SerializablePropertyBoolTestBoolNodePrivate));
		g_once_init_leave (&serializable_property_bool_test_bool_node_type_id__volatile, serializable_property_bool_test_bool_node_type_id);
	}
	return serializable_property_bool_test_bool_node_type_id__volatile;
}

static void
_vala_serializable_property_bool_test_bool_node_get_property (GObject * object,
                                                              guint property_id,
                                                              GValue * value,
                                                              GParamSpec * pspec)
{
	SerializablePropertyBoolTestBoolNode * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_PROPERTY_BOOL_TEST_TYPE_BOOL_NODE, SerializablePropertyBoolTestBoolNode);
#line 28 "SerializablePropertyBoolTest.vala"
	switch (property_id) {
#line 28 "SerializablePropertyBoolTest.vala"
		case SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE_BOOLEAN_PROPERTY:
#line 28 "SerializablePropertyBoolTest.vala"
		g_value_set_object (value, serializable_property_bool_test_bool_node_get_boolean (self));
#line 28 "SerializablePropertyBoolTest.vala"
		break;
#line 28 "SerializablePropertyBoolTest.vala"
		case SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE_INTEGER_PROPERTY:
#line 28 "SerializablePropertyBoolTest.vala"
		g_value_set_int (value, serializable_property_bool_test_bool_node_get_integer (self));
#line 28 "SerializablePropertyBoolTest.vala"
		break;
#line 28 "SerializablePropertyBoolTest.vala"
		case SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE_NAME_PROPERTY:
#line 28 "SerializablePropertyBoolTest.vala"
		g_value_set_string (value, serializable_property_bool_test_bool_node_get_name (self));
#line 28 "SerializablePropertyBoolTest.vala"
		break;
#line 1642 "SerializablePropertyBoolTest.c"
		default:
#line 28 "SerializablePropertyBoolTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 28 "SerializablePropertyBoolTest.vala"
		break;
#line 1648 "SerializablePropertyBoolTest.c"
	}
}

static void
_vala_serializable_property_bool_test_bool_node_set_property (GObject * object,
                                                              guint property_id,
                                                              const GValue * value,
                                                              GParamSpec * pspec)
{
	SerializablePropertyBoolTestBoolNode * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_PROPERTY_BOOL_TEST_TYPE_BOOL_NODE, SerializablePropertyBoolTestBoolNode);
#line 28 "SerializablePropertyBoolTest.vala"
	switch (property_id) {
#line 28 "SerializablePropertyBoolTest.vala"
		case SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE_BOOLEAN_PROPERTY:
#line 28 "SerializablePropertyBoolTest.vala"
		serializable_property_bool_test_bool_node_set_boolean (self, g_value_get_object (value));
#line 28 "SerializablePropertyBoolTest.vala"
		break;
#line 28 "SerializablePropertyBoolTest.vala"
		case SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE_INTEGER_PROPERTY:
#line 28 "SerializablePropertyBoolTest.vala"
		serializable_property_bool_test_bool_node_set_integer (self, g_value_get_int (value));
#line 28 "SerializablePropertyBoolTest.vala"
		break;
#line 28 "SerializablePropertyBoolTest.vala"
		case SERIALIZABLE_PROPERTY_BOOL_TEST_BOOL_NODE_NAME_PROPERTY:
#line 28 "SerializablePropertyBoolTest.vala"
		serializable_property_bool_test_bool_node_set_name (self, g_value_get_string (value));
#line 28 "SerializablePropertyBoolTest.vala"
		break;
#line 1680 "SerializablePropertyBoolTest.c"
		default:
#line 28 "SerializablePropertyBoolTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 28 "SerializablePropertyBoolTest.vala"
		break;
#line 1686 "SerializablePropertyBoolTest.c"
	}
}

static void
serializable_property_bool_test_class_init (SerializablePropertyBoolTestClass * klass,
                                            gpointer klass_data)
{
#line 27 "SerializablePropertyBoolTest.vala"
	serializable_property_bool_test_parent_class = g_type_class_peek_parent (klass);
#line 1696 "SerializablePropertyBoolTest.c"
}

static void
serializable_property_bool_test_instance_init (SerializablePropertyBoolTest * self,
                                               gpointer klass)
{
}

/**
 *
 *  SerializablePropertyBoolTest.vala
 *
 *  Authors:
 *
 *       Daniel Espinosa <esodan@gmail.com>
 *
 *
 *  Copyright (c) 2015 Daniel Espinosa
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
GType
serializable_property_bool_test_get_type (void)
{
	static volatile gsize serializable_property_bool_test_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_property_bool_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializablePropertyBoolTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_property_bool_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializablePropertyBoolTest), 0, (GInstanceInitFunc) serializable_property_bool_test_instance_init, NULL };
		GType serializable_property_bool_test_type_id;
		serializable_property_bool_test_type_id = g_type_register_static (TYPE_GXML_TEST, "SerializablePropertyBoolTest", &g_define_type_info, 0);
		g_once_init_leave (&serializable_property_bool_test_type_id__volatile, serializable_property_bool_test_type_id);
	}
	return serializable_property_bool_test_type_id__volatile;
}

