/* SerializableGeeDualKeyMapTest.c generated by valac 0.44.3, the Vala compiler
 * generated from SerializableGeeDualKeyMapTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */

#include <gxml/gxml.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <stdio.h>
#include <gee.h>

#define TYPE_SPACES (spaces_get_type ())
#define SPACES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SPACES, Spaces))
#define SPACES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SPACES, SpacesClass))
#define IS_SPACES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SPACES))
#define IS_SPACES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SPACES))
#define SPACES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SPACES, SpacesClass))

typedef struct _Spaces Spaces;
typedef struct _SpacesClass SpacesClass;
typedef struct _SpacesPrivate SpacesPrivate;
enum  {
	SPACES_0_PROPERTY,
	SPACES_NAME_PROPERTY,
	SPACES_OWNER_PROPERTY,
	SPACES_NUM_PROPERTIES
};
static GParamSpec* spaces_properties[SPACES_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST (serializable_gee_dual_key_map_test_get_type ())
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST, SerializableGeeDualKeyMapTest))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST, SerializableGeeDualKeyMapTestClass))
#define IS_SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST))
#define IS_SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST, SerializableGeeDualKeyMapTestClass))

typedef struct _SerializableGeeDualKeyMapTest SerializableGeeDualKeyMapTest;
typedef struct _SerializableGeeDualKeyMapTestClass SerializableGeeDualKeyMapTestClass;
typedef struct _SerializableGeeDualKeyMapTestPrivate SerializableGeeDualKeyMapTestPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define TYPE_BOOK_STORE (book_store_get_type ())
#define BOOK_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BOOK_STORE, BookStore))
#define BOOK_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BOOK_STORE, BookStoreClass))
#define IS_BOOK_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BOOK_STORE))
#define IS_BOOK_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BOOK_STORE))
#define BOOK_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BOOK_STORE, BookStoreClass))

typedef struct _BookStore BookStore;
typedef struct _BookStoreClass BookStoreClass;

#define BOOK_TYPE_ARRAY (book_array_get_type ())
#define BOOK_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOOK_TYPE_ARRAY, BookArray))
#define BOOK_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOOK_TYPE_ARRAY, BookArrayClass))
#define BOOK_IS_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOOK_TYPE_ARRAY))
#define BOOK_IS_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOOK_TYPE_ARRAY))
#define BOOK_ARRAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOOK_TYPE_ARRAY, BookArrayClass))

typedef struct _BookArray BookArray;
typedef struct _BookArrayClass BookArrayClass;

#define TYPE_BOOK (book_get_type ())
#define BOOK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BOOK, Book))
#define BOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BOOK, BookClass))
#define IS_BOOK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BOOK))
#define IS_BOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BOOK))
#define BOOK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BOOK, BookClass))

typedef struct _Book Book;
typedef struct _BookClass BookClass;

#define TYPE_NAME (name_get_type ())
#define NAME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_NAME, Name))
#define NAME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_NAME, NameClass))
#define IS_NAME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_NAME))
#define IS_NAME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_NAME))
#define NAME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_NAME, NameClass))

typedef struct _Name Name;
typedef struct _NameClass NameClass;

#define TYPE_AUTHORS (authors_get_type ())
#define AUTHORS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_AUTHORS, Authors))
#define AUTHORS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_AUTHORS, AuthorsClass))
#define IS_AUTHORS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_AUTHORS))
#define IS_AUTHORS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_AUTHORS))
#define AUTHORS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_AUTHORS, AuthorsClass))

typedef struct _Authors Authors;
typedef struct _AuthorsClass AuthorsClass;

#define AUTHOR_TYPE_ARRAY (author_array_get_type ())
#define AUTHOR_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), AUTHOR_TYPE_ARRAY, AuthorArray))
#define AUTHOR_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), AUTHOR_TYPE_ARRAY, AuthorArrayClass))
#define AUTHOR_IS_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), AUTHOR_TYPE_ARRAY))
#define AUTHOR_IS_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), AUTHOR_TYPE_ARRAY))
#define AUTHOR_ARRAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), AUTHOR_TYPE_ARRAY, AuthorArrayClass))

typedef struct _AuthorArray AuthorArray;
typedef struct _AuthorArrayClass AuthorArrayClass;

#define INVENTORY_TYPE_DUAL_KEY_MAP (inventory_dual_key_map_get_type ())
#define INVENTORY_DUAL_KEY_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), INVENTORY_TYPE_DUAL_KEY_MAP, InventoryDualKeyMap))
#define INVENTORY_DUAL_KEY_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), INVENTORY_TYPE_DUAL_KEY_MAP, InventoryDualKeyMapClass))
#define INVENTORY_IS_DUAL_KEY_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), INVENTORY_TYPE_DUAL_KEY_MAP))
#define INVENTORY_IS_DUAL_KEY_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), INVENTORY_TYPE_DUAL_KEY_MAP))
#define INVENTORY_DUAL_KEY_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), INVENTORY_TYPE_DUAL_KEY_MAP, InventoryDualKeyMapClass))

typedef struct _InventoryDualKeyMap InventoryDualKeyMap;
typedef struct _InventoryDualKeyMapClass InventoryDualKeyMapClass;

#define TYPE_INVENTORY (inventory_get_type ())
#define INVENTORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_INVENTORY, Inventory))
#define INVENTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_INVENTORY, InventoryClass))
#define IS_INVENTORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_INVENTORY))
#define IS_INVENTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_INVENTORY))
#define INVENTORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_INVENTORY, InventoryClass))

typedef struct _Inventory Inventory;
typedef struct _InventoryClass InventoryClass;

#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BIG_BAG (serializable_gee_dual_key_map_test_big_bag_get_type ())
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BIG_BAG, SerializableGeeDualKeyMapTestBigBag))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BIG_BAG, SerializableGeeDualKeyMapTestBigBagClass))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_IS_BIG_BAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BIG_BAG))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_IS_BIG_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BIG_BAG))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BIG_BAG, SerializableGeeDualKeyMapTestBigBagClass))

typedef struct _SerializableGeeDualKeyMapTestBigBag SerializableGeeDualKeyMapTestBigBag;
typedef struct _SerializableGeeDualKeyMapTestBigBagClass SerializableGeeDualKeyMapTestBigBagClass;

#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_TYPE_DUAL_MAP (serializable_gee_dual_key_map_test_small_bag_dual_map_get_type ())
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_DUAL_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_TYPE_DUAL_MAP, SerializableGeeDualKeyMapTestSmallBagDualMap))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_DUAL_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_TYPE_DUAL_MAP, SerializableGeeDualKeyMapTestSmallBagDualMapClass))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_IS_DUAL_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_TYPE_DUAL_MAP))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_IS_DUAL_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_TYPE_DUAL_MAP))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_DUAL_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_TYPE_DUAL_MAP, SerializableGeeDualKeyMapTestSmallBagDualMapClass))

typedef struct _SerializableGeeDualKeyMapTestSmallBagDualMap SerializableGeeDualKeyMapTestSmallBagDualMap;
typedef struct _SerializableGeeDualKeyMapTestSmallBagDualMapClass SerializableGeeDualKeyMapTestSmallBagDualMapClass;

#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_SMALL_BAG (serializable_gee_dual_key_map_test_small_bag_get_type ())
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeDualKeyMapTestSmallBag))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeDualKeyMapTestSmallBagClass))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_IS_SMALL_BAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_SMALL_BAG))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_IS_SMALL_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_SMALL_BAG))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeDualKeyMapTestSmallBagClass))

typedef struct _SerializableGeeDualKeyMapTestSmallBag SerializableGeeDualKeyMapTestSmallBag;
typedef struct _SerializableGeeDualKeyMapTestSmallBagClass SerializableGeeDualKeyMapTestSmallBagClass;

#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_TYPE_DUAL_MAP (serializable_gee_dual_key_map_test_ball_dual_map_get_type ())
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_DUAL_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_TYPE_DUAL_MAP, SerializableGeeDualKeyMapTestBallDualMap))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_DUAL_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_TYPE_DUAL_MAP, SerializableGeeDualKeyMapTestBallDualMapClass))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_IS_DUAL_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_TYPE_DUAL_MAP))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_IS_DUAL_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_TYPE_DUAL_MAP))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_DUAL_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_TYPE_DUAL_MAP, SerializableGeeDualKeyMapTestBallDualMapClass))

typedef struct _SerializableGeeDualKeyMapTestBallDualMap SerializableGeeDualKeyMapTestBallDualMap;
typedef struct _SerializableGeeDualKeyMapTestBallDualMapClass SerializableGeeDualKeyMapTestBallDualMapClass;

#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL (serializable_gee_dual_key_map_test_ball_get_type ())
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL, SerializableGeeDualKeyMapTestBall))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL, SerializableGeeDualKeyMapTestBallClass))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_IS_BALL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_IS_BALL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL, SerializableGeeDualKeyMapTestBallClass))

typedef struct _SerializableGeeDualKeyMapTestBall SerializableGeeDualKeyMapTestBall;
typedef struct _SerializableGeeDualKeyMapTestBallClass SerializableGeeDualKeyMapTestBallClass;

#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL_FILL (serializable_gee_dual_key_map_test_ball_fill_get_type ())
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL_FILL, SerializableGeeDualKeyMapTestBallFill))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL_FILL, SerializableGeeDualKeyMapTestBallFillClass))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_IS_BALL_FILL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL_FILL))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_IS_BALL_FILL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL_FILL))
#define SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL_FILL, SerializableGeeDualKeyMapTestBallFillClass))

typedef struct _SerializableGeeDualKeyMapTestBallFill SerializableGeeDualKeyMapTestBallFill;
typedef struct _SerializableGeeDualKeyMapTestBallFillClass SerializableGeeDualKeyMapTestBallFillClass;
typedef struct _SerializableGeeDualKeyMapTestBallFillPrivate SerializableGeeDualKeyMapTestBallFillPrivate;
enum  {
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_0_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_NAME_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_dual_key_map_test_ball_fill_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_NUM_PROPERTIES];
typedef struct _SerializableGeeDualKeyMapTestBallPrivate SerializableGeeDualKeyMapTestBallPrivate;
enum  {
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_0_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_NAME_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_SIZE_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_BALLFILL_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_dual_key_map_test_ball_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_NUM_PROPERTIES];
typedef struct _SerializableGeeDualKeyMapTestBallDualMapPrivate SerializableGeeDualKeyMapTestBallDualMapPrivate;
enum  {
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_DUAL_MAP_0_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_DUAL_MAP_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_dual_key_map_test_ball_dual_map_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_DUAL_MAP_NUM_PROPERTIES];
typedef struct _SerializableGeeDualKeyMapTestSmallBagPrivate SerializableGeeDualKeyMapTestSmallBagPrivate;
enum  {
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_0_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_NAME_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_CASH_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_BALLS_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_dual_key_map_test_small_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_NUM_PROPERTIES];
typedef struct _SerializableGeeDualKeyMapTestSmallBagDualMapPrivate SerializableGeeDualKeyMapTestSmallBagDualMapPrivate;
enum  {
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_DUAL_MAP_0_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_DUAL_MAP_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_dual_key_map_test_small_bag_dual_map_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_DUAL_MAP_NUM_PROPERTIES];
typedef struct _SerializableGeeDualKeyMapTestBigBagPrivate SerializableGeeDualKeyMapTestBigBagPrivate;
enum  {
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_0_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_NAME_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_BAGS_PROPERTY,
	SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_dual_key_map_test_big_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_NUM_PROPERTIES];
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _Spaces {
	GXmlSerializableObjectModel parent_instance;
	SpacesPrivate * priv;
};

struct _SpacesClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SpacesPrivate {
	gchar* _name;
	gchar* _owner;
};

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _SerializableGeeDualKeyMapTest {
	GXmlTest parent_instance;
	SerializableGeeDualKeyMapTestPrivate * priv;
};

struct _SerializableGeeDualKeyMapTestClass {
	GXmlTestClass parent_class;
};

struct _SerializableGeeDualKeyMapTestBallFill {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeDualKeyMapTestBallFillPrivate * priv;
};

struct _SerializableGeeDualKeyMapTestBallFillClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeDualKeyMapTestBallFillPrivate {
	gchar* _name;
};

struct _SerializableGeeDualKeyMapTestBall {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeDualKeyMapTestBallPrivate * priv;
};

struct _SerializableGeeDualKeyMapTestBallClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeDualKeyMapTestBallPrivate {
	gchar* _name;
	gchar* _size;
	SerializableGeeDualKeyMapTestBallFill* _ballfill;
};

struct _SerializableGeeDualKeyMapTestBallDualMap {
	GXmlSerializableDualKeyMap parent_instance;
	SerializableGeeDualKeyMapTestBallDualMapPrivate * priv;
};

struct _SerializableGeeDualKeyMapTestBallDualMapClass {
	GXmlSerializableDualKeyMapClass parent_class;
};

struct _SerializableGeeDualKeyMapTestSmallBag {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeDualKeyMapTestSmallBagPrivate * priv;
};

struct _SerializableGeeDualKeyMapTestSmallBagClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeDualKeyMapTestSmallBagPrivate {
	gchar* _name;
	gchar* _cash;
	SerializableGeeDualKeyMapTestBallDualMap* _balls;
};

struct _SerializableGeeDualKeyMapTestSmallBagDualMap {
	GXmlSerializableDualKeyMap parent_instance;
	SerializableGeeDualKeyMapTestSmallBagDualMapPrivate * priv;
};

struct _SerializableGeeDualKeyMapTestSmallBagDualMapClass {
	GXmlSerializableDualKeyMapClass parent_class;
};

struct _SerializableGeeDualKeyMapTestBigBag {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeDualKeyMapTestBigBagPrivate * priv;
};

struct _SerializableGeeDualKeyMapTestBigBagClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeDualKeyMapTestBigBagPrivate {
	gchar* _name;
	SerializableGeeDualKeyMapTestSmallBagDualMap* _bags;
};

static gint Spaces_private_offset;
static gpointer spaces_parent_class = NULL;
static GXmlSerializableMapDualKeyIface * spaces_gxml_serializable_map_dual_key_parent_iface = NULL;
static gpointer serializable_gee_dual_key_map_test_parent_class = NULL;
static gint SerializableGeeDualKeyMapTestBallFill_private_offset;
static gpointer serializable_gee_dual_key_map_test_ball_fill_parent_class = NULL;
static gint SerializableGeeDualKeyMapTestBall_private_offset;
static gpointer serializable_gee_dual_key_map_test_ball_parent_class = NULL;
static gpointer serializable_gee_dual_key_map_test_ball_dual_map_parent_class = NULL;
static GXmlSerializableMapDualKeyIface * serializable_gee_dual_key_map_test_ball_gxml_serializable_map_dual_key_parent_iface = NULL;
static gint SerializableGeeDualKeyMapTestSmallBag_private_offset;
static gpointer serializable_gee_dual_key_map_test_small_bag_parent_class = NULL;
static gpointer serializable_gee_dual_key_map_test_small_bag_dual_map_parent_class = NULL;
static GXmlSerializableMapDualKeyIface * serializable_gee_dual_key_map_test_small_bag_gxml_serializable_map_dual_key_parent_iface = NULL;
static gint SerializableGeeDualKeyMapTestBigBag_private_offset;
static gpointer serializable_gee_dual_key_map_test_big_bag_parent_class = NULL;

GType spaces_get_type (void) G_GNUC_CONST;
static gchar* spaces_real_get_map_primary_key (GXmlSerializableMapDualKey* base);
const gchar* spaces_get_owner (Spaces* self);
static gchar* spaces_real_get_map_secondary_key (GXmlSerializableMapDualKey* base);
const gchar* spaces_get_name (Spaces* self);
Spaces* spaces_new_full (const gchar* owner,
                         const gchar* name);
Spaces* spaces_construct_full (GType object_type,
                               const gchar* owner,
                               const gchar* name);
void spaces_set_name (Spaces* self,
                      const gchar* value);
void spaces_set_owner (Spaces* self,
                       const gchar* value);
static gchar* spaces_real_to_string (GXmlSerializableObjectModel* base);
Spaces* spaces_new (void);
Spaces* spaces_construct (GType object_type);
static void spaces_finalize (GObject * obj);
static void _vala_spaces_get_property (GObject * object,
                                guint property_id,
                                GValue * value,
                                GParamSpec * pspec);
static void _vala_spaces_set_property (GObject * object,
                                guint property_id,
                                const GValue * value,
                                GParamSpec * pspec);
gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType serializable_gee_dual_key_map_test_get_type (void) G_GNUC_CONST;
void serializable_gee_dual_key_map_test_add_tests (void);
static void __lambda299_ (void);
static void ___lambda299__gtest_func (void);
static void __lambda300_ (void);
static void ___lambda300__gtest_func (void);
static void __lambda301_ (void);
static void ___lambda301__gtest_func (void);
static void __lambda302_ (void);
static void ___lambda302__gtest_func (void);
static void __lambda303_ (void);
GType book_store_get_type (void) G_GNUC_CONST;
BookStore* book_store_new (void);
BookStore* book_store_construct (GType object_type);
const gchar* book_store_get_name (BookStore* self);
GType book_array_get_type (void) G_GNUC_CONST;
BookArray* book_store_get_books (BookStore* self);
GType book_get_type (void) G_GNUC_CONST;
GType name_get_type (void) G_GNUC_CONST;
Name* book_get_name (Book* self);
gchar* name_get_name (Name* self);
const gchar* book_get_year (Book* self);
GType authors_get_type (void) G_GNUC_CONST;
Authors* book_get_authors (Book* self);
GType author_array_get_type (void) G_GNUC_CONST;
AuthorArray* authors_get_array (Authors* self);
GType inventory_dual_key_map_get_type (void) G_GNUC_CONST;
InventoryDualKeyMap* book_get_inventory_registers (Book* self);
GType inventory_get_type (void) G_GNUC_CONST;
gint inventory_get_number (Inventory* self);
const gchar* inventory_get_inventory (Inventory* self);
gint inventory_get_row (Inventory* self);
static void ___lambda303__gtest_func (void);
static void __lambda304_ (void);
static GType serializable_gee_dual_key_map_test_big_bag_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeDualKeyMapTestBigBag* serializable_gee_dual_key_map_test_big_bag_new (void);
static SerializableGeeDualKeyMapTestBigBag* serializable_gee_dual_key_map_test_big_bag_construct (GType object_type);
GType serializable_gee_dual_key_map_test_small_bag_dual_map_get_type (void) G_GNUC_CONST;
static SerializableGeeDualKeyMapTestSmallBagDualMap* serializable_gee_dual_key_map_test_big_bag_get_bags (SerializableGeeDualKeyMapTestBigBag* self);
static GType serializable_gee_dual_key_map_test_small_bag_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeDualKeyMapTestSmallBag* serializable_gee_dual_key_map_test_small_bag_new (void);
static SerializableGeeDualKeyMapTestSmallBag* serializable_gee_dual_key_map_test_small_bag_construct (GType object_type);
static void serializable_gee_dual_key_map_test_small_bag_set_name (SerializableGeeDualKeyMapTestSmallBag* self,
                                                            const gchar* value);
GType serializable_gee_dual_key_map_test_ball_dual_map_get_type (void) G_GNUC_CONST;
static SerializableGeeDualKeyMapTestBallDualMap* serializable_gee_dual_key_map_test_small_bag_get_balls (SerializableGeeDualKeyMapTestSmallBag* self);
static GType serializable_gee_dual_key_map_test_ball_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeDualKeyMapTestBall* serializable_gee_dual_key_map_test_ball_new (void);
static SerializableGeeDualKeyMapTestBall* serializable_gee_dual_key_map_test_ball_construct (GType object_type);
static void serializable_gee_dual_key_map_test_ball_set_name (SerializableGeeDualKeyMapTestBall* self,
                                                       const gchar* value);
static SerializableGeeDualKeyMapTestBallFill* serializable_gee_dual_key_map_test_ball_fill_new (void);
static SerializableGeeDualKeyMapTestBallFill* serializable_gee_dual_key_map_test_ball_fill_construct (GType object_type);
static GType serializable_gee_dual_key_map_test_ball_fill_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static void serializable_gee_dual_key_map_test_ball_set_ballfill (SerializableGeeDualKeyMapTestBall* self,
                                                           SerializableGeeDualKeyMapTestBallFill* value);
static SerializableGeeDualKeyMapTestBallFill* serializable_gee_dual_key_map_test_ball_get_ballfill (SerializableGeeDualKeyMapTestBall* self);
static void serializable_gee_dual_key_map_test_ball_fill_set_text (SerializableGeeDualKeyMapTestBallFill* self,
                                                            const gchar* txt);
static const gchar* serializable_gee_dual_key_map_test_ball_get_size (SerializableGeeDualKeyMapTestBall* self);
static const gchar* serializable_gee_dual_key_map_test_ball_get_name (SerializableGeeDualKeyMapTestBall* self);
static const gchar* serializable_gee_dual_key_map_test_small_bag_get_cash (SerializableGeeDualKeyMapTestSmallBag* self);
static const gchar* serializable_gee_dual_key_map_test_small_bag_get_name (SerializableGeeDualKeyMapTestSmallBag* self);
static void ___lambda304__gtest_func (void);
SerializableGeeDualKeyMapTest* serializable_gee_dual_key_map_test_new (void);
SerializableGeeDualKeyMapTest* serializable_gee_dual_key_map_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static gchar* serializable_gee_dual_key_map_test_ball_fill_real_to_string (GXmlSerializableObjectModel* base);
static const gchar* serializable_gee_dual_key_map_test_ball_fill_get_name (SerializableGeeDualKeyMapTestBallFill* self);
static gchar* serializable_gee_dual_key_map_test_ball_fill_real_node_name (GXmlSerializableObjectModel* base);
static gboolean serializable_gee_dual_key_map_test_ball_fill_real_serialize_use_xml_node_value (GXmlSerializableObjectModel* base);
static void serializable_gee_dual_key_map_test_ball_fill_set_name (SerializableGeeDualKeyMapTestBallFill* self,
                                                            const gchar* value);
static void serializable_gee_dual_key_map_test_ball_fill_finalize (GObject * obj);
static void _vala_serializable_gee_dual_key_map_test_ball_fill_get_property (GObject * object,
                                                                      guint property_id,
                                                                      GValue * value,
                                                                      GParamSpec * pspec);
static void _vala_serializable_gee_dual_key_map_test_ball_fill_set_property (GObject * object,
                                                                      guint property_id,
                                                                      const GValue * value,
                                                                      GParamSpec * pspec);
static gchar* serializable_gee_dual_key_map_test_ball_real_to_string (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_dual_key_map_test_ball_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_dual_key_map_test_ball_real_get_map_primary_key (GXmlSerializableMapDualKey* base);
static gchar* serializable_gee_dual_key_map_test_ball_real_get_map_secondary_key (GXmlSerializableMapDualKey* base);
static void serializable_gee_dual_key_map_test_ball_set_size (SerializableGeeDualKeyMapTestBall* self,
                                                       const gchar* value);
static gboolean serializable_gee_dual_key_map_test_ball_dual_map_real_deserialize_proceed (GXmlSerializableDualKeyMap* base);
static SerializableGeeDualKeyMapTestBallDualMap* serializable_gee_dual_key_map_test_ball_dual_map_new (void);
static SerializableGeeDualKeyMapTestBallDualMap* serializable_gee_dual_key_map_test_ball_dual_map_construct (GType object_type);
static void serializable_gee_dual_key_map_test_ball_finalize (GObject * obj);
static void _vala_serializable_gee_dual_key_map_test_ball_get_property (GObject * object,
                                                                 guint property_id,
                                                                 GValue * value,
                                                                 GParamSpec * pspec);
static void _vala_serializable_gee_dual_key_map_test_ball_set_property (GObject * object,
                                                                 guint property_id,
                                                                 const GValue * value,
                                                                 GParamSpec * pspec);
static gchar* serializable_gee_dual_key_map_test_small_bag_real_to_string (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_dual_key_map_test_small_bag_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_dual_key_map_test_small_bag_real_get_map_primary_key (GXmlSerializableMapDualKey* base);
static gchar* serializable_gee_dual_key_map_test_small_bag_real_get_map_secondary_key (GXmlSerializableMapDualKey* base);
static void serializable_gee_dual_key_map_test_small_bag_set_cash (SerializableGeeDualKeyMapTestSmallBag* self,
                                                            const gchar* value);
static void serializable_gee_dual_key_map_test_small_bag_set_balls (SerializableGeeDualKeyMapTestSmallBag* self,
                                                             SerializableGeeDualKeyMapTestBallDualMap* value);
static gboolean serializable_gee_dual_key_map_test_small_bag_dual_map_real_deserialize_proceed (GXmlSerializableDualKeyMap* base);
static SerializableGeeDualKeyMapTestSmallBagDualMap* serializable_gee_dual_key_map_test_small_bag_dual_map_new (void);
static SerializableGeeDualKeyMapTestSmallBagDualMap* serializable_gee_dual_key_map_test_small_bag_dual_map_construct (GType object_type);
static void serializable_gee_dual_key_map_test_small_bag_finalize (GObject * obj);
static void _vala_serializable_gee_dual_key_map_test_small_bag_get_property (GObject * object,
                                                                      guint property_id,
                                                                      GValue * value,
                                                                      GParamSpec * pspec);
static void _vala_serializable_gee_dual_key_map_test_small_bag_set_property (GObject * object,
                                                                      guint property_id,
                                                                      const GValue * value,
                                                                      GParamSpec * pspec);
static gchar* serializable_gee_dual_key_map_test_big_bag_real_to_string (GXmlSerializableObjectModel* base);
static const gchar* serializable_gee_dual_key_map_test_big_bag_get_name (SerializableGeeDualKeyMapTestBigBag* self);
static gchar* serializable_gee_dual_key_map_test_big_bag_real_node_name (GXmlSerializableObjectModel* base);
static void serializable_gee_dual_key_map_test_big_bag_set_name (SerializableGeeDualKeyMapTestBigBag* self,
                                                          const gchar* value);
static void serializable_gee_dual_key_map_test_big_bag_set_bags (SerializableGeeDualKeyMapTestBigBag* self,
                                                          SerializableGeeDualKeyMapTestSmallBagDualMap* value);
static void serializable_gee_dual_key_map_test_big_bag_finalize (GObject * obj);
static void _vala_serializable_gee_dual_key_map_test_big_bag_get_property (GObject * object,
                                                                    guint property_id,
                                                                    GValue * value,
                                                                    GParamSpec * pspec);
static void _vala_serializable_gee_dual_key_map_test_big_bag_set_property (GObject * object,
                                                                    guint property_id,
                                                                    const GValue * value,
                                                                    GParamSpec * pspec);

static inline gpointer
spaces_get_instance_private (Spaces* self)
{
	return G_STRUCT_MEMBER_P (self, Spaces_private_offset);
}

static gchar*
spaces_real_get_map_primary_key (GXmlSerializableMapDualKey* base)
{
	Spaces * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 31 "SerializableGeeDualKeyMapTest.vala"
	self = (Spaces*) base;
#line 31 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_owner;
#line 31 "SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 31 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp1_;
#line 31 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 573 "SerializableGeeDualKeyMapTest.c"
}

static gchar*
spaces_real_get_map_secondary_key (GXmlSerializableMapDualKey* base)
{
	Spaces * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 32 "SerializableGeeDualKeyMapTest.vala"
	self = (Spaces*) base;
#line 32 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 32 "SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 32 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp1_;
#line 32 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 593 "SerializableGeeDualKeyMapTest.c"
}

Spaces*
spaces_construct_full (GType object_type,
                       const gchar* owner,
                       const gchar* name)
{
	Spaces * self = NULL;
#line 35 "SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (owner != NULL, NULL);
#line 35 "SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 35 "SerializableGeeDualKeyMapTest.vala"
	self = (Spaces*) gxml_serializable_object_model_construct (object_type);
#line 37 "SerializableGeeDualKeyMapTest.vala"
	spaces_set_name (self, name);
#line 38 "SerializableGeeDualKeyMapTest.vala"
	spaces_set_owner (self, owner);
#line 35 "SerializableGeeDualKeyMapTest.vala"
	return self;
#line 614 "SerializableGeeDualKeyMapTest.c"
}

Spaces*
spaces_new_full (const gchar* owner,
                 const gchar* name)
{
#line 35 "SerializableGeeDualKeyMapTest.vala"
	return spaces_construct_full (TYPE_SPACES, owner, name);
#line 623 "SerializableGeeDualKeyMapTest.c"
}

static gchar*
spaces_real_to_string (GXmlSerializableObjectModel* base)
{
	Spaces * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 40 "SerializableGeeDualKeyMapTest.vala"
	self = (Spaces*) base;
#line 40 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 40 "SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 40 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp1_;
#line 40 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 643 "SerializableGeeDualKeyMapTest.c"
}

Spaces*
spaces_construct (GType object_type)
{
	Spaces * self = NULL;
#line 29 "SerializableGeeDualKeyMapTest.vala"
	self = (Spaces*) gxml_serializable_object_model_construct (object_type);
#line 29 "SerializableGeeDualKeyMapTest.vala"
	return self;
#line 654 "SerializableGeeDualKeyMapTest.c"
}

Spaces*
spaces_new (void)
{
#line 29 "SerializableGeeDualKeyMapTest.vala"
	return spaces_construct (TYPE_SPACES);
#line 662 "SerializableGeeDualKeyMapTest.c"
}

const gchar*
spaces_get_name (Spaces* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 33 "SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 33 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 33 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 33 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 678 "SerializableGeeDualKeyMapTest.c"
}

void
spaces_set_name (Spaces* self,
                 const gchar* value)
{
#line 33 "SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 33 "SerializableGeeDualKeyMapTest.vala"
	if (g_strcmp0 (value, spaces_get_name (self)) != 0) {
#line 689 "SerializableGeeDualKeyMapTest.c"
		gchar* _tmp0_;
#line 33 "SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 33 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (self->priv->_name);
#line 33 "SerializableGeeDualKeyMapTest.vala"
		self->priv->_name = _tmp0_;
#line 33 "SerializableGeeDualKeyMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, spaces_properties[SPACES_NAME_PROPERTY]);
#line 699 "SerializableGeeDualKeyMapTest.c"
	}
}

const gchar*
spaces_get_owner (Spaces* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 34 "SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 34 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_owner;
#line 34 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 34 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 716 "SerializableGeeDualKeyMapTest.c"
}

void
spaces_set_owner (Spaces* self,
                  const gchar* value)
{
#line 34 "SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 34 "SerializableGeeDualKeyMapTest.vala"
	if (g_strcmp0 (value, spaces_get_owner (self)) != 0) {
#line 727 "SerializableGeeDualKeyMapTest.c"
		gchar* _tmp0_;
#line 34 "SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 34 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (self->priv->_owner);
#line 34 "SerializableGeeDualKeyMapTest.vala"
		self->priv->_owner = _tmp0_;
#line 34 "SerializableGeeDualKeyMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, spaces_properties[SPACES_OWNER_PROPERTY]);
#line 737 "SerializableGeeDualKeyMapTest.c"
	}
}

static void
spaces_class_init (SpacesClass * klass,
                   gpointer klass_data)
{
#line 29 "SerializableGeeDualKeyMapTest.vala"
	spaces_parent_class = g_type_class_peek_parent (klass);
#line 29 "SerializableGeeDualKeyMapTest.vala"
	g_type_class_adjust_private_offset (klass, &Spaces_private_offset);
#line 29 "SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) spaces_real_to_string;
#line 29 "SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_spaces_get_property;
#line 29 "SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_spaces_set_property;
#line 29 "SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->finalize = spaces_finalize;
#line 29 "SerializableGeeDualKeyMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SPACES_NAME_PROPERTY, spaces_properties[SPACES_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 29 "SerializableGeeDualKeyMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SPACES_OWNER_PROPERTY, spaces_properties[SPACES_OWNER_PROPERTY] = g_param_spec_string ("owner", "owner", "owner", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 761 "SerializableGeeDualKeyMapTest.c"
}

static void
spaces_gxml_serializable_map_dual_key_interface_init (GXmlSerializableMapDualKeyIface * iface,
                                                      gpointer iface_data)
{
#line 29 "SerializableGeeDualKeyMapTest.vala"
	spaces_gxml_serializable_map_dual_key_parent_iface = g_type_interface_peek_parent (iface);
#line 29 "SerializableGeeDualKeyMapTest.vala"
	iface->get_map_primary_key = (gpointer (*) (GXmlSerializableMapDualKey*)) spaces_real_get_map_primary_key;
#line 29 "SerializableGeeDualKeyMapTest.vala"
	iface->get_map_secondary_key = (gpointer (*) (GXmlSerializableMapDualKey*)) spaces_real_get_map_secondary_key;
#line 774 "SerializableGeeDualKeyMapTest.c"
}

static void
spaces_instance_init (Spaces * self,
                      gpointer klass)
{
#line 29 "SerializableGeeDualKeyMapTest.vala"
	self->priv = spaces_get_instance_private (self);
#line 783 "SerializableGeeDualKeyMapTest.c"
}

static void
spaces_finalize (GObject * obj)
{
	Spaces * self;
#line 29 "SerializableGeeDualKeyMapTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SPACES, Spaces);
#line 33 "SerializableGeeDualKeyMapTest.vala"
	_g_free0 (self->priv->_name);
#line 34 "SerializableGeeDualKeyMapTest.vala"
	_g_free0 (self->priv->_owner);
#line 29 "SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (spaces_parent_class)->finalize (obj);
#line 798 "SerializableGeeDualKeyMapTest.c"
}

/**
 *
 *  GXml.Serializable.BasicTypeTest
 *
 *  Authors:
 *
 *       Daniel Espinosa <esodan@gmail.com>
 *
 *
 *  Copyright (c) 2013-2015 Daniel Espinosa
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
GType
spaces_get_type (void)
{
	static volatile gsize spaces_type_id__volatile = 0;
	if (g_once_init_enter (&spaces_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SpacesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spaces_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Spaces), 0, (GInstanceInitFunc) spaces_instance_init, NULL };
		static const GInterfaceInfo gxml_serializable_map_dual_key_info = { (GInterfaceInitFunc) spaces_gxml_serializable_map_dual_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType spaces_type_id;
		spaces_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "Spaces", &g_define_type_info, 0);
		g_type_add_interface_static (spaces_type_id, GXML_TYPE_SERIALIZABLE_MAP_DUAL_KEY, &gxml_serializable_map_dual_key_info);
		Spaces_private_offset = g_type_add_instance_private (spaces_type_id, sizeof (SpacesPrivate));
		g_once_init_leave (&spaces_type_id__volatile, spaces_type_id);
	}
	return spaces_type_id__volatile;
}

static void
_vala_spaces_get_property (GObject * object,
                           guint property_id,
                           GValue * value,
                           GParamSpec * pspec)
{
	Spaces * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_SPACES, Spaces);
#line 29 "SerializableGeeDualKeyMapTest.vala"
	switch (property_id) {
#line 29 "SerializableGeeDualKeyMapTest.vala"
		case SPACES_NAME_PROPERTY:
#line 29 "SerializableGeeDualKeyMapTest.vala"
		g_value_set_string (value, spaces_get_name (self));
#line 29 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 29 "SerializableGeeDualKeyMapTest.vala"
		case SPACES_OWNER_PROPERTY:
#line 29 "SerializableGeeDualKeyMapTest.vala"
		g_value_set_string (value, spaces_get_owner (self));
#line 29 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 863 "SerializableGeeDualKeyMapTest.c"
		default:
#line 29 "SerializableGeeDualKeyMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 29 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 869 "SerializableGeeDualKeyMapTest.c"
	}
}

static void
_vala_spaces_set_property (GObject * object,
                           guint property_id,
                           const GValue * value,
                           GParamSpec * pspec)
{
	Spaces * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_SPACES, Spaces);
#line 29 "SerializableGeeDualKeyMapTest.vala"
	switch (property_id) {
#line 29 "SerializableGeeDualKeyMapTest.vala"
		case SPACES_NAME_PROPERTY:
#line 29 "SerializableGeeDualKeyMapTest.vala"
		spaces_set_name (self, g_value_get_string (value));
#line 29 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 29 "SerializableGeeDualKeyMapTest.vala"
		case SPACES_OWNER_PROPERTY:
#line 29 "SerializableGeeDualKeyMapTest.vala"
		spaces_set_owner (self, g_value_get_string (value));
#line 29 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 895 "SerializableGeeDualKeyMapTest.c"
		default:
#line 29 "SerializableGeeDualKeyMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 29 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 901 "SerializableGeeDualKeyMapTest.c"
	}
}

static void
__lambda299_ (void)
{
	GXmlSerializableDualKeyMap* c = NULL;
	GXmlSerializableDualKeyMap* _tmp0_;
	Spaces* o1 = NULL;
	Spaces* _tmp1_;
	Spaces* o2 = NULL;
	Spaces* _tmp2_;
	Spaces* o3 = NULL;
	Spaces* _tmp3_;
	Spaces* o4 = NULL;
	Spaces* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	const gchar* _tmp14_;
	const gchar* _tmp15_;
	const gchar* _tmp16_;
	const gchar* _tmp17_;
	const gchar* _tmp18_;
	const gchar* _tmp19_;
	const gchar* _tmp20_;
	gint _tmp21_;
	gint _tmp22_;
	gboolean found1 = FALSE;
	gboolean found2 = FALSE;
	gboolean found3 = FALSE;
	gboolean found4 = FALSE;
#line 95 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = gxml_serializable_dual_key_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, TYPE_SPACES, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 95 "SerializableGeeDualKeyMapTest.vala"
	c = _tmp0_;
#line 96 "SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = spaces_new_full ("Floor", "Big");
#line 96 "SerializableGeeDualKeyMapTest.vala"
	o1 = _tmp1_;
#line 97 "SerializableGeeDualKeyMapTest.vala"
	_tmp2_ = spaces_new_full ("Wall", "Small");
#line 97 "SerializableGeeDualKeyMapTest.vala"
	o2 = _tmp2_;
#line 98 "SerializableGeeDualKeyMapTest.vala"
	_tmp3_ = spaces_new_full ("Floor", "Bigger");
#line 98 "SerializableGeeDualKeyMapTest.vala"
	o3 = _tmp3_;
#line 99 "SerializableGeeDualKeyMapTest.vala"
	_tmp4_ = spaces_new_full ("Wall", "Smallest");
#line 99 "SerializableGeeDualKeyMapTest.vala"
	o4 = _tmp4_;
#line 100 "SerializableGeeDualKeyMapTest.vala"
	_tmp5_ = spaces_get_owner (o1);
#line 100 "SerializableGeeDualKeyMapTest.vala"
	_tmp6_ = _tmp5_;
#line 100 "SerializableGeeDualKeyMapTest.vala"
	_tmp7_ = spaces_get_name (o1);
#line 100 "SerializableGeeDualKeyMapTest.vala"
	_tmp8_ = _tmp7_;
#line 100 "SerializableGeeDualKeyMapTest.vala"
	gxml_serializable_dual_key_map_set (c, _tmp6_, _tmp8_, o1);
#line 101 "SerializableGeeDualKeyMapTest.vala"
	_tmp9_ = spaces_get_owner (o2);
#line 101 "SerializableGeeDualKeyMapTest.vala"
	_tmp10_ = _tmp9_;
#line 101 "SerializableGeeDualKeyMapTest.vala"
	_tmp11_ = spaces_get_name (o2);
#line 101 "SerializableGeeDualKeyMapTest.vala"
	_tmp12_ = _tmp11_;
#line 101 "SerializableGeeDualKeyMapTest.vala"
	gxml_serializable_dual_key_map_set (c, _tmp10_, _tmp12_, o2);
#line 102 "SerializableGeeDualKeyMapTest.vala"
	_tmp13_ = spaces_get_owner (o3);
#line 102 "SerializableGeeDualKeyMapTest.vala"
	_tmp14_ = _tmp13_;
#line 102 "SerializableGeeDualKeyMapTest.vala"
	_tmp15_ = spaces_get_name (o3);
#line 102 "SerializableGeeDualKeyMapTest.vala"
	_tmp16_ = _tmp15_;
#line 102 "SerializableGeeDualKeyMapTest.vala"
	gxml_serializable_dual_key_map_set (c, _tmp14_, _tmp16_, o3);
#line 103 "SerializableGeeDualKeyMapTest.vala"
	_tmp17_ = spaces_get_owner (o4);
#line 103 "SerializableGeeDualKeyMapTest.vala"
	_tmp18_ = _tmp17_;
#line 103 "SerializableGeeDualKeyMapTest.vala"
	_tmp19_ = spaces_get_name (o4);
#line 103 "SerializableGeeDualKeyMapTest.vala"
	_tmp20_ = _tmp19_;
#line 103 "SerializableGeeDualKeyMapTest.vala"
	gxml_serializable_dual_key_map_set (c, _tmp18_, _tmp20_, o4);
#line 104 "SerializableGeeDualKeyMapTest.vala"
	_tmp21_ = gxml_serializable_dual_key_map_get_size (c);
#line 104 "SerializableGeeDualKeyMapTest.vala"
	_tmp22_ = _tmp21_;
#line 104 "SerializableGeeDualKeyMapTest.vala"
	if (_tmp22_ != 4) {
#line 1006 "SerializableGeeDualKeyMapTest.c"
		FILE* _tmp23_;
		gint _tmp24_;
		gint _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
#line 105 "SerializableGeeDualKeyMapTest.vala"
		_tmp23_ = stdout;
#line 105 "SerializableGeeDualKeyMapTest.vala"
		_tmp24_ = gxml_serializable_dual_key_map_get_size (c);
#line 105 "SerializableGeeDualKeyMapTest.vala"
		_tmp25_ = _tmp24_;
#line 105 "SerializableGeeDualKeyMapTest.vala"
		_tmp26_ = g_strdup_printf ("%i", _tmp25_);
#line 105 "SerializableGeeDualKeyMapTest.vala"
		_tmp27_ = _tmp26_;
#line 105 "SerializableGeeDualKeyMapTest.vala"
		_tmp28_ = g_strconcat ("SIZE: ", _tmp27_, "\n", NULL);
#line 105 "SerializableGeeDualKeyMapTest.vala"
		_tmp29_ = _tmp28_;
#line 105 "SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp23_, "%s", _tmp29_);
#line 105 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp29_);
#line 105 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp27_);
#line 106 "SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 1036 "SerializableGeeDualKeyMapTest.c"
	}
#line 108 "SerializableGeeDualKeyMapTest.vala"
	found1 = FALSE;
#line 109 "SerializableGeeDualKeyMapTest.vala"
	found2 = FALSE;
#line 110 "SerializableGeeDualKeyMapTest.vala"
	found3 = FALSE;
#line 111 "SerializableGeeDualKeyMapTest.vala"
	found4 = FALSE;
#line 1046 "SerializableGeeDualKeyMapTest.c"
	{
		GeeIterator* _s_it = NULL;
		GeeCollection* _tmp30_;
		GeeCollection* _tmp31_;
		GeeIterator* _tmp32_;
		GeeIterator* _tmp33_;
#line 112 "SerializableGeeDualKeyMapTest.vala"
		_tmp30_ = gxml_serializable_dual_key_map_values (c);
#line 112 "SerializableGeeDualKeyMapTest.vala"
		_tmp31_ = _tmp30_;
#line 112 "SerializableGeeDualKeyMapTest.vala"
		_tmp32_ = gee_iterable_iterator ((GeeIterable*) _tmp31_);
#line 112 "SerializableGeeDualKeyMapTest.vala"
		_tmp33_ = _tmp32_;
#line 112 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp31_);
#line 112 "SerializableGeeDualKeyMapTest.vala"
		_s_it = _tmp33_;
#line 112 "SerializableGeeDualKeyMapTest.vala"
		while (TRUE) {
#line 1067 "SerializableGeeDualKeyMapTest.c"
			GeeIterator* _tmp34_;
			Spaces* s = NULL;
			GeeIterator* _tmp35_;
			gpointer _tmp36_;
			gboolean _tmp37_ = FALSE;
			Spaces* _tmp38_;
			const gchar* _tmp39_;
			const gchar* _tmp40_;
			gboolean _tmp44_ = FALSE;
			Spaces* _tmp45_;
			const gchar* _tmp46_;
			const gchar* _tmp47_;
			gboolean _tmp51_ = FALSE;
			Spaces* _tmp52_;
			const gchar* _tmp53_;
			const gchar* _tmp54_;
			gboolean _tmp58_ = FALSE;
			Spaces* _tmp59_;
			const gchar* _tmp60_;
			const gchar* _tmp61_;
#line 112 "SerializableGeeDualKeyMapTest.vala"
			_tmp34_ = _s_it;
#line 112 "SerializableGeeDualKeyMapTest.vala"
			if (!gee_iterator_next (_tmp34_)) {
#line 112 "SerializableGeeDualKeyMapTest.vala"
				break;
#line 1094 "SerializableGeeDualKeyMapTest.c"
			}
#line 112 "SerializableGeeDualKeyMapTest.vala"
			_tmp35_ = _s_it;
#line 112 "SerializableGeeDualKeyMapTest.vala"
			_tmp36_ = gee_iterator_get (_tmp35_);
#line 112 "SerializableGeeDualKeyMapTest.vala"
			s = (Spaces*) _tmp36_;
#line 113 "SerializableGeeDualKeyMapTest.vala"
			_tmp38_ = s;
#line 113 "SerializableGeeDualKeyMapTest.vala"
			_tmp39_ = spaces_get_owner (_tmp38_);
#line 113 "SerializableGeeDualKeyMapTest.vala"
			_tmp40_ = _tmp39_;
#line 113 "SerializableGeeDualKeyMapTest.vala"
			if (g_strcmp0 (_tmp40_, "Floor") == 0) {
#line 1110 "SerializableGeeDualKeyMapTest.c"
				Spaces* _tmp41_;
				const gchar* _tmp42_;
				const gchar* _tmp43_;
#line 113 "SerializableGeeDualKeyMapTest.vala"
				_tmp41_ = s;
#line 113 "SerializableGeeDualKeyMapTest.vala"
				_tmp42_ = spaces_get_name (_tmp41_);
#line 113 "SerializableGeeDualKeyMapTest.vala"
				_tmp43_ = _tmp42_;
#line 113 "SerializableGeeDualKeyMapTest.vala"
				_tmp37_ = g_strcmp0 (_tmp43_, "Big") == 0;
#line 1122 "SerializableGeeDualKeyMapTest.c"
			} else {
#line 113 "SerializableGeeDualKeyMapTest.vala"
				_tmp37_ = FALSE;
#line 1126 "SerializableGeeDualKeyMapTest.c"
			}
#line 113 "SerializableGeeDualKeyMapTest.vala"
			if (_tmp37_) {
#line 114 "SerializableGeeDualKeyMapTest.vala"
				found1 = TRUE;
#line 1132 "SerializableGeeDualKeyMapTest.c"
			}
#line 115 "SerializableGeeDualKeyMapTest.vala"
			_tmp45_ = s;
#line 115 "SerializableGeeDualKeyMapTest.vala"
			_tmp46_ = spaces_get_owner (_tmp45_);
#line 115 "SerializableGeeDualKeyMapTest.vala"
			_tmp47_ = _tmp46_;
#line 115 "SerializableGeeDualKeyMapTest.vala"
			if (g_strcmp0 (_tmp47_, "Wall") == 0) {
#line 1142 "SerializableGeeDualKeyMapTest.c"
				Spaces* _tmp48_;
				const gchar* _tmp49_;
				const gchar* _tmp50_;
#line 115 "SerializableGeeDualKeyMapTest.vala"
				_tmp48_ = s;
#line 115 "SerializableGeeDualKeyMapTest.vala"
				_tmp49_ = spaces_get_name (_tmp48_);
#line 115 "SerializableGeeDualKeyMapTest.vala"
				_tmp50_ = _tmp49_;
#line 115 "SerializableGeeDualKeyMapTest.vala"
				_tmp44_ = g_strcmp0 (_tmp50_, "Small") == 0;
#line 1154 "SerializableGeeDualKeyMapTest.c"
			} else {
#line 115 "SerializableGeeDualKeyMapTest.vala"
				_tmp44_ = FALSE;
#line 1158 "SerializableGeeDualKeyMapTest.c"
			}
#line 115 "SerializableGeeDualKeyMapTest.vala"
			if (_tmp44_) {
#line 116 "SerializableGeeDualKeyMapTest.vala"
				found2 = TRUE;
#line 1164 "SerializableGeeDualKeyMapTest.c"
			}
#line 117 "SerializableGeeDualKeyMapTest.vala"
			_tmp52_ = s;
#line 117 "SerializableGeeDualKeyMapTest.vala"
			_tmp53_ = spaces_get_owner (_tmp52_);
#line 117 "SerializableGeeDualKeyMapTest.vala"
			_tmp54_ = _tmp53_;
#line 117 "SerializableGeeDualKeyMapTest.vala"
			if (g_strcmp0 (_tmp54_, "Floor") == 0) {
#line 1174 "SerializableGeeDualKeyMapTest.c"
				Spaces* _tmp55_;
				const gchar* _tmp56_;
				const gchar* _tmp57_;
#line 117 "SerializableGeeDualKeyMapTest.vala"
				_tmp55_ = s;
#line 117 "SerializableGeeDualKeyMapTest.vala"
				_tmp56_ = spaces_get_name (_tmp55_);
#line 117 "SerializableGeeDualKeyMapTest.vala"
				_tmp57_ = _tmp56_;
#line 117 "SerializableGeeDualKeyMapTest.vala"
				_tmp51_ = g_strcmp0 (_tmp57_, "Bigger") == 0;
#line 1186 "SerializableGeeDualKeyMapTest.c"
			} else {
#line 117 "SerializableGeeDualKeyMapTest.vala"
				_tmp51_ = FALSE;
#line 1190 "SerializableGeeDualKeyMapTest.c"
			}
#line 117 "SerializableGeeDualKeyMapTest.vala"
			if (_tmp51_) {
#line 118 "SerializableGeeDualKeyMapTest.vala"
				found3 = TRUE;
#line 1196 "SerializableGeeDualKeyMapTest.c"
			}
#line 119 "SerializableGeeDualKeyMapTest.vala"
			_tmp59_ = s;
#line 119 "SerializableGeeDualKeyMapTest.vala"
			_tmp60_ = spaces_get_owner (_tmp59_);
#line 119 "SerializableGeeDualKeyMapTest.vala"
			_tmp61_ = _tmp60_;
#line 119 "SerializableGeeDualKeyMapTest.vala"
			if (g_strcmp0 (_tmp61_, "Wall") == 0) {
#line 1206 "SerializableGeeDualKeyMapTest.c"
				Spaces* _tmp62_;
				const gchar* _tmp63_;
				const gchar* _tmp64_;
#line 119 "SerializableGeeDualKeyMapTest.vala"
				_tmp62_ = s;
#line 119 "SerializableGeeDualKeyMapTest.vala"
				_tmp63_ = spaces_get_name (_tmp62_);
#line 119 "SerializableGeeDualKeyMapTest.vala"
				_tmp64_ = _tmp63_;
#line 119 "SerializableGeeDualKeyMapTest.vala"
				_tmp58_ = g_strcmp0 (_tmp64_, "Smallest") == 0;
#line 1218 "SerializableGeeDualKeyMapTest.c"
			} else {
#line 119 "SerializableGeeDualKeyMapTest.vala"
				_tmp58_ = FALSE;
#line 1222 "SerializableGeeDualKeyMapTest.c"
			}
#line 119 "SerializableGeeDualKeyMapTest.vala"
			if (_tmp58_) {
#line 120 "SerializableGeeDualKeyMapTest.vala"
				found4 = TRUE;
#line 1228 "SerializableGeeDualKeyMapTest.c"
			}
#line 112 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (s);
#line 1232 "SerializableGeeDualKeyMapTest.c"
		}
#line 112 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_s_it);
#line 1236 "SerializableGeeDualKeyMapTest.c"
	}
#line 122 "SerializableGeeDualKeyMapTest.vala"
	if (!found1) {
#line 1240 "SerializableGeeDualKeyMapTest.c"
		FILE* _tmp65_;
#line 123 "SerializableGeeDualKeyMapTest.vala"
		_tmp65_ = stdout;
#line 123 "SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp65_, "%s", "Not found 'Floor' & 'Big':\n");
#line 124 "SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 1248 "SerializableGeeDualKeyMapTest.c"
	}
#line 126 "SerializableGeeDualKeyMapTest.vala"
	if (!found2) {
#line 1252 "SerializableGeeDualKeyMapTest.c"
		FILE* _tmp66_;
#line 127 "SerializableGeeDualKeyMapTest.vala"
		_tmp66_ = stdout;
#line 127 "SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp66_, "%s", "Not found 'Wall' & 'Small':\n");
#line 128 "SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 1260 "SerializableGeeDualKeyMapTest.c"
	}
#line 130 "SerializableGeeDualKeyMapTest.vala"
	if (!found3) {
#line 1264 "SerializableGeeDualKeyMapTest.c"
		FILE* _tmp67_;
#line 131 "SerializableGeeDualKeyMapTest.vala"
		_tmp67_ = stdout;
#line 131 "SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp67_, "%s", "Not found 'Floor' & 'Bigger':\n");
#line 132 "SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 1272 "SerializableGeeDualKeyMapTest.c"
	}
#line 134 "SerializableGeeDualKeyMapTest.vala"
	if (!found4) {
#line 1276 "SerializableGeeDualKeyMapTest.c"
		FILE* _tmp68_;
#line 135 "SerializableGeeDualKeyMapTest.vala"
		_tmp68_ = stdout;
#line 135 "SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp68_, "%s", "Not found 'Wall' & 'Smallest':\n");
#line 136 "SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 1284 "SerializableGeeDualKeyMapTest.c"
	}
#line 138 "SerializableGeeDualKeyMapTest.vala"
	found3 = FALSE;
#line 138 "SerializableGeeDualKeyMapTest.vala"
	found1 = found3;
#line 1290 "SerializableGeeDualKeyMapTest.c"
	{
		GeeIterator* _s_it = NULL;
		GeeCollection* _tmp69_;
		GeeCollection* _tmp70_;
		GeeIterator* _tmp71_;
		GeeIterator* _tmp72_;
#line 139 "SerializableGeeDualKeyMapTest.vala"
		_tmp69_ = gxml_serializable_dual_key_map_values_for_key (c, "Floor");
#line 139 "SerializableGeeDualKeyMapTest.vala"
		_tmp70_ = _tmp69_;
#line 139 "SerializableGeeDualKeyMapTest.vala"
		_tmp71_ = gee_iterable_iterator ((GeeIterable*) _tmp70_);
#line 139 "SerializableGeeDualKeyMapTest.vala"
		_tmp72_ = _tmp71_;
#line 139 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp70_);
#line 139 "SerializableGeeDualKeyMapTest.vala"
		_s_it = _tmp72_;
#line 139 "SerializableGeeDualKeyMapTest.vala"
		while (TRUE) {
#line 1311 "SerializableGeeDualKeyMapTest.c"
			GeeIterator* _tmp73_;
			Spaces* s = NULL;
			GeeIterator* _tmp74_;
			gpointer _tmp75_;
			gboolean _tmp76_ = FALSE;
			Spaces* _tmp77_;
			const gchar* _tmp78_;
			const gchar* _tmp79_;
			gboolean _tmp83_ = FALSE;
			Spaces* _tmp84_;
			const gchar* _tmp85_;
			const gchar* _tmp86_;
#line 139 "SerializableGeeDualKeyMapTest.vala"
			_tmp73_ = _s_it;
#line 139 "SerializableGeeDualKeyMapTest.vala"
			if (!gee_iterator_next (_tmp73_)) {
#line 139 "SerializableGeeDualKeyMapTest.vala"
				break;
#line 1330 "SerializableGeeDualKeyMapTest.c"
			}
#line 139 "SerializableGeeDualKeyMapTest.vala"
			_tmp74_ = _s_it;
#line 139 "SerializableGeeDualKeyMapTest.vala"
			_tmp75_ = gee_iterator_get (_tmp74_);
#line 139 "SerializableGeeDualKeyMapTest.vala"
			s = (Spaces*) _tmp75_;
#line 140 "SerializableGeeDualKeyMapTest.vala"
			_tmp77_ = s;
#line 140 "SerializableGeeDualKeyMapTest.vala"
			_tmp78_ = spaces_get_owner (_tmp77_);
#line 140 "SerializableGeeDualKeyMapTest.vala"
			_tmp79_ = _tmp78_;
#line 140 "SerializableGeeDualKeyMapTest.vala"
			if (g_strcmp0 (_tmp79_, "Floor") == 0) {
#line 1346 "SerializableGeeDualKeyMapTest.c"
				Spaces* _tmp80_;
				const gchar* _tmp81_;
				const gchar* _tmp82_;
#line 140 "SerializableGeeDualKeyMapTest.vala"
				_tmp80_ = s;
#line 140 "SerializableGeeDualKeyMapTest.vala"
				_tmp81_ = spaces_get_name (_tmp80_);
#line 140 "SerializableGeeDualKeyMapTest.vala"
				_tmp82_ = _tmp81_;
#line 140 "SerializableGeeDualKeyMapTest.vala"
				_tmp76_ = g_strcmp0 (_tmp82_, "Big") == 0;
#line 1358 "SerializableGeeDualKeyMapTest.c"
			} else {
#line 140 "SerializableGeeDualKeyMapTest.vala"
				_tmp76_ = FALSE;
#line 1362 "SerializableGeeDualKeyMapTest.c"
			}
#line 140 "SerializableGeeDualKeyMapTest.vala"
			if (_tmp76_) {
#line 141 "SerializableGeeDualKeyMapTest.vala"
				found1 = TRUE;
#line 1368 "SerializableGeeDualKeyMapTest.c"
			}
#line 142 "SerializableGeeDualKeyMapTest.vala"
			_tmp84_ = s;
#line 142 "SerializableGeeDualKeyMapTest.vala"
			_tmp85_ = spaces_get_owner (_tmp84_);
#line 142 "SerializableGeeDualKeyMapTest.vala"
			_tmp86_ = _tmp85_;
#line 142 "SerializableGeeDualKeyMapTest.vala"
			if (g_strcmp0 (_tmp86_, "Floor") == 0) {
#line 1378 "SerializableGeeDualKeyMapTest.c"
				Spaces* _tmp87_;
				const gchar* _tmp88_;
				const gchar* _tmp89_;
#line 142 "SerializableGeeDualKeyMapTest.vala"
				_tmp87_ = s;
#line 142 "SerializableGeeDualKeyMapTest.vala"
				_tmp88_ = spaces_get_name (_tmp87_);
#line 142 "SerializableGeeDualKeyMapTest.vala"
				_tmp89_ = _tmp88_;
#line 142 "SerializableGeeDualKeyMapTest.vala"
				_tmp83_ = g_strcmp0 (_tmp89_, "Bigger") == 0;
#line 1390 "SerializableGeeDualKeyMapTest.c"
			} else {
#line 142 "SerializableGeeDualKeyMapTest.vala"
				_tmp83_ = FALSE;
#line 1394 "SerializableGeeDualKeyMapTest.c"
			}
#line 142 "SerializableGeeDualKeyMapTest.vala"
			if (_tmp83_) {
#line 143 "SerializableGeeDualKeyMapTest.vala"
				found3 = TRUE;
#line 1400 "SerializableGeeDualKeyMapTest.c"
			}
#line 139 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (s);
#line 1404 "SerializableGeeDualKeyMapTest.c"
		}
#line 139 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_s_it);
#line 1408 "SerializableGeeDualKeyMapTest.c"
	}
#line 145 "SerializableGeeDualKeyMapTest.vala"
	if (!found1) {
#line 1412 "SerializableGeeDualKeyMapTest.c"
		FILE* _tmp90_;
#line 146 "SerializableGeeDualKeyMapTest.vala"
		_tmp90_ = stdout;
#line 146 "SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp90_, "%s", "Not found 'Floor' & 'Big':\n");
#line 147 "SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 1420 "SerializableGeeDualKeyMapTest.c"
	}
#line 149 "SerializableGeeDualKeyMapTest.vala"
	if (!found3) {
#line 1424 "SerializableGeeDualKeyMapTest.c"
		FILE* _tmp91_;
#line 150 "SerializableGeeDualKeyMapTest.vala"
		_tmp91_ = stdout;
#line 150 "SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp91_, "%s", "Not found 'Floor' & 'Bigger':\n");
#line 151 "SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 1432 "SerializableGeeDualKeyMapTest.c"
	}
#line 153 "SerializableGeeDualKeyMapTest.vala"
	found4 = TRUE;
#line 153 "SerializableGeeDualKeyMapTest.vala"
	found2 = found4;
#line 1438 "SerializableGeeDualKeyMapTest.c"
	{
		GeeIterator* _k2_it = NULL;
		GeeCollection* _tmp92_;
		GeeCollection* _tmp93_;
		GeeIterator* _tmp94_;
		GeeIterator* _tmp95_;
#line 154 "SerializableGeeDualKeyMapTest.vala"
		_tmp92_ = gxml_serializable_dual_key_map_secondary_keys (c, "Wall");
#line 154 "SerializableGeeDualKeyMapTest.vala"
		_tmp93_ = _tmp92_;
#line 154 "SerializableGeeDualKeyMapTest.vala"
		_tmp94_ = gee_iterable_iterator ((GeeIterable*) _tmp93_);
#line 154 "SerializableGeeDualKeyMapTest.vala"
		_tmp95_ = _tmp94_;
#line 154 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp93_);
#line 154 "SerializableGeeDualKeyMapTest.vala"
		_k2_it = _tmp95_;
#line 154 "SerializableGeeDualKeyMapTest.vala"
		while (TRUE) {
#line 1459 "SerializableGeeDualKeyMapTest.c"
			GeeIterator* _tmp96_;
			gchar* k2 = NULL;
			GeeIterator* _tmp97_;
			gpointer _tmp98_;
			Spaces* s = NULL;
			const gchar* _tmp99_;
			gpointer _tmp100_;
			gboolean _tmp101_ = FALSE;
			Spaces* _tmp102_;
			const gchar* _tmp103_;
			const gchar* _tmp104_;
			gboolean _tmp108_ = FALSE;
			Spaces* _tmp109_;
			const gchar* _tmp110_;
			const gchar* _tmp111_;
#line 154 "SerializableGeeDualKeyMapTest.vala"
			_tmp96_ = _k2_it;
#line 154 "SerializableGeeDualKeyMapTest.vala"
			if (!gee_iterator_next (_tmp96_)) {
#line 154 "SerializableGeeDualKeyMapTest.vala"
				break;
#line 1481 "SerializableGeeDualKeyMapTest.c"
			}
#line 154 "SerializableGeeDualKeyMapTest.vala"
			_tmp97_ = _k2_it;
#line 154 "SerializableGeeDualKeyMapTest.vala"
			_tmp98_ = gee_iterator_get (_tmp97_);
#line 154 "SerializableGeeDualKeyMapTest.vala"
			k2 = (gchar*) _tmp98_;
#line 155 "SerializableGeeDualKeyMapTest.vala"
			_tmp99_ = k2;
#line 155 "SerializableGeeDualKeyMapTest.vala"
			_tmp100_ = gxml_serializable_dual_key_map_get (c, "Wall", _tmp99_);
#line 155 "SerializableGeeDualKeyMapTest.vala"
			s = (Spaces*) _tmp100_;
#line 156 "SerializableGeeDualKeyMapTest.vala"
			_tmp102_ = s;
#line 156 "SerializableGeeDualKeyMapTest.vala"
			_tmp103_ = spaces_get_owner (_tmp102_);
#line 156 "SerializableGeeDualKeyMapTest.vala"
			_tmp104_ = _tmp103_;
#line 156 "SerializableGeeDualKeyMapTest.vala"
			if (g_strcmp0 (_tmp104_, "Wall") == 0) {
#line 1503 "SerializableGeeDualKeyMapTest.c"
				Spaces* _tmp105_;
				const gchar* _tmp106_;
				const gchar* _tmp107_;
#line 156 "SerializableGeeDualKeyMapTest.vala"
				_tmp105_ = s;
#line 156 "SerializableGeeDualKeyMapTest.vala"
				_tmp106_ = spaces_get_name (_tmp105_);
#line 156 "SerializableGeeDualKeyMapTest.vala"
				_tmp107_ = _tmp106_;
#line 156 "SerializableGeeDualKeyMapTest.vala"
				_tmp101_ = g_strcmp0 (_tmp107_, "Small") == 0;
#line 1515 "SerializableGeeDualKeyMapTest.c"
			} else {
#line 156 "SerializableGeeDualKeyMapTest.vala"
				_tmp101_ = FALSE;
#line 1519 "SerializableGeeDualKeyMapTest.c"
			}
#line 156 "SerializableGeeDualKeyMapTest.vala"
			if (_tmp101_) {
#line 157 "SerializableGeeDualKeyMapTest.vala"
				found2 = TRUE;
#line 1525 "SerializableGeeDualKeyMapTest.c"
			}
#line 158 "SerializableGeeDualKeyMapTest.vala"
			_tmp109_ = s;
#line 158 "SerializableGeeDualKeyMapTest.vala"
			_tmp110_ = spaces_get_owner (_tmp109_);
#line 158 "SerializableGeeDualKeyMapTest.vala"
			_tmp111_ = _tmp110_;
#line 158 "SerializableGeeDualKeyMapTest.vala"
			if (g_strcmp0 (_tmp111_, "Wall") == 0) {
#line 1535 "SerializableGeeDualKeyMapTest.c"
				Spaces* _tmp112_;
				const gchar* _tmp113_;
				const gchar* _tmp114_;
#line 158 "SerializableGeeDualKeyMapTest.vala"
				_tmp112_ = s;
#line 158 "SerializableGeeDualKeyMapTest.vala"
				_tmp113_ = spaces_get_name (_tmp112_);
#line 158 "SerializableGeeDualKeyMapTest.vala"
				_tmp114_ = _tmp113_;
#line 158 "SerializableGeeDualKeyMapTest.vala"
				_tmp108_ = g_strcmp0 (_tmp114_, "Smallest") == 0;
#line 1547 "SerializableGeeDualKeyMapTest.c"
			} else {
#line 158 "SerializableGeeDualKeyMapTest.vala"
				_tmp108_ = FALSE;
#line 1551 "SerializableGeeDualKeyMapTest.c"
			}
#line 158 "SerializableGeeDualKeyMapTest.vala"
			if (_tmp108_) {
#line 159 "SerializableGeeDualKeyMapTest.vala"
				found4 = TRUE;
#line 1557 "SerializableGeeDualKeyMapTest.c"
			}
#line 154 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (s);
#line 154 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (k2);
#line 1563 "SerializableGeeDualKeyMapTest.c"
		}
#line 154 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_k2_it);
#line 1567 "SerializableGeeDualKeyMapTest.c"
	}
#line 161 "SerializableGeeDualKeyMapTest.vala"
	if (!found2) {
#line 1571 "SerializableGeeDualKeyMapTest.c"
		FILE* _tmp115_;
#line 162 "SerializableGeeDualKeyMapTest.vala"
		_tmp115_ = stdout;
#line 162 "SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp115_, "%s", "Not found 'Wall' & 'Small':\n");
#line 163 "SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 1579 "SerializableGeeDualKeyMapTest.c"
	}
#line 165 "SerializableGeeDualKeyMapTest.vala"
	if (!found4) {
#line 1583 "SerializableGeeDualKeyMapTest.c"
		FILE* _tmp116_;
#line 166 "SerializableGeeDualKeyMapTest.vala"
		_tmp116_ = stdout;
#line 166 "SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp116_, "%s", "Not found 'Wall' & 'Smallest':\n");
#line 167 "SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 1591 "SerializableGeeDualKeyMapTest.c"
	}
#line 94 "SerializableGeeDualKeyMapTest.vala"
	_g_object_unref0 (o4);
#line 94 "SerializableGeeDualKeyMapTest.vala"
	_g_object_unref0 (o3);
#line 94 "SerializableGeeDualKeyMapTest.vala"
	_g_object_unref0 (o2);
#line 94 "SerializableGeeDualKeyMapTest.vala"
	_g_object_unref0 (o1);
#line 94 "SerializableGeeDualKeyMapTest.vala"
	_g_object_unref0 (c);
#line 1603 "SerializableGeeDualKeyMapTest.c"
}

static void
___lambda299__gtest_func (void)
{
#line 93 "SerializableGeeDualKeyMapTest.vala"
	__lambda299_ ();
#line 1611 "SerializableGeeDualKeyMapTest.c"
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result = NULL;
#line 1516 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1517 "glib-2.0.vapi"
	result = self;
#line 1517 "glib-2.0.vapi"
	return result;
#line 1624 "SerializableGeeDualKeyMapTest.c"
}

static void
__lambda300_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlSerializableDualKeyMap* c = NULL;
		GXmlSerializableDualKeyMap* _tmp0_;
		Spaces* o1 = NULL;
		Spaces* _tmp1_;
		Spaces* o2 = NULL;
		Spaces* _tmp2_;
		Spaces* o3 = NULL;
		Spaces* _tmp3_;
		Spaces* o4 = NULL;
		Spaces* _tmp4_;
		GXmlSerializableDualKeyMap* _tmp5_;
		Spaces* _tmp6_;
		const gchar* _tmp7_;
		const gchar* _tmp8_;
		Spaces* _tmp9_;
		const gchar* _tmp10_;
		const gchar* _tmp11_;
		Spaces* _tmp12_;
		GXmlSerializableDualKeyMap* _tmp13_;
		Spaces* _tmp14_;
		const gchar* _tmp15_;
		const gchar* _tmp16_;
		Spaces* _tmp17_;
		const gchar* _tmp18_;
		const gchar* _tmp19_;
		Spaces* _tmp20_;
		GXmlSerializableDualKeyMap* _tmp21_;
		Spaces* _tmp22_;
		const gchar* _tmp23_;
		const gchar* _tmp24_;
		Spaces* _tmp25_;
		const gchar* _tmp26_;
		const gchar* _tmp27_;
		Spaces* _tmp28_;
		GXmlSerializableDualKeyMap* _tmp29_;
		Spaces* _tmp30_;
		const gchar* _tmp31_;
		const gchar* _tmp32_;
		Spaces* _tmp33_;
		const gchar* _tmp34_;
		const gchar* _tmp35_;
		Spaces* _tmp36_;
		GXmlTDocument* doc = NULL;
		GXmlTDocument* _tmp37_;
		GXmlNode* root = NULL;
		GXmlTDocument* _tmp38_;
		GXmlNode* _tmp39_;
		GXmlTDocument* _tmp40_;
		GeeBidirList* _tmp41_;
		GeeBidirList* _tmp42_;
		GeeBidirList* _tmp43_;
		GXmlNode* _tmp44_;
		GXmlSerializableDualKeyMap* _tmp45_;
		GXmlNode* _tmp46_;
		GXmlNode* _tmp47_;
		GXmlNode* _tmp48_;
		GXmlNode* _tmp49_;
		GeeBidirList* _tmp50_;
		GeeBidirList* _tmp51_;
		GeeBidirList* _tmp52_;
		gint _tmp53_;
		gint _tmp54_;
		gboolean found1 = FALSE;
		gboolean found2 = FALSE;
		gboolean found3 = FALSE;
		gboolean found4 = FALSE;
		gint nodes = 0;
		gint i = 0;
#line 173 "SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = gxml_serializable_dual_key_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, TYPE_SPACES, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 173 "SerializableGeeDualKeyMapTest.vala"
		c = _tmp0_;
#line 174 "SerializableGeeDualKeyMapTest.vala"
		_tmp1_ = spaces_new_full ("Floor", "Big");
#line 174 "SerializableGeeDualKeyMapTest.vala"
		o1 = _tmp1_;
#line 175 "SerializableGeeDualKeyMapTest.vala"
		_tmp2_ = spaces_new_full ("Wall", "Small");
#line 175 "SerializableGeeDualKeyMapTest.vala"
		o2 = _tmp2_;
#line 176 "SerializableGeeDualKeyMapTest.vala"
		_tmp3_ = spaces_new_full ("Floor", "Bigger");
#line 176 "SerializableGeeDualKeyMapTest.vala"
		o3 = _tmp3_;
#line 177 "SerializableGeeDualKeyMapTest.vala"
		_tmp4_ = spaces_new_full ("Wall", "Smallest");
#line 177 "SerializableGeeDualKeyMapTest.vala"
		o4 = _tmp4_;
#line 178 "SerializableGeeDualKeyMapTest.vala"
		_tmp5_ = c;
#line 178 "SerializableGeeDualKeyMapTest.vala"
		_tmp6_ = o1;
#line 178 "SerializableGeeDualKeyMapTest.vala"
		_tmp7_ = spaces_get_owner (_tmp6_);
#line 178 "SerializableGeeDualKeyMapTest.vala"
		_tmp8_ = _tmp7_;
#line 178 "SerializableGeeDualKeyMapTest.vala"
		_tmp9_ = o1;
#line 178 "SerializableGeeDualKeyMapTest.vala"
		_tmp10_ = spaces_get_name (_tmp9_);
#line 178 "SerializableGeeDualKeyMapTest.vala"
		_tmp11_ = _tmp10_;
#line 178 "SerializableGeeDualKeyMapTest.vala"
		_tmp12_ = o1;
#line 178 "SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_dual_key_map_set (_tmp5_, _tmp8_, _tmp11_, _tmp12_);
#line 179 "SerializableGeeDualKeyMapTest.vala"
		_tmp13_ = c;
#line 179 "SerializableGeeDualKeyMapTest.vala"
		_tmp14_ = o2;
#line 179 "SerializableGeeDualKeyMapTest.vala"
		_tmp15_ = spaces_get_owner (_tmp14_);
#line 179 "SerializableGeeDualKeyMapTest.vala"
		_tmp16_ = _tmp15_;
#line 179 "SerializableGeeDualKeyMapTest.vala"
		_tmp17_ = o2;
#line 179 "SerializableGeeDualKeyMapTest.vala"
		_tmp18_ = spaces_get_name (_tmp17_);
#line 179 "SerializableGeeDualKeyMapTest.vala"
		_tmp19_ = _tmp18_;
#line 179 "SerializableGeeDualKeyMapTest.vala"
		_tmp20_ = o2;
#line 179 "SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_dual_key_map_set (_tmp13_, _tmp16_, _tmp19_, _tmp20_);
#line 180 "SerializableGeeDualKeyMapTest.vala"
		_tmp21_ = c;
#line 180 "SerializableGeeDualKeyMapTest.vala"
		_tmp22_ = o3;
#line 180 "SerializableGeeDualKeyMapTest.vala"
		_tmp23_ = spaces_get_owner (_tmp22_);
#line 180 "SerializableGeeDualKeyMapTest.vala"
		_tmp24_ = _tmp23_;
#line 180 "SerializableGeeDualKeyMapTest.vala"
		_tmp25_ = o3;
#line 180 "SerializableGeeDualKeyMapTest.vala"
		_tmp26_ = spaces_get_name (_tmp25_);
#line 180 "SerializableGeeDualKeyMapTest.vala"
		_tmp27_ = _tmp26_;
#line 180 "SerializableGeeDualKeyMapTest.vala"
		_tmp28_ = o3;
#line 180 "SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_dual_key_map_set (_tmp21_, _tmp24_, _tmp27_, _tmp28_);
#line 181 "SerializableGeeDualKeyMapTest.vala"
		_tmp29_ = c;
#line 181 "SerializableGeeDualKeyMapTest.vala"
		_tmp30_ = o4;
#line 181 "SerializableGeeDualKeyMapTest.vala"
		_tmp31_ = spaces_get_owner (_tmp30_);
#line 181 "SerializableGeeDualKeyMapTest.vala"
		_tmp32_ = _tmp31_;
#line 181 "SerializableGeeDualKeyMapTest.vala"
		_tmp33_ = o4;
#line 181 "SerializableGeeDualKeyMapTest.vala"
		_tmp34_ = spaces_get_name (_tmp33_);
#line 181 "SerializableGeeDualKeyMapTest.vala"
		_tmp35_ = _tmp34_;
#line 181 "SerializableGeeDualKeyMapTest.vala"
		_tmp36_ = o4;
#line 181 "SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_dual_key_map_set (_tmp29_, _tmp32_, _tmp35_, _tmp36_);
#line 182 "SerializableGeeDualKeyMapTest.vala"
		_tmp37_ = gxml_tdocument_new ();
#line 182 "SerializableGeeDualKeyMapTest.vala"
		doc = _tmp37_;
#line 183 "SerializableGeeDualKeyMapTest.vala"
		_tmp38_ = doc;
#line 183 "SerializableGeeDualKeyMapTest.vala"
		_tmp39_ = gxml_document_create_element ((GXmlDocument*) _tmp38_, "root", &_inner_error0_);
#line 183 "SerializableGeeDualKeyMapTest.vala"
		root = _tmp39_;
#line 183 "SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 183 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (doc);
#line 183 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (o4);
#line 183 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (o3);
#line 183 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (o2);
#line 183 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (o1);
#line 183 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (c);
#line 1816 "SerializableGeeDualKeyMapTest.c"
			goto __catch352_g_error;
		}
#line 184 "SerializableGeeDualKeyMapTest.vala"
		_tmp40_ = doc;
#line 184 "SerializableGeeDualKeyMapTest.vala"
		_tmp41_ = gxml_tnode_get_children_nodes ((GXmlTNode*) _tmp40_);
#line 184 "SerializableGeeDualKeyMapTest.vala"
		_tmp42_ = _tmp41_;
#line 184 "SerializableGeeDualKeyMapTest.vala"
		_tmp43_ = _tmp42_;
#line 184 "SerializableGeeDualKeyMapTest.vala"
		_tmp44_ = root;
#line 184 "SerializableGeeDualKeyMapTest.vala"
		gee_collection_add ((GeeCollection*) _tmp43_, _tmp44_);
#line 184 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp43_);
#line 185 "SerializableGeeDualKeyMapTest.vala"
		_tmp45_ = c;
#line 185 "SerializableGeeDualKeyMapTest.vala"
		_tmp46_ = root;
#line 185 "SerializableGeeDualKeyMapTest.vala"
		_tmp47_ = gxml_serializable_dual_key_map_serialize (_tmp45_, _tmp46_, &_inner_error0_);
#line 185 "SerializableGeeDualKeyMapTest.vala"
		_tmp48_ = _tmp47_;
#line 185 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp48_);
#line 185 "SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 185 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (root);
#line 185 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (doc);
#line 185 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (o4);
#line 185 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (o3);
#line 185 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (o2);
#line 185 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (o1);
#line 185 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (c);
#line 1859 "SerializableGeeDualKeyMapTest.c"
			goto __catch352_g_error;
		}
#line 186 "SerializableGeeDualKeyMapTest.vala"
		_tmp49_ = root;
#line 186 "SerializableGeeDualKeyMapTest.vala"
		_tmp50_ = gxml_node_get_children_nodes (_tmp49_);
#line 186 "SerializableGeeDualKeyMapTest.vala"
		_tmp51_ = _tmp50_;
#line 186 "SerializableGeeDualKeyMapTest.vala"
		_tmp52_ = _tmp51_;
#line 186 "SerializableGeeDualKeyMapTest.vala"
		_tmp53_ = gee_collection_get_size ((GeeCollection*) _tmp52_);
#line 186 "SerializableGeeDualKeyMapTest.vala"
		_tmp54_ = _tmp53_;
#line 186 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp54_ == 4, "root.children_nodes.size == 4");
#line 186 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp52_);
#line 187 "SerializableGeeDualKeyMapTest.vala"
		found1 = FALSE;
#line 188 "SerializableGeeDualKeyMapTest.vala"
		found2 = FALSE;
#line 189 "SerializableGeeDualKeyMapTest.vala"
		found3 = FALSE;
#line 190 "SerializableGeeDualKeyMapTest.vala"
		found4 = FALSE;
#line 191 "SerializableGeeDualKeyMapTest.vala"
		nodes = 0;
#line 192 "SerializableGeeDualKeyMapTest.vala"
		i = 0;
#line 1890 "SerializableGeeDualKeyMapTest.c"
		{
			GeeBidirList* _n_list = NULL;
			GXmlNode* _tmp55_;
			GeeBidirList* _tmp56_;
			GeeBidirList* _tmp57_;
			gint _n_size = 0;
			GeeBidirList* _tmp58_;
			gint _tmp59_;
			gint _tmp60_;
			gint _n_index = 0;
#line 193 "SerializableGeeDualKeyMapTest.vala"
			_tmp55_ = root;
#line 193 "SerializableGeeDualKeyMapTest.vala"
			_tmp56_ = gxml_node_get_children_nodes (_tmp55_);
#line 193 "SerializableGeeDualKeyMapTest.vala"
			_tmp57_ = _tmp56_;
#line 193 "SerializableGeeDualKeyMapTest.vala"
			_n_list = _tmp57_;
#line 193 "SerializableGeeDualKeyMapTest.vala"
			_tmp58_ = _n_list;
#line 193 "SerializableGeeDualKeyMapTest.vala"
			_tmp59_ = gee_collection_get_size ((GeeCollection*) _tmp58_);
#line 193 "SerializableGeeDualKeyMapTest.vala"
			_tmp60_ = _tmp59_;
#line 193 "SerializableGeeDualKeyMapTest.vala"
			_n_size = _tmp60_;
#line 193 "SerializableGeeDualKeyMapTest.vala"
			_n_index = -1;
#line 193 "SerializableGeeDualKeyMapTest.vala"
			while (TRUE) {
#line 1921 "SerializableGeeDualKeyMapTest.c"
				GXmlNode* n = NULL;
				GeeBidirList* _tmp61_;
				gpointer _tmp62_;
				gint _tmp63_;
				gboolean _tmp64_ = FALSE;
				GXmlNode* _tmp65_;
#line 193 "SerializableGeeDualKeyMapTest.vala"
				_n_index = _n_index + 1;
#line 193 "SerializableGeeDualKeyMapTest.vala"
				if (!(_n_index < _n_size)) {
#line 193 "SerializableGeeDualKeyMapTest.vala"
					break;
#line 1934 "SerializableGeeDualKeyMapTest.c"
				}
#line 193 "SerializableGeeDualKeyMapTest.vala"
				_tmp61_ = _n_list;
#line 193 "SerializableGeeDualKeyMapTest.vala"
				_tmp62_ = gee_list_get ((GeeList*) _tmp61_, _n_index);
#line 193 "SerializableGeeDualKeyMapTest.vala"
				n = (GXmlNode*) _tmp62_;
#line 194 "SerializableGeeDualKeyMapTest.vala"
				_tmp63_ = nodes;
#line 194 "SerializableGeeDualKeyMapTest.vala"
				nodes = _tmp63_ + 1;
#line 195 "SerializableGeeDualKeyMapTest.vala"
				_tmp65_ = n;
#line 195 "SerializableGeeDualKeyMapTest.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp65_, GXML_TYPE_ELEMENT)) {
#line 1950 "SerializableGeeDualKeyMapTest.c"
					GXmlNode* _tmp66_;
					gchar* _tmp67_;
					gchar* _tmp68_;
					gchar* _tmp69_;
#line 195 "SerializableGeeDualKeyMapTest.vala"
					_tmp66_ = n;
#line 195 "SerializableGeeDualKeyMapTest.vala"
					_tmp67_ = gxml_node_get_name (_tmp66_);
#line 195 "SerializableGeeDualKeyMapTest.vala"
					_tmp68_ = _tmp67_;
#line 195 "SerializableGeeDualKeyMapTest.vala"
					_tmp69_ = _tmp68_;
#line 195 "SerializableGeeDualKeyMapTest.vala"
					_tmp64_ = g_strcmp0 (_tmp69_, "spaces") == 0;
#line 195 "SerializableGeeDualKeyMapTest.vala"
					_g_free0 (_tmp69_);
#line 1967 "SerializableGeeDualKeyMapTest.c"
				} else {
#line 195 "SerializableGeeDualKeyMapTest.vala"
					_tmp64_ = FALSE;
#line 1971 "SerializableGeeDualKeyMapTest.c"
				}
#line 195 "SerializableGeeDualKeyMapTest.vala"
				if (_tmp64_) {
#line 1975 "SerializableGeeDualKeyMapTest.c"
					gint _tmp70_;
					GXmlNode* name = NULL;
					GXmlNode* _tmp71_;
					GeeMap* _tmp72_;
					GeeMap* _tmp73_;
					GeeMap* _tmp74_;
					gpointer _tmp75_;
					GXmlNode* _tmp76_;
					GXmlNode* owner = NULL;
					GXmlNode* _tmp77_;
					GeeMap* _tmp78_;
					GeeMap* _tmp79_;
					GeeMap* _tmp80_;
					gpointer _tmp81_;
					GXmlNode* _tmp82_;
					gboolean _tmp83_ = FALSE;
					GXmlNode* _tmp84_;
#line 196 "SerializableGeeDualKeyMapTest.vala"
					_tmp70_ = i;
#line 196 "SerializableGeeDualKeyMapTest.vala"
					i = _tmp70_ + 1;
#line 197 "SerializableGeeDualKeyMapTest.vala"
					_tmp71_ = n;
#line 197 "SerializableGeeDualKeyMapTest.vala"
					_tmp72_ = gxml_node_get_attrs (_tmp71_);
#line 197 "SerializableGeeDualKeyMapTest.vala"
					_tmp73_ = _tmp72_;
#line 197 "SerializableGeeDualKeyMapTest.vala"
					_tmp74_ = _tmp73_;
#line 197 "SerializableGeeDualKeyMapTest.vala"
					_tmp75_ = gee_map_get (_tmp74_, "name");
#line 197 "SerializableGeeDualKeyMapTest.vala"
					_tmp76_ = (GXmlNode*) _tmp75_;
#line 197 "SerializableGeeDualKeyMapTest.vala"
					_g_object_unref0 (_tmp74_);
#line 197 "SerializableGeeDualKeyMapTest.vala"
					name = _tmp76_;
#line 198 "SerializableGeeDualKeyMapTest.vala"
					_tmp77_ = n;
#line 198 "SerializableGeeDualKeyMapTest.vala"
					_tmp78_ = gxml_node_get_attrs (_tmp77_);
#line 198 "SerializableGeeDualKeyMapTest.vala"
					_tmp79_ = _tmp78_;
#line 198 "SerializableGeeDualKeyMapTest.vala"
					_tmp80_ = _tmp79_;
#line 198 "SerializableGeeDualKeyMapTest.vala"
					_tmp81_ = gee_map_get (_tmp80_, "owner");
#line 198 "SerializableGeeDualKeyMapTest.vala"
					_tmp82_ = (GXmlNode*) _tmp81_;
#line 198 "SerializableGeeDualKeyMapTest.vala"
					_g_object_unref0 (_tmp80_);
#line 198 "SerializableGeeDualKeyMapTest.vala"
					owner = _tmp82_;
#line 199 "SerializableGeeDualKeyMapTest.vala"
					_tmp84_ = name;
#line 199 "SerializableGeeDualKeyMapTest.vala"
					if (_tmp84_ != NULL) {
#line 2033 "SerializableGeeDualKeyMapTest.c"
						GXmlNode* _tmp85_;
#line 199 "SerializableGeeDualKeyMapTest.vala"
						_tmp85_ = owner;
#line 199 "SerializableGeeDualKeyMapTest.vala"
						_tmp83_ = _tmp85_ != NULL;
#line 2039 "SerializableGeeDualKeyMapTest.c"
					} else {
#line 199 "SerializableGeeDualKeyMapTest.vala"
						_tmp83_ = FALSE;
#line 2043 "SerializableGeeDualKeyMapTest.c"
					}
#line 199 "SerializableGeeDualKeyMapTest.vala"
					if (_tmp83_) {
#line 2047 "SerializableGeeDualKeyMapTest.c"
						gboolean _tmp86_ = FALSE;
						GXmlNode* _tmp87_;
						gchar* _tmp88_;
						gchar* _tmp89_;
						gchar* _tmp90_;
						gboolean _tmp91_;
						gboolean _tmp96_ = FALSE;
						GXmlNode* _tmp97_;
						gchar* _tmp98_;
						gchar* _tmp99_;
						gchar* _tmp100_;
						gboolean _tmp101_;
						gboolean _tmp106_ = FALSE;
						GXmlNode* _tmp107_;
						gchar* _tmp108_;
						gchar* _tmp109_;
						gchar* _tmp110_;
						gboolean _tmp111_;
						gboolean _tmp116_ = FALSE;
						GXmlNode* _tmp117_;
						gchar* _tmp118_;
						gchar* _tmp119_;
						gchar* _tmp120_;
						gboolean _tmp121_;
#line 200 "SerializableGeeDualKeyMapTest.vala"
						_tmp87_ = name;
#line 200 "SerializableGeeDualKeyMapTest.vala"
						_tmp88_ = gxml_node_get_value (_tmp87_);
#line 200 "SerializableGeeDualKeyMapTest.vala"
						_tmp89_ = _tmp88_;
#line 200 "SerializableGeeDualKeyMapTest.vala"
						_tmp90_ = _tmp89_;
#line 200 "SerializableGeeDualKeyMapTest.vala"
						_tmp91_ = g_strcmp0 (_tmp90_, "Big") == 0;
#line 200 "SerializableGeeDualKeyMapTest.vala"
						_g_free0 (_tmp90_);
#line 200 "SerializableGeeDualKeyMapTest.vala"
						if (_tmp91_) {
#line 2086 "SerializableGeeDualKeyMapTest.c"
							GXmlNode* _tmp92_;
							gchar* _tmp93_;
							gchar* _tmp94_;
							gchar* _tmp95_;
#line 200 "SerializableGeeDualKeyMapTest.vala"
							_tmp92_ = owner;
#line 200 "SerializableGeeDualKeyMapTest.vala"
							_tmp93_ = gxml_node_get_value (_tmp92_);
#line 200 "SerializableGeeDualKeyMapTest.vala"
							_tmp94_ = _tmp93_;
#line 200 "SerializableGeeDualKeyMapTest.vala"
							_tmp95_ = _tmp94_;
#line 200 "SerializableGeeDualKeyMapTest.vala"
							_tmp86_ = g_strcmp0 (_tmp95_, "Floor") == 0;
#line 200 "SerializableGeeDualKeyMapTest.vala"
							_g_free0 (_tmp95_);
#line 2103 "SerializableGeeDualKeyMapTest.c"
						} else {
#line 200 "SerializableGeeDualKeyMapTest.vala"
							_tmp86_ = FALSE;
#line 2107 "SerializableGeeDualKeyMapTest.c"
						}
#line 200 "SerializableGeeDualKeyMapTest.vala"
						if (_tmp86_) {
#line 200 "SerializableGeeDualKeyMapTest.vala"
							found1 = TRUE;
#line 2113 "SerializableGeeDualKeyMapTest.c"
						}
#line 201 "SerializableGeeDualKeyMapTest.vala"
						_tmp97_ = name;
#line 201 "SerializableGeeDualKeyMapTest.vala"
						_tmp98_ = gxml_node_get_value (_tmp97_);
#line 201 "SerializableGeeDualKeyMapTest.vala"
						_tmp99_ = _tmp98_;
#line 201 "SerializableGeeDualKeyMapTest.vala"
						_tmp100_ = _tmp99_;
#line 201 "SerializableGeeDualKeyMapTest.vala"
						_tmp101_ = g_strcmp0 (_tmp100_, "Small") == 0;
#line 201 "SerializableGeeDualKeyMapTest.vala"
						_g_free0 (_tmp100_);
#line 201 "SerializableGeeDualKeyMapTest.vala"
						if (_tmp101_) {
#line 2129 "SerializableGeeDualKeyMapTest.c"
							GXmlNode* _tmp102_;
							gchar* _tmp103_;
							gchar* _tmp104_;
							gchar* _tmp105_;
#line 201 "SerializableGeeDualKeyMapTest.vala"
							_tmp102_ = owner;
#line 201 "SerializableGeeDualKeyMapTest.vala"
							_tmp103_ = gxml_node_get_value (_tmp102_);
#line 201 "SerializableGeeDualKeyMapTest.vala"
							_tmp104_ = _tmp103_;
#line 201 "SerializableGeeDualKeyMapTest.vala"
							_tmp105_ = _tmp104_;
#line 201 "SerializableGeeDualKeyMapTest.vala"
							_tmp96_ = g_strcmp0 (_tmp105_, "Wall") == 0;
#line 201 "SerializableGeeDualKeyMapTest.vala"
							_g_free0 (_tmp105_);
#line 2146 "SerializableGeeDualKeyMapTest.c"
						} else {
#line 201 "SerializableGeeDualKeyMapTest.vala"
							_tmp96_ = FALSE;
#line 2150 "SerializableGeeDualKeyMapTest.c"
						}
#line 201 "SerializableGeeDualKeyMapTest.vala"
						if (_tmp96_) {
#line 201 "SerializableGeeDualKeyMapTest.vala"
							found2 = TRUE;
#line 2156 "SerializableGeeDualKeyMapTest.c"
						}
#line 202 "SerializableGeeDualKeyMapTest.vala"
						_tmp107_ = name;
#line 202 "SerializableGeeDualKeyMapTest.vala"
						_tmp108_ = gxml_node_get_value (_tmp107_);
#line 202 "SerializableGeeDualKeyMapTest.vala"
						_tmp109_ = _tmp108_;
#line 202 "SerializableGeeDualKeyMapTest.vala"
						_tmp110_ = _tmp109_;
#line 202 "SerializableGeeDualKeyMapTest.vala"
						_tmp111_ = g_strcmp0 (_tmp110_, "Bigger") == 0;
#line 202 "SerializableGeeDualKeyMapTest.vala"
						_g_free0 (_tmp110_);
#line 202 "SerializableGeeDualKeyMapTest.vala"
						if (_tmp111_) {
#line 2172 "SerializableGeeDualKeyMapTest.c"
							GXmlNode* _tmp112_;
							gchar* _tmp113_;
							gchar* _tmp114_;
							gchar* _tmp115_;
#line 202 "SerializableGeeDualKeyMapTest.vala"
							_tmp112_ = owner;
#line 202 "SerializableGeeDualKeyMapTest.vala"
							_tmp113_ = gxml_node_get_value (_tmp112_);
#line 202 "SerializableGeeDualKeyMapTest.vala"
							_tmp114_ = _tmp113_;
#line 202 "SerializableGeeDualKeyMapTest.vala"
							_tmp115_ = _tmp114_;
#line 202 "SerializableGeeDualKeyMapTest.vala"
							_tmp106_ = g_strcmp0 (_tmp115_, "Floor") == 0;
#line 202 "SerializableGeeDualKeyMapTest.vala"
							_g_free0 (_tmp115_);
#line 2189 "SerializableGeeDualKeyMapTest.c"
						} else {
#line 202 "SerializableGeeDualKeyMapTest.vala"
							_tmp106_ = FALSE;
#line 2193 "SerializableGeeDualKeyMapTest.c"
						}
#line 202 "SerializableGeeDualKeyMapTest.vala"
						if (_tmp106_) {
#line 202 "SerializableGeeDualKeyMapTest.vala"
							found3 = TRUE;
#line 2199 "SerializableGeeDualKeyMapTest.c"
						}
#line 203 "SerializableGeeDualKeyMapTest.vala"
						_tmp117_ = name;
#line 203 "SerializableGeeDualKeyMapTest.vala"
						_tmp118_ = gxml_node_get_value (_tmp117_);
#line 203 "SerializableGeeDualKeyMapTest.vala"
						_tmp119_ = _tmp118_;
#line 203 "SerializableGeeDualKeyMapTest.vala"
						_tmp120_ = _tmp119_;
#line 203 "SerializableGeeDualKeyMapTest.vala"
						_tmp121_ = g_strcmp0 (_tmp120_, "Smallest") == 0;
#line 203 "SerializableGeeDualKeyMapTest.vala"
						_g_free0 (_tmp120_);
#line 203 "SerializableGeeDualKeyMapTest.vala"
						if (_tmp121_) {
#line 2215 "SerializableGeeDualKeyMapTest.c"
							GXmlNode* _tmp122_;
							gchar* _tmp123_;
							gchar* _tmp124_;
							gchar* _tmp125_;
#line 203 "SerializableGeeDualKeyMapTest.vala"
							_tmp122_ = owner;
#line 203 "SerializableGeeDualKeyMapTest.vala"
							_tmp123_ = gxml_node_get_value (_tmp122_);
#line 203 "SerializableGeeDualKeyMapTest.vala"
							_tmp124_ = _tmp123_;
#line 203 "SerializableGeeDualKeyMapTest.vala"
							_tmp125_ = _tmp124_;
#line 203 "SerializableGeeDualKeyMapTest.vala"
							_tmp116_ = g_strcmp0 (_tmp125_, "Wall") == 0;
#line 203 "SerializableGeeDualKeyMapTest.vala"
							_g_free0 (_tmp125_);
#line 2232 "SerializableGeeDualKeyMapTest.c"
						} else {
#line 203 "SerializableGeeDualKeyMapTest.vala"
							_tmp116_ = FALSE;
#line 2236 "SerializableGeeDualKeyMapTest.c"
						}
#line 203 "SerializableGeeDualKeyMapTest.vala"
						if (_tmp116_) {
#line 203 "SerializableGeeDualKeyMapTest.vala"
							found4 = TRUE;
#line 2242 "SerializableGeeDualKeyMapTest.c"
						}
					}
#line 195 "SerializableGeeDualKeyMapTest.vala"
					_g_object_unref0 (owner);
#line 195 "SerializableGeeDualKeyMapTest.vala"
					_g_object_unref0 (name);
#line 2249 "SerializableGeeDualKeyMapTest.c"
				}
#line 193 "SerializableGeeDualKeyMapTest.vala"
				_g_object_unref0 (n);
#line 2253 "SerializableGeeDualKeyMapTest.c"
			}
#line 193 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (_n_list);
#line 2257 "SerializableGeeDualKeyMapTest.c"
		}
#line 207 "SerializableGeeDualKeyMapTest.vala"
		if (i != 4) {
#line 2261 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp126_;
			gchar* _tmp127_;
			gchar* _tmp128_;
			GXmlTDocument* _tmp129_;
			gchar* _tmp130_;
			gchar* _tmp131_;
			gchar* _tmp132_;
			gchar* _tmp133_;
#line 208 "SerializableGeeDualKeyMapTest.vala"
			_tmp126_ = stdout;
#line 208 "SerializableGeeDualKeyMapTest.vala"
			_tmp127_ = g_strdup_printf ("%i", nodes);
#line 208 "SerializableGeeDualKeyMapTest.vala"
			_tmp128_ = _tmp127_;
#line 208 "SerializableGeeDualKeyMapTest.vala"
			_tmp129_ = doc;
#line 208 "SerializableGeeDualKeyMapTest.vala"
			_tmp130_ = gxml_tnode_to_string ((GXmlTNode*) _tmp129_);
#line 208 "SerializableGeeDualKeyMapTest.vala"
			_tmp131_ = _tmp130_;
#line 208 "SerializableGeeDualKeyMapTest.vala"
			_tmp132_ = g_strconcat ("ERROR: Incorrect number of space nodes. Expected 4, got: ", _tmp128_, "\n", _tmp131_, NULL);
#line 208 "SerializableGeeDualKeyMapTest.vala"
			_tmp133_ = _tmp132_;
#line 208 "SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp126_, "%s", _tmp133_);
#line 208 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp133_);
#line 208 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp131_);
#line 208 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp128_);
#line 209 "SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 2296 "SerializableGeeDualKeyMapTest.c"
		}
#line 212 "SerializableGeeDualKeyMapTest.vala"
		if (nodes != 4) {
#line 2300 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp134_;
			gchar* _tmp135_;
			gchar* _tmp136_;
			GXmlTDocument* _tmp137_;
			gchar* _tmp138_;
			gchar* _tmp139_;
			gchar* _tmp140_;
			gchar* _tmp141_;
#line 213 "SerializableGeeDualKeyMapTest.vala"
			_tmp134_ = stdout;
#line 213 "SerializableGeeDualKeyMapTest.vala"
			_tmp135_ = g_strdup_printf ("%i", nodes);
#line 213 "SerializableGeeDualKeyMapTest.vala"
			_tmp136_ = _tmp135_;
#line 213 "SerializableGeeDualKeyMapTest.vala"
			_tmp137_ = doc;
#line 213 "SerializableGeeDualKeyMapTest.vala"
			_tmp138_ = gxml_tnode_to_string ((GXmlTNode*) _tmp137_);
#line 213 "SerializableGeeDualKeyMapTest.vala"
			_tmp139_ = _tmp138_;
#line 213 "SerializableGeeDualKeyMapTest.vala"
			_tmp140_ = g_strconcat ("ERROR: Incorrect number of nodes. Expected 5, got: ", _tmp136_, "\n", _tmp139_, NULL);
#line 213 "SerializableGeeDualKeyMapTest.vala"
			_tmp141_ = _tmp140_;
#line 213 "SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp134_, "%s", _tmp141_);
#line 213 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp141_);
#line 213 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp139_);
#line 213 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp136_);
#line 214 "SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 2335 "SerializableGeeDualKeyMapTest.c"
		}
#line 216 "SerializableGeeDualKeyMapTest.vala"
		if (!found1) {
#line 2339 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp142_;
			GXmlTDocument* _tmp143_;
			gchar* _tmp144_;
			gchar* _tmp145_;
			gchar* _tmp146_;
			gchar* _tmp147_;
#line 217 "SerializableGeeDualKeyMapTest.vala"
			_tmp142_ = stdout;
#line 217 "SerializableGeeDualKeyMapTest.vala"
			_tmp143_ = doc;
#line 217 "SerializableGeeDualKeyMapTest.vala"
			_tmp144_ = gxml_tnode_to_string ((GXmlTNode*) _tmp143_);
#line 217 "SerializableGeeDualKeyMapTest.vala"
			_tmp145_ = _tmp144_;
#line 217 "SerializableGeeDualKeyMapTest.vala"
			_tmp146_ = g_strconcat ("ERROR: 'Big' / 'Floor' not found\n", _tmp145_, NULL);
#line 217 "SerializableGeeDualKeyMapTest.vala"
			_tmp147_ = _tmp146_;
#line 217 "SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp142_, "%s", _tmp147_);
#line 217 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp147_);
#line 217 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp145_);
#line 218 "SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 2366 "SerializableGeeDualKeyMapTest.c"
		}
#line 220 "SerializableGeeDualKeyMapTest.vala"
		if (!found2) {
#line 2370 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp148_;
			GXmlTDocument* _tmp149_;
			gchar* _tmp150_;
			gchar* _tmp151_;
			gchar* _tmp152_;
			gchar* _tmp153_;
#line 221 "SerializableGeeDualKeyMapTest.vala"
			_tmp148_ = stdout;
#line 221 "SerializableGeeDualKeyMapTest.vala"
			_tmp149_ = doc;
#line 221 "SerializableGeeDualKeyMapTest.vala"
			_tmp150_ = gxml_tnode_to_string ((GXmlTNode*) _tmp149_);
#line 221 "SerializableGeeDualKeyMapTest.vala"
			_tmp151_ = _tmp150_;
#line 221 "SerializableGeeDualKeyMapTest.vala"
			_tmp152_ = g_strconcat ("ERROR: 'Small' / 'Wall' not found\n", _tmp151_, NULL);
#line 221 "SerializableGeeDualKeyMapTest.vala"
			_tmp153_ = _tmp152_;
#line 221 "SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp148_, "%s", _tmp153_);
#line 221 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp153_);
#line 221 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp151_);
#line 222 "SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 2397 "SerializableGeeDualKeyMapTest.c"
		}
#line 224 "SerializableGeeDualKeyMapTest.vala"
		if (!found3) {
#line 2401 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp154_;
			GXmlTDocument* _tmp155_;
			gchar* _tmp156_;
			gchar* _tmp157_;
			gchar* _tmp158_;
			gchar* _tmp159_;
#line 225 "SerializableGeeDualKeyMapTest.vala"
			_tmp154_ = stdout;
#line 225 "SerializableGeeDualKeyMapTest.vala"
			_tmp155_ = doc;
#line 225 "SerializableGeeDualKeyMapTest.vala"
			_tmp156_ = gxml_tnode_to_string ((GXmlTNode*) _tmp155_);
#line 225 "SerializableGeeDualKeyMapTest.vala"
			_tmp157_ = _tmp156_;
#line 225 "SerializableGeeDualKeyMapTest.vala"
			_tmp158_ = g_strconcat ("ERROR: 'Bigger' / 'Floor' not found\n", _tmp157_, NULL);
#line 225 "SerializableGeeDualKeyMapTest.vala"
			_tmp159_ = _tmp158_;
#line 225 "SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp154_, "%s", _tmp159_);
#line 225 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp159_);
#line 225 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp157_);
#line 226 "SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 2428 "SerializableGeeDualKeyMapTest.c"
		}
#line 228 "SerializableGeeDualKeyMapTest.vala"
		if (!found4) {
#line 2432 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp160_;
			GXmlTDocument* _tmp161_;
			gchar* _tmp162_;
			gchar* _tmp163_;
			gchar* _tmp164_;
			gchar* _tmp165_;
#line 229 "SerializableGeeDualKeyMapTest.vala"
			_tmp160_ = stdout;
#line 229 "SerializableGeeDualKeyMapTest.vala"
			_tmp161_ = doc;
#line 229 "SerializableGeeDualKeyMapTest.vala"
			_tmp162_ = gxml_tnode_to_string ((GXmlTNode*) _tmp161_);
#line 229 "SerializableGeeDualKeyMapTest.vala"
			_tmp163_ = _tmp162_;
#line 229 "SerializableGeeDualKeyMapTest.vala"
			_tmp164_ = g_strconcat ("ERROR: 'Smallest' / 'Wall' not found\n", _tmp163_, NULL);
#line 229 "SerializableGeeDualKeyMapTest.vala"
			_tmp165_ = _tmp164_;
#line 229 "SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp160_, "%s", _tmp165_);
#line 229 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp165_);
#line 229 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp163_);
#line 230 "SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 2459 "SerializableGeeDualKeyMapTest.c"
		}
#line 172 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (root);
#line 172 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (doc);
#line 172 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (o4);
#line 172 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (o3);
#line 172 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (o2);
#line 172 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (o1);
#line 172 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (c);
#line 2475 "SerializableGeeDualKeyMapTest.c"
	}
	goto __finally352;
	__catch352_g_error:
	{
		GError* e = NULL;
		FILE* _tmp166_;
		const gchar* _tmp167_;
		const gchar* _tmp168_;
		gchar* _tmp169_;
		gchar* _tmp170_;
#line 172 "SerializableGeeDualKeyMapTest.vala"
		e = _inner_error0_;
#line 172 "SerializableGeeDualKeyMapTest.vala"
		_inner_error0_ = NULL;
#line 234 "SerializableGeeDualKeyMapTest.vala"
		_tmp166_ = stdout;
#line 234 "SerializableGeeDualKeyMapTest.vala"
		_tmp167_ = e->message;
#line 234 "SerializableGeeDualKeyMapTest.vala"
		_tmp168_ = string_to_string (_tmp167_);
#line 234 "SerializableGeeDualKeyMapTest.vala"
		_tmp169_ = g_strconcat ("ERROR: ", _tmp168_, NULL);
#line 234 "SerializableGeeDualKeyMapTest.vala"
		_tmp170_ = _tmp169_;
#line 234 "SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp166_, "%s", _tmp170_);
#line 234 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp170_);
#line 235 "SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 172 "SerializableGeeDualKeyMapTest.vala"
		_g_error_free0 (e);
#line 2508 "SerializableGeeDualKeyMapTest.c"
	}
	__finally352:
#line 172 "SerializableGeeDualKeyMapTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 172 "SerializableGeeDualKeyMapTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 172 "SerializableGeeDualKeyMapTest.vala"
		g_clear_error (&_inner_error0_);
#line 172 "SerializableGeeDualKeyMapTest.vala"
		return;
#line 2519 "SerializableGeeDualKeyMapTest.c"
	}
}

static void
___lambda300__gtest_func (void)
{
#line 170 "SerializableGeeDualKeyMapTest.vala"
	__lambda300_ ();
#line 2528 "SerializableGeeDualKeyMapTest.c"
}

static void
__lambda301_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlSerializableDualKeyMap* c = NULL;
		GXmlSerializableDualKeyMap* _tmp1_;
		GXmlSerializableDualKeyMap* _tmp2_;
		GXmlGDocument* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		GXmlSerializableDualKeyMap* _tmp7_;
		gint _tmp8_;
		gint _tmp9_;
		gboolean found1 = FALSE;
		gboolean found2 = FALSE;
		gboolean found3 = FALSE;
		gboolean found4 = FALSE;
#line 241 "SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"<root><spaces name=\"Small\" owner=\"Wall\"/><spaces name=\"Smallest\"" \
" owner=\"Wall\"/><spaces name=\"Big\" owner=\"Floor\"/><spaces name=\"" \
"Bigger\" owner=\"Floor\"/><spark /></root>", 0, &_inner_error0_);
#line 241 "SerializableGeeDualKeyMapTest.vala"
		doc = _tmp0_;
#line 241 "SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2558 "SerializableGeeDualKeyMapTest.c"
			goto __catch353_g_error;
		}
#line 243 "SerializableGeeDualKeyMapTest.vala"
		_tmp1_ = gxml_serializable_dual_key_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, TYPE_SPACES, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 243 "SerializableGeeDualKeyMapTest.vala"
		c = _tmp1_;
#line 244 "SerializableGeeDualKeyMapTest.vala"
		_tmp2_ = c;
#line 244 "SerializableGeeDualKeyMapTest.vala"
		_tmp3_ = doc;
#line 244 "SerializableGeeDualKeyMapTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) _tmp3_);
#line 244 "SerializableGeeDualKeyMapTest.vala"
		_tmp5_ = _tmp4_;
#line 244 "SerializableGeeDualKeyMapTest.vala"
		_tmp6_ = _tmp5_;
#line 244 "SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_dual_key_map_deserialize (_tmp2_, _tmp6_, &_inner_error0_);
#line 244 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp6_);
#line 244 "SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 244 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (c);
#line 244 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (doc);
#line 2585 "SerializableGeeDualKeyMapTest.c"
			goto __catch353_g_error;
		}
#line 245 "SerializableGeeDualKeyMapTest.vala"
		_tmp7_ = c;
#line 245 "SerializableGeeDualKeyMapTest.vala"
		_tmp8_ = gxml_serializable_dual_key_map_get_size (_tmp7_);
#line 245 "SerializableGeeDualKeyMapTest.vala"
		_tmp9_ = _tmp8_;
#line 245 "SerializableGeeDualKeyMapTest.vala"
		if (_tmp9_ != 4) {
#line 2596 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp10_;
			GXmlSerializableDualKeyMap* _tmp11_;
			gint _tmp12_;
			gint _tmp13_;
			gchar* _tmp14_;
			gchar* _tmp15_;
			gchar* _tmp16_;
			gchar* _tmp17_;
#line 246 "SerializableGeeDualKeyMapTest.vala"
			_tmp10_ = stdout;
#line 246 "SerializableGeeDualKeyMapTest.vala"
			_tmp11_ = c;
#line 246 "SerializableGeeDualKeyMapTest.vala"
			_tmp12_ = gxml_serializable_dual_key_map_get_size (_tmp11_);
#line 246 "SerializableGeeDualKeyMapTest.vala"
			_tmp13_ = _tmp12_;
#line 246 "SerializableGeeDualKeyMapTest.vala"
			_tmp14_ = g_strdup_printf ("%i", _tmp13_);
#line 246 "SerializableGeeDualKeyMapTest.vala"
			_tmp15_ = _tmp14_;
#line 246 "SerializableGeeDualKeyMapTest.vala"
			_tmp16_ = g_strconcat ("ERROR: incorrect size must be 4 got: ", _tmp15_, "\n", NULL);
#line 246 "SerializableGeeDualKeyMapTest.vala"
			_tmp17_ = _tmp16_;
#line 246 "SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp10_, "%s", _tmp17_);
#line 246 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp17_);
#line 246 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp15_);
#line 247 "SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 2629 "SerializableGeeDualKeyMapTest.c"
		}
#line 249 "SerializableGeeDualKeyMapTest.vala"
		found1 = FALSE;
#line 250 "SerializableGeeDualKeyMapTest.vala"
		found2 = FALSE;
#line 251 "SerializableGeeDualKeyMapTest.vala"
		found3 = FALSE;
#line 252 "SerializableGeeDualKeyMapTest.vala"
		found4 = FALSE;
#line 2639 "SerializableGeeDualKeyMapTest.c"
		{
			GeeIterator* _s_it = NULL;
			GXmlSerializableDualKeyMap* _tmp18_;
			GeeCollection* _tmp19_;
			GeeCollection* _tmp20_;
			GeeIterator* _tmp21_;
			GeeIterator* _tmp22_;
#line 253 "SerializableGeeDualKeyMapTest.vala"
			_tmp18_ = c;
#line 253 "SerializableGeeDualKeyMapTest.vala"
			_tmp19_ = gxml_serializable_dual_key_map_values (_tmp18_);
#line 253 "SerializableGeeDualKeyMapTest.vala"
			_tmp20_ = _tmp19_;
#line 253 "SerializableGeeDualKeyMapTest.vala"
			_tmp21_ = gee_iterable_iterator ((GeeIterable*) _tmp20_);
#line 253 "SerializableGeeDualKeyMapTest.vala"
			_tmp22_ = _tmp21_;
#line 253 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (_tmp20_);
#line 253 "SerializableGeeDualKeyMapTest.vala"
			_s_it = _tmp22_;
#line 253 "SerializableGeeDualKeyMapTest.vala"
			while (TRUE) {
#line 2663 "SerializableGeeDualKeyMapTest.c"
				GeeIterator* _tmp23_;
				Spaces* s = NULL;
				GeeIterator* _tmp24_;
				gpointer _tmp25_;
				gboolean _tmp26_ = FALSE;
				Spaces* _tmp27_;
				const gchar* _tmp28_;
				const gchar* _tmp29_;
				gboolean _tmp33_ = FALSE;
				Spaces* _tmp34_;
				const gchar* _tmp35_;
				const gchar* _tmp36_;
				gboolean _tmp40_ = FALSE;
				Spaces* _tmp41_;
				const gchar* _tmp42_;
				const gchar* _tmp43_;
				gboolean _tmp47_ = FALSE;
				Spaces* _tmp48_;
				const gchar* _tmp49_;
				const gchar* _tmp50_;
#line 253 "SerializableGeeDualKeyMapTest.vala"
				_tmp23_ = _s_it;
#line 253 "SerializableGeeDualKeyMapTest.vala"
				if (!gee_iterator_next (_tmp23_)) {
#line 253 "SerializableGeeDualKeyMapTest.vala"
					break;
#line 2690 "SerializableGeeDualKeyMapTest.c"
				}
#line 253 "SerializableGeeDualKeyMapTest.vala"
				_tmp24_ = _s_it;
#line 253 "SerializableGeeDualKeyMapTest.vala"
				_tmp25_ = gee_iterator_get (_tmp24_);
#line 253 "SerializableGeeDualKeyMapTest.vala"
				s = (Spaces*) _tmp25_;
#line 254 "SerializableGeeDualKeyMapTest.vala"
				_tmp27_ = s;
#line 254 "SerializableGeeDualKeyMapTest.vala"
				_tmp28_ = spaces_get_owner (_tmp27_);
#line 254 "SerializableGeeDualKeyMapTest.vala"
				_tmp29_ = _tmp28_;
#line 254 "SerializableGeeDualKeyMapTest.vala"
				if (g_strcmp0 (_tmp29_, "Floor") == 0) {
#line 2706 "SerializableGeeDualKeyMapTest.c"
					Spaces* _tmp30_;
					const gchar* _tmp31_;
					const gchar* _tmp32_;
#line 254 "SerializableGeeDualKeyMapTest.vala"
					_tmp30_ = s;
#line 254 "SerializableGeeDualKeyMapTest.vala"
					_tmp31_ = spaces_get_name (_tmp30_);
#line 254 "SerializableGeeDualKeyMapTest.vala"
					_tmp32_ = _tmp31_;
#line 254 "SerializableGeeDualKeyMapTest.vala"
					_tmp26_ = g_strcmp0 (_tmp32_, "Big") == 0;
#line 2718 "SerializableGeeDualKeyMapTest.c"
				} else {
#line 254 "SerializableGeeDualKeyMapTest.vala"
					_tmp26_ = FALSE;
#line 2722 "SerializableGeeDualKeyMapTest.c"
				}
#line 254 "SerializableGeeDualKeyMapTest.vala"
				if (_tmp26_) {
#line 254 "SerializableGeeDualKeyMapTest.vala"
					found1 = TRUE;
#line 2728 "SerializableGeeDualKeyMapTest.c"
				}
#line 255 "SerializableGeeDualKeyMapTest.vala"
				_tmp34_ = s;
#line 255 "SerializableGeeDualKeyMapTest.vala"
				_tmp35_ = spaces_get_owner (_tmp34_);
#line 255 "SerializableGeeDualKeyMapTest.vala"
				_tmp36_ = _tmp35_;
#line 255 "SerializableGeeDualKeyMapTest.vala"
				if (g_strcmp0 (_tmp36_, "Wall") == 0) {
#line 2738 "SerializableGeeDualKeyMapTest.c"
					Spaces* _tmp37_;
					const gchar* _tmp38_;
					const gchar* _tmp39_;
#line 255 "SerializableGeeDualKeyMapTest.vala"
					_tmp37_ = s;
#line 255 "SerializableGeeDualKeyMapTest.vala"
					_tmp38_ = spaces_get_name (_tmp37_);
#line 255 "SerializableGeeDualKeyMapTest.vala"
					_tmp39_ = _tmp38_;
#line 255 "SerializableGeeDualKeyMapTest.vala"
					_tmp33_ = g_strcmp0 (_tmp39_, "Small") == 0;
#line 2750 "SerializableGeeDualKeyMapTest.c"
				} else {
#line 255 "SerializableGeeDualKeyMapTest.vala"
					_tmp33_ = FALSE;
#line 2754 "SerializableGeeDualKeyMapTest.c"
				}
#line 255 "SerializableGeeDualKeyMapTest.vala"
				if (_tmp33_) {
#line 255 "SerializableGeeDualKeyMapTest.vala"
					found2 = TRUE;
#line 2760 "SerializableGeeDualKeyMapTest.c"
				}
#line 256 "SerializableGeeDualKeyMapTest.vala"
				_tmp41_ = s;
#line 256 "SerializableGeeDualKeyMapTest.vala"
				_tmp42_ = spaces_get_owner (_tmp41_);
#line 256 "SerializableGeeDualKeyMapTest.vala"
				_tmp43_ = _tmp42_;
#line 256 "SerializableGeeDualKeyMapTest.vala"
				if (g_strcmp0 (_tmp43_, "Floor") == 0) {
#line 2770 "SerializableGeeDualKeyMapTest.c"
					Spaces* _tmp44_;
					const gchar* _tmp45_;
					const gchar* _tmp46_;
#line 256 "SerializableGeeDualKeyMapTest.vala"
					_tmp44_ = s;
#line 256 "SerializableGeeDualKeyMapTest.vala"
					_tmp45_ = spaces_get_name (_tmp44_);
#line 256 "SerializableGeeDualKeyMapTest.vala"
					_tmp46_ = _tmp45_;
#line 256 "SerializableGeeDualKeyMapTest.vala"
					_tmp40_ = g_strcmp0 (_tmp46_, "Bigger") == 0;
#line 2782 "SerializableGeeDualKeyMapTest.c"
				} else {
#line 256 "SerializableGeeDualKeyMapTest.vala"
					_tmp40_ = FALSE;
#line 2786 "SerializableGeeDualKeyMapTest.c"
				}
#line 256 "SerializableGeeDualKeyMapTest.vala"
				if (_tmp40_) {
#line 256 "SerializableGeeDualKeyMapTest.vala"
					found3 = TRUE;
#line 2792 "SerializableGeeDualKeyMapTest.c"
				}
#line 257 "SerializableGeeDualKeyMapTest.vala"
				_tmp48_ = s;
#line 257 "SerializableGeeDualKeyMapTest.vala"
				_tmp49_ = spaces_get_owner (_tmp48_);
#line 257 "SerializableGeeDualKeyMapTest.vala"
				_tmp50_ = _tmp49_;
#line 257 "SerializableGeeDualKeyMapTest.vala"
				if (g_strcmp0 (_tmp50_, "Wall") == 0) {
#line 2802 "SerializableGeeDualKeyMapTest.c"
					Spaces* _tmp51_;
					const gchar* _tmp52_;
					const gchar* _tmp53_;
#line 257 "SerializableGeeDualKeyMapTest.vala"
					_tmp51_ = s;
#line 257 "SerializableGeeDualKeyMapTest.vala"
					_tmp52_ = spaces_get_name (_tmp51_);
#line 257 "SerializableGeeDualKeyMapTest.vala"
					_tmp53_ = _tmp52_;
#line 257 "SerializableGeeDualKeyMapTest.vala"
					_tmp47_ = g_strcmp0 (_tmp53_, "Smallest") == 0;
#line 2814 "SerializableGeeDualKeyMapTest.c"
				} else {
#line 257 "SerializableGeeDualKeyMapTest.vala"
					_tmp47_ = FALSE;
#line 2818 "SerializableGeeDualKeyMapTest.c"
				}
#line 257 "SerializableGeeDualKeyMapTest.vala"
				if (_tmp47_) {
#line 257 "SerializableGeeDualKeyMapTest.vala"
					found4 = TRUE;
#line 2824 "SerializableGeeDualKeyMapTest.c"
				}
#line 253 "SerializableGeeDualKeyMapTest.vala"
				_g_object_unref0 (s);
#line 2828 "SerializableGeeDualKeyMapTest.c"
			}
#line 253 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (_s_it);
#line 2832 "SerializableGeeDualKeyMapTest.c"
		}
#line 259 "SerializableGeeDualKeyMapTest.vala"
		if (!found1) {
#line 2836 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp54_;
			GXmlGDocument* _tmp55_;
			gchar* _tmp56_;
			gchar* _tmp57_;
			gchar* _tmp58_;
			gchar* _tmp59_;
#line 260 "SerializableGeeDualKeyMapTest.vala"
			_tmp54_ = stdout;
#line 260 "SerializableGeeDualKeyMapTest.vala"
			_tmp55_ = doc;
#line 260 "SerializableGeeDualKeyMapTest.vala"
			_tmp56_ = gxml_gnode_to_string ((GXmlGNode*) _tmp55_);
#line 260 "SerializableGeeDualKeyMapTest.vala"
			_tmp57_ = _tmp56_;
#line 260 "SerializableGeeDualKeyMapTest.vala"
			_tmp58_ = g_strconcat ("ERROR: 'Big' / 'Floor' not found\n", _tmp57_, NULL);
#line 260 "SerializableGeeDualKeyMapTest.vala"
			_tmp59_ = _tmp58_;
#line 260 "SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp54_, "%s", _tmp59_);
#line 260 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp59_);
#line 260 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp57_);
#line 261 "SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 2863 "SerializableGeeDualKeyMapTest.c"
		}
#line 263 "SerializableGeeDualKeyMapTest.vala"
		if (!found2) {
#line 2867 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp60_;
			GXmlGDocument* _tmp61_;
			gchar* _tmp62_;
			gchar* _tmp63_;
			gchar* _tmp64_;
			gchar* _tmp65_;
#line 264 "SerializableGeeDualKeyMapTest.vala"
			_tmp60_ = stdout;
#line 264 "SerializableGeeDualKeyMapTest.vala"
			_tmp61_ = doc;
#line 264 "SerializableGeeDualKeyMapTest.vala"
			_tmp62_ = gxml_gnode_to_string ((GXmlGNode*) _tmp61_);
#line 264 "SerializableGeeDualKeyMapTest.vala"
			_tmp63_ = _tmp62_;
#line 264 "SerializableGeeDualKeyMapTest.vala"
			_tmp64_ = g_strconcat ("ERROR: 'Small' / 'Wall' not found\n", _tmp63_, NULL);
#line 264 "SerializableGeeDualKeyMapTest.vala"
			_tmp65_ = _tmp64_;
#line 264 "SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp60_, "%s", _tmp65_);
#line 264 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp65_);
#line 264 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp63_);
#line 265 "SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 2894 "SerializableGeeDualKeyMapTest.c"
		}
#line 267 "SerializableGeeDualKeyMapTest.vala"
		if (!found3) {
#line 2898 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp66_;
			GXmlGDocument* _tmp67_;
			gchar* _tmp68_;
			gchar* _tmp69_;
			gchar* _tmp70_;
			gchar* _tmp71_;
#line 268 "SerializableGeeDualKeyMapTest.vala"
			_tmp66_ = stdout;
#line 268 "SerializableGeeDualKeyMapTest.vala"
			_tmp67_ = doc;
#line 268 "SerializableGeeDualKeyMapTest.vala"
			_tmp68_ = gxml_gnode_to_string ((GXmlGNode*) _tmp67_);
#line 268 "SerializableGeeDualKeyMapTest.vala"
			_tmp69_ = _tmp68_;
#line 268 "SerializableGeeDualKeyMapTest.vala"
			_tmp70_ = g_strconcat ("ERROR: 'Bigger' / 'Floor' not found\n", _tmp69_, NULL);
#line 268 "SerializableGeeDualKeyMapTest.vala"
			_tmp71_ = _tmp70_;
#line 268 "SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp66_, "%s", _tmp71_);
#line 268 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp71_);
#line 268 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp69_);
#line 269 "SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 2925 "SerializableGeeDualKeyMapTest.c"
		}
#line 271 "SerializableGeeDualKeyMapTest.vala"
		if (!found4) {
#line 2929 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp72_;
			GXmlGDocument* _tmp73_;
			gchar* _tmp74_;
			gchar* _tmp75_;
			gchar* _tmp76_;
			gchar* _tmp77_;
#line 272 "SerializableGeeDualKeyMapTest.vala"
			_tmp72_ = stdout;
#line 272 "SerializableGeeDualKeyMapTest.vala"
			_tmp73_ = doc;
#line 272 "SerializableGeeDualKeyMapTest.vala"
			_tmp74_ = gxml_gnode_to_string ((GXmlGNode*) _tmp73_);
#line 272 "SerializableGeeDualKeyMapTest.vala"
			_tmp75_ = _tmp74_;
#line 272 "SerializableGeeDualKeyMapTest.vala"
			_tmp76_ = g_strconcat ("ERROR: 'Smallest' / 'Wall' not found\n", _tmp75_, NULL);
#line 272 "SerializableGeeDualKeyMapTest.vala"
			_tmp77_ = _tmp76_;
#line 272 "SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp72_, "%s", _tmp77_);
#line 272 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp77_);
#line 272 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp75_);
#line 273 "SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 2956 "SerializableGeeDualKeyMapTest.c"
		}
#line 240 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (c);
#line 240 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (doc);
#line 2962 "SerializableGeeDualKeyMapTest.c"
	}
	goto __finally353;
	__catch353_g_error:
	{
		GError* e = NULL;
		FILE* _tmp78_;
		const gchar* _tmp79_;
		const gchar* _tmp80_;
		gchar* _tmp81_;
		gchar* _tmp82_;
#line 240 "SerializableGeeDualKeyMapTest.vala"
		e = _inner_error0_;
#line 240 "SerializableGeeDualKeyMapTest.vala"
		_inner_error0_ = NULL;
#line 277 "SerializableGeeDualKeyMapTest.vala"
		_tmp78_ = stdout;
#line 277 "SerializableGeeDualKeyMapTest.vala"
		_tmp79_ = e->message;
#line 277 "SerializableGeeDualKeyMapTest.vala"
		_tmp80_ = string_to_string (_tmp79_);
#line 277 "SerializableGeeDualKeyMapTest.vala"
		_tmp81_ = g_strconcat ("ERROR: ", _tmp80_, NULL);
#line 277 "SerializableGeeDualKeyMapTest.vala"
		_tmp82_ = _tmp81_;
#line 277 "SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp78_, "%s", _tmp82_);
#line 277 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp82_);
#line 278 "SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 240 "SerializableGeeDualKeyMapTest.vala"
		_g_error_free0 (e);
#line 2995 "SerializableGeeDualKeyMapTest.c"
	}
	__finally353:
#line 240 "SerializableGeeDualKeyMapTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 240 "SerializableGeeDualKeyMapTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 240 "SerializableGeeDualKeyMapTest.vala"
		g_clear_error (&_inner_error0_);
#line 240 "SerializableGeeDualKeyMapTest.vala"
		return;
#line 3006 "SerializableGeeDualKeyMapTest.c"
	}
}

static void
___lambda301__gtest_func (void)
{
#line 238 "SerializableGeeDualKeyMapTest.vala"
	__lambda301_ ();
#line 3015 "SerializableGeeDualKeyMapTest.c"
}

static void
__lambda302_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* idoc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlSerializableDualKeyMap* ic = NULL;
		GXmlSerializableDualKeyMap* _tmp1_;
		GXmlSerializableDualKeyMap* _tmp2_;
		GXmlGDocument* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		GXmlSerializableDualKeyMap* _tmp7_;
		gint _tmp8_;
		gint _tmp9_;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp21_;
		GXmlSerializableDualKeyMap* _tmp22_;
		GXmlGDocument* _tmp23_;
		GXmlNode* _tmp24_;
		GXmlNode* _tmp25_;
		GXmlNode* _tmp26_;
		GXmlNode* _tmp27_;
		GXmlNode* _tmp28_;
		GXmlSerializableDualKeyMap* c = NULL;
		GXmlSerializableDualKeyMap* _tmp29_;
		GXmlSerializableDualKeyMap* _tmp30_;
		GXmlGDocument* _tmp31_;
		GXmlNode* _tmp32_;
		GXmlNode* _tmp33_;
		GXmlNode* _tmp34_;
		GXmlSerializableDualKeyMap* _tmp35_;
		gint _tmp36_;
		gint _tmp37_;
#line 284 "SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"<root><spaces name=\"Small\" owner=\"Wall\"/><spaces name=\"Smallest\"" \
" owner=\"Wall\"/><spaces name=\"Big\" owner=\"Floor\"/><spaces name=\"" \
"Bigger\" owner=\"Floor\"/><spark /></root>", 0, &_inner_error0_);
#line 284 "SerializableGeeDualKeyMapTest.vala"
		idoc = _tmp0_;
#line 284 "SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 3060 "SerializableGeeDualKeyMapTest.c"
			goto __catch354_g_error;
		}
#line 286 "SerializableGeeDualKeyMapTest.vala"
		_tmp1_ = gxml_serializable_dual_key_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, TYPE_SPACES, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 286 "SerializableGeeDualKeyMapTest.vala"
		ic = _tmp1_;
#line 287 "SerializableGeeDualKeyMapTest.vala"
		_tmp2_ = ic;
#line 287 "SerializableGeeDualKeyMapTest.vala"
		_tmp3_ = idoc;
#line 287 "SerializableGeeDualKeyMapTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) _tmp3_);
#line 287 "SerializableGeeDualKeyMapTest.vala"
		_tmp5_ = _tmp4_;
#line 287 "SerializableGeeDualKeyMapTest.vala"
		_tmp6_ = _tmp5_;
#line 287 "SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_dual_key_map_deserialize (_tmp2_, _tmp6_, &_inner_error0_);
#line 287 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp6_);
#line 287 "SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 287 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (ic);
#line 287 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (idoc);
#line 3087 "SerializableGeeDualKeyMapTest.c"
			goto __catch354_g_error;
		}
#line 288 "SerializableGeeDualKeyMapTest.vala"
		_tmp7_ = ic;
#line 288 "SerializableGeeDualKeyMapTest.vala"
		_tmp8_ = gxml_serializable_dual_key_map_get_size (_tmp7_);
#line 288 "SerializableGeeDualKeyMapTest.vala"
		_tmp9_ = _tmp8_;
#line 288 "SerializableGeeDualKeyMapTest.vala"
		if (_tmp9_ != 4) {
#line 3098 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp10_;
			GXmlSerializableDualKeyMap* _tmp11_;
			gint _tmp12_;
			gint _tmp13_;
			gchar* _tmp14_;
			gchar* _tmp15_;
			GXmlGDocument* _tmp16_;
			gchar* _tmp17_;
			gchar* _tmp18_;
			gchar* _tmp19_;
			gchar* _tmp20_;
#line 289 "SerializableGeeDualKeyMapTest.vala"
			_tmp10_ = stdout;
#line 289 "SerializableGeeDualKeyMapTest.vala"
			_tmp11_ = ic;
#line 289 "SerializableGeeDualKeyMapTest.vala"
			_tmp12_ = gxml_serializable_dual_key_map_get_size (_tmp11_);
#line 289 "SerializableGeeDualKeyMapTest.vala"
			_tmp13_ = _tmp12_;
#line 289 "SerializableGeeDualKeyMapTest.vala"
			_tmp14_ = g_strdup_printf ("%i", _tmp13_);
#line 289 "SerializableGeeDualKeyMapTest.vala"
			_tmp15_ = _tmp14_;
#line 289 "SerializableGeeDualKeyMapTest.vala"
			_tmp16_ = idoc;
#line 289 "SerializableGeeDualKeyMapTest.vala"
			_tmp17_ = gxml_gnode_to_string ((GXmlGNode*) _tmp16_);
#line 289 "SerializableGeeDualKeyMapTest.vala"
			_tmp18_ = _tmp17_;
#line 289 "SerializableGeeDualKeyMapTest.vala"
			_tmp19_ = g_strconcat ("ERROR: Incorrect size (1st deserialize). Expected 4, got: ", _tmp15_, "\n", _tmp18_, "\n", NULL);
#line 289 "SerializableGeeDualKeyMapTest.vala"
			_tmp20_ = _tmp19_;
#line 289 "SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp10_, "%s", _tmp20_);
#line 289 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp20_);
#line 289 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp18_);
#line 289 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp15_);
#line 290 "SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 3142 "SerializableGeeDualKeyMapTest.c"
		}
#line 292 "SerializableGeeDualKeyMapTest.vala"
		_tmp21_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n<root />", 0, &_inner_error0_);
#line 292 "SerializableGeeDualKeyMapTest.vala"
		doc = _tmp21_;
#line 292 "SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 292 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (ic);
#line 292 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (idoc);
#line 3154 "SerializableGeeDualKeyMapTest.c"
			goto __catch354_g_error;
		}
#line 294 "SerializableGeeDualKeyMapTest.vala"
		_tmp22_ = ic;
#line 294 "SerializableGeeDualKeyMapTest.vala"
		_tmp23_ = doc;
#line 294 "SerializableGeeDualKeyMapTest.vala"
		_tmp24_ = gxml_document_get_root ((GXmlDocument*) _tmp23_);
#line 294 "SerializableGeeDualKeyMapTest.vala"
		_tmp25_ = _tmp24_;
#line 294 "SerializableGeeDualKeyMapTest.vala"
		_tmp26_ = _tmp25_;
#line 294 "SerializableGeeDualKeyMapTest.vala"
		_tmp27_ = gxml_serializable_dual_key_map_serialize (_tmp22_, _tmp26_, &_inner_error0_);
#line 294 "SerializableGeeDualKeyMapTest.vala"
		_tmp28_ = _tmp27_;
#line 294 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp28_);
#line 294 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp26_);
#line 294 "SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 294 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (doc);
#line 294 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (ic);
#line 294 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (idoc);
#line 3183 "SerializableGeeDualKeyMapTest.c"
			goto __catch354_g_error;
		}
#line 295 "SerializableGeeDualKeyMapTest.vala"
		_tmp29_ = gxml_serializable_dual_key_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, TYPE_SPACES, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 295 "SerializableGeeDualKeyMapTest.vala"
		c = _tmp29_;
#line 296 "SerializableGeeDualKeyMapTest.vala"
		_tmp30_ = c;
#line 296 "SerializableGeeDualKeyMapTest.vala"
		_tmp31_ = doc;
#line 296 "SerializableGeeDualKeyMapTest.vala"
		_tmp32_ = gxml_document_get_root ((GXmlDocument*) _tmp31_);
#line 296 "SerializableGeeDualKeyMapTest.vala"
		_tmp33_ = _tmp32_;
#line 296 "SerializableGeeDualKeyMapTest.vala"
		_tmp34_ = _tmp33_;
#line 296 "SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_dual_key_map_deserialize (_tmp30_, _tmp34_, &_inner_error0_);
#line 296 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp34_);
#line 296 "SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 296 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (c);
#line 296 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (doc);
#line 296 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (ic);
#line 296 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (idoc);
#line 3214 "SerializableGeeDualKeyMapTest.c"
			goto __catch354_g_error;
		}
#line 297 "SerializableGeeDualKeyMapTest.vala"
		_tmp35_ = c;
#line 297 "SerializableGeeDualKeyMapTest.vala"
		_tmp36_ = gxml_serializable_dual_key_map_get_size (_tmp35_);
#line 297 "SerializableGeeDualKeyMapTest.vala"
		_tmp37_ = _tmp36_;
#line 297 "SerializableGeeDualKeyMapTest.vala"
		if (_tmp37_ != 4) {
#line 3225 "SerializableGeeDualKeyMapTest.c"
			FILE* _tmp38_;
			GXmlSerializableDualKeyMap* _tmp39_;
			gint _tmp40_;
			gint _tmp41_;
			gchar* _tmp42_;
			gchar* _tmp43_;
			GXmlGDocument* _tmp44_;
			gchar* _tmp45_;
			gchar* _tmp46_;
			gchar* _tmp47_;
			gchar* _tmp48_;
#line 298 "SerializableGeeDualKeyMapTest.vala"
			_tmp38_ = stdout;
#line 298 "SerializableGeeDualKeyMapTest.vala"
			_tmp39_ = c;
#line 298 "SerializableGeeDualKeyMapTest.vala"
			_tmp40_ = gxml_serializable_dual_key_map_get_size (_tmp39_);
#line 298 "SerializableGeeDualKeyMapTest.vala"
			_tmp41_ = _tmp40_;
#line 298 "SerializableGeeDualKeyMapTest.vala"
			_tmp42_ = g_strdup_printf ("%i", _tmp41_);
#line 298 "SerializableGeeDualKeyMapTest.vala"
			_tmp43_ = _tmp42_;
#line 298 "SerializableGeeDualKeyMapTest.vala"
			_tmp44_ = doc;
#line 298 "SerializableGeeDualKeyMapTest.vala"
			_tmp45_ = gxml_gnode_to_string ((GXmlGNode*) _tmp44_);
#line 298 "SerializableGeeDualKeyMapTest.vala"
			_tmp46_ = _tmp45_;
#line 298 "SerializableGeeDualKeyMapTest.vala"
			_tmp47_ = g_strconcat ("ERROR: Incorrect size. Expected 4, got: ", _tmp43_, "\n", _tmp46_, "\n", NULL);
#line 298 "SerializableGeeDualKeyMapTest.vala"
			_tmp48_ = _tmp47_;
#line 298 "SerializableGeeDualKeyMapTest.vala"
			fprintf (_tmp38_, "%s", _tmp48_);
#line 298 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp48_);
#line 298 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp46_);
#line 298 "SerializableGeeDualKeyMapTest.vala"
			_g_free0 (_tmp43_);
#line 299 "SerializableGeeDualKeyMapTest.vala"
			g_assert_not_reached ();
#line 3269 "SerializableGeeDualKeyMapTest.c"
		}
#line 283 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (c);
#line 283 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (doc);
#line 283 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (ic);
#line 283 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (idoc);
#line 3279 "SerializableGeeDualKeyMapTest.c"
	}
	goto __finally354;
	__catch354_g_error:
	{
		GError* e = NULL;
		FILE* _tmp49_;
		const gchar* _tmp50_;
		const gchar* _tmp51_;
		gchar* _tmp52_;
		gchar* _tmp53_;
#line 283 "SerializableGeeDualKeyMapTest.vala"
		e = _inner_error0_;
#line 283 "SerializableGeeDualKeyMapTest.vala"
		_inner_error0_ = NULL;
#line 303 "SerializableGeeDualKeyMapTest.vala"
		_tmp49_ = stdout;
#line 303 "SerializableGeeDualKeyMapTest.vala"
		_tmp50_ = e->message;
#line 303 "SerializableGeeDualKeyMapTest.vala"
		_tmp51_ = string_to_string (_tmp50_);
#line 303 "SerializableGeeDualKeyMapTest.vala"
		_tmp52_ = g_strconcat ("ERROR: ", _tmp51_, NULL);
#line 303 "SerializableGeeDualKeyMapTest.vala"
		_tmp53_ = _tmp52_;
#line 303 "SerializableGeeDualKeyMapTest.vala"
		fprintf (_tmp49_, "%s", _tmp53_);
#line 303 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp53_);
#line 304 "SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 283 "SerializableGeeDualKeyMapTest.vala"
		_g_error_free0 (e);
#line 3312 "SerializableGeeDualKeyMapTest.c"
	}
	__finally354:
#line 283 "SerializableGeeDualKeyMapTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 283 "SerializableGeeDualKeyMapTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 283 "SerializableGeeDualKeyMapTest.vala"
		g_clear_error (&_inner_error0_);
#line 283 "SerializableGeeDualKeyMapTest.vala"
		return;
#line 3323 "SerializableGeeDualKeyMapTest.c"
	}
}

static void
___lambda302__gtest_func (void)
{
#line 281 "SerializableGeeDualKeyMapTest.vala"
	__lambda302_ ();
#line 3332 "SerializableGeeDualKeyMapTest.c"
}

static void
__lambda303_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* d = NULL;
		GXmlGDocument* _tmp0_;
		BookStore* bs = NULL;
		BookStore* _tmp1_;
		BookStore* _tmp2_;
		GXmlGDocument* _tmp3_;
		BookStore* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		BookStore* _tmp7_;
		BookArray* _tmp8_;
		BookArray* _tmp9_;
		gint _tmp10_;
		gint _tmp11_;
		Book* b = NULL;
		BookStore* _tmp12_;
		BookArray* _tmp13_;
		BookArray* _tmp14_;
		gpointer _tmp15_;
		Name* _tmp16_;
		Name* _tmp17_;
		Name* _tmp18_;
		Name* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		const gchar* _tmp22_;
		const gchar* _tmp23_;
		Authors* _tmp24_;
		Authors* _tmp25_;
		Authors* _tmp26_;
		Authors* _tmp27_;
		AuthorArray* _tmp28_;
		AuthorArray* _tmp29_;
		Authors* _tmp30_;
		Authors* _tmp31_;
		AuthorArray* _tmp32_;
		AuthorArray* _tmp33_;
		gint _tmp34_;
		gint _tmp35_;
		InventoryDualKeyMap* _tmp36_;
		InventoryDualKeyMap* _tmp37_;
		InventoryDualKeyMap* _tmp38_;
		InventoryDualKeyMap* _tmp39_;
		gint _tmp40_;
		gint _tmp41_;
		Inventory* ir = NULL;
		InventoryDualKeyMap* _tmp42_;
		InventoryDualKeyMap* _tmp43_;
		gpointer _tmp44_;
		gint _tmp45_;
		gint _tmp46_;
		const gchar* _tmp47_;
		const gchar* _tmp48_;
		gint _tmp49_;
		gint _tmp50_;
#line 310 "SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = gxml_gdocument_new_from_path (TEST_DIR "/test-collection.xml", 0, &_inner_error0_);
#line 310 "SerializableGeeDualKeyMapTest.vala"
		d = _tmp0_;
#line 310 "SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 3401 "SerializableGeeDualKeyMapTest.c"
			goto __catch355_g_error;
		}
#line 311 "SerializableGeeDualKeyMapTest.vala"
		_tmp1_ = book_store_new ();
#line 311 "SerializableGeeDualKeyMapTest.vala"
		bs = _tmp1_;
#line 312 "SerializableGeeDualKeyMapTest.vala"
		_tmp2_ = bs;
#line 312 "SerializableGeeDualKeyMapTest.vala"
		_tmp3_ = d;
#line 312 "SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 312 "SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 312 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bs);
#line 312 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (d);
#line 3420 "SerializableGeeDualKeyMapTest.c"
			goto __catch355_g_error;
		}
#line 313 "SerializableGeeDualKeyMapTest.vala"
		_tmp4_ = bs;
#line 313 "SerializableGeeDualKeyMapTest.vala"
		_tmp5_ = book_store_get_name (_tmp4_);
#line 313 "SerializableGeeDualKeyMapTest.vala"
		_tmp6_ = _tmp5_;
#line 313 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp6_, "The Great Book") == 0, "bs.name == \"The Great Book\"");
#line 314 "SerializableGeeDualKeyMapTest.vala"
		_tmp7_ = bs;
#line 314 "SerializableGeeDualKeyMapTest.vala"
		_tmp8_ = book_store_get_books (_tmp7_);
#line 314 "SerializableGeeDualKeyMapTest.vala"
		_tmp9_ = _tmp8_;
#line 314 "SerializableGeeDualKeyMapTest.vala"
		_tmp10_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp9_);
#line 314 "SerializableGeeDualKeyMapTest.vala"
		_tmp11_ = _tmp10_;
#line 314 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp11_ == 3, "bs.books.size == 3");
#line 315 "SerializableGeeDualKeyMapTest.vala"
		_tmp12_ = bs;
#line 315 "SerializableGeeDualKeyMapTest.vala"
		_tmp13_ = book_store_get_books (_tmp12_);
#line 315 "SerializableGeeDualKeyMapTest.vala"
		_tmp14_ = _tmp13_;
#line 315 "SerializableGeeDualKeyMapTest.vala"
		_tmp15_ = gee_list_first ((GeeList*) _tmp14_);
#line 315 "SerializableGeeDualKeyMapTest.vala"
		b = (Book*) _tmp15_;
#line 316 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (b != NULL, "b != null");
#line 317 "SerializableGeeDualKeyMapTest.vala"
		_tmp16_ = book_get_name (b);
#line 317 "SerializableGeeDualKeyMapTest.vala"
		_tmp17_ = _tmp16_;
#line 317 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp17_ != NULL, "b.name != null");
#line 318 "SerializableGeeDualKeyMapTest.vala"
		_tmp18_ = book_get_name (b);
#line 318 "SerializableGeeDualKeyMapTest.vala"
		_tmp19_ = _tmp18_;
#line 318 "SerializableGeeDualKeyMapTest.vala"
		_tmp20_ = name_get_name (_tmp19_);
#line 318 "SerializableGeeDualKeyMapTest.vala"
		_tmp21_ = _tmp20_;
#line 318 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp21_, "Book1") == 0, "b.name.get_name () == \"Book1\"");
#line 318 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp21_);
#line 319 "SerializableGeeDualKeyMapTest.vala"
		_tmp22_ = book_get_year (b);
#line 319 "SerializableGeeDualKeyMapTest.vala"
		_tmp23_ = _tmp22_;
#line 319 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp23_, "2015") == 0, "b.year == \"2015\"");
#line 320 "SerializableGeeDualKeyMapTest.vala"
		_tmp24_ = book_get_authors (b);
#line 320 "SerializableGeeDualKeyMapTest.vala"
		_tmp25_ = _tmp24_;
#line 320 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp25_ != NULL, "b.authors != null");
#line 321 "SerializableGeeDualKeyMapTest.vala"
		_tmp26_ = book_get_authors (b);
#line 321 "SerializableGeeDualKeyMapTest.vala"
		_tmp27_ = _tmp26_;
#line 321 "SerializableGeeDualKeyMapTest.vala"
		_tmp28_ = authors_get_array (_tmp27_);
#line 321 "SerializableGeeDualKeyMapTest.vala"
		_tmp29_ = _tmp28_;
#line 321 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp29_ != NULL, "b.authors.array != null");
#line 322 "SerializableGeeDualKeyMapTest.vala"
		_tmp30_ = book_get_authors (b);
#line 322 "SerializableGeeDualKeyMapTest.vala"
		_tmp31_ = _tmp30_;
#line 322 "SerializableGeeDualKeyMapTest.vala"
		_tmp32_ = authors_get_array (_tmp31_);
#line 322 "SerializableGeeDualKeyMapTest.vala"
		_tmp33_ = _tmp32_;
#line 322 "SerializableGeeDualKeyMapTest.vala"
		_tmp34_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp33_);
#line 322 "SerializableGeeDualKeyMapTest.vala"
		_tmp35_ = _tmp34_;
#line 322 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp35_ == 2, "b.authors.array.size == 2");
#line 323 "SerializableGeeDualKeyMapTest.vala"
		_tmp36_ = book_get_inventory_registers (b);
#line 323 "SerializableGeeDualKeyMapTest.vala"
		_tmp37_ = _tmp36_;
#line 323 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp37_ != NULL, "b.inventory_registers != null");
#line 324 "SerializableGeeDualKeyMapTest.vala"
		_tmp38_ = book_get_inventory_registers (b);
#line 324 "SerializableGeeDualKeyMapTest.vala"
		_tmp39_ = _tmp38_;
#line 324 "SerializableGeeDualKeyMapTest.vala"
		_tmp40_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp39_);
#line 324 "SerializableGeeDualKeyMapTest.vala"
		_tmp41_ = _tmp40_;
#line 324 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp41_ == 4, "b.inventory_registers.size == 4");
#line 325 "SerializableGeeDualKeyMapTest.vala"
		_tmp42_ = book_get_inventory_registers (b);
#line 325 "SerializableGeeDualKeyMapTest.vala"
		_tmp43_ = _tmp42_;
#line 325 "SerializableGeeDualKeyMapTest.vala"
		_tmp44_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp43_, (gpointer) ((gintptr) 1), "K001");
#line 325 "SerializableGeeDualKeyMapTest.vala"
		ir = (Inventory*) _tmp44_;
#line 326 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (ir != NULL, "ir != null");
#line 327 "SerializableGeeDualKeyMapTest.vala"
		_tmp45_ = inventory_get_number (ir);
#line 327 "SerializableGeeDualKeyMapTest.vala"
		_tmp46_ = _tmp45_;
#line 327 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp46_ == 1, "ir.number == 1");
#line 328 "SerializableGeeDualKeyMapTest.vala"
		_tmp47_ = inventory_get_inventory (ir);
#line 328 "SerializableGeeDualKeyMapTest.vala"
		_tmp48_ = _tmp47_;
#line 328 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp48_, "K001") == 0, "ir.inventory == \"K001\"");
#line 329 "SerializableGeeDualKeyMapTest.vala"
		_tmp49_ = inventory_get_row (ir);
#line 329 "SerializableGeeDualKeyMapTest.vala"
		_tmp50_ = _tmp49_;
#line 329 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp50_ == 5, "ir.row == 5");
#line 309 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (ir);
#line 309 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (b);
#line 309 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (bs);
#line 309 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (d);
#line 3561 "SerializableGeeDualKeyMapTest.c"
	}
	goto __finally355;
	__catch355_g_error:
	{
		GError* e = NULL;
#line 309 "SerializableGeeDualKeyMapTest.vala"
		e = _inner_error0_;
#line 309 "SerializableGeeDualKeyMapTest.vala"
		_inner_error0_ = NULL;
#line 334 "SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 309 "SerializableGeeDualKeyMapTest.vala"
		_g_error_free0 (e);
#line 3575 "SerializableGeeDualKeyMapTest.c"
	}
	__finally355:
#line 309 "SerializableGeeDualKeyMapTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 309 "SerializableGeeDualKeyMapTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 309 "SerializableGeeDualKeyMapTest.vala"
		g_clear_error (&_inner_error0_);
#line 309 "SerializableGeeDualKeyMapTest.vala"
		return;
#line 3586 "SerializableGeeDualKeyMapTest.c"
	}
}

static void
___lambda303__gtest_func (void)
{
#line 307 "SerializableGeeDualKeyMapTest.vala"
	__lambda303_ ();
#line 3595 "SerializableGeeDualKeyMapTest.c"
}

static void
__lambda304_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		SerializableGeeDualKeyMapTestBigBag* bag = NULL;
		SerializableGeeDualKeyMapTestBigBag* _tmp0_;
		SerializableGeeDualKeyMapTestBigBag* _tmp1_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp2_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp3_;
		SerializableGeeDualKeyMapTestBigBag* _tmp54_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp55_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp56_;
		gint _tmp57_;
		gint _tmp58_;
		GXmlGDocument* d = NULL;
		GXmlGDocument* _tmp59_;
		SerializableGeeDualKeyMapTestBigBag* _tmp60_;
		GXmlGDocument* _tmp61_;
		GXmlNode* _tmp62_;
		GXmlNode* _tmp63_;
		GXmlGDocument* _tmp64_;
		GXmlNode* _tmp65_;
		GXmlNode* _tmp66_;
		GXmlNode* _tmp67_;
		GXmlGDocument* _tmp68_;
		GXmlNode* _tmp69_;
		GXmlNode* _tmp70_;
		GXmlNode* _tmp71_;
		gchar* _tmp72_;
		gchar* _tmp73_;
		gchar* _tmp74_;
		GXmlGDocument* _tmp75_;
		GXmlNode* _tmp76_;
		GXmlNode* _tmp77_;
		GXmlNode* _tmp78_;
		GeeBidirList* _tmp79_;
		GeeBidirList* _tmp80_;
		GeeBidirList* _tmp81_;
		gint _tmp82_;
		gint _tmp83_;
		GXmlGDocument* _tmp84_;
		GXmlNode* _tmp85_;
		GXmlNode* _tmp86_;
		GXmlNode* _tmp87_;
		GeeBidirList* _tmp88_;
		GeeBidirList* _tmp89_;
		GeeBidirList* _tmp90_;
		gpointer _tmp91_;
		GXmlNode* _tmp92_;
		gchar* _tmp93_;
		gchar* _tmp94_;
		gchar* _tmp95_;
		GXmlGDocument* _tmp96_;
		GXmlNode* _tmp97_;
		GXmlNode* _tmp98_;
		GXmlNode* _tmp99_;
		GeeBidirList* _tmp100_;
		GeeBidirList* _tmp101_;
		GeeBidirList* _tmp102_;
		gpointer _tmp103_;
		GXmlNode* _tmp104_;
		GeeBidirList* _tmp105_;
		GeeBidirList* _tmp106_;
		GeeBidirList* _tmp107_;
		gint _tmp108_;
		gint _tmp109_;
		GXmlGDocument* _tmp110_;
		GXmlNode* _tmp111_;
		GXmlNode* _tmp112_;
		GXmlNode* _tmp113_;
		GeeBidirList* _tmp114_;
		GeeBidirList* _tmp115_;
		GeeBidirList* _tmp116_;
		gpointer _tmp117_;
		GXmlNode* _tmp118_;
		GeeBidirList* _tmp119_;
		GeeBidirList* _tmp120_;
		GeeBidirList* _tmp121_;
		gpointer _tmp122_;
		GXmlNode* _tmp123_;
		gchar* _tmp124_;
		gchar* _tmp125_;
		gchar* _tmp126_;
		GXmlGDocument* _tmp127_;
		GXmlNode* _tmp128_;
		GXmlNode* _tmp129_;
		GXmlNode* _tmp130_;
		GeeBidirList* _tmp131_;
		GeeBidirList* _tmp132_;
		GeeBidirList* _tmp133_;
		gpointer _tmp134_;
		GXmlNode* _tmp135_;
		GeeBidirList* _tmp136_;
		GeeBidirList* _tmp137_;
		GeeBidirList* _tmp138_;
		gpointer _tmp139_;
		GXmlNode* _tmp140_;
		GeeBidirList* _tmp141_;
		GeeBidirList* _tmp142_;
		GeeBidirList* _tmp143_;
		gint _tmp144_;
		gint _tmp145_;
		GXmlGDocument* _tmp146_;
		GXmlNode* _tmp147_;
		GXmlNode* _tmp148_;
		GXmlNode* _tmp149_;
		GeeBidirList* _tmp150_;
		GeeBidirList* _tmp151_;
		GeeBidirList* _tmp152_;
		gpointer _tmp153_;
		GXmlNode* _tmp154_;
		GeeBidirList* _tmp155_;
		GeeBidirList* _tmp156_;
		GeeBidirList* _tmp157_;
		gpointer _tmp158_;
		GXmlNode* _tmp159_;
		GeeBidirList* _tmp160_;
		GeeBidirList* _tmp161_;
		GeeBidirList* _tmp162_;
		gpointer _tmp163_;
		GXmlNode* _tmp164_;
		gchar* _tmp165_;
		gchar* _tmp166_;
		gchar* _tmp167_;
		GXmlGDocument* _tmp168_;
		GXmlNode* _tmp169_;
		GXmlNode* _tmp170_;
		GXmlNode* _tmp171_;
		GeeBidirList* _tmp172_;
		GeeBidirList* _tmp173_;
		GeeBidirList* _tmp174_;
		gpointer _tmp175_;
		GXmlNode* _tmp176_;
		GeeBidirList* _tmp177_;
		GeeBidirList* _tmp178_;
		GeeBidirList* _tmp179_;
		gpointer _tmp180_;
		GXmlNode* _tmp181_;
		GeeBidirList* _tmp182_;
		GeeBidirList* _tmp183_;
		GeeBidirList* _tmp184_;
		gpointer _tmp185_;
		GXmlNode* _tmp186_;
		GeeBidirList* _tmp187_;
		GeeBidirList* _tmp188_;
		GeeBidirList* _tmp189_;
		gint _tmp190_;
		gint _tmp191_;
		GXmlGDocument* _tmp192_;
		GXmlNode* _tmp193_;
		GXmlNode* _tmp194_;
		GXmlNode* _tmp195_;
		GeeBidirList* _tmp196_;
		GeeBidirList* _tmp197_;
		GeeBidirList* _tmp198_;
		gpointer _tmp199_;
		GXmlNode* _tmp200_;
		GeeBidirList* _tmp201_;
		GeeBidirList* _tmp202_;
		GeeBidirList* _tmp203_;
		gpointer _tmp204_;
		GXmlNode* _tmp205_;
		GeeBidirList* _tmp206_;
		GeeBidirList* _tmp207_;
		GeeBidirList* _tmp208_;
		gpointer _tmp209_;
		GXmlNode* _tmp210_;
		GeeBidirList* _tmp211_;
		GeeBidirList* _tmp212_;
		GeeBidirList* _tmp213_;
		gpointer _tmp214_;
		GXmlNode* _tmp215_;
		GXmlGDocument* _tmp216_;
		GXmlNode* _tmp217_;
		GXmlNode* _tmp218_;
		GXmlNode* _tmp219_;
		GeeBidirList* _tmp220_;
		GeeBidirList* _tmp221_;
		GeeBidirList* _tmp222_;
		gpointer _tmp223_;
		GXmlNode* _tmp224_;
		GeeBidirList* _tmp225_;
		GeeBidirList* _tmp226_;
		GeeBidirList* _tmp227_;
		gpointer _tmp228_;
		GXmlNode* _tmp229_;
		GeeBidirList* _tmp230_;
		GeeBidirList* _tmp231_;
		GeeBidirList* _tmp232_;
		gpointer _tmp233_;
		GXmlNode* _tmp234_;
		GeeBidirList* _tmp235_;
		GeeBidirList* _tmp236_;
		GeeBidirList* _tmp237_;
		gpointer _tmp238_;
		GXmlNode* _tmp239_;
		gchar* _tmp240_;
		gchar* _tmp241_;
		gchar* _tmp242_;
		SerializableGeeDualKeyMapTestBigBag* bagt = NULL;
		SerializableGeeDualKeyMapTestBigBag* _tmp243_;
		SerializableGeeDualKeyMapTestBigBag* _tmp244_;
		GXmlGDocument* _tmp245_;
		SerializableGeeDualKeyMapTestBigBag* _tmp246_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp247_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp248_;
		gint _tmp249_;
		gint _tmp250_;
		gboolean _tmp251_ = FALSE;
		SerializableGeeDualKeyMapTestBigBag* _tmp252_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp253_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp254_;
		SerializableGeeDualKeyMapTestBigBag* _tmp255_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp256_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp257_;
		gint _tmp258_;
		gint _tmp259_;
		gboolean _tmp260_ = FALSE;
		SerializableGeeDualKeyMapTestBigBag* _tmp261_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp262_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp263_;
		gpointer _tmp264_;
		SerializableGeeDualKeyMapTestSmallBag* _tmp265_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp266_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp267_;
		gboolean _tmp268_;
		SerializableGeeDualKeyMapTestBigBag* _tmp269_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp270_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp271_;
		gpointer _tmp272_;
		SerializableGeeDualKeyMapTestSmallBag* _tmp273_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp274_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp275_;
		gint _tmp276_;
		gint _tmp277_;
		SerializableGeeDualKeyMapTestBigBag* _tmp278_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp279_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp280_;
		gpointer _tmp281_;
		SerializableGeeDualKeyMapTestSmallBag* _tmp282_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp283_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp284_;
		gpointer _tmp285_;
		SerializableGeeDualKeyMapTestBall* _tmp286_;
		const gchar* _tmp287_;
		const gchar* _tmp288_;
		SerializableGeeDualKeyMapTestBigBag* _tmp289_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp290_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp291_;
		gpointer _tmp292_;
		SerializableGeeDualKeyMapTestSmallBag* _tmp293_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp294_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp295_;
		gpointer _tmp296_;
		SerializableGeeDualKeyMapTestBall* _tmp297_;
		SerializableGeeDualKeyMapTestBallFill* _tmp298_;
		SerializableGeeDualKeyMapTestBallFill* _tmp299_;
		SerializableGeeDualKeyMapTestBigBag* _tmp300_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp301_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp302_;
		gpointer _tmp303_;
		SerializableGeeDualKeyMapTestSmallBag* _tmp304_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp305_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp306_;
		gpointer _tmp307_;
		SerializableGeeDualKeyMapTestBall* _tmp308_;
		SerializableGeeDualKeyMapTestBallFill* _tmp309_;
		SerializableGeeDualKeyMapTestBallFill* _tmp310_;
		gchar* _tmp311_;
		gchar* _tmp312_;
		gchar* _tmp313_;
		SerializableGeeDualKeyMapTestBigBag* _tmp314_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp315_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp316_;
		gpointer _tmp317_;
		SerializableGeeDualKeyMapTestSmallBag* _tmp318_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp319_;
		SerializableGeeDualKeyMapTestBallDualMap* _tmp320_;
		gpointer _tmp321_;
		SerializableGeeDualKeyMapTestBall* _tmp322_;
		SerializableGeeDualKeyMapTestBallFill* _tmp323_;
		SerializableGeeDualKeyMapTestBallFill* _tmp324_;
		gchar* _tmp325_;
		gchar* _tmp326_;
		gchar* _tmp327_;
		SerializableGeeDualKeyMapTestBigBag* bag3 = NULL;
		SerializableGeeDualKeyMapTestBigBag* _tmp328_;
		SerializableGeeDualKeyMapTestBigBag* _tmp329_;
		GXmlGDocument* _tmp330_;
		SerializableGeeDualKeyMapTestBigBag* _tmp331_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp332_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp333_;
		gint _tmp334_;
		gint _tmp335_;
		gboolean _tmp336_ = FALSE;
		SerializableGeeDualKeyMapTestBigBag* _tmp337_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp338_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp339_;
		SerializableGeeDualKeyMapTestBigBag* _tmp340_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp341_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp342_;
		gint _tmp343_;
		gint _tmp344_;
		SerializableGeeDualKeyMapTestBigBag* _tmp345_;
		GXmlGDocument* _tmp346_;
		SerializableGeeDualKeyMapTestBigBag* _tmp347_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp348_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp349_;
		SerializableGeeDualKeyMapTestBigBag* bag2 = NULL;
		SerializableGeeDualKeyMapTestBigBag* _tmp350_;
		SerializableGeeDualKeyMapTestBigBag* _tmp351_;
		GXmlGDocument* _tmp352_;
		SerializableGeeDualKeyMapTestBigBag* _tmp353_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp354_;
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp355_;
		GXmlGDocument* d2 = NULL;
		GXmlGDocument* _tmp356_;
		SerializableGeeDualKeyMapTestBigBag* _tmp357_;
		GXmlGDocument* _tmp358_;
		GXmlNode* _tmp359_;
		GXmlNode* _tmp360_;
		GXmlGDocument* _tmp361_;
		GXmlNode* _tmp362_;
		GXmlNode* _tmp363_;
		GXmlNode* _tmp364_;
		GXmlGDocument* _tmp365_;
		GXmlNode* _tmp366_;
		GXmlNode* _tmp367_;
		GXmlNode* _tmp368_;
		gchar* _tmp369_;
		gchar* _tmp370_;
		gchar* _tmp371_;
		GXmlGDocument* _tmp372_;
		GXmlNode* _tmp373_;
		GXmlNode* _tmp374_;
		GXmlNode* _tmp375_;
		GeeBidirList* _tmp376_;
		GeeBidirList* _tmp377_;
		GeeBidirList* _tmp378_;
		gint _tmp379_;
		gint _tmp380_;
		GXmlGDocument* _tmp381_;
		GXmlNode* _tmp382_;
		GXmlNode* _tmp383_;
		GXmlNode* _tmp384_;
		GeeBidirList* _tmp385_;
		GeeBidirList* _tmp386_;
		GeeBidirList* _tmp387_;
		gpointer _tmp388_;
		GXmlNode* _tmp389_;
		gchar* _tmp390_;
		gchar* _tmp391_;
		gchar* _tmp392_;
		GXmlGDocument* _tmp393_;
		GXmlNode* _tmp394_;
		GXmlNode* _tmp395_;
		GXmlNode* _tmp396_;
		GeeBidirList* _tmp397_;
		GeeBidirList* _tmp398_;
		GeeBidirList* _tmp399_;
		gpointer _tmp400_;
		GXmlNode* _tmp401_;
		GeeBidirList* _tmp402_;
		GeeBidirList* _tmp403_;
		GeeBidirList* _tmp404_;
		gint _tmp405_;
		gint _tmp406_;
		GXmlGDocument* _tmp407_;
		GXmlNode* _tmp408_;
		GXmlNode* _tmp409_;
		GXmlNode* _tmp410_;
		GeeBidirList* _tmp411_;
		GeeBidirList* _tmp412_;
		GeeBidirList* _tmp413_;
		gpointer _tmp414_;
		GXmlNode* _tmp415_;
		GeeBidirList* _tmp416_;
		GeeBidirList* _tmp417_;
		GeeBidirList* _tmp418_;
		gpointer _tmp419_;
		GXmlNode* _tmp420_;
		gchar* _tmp421_;
		gchar* _tmp422_;
		gchar* _tmp423_;
		GXmlGDocument* _tmp424_;
		GXmlNode* _tmp425_;
		GXmlNode* _tmp426_;
		GXmlNode* _tmp427_;
		GeeBidirList* _tmp428_;
		GeeBidirList* _tmp429_;
		GeeBidirList* _tmp430_;
		gpointer _tmp431_;
		GXmlNode* _tmp432_;
		GeeBidirList* _tmp433_;
		GeeBidirList* _tmp434_;
		GeeBidirList* _tmp435_;
		gpointer _tmp436_;
		GXmlNode* _tmp437_;
		GeeBidirList* _tmp438_;
		GeeBidirList* _tmp439_;
		GeeBidirList* _tmp440_;
		gint _tmp441_;
		gint _tmp442_;
		GXmlGDocument* _tmp443_;
		GXmlNode* _tmp444_;
		GXmlNode* _tmp445_;
		GXmlNode* _tmp446_;
		GeeBidirList* _tmp447_;
		GeeBidirList* _tmp448_;
		GeeBidirList* _tmp449_;
		gpointer _tmp450_;
		GXmlNode* _tmp451_;
		GeeBidirList* _tmp452_;
		GeeBidirList* _tmp453_;
		GeeBidirList* _tmp454_;
		gpointer _tmp455_;
		GXmlNode* _tmp456_;
		GeeBidirList* _tmp457_;
		GeeBidirList* _tmp458_;
		GeeBidirList* _tmp459_;
		gpointer _tmp460_;
		GXmlNode* _tmp461_;
		gchar* _tmp462_;
		gchar* _tmp463_;
		gchar* _tmp464_;
		GXmlGDocument* _tmp465_;
		GXmlNode* _tmp466_;
		GXmlNode* _tmp467_;
		GXmlNode* _tmp468_;
		GeeBidirList* _tmp469_;
		GeeBidirList* _tmp470_;
		GeeBidirList* _tmp471_;
		gpointer _tmp472_;
		GXmlNode* _tmp473_;
		GeeBidirList* _tmp474_;
		GeeBidirList* _tmp475_;
		GeeBidirList* _tmp476_;
		gpointer _tmp477_;
		GXmlNode* _tmp478_;
		GeeBidirList* _tmp479_;
		GeeBidirList* _tmp480_;
		GeeBidirList* _tmp481_;
		gpointer _tmp482_;
		GXmlNode* _tmp483_;
		GeeBidirList* _tmp484_;
		GeeBidirList* _tmp485_;
		GeeBidirList* _tmp486_;
		gint _tmp487_;
		gint _tmp488_;
		GXmlGDocument* _tmp489_;
		GXmlNode* _tmp490_;
		GXmlNode* _tmp491_;
		GXmlNode* _tmp492_;
		GeeBidirList* _tmp493_;
		GeeBidirList* _tmp494_;
		GeeBidirList* _tmp495_;
		gpointer _tmp496_;
		GXmlNode* _tmp497_;
		GeeBidirList* _tmp498_;
		GeeBidirList* _tmp499_;
		GeeBidirList* _tmp500_;
		gpointer _tmp501_;
		GXmlNode* _tmp502_;
		GeeBidirList* _tmp503_;
		GeeBidirList* _tmp504_;
		GeeBidirList* _tmp505_;
		gpointer _tmp506_;
		GXmlNode* _tmp507_;
		GeeBidirList* _tmp508_;
		GeeBidirList* _tmp509_;
		GeeBidirList* _tmp510_;
		gpointer _tmp511_;
		GXmlNode* _tmp512_;
		GXmlGDocument* _tmp513_;
		GXmlNode* _tmp514_;
		GXmlNode* _tmp515_;
		GXmlNode* _tmp516_;
		GeeBidirList* _tmp517_;
		GeeBidirList* _tmp518_;
		GeeBidirList* _tmp519_;
		gpointer _tmp520_;
		GXmlNode* _tmp521_;
		GeeBidirList* _tmp522_;
		GeeBidirList* _tmp523_;
		GeeBidirList* _tmp524_;
		gpointer _tmp525_;
		GXmlNode* _tmp526_;
		GeeBidirList* _tmp527_;
		GeeBidirList* _tmp528_;
		GeeBidirList* _tmp529_;
		gpointer _tmp530_;
		GXmlNode* _tmp531_;
		GeeBidirList* _tmp532_;
		GeeBidirList* _tmp533_;
		GeeBidirList* _tmp534_;
		gpointer _tmp535_;
		GXmlNode* _tmp536_;
		gchar* _tmp537_;
		gchar* _tmp538_;
		gchar* _tmp539_;
#line 341 "SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = serializable_gee_dual_key_map_test_big_bag_new ();
#line 341 "SerializableGeeDualKeyMapTest.vala"
		bag = _tmp0_;
#line 342 "SerializableGeeDualKeyMapTest.vala"
		_tmp1_ = bag;
#line 342 "SerializableGeeDualKeyMapTest.vala"
		_tmp2_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp1_);
#line 342 "SerializableGeeDualKeyMapTest.vala"
		_tmp3_ = _tmp2_;
#line 342 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp3_ != NULL, "bag.bags != null");
#line 4111 "SerializableGeeDualKeyMapTest.c"
		{
			gint i = 0;
#line 343 "SerializableGeeDualKeyMapTest.vala"
			i = 0;
#line 4116 "SerializableGeeDualKeyMapTest.c"
			{
				gboolean _tmp4_ = FALSE;
#line 343 "SerializableGeeDualKeyMapTest.vala"
				_tmp4_ = TRUE;
#line 343 "SerializableGeeDualKeyMapTest.vala"
				while (TRUE) {
#line 4123 "SerializableGeeDualKeyMapTest.c"
					SerializableGeeDualKeyMapTestSmallBag* sbag = NULL;
					SerializableGeeDualKeyMapTestSmallBag* _tmp6_;
					SerializableGeeDualKeyMapTestSmallBag* _tmp7_;
					gchar* _tmp8_;
					gchar* _tmp9_;
					gchar* _tmp10_;
					gchar* _tmp11_;
					SerializableGeeDualKeyMapTestSmallBag* _tmp12_;
					SerializableGeeDualKeyMapTestBallDualMap* _tmp13_;
					SerializableGeeDualKeyMapTestBallDualMap* _tmp14_;
					SerializableGeeDualKeyMapTestSmallBag* _tmp39_;
					SerializableGeeDualKeyMapTestBallDualMap* _tmp40_;
					SerializableGeeDualKeyMapTestBallDualMap* _tmp41_;
					gint _tmp42_;
					gint _tmp43_;
					SerializableGeeDualKeyMapTestBigBag* _tmp44_;
					SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp45_;
					SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp46_;
					SerializableGeeDualKeyMapTestSmallBag* _tmp47_;
					const gchar* _tmp48_;
					const gchar* _tmp49_;
					SerializableGeeDualKeyMapTestSmallBag* _tmp50_;
					const gchar* _tmp51_;
					const gchar* _tmp52_;
					SerializableGeeDualKeyMapTestSmallBag* _tmp53_;
#line 343 "SerializableGeeDualKeyMapTest.vala"
					if (!_tmp4_) {
#line 4151 "SerializableGeeDualKeyMapTest.c"
						gint _tmp5_;
#line 343 "SerializableGeeDualKeyMapTest.vala"
						_tmp5_ = i;
#line 343 "SerializableGeeDualKeyMapTest.vala"
						i = _tmp5_ + 1;
#line 4157 "SerializableGeeDualKeyMapTest.c"
					}
#line 343 "SerializableGeeDualKeyMapTest.vala"
					_tmp4_ = FALSE;
#line 343 "SerializableGeeDualKeyMapTest.vala"
					if (!(i < 2)) {
#line 343 "SerializableGeeDualKeyMapTest.vala"
						break;
#line 4165 "SerializableGeeDualKeyMapTest.c"
					}
#line 344 "SerializableGeeDualKeyMapTest.vala"
					_tmp6_ = serializable_gee_dual_key_map_test_small_bag_new ();
#line 344 "SerializableGeeDualKeyMapTest.vala"
					sbag = _tmp6_;
#line 345 "SerializableGeeDualKeyMapTest.vala"
					_tmp7_ = sbag;
#line 345 "SerializableGeeDualKeyMapTest.vala"
					_tmp8_ = g_strdup_printf ("%i", i);
#line 345 "SerializableGeeDualKeyMapTest.vala"
					_tmp9_ = _tmp8_;
#line 345 "SerializableGeeDualKeyMapTest.vala"
					_tmp10_ = g_strconcat ("SmallBag", _tmp9_, NULL);
#line 345 "SerializableGeeDualKeyMapTest.vala"
					_tmp11_ = _tmp10_;
#line 345 "SerializableGeeDualKeyMapTest.vala"
					serializable_gee_dual_key_map_test_small_bag_set_name (_tmp7_, _tmp11_);
#line 345 "SerializableGeeDualKeyMapTest.vala"
					_g_free0 (_tmp11_);
#line 345 "SerializableGeeDualKeyMapTest.vala"
					_g_free0 (_tmp9_);
#line 346 "SerializableGeeDualKeyMapTest.vala"
					_tmp12_ = sbag;
#line 346 "SerializableGeeDualKeyMapTest.vala"
					_tmp13_ = serializable_gee_dual_key_map_test_small_bag_get_balls (_tmp12_);
#line 346 "SerializableGeeDualKeyMapTest.vala"
					_tmp14_ = _tmp13_;
#line 346 "SerializableGeeDualKeyMapTest.vala"
					_vala_assert (_tmp14_ != NULL, "sbag.balls != null");
#line 4195 "SerializableGeeDualKeyMapTest.c"
					{
						gint j = 0;
#line 347 "SerializableGeeDualKeyMapTest.vala"
						j = 0;
#line 4200 "SerializableGeeDualKeyMapTest.c"
						{
							gboolean _tmp15_ = FALSE;
#line 347 "SerializableGeeDualKeyMapTest.vala"
							_tmp15_ = TRUE;
#line 347 "SerializableGeeDualKeyMapTest.vala"
							while (TRUE) {
#line 4207 "SerializableGeeDualKeyMapTest.c"
								SerializableGeeDualKeyMapTestBall* b = NULL;
								SerializableGeeDualKeyMapTestBall* _tmp17_;
								SerializableGeeDualKeyMapTestBall* _tmp18_;
								gchar* _tmp19_;
								gchar* _tmp20_;
								gchar* _tmp21_;
								gchar* _tmp22_;
								SerializableGeeDualKeyMapTestBall* _tmp23_;
								SerializableGeeDualKeyMapTestBallFill* _tmp24_;
								SerializableGeeDualKeyMapTestBallFill* _tmp25_;
								SerializableGeeDualKeyMapTestBall* _tmp26_;
								SerializableGeeDualKeyMapTestBallFill* _tmp27_;
								SerializableGeeDualKeyMapTestBallFill* _tmp28_;
								SerializableGeeDualKeyMapTestSmallBag* _tmp29_;
								SerializableGeeDualKeyMapTestBallDualMap* _tmp30_;
								SerializableGeeDualKeyMapTestBallDualMap* _tmp31_;
								SerializableGeeDualKeyMapTestBall* _tmp32_;
								const gchar* _tmp33_;
								const gchar* _tmp34_;
								SerializableGeeDualKeyMapTestBall* _tmp35_;
								const gchar* _tmp36_;
								const gchar* _tmp37_;
								SerializableGeeDualKeyMapTestBall* _tmp38_;
#line 347 "SerializableGeeDualKeyMapTest.vala"
								if (!_tmp15_) {
#line 4233 "SerializableGeeDualKeyMapTest.c"
									gint _tmp16_;
#line 347 "SerializableGeeDualKeyMapTest.vala"
									_tmp16_ = j;
#line 347 "SerializableGeeDualKeyMapTest.vala"
									j = _tmp16_ + 1;
#line 4239 "SerializableGeeDualKeyMapTest.c"
								}
#line 347 "SerializableGeeDualKeyMapTest.vala"
								_tmp15_ = FALSE;
#line 347 "SerializableGeeDualKeyMapTest.vala"
								if (!(j < 2)) {
#line 347 "SerializableGeeDualKeyMapTest.vala"
									break;
#line 4247 "SerializableGeeDualKeyMapTest.c"
								}
#line 348 "SerializableGeeDualKeyMapTest.vala"
								_tmp17_ = serializable_gee_dual_key_map_test_ball_new ();
#line 348 "SerializableGeeDualKeyMapTest.vala"
								b = _tmp17_;
#line 349 "SerializableGeeDualKeyMapTest.vala"
								_tmp18_ = b;
#line 349 "SerializableGeeDualKeyMapTest.vala"
								_tmp19_ = g_strdup_printf ("%i", j);
#line 349 "SerializableGeeDualKeyMapTest.vala"
								_tmp20_ = _tmp19_;
#line 349 "SerializableGeeDualKeyMapTest.vala"
								_tmp21_ = g_strconcat ("Ball", _tmp20_, NULL);
#line 349 "SerializableGeeDualKeyMapTest.vala"
								_tmp22_ = _tmp21_;
#line 349 "SerializableGeeDualKeyMapTest.vala"
								serializable_gee_dual_key_map_test_ball_set_name (_tmp18_, _tmp22_);
#line 349 "SerializableGeeDualKeyMapTest.vala"
								_g_free0 (_tmp22_);
#line 349 "SerializableGeeDualKeyMapTest.vala"
								_g_free0 (_tmp20_);
#line 350 "SerializableGeeDualKeyMapTest.vala"
								_tmp23_ = b;
#line 350 "SerializableGeeDualKeyMapTest.vala"
								_tmp24_ = serializable_gee_dual_key_map_test_ball_fill_new ();
#line 350 "SerializableGeeDualKeyMapTest.vala"
								_tmp25_ = _tmp24_;
#line 350 "SerializableGeeDualKeyMapTest.vala"
								serializable_gee_dual_key_map_test_ball_set_ballfill (_tmp23_, _tmp25_);
#line 350 "SerializableGeeDualKeyMapTest.vala"
								_g_object_unref0 (_tmp25_);
#line 351 "SerializableGeeDualKeyMapTest.vala"
								_tmp26_ = b;
#line 351 "SerializableGeeDualKeyMapTest.vala"
								_tmp27_ = serializable_gee_dual_key_map_test_ball_get_ballfill (_tmp26_);
#line 351 "SerializableGeeDualKeyMapTest.vala"
								_tmp28_ = _tmp27_;
#line 351 "SerializableGeeDualKeyMapTest.vala"
								serializable_gee_dual_key_map_test_ball_fill_set_text (_tmp28_, "golden dust");
#line 352 "SerializableGeeDualKeyMapTest.vala"
								_tmp29_ = sbag;
#line 352 "SerializableGeeDualKeyMapTest.vala"
								_tmp30_ = serializable_gee_dual_key_map_test_small_bag_get_balls (_tmp29_);
#line 352 "SerializableGeeDualKeyMapTest.vala"
								_tmp31_ = _tmp30_;
#line 352 "SerializableGeeDualKeyMapTest.vala"
								_tmp32_ = b;
#line 352 "SerializableGeeDualKeyMapTest.vala"
								_tmp33_ = serializable_gee_dual_key_map_test_ball_get_size (_tmp32_);
#line 352 "SerializableGeeDualKeyMapTest.vala"
								_tmp34_ = _tmp33_;
#line 352 "SerializableGeeDualKeyMapTest.vala"
								_tmp35_ = b;
#line 352 "SerializableGeeDualKeyMapTest.vala"
								_tmp36_ = serializable_gee_dual_key_map_test_ball_get_name (_tmp35_);
#line 352 "SerializableGeeDualKeyMapTest.vala"
								_tmp37_ = _tmp36_;
#line 352 "SerializableGeeDualKeyMapTest.vala"
								_tmp38_ = b;
#line 352 "SerializableGeeDualKeyMapTest.vala"
								gxml_serializable_dual_key_map_set ((GXmlSerializableDualKeyMap*) _tmp31_, _tmp34_, _tmp37_, _tmp38_);
#line 347 "SerializableGeeDualKeyMapTest.vala"
								_g_object_unref0 (b);
#line 4311 "SerializableGeeDualKeyMapTest.c"
							}
						}
					}
#line 354 "SerializableGeeDualKeyMapTest.vala"
					_tmp39_ = sbag;
#line 354 "SerializableGeeDualKeyMapTest.vala"
					_tmp40_ = serializable_gee_dual_key_map_test_small_bag_get_balls (_tmp39_);
#line 354 "SerializableGeeDualKeyMapTest.vala"
					_tmp41_ = _tmp40_;
#line 354 "SerializableGeeDualKeyMapTest.vala"
					_tmp42_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp41_);
#line 354 "SerializableGeeDualKeyMapTest.vala"
					_tmp43_ = _tmp42_;
#line 354 "SerializableGeeDualKeyMapTest.vala"
					_vala_assert (_tmp43_ == 2, "sbag.balls.size == 2");
#line 355 "SerializableGeeDualKeyMapTest.vala"
					_tmp44_ = bag;
#line 355 "SerializableGeeDualKeyMapTest.vala"
					_tmp45_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp44_);
#line 355 "SerializableGeeDualKeyMapTest.vala"
					_tmp46_ = _tmp45_;
#line 355 "SerializableGeeDualKeyMapTest.vala"
					_tmp47_ = sbag;
#line 355 "SerializableGeeDualKeyMapTest.vala"
					_tmp48_ = serializable_gee_dual_key_map_test_small_bag_get_cash (_tmp47_);
#line 355 "SerializableGeeDualKeyMapTest.vala"
					_tmp49_ = _tmp48_;
#line 355 "SerializableGeeDualKeyMapTest.vala"
					_tmp50_ = sbag;
#line 355 "SerializableGeeDualKeyMapTest.vala"
					_tmp51_ = serializable_gee_dual_key_map_test_small_bag_get_name (_tmp50_);
#line 355 "SerializableGeeDualKeyMapTest.vala"
					_tmp52_ = _tmp51_;
#line 355 "SerializableGeeDualKeyMapTest.vala"
					_tmp53_ = sbag;
#line 355 "SerializableGeeDualKeyMapTest.vala"
					gxml_serializable_dual_key_map_set ((GXmlSerializableDualKeyMap*) _tmp46_, _tmp49_, _tmp52_, _tmp53_);
#line 343 "SerializableGeeDualKeyMapTest.vala"
					_g_object_unref0 (sbag);
#line 4351 "SerializableGeeDualKeyMapTest.c"
				}
			}
		}
#line 357 "SerializableGeeDualKeyMapTest.vala"
		_tmp54_ = bag;
#line 357 "SerializableGeeDualKeyMapTest.vala"
		_tmp55_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp54_);
#line 357 "SerializableGeeDualKeyMapTest.vala"
		_tmp56_ = _tmp55_;
#line 357 "SerializableGeeDualKeyMapTest.vala"
		_tmp57_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp56_);
#line 357 "SerializableGeeDualKeyMapTest.vala"
		_tmp58_ = _tmp57_;
#line 357 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp58_ == 2, "bag.bags.size == 2");
#line 359 "SerializableGeeDualKeyMapTest.vala"
		_tmp59_ = gxml_gdocument_new ();
#line 359 "SerializableGeeDualKeyMapTest.vala"
		d = _tmp59_;
#line 360 "SerializableGeeDualKeyMapTest.vala"
		_tmp60_ = bag;
#line 360 "SerializableGeeDualKeyMapTest.vala"
		_tmp61_ = d;
#line 360 "SerializableGeeDualKeyMapTest.vala"
		_tmp62_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp60_, (GXmlNode*) _tmp61_, &_inner_error0_);
#line 360 "SerializableGeeDualKeyMapTest.vala"
		_tmp63_ = _tmp62_;
#line 360 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp63_);
#line 360 "SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 360 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (d);
#line 360 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag);
#line 4387 "SerializableGeeDualKeyMapTest.c"
			goto __catch356_g_error;
		}
#line 361 "SerializableGeeDualKeyMapTest.vala"
		_tmp64_ = d;
#line 361 "SerializableGeeDualKeyMapTest.vala"
		_tmp65_ = gxml_document_get_root ((GXmlDocument*) _tmp64_);
#line 361 "SerializableGeeDualKeyMapTest.vala"
		_tmp66_ = _tmp65_;
#line 361 "SerializableGeeDualKeyMapTest.vala"
		_tmp67_ = _tmp66_;
#line 361 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp67_ != NULL, "d.root != null");
#line 361 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp67_);
#line 362 "SerializableGeeDualKeyMapTest.vala"
		_tmp68_ = d;
#line 362 "SerializableGeeDualKeyMapTest.vala"
		_tmp69_ = gxml_document_get_root ((GXmlDocument*) _tmp68_);
#line 362 "SerializableGeeDualKeyMapTest.vala"
		_tmp70_ = _tmp69_;
#line 362 "SerializableGeeDualKeyMapTest.vala"
		_tmp71_ = _tmp70_;
#line 362 "SerializableGeeDualKeyMapTest.vala"
		_tmp72_ = gxml_node_get_name (_tmp71_);
#line 362 "SerializableGeeDualKeyMapTest.vala"
		_tmp73_ = _tmp72_;
#line 362 "SerializableGeeDualKeyMapTest.vala"
		_tmp74_ = _tmp73_;
#line 362 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp74_, "BigBag") == 0, "d.root.name == \"BigBag\"");
#line 362 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp74_);
#line 362 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp71_);
#line 363 "SerializableGeeDualKeyMapTest.vala"
		_tmp75_ = d;
#line 363 "SerializableGeeDualKeyMapTest.vala"
		_tmp76_ = gxml_document_get_root ((GXmlDocument*) _tmp75_);
#line 363 "SerializableGeeDualKeyMapTest.vala"
		_tmp77_ = _tmp76_;
#line 363 "SerializableGeeDualKeyMapTest.vala"
		_tmp78_ = _tmp77_;
#line 363 "SerializableGeeDualKeyMapTest.vala"
		_tmp79_ = gxml_node_get_children_nodes (_tmp78_);
#line 363 "SerializableGeeDualKeyMapTest.vala"
		_tmp80_ = _tmp79_;
#line 363 "SerializableGeeDualKeyMapTest.vala"
		_tmp81_ = _tmp80_;
#line 363 "SerializableGeeDualKeyMapTest.vala"
		_tmp82_ = gee_collection_get_size ((GeeCollection*) _tmp81_);
#line 363 "SerializableGeeDualKeyMapTest.vala"
		_tmp83_ = _tmp82_;
#line 363 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp83_ == 2, "d.root.children_nodes.size == 2");
#line 363 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp81_);
#line 363 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp78_);
#line 364 "SerializableGeeDualKeyMapTest.vala"
		_tmp84_ = d;
#line 364 "SerializableGeeDualKeyMapTest.vala"
		_tmp85_ = gxml_document_get_root ((GXmlDocument*) _tmp84_);
#line 364 "SerializableGeeDualKeyMapTest.vala"
		_tmp86_ = _tmp85_;
#line 364 "SerializableGeeDualKeyMapTest.vala"
		_tmp87_ = _tmp86_;
#line 364 "SerializableGeeDualKeyMapTest.vala"
		_tmp88_ = gxml_node_get_children_nodes (_tmp87_);
#line 364 "SerializableGeeDualKeyMapTest.vala"
		_tmp89_ = _tmp88_;
#line 364 "SerializableGeeDualKeyMapTest.vala"
		_tmp90_ = _tmp89_;
#line 364 "SerializableGeeDualKeyMapTest.vala"
		_tmp91_ = gee_list_get ((GeeList*) _tmp90_, 0);
#line 364 "SerializableGeeDualKeyMapTest.vala"
		_tmp92_ = (GXmlNode*) _tmp91_;
#line 364 "SerializableGeeDualKeyMapTest.vala"
		_tmp93_ = gxml_node_get_name (_tmp92_);
#line 364 "SerializableGeeDualKeyMapTest.vala"
		_tmp94_ = _tmp93_;
#line 364 "SerializableGeeDualKeyMapTest.vala"
		_tmp95_ = _tmp94_;
#line 364 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp95_, "SmallBag") == 0, "d.root.children_nodes[0].name == \"SmallBag\"");
#line 364 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp95_);
#line 364 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp92_);
#line 364 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp90_);
#line 364 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp87_);
#line 365 "SerializableGeeDualKeyMapTest.vala"
		_tmp96_ = d;
#line 365 "SerializableGeeDualKeyMapTest.vala"
		_tmp97_ = gxml_document_get_root ((GXmlDocument*) _tmp96_);
#line 365 "SerializableGeeDualKeyMapTest.vala"
		_tmp98_ = _tmp97_;
#line 365 "SerializableGeeDualKeyMapTest.vala"
		_tmp99_ = _tmp98_;
#line 365 "SerializableGeeDualKeyMapTest.vala"
		_tmp100_ = gxml_node_get_children_nodes (_tmp99_);
#line 365 "SerializableGeeDualKeyMapTest.vala"
		_tmp101_ = _tmp100_;
#line 365 "SerializableGeeDualKeyMapTest.vala"
		_tmp102_ = _tmp101_;
#line 365 "SerializableGeeDualKeyMapTest.vala"
		_tmp103_ = gee_list_get ((GeeList*) _tmp102_, 0);
#line 365 "SerializableGeeDualKeyMapTest.vala"
		_tmp104_ = (GXmlNode*) _tmp103_;
#line 365 "SerializableGeeDualKeyMapTest.vala"
		_tmp105_ = gxml_node_get_children_nodes (_tmp104_);
#line 365 "SerializableGeeDualKeyMapTest.vala"
		_tmp106_ = _tmp105_;
#line 365 "SerializableGeeDualKeyMapTest.vala"
		_tmp107_ = _tmp106_;
#line 365 "SerializableGeeDualKeyMapTest.vala"
		_tmp108_ = gee_collection_get_size ((GeeCollection*) _tmp107_);
#line 365 "SerializableGeeDualKeyMapTest.vala"
		_tmp109_ = _tmp108_;
#line 365 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp109_ == 2, "d.root.children_nodes[0].children_nodes.size == 2");
#line 365 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp107_);
#line 365 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp104_);
#line 365 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp102_);
#line 365 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp99_);
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_tmp110_ = d;
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_tmp111_ = gxml_document_get_root ((GXmlDocument*) _tmp110_);
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_tmp112_ = _tmp111_;
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_tmp113_ = _tmp112_;
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_tmp114_ = gxml_node_get_children_nodes (_tmp113_);
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_tmp115_ = _tmp114_;
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_tmp116_ = _tmp115_;
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_tmp117_ = gee_list_get ((GeeList*) _tmp116_, 0);
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_tmp118_ = (GXmlNode*) _tmp117_;
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_tmp119_ = gxml_node_get_children_nodes (_tmp118_);
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_tmp120_ = _tmp119_;
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_tmp121_ = _tmp120_;
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_tmp122_ = gee_list_get ((GeeList*) _tmp121_, 0);
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_tmp123_ = (GXmlNode*) _tmp122_;
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_tmp124_ = gxml_node_get_name (_tmp123_);
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_tmp125_ = _tmp124_;
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_tmp126_ = _tmp125_;
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp126_, "Ball") == 0, "d.root.children_nodes[0].children_nodes[0].name == \"Ball\"");
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp126_);
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp123_);
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp121_);
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp118_);
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp116_);
#line 366 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp113_);
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_tmp127_ = d;
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_tmp128_ = gxml_document_get_root ((GXmlDocument*) _tmp127_);
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_tmp129_ = _tmp128_;
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_tmp130_ = _tmp129_;
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_tmp131_ = gxml_node_get_children_nodes (_tmp130_);
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_tmp132_ = _tmp131_;
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_tmp133_ = _tmp132_;
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_tmp134_ = gee_list_get ((GeeList*) _tmp133_, 0);
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_tmp135_ = (GXmlNode*) _tmp134_;
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_tmp136_ = gxml_node_get_children_nodes (_tmp135_);
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_tmp137_ = _tmp136_;
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_tmp138_ = _tmp137_;
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_tmp139_ = gee_list_get ((GeeList*) _tmp138_, 0);
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_tmp140_ = (GXmlNode*) _tmp139_;
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_tmp141_ = gxml_node_get_children_nodes (_tmp140_);
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_tmp142_ = _tmp141_;
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_tmp143_ = _tmp142_;
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_tmp144_ = gee_collection_get_size ((GeeCollection*) _tmp143_);
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_tmp145_ = _tmp144_;
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp145_ == 1, "d.root.children_nodes[0].children_nodes[0].children_nodes.size == 1");
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp143_);
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp140_);
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp138_);
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp135_);
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp133_);
#line 367 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp130_);
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_tmp146_ = d;
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_tmp147_ = gxml_document_get_root ((GXmlDocument*) _tmp146_);
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_tmp148_ = _tmp147_;
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_tmp149_ = _tmp148_;
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_tmp150_ = gxml_node_get_children_nodes (_tmp149_);
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_tmp151_ = _tmp150_;
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_tmp152_ = _tmp151_;
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_tmp153_ = gee_list_get ((GeeList*) _tmp152_, 0);
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_tmp154_ = (GXmlNode*) _tmp153_;
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_tmp155_ = gxml_node_get_children_nodes (_tmp154_);
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_tmp156_ = _tmp155_;
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_tmp157_ = _tmp156_;
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_tmp158_ = gee_list_get ((GeeList*) _tmp157_, 0);
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_tmp159_ = (GXmlNode*) _tmp158_;
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_tmp160_ = gxml_node_get_children_nodes (_tmp159_);
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_tmp161_ = _tmp160_;
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_tmp162_ = _tmp161_;
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_tmp163_ = gee_list_get ((GeeList*) _tmp162_, 0);
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_tmp164_ = (GXmlNode*) _tmp163_;
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_tmp165_ = gxml_node_get_name (_tmp164_);
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_tmp166_ = _tmp165_;
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_tmp167_ = _tmp166_;
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp167_, "BallFill") == 0, "d.root.children_nodes[0].children_nodes[0].children_nodes[0].name == \"BallFill\"");
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp167_);
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp164_);
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp162_);
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp159_);
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp157_);
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp154_);
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp152_);
#line 368 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp149_);
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp168_ = d;
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp169_ = gxml_document_get_root ((GXmlDocument*) _tmp168_);
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp170_ = _tmp169_;
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp171_ = _tmp170_;
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp172_ = gxml_node_get_children_nodes (_tmp171_);
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp173_ = _tmp172_;
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp174_ = _tmp173_;
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp175_ = gee_list_get ((GeeList*) _tmp174_, 0);
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp176_ = (GXmlNode*) _tmp175_;
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp177_ = gxml_node_get_children_nodes (_tmp176_);
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp178_ = _tmp177_;
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp179_ = _tmp178_;
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp180_ = gee_list_get ((GeeList*) _tmp179_, 0);
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp181_ = (GXmlNode*) _tmp180_;
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp182_ = gxml_node_get_children_nodes (_tmp181_);
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp183_ = _tmp182_;
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp184_ = _tmp183_;
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp185_ = gee_list_get ((GeeList*) _tmp184_, 0);
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp186_ = (GXmlNode*) _tmp185_;
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp187_ = gxml_node_get_children_nodes (_tmp186_);
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp188_ = _tmp187_;
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp189_ = _tmp188_;
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp190_ = gee_collection_get_size ((GeeCollection*) _tmp189_);
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_tmp191_ = _tmp190_;
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp191_ == 1, "d.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes.size == 1");
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp189_);
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp186_);
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp184_);
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp181_);
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp179_);
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp176_);
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp174_);
#line 369 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp171_);
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp192_ = d;
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp193_ = gxml_document_get_root ((GXmlDocument*) _tmp192_);
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp194_ = _tmp193_;
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp195_ = _tmp194_;
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp196_ = gxml_node_get_children_nodes (_tmp195_);
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp197_ = _tmp196_;
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp198_ = _tmp197_;
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp199_ = gee_list_get ((GeeList*) _tmp198_, 0);
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp200_ = (GXmlNode*) _tmp199_;
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp201_ = gxml_node_get_children_nodes (_tmp200_);
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp202_ = _tmp201_;
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp203_ = _tmp202_;
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp204_ = gee_list_get ((GeeList*) _tmp203_, 0);
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp205_ = (GXmlNode*) _tmp204_;
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp206_ = gxml_node_get_children_nodes (_tmp205_);
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp207_ = _tmp206_;
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp208_ = _tmp207_;
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp209_ = gee_list_get ((GeeList*) _tmp208_, 0);
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp210_ = (GXmlNode*) _tmp209_;
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp211_ = gxml_node_get_children_nodes (_tmp210_);
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp212_ = _tmp211_;
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp213_ = _tmp212_;
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp214_ = gee_list_get ((GeeList*) _tmp213_, 0);
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_tmp215_ = (GXmlNode*) _tmp214_;
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp215_, GXML_TYPE_TEXT), "d.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes[0] is Text");
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp215_);
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp213_);
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp210_);
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp208_);
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp205_);
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp203_);
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp200_);
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp198_);
#line 370 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp195_);
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp216_ = d;
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp217_ = gxml_document_get_root ((GXmlDocument*) _tmp216_);
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp218_ = _tmp217_;
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp219_ = _tmp218_;
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp220_ = gxml_node_get_children_nodes (_tmp219_);
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp221_ = _tmp220_;
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp222_ = _tmp221_;
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp223_ = gee_list_get ((GeeList*) _tmp222_, 0);
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp224_ = (GXmlNode*) _tmp223_;
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp225_ = gxml_node_get_children_nodes (_tmp224_);
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp226_ = _tmp225_;
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp227_ = _tmp226_;
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp228_ = gee_list_get ((GeeList*) _tmp227_, 0);
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp229_ = (GXmlNode*) _tmp228_;
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp230_ = gxml_node_get_children_nodes (_tmp229_);
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp231_ = _tmp230_;
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp232_ = _tmp231_;
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp233_ = gee_list_get ((GeeList*) _tmp232_, 0);
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp234_ = (GXmlNode*) _tmp233_;
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp235_ = gxml_node_get_children_nodes (_tmp234_);
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp236_ = _tmp235_;
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp237_ = _tmp236_;
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp238_ = gee_list_get ((GeeList*) _tmp237_, 0);
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp239_ = (GXmlNode*) _tmp238_;
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp240_ = gxml_node_get_value (_tmp239_);
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp241_ = _tmp240_;
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_tmp242_ = _tmp241_;
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp242_, "golden dust") == 0, "d.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes[0].value == \"golden dust\"");
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp242_);
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp239_);
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp237_);
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp234_);
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp232_);
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp229_);
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp227_);
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp224_);
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp222_);
#line 371 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp219_);
#line 374 "SerializableGeeDualKeyMapTest.vala"
		_tmp243_ = serializable_gee_dual_key_map_test_big_bag_new ();
#line 374 "SerializableGeeDualKeyMapTest.vala"
		bagt = _tmp243_;
#line 375 "SerializableGeeDualKeyMapTest.vala"
		_tmp244_ = bagt;
#line 375 "SerializableGeeDualKeyMapTest.vala"
		_tmp245_ = d;
#line 375 "SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp244_, (GXmlNode*) _tmp245_, &_inner_error0_);
#line 375 "SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 375 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bagt);
#line 375 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (d);
#line 375 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag);
#line 4908 "SerializableGeeDualKeyMapTest.c"
			goto __catch356_g_error;
		}
#line 376 "SerializableGeeDualKeyMapTest.vala"
		_tmp246_ = bagt;
#line 376 "SerializableGeeDualKeyMapTest.vala"
		_tmp247_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp246_);
#line 376 "SerializableGeeDualKeyMapTest.vala"
		_tmp248_ = _tmp247_;
#line 376 "SerializableGeeDualKeyMapTest.vala"
		_tmp249_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp248_);
#line 376 "SerializableGeeDualKeyMapTest.vala"
		_tmp250_ = _tmp249_;
#line 376 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp250_ == 0, "bagt.bags.size == 0");
#line 377 "SerializableGeeDualKeyMapTest.vala"
		_tmp252_ = bagt;
#line 377 "SerializableGeeDualKeyMapTest.vala"
		_tmp253_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp252_);
#line 377 "SerializableGeeDualKeyMapTest.vala"
		_tmp254_ = _tmp253_;
#line 377 "SerializableGeeDualKeyMapTest.vala"
		_tmp251_ = gxml_serializable_dual_key_map_deserialize_children ((GXmlSerializableDualKeyMap*) _tmp254_, &_inner_error0_);
#line 377 "SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 377 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bagt);
#line 377 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (d);
#line 377 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag);
#line 4939 "SerializableGeeDualKeyMapTest.c"
			goto __catch356_g_error;
		}
#line 377 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp251_, "bagt.bags.deserialize_children ()");
#line 378 "SerializableGeeDualKeyMapTest.vala"
		_tmp255_ = bagt;
#line 378 "SerializableGeeDualKeyMapTest.vala"
		_tmp256_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp255_);
#line 378 "SerializableGeeDualKeyMapTest.vala"
		_tmp257_ = _tmp256_;
#line 378 "SerializableGeeDualKeyMapTest.vala"
		_tmp258_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp257_);
#line 378 "SerializableGeeDualKeyMapTest.vala"
		_tmp259_ = _tmp258_;
#line 378 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp259_ == 2, "bagt.bags.size == 2");
#line 379 "SerializableGeeDualKeyMapTest.vala"
		_tmp261_ = bagt;
#line 379 "SerializableGeeDualKeyMapTest.vala"
		_tmp262_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp261_);
#line 379 "SerializableGeeDualKeyMapTest.vala"
		_tmp263_ = _tmp262_;
#line 379 "SerializableGeeDualKeyMapTest.vala"
		_tmp264_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp263_, "money", "SmallBag1");
#line 379 "SerializableGeeDualKeyMapTest.vala"
		_tmp265_ = (SerializableGeeDualKeyMapTestSmallBag*) _tmp264_;
#line 379 "SerializableGeeDualKeyMapTest.vala"
		_tmp266_ = serializable_gee_dual_key_map_test_small_bag_get_balls (_tmp265_);
#line 379 "SerializableGeeDualKeyMapTest.vala"
		_tmp267_ = _tmp266_;
#line 379 "SerializableGeeDualKeyMapTest.vala"
		_tmp268_ = gxml_serializable_dual_key_map_deserialize_children ((GXmlSerializableDualKeyMap*) _tmp267_, &_inner_error0_);
#line 379 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp265_);
#line 379 "SerializableGeeDualKeyMapTest.vala"
		_tmp260_ = _tmp268_;
#line 379 "SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 379 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bagt);
#line 379 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (d);
#line 379 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag);
#line 4984 "SerializableGeeDualKeyMapTest.c"
			goto __catch356_g_error;
		}
#line 379 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp260_, "bagt.bags.get(\"money\",\"SmallBag1\").balls.deserialize_children ()");
#line 380 "SerializableGeeDualKeyMapTest.vala"
		_tmp269_ = bagt;
#line 380 "SerializableGeeDualKeyMapTest.vala"
		_tmp270_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp269_);
#line 380 "SerializableGeeDualKeyMapTest.vala"
		_tmp271_ = _tmp270_;
#line 380 "SerializableGeeDualKeyMapTest.vala"
		_tmp272_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp271_, "money", "SmallBag1");
#line 380 "SerializableGeeDualKeyMapTest.vala"
		_tmp273_ = (SerializableGeeDualKeyMapTestSmallBag*) _tmp272_;
#line 380 "SerializableGeeDualKeyMapTest.vala"
		_tmp274_ = serializable_gee_dual_key_map_test_small_bag_get_balls (_tmp273_);
#line 380 "SerializableGeeDualKeyMapTest.vala"
		_tmp275_ = _tmp274_;
#line 380 "SerializableGeeDualKeyMapTest.vala"
		_tmp276_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp275_);
#line 380 "SerializableGeeDualKeyMapTest.vala"
		_tmp277_ = _tmp276_;
#line 380 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp277_ == 2, "bagt.bags.get(\"money\",\"SmallBag1\").balls.size == 2");
#line 380 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp273_);
#line 381 "SerializableGeeDualKeyMapTest.vala"
		_tmp278_ = bagt;
#line 381 "SerializableGeeDualKeyMapTest.vala"
		_tmp279_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp278_);
#line 381 "SerializableGeeDualKeyMapTest.vala"
		_tmp280_ = _tmp279_;
#line 381 "SerializableGeeDualKeyMapTest.vala"
		_tmp281_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp280_, "money", "SmallBag1");
#line 381 "SerializableGeeDualKeyMapTest.vala"
		_tmp282_ = (SerializableGeeDualKeyMapTestSmallBag*) _tmp281_;
#line 381 "SerializableGeeDualKeyMapTest.vala"
		_tmp283_ = serializable_gee_dual_key_map_test_small_bag_get_balls (_tmp282_);
#line 381 "SerializableGeeDualKeyMapTest.vala"
		_tmp284_ = _tmp283_;
#line 381 "SerializableGeeDualKeyMapTest.vala"
		_tmp285_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp284_, "medium", "Ball1");
#line 381 "SerializableGeeDualKeyMapTest.vala"
		_tmp286_ = (SerializableGeeDualKeyMapTestBall*) _tmp285_;
#line 381 "SerializableGeeDualKeyMapTest.vala"
		_tmp287_ = serializable_gee_dual_key_map_test_ball_get_name (_tmp286_);
#line 381 "SerializableGeeDualKeyMapTest.vala"
		_tmp288_ = _tmp287_;
#line 381 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp288_, "Ball1") == 0, "bagt.bags.get(\"money\",\"SmallBag1\").balls.get(\"medium\",\"Ball1\").name == \"Ball1\"");
#line 381 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp286_);
#line 381 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp282_);
#line 382 "SerializableGeeDualKeyMapTest.vala"
		_tmp289_ = bagt;
#line 382 "SerializableGeeDualKeyMapTest.vala"
		_tmp290_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp289_);
#line 382 "SerializableGeeDualKeyMapTest.vala"
		_tmp291_ = _tmp290_;
#line 382 "SerializableGeeDualKeyMapTest.vala"
		_tmp292_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp291_, "money", "SmallBag1");
#line 382 "SerializableGeeDualKeyMapTest.vala"
		_tmp293_ = (SerializableGeeDualKeyMapTestSmallBag*) _tmp292_;
#line 382 "SerializableGeeDualKeyMapTest.vala"
		_tmp294_ = serializable_gee_dual_key_map_test_small_bag_get_balls (_tmp293_);
#line 382 "SerializableGeeDualKeyMapTest.vala"
		_tmp295_ = _tmp294_;
#line 382 "SerializableGeeDualKeyMapTest.vala"
		_tmp296_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp295_, "medium", "Ball1");
#line 382 "SerializableGeeDualKeyMapTest.vala"
		_tmp297_ = (SerializableGeeDualKeyMapTestBall*) _tmp296_;
#line 382 "SerializableGeeDualKeyMapTest.vala"
		_tmp298_ = serializable_gee_dual_key_map_test_ball_get_ballfill (_tmp297_);
#line 382 "SerializableGeeDualKeyMapTest.vala"
		_tmp299_ = _tmp298_;
#line 382 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp299_ != NULL, "bagt.bags.get(\"money\",\"SmallBag1\").balls.get(\"medium\",\"Ball1\").ballfill !=null");
#line 382 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp297_);
#line 382 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp293_);
#line 383 "SerializableGeeDualKeyMapTest.vala"
		_tmp300_ = bagt;
#line 383 "SerializableGeeDualKeyMapTest.vala"
		_tmp301_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp300_);
#line 383 "SerializableGeeDualKeyMapTest.vala"
		_tmp302_ = _tmp301_;
#line 383 "SerializableGeeDualKeyMapTest.vala"
		_tmp303_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp302_, "money", "SmallBag1");
#line 383 "SerializableGeeDualKeyMapTest.vala"
		_tmp304_ = (SerializableGeeDualKeyMapTestSmallBag*) _tmp303_;
#line 383 "SerializableGeeDualKeyMapTest.vala"
		_tmp305_ = serializable_gee_dual_key_map_test_small_bag_get_balls (_tmp304_);
#line 383 "SerializableGeeDualKeyMapTest.vala"
		_tmp306_ = _tmp305_;
#line 383 "SerializableGeeDualKeyMapTest.vala"
		_tmp307_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp306_, "medium", "Ball1");
#line 383 "SerializableGeeDualKeyMapTest.vala"
		_tmp308_ = (SerializableGeeDualKeyMapTestBall*) _tmp307_;
#line 383 "SerializableGeeDualKeyMapTest.vala"
		_tmp309_ = serializable_gee_dual_key_map_test_ball_get_ballfill (_tmp308_);
#line 383 "SerializableGeeDualKeyMapTest.vala"
		_tmp310_ = _tmp309_;
#line 383 "SerializableGeeDualKeyMapTest.vala"
		_tmp311_ = gxml_serializable_get_serialized_xml_node_value ((GXmlSerializable*) _tmp310_);
#line 383 "SerializableGeeDualKeyMapTest.vala"
		_tmp312_ = _tmp311_;
#line 383 "SerializableGeeDualKeyMapTest.vala"
		_tmp313_ = _tmp312_;
#line 383 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp313_ != NULL, "bagt.bags.get(\"money\",\"SmallBag1\").balls.get(\"medium\",\"Ball1\").ballfill.serialized_xml_node_value !=null");
#line 383 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp313_);
#line 383 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp308_);
#line 383 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp304_);
#line 384 "SerializableGeeDualKeyMapTest.vala"
		_tmp314_ = bagt;
#line 384 "SerializableGeeDualKeyMapTest.vala"
		_tmp315_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp314_);
#line 384 "SerializableGeeDualKeyMapTest.vala"
		_tmp316_ = _tmp315_;
#line 384 "SerializableGeeDualKeyMapTest.vala"
		_tmp317_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp316_, "money", "SmallBag1");
#line 384 "SerializableGeeDualKeyMapTest.vala"
		_tmp318_ = (SerializableGeeDualKeyMapTestSmallBag*) _tmp317_;
#line 384 "SerializableGeeDualKeyMapTest.vala"
		_tmp319_ = serializable_gee_dual_key_map_test_small_bag_get_balls (_tmp318_);
#line 384 "SerializableGeeDualKeyMapTest.vala"
		_tmp320_ = _tmp319_;
#line 384 "SerializableGeeDualKeyMapTest.vala"
		_tmp321_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp320_, "medium", "Ball1");
#line 384 "SerializableGeeDualKeyMapTest.vala"
		_tmp322_ = (SerializableGeeDualKeyMapTestBall*) _tmp321_;
#line 384 "SerializableGeeDualKeyMapTest.vala"
		_tmp323_ = serializable_gee_dual_key_map_test_ball_get_ballfill (_tmp322_);
#line 384 "SerializableGeeDualKeyMapTest.vala"
		_tmp324_ = _tmp323_;
#line 384 "SerializableGeeDualKeyMapTest.vala"
		_tmp325_ = gxml_serializable_get_serialized_xml_node_value ((GXmlSerializable*) _tmp324_);
#line 384 "SerializableGeeDualKeyMapTest.vala"
		_tmp326_ = _tmp325_;
#line 384 "SerializableGeeDualKeyMapTest.vala"
		_tmp327_ = _tmp326_;
#line 384 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp327_, "golden dust") == 0, "bagt.bags.get(\"money\",\"SmallBag1\").balls.get(\"medium\",\"Ball1\").ballfill.serialized_xml_node_value ==\"golden dust\"");
#line 384 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp327_);
#line 384 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp322_);
#line 384 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp318_);
#line 385 "SerializableGeeDualKeyMapTest.vala"
		_tmp328_ = serializable_gee_dual_key_map_test_big_bag_new ();
#line 385 "SerializableGeeDualKeyMapTest.vala"
		bag3 = _tmp328_;
#line 386 "SerializableGeeDualKeyMapTest.vala"
		_tmp329_ = bag3;
#line 386 "SerializableGeeDualKeyMapTest.vala"
		_tmp330_ = d;
#line 386 "SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp329_, (GXmlNode*) _tmp330_, &_inner_error0_);
#line 386 "SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 386 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag3);
#line 386 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bagt);
#line 386 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (d);
#line 386 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag);
#line 5159 "SerializableGeeDualKeyMapTest.c"
			goto __catch356_g_error;
		}
#line 387 "SerializableGeeDualKeyMapTest.vala"
		_tmp331_ = bag3;
#line 387 "SerializableGeeDualKeyMapTest.vala"
		_tmp332_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp331_);
#line 387 "SerializableGeeDualKeyMapTest.vala"
		_tmp333_ = _tmp332_;
#line 387 "SerializableGeeDualKeyMapTest.vala"
		_tmp334_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp333_);
#line 387 "SerializableGeeDualKeyMapTest.vala"
		_tmp335_ = _tmp334_;
#line 387 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp335_ == 0, "bag3.bags.size == 0");
#line 388 "SerializableGeeDualKeyMapTest.vala"
		_tmp337_ = bag3;
#line 388 "SerializableGeeDualKeyMapTest.vala"
		_tmp338_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp337_);
#line 388 "SerializableGeeDualKeyMapTest.vala"
		_tmp339_ = _tmp338_;
#line 388 "SerializableGeeDualKeyMapTest.vala"
		_tmp336_ = gxml_serializable_dual_key_map_deserialize_children ((GXmlSerializableDualKeyMap*) _tmp339_, &_inner_error0_);
#line 388 "SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 388 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag3);
#line 388 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bagt);
#line 388 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (d);
#line 388 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag);
#line 5192 "SerializableGeeDualKeyMapTest.c"
			goto __catch356_g_error;
		}
#line 388 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp336_, "bag3.bags.deserialize_children ()");
#line 389 "SerializableGeeDualKeyMapTest.vala"
		_tmp340_ = bag3;
#line 389 "SerializableGeeDualKeyMapTest.vala"
		_tmp341_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp340_);
#line 389 "SerializableGeeDualKeyMapTest.vala"
		_tmp342_ = _tmp341_;
#line 389 "SerializableGeeDualKeyMapTest.vala"
		_tmp343_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp342_);
#line 389 "SerializableGeeDualKeyMapTest.vala"
		_tmp344_ = _tmp343_;
#line 389 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp344_ == 2, "bag3.bags.size == 2");
#line 390 "SerializableGeeDualKeyMapTest.vala"
		_tmp345_ = bag3;
#line 390 "SerializableGeeDualKeyMapTest.vala"
		_tmp346_ = d;
#line 390 "SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp345_, (GXmlNode*) _tmp346_, &_inner_error0_);
#line 390 "SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 390 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag3);
#line 390 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bagt);
#line 390 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (d);
#line 390 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag);
#line 5225 "SerializableGeeDualKeyMapTest.c"
			goto __catch356_g_error;
		}
#line 391 "SerializableGeeDualKeyMapTest.vala"
		_tmp347_ = bag3;
#line 391 "SerializableGeeDualKeyMapTest.vala"
		_tmp348_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp347_);
#line 391 "SerializableGeeDualKeyMapTest.vala"
		_tmp349_ = _tmp348_;
#line 391 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (!gxml_serializable_dual_key_map_deserialized ((GXmlSerializableDualKeyMap*) _tmp349_), "!bag3.bags.deserialized ()");
#line 393 "SerializableGeeDualKeyMapTest.vala"
		_tmp350_ = serializable_gee_dual_key_map_test_big_bag_new ();
#line 393 "SerializableGeeDualKeyMapTest.vala"
		bag2 = _tmp350_;
#line 394 "SerializableGeeDualKeyMapTest.vala"
		_tmp351_ = bag2;
#line 394 "SerializableGeeDualKeyMapTest.vala"
		_tmp352_ = d;
#line 394 "SerializableGeeDualKeyMapTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp351_, (GXmlNode*) _tmp352_, &_inner_error0_);
#line 394 "SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 394 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag2);
#line 394 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag3);
#line 394 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bagt);
#line 394 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (d);
#line 394 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag);
#line 5258 "SerializableGeeDualKeyMapTest.c"
			goto __catch356_g_error;
		}
#line 395 "SerializableGeeDualKeyMapTest.vala"
		_tmp353_ = bag2;
#line 395 "SerializableGeeDualKeyMapTest.vala"
		_tmp354_ = serializable_gee_dual_key_map_test_big_bag_get_bags (_tmp353_);
#line 395 "SerializableGeeDualKeyMapTest.vala"
		_tmp355_ = _tmp354_;
#line 395 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (!gxml_serializable_dual_key_map_deserialized ((GXmlSerializableDualKeyMap*) _tmp355_), "!bag2.bags.deserialized ()");
#line 396 "SerializableGeeDualKeyMapTest.vala"
		_tmp356_ = gxml_gdocument_new ();
#line 396 "SerializableGeeDualKeyMapTest.vala"
		d2 = _tmp356_;
#line 397 "SerializableGeeDualKeyMapTest.vala"
		_tmp357_ = bag2;
#line 397 "SerializableGeeDualKeyMapTest.vala"
		_tmp358_ = d2;
#line 397 "SerializableGeeDualKeyMapTest.vala"
		_tmp359_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp357_, (GXmlNode*) _tmp358_, &_inner_error0_);
#line 397 "SerializableGeeDualKeyMapTest.vala"
		_tmp360_ = _tmp359_;
#line 397 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp360_);
#line 397 "SerializableGeeDualKeyMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 397 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (d2);
#line 397 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag2);
#line 397 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag3);
#line 397 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bagt);
#line 397 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (d);
#line 397 "SerializableGeeDualKeyMapTest.vala"
			_g_object_unref0 (bag);
#line 5297 "SerializableGeeDualKeyMapTest.c"
			goto __catch356_g_error;
		}
#line 399 "SerializableGeeDualKeyMapTest.vala"
		_tmp361_ = d2;
#line 399 "SerializableGeeDualKeyMapTest.vala"
		_tmp362_ = gxml_document_get_root ((GXmlDocument*) _tmp361_);
#line 399 "SerializableGeeDualKeyMapTest.vala"
		_tmp363_ = _tmp362_;
#line 399 "SerializableGeeDualKeyMapTest.vala"
		_tmp364_ = _tmp363_;
#line 399 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp364_ != NULL, "d2.root != null");
#line 399 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp364_);
#line 400 "SerializableGeeDualKeyMapTest.vala"
		_tmp365_ = d2;
#line 400 "SerializableGeeDualKeyMapTest.vala"
		_tmp366_ = gxml_document_get_root ((GXmlDocument*) _tmp365_);
#line 400 "SerializableGeeDualKeyMapTest.vala"
		_tmp367_ = _tmp366_;
#line 400 "SerializableGeeDualKeyMapTest.vala"
		_tmp368_ = _tmp367_;
#line 400 "SerializableGeeDualKeyMapTest.vala"
		_tmp369_ = gxml_node_get_name (_tmp368_);
#line 400 "SerializableGeeDualKeyMapTest.vala"
		_tmp370_ = _tmp369_;
#line 400 "SerializableGeeDualKeyMapTest.vala"
		_tmp371_ = _tmp370_;
#line 400 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp371_, "BigBag") == 0, "d2.root.name == \"BigBag\"");
#line 400 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp371_);
#line 400 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp368_);
#line 401 "SerializableGeeDualKeyMapTest.vala"
		_tmp372_ = d2;
#line 401 "SerializableGeeDualKeyMapTest.vala"
		_tmp373_ = gxml_document_get_root ((GXmlDocument*) _tmp372_);
#line 401 "SerializableGeeDualKeyMapTest.vala"
		_tmp374_ = _tmp373_;
#line 401 "SerializableGeeDualKeyMapTest.vala"
		_tmp375_ = _tmp374_;
#line 401 "SerializableGeeDualKeyMapTest.vala"
		_tmp376_ = gxml_node_get_children_nodes (_tmp375_);
#line 401 "SerializableGeeDualKeyMapTest.vala"
		_tmp377_ = _tmp376_;
#line 401 "SerializableGeeDualKeyMapTest.vala"
		_tmp378_ = _tmp377_;
#line 401 "SerializableGeeDualKeyMapTest.vala"
		_tmp379_ = gee_collection_get_size ((GeeCollection*) _tmp378_);
#line 401 "SerializableGeeDualKeyMapTest.vala"
		_tmp380_ = _tmp379_;
#line 401 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp380_ == 2, "d2.root.children_nodes.size == 2");
#line 401 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp378_);
#line 401 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp375_);
#line 402 "SerializableGeeDualKeyMapTest.vala"
		_tmp381_ = d2;
#line 402 "SerializableGeeDualKeyMapTest.vala"
		_tmp382_ = gxml_document_get_root ((GXmlDocument*) _tmp381_);
#line 402 "SerializableGeeDualKeyMapTest.vala"
		_tmp383_ = _tmp382_;
#line 402 "SerializableGeeDualKeyMapTest.vala"
		_tmp384_ = _tmp383_;
#line 402 "SerializableGeeDualKeyMapTest.vala"
		_tmp385_ = gxml_node_get_children_nodes (_tmp384_);
#line 402 "SerializableGeeDualKeyMapTest.vala"
		_tmp386_ = _tmp385_;
#line 402 "SerializableGeeDualKeyMapTest.vala"
		_tmp387_ = _tmp386_;
#line 402 "SerializableGeeDualKeyMapTest.vala"
		_tmp388_ = gee_list_get ((GeeList*) _tmp387_, 0);
#line 402 "SerializableGeeDualKeyMapTest.vala"
		_tmp389_ = (GXmlNode*) _tmp388_;
#line 402 "SerializableGeeDualKeyMapTest.vala"
		_tmp390_ = gxml_node_get_name (_tmp389_);
#line 402 "SerializableGeeDualKeyMapTest.vala"
		_tmp391_ = _tmp390_;
#line 402 "SerializableGeeDualKeyMapTest.vala"
		_tmp392_ = _tmp391_;
#line 402 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp392_, "SmallBag") == 0, "d2.root.children_nodes[0].name == \"SmallBag\"");
#line 402 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp392_);
#line 402 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp389_);
#line 402 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp387_);
#line 402 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp384_);
#line 403 "SerializableGeeDualKeyMapTest.vala"
		_tmp393_ = d2;
#line 403 "SerializableGeeDualKeyMapTest.vala"
		_tmp394_ = gxml_document_get_root ((GXmlDocument*) _tmp393_);
#line 403 "SerializableGeeDualKeyMapTest.vala"
		_tmp395_ = _tmp394_;
#line 403 "SerializableGeeDualKeyMapTest.vala"
		_tmp396_ = _tmp395_;
#line 403 "SerializableGeeDualKeyMapTest.vala"
		_tmp397_ = gxml_node_get_children_nodes (_tmp396_);
#line 403 "SerializableGeeDualKeyMapTest.vala"
		_tmp398_ = _tmp397_;
#line 403 "SerializableGeeDualKeyMapTest.vala"
		_tmp399_ = _tmp398_;
#line 403 "SerializableGeeDualKeyMapTest.vala"
		_tmp400_ = gee_list_get ((GeeList*) _tmp399_, 0);
#line 403 "SerializableGeeDualKeyMapTest.vala"
		_tmp401_ = (GXmlNode*) _tmp400_;
#line 403 "SerializableGeeDualKeyMapTest.vala"
		_tmp402_ = gxml_node_get_children_nodes (_tmp401_);
#line 403 "SerializableGeeDualKeyMapTest.vala"
		_tmp403_ = _tmp402_;
#line 403 "SerializableGeeDualKeyMapTest.vala"
		_tmp404_ = _tmp403_;
#line 403 "SerializableGeeDualKeyMapTest.vala"
		_tmp405_ = gee_collection_get_size ((GeeCollection*) _tmp404_);
#line 403 "SerializableGeeDualKeyMapTest.vala"
		_tmp406_ = _tmp405_;
#line 403 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp406_ == 2, "d2.root.children_nodes[0].children_nodes.size == 2");
#line 403 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp404_);
#line 403 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp401_);
#line 403 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp399_);
#line 403 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp396_);
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_tmp407_ = d2;
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_tmp408_ = gxml_document_get_root ((GXmlDocument*) _tmp407_);
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_tmp409_ = _tmp408_;
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_tmp410_ = _tmp409_;
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_tmp411_ = gxml_node_get_children_nodes (_tmp410_);
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_tmp412_ = _tmp411_;
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_tmp413_ = _tmp412_;
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_tmp414_ = gee_list_get ((GeeList*) _tmp413_, 0);
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_tmp415_ = (GXmlNode*) _tmp414_;
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_tmp416_ = gxml_node_get_children_nodes (_tmp415_);
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_tmp417_ = _tmp416_;
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_tmp418_ = _tmp417_;
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_tmp419_ = gee_list_get ((GeeList*) _tmp418_, 0);
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_tmp420_ = (GXmlNode*) _tmp419_;
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_tmp421_ = gxml_node_get_name (_tmp420_);
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_tmp422_ = _tmp421_;
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_tmp423_ = _tmp422_;
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp423_, "Ball") == 0, "d2.root.children_nodes[0].children_nodes[0].name == \"Ball\"");
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp423_);
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp420_);
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp418_);
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp415_);
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp413_);
#line 404 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp410_);
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_tmp424_ = d2;
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_tmp425_ = gxml_document_get_root ((GXmlDocument*) _tmp424_);
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_tmp426_ = _tmp425_;
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_tmp427_ = _tmp426_;
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_tmp428_ = gxml_node_get_children_nodes (_tmp427_);
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_tmp429_ = _tmp428_;
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_tmp430_ = _tmp429_;
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_tmp431_ = gee_list_get ((GeeList*) _tmp430_, 0);
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_tmp432_ = (GXmlNode*) _tmp431_;
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_tmp433_ = gxml_node_get_children_nodes (_tmp432_);
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_tmp434_ = _tmp433_;
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_tmp435_ = _tmp434_;
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_tmp436_ = gee_list_get ((GeeList*) _tmp435_, 0);
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_tmp437_ = (GXmlNode*) _tmp436_;
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_tmp438_ = gxml_node_get_children_nodes (_tmp437_);
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_tmp439_ = _tmp438_;
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_tmp440_ = _tmp439_;
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_tmp441_ = gee_collection_get_size ((GeeCollection*) _tmp440_);
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_tmp442_ = _tmp441_;
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp442_ == 1, "d2.root.children_nodes[0].children_nodes[0].children_nodes.size == 1");
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp440_);
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp437_);
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp435_);
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp432_);
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp430_);
#line 405 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp427_);
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_tmp443_ = d2;
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_tmp444_ = gxml_document_get_root ((GXmlDocument*) _tmp443_);
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_tmp445_ = _tmp444_;
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_tmp446_ = _tmp445_;
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_tmp447_ = gxml_node_get_children_nodes (_tmp446_);
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_tmp448_ = _tmp447_;
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_tmp449_ = _tmp448_;
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_tmp450_ = gee_list_get ((GeeList*) _tmp449_, 0);
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_tmp451_ = (GXmlNode*) _tmp450_;
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_tmp452_ = gxml_node_get_children_nodes (_tmp451_);
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_tmp453_ = _tmp452_;
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_tmp454_ = _tmp453_;
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_tmp455_ = gee_list_get ((GeeList*) _tmp454_, 0);
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_tmp456_ = (GXmlNode*) _tmp455_;
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_tmp457_ = gxml_node_get_children_nodes (_tmp456_);
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_tmp458_ = _tmp457_;
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_tmp459_ = _tmp458_;
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_tmp460_ = gee_list_get ((GeeList*) _tmp459_, 0);
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_tmp461_ = (GXmlNode*) _tmp460_;
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_tmp462_ = gxml_node_get_name (_tmp461_);
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_tmp463_ = _tmp462_;
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_tmp464_ = _tmp463_;
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp464_, "BallFill") == 0, "d2.root.children_nodes[0].children_nodes[0].children_nodes[0].name == \"BallFill\"");
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp464_);
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp461_);
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp459_);
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp456_);
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp454_);
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp451_);
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp449_);
#line 406 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp446_);
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp465_ = d2;
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp466_ = gxml_document_get_root ((GXmlDocument*) _tmp465_);
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp467_ = _tmp466_;
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp468_ = _tmp467_;
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp469_ = gxml_node_get_children_nodes (_tmp468_);
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp470_ = _tmp469_;
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp471_ = _tmp470_;
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp472_ = gee_list_get ((GeeList*) _tmp471_, 0);
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp473_ = (GXmlNode*) _tmp472_;
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp474_ = gxml_node_get_children_nodes (_tmp473_);
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp475_ = _tmp474_;
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp476_ = _tmp475_;
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp477_ = gee_list_get ((GeeList*) _tmp476_, 0);
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp478_ = (GXmlNode*) _tmp477_;
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp479_ = gxml_node_get_children_nodes (_tmp478_);
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp480_ = _tmp479_;
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp481_ = _tmp480_;
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp482_ = gee_list_get ((GeeList*) _tmp481_, 0);
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp483_ = (GXmlNode*) _tmp482_;
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp484_ = gxml_node_get_children_nodes (_tmp483_);
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp485_ = _tmp484_;
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp486_ = _tmp485_;
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp487_ = gee_collection_get_size ((GeeCollection*) _tmp486_);
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_tmp488_ = _tmp487_;
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (_tmp488_ == 1, "d2.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes.size == 1");
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp486_);
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp483_);
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp481_);
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp478_);
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp476_);
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp473_);
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp471_);
#line 407 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp468_);
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp489_ = d2;
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp490_ = gxml_document_get_root ((GXmlDocument*) _tmp489_);
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp491_ = _tmp490_;
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp492_ = _tmp491_;
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp493_ = gxml_node_get_children_nodes (_tmp492_);
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp494_ = _tmp493_;
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp495_ = _tmp494_;
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp496_ = gee_list_get ((GeeList*) _tmp495_, 0);
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp497_ = (GXmlNode*) _tmp496_;
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp498_ = gxml_node_get_children_nodes (_tmp497_);
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp499_ = _tmp498_;
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp500_ = _tmp499_;
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp501_ = gee_list_get ((GeeList*) _tmp500_, 0);
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp502_ = (GXmlNode*) _tmp501_;
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp503_ = gxml_node_get_children_nodes (_tmp502_);
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp504_ = _tmp503_;
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp505_ = _tmp504_;
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp506_ = gee_list_get ((GeeList*) _tmp505_, 0);
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp507_ = (GXmlNode*) _tmp506_;
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp508_ = gxml_node_get_children_nodes (_tmp507_);
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp509_ = _tmp508_;
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp510_ = _tmp509_;
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp511_ = gee_list_get ((GeeList*) _tmp510_, 0);
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_tmp512_ = (GXmlNode*) _tmp511_;
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp512_, GXML_TYPE_TEXT), "d2.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes[0] is GXml.Text");
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp512_);
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp510_);
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp507_);
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp505_);
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp502_);
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp500_);
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp497_);
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp495_);
#line 408 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp492_);
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp513_ = d2;
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp514_ = gxml_document_get_root ((GXmlDocument*) _tmp513_);
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp515_ = _tmp514_;
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp516_ = _tmp515_;
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp517_ = gxml_node_get_children_nodes (_tmp516_);
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp518_ = _tmp517_;
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp519_ = _tmp518_;
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp520_ = gee_list_get ((GeeList*) _tmp519_, 0);
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp521_ = (GXmlNode*) _tmp520_;
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp522_ = gxml_node_get_children_nodes (_tmp521_);
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp523_ = _tmp522_;
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp524_ = _tmp523_;
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp525_ = gee_list_get ((GeeList*) _tmp524_, 0);
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp526_ = (GXmlNode*) _tmp525_;
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp527_ = gxml_node_get_children_nodes (_tmp526_);
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp528_ = _tmp527_;
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp529_ = _tmp528_;
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp530_ = gee_list_get ((GeeList*) _tmp529_, 0);
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp531_ = (GXmlNode*) _tmp530_;
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp532_ = gxml_node_get_children_nodes (_tmp531_);
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp533_ = _tmp532_;
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp534_ = _tmp533_;
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp535_ = gee_list_get ((GeeList*) _tmp534_, 0);
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp536_ = (GXmlNode*) _tmp535_;
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp537_ = gxml_node_get_value (_tmp536_);
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp538_ = _tmp537_;
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_tmp539_ = _tmp538_;
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp539_, "golden dust") == 0, "d2.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes[0].value == \"golden dust\"");
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp539_);
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp536_);
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp534_);
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp531_);
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp529_);
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp526_);
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp524_);
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp521_);
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp519_);
#line 409 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (_tmp516_);
#line 339 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (d2);
#line 339 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (bag2);
#line 339 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (bag3);
#line 339 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (bagt);
#line 339 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (d);
#line 339 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (bag);
#line 5812 "SerializableGeeDualKeyMapTest.c"
	}
	goto __finally356;
	__catch356_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp540_;
		gchar* _tmp541_;
		gchar* _tmp542_;
#line 339 "SerializableGeeDualKeyMapTest.vala"
		e = _inner_error0_;
#line 339 "SerializableGeeDualKeyMapTest.vala"
		_inner_error0_ = NULL;
#line 411 "SerializableGeeDualKeyMapTest.vala"
		_tmp540_ = e->message;
#line 411 "SerializableGeeDualKeyMapTest.vala"
		_tmp541_ = g_strconcat ("ERROR: ", _tmp540_, NULL);
#line 411 "SerializableGeeDualKeyMapTest.vala"
		_tmp542_ = _tmp541_;
#line 411 "SerializableGeeDualKeyMapTest.vala"
		g_message ("SerializableGeeDualKeyMapTest.vala:411: %s", _tmp542_);
#line 411 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (_tmp542_);
#line 412 "SerializableGeeDualKeyMapTest.vala"
		g_assert_not_reached ();
#line 339 "SerializableGeeDualKeyMapTest.vala"
		_g_error_free0 (e);
#line 5839 "SerializableGeeDualKeyMapTest.c"
	}
	__finally356:
#line 339 "SerializableGeeDualKeyMapTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 339 "SerializableGeeDualKeyMapTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 339 "SerializableGeeDualKeyMapTest.vala"
		g_clear_error (&_inner_error0_);
#line 339 "SerializableGeeDualKeyMapTest.vala"
		return;
#line 5850 "SerializableGeeDualKeyMapTest.c"
	}
}

static void
___lambda304__gtest_func (void)
{
#line 337 "SerializableGeeDualKeyMapTest.vala"
	__lambda304_ ();
#line 5859 "SerializableGeeDualKeyMapTest.c"
}

void
serializable_gee_dual_key_map_test_add_tests (void)
{
#line 93 "SerializableGeeDualKeyMapTest.vala"
	g_test_add_func ("/gxml/serializable/dualkeymap/api", ___lambda299__gtest_func);
#line 170 "SerializableGeeDualKeyMapTest.vala"
	g_test_add_func ("/gxml/serializable/dualkeymap/serialize", ___lambda300__gtest_func);
#line 238 "SerializableGeeDualKeyMapTest.vala"
	g_test_add_func ("/gxml/serializable/dualkeymap/deserialize", ___lambda301__gtest_func);
#line 281 "SerializableGeeDualKeyMapTest.vala"
	g_test_add_func ("/gxml/serializable/dualkeymap/de-se-deserialize", ___lambda302__gtest_func);
#line 307 "SerializableGeeDualKeyMapTest.vala"
	g_test_add_func ("/gxml/serializable/dualkeymap/deserialize-node-names", ___lambda303__gtest_func);
#line 337 "SerializableGeeDualKeyMapTest.vala"
	g_test_add_func ("/gxml/serializable/dualkeymap/post-deserialization/serialize/contents", ___lambda304__gtest_func);
#line 5877 "SerializableGeeDualKeyMapTest.c"
}

SerializableGeeDualKeyMapTest*
serializable_gee_dual_key_map_test_construct (GType object_type)
{
	SerializableGeeDualKeyMapTest* self = NULL;
#line 43 "SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTest*) gxml_test_construct (object_type);
#line 43 "SerializableGeeDualKeyMapTest.vala"
	return self;
#line 5888 "SerializableGeeDualKeyMapTest.c"
}

SerializableGeeDualKeyMapTest*
serializable_gee_dual_key_map_test_new (void)
{
#line 43 "SerializableGeeDualKeyMapTest.vala"
	return serializable_gee_dual_key_map_test_construct (TYPE_SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST);
#line 5896 "SerializableGeeDualKeyMapTest.c"
}

static inline gpointer
serializable_gee_dual_key_map_test_ball_fill_get_instance_private (SerializableGeeDualKeyMapTestBallFill* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeDualKeyMapTestBallFill_private_offset);
}

static void
serializable_gee_dual_key_map_test_ball_fill_set_text (SerializableGeeDualKeyMapTestBallFill* self,
                                                       const gchar* txt)
{
#line 49 "SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 49 "SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (txt != NULL);
#line 49 "SerializableGeeDualKeyMapTest.vala"
	gxml_serializable_set_serialized_xml_node_value ((GXmlSerializable*) self, txt);
#line 5915 "SerializableGeeDualKeyMapTest.c"
}

static gchar*
serializable_gee_dual_key_map_test_ball_fill_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeDualKeyMapTestBallFill * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 50 "SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBallFill*) base;
#line 50 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 50 "SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 50 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp1_;
#line 50 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 5935 "SerializableGeeDualKeyMapTest.c"
}

static gchar*
serializable_gee_dual_key_map_test_ball_fill_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeDualKeyMapTestBallFill * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 51 "SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBallFill*) base;
#line 51 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = g_strdup ("BallFill");
#line 51 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 51 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 5952 "SerializableGeeDualKeyMapTest.c"
}

static gboolean
serializable_gee_dual_key_map_test_ball_fill_real_serialize_use_xml_node_value (GXmlSerializableObjectModel* base)
{
	SerializableGeeDualKeyMapTestBallFill * self;
	gboolean result = FALSE;
#line 52 "SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBallFill*) base;
#line 52 "SerializableGeeDualKeyMapTest.vala"
	result = TRUE;
#line 52 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 5966 "SerializableGeeDualKeyMapTest.c"
}

static SerializableGeeDualKeyMapTestBallFill*
serializable_gee_dual_key_map_test_ball_fill_construct (GType object_type)
{
	SerializableGeeDualKeyMapTestBallFill * self = NULL;
#line 46 "SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBallFill*) gxml_serializable_object_model_construct (object_type);
#line 46 "SerializableGeeDualKeyMapTest.vala"
	return self;
#line 5977 "SerializableGeeDualKeyMapTest.c"
}

static SerializableGeeDualKeyMapTestBallFill*
serializable_gee_dual_key_map_test_ball_fill_new (void)
{
#line 46 "SerializableGeeDualKeyMapTest.vala"
	return serializable_gee_dual_key_map_test_ball_fill_construct (SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL_FILL);
#line 5985 "SerializableGeeDualKeyMapTest.c"
}

static const gchar*
serializable_gee_dual_key_map_test_ball_fill_get_name (SerializableGeeDualKeyMapTestBallFill* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 48 "SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 48 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 48 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 48 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6001 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_ball_fill_set_name (SerializableGeeDualKeyMapTestBallFill* self,
                                                       const gchar* value)
{
#line 48 "SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 48 "SerializableGeeDualKeyMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_dual_key_map_test_ball_fill_get_name (self)) != 0) {
#line 6012 "SerializableGeeDualKeyMapTest.c"
		gchar* _tmp0_;
#line 48 "SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 48 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (self->priv->_name);
#line 48 "SerializableGeeDualKeyMapTest.vala"
		self->priv->_name = _tmp0_;
#line 48 "SerializableGeeDualKeyMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_dual_key_map_test_ball_fill_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_NAME_PROPERTY]);
#line 6022 "SerializableGeeDualKeyMapTest.c"
	}
}

static void
serializable_gee_dual_key_map_test_ball_fill_class_init (SerializableGeeDualKeyMapTestBallFillClass * klass,
                                                         gpointer klass_data)
{
#line 46 "SerializableGeeDualKeyMapTest.vala"
	serializable_gee_dual_key_map_test_ball_fill_parent_class = g_type_class_peek_parent (klass);
#line 46 "SerializableGeeDualKeyMapTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeDualKeyMapTestBallFill_private_offset);
#line 46 "SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_dual_key_map_test_ball_fill_real_to_string;
#line 46 "SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_dual_key_map_test_ball_fill_real_node_name;
#line 46 "SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->serialize_use_xml_node_value = (gboolean (*) (GXmlSerializableObjectModel*)) serializable_gee_dual_key_map_test_ball_fill_real_serialize_use_xml_node_value;
#line 46 "SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_dual_key_map_test_ball_fill_get_property;
#line 46 "SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_dual_key_map_test_ball_fill_set_property;
#line 46 "SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_dual_key_map_test_ball_fill_finalize;
#line 46 "SerializableGeeDualKeyMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_NAME_PROPERTY, serializable_gee_dual_key_map_test_ball_fill_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6048 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_ball_fill_instance_init (SerializableGeeDualKeyMapTestBallFill * self,
                                                            gpointer klass)
{
	gchar* _tmp0_;
#line 46 "SerializableGeeDualKeyMapTest.vala"
	self->priv = serializable_gee_dual_key_map_test_ball_fill_get_instance_private (self);
#line 48 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = g_strdup ("Fill");
#line 48 "SerializableGeeDualKeyMapTest.vala"
	self->priv->_name = _tmp0_;
#line 6062 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_ball_fill_finalize (GObject * obj)
{
	SerializableGeeDualKeyMapTestBallFill * self;
#line 46 "SerializableGeeDualKeyMapTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL_FILL, SerializableGeeDualKeyMapTestBallFill);
#line 48 "SerializableGeeDualKeyMapTest.vala"
	_g_free0 (self->priv->_name);
#line 46 "SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (serializable_gee_dual_key_map_test_ball_fill_parent_class)->finalize (obj);
#line 6075 "SerializableGeeDualKeyMapTest.c"
}

static GType
serializable_gee_dual_key_map_test_ball_fill_get_type (void)
{
	static volatile gsize serializable_gee_dual_key_map_test_ball_fill_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_dual_key_map_test_ball_fill_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeDualKeyMapTestBallFillClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_dual_key_map_test_ball_fill_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeDualKeyMapTestBallFill), 0, (GInstanceInitFunc) serializable_gee_dual_key_map_test_ball_fill_instance_init, NULL };
		GType serializable_gee_dual_key_map_test_ball_fill_type_id;
		serializable_gee_dual_key_map_test_ball_fill_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeDualKeyMapTestBallFill", &g_define_type_info, 0);
		SerializableGeeDualKeyMapTestBallFill_private_offset = g_type_add_instance_private (serializable_gee_dual_key_map_test_ball_fill_type_id, sizeof (SerializableGeeDualKeyMapTestBallFillPrivate));
		g_once_init_leave (&serializable_gee_dual_key_map_test_ball_fill_type_id__volatile, serializable_gee_dual_key_map_test_ball_fill_type_id);
	}
	return serializable_gee_dual_key_map_test_ball_fill_type_id__volatile;
}

static void
_vala_serializable_gee_dual_key_map_test_ball_fill_get_property (GObject * object,
                                                                 guint property_id,
                                                                 GValue * value,
                                                                 GParamSpec * pspec)
{
	SerializableGeeDualKeyMapTestBallFill * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL_FILL, SerializableGeeDualKeyMapTestBallFill);
#line 46 "SerializableGeeDualKeyMapTest.vala"
	switch (property_id) {
#line 46 "SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_NAME_PROPERTY:
#line 46 "SerializableGeeDualKeyMapTest.vala"
		g_value_set_string (value, serializable_gee_dual_key_map_test_ball_fill_get_name (self));
#line 46 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 6108 "SerializableGeeDualKeyMapTest.c"
		default:
#line 46 "SerializableGeeDualKeyMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 46 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 6114 "SerializableGeeDualKeyMapTest.c"
	}
}

static void
_vala_serializable_gee_dual_key_map_test_ball_fill_set_property (GObject * object,
                                                                 guint property_id,
                                                                 const GValue * value,
                                                                 GParamSpec * pspec)
{
	SerializableGeeDualKeyMapTestBallFill * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL_FILL, SerializableGeeDualKeyMapTestBallFill);
#line 46 "SerializableGeeDualKeyMapTest.vala"
	switch (property_id) {
#line 46 "SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_FILL_NAME_PROPERTY:
#line 46 "SerializableGeeDualKeyMapTest.vala"
		serializable_gee_dual_key_map_test_ball_fill_set_name (self, g_value_get_string (value));
#line 46 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 6134 "SerializableGeeDualKeyMapTest.c"
		default:
#line 46 "SerializableGeeDualKeyMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 46 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 6140 "SerializableGeeDualKeyMapTest.c"
	}
}

static inline gpointer
serializable_gee_dual_key_map_test_ball_get_instance_private (SerializableGeeDualKeyMapTestBall* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeDualKeyMapTestBall_private_offset);
}

static gchar*
serializable_gee_dual_key_map_test_ball_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeDualKeyMapTestBall * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 60 "SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBall*) base;
#line 60 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 60 "SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 60 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp1_;
#line 60 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6167 "SerializableGeeDualKeyMapTest.c"
}

static gchar*
serializable_gee_dual_key_map_test_ball_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeDualKeyMapTestBall * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 61 "SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBall*) base;
#line 61 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = g_strdup ("Ball");
#line 61 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 61 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6184 "SerializableGeeDualKeyMapTest.c"
}

static gchar*
serializable_gee_dual_key_map_test_ball_real_get_map_primary_key (GXmlSerializableMapDualKey* base)
{
	SerializableGeeDualKeyMapTestBall * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 62 "SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBall*) base;
#line 62 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_size;
#line 62 "SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 62 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp1_;
#line 62 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6204 "SerializableGeeDualKeyMapTest.c"
}

static gchar*
serializable_gee_dual_key_map_test_ball_real_get_map_secondary_key (GXmlSerializableMapDualKey* base)
{
	SerializableGeeDualKeyMapTestBall * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 63 "SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBall*) base;
#line 63 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 63 "SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 63 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp1_;
#line 63 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6224 "SerializableGeeDualKeyMapTest.c"
}

static SerializableGeeDualKeyMapTestBall*
serializable_gee_dual_key_map_test_ball_construct (GType object_type)
{
	SerializableGeeDualKeyMapTestBall * self = NULL;
#line 55 "SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBall*) gxml_serializable_object_model_construct (object_type);
#line 55 "SerializableGeeDualKeyMapTest.vala"
	return self;
#line 6235 "SerializableGeeDualKeyMapTest.c"
}

static SerializableGeeDualKeyMapTestBall*
serializable_gee_dual_key_map_test_ball_new (void)
{
#line 55 "SerializableGeeDualKeyMapTest.vala"
	return serializable_gee_dual_key_map_test_ball_construct (SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL);
#line 6243 "SerializableGeeDualKeyMapTest.c"
}

static const gchar*
serializable_gee_dual_key_map_test_ball_get_name (SerializableGeeDualKeyMapTestBall* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 57 "SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 57 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 57 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 57 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6259 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_ball_set_name (SerializableGeeDualKeyMapTestBall* self,
                                                  const gchar* value)
{
#line 57 "SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 57 "SerializableGeeDualKeyMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_dual_key_map_test_ball_get_name (self)) != 0) {
#line 6270 "SerializableGeeDualKeyMapTest.c"
		gchar* _tmp0_;
#line 57 "SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 57 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (self->priv->_name);
#line 57 "SerializableGeeDualKeyMapTest.vala"
		self->priv->_name = _tmp0_;
#line 57 "SerializableGeeDualKeyMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_dual_key_map_test_ball_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_NAME_PROPERTY]);
#line 6280 "SerializableGeeDualKeyMapTest.c"
	}
}

static const gchar*
serializable_gee_dual_key_map_test_ball_get_size (SerializableGeeDualKeyMapTestBall* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 58 "SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 58 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_size;
#line 58 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 58 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6297 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_ball_set_size (SerializableGeeDualKeyMapTestBall* self,
                                                  const gchar* value)
{
#line 58 "SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 58 "SerializableGeeDualKeyMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_dual_key_map_test_ball_get_size (self)) != 0) {
#line 6308 "SerializableGeeDualKeyMapTest.c"
		gchar* _tmp0_;
#line 58 "SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 58 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (self->priv->_size);
#line 58 "SerializableGeeDualKeyMapTest.vala"
		self->priv->_size = _tmp0_;
#line 58 "SerializableGeeDualKeyMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_dual_key_map_test_ball_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_SIZE_PROPERTY]);
#line 6318 "SerializableGeeDualKeyMapTest.c"
	}
}

static SerializableGeeDualKeyMapTestBallFill*
serializable_gee_dual_key_map_test_ball_get_ballfill (SerializableGeeDualKeyMapTestBall* self)
{
	SerializableGeeDualKeyMapTestBallFill* result;
	SerializableGeeDualKeyMapTestBallFill* _tmp0_;
#line 59 "SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 59 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_ballfill;
#line 59 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 59 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6335 "SerializableGeeDualKeyMapTest.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 59 "SerializableGeeDualKeyMapTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 6343 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_ball_set_ballfill (SerializableGeeDualKeyMapTestBall* self,
                                                      SerializableGeeDualKeyMapTestBallFill* value)
{
#line 59 "SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 59 "SerializableGeeDualKeyMapTest.vala"
	if (serializable_gee_dual_key_map_test_ball_get_ballfill (self) != value) {
#line 6354 "SerializableGeeDualKeyMapTest.c"
		SerializableGeeDualKeyMapTestBallFill* _tmp0_;
#line 59 "SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 59 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (self->priv->_ballfill);
#line 59 "SerializableGeeDualKeyMapTest.vala"
		self->priv->_ballfill = _tmp0_;
#line 59 "SerializableGeeDualKeyMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_dual_key_map_test_ball_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_BALLFILL_PROPERTY]);
#line 6364 "SerializableGeeDualKeyMapTest.c"
	}
}

static gboolean
serializable_gee_dual_key_map_test_ball_dual_map_real_deserialize_proceed (GXmlSerializableDualKeyMap* base)
{
	SerializableGeeDualKeyMapTestBallDualMap * self;
	gboolean result = FALSE;
#line 65 "SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBallDualMap*) base;
#line 65 "SerializableGeeDualKeyMapTest.vala"
	result = FALSE;
#line 65 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6379 "SerializableGeeDualKeyMapTest.c"
}

static SerializableGeeDualKeyMapTestBallDualMap*
serializable_gee_dual_key_map_test_ball_dual_map_construct (GType object_type)
{
	SerializableGeeDualKeyMapTestBallDualMap * self = NULL;
#line 64 "SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBallDualMap*) gxml_serializable_dual_key_map_construct (object_type, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 64 "SerializableGeeDualKeyMapTest.vala"
	return self;
#line 6390 "SerializableGeeDualKeyMapTest.c"
}

static SerializableGeeDualKeyMapTestBallDualMap*
serializable_gee_dual_key_map_test_ball_dual_map_new (void)
{
#line 64 "SerializableGeeDualKeyMapTest.vala"
	return serializable_gee_dual_key_map_test_ball_dual_map_construct (SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_TYPE_DUAL_MAP);
#line 6398 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_ball_dual_map_class_init (SerializableGeeDualKeyMapTestBallDualMapClass * klass,
                                                             gpointer klass_data)
{
#line 64 "SerializableGeeDualKeyMapTest.vala"
	serializable_gee_dual_key_map_test_ball_dual_map_parent_class = g_type_class_peek_parent (klass);
#line 64 "SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableDualKeyMapClass *) klass)->deserialize_proceed = (gboolean (*) (GXmlSerializableDualKeyMap*)) serializable_gee_dual_key_map_test_ball_dual_map_real_deserialize_proceed;
#line 6409 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_ball_dual_map_instance_init (SerializableGeeDualKeyMapTestBallDualMap * self,
                                                                gpointer klass)
{
}

GType
serializable_gee_dual_key_map_test_ball_dual_map_get_type (void)
{
	static volatile gsize serializable_gee_dual_key_map_test_ball_dual_map_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_dual_key_map_test_ball_dual_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeDualKeyMapTestBallDualMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_dual_key_map_test_ball_dual_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeDualKeyMapTestBallDualMap), 0, (GInstanceInitFunc) serializable_gee_dual_key_map_test_ball_dual_map_instance_init, NULL };
		GType serializable_gee_dual_key_map_test_ball_dual_map_type_id;
		serializable_gee_dual_key_map_test_ball_dual_map_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_DUAL_KEY_MAP, "SerializableGeeDualKeyMapTestBallDualMap", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_dual_key_map_test_ball_dual_map_type_id__volatile, serializable_gee_dual_key_map_test_ball_dual_map_type_id);
	}
	return serializable_gee_dual_key_map_test_ball_dual_map_type_id__volatile;
}

static void
serializable_gee_dual_key_map_test_ball_class_init (SerializableGeeDualKeyMapTestBallClass * klass,
                                                    gpointer klass_data)
{
#line 55 "SerializableGeeDualKeyMapTest.vala"
	serializable_gee_dual_key_map_test_ball_parent_class = g_type_class_peek_parent (klass);
#line 55 "SerializableGeeDualKeyMapTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeDualKeyMapTestBall_private_offset);
#line 55 "SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_dual_key_map_test_ball_real_to_string;
#line 55 "SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_dual_key_map_test_ball_real_node_name;
#line 55 "SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_dual_key_map_test_ball_get_property;
#line 55 "SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_dual_key_map_test_ball_set_property;
#line 55 "SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_dual_key_map_test_ball_finalize;
#line 55 "SerializableGeeDualKeyMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_NAME_PROPERTY, serializable_gee_dual_key_map_test_ball_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 55 "SerializableGeeDualKeyMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_SIZE_PROPERTY, serializable_gee_dual_key_map_test_ball_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_SIZE_PROPERTY] = g_param_spec_string ("size", "size", "size", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 55 "SerializableGeeDualKeyMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_BALLFILL_PROPERTY, serializable_gee_dual_key_map_test_ball_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_BALLFILL_PROPERTY] = g_param_spec_object ("ballfill", "ballfill", "ballfill", SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL_FILL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6455 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_ball_gxml_serializable_map_dual_key_interface_init (GXmlSerializableMapDualKeyIface * iface,
                                                                                       gpointer iface_data)
{
#line 55 "SerializableGeeDualKeyMapTest.vala"
	serializable_gee_dual_key_map_test_ball_gxml_serializable_map_dual_key_parent_iface = g_type_interface_peek_parent (iface);
#line 55 "SerializableGeeDualKeyMapTest.vala"
	iface->get_map_primary_key = (gpointer (*) (GXmlSerializableMapDualKey*)) serializable_gee_dual_key_map_test_ball_real_get_map_primary_key;
#line 55 "SerializableGeeDualKeyMapTest.vala"
	iface->get_map_secondary_key = (gpointer (*) (GXmlSerializableMapDualKey*)) serializable_gee_dual_key_map_test_ball_real_get_map_secondary_key;
#line 6468 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_ball_instance_init (SerializableGeeDualKeyMapTestBall * self,
                                                       gpointer klass)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
#line 55 "SerializableGeeDualKeyMapTest.vala"
	self->priv = serializable_gee_dual_key_map_test_ball_get_instance_private (self);
#line 57 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = g_strdup ("Ball");
#line 57 "SerializableGeeDualKeyMapTest.vala"
	self->priv->_name = _tmp0_;
#line 58 "SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup ("medium");
#line 58 "SerializableGeeDualKeyMapTest.vala"
	self->priv->_size = _tmp1_;
#line 6487 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_ball_finalize (GObject * obj)
{
	SerializableGeeDualKeyMapTestBall * self;
#line 55 "SerializableGeeDualKeyMapTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL, SerializableGeeDualKeyMapTestBall);
#line 57 "SerializableGeeDualKeyMapTest.vala"
	_g_free0 (self->priv->_name);
#line 58 "SerializableGeeDualKeyMapTest.vala"
	_g_free0 (self->priv->_size);
#line 59 "SerializableGeeDualKeyMapTest.vala"
	_g_object_unref0 (self->priv->_ballfill);
#line 55 "SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (serializable_gee_dual_key_map_test_ball_parent_class)->finalize (obj);
#line 6504 "SerializableGeeDualKeyMapTest.c"
}

static GType
serializable_gee_dual_key_map_test_ball_get_type (void)
{
	static volatile gsize serializable_gee_dual_key_map_test_ball_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_dual_key_map_test_ball_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeDualKeyMapTestBallClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_dual_key_map_test_ball_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeDualKeyMapTestBall), 0, (GInstanceInitFunc) serializable_gee_dual_key_map_test_ball_instance_init, NULL };
		static const GInterfaceInfo gxml_serializable_map_dual_key_info = { (GInterfaceInitFunc) serializable_gee_dual_key_map_test_ball_gxml_serializable_map_dual_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType serializable_gee_dual_key_map_test_ball_type_id;
		serializable_gee_dual_key_map_test_ball_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeDualKeyMapTestBall", &g_define_type_info, 0);
		g_type_add_interface_static (serializable_gee_dual_key_map_test_ball_type_id, GXML_TYPE_SERIALIZABLE_MAP_DUAL_KEY, &gxml_serializable_map_dual_key_info);
		SerializableGeeDualKeyMapTestBall_private_offset = g_type_add_instance_private (serializable_gee_dual_key_map_test_ball_type_id, sizeof (SerializableGeeDualKeyMapTestBallPrivate));
		g_once_init_leave (&serializable_gee_dual_key_map_test_ball_type_id__volatile, serializable_gee_dual_key_map_test_ball_type_id);
	}
	return serializable_gee_dual_key_map_test_ball_type_id__volatile;
}

static void
_vala_serializable_gee_dual_key_map_test_ball_get_property (GObject * object,
                                                            guint property_id,
                                                            GValue * value,
                                                            GParamSpec * pspec)
{
	SerializableGeeDualKeyMapTestBall * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL, SerializableGeeDualKeyMapTestBall);
#line 55 "SerializableGeeDualKeyMapTest.vala"
	switch (property_id) {
#line 55 "SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_NAME_PROPERTY:
#line 55 "SerializableGeeDualKeyMapTest.vala"
		g_value_set_string (value, serializable_gee_dual_key_map_test_ball_get_name (self));
#line 55 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 55 "SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_SIZE_PROPERTY:
#line 55 "SerializableGeeDualKeyMapTest.vala"
		g_value_set_string (value, serializable_gee_dual_key_map_test_ball_get_size (self));
#line 55 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 55 "SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_BALLFILL_PROPERTY:
#line 55 "SerializableGeeDualKeyMapTest.vala"
		g_value_set_object (value, serializable_gee_dual_key_map_test_ball_get_ballfill (self));
#line 55 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 6551 "SerializableGeeDualKeyMapTest.c"
		default:
#line 55 "SerializableGeeDualKeyMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 55 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 6557 "SerializableGeeDualKeyMapTest.c"
	}
}

static void
_vala_serializable_gee_dual_key_map_test_ball_set_property (GObject * object,
                                                            guint property_id,
                                                            const GValue * value,
                                                            GParamSpec * pspec)
{
	SerializableGeeDualKeyMapTestBall * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BALL, SerializableGeeDualKeyMapTestBall);
#line 55 "SerializableGeeDualKeyMapTest.vala"
	switch (property_id) {
#line 55 "SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_NAME_PROPERTY:
#line 55 "SerializableGeeDualKeyMapTest.vala"
		serializable_gee_dual_key_map_test_ball_set_name (self, g_value_get_string (value));
#line 55 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 55 "SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_SIZE_PROPERTY:
#line 55 "SerializableGeeDualKeyMapTest.vala"
		serializable_gee_dual_key_map_test_ball_set_size (self, g_value_get_string (value));
#line 55 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 55 "SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_BALLFILL_PROPERTY:
#line 55 "SerializableGeeDualKeyMapTest.vala"
		serializable_gee_dual_key_map_test_ball_set_ballfill (self, g_value_get_object (value));
#line 55 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 6589 "SerializableGeeDualKeyMapTest.c"
		default:
#line 55 "SerializableGeeDualKeyMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 55 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 6595 "SerializableGeeDualKeyMapTest.c"
	}
}

static inline gpointer
serializable_gee_dual_key_map_test_small_bag_get_instance_private (SerializableGeeDualKeyMapTestSmallBag* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeDualKeyMapTestSmallBag_private_offset);
}

static gchar*
serializable_gee_dual_key_map_test_small_bag_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeDualKeyMapTestSmallBag * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 74 "SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestSmallBag*) base;
#line 74 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 74 "SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 74 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp1_;
#line 74 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6622 "SerializableGeeDualKeyMapTest.c"
}

static gchar*
serializable_gee_dual_key_map_test_small_bag_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeDualKeyMapTestSmallBag * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 75 "SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestSmallBag*) base;
#line 75 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = g_strdup ("SmallBag");
#line 75 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 75 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6639 "SerializableGeeDualKeyMapTest.c"
}

static gchar*
serializable_gee_dual_key_map_test_small_bag_real_get_map_primary_key (GXmlSerializableMapDualKey* base)
{
	SerializableGeeDualKeyMapTestSmallBag * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 76 "SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestSmallBag*) base;
#line 76 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_cash;
#line 76 "SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 76 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp1_;
#line 76 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6659 "SerializableGeeDualKeyMapTest.c"
}

static gchar*
serializable_gee_dual_key_map_test_small_bag_real_get_map_secondary_key (GXmlSerializableMapDualKey* base)
{
	SerializableGeeDualKeyMapTestSmallBag * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 77 "SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestSmallBag*) base;
#line 77 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 77 "SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 77 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp1_;
#line 77 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6679 "SerializableGeeDualKeyMapTest.c"
}

static SerializableGeeDualKeyMapTestSmallBag*
serializable_gee_dual_key_map_test_small_bag_construct (GType object_type)
{
	SerializableGeeDualKeyMapTestSmallBag * self = NULL;
#line 69 "SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestSmallBag*) gxml_serializable_object_model_construct (object_type);
#line 69 "SerializableGeeDualKeyMapTest.vala"
	return self;
#line 6690 "SerializableGeeDualKeyMapTest.c"
}

static SerializableGeeDualKeyMapTestSmallBag*
serializable_gee_dual_key_map_test_small_bag_new (void)
{
#line 69 "SerializableGeeDualKeyMapTest.vala"
	return serializable_gee_dual_key_map_test_small_bag_construct (SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_SMALL_BAG);
#line 6698 "SerializableGeeDualKeyMapTest.c"
}

static const gchar*
serializable_gee_dual_key_map_test_small_bag_get_name (SerializableGeeDualKeyMapTestSmallBag* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 71 "SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 71 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 71 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 71 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6714 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_small_bag_set_name (SerializableGeeDualKeyMapTestSmallBag* self,
                                                       const gchar* value)
{
#line 71 "SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 71 "SerializableGeeDualKeyMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_dual_key_map_test_small_bag_get_name (self)) != 0) {
#line 6725 "SerializableGeeDualKeyMapTest.c"
		gchar* _tmp0_;
#line 71 "SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 71 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (self->priv->_name);
#line 71 "SerializableGeeDualKeyMapTest.vala"
		self->priv->_name = _tmp0_;
#line 71 "SerializableGeeDualKeyMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_dual_key_map_test_small_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_NAME_PROPERTY]);
#line 6735 "SerializableGeeDualKeyMapTest.c"
	}
}

static const gchar*
serializable_gee_dual_key_map_test_small_bag_get_cash (SerializableGeeDualKeyMapTestSmallBag* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 72 "SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 72 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_cash;
#line 72 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 72 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6752 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_small_bag_set_cash (SerializableGeeDualKeyMapTestSmallBag* self,
                                                       const gchar* value)
{
#line 72 "SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 72 "SerializableGeeDualKeyMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_dual_key_map_test_small_bag_get_cash (self)) != 0) {
#line 6763 "SerializableGeeDualKeyMapTest.c"
		gchar* _tmp0_;
#line 72 "SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 72 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (self->priv->_cash);
#line 72 "SerializableGeeDualKeyMapTest.vala"
		self->priv->_cash = _tmp0_;
#line 72 "SerializableGeeDualKeyMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_dual_key_map_test_small_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_CASH_PROPERTY]);
#line 6773 "SerializableGeeDualKeyMapTest.c"
	}
}

static SerializableGeeDualKeyMapTestBallDualMap*
serializable_gee_dual_key_map_test_small_bag_get_balls (SerializableGeeDualKeyMapTestSmallBag* self)
{
	SerializableGeeDualKeyMapTestBallDualMap* result;
	SerializableGeeDualKeyMapTestBallDualMap* _tmp0_;
#line 73 "SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 73 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_balls;
#line 73 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 73 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6790 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_small_bag_set_balls (SerializableGeeDualKeyMapTestSmallBag* self,
                                                        SerializableGeeDualKeyMapTestBallDualMap* value)
{
#line 73 "SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 73 "SerializableGeeDualKeyMapTest.vala"
	if (serializable_gee_dual_key_map_test_small_bag_get_balls (self) != value) {
#line 6801 "SerializableGeeDualKeyMapTest.c"
		SerializableGeeDualKeyMapTestBallDualMap* _tmp0_;
#line 73 "SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 73 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (self->priv->_balls);
#line 73 "SerializableGeeDualKeyMapTest.vala"
		self->priv->_balls = _tmp0_;
#line 73 "SerializableGeeDualKeyMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_dual_key_map_test_small_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_BALLS_PROPERTY]);
#line 6811 "SerializableGeeDualKeyMapTest.c"
	}
}

static gboolean
serializable_gee_dual_key_map_test_small_bag_dual_map_real_deserialize_proceed (GXmlSerializableDualKeyMap* base)
{
	SerializableGeeDualKeyMapTestSmallBagDualMap * self;
	gboolean result = FALSE;
#line 79 "SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestSmallBagDualMap*) base;
#line 79 "SerializableGeeDualKeyMapTest.vala"
	result = FALSE;
#line 79 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 6826 "SerializableGeeDualKeyMapTest.c"
}

static SerializableGeeDualKeyMapTestSmallBagDualMap*
serializable_gee_dual_key_map_test_small_bag_dual_map_construct (GType object_type)
{
	SerializableGeeDualKeyMapTestSmallBagDualMap * self = NULL;
#line 78 "SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestSmallBagDualMap*) gxml_serializable_dual_key_map_construct (object_type, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_SMALL_BAG, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 78 "SerializableGeeDualKeyMapTest.vala"
	return self;
#line 6837 "SerializableGeeDualKeyMapTest.c"
}

static SerializableGeeDualKeyMapTestSmallBagDualMap*
serializable_gee_dual_key_map_test_small_bag_dual_map_new (void)
{
#line 78 "SerializableGeeDualKeyMapTest.vala"
	return serializable_gee_dual_key_map_test_small_bag_dual_map_construct (SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_TYPE_DUAL_MAP);
#line 6845 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_small_bag_dual_map_class_init (SerializableGeeDualKeyMapTestSmallBagDualMapClass * klass,
                                                                  gpointer klass_data)
{
#line 78 "SerializableGeeDualKeyMapTest.vala"
	serializable_gee_dual_key_map_test_small_bag_dual_map_parent_class = g_type_class_peek_parent (klass);
#line 78 "SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableDualKeyMapClass *) klass)->deserialize_proceed = (gboolean (*) (GXmlSerializableDualKeyMap*)) serializable_gee_dual_key_map_test_small_bag_dual_map_real_deserialize_proceed;
#line 6856 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_small_bag_dual_map_instance_init (SerializableGeeDualKeyMapTestSmallBagDualMap * self,
                                                                     gpointer klass)
{
}

GType
serializable_gee_dual_key_map_test_small_bag_dual_map_get_type (void)
{
	static volatile gsize serializable_gee_dual_key_map_test_small_bag_dual_map_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_dual_key_map_test_small_bag_dual_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeDualKeyMapTestSmallBagDualMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_dual_key_map_test_small_bag_dual_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeDualKeyMapTestSmallBagDualMap), 0, (GInstanceInitFunc) serializable_gee_dual_key_map_test_small_bag_dual_map_instance_init, NULL };
		GType serializable_gee_dual_key_map_test_small_bag_dual_map_type_id;
		serializable_gee_dual_key_map_test_small_bag_dual_map_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_DUAL_KEY_MAP, "SerializableGeeDualKeyMapTestSmallBagDualMap", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_dual_key_map_test_small_bag_dual_map_type_id__volatile, serializable_gee_dual_key_map_test_small_bag_dual_map_type_id);
	}
	return serializable_gee_dual_key_map_test_small_bag_dual_map_type_id__volatile;
}

static void
serializable_gee_dual_key_map_test_small_bag_class_init (SerializableGeeDualKeyMapTestSmallBagClass * klass,
                                                         gpointer klass_data)
{
#line 69 "SerializableGeeDualKeyMapTest.vala"
	serializable_gee_dual_key_map_test_small_bag_parent_class = g_type_class_peek_parent (klass);
#line 69 "SerializableGeeDualKeyMapTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeDualKeyMapTestSmallBag_private_offset);
#line 69 "SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_dual_key_map_test_small_bag_real_to_string;
#line 69 "SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_dual_key_map_test_small_bag_real_node_name;
#line 69 "SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_dual_key_map_test_small_bag_get_property;
#line 69 "SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_dual_key_map_test_small_bag_set_property;
#line 69 "SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_dual_key_map_test_small_bag_finalize;
#line 69 "SerializableGeeDualKeyMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_NAME_PROPERTY, serializable_gee_dual_key_map_test_small_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 69 "SerializableGeeDualKeyMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_CASH_PROPERTY, serializable_gee_dual_key_map_test_small_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_CASH_PROPERTY] = g_param_spec_string ("cash", "cash", "cash", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 69 "SerializableGeeDualKeyMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_BALLS_PROPERTY, serializable_gee_dual_key_map_test_small_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_BALLS_PROPERTY] = g_param_spec_object ("balls", "balls", "balls", SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BALL_TYPE_DUAL_MAP, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6902 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_small_bag_gxml_serializable_map_dual_key_interface_init (GXmlSerializableMapDualKeyIface * iface,
                                                                                            gpointer iface_data)
{
#line 69 "SerializableGeeDualKeyMapTest.vala"
	serializable_gee_dual_key_map_test_small_bag_gxml_serializable_map_dual_key_parent_iface = g_type_interface_peek_parent (iface);
#line 69 "SerializableGeeDualKeyMapTest.vala"
	iface->get_map_primary_key = (gpointer (*) (GXmlSerializableMapDualKey*)) serializable_gee_dual_key_map_test_small_bag_real_get_map_primary_key;
#line 69 "SerializableGeeDualKeyMapTest.vala"
	iface->get_map_secondary_key = (gpointer (*) (GXmlSerializableMapDualKey*)) serializable_gee_dual_key_map_test_small_bag_real_get_map_secondary_key;
#line 6915 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_small_bag_instance_init (SerializableGeeDualKeyMapTestSmallBag * self,
                                                            gpointer klass)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	SerializableGeeDualKeyMapTestBallDualMap* _tmp2_;
#line 69 "SerializableGeeDualKeyMapTest.vala"
	self->priv = serializable_gee_dual_key_map_test_small_bag_get_instance_private (self);
#line 71 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = g_strdup ("SmallBag");
#line 71 "SerializableGeeDualKeyMapTest.vala"
	self->priv->_name = _tmp0_;
#line 72 "SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup ("money");
#line 72 "SerializableGeeDualKeyMapTest.vala"
	self->priv->_cash = _tmp1_;
#line 73 "SerializableGeeDualKeyMapTest.vala"
	_tmp2_ = serializable_gee_dual_key_map_test_ball_dual_map_new ();
#line 73 "SerializableGeeDualKeyMapTest.vala"
	self->priv->_balls = _tmp2_;
#line 6939 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_small_bag_finalize (GObject * obj)
{
	SerializableGeeDualKeyMapTestSmallBag * self;
#line 69 "SerializableGeeDualKeyMapTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeDualKeyMapTestSmallBag);
#line 71 "SerializableGeeDualKeyMapTest.vala"
	_g_free0 (self->priv->_name);
#line 72 "SerializableGeeDualKeyMapTest.vala"
	_g_free0 (self->priv->_cash);
#line 73 "SerializableGeeDualKeyMapTest.vala"
	_g_object_unref0 (self->priv->_balls);
#line 69 "SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (serializable_gee_dual_key_map_test_small_bag_parent_class)->finalize (obj);
#line 6956 "SerializableGeeDualKeyMapTest.c"
}

static GType
serializable_gee_dual_key_map_test_small_bag_get_type (void)
{
	static volatile gsize serializable_gee_dual_key_map_test_small_bag_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_dual_key_map_test_small_bag_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeDualKeyMapTestSmallBagClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_dual_key_map_test_small_bag_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeDualKeyMapTestSmallBag), 0, (GInstanceInitFunc) serializable_gee_dual_key_map_test_small_bag_instance_init, NULL };
		static const GInterfaceInfo gxml_serializable_map_dual_key_info = { (GInterfaceInitFunc) serializable_gee_dual_key_map_test_small_bag_gxml_serializable_map_dual_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType serializable_gee_dual_key_map_test_small_bag_type_id;
		serializable_gee_dual_key_map_test_small_bag_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeDualKeyMapTestSmallBag", &g_define_type_info, 0);
		g_type_add_interface_static (serializable_gee_dual_key_map_test_small_bag_type_id, GXML_TYPE_SERIALIZABLE_MAP_DUAL_KEY, &gxml_serializable_map_dual_key_info);
		SerializableGeeDualKeyMapTestSmallBag_private_offset = g_type_add_instance_private (serializable_gee_dual_key_map_test_small_bag_type_id, sizeof (SerializableGeeDualKeyMapTestSmallBagPrivate));
		g_once_init_leave (&serializable_gee_dual_key_map_test_small_bag_type_id__volatile, serializable_gee_dual_key_map_test_small_bag_type_id);
	}
	return serializable_gee_dual_key_map_test_small_bag_type_id__volatile;
}

static void
_vala_serializable_gee_dual_key_map_test_small_bag_get_property (GObject * object,
                                                                 guint property_id,
                                                                 GValue * value,
                                                                 GParamSpec * pspec)
{
	SerializableGeeDualKeyMapTestSmallBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeDualKeyMapTestSmallBag);
#line 69 "SerializableGeeDualKeyMapTest.vala"
	switch (property_id) {
#line 69 "SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_NAME_PROPERTY:
#line 69 "SerializableGeeDualKeyMapTest.vala"
		g_value_set_string (value, serializable_gee_dual_key_map_test_small_bag_get_name (self));
#line 69 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 69 "SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_CASH_PROPERTY:
#line 69 "SerializableGeeDualKeyMapTest.vala"
		g_value_set_string (value, serializable_gee_dual_key_map_test_small_bag_get_cash (self));
#line 69 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 69 "SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_BALLS_PROPERTY:
#line 69 "SerializableGeeDualKeyMapTest.vala"
		g_value_set_object (value, serializable_gee_dual_key_map_test_small_bag_get_balls (self));
#line 69 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 7003 "SerializableGeeDualKeyMapTest.c"
		default:
#line 69 "SerializableGeeDualKeyMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 69 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 7009 "SerializableGeeDualKeyMapTest.c"
	}
}

static void
_vala_serializable_gee_dual_key_map_test_small_bag_set_property (GObject * object,
                                                                 guint property_id,
                                                                 const GValue * value,
                                                                 GParamSpec * pspec)
{
	SerializableGeeDualKeyMapTestSmallBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeDualKeyMapTestSmallBag);
#line 69 "SerializableGeeDualKeyMapTest.vala"
	switch (property_id) {
#line 69 "SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_NAME_PROPERTY:
#line 69 "SerializableGeeDualKeyMapTest.vala"
		serializable_gee_dual_key_map_test_small_bag_set_name (self, g_value_get_string (value));
#line 69 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 69 "SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_CASH_PROPERTY:
#line 69 "SerializableGeeDualKeyMapTest.vala"
		serializable_gee_dual_key_map_test_small_bag_set_cash (self, g_value_get_string (value));
#line 69 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 69 "SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_BALLS_PROPERTY:
#line 69 "SerializableGeeDualKeyMapTest.vala"
		serializable_gee_dual_key_map_test_small_bag_set_balls (self, g_value_get_object (value));
#line 69 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 7041 "SerializableGeeDualKeyMapTest.c"
		default:
#line 69 "SerializableGeeDualKeyMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 69 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 7047 "SerializableGeeDualKeyMapTest.c"
	}
}

static inline gpointer
serializable_gee_dual_key_map_test_big_bag_get_instance_private (SerializableGeeDualKeyMapTestBigBag* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeDualKeyMapTestBigBag_private_offset);
}

static gchar*
serializable_gee_dual_key_map_test_big_bag_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeDualKeyMapTestBigBag * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 87 "SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBigBag*) base;
#line 87 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 87 "SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 87 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp1_;
#line 87 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 7074 "SerializableGeeDualKeyMapTest.c"
}

static gchar*
serializable_gee_dual_key_map_test_big_bag_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeDualKeyMapTestBigBag * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 88 "SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBigBag*) base;
#line 88 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = g_strdup ("BigBag");
#line 88 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 88 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 7091 "SerializableGeeDualKeyMapTest.c"
}

static SerializableGeeDualKeyMapTestBigBag*
serializable_gee_dual_key_map_test_big_bag_construct (GType object_type)
{
	SerializableGeeDualKeyMapTestBigBag * self = NULL;
#line 83 "SerializableGeeDualKeyMapTest.vala"
	self = (SerializableGeeDualKeyMapTestBigBag*) gxml_serializable_object_model_construct (object_type);
#line 83 "SerializableGeeDualKeyMapTest.vala"
	return self;
#line 7102 "SerializableGeeDualKeyMapTest.c"
}

static SerializableGeeDualKeyMapTestBigBag*
serializable_gee_dual_key_map_test_big_bag_new (void)
{
#line 83 "SerializableGeeDualKeyMapTest.vala"
	return serializable_gee_dual_key_map_test_big_bag_construct (SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BIG_BAG);
#line 7110 "SerializableGeeDualKeyMapTest.c"
}

static const gchar*
serializable_gee_dual_key_map_test_big_bag_get_name (SerializableGeeDualKeyMapTestBigBag* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 85 "SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 85 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 85 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 85 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 7126 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_big_bag_set_name (SerializableGeeDualKeyMapTestBigBag* self,
                                                     const gchar* value)
{
#line 85 "SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 85 "SerializableGeeDualKeyMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_dual_key_map_test_big_bag_get_name (self)) != 0) {
#line 7137 "SerializableGeeDualKeyMapTest.c"
		gchar* _tmp0_;
#line 85 "SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 85 "SerializableGeeDualKeyMapTest.vala"
		_g_free0 (self->priv->_name);
#line 85 "SerializableGeeDualKeyMapTest.vala"
		self->priv->_name = _tmp0_;
#line 85 "SerializableGeeDualKeyMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_dual_key_map_test_big_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_NAME_PROPERTY]);
#line 7147 "SerializableGeeDualKeyMapTest.c"
	}
}

static SerializableGeeDualKeyMapTestSmallBagDualMap*
serializable_gee_dual_key_map_test_big_bag_get_bags (SerializableGeeDualKeyMapTestBigBag* self)
{
	SerializableGeeDualKeyMapTestSmallBagDualMap* result;
	SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp0_;
#line 86 "SerializableGeeDualKeyMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 86 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = self->priv->_bags;
#line 86 "SerializableGeeDualKeyMapTest.vala"
	result = _tmp0_;
#line 86 "SerializableGeeDualKeyMapTest.vala"
	return result;
#line 7164 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_big_bag_set_bags (SerializableGeeDualKeyMapTestBigBag* self,
                                                     SerializableGeeDualKeyMapTestSmallBagDualMap* value)
{
#line 86 "SerializableGeeDualKeyMapTest.vala"
	g_return_if_fail (self != NULL);
#line 86 "SerializableGeeDualKeyMapTest.vala"
	if (serializable_gee_dual_key_map_test_big_bag_get_bags (self) != value) {
#line 7175 "SerializableGeeDualKeyMapTest.c"
		SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp0_;
#line 86 "SerializableGeeDualKeyMapTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 86 "SerializableGeeDualKeyMapTest.vala"
		_g_object_unref0 (self->priv->_bags);
#line 86 "SerializableGeeDualKeyMapTest.vala"
		self->priv->_bags = _tmp0_;
#line 86 "SerializableGeeDualKeyMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_dual_key_map_test_big_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_BAGS_PROPERTY]);
#line 7185 "SerializableGeeDualKeyMapTest.c"
	}
}

static void
serializable_gee_dual_key_map_test_big_bag_class_init (SerializableGeeDualKeyMapTestBigBagClass * klass,
                                                       gpointer klass_data)
{
#line 83 "SerializableGeeDualKeyMapTest.vala"
	serializable_gee_dual_key_map_test_big_bag_parent_class = g_type_class_peek_parent (klass);
#line 83 "SerializableGeeDualKeyMapTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeDualKeyMapTestBigBag_private_offset);
#line 83 "SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_dual_key_map_test_big_bag_real_to_string;
#line 83 "SerializableGeeDualKeyMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_dual_key_map_test_big_bag_real_node_name;
#line 83 "SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_dual_key_map_test_big_bag_get_property;
#line 83 "SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_dual_key_map_test_big_bag_set_property;
#line 83 "SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_dual_key_map_test_big_bag_finalize;
#line 83 "SerializableGeeDualKeyMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_NAME_PROPERTY, serializable_gee_dual_key_map_test_big_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 83 "SerializableGeeDualKeyMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_BAGS_PROPERTY, serializable_gee_dual_key_map_test_big_bag_properties[SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_BAGS_PROPERTY] = g_param_spec_object ("bags", "bags", "bags", SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_SMALL_BAG_TYPE_DUAL_MAP, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 7211 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_big_bag_instance_init (SerializableGeeDualKeyMapTestBigBag * self,
                                                          gpointer klass)
{
	gchar* _tmp0_;
	SerializableGeeDualKeyMapTestSmallBagDualMap* _tmp1_;
#line 83 "SerializableGeeDualKeyMapTest.vala"
	self->priv = serializable_gee_dual_key_map_test_big_bag_get_instance_private (self);
#line 85 "SerializableGeeDualKeyMapTest.vala"
	_tmp0_ = g_strdup ("ball");
#line 85 "SerializableGeeDualKeyMapTest.vala"
	self->priv->_name = _tmp0_;
#line 86 "SerializableGeeDualKeyMapTest.vala"
	_tmp1_ = serializable_gee_dual_key_map_test_small_bag_dual_map_new ();
#line 86 "SerializableGeeDualKeyMapTest.vala"
	self->priv->_bags = _tmp1_;
#line 7230 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_big_bag_finalize (GObject * obj)
{
	SerializableGeeDualKeyMapTestBigBag * self;
#line 83 "SerializableGeeDualKeyMapTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BIG_BAG, SerializableGeeDualKeyMapTestBigBag);
#line 85 "SerializableGeeDualKeyMapTest.vala"
	_g_free0 (self->priv->_name);
#line 86 "SerializableGeeDualKeyMapTest.vala"
	_g_object_unref0 (self->priv->_bags);
#line 83 "SerializableGeeDualKeyMapTest.vala"
	G_OBJECT_CLASS (serializable_gee_dual_key_map_test_big_bag_parent_class)->finalize (obj);
#line 7245 "SerializableGeeDualKeyMapTest.c"
}

static GType
serializable_gee_dual_key_map_test_big_bag_get_type (void)
{
	static volatile gsize serializable_gee_dual_key_map_test_big_bag_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_dual_key_map_test_big_bag_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeDualKeyMapTestBigBagClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_dual_key_map_test_big_bag_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeDualKeyMapTestBigBag), 0, (GInstanceInitFunc) serializable_gee_dual_key_map_test_big_bag_instance_init, NULL };
		GType serializable_gee_dual_key_map_test_big_bag_type_id;
		serializable_gee_dual_key_map_test_big_bag_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeDualKeyMapTestBigBag", &g_define_type_info, 0);
		SerializableGeeDualKeyMapTestBigBag_private_offset = g_type_add_instance_private (serializable_gee_dual_key_map_test_big_bag_type_id, sizeof (SerializableGeeDualKeyMapTestBigBagPrivate));
		g_once_init_leave (&serializable_gee_dual_key_map_test_big_bag_type_id__volatile, serializable_gee_dual_key_map_test_big_bag_type_id);
	}
	return serializable_gee_dual_key_map_test_big_bag_type_id__volatile;
}

static void
_vala_serializable_gee_dual_key_map_test_big_bag_get_property (GObject * object,
                                                               guint property_id,
                                                               GValue * value,
                                                               GParamSpec * pspec)
{
	SerializableGeeDualKeyMapTestBigBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BIG_BAG, SerializableGeeDualKeyMapTestBigBag);
#line 83 "SerializableGeeDualKeyMapTest.vala"
	switch (property_id) {
#line 83 "SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_NAME_PROPERTY:
#line 83 "SerializableGeeDualKeyMapTest.vala"
		g_value_set_string (value, serializable_gee_dual_key_map_test_big_bag_get_name (self));
#line 83 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 83 "SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_BAGS_PROPERTY:
#line 83 "SerializableGeeDualKeyMapTest.vala"
		g_value_set_object (value, serializable_gee_dual_key_map_test_big_bag_get_bags (self));
#line 83 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 7284 "SerializableGeeDualKeyMapTest.c"
		default:
#line 83 "SerializableGeeDualKeyMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 83 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 7290 "SerializableGeeDualKeyMapTest.c"
	}
}

static void
_vala_serializable_gee_dual_key_map_test_big_bag_set_property (GObject * object,
                                                               guint property_id,
                                                               const GValue * value,
                                                               GParamSpec * pspec)
{
	SerializableGeeDualKeyMapTestBigBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_TYPE_BIG_BAG, SerializableGeeDualKeyMapTestBigBag);
#line 83 "SerializableGeeDualKeyMapTest.vala"
	switch (property_id) {
#line 83 "SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_NAME_PROPERTY:
#line 83 "SerializableGeeDualKeyMapTest.vala"
		serializable_gee_dual_key_map_test_big_bag_set_name (self, g_value_get_string (value));
#line 83 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 83 "SerializableGeeDualKeyMapTest.vala"
		case SERIALIZABLE_GEE_DUAL_KEY_MAP_TEST_BIG_BAG_BAGS_PROPERTY:
#line 83 "SerializableGeeDualKeyMapTest.vala"
		serializable_gee_dual_key_map_test_big_bag_set_bags (self, g_value_get_object (value));
#line 83 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 7316 "SerializableGeeDualKeyMapTest.c"
		default:
#line 83 "SerializableGeeDualKeyMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 83 "SerializableGeeDualKeyMapTest.vala"
		break;
#line 7322 "SerializableGeeDualKeyMapTest.c"
	}
}

static void
serializable_gee_dual_key_map_test_class_init (SerializableGeeDualKeyMapTestClass * klass,
                                               gpointer klass_data)
{
#line 43 "SerializableGeeDualKeyMapTest.vala"
	serializable_gee_dual_key_map_test_parent_class = g_type_class_peek_parent (klass);
#line 7332 "SerializableGeeDualKeyMapTest.c"
}

static void
serializable_gee_dual_key_map_test_instance_init (SerializableGeeDualKeyMapTest * self,
                                                  gpointer klass)
{
}

GType
serializable_gee_dual_key_map_test_get_type (void)
{
	static volatile gsize serializable_gee_dual_key_map_test_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_dual_key_map_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeDualKeyMapTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_dual_key_map_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeDualKeyMapTest), 0, (GInstanceInitFunc) serializable_gee_dual_key_map_test_instance_init, NULL };
		GType serializable_gee_dual_key_map_test_type_id;
		serializable_gee_dual_key_map_test_type_id = g_type_register_static (TYPE_GXML_TEST, "SerializableGeeDualKeyMapTest", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_dual_key_map_test_type_id__volatile, serializable_gee_dual_key_map_test_type_id);
	}
	return serializable_gee_dual_key_map_test_type_id__volatile;
}

