/* SerializableObjectModelTest.c generated by valac 0.44.3, the Vala compiler
 * generated from SerializableObjectModelTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */

#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gxml/gxml.h>
#include <glib-object.h>
#include <float.h>
#include <math.h>
#include <gee.h>
#include <stdio.h>

#define TYPE_OBJECT_MODEL (object_model_get_type ())
#define OBJECT_MODEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_OBJECT_MODEL, ObjectModel))
#define OBJECT_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_OBJECT_MODEL, ObjectModelClass))
#define IS_OBJECT_MODEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_OBJECT_MODEL))
#define IS_OBJECT_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_OBJECT_MODEL))
#define OBJECT_MODEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_OBJECT_MODEL, ObjectModelClass))

typedef struct _ObjectModel ObjectModel;
typedef struct _ObjectModelClass ObjectModelClass;
typedef struct _ObjectModelPrivate ObjectModelPrivate;
enum  {
	OBJECT_MODEL_0_PROPERTY,
	OBJECT_MODEL_NUM_PROPERTIES
};
static GParamSpec* object_model_properties[OBJECT_MODEL_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_param_spec_unref0(var) ((var == NULL) ? NULL : (var = (g_param_spec_unref (var), NULL)))

#define TYPE_COMPUTER (computer_get_type ())
#define COMPUTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COMPUTER, Computer))
#define COMPUTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COMPUTER, ComputerClass))
#define IS_COMPUTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COMPUTER))
#define IS_COMPUTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COMPUTER))
#define COMPUTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COMPUTER, ComputerClass))

typedef struct _Computer Computer;
typedef struct _ComputerClass ComputerClass;
typedef struct _ComputerPrivate ComputerPrivate;
enum  {
	COMPUTER_0_PROPERTY,
	COMPUTER_MANUFACTURER_PROPERTY,
	COMPUTER_MODEL_PROPERTY,
	COMPUTER_CORES_PROPERTY,
	COMPUTER_GHZ_PROPERTY,
	COMPUTER_QUANTITY_PROPERTY,
	COMPUTER_NUM_PROPERTIES
};
static GParamSpec* computer_properties[COMPUTER_NUM_PROPERTIES];

#define TYPE_MANUAL (manual_get_type ())
#define MANUAL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MANUAL, Manual))
#define MANUAL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MANUAL, ManualClass))
#define IS_MANUAL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MANUAL))
#define IS_MANUAL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MANUAL))
#define MANUAL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MANUAL, ManualClass))

typedef struct _Manual Manual;
typedef struct _ManualClass ManualClass;
typedef struct _ManualPrivate ManualPrivate;
enum  {
	MANUAL_0_PROPERTY,
	MANUAL_DOCUMENT_PROPERTY,
	MANUAL_PAGES_PROPERTY,
	MANUAL_NUM_PROPERTIES
};
static GParamSpec* manual_properties[MANUAL_NUM_PROPERTIES];

#define TYPE_PACKAGE (package_get_type ())
#define PACKAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PACKAGE, Package))
#define PACKAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PACKAGE, PackageClass))
#define IS_PACKAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PACKAGE))
#define IS_PACKAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PACKAGE))
#define PACKAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PACKAGE, PackageClass))

typedef struct _Package Package;
typedef struct _PackageClass PackageClass;
typedef struct _PackagePrivate PackagePrivate;
enum  {
	PACKAGE_0_PROPERTY,
	PACKAGE_COMPUTER_PROPERTY,
	PACKAGE_MANUAL_PROPERTY,
	PACKAGE_SOURCE_PROPERTY,
	PACKAGE_DESTINY_PROPERTY,
	PACKAGE_TAGS_PROPERTY,
	PACKAGE_NUM_PROPERTIES
};
static GParamSpec* package_properties[PACKAGE_NUM_PROPERTIES];
#define _g_array_unref0(var) ((var == NULL) ? NULL : (var = (g_array_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define TYPE_MONITOR (monitor_get_type ())
#define MONITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MONITOR, Monitor))
#define MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MONITOR, MonitorClass))
#define IS_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MONITOR))
#define IS_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MONITOR))
#define MONITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MONITOR, MonitorClass))

typedef struct _Monitor Monitor;
typedef struct _MonitorClass MonitorClass;
typedef struct _MonitorPrivate MonitorPrivate;
enum  {
	MONITOR_0_PROPERTY,
	MONITOR_RESOLUTION_PROPERTY,
	MONITOR_AC_POWER_PROPERTY,
	MONITOR_DC_POWER_PROPERTY,
	MONITOR_NUM_PROPERTIES
};
static GParamSpec* monitor_properties[MONITOR_NUM_PROPERTIES];

#define TYPE_CPU (cpu_get_type ())
#define CPU(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CPU, Cpu))
#define CPU_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CPU, CpuClass))
#define IS_CPU(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CPU))
#define IS_CPU_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CPU))
#define CPU_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CPU, CpuClass))

typedef struct _Cpu Cpu;
typedef struct _CpuClass CpuClass;
typedef struct _CpuPrivate CpuPrivate;
enum  {
	CPU_0_PROPERTY,
	CPU_GHZ_PROPERTY,
	CPU_PILES_PROPERTY,
	CPU_NUM_PROPERTIES
};
static GParamSpec* cpu_properties[CPU_NUM_PROPERTIES];

#define TYPE_NODE_NAME (node_name_get_type ())
#define NODE_NAME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_NODE_NAME, NodeName))
#define NODE_NAME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_NODE_NAME, NodeNameClass))
#define IS_NODE_NAME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_NODE_NAME))
#define IS_NODE_NAME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_NODE_NAME))
#define NODE_NAME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_NODE_NAME, NodeNameClass))

typedef struct _NodeName NodeName;
typedef struct _NodeNameClass NodeNameClass;
typedef struct _NodeNamePrivate NodeNamePrivate;
enum  {
	NODE_NAME_0_PROPERTY,
	NODE_NAME_INVALID_PROPERTY,
	NODE_NAME_NUM_PROPERTIES
};
static GParamSpec* node_name_properties[NODE_NAME_NUM_PROPERTIES];

#define TYPE_CONFIGURATION (configuration_get_type ())
#define CONFIGURATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONFIGURATION, Configuration))
#define CONFIGURATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONFIGURATION, ConfigurationClass))
#define IS_CONFIGURATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONFIGURATION))
#define IS_CONFIGURATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONFIGURATION))
#define CONFIGURATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONFIGURATION, ConfigurationClass))

typedef struct _Configuration Configuration;
typedef struct _ConfigurationClass ConfigurationClass;
typedef struct _ConfigurationPrivate ConfigurationPrivate;
enum  {
	CONFIGURATION_0_PROPERTY,
	CONFIGURATION_INVALID_PROPERTY,
	CONFIGURATION_DEVICE_PROPERTY,
	CONFIGURATION_NUM_PROPERTIES
};
static GParamSpec* configuration_properties[CONFIGURATION_NUM_PROPERTIES];
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))

#define TYPE_FAKE_SERIALIZABLE (fake_serializable_get_type ())
#define FAKE_SERIALIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FAKE_SERIALIZABLE, FakeSerializable))
#define FAKE_SERIALIZABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FAKE_SERIALIZABLE, FakeSerializableClass))
#define IS_FAKE_SERIALIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FAKE_SERIALIZABLE))
#define IS_FAKE_SERIALIZABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FAKE_SERIALIZABLE))
#define FAKE_SERIALIZABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FAKE_SERIALIZABLE, FakeSerializableClass))

typedef struct _FakeSerializable FakeSerializable;
typedef struct _FakeSerializableClass FakeSerializableClass;
typedef struct _FakeSerializablePrivate FakeSerializablePrivate;
enum  {
	FAKE_SERIALIZABLE_0_PROPERTY,
	FAKE_SERIALIZABLE_NONE_PROPERTY,
	FAKE_SERIALIZABLE_NUM_PROPERTIES
};
static GParamSpec* fake_serializable_properties[FAKE_SERIALIZABLE_NUM_PROPERTIES];

#define TYPE_UNKNOWN_ATTRIBUTE (unknown_attribute_get_type ())
#define UNKNOWN_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_UNKNOWN_ATTRIBUTE, UnknownAttribute))
#define UNKNOWN_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_UNKNOWN_ATTRIBUTE, UnknownAttributeClass))
#define IS_UNKNOWN_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_UNKNOWN_ATTRIBUTE))
#define IS_UNKNOWN_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_UNKNOWN_ATTRIBUTE))
#define UNKNOWN_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_UNKNOWN_ATTRIBUTE, UnknownAttributeClass))

typedef struct _UnknownAttribute UnknownAttribute;
typedef struct _UnknownAttributeClass UnknownAttributeClass;
typedef struct _UnknownAttributePrivate UnknownAttributePrivate;
enum  {
	UNKNOWN_ATTRIBUTE_0_PROPERTY,
	UNKNOWN_ATTRIBUTE_NAME_PROPERTY,
	UNKNOWN_ATTRIBUTE_ARRAY_PROPERTY,
	UNKNOWN_ATTRIBUTE_FAKE_PROPERTY,
	UNKNOWN_ATTRIBUTE_NUM_PROPERTIES
};
static GParamSpec* unknown_attribute_properties[UNKNOWN_ATTRIBUTE_NUM_PROPERTIES];

#define TYPE_NAME_SPACE (name_space_get_type ())
#define NAME_SPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_NAME_SPACE, NameSpace))
#define NAME_SPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_NAME_SPACE, NameSpaceClass))
#define IS_NAME_SPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_NAME_SPACE))
#define IS_NAME_SPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_NAME_SPACE))
#define NAME_SPACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_NAME_SPACE, NameSpaceClass))

typedef struct _NameSpace NameSpace;
typedef struct _NameSpaceClass NameSpaceClass;
typedef struct _NameSpacePrivate NameSpacePrivate;
enum  {
	NAME_SPACE_0_PROPERTY,
	NAME_SPACE_NUM_PROPERTIES
};
static GParamSpec* name_space_properties[NAME_SPACE_NUM_PROPERTIES];

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_SERIALIZABLE_OBJECT_MODEL_TEST (serializable_object_model_test_get_type ())
#define SERIALIZABLE_OBJECT_MODEL_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_OBJECT_MODEL_TEST, SerializableObjectModelTest))
#define SERIALIZABLE_OBJECT_MODEL_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_OBJECT_MODEL_TEST, SerializableObjectModelTestClass))
#define IS_SERIALIZABLE_OBJECT_MODEL_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_OBJECT_MODEL_TEST))
#define IS_SERIALIZABLE_OBJECT_MODEL_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_OBJECT_MODEL_TEST))
#define SERIALIZABLE_OBJECT_MODEL_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_OBJECT_MODEL_TEST, SerializableObjectModelTestClass))

typedef struct _SerializableObjectModelTest SerializableObjectModelTest;
typedef struct _SerializableObjectModelTestClass SerializableObjectModelTestClass;
typedef struct _SerializableObjectModelTestPrivate SerializableObjectModelTestPrivate;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _ObjectModel {
	GXmlSerializableObjectModel parent_instance;
	ObjectModelPrivate * priv;
};

struct _ObjectModelClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _Computer {
	ObjectModel parent_instance;
	ComputerPrivate * priv;
};

struct _ComputerClass {
	ObjectModelClass parent_class;
};

struct _ComputerPrivate {
	gchar* _manufacturer;
	gchar* _model;
	gint _cores;
	gfloat _ghz;
	guint _quantity;
};

struct _Manual {
	ObjectModel parent_instance;
	ManualPrivate * priv;
};

struct _ManualClass {
	ObjectModelClass parent_class;
};

struct _ManualPrivate {
	gchar* _document;
	gint _pages;
};

struct _Package {
	ObjectModel parent_instance;
	PackagePrivate * priv;
};

struct _PackageClass {
	ObjectModelClass parent_class;
};

struct _PackagePrivate {
	GArray* _tags;
	Computer* _computer;
	Manual* _manual;
	gchar* _source;
	gchar* _destiny;
};

struct _Monitor {
	ObjectModel parent_instance;
	MonitorPrivate * priv;
};

struct _MonitorClass {
	ObjectModelClass parent_class;
};

struct _MonitorPrivate {
	gchar* _resolution;
	gint _ac_power;
	gint _dc_power;
};

struct _Cpu {
	ObjectModel parent_instance;
	CpuPrivate * priv;
};

struct _CpuClass {
	ObjectModelClass parent_class;
};

struct _CpuPrivate {
	gfloat _ghz;
	GeeArrayList* _piles;
};

struct _NodeName {
	ObjectModel parent_instance;
	NodeNamePrivate * priv;
};

struct _NodeNameClass {
	ObjectModelClass parent_class;
};

struct _NodeNamePrivate {
	gboolean _invalid;
};

struct _Configuration {
	ObjectModel parent_instance;
	ConfigurationPrivate * priv;
};

struct _ConfigurationClass {
	ObjectModelClass parent_class;
};

struct _ConfigurationPrivate {
	gboolean _invalid;
	gchar* _device;
};

struct _FakeSerializable {
	ObjectModel parent_instance;
	FakeSerializablePrivate * priv;
};

struct _FakeSerializableClass {
	ObjectModelClass parent_class;
};

struct _FakeSerializablePrivate {
	gchar* _none;
};

struct _UnknownAttribute {
	ObjectModel parent_instance;
	UnknownAttributePrivate * priv;
};

struct _UnknownAttributeClass {
	ObjectModelClass parent_class;
};

struct _UnknownAttributePrivate {
	gchar* _name;
	GeeArrayList* _array;
	FakeSerializable* _fake;
};

struct _NameSpace {
	GXmlSerializableObjectModel parent_instance;
	NameSpacePrivate * priv;
};

struct _NameSpaceClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _SerializableObjectModelTest {
	GXmlTest parent_instance;
	SerializableObjectModelTestPrivate * priv;
};

struct _SerializableObjectModelTestClass {
	GXmlTestClass parent_class;
};

static gpointer object_model_parent_class = NULL;
static gint Computer_private_offset;
static gpointer computer_parent_class = NULL;
static gint Manual_private_offset;
static gpointer manual_parent_class = NULL;
static gint Package_private_offset;
static gpointer package_parent_class = NULL;
static gint Monitor_private_offset;
static gpointer monitor_parent_class = NULL;
static gint Cpu_private_offset;
static gpointer cpu_parent_class = NULL;
static gint NodeName_private_offset;
static gpointer node_name_parent_class = NULL;
static gint Configuration_private_offset;
static gpointer configuration_parent_class = NULL;
static gint FakeSerializable_private_offset;
static gpointer fake_serializable_parent_class = NULL;
static gint UnknownAttribute_private_offset;
static gpointer unknown_attribute_parent_class = NULL;
static gpointer name_space_parent_class = NULL;
static gpointer serializable_object_model_test_parent_class = NULL;

#define XML_COMPUTER_FILE "<?xml version=\"1.0\"?>\n" \
"<computer manufacturer=\"ThecnicalGroup\" model=\"YH576G\" cores=\"4\"" \
" ghz=\"2.8\"/>"
#define SERIALIZED_XML_COMPUTER_FILE "<?xml version=\"1.0\"?><computer manufacturer=\"MexicanLaptop, Inc.\" " \
"model=\"LQ59678\" cores=\"8\" ghz=\"3.5\"/>"
#define XML_PACKAGE_FILE "<?xml version=\"1.0\"?>\n" \
"<PACKAGE source=\"Mexico/Central\" destiny=\"Japan\">\n" \
"<manual document=\"Specification\" pages=\"3\">This is an Specificatio" \
"n file</manual>\n" \
"<Computer manufacturer=\"LanCorop\" model=\"Lap39120\" cores=\"16\" gh" \
"z=\"3.5\"/>\n" \
"<tag>Printer</tag><tag>Partner</tag><tag>Support</tag>\n" \
"</PACKAGE>"
#define XML_PACKAGE_UNKNOWN_NODES_FILE "<?xml version=\"1.0\"?>\n" \
"<PACKAGE source=\"Mexico/North\" destiny=\"Brazil\" Hope=\"2/4.04\">\n" \
"<manual document=\"Sales Card\" pages=\"1\">Selling Card Specification" \
"</manual>\n" \
"<Computer manufacturer=\"BoxingLAN\" model=\"J24-EX9\" cores=\"32\" gh" \
"z=\"1.8\"/>\n" \
"<Box size=\"1\" volume=\"33.15\" units=\"cm3\" />\n" \
"</PACKAGE>"
#define XML_CPU_FILE "<?xml version=\"1.0\"?>\n<cpu ghz=\"3.85\" piles=\"1,2,3\"/>"
GType object_model_get_type (void) G_GNUC_CONST;
static gchar* object_model_real_to_string (GXmlSerializableObjectModel* base);
ObjectModel* object_model_new (void);
ObjectModel* object_model_construct (GType object_type);
GType computer_get_type (void) G_GNUC_CONST;
Computer* computer_new (void);
Computer* computer_construct (GType object_type);
void computer_set_manufacturer (Computer* self,
                                const gchar* value);
void computer_set_model (Computer* self,
                         const gchar* value);
void computer_set_cores (Computer* self,
                         gint value);
void computer_set_ghz (Computer* self,
                       gfloat value);
const gchar* computer_get_manufacturer (Computer* self);
const gchar* computer_get_model (Computer* self);
gint computer_get_cores (Computer* self);
gfloat computer_get_ghz (Computer* self);
guint computer_get_quantity (Computer* self);
void computer_set_quantity (Computer* self,
                            guint value);
static void computer_finalize (GObject * obj);
static void _vala_computer_get_property (GObject * object,
                                  guint property_id,
                                  GValue * value,
                                  GParamSpec * pspec);
static void _vala_computer_set_property (GObject * object,
                                  guint property_id,
                                  const GValue * value,
                                  GParamSpec * pspec);
GType manual_get_type (void) G_GNUC_CONST;
gchar* manual_get_contents (Manual* self);
void manual_set_contents (Manual* self,
                          const gchar* val);
Manual* manual_new (void);
Manual* manual_construct (GType object_type);
void manual_set_document (Manual* self,
                          const gchar* value);
void manual_set_pages (Manual* self,
                       gint value);
static gchar* manual_real_to_string (GXmlSerializableObjectModel* base);
static gboolean manual_real_serialize_use_xml_node_value (GXmlSerializableObjectModel* base);
const gchar* manual_get_document (Manual* self);
gint manual_get_pages (Manual* self);
static void manual_finalize (GObject * obj);
static void _vala_manual_get_property (GObject * object,
                                guint property_id,
                                GValue * value,
                                GParamSpec * pspec);
static void _vala_manual_set_property (GObject * object,
                                guint property_id,
                                const GValue * value,
                                GParamSpec * pspec);
GType package_get_type (void) G_GNUC_CONST;
static void _g_free0_ (gpointer var);
static void _vala_gchar_free_function_content_of (gpointer data);
static gboolean package_real_property_use_nick (GXmlSerializableObjectModel* base);
static gboolean package_real_get_enable_unknown_serializable_property (GXmlSerializableObjectModel* base);
Package* package_new (void);
Package* package_construct (GType object_type);
void package_set_computer (Package* self,
                           Computer* value);
void package_set_manual (Package* self,
                         Manual* value);
void package_set_source (Package* self,
                         const gchar* value);
void package_set_destiny (Package* self,
                          const gchar* value);
static void __lambda262_ (Package* self,
                   GXmlNode* element,
                   GParamSpec* prop,
                   GXmlNode* * node);
GArray* package_get_tags (Package* self);
static void ___lambda262__gxml_serializable_serialize_unknown_property (GXmlSerializable* _sender,
                                                                 GXmlNode* element,
                                                                 GParamSpec* prop,
                                                                 GXmlNode* * node,
                                                                 gpointer self);
static void __lambda263_ (Package* self,
                   GXmlNode* element,
                   GParamSpec* prop);
static void ___lambda263__gxml_serializable_deserialize_unknown_property (GXmlSerializable* _sender,
                                                                   GXmlNode* node,
                                                                   GParamSpec* prop,
                                                                   gpointer self);
gchar* package_unknown_to_string (Package* self);
Computer* package_get_computer (Package* self);
Manual* package_get_manual (Package* self);
const gchar* package_get_source (Package* self);
const gchar* package_get_destiny (Package* self);
static void package_finalize (GObject * obj);
static void _vala_package_get_property (GObject * object,
                                 guint property_id,
                                 GValue * value,
                                 GParamSpec * pspec);
static void _vala_package_set_property (GObject * object,
                                 guint property_id,
                                 const GValue * value,
                                 GParamSpec * pspec);
GType monitor_get_type (void) G_GNUC_CONST;
static gboolean monitor_real_property_use_nick (GXmlSerializableObjectModel* base);
Monitor* monitor_new (void);
Monitor* monitor_construct (GType object_type);
const gchar* monitor_get_resolution (Monitor* self);
void monitor_set_resolution (Monitor* self,
                             const gchar* value);
gint monitor_get_ac_power (Monitor* self);
void monitor_set_ac_power (Monitor* self,
                           gint value);
gint monitor_get_dc_power (Monitor* self);
void monitor_set_dc_power (Monitor* self,
                           gint value);
static void monitor_finalize (GObject * obj);
static void _vala_monitor_get_property (GObject * object,
                                 guint property_id,
                                 GValue * value,
                                 GParamSpec * pspec);
static void _vala_monitor_set_property (GObject * object,
                                 guint property_id,
                                 const GValue * value,
                                 GParamSpec * pspec);
GType cpu_get_type (void) G_GNUC_CONST;
Cpu* cpu_new (void);
Cpu* cpu_construct (GType object_type);
void cpu_set_piles (Cpu* self,
                    GeeArrayList* value);
gchar* cpu_piles_to_string (Cpu* self);
GeeArrayList* cpu_get_piles (Cpu* self);
gfloat cpu_get_ghz (Cpu* self);
void cpu_set_ghz (Cpu* self,
                  gfloat value);
static void cpu_finalize (GObject * obj);
static void _vala_cpu_get_property (GObject * object,
                             guint property_id,
                             GValue * value,
                             GParamSpec * pspec);
static void _vala_cpu_set_property (GObject * object,
                             guint property_id,
                             const GValue * value,
                             GParamSpec * pspec);
GType node_name_get_type (void) G_GNUC_CONST;
static gchar* node_name_real_node_name (GXmlSerializableObjectModel* base);
NodeName* node_name_new (void);
NodeName* node_name_construct (GType object_type);
gboolean node_name_get_invalid (NodeName* self);
void node_name_set_invalid (NodeName* self,
                            gboolean value);
static void node_name_finalize (GObject * obj);
static void _vala_node_name_get_property (GObject * object,
                                   guint property_id,
                                   GValue * value,
                                   GParamSpec * pspec);
static void _vala_node_name_set_property (GObject * object,
                                   guint property_id,
                                   const GValue * value,
                                   GParamSpec * pspec);
GType configuration_get_type (void) G_GNUC_CONST;
static gchar* configuration_real_node_name (GXmlSerializableObjectModel* base);
static gboolean configuration_real_property_use_nick (GXmlSerializableObjectModel* base);
static GParamSpec** configuration_real_list_serializable_properties (GXmlSerializableObjectModel* base,
                                                              gint* result_length1);
static void _g_param_spec_unref0_ (gpointer var);
static void _vala_array_add1 (GParamSpec** * array,
                       int* length,
                       int* size,
                       GParamSpec* value);
static GXmlNode* configuration_real_serialize (GXmlSerializableObjectModel* base,
                                        GXmlNode* node,
                                        GError** error);
static gboolean configuration_real_deserialize (GXmlSerializableObjectModel* base,
                                         GXmlNode* node,
                                         GError** error);
void configuration_set_invalid (Configuration* self,
                                gboolean value);
Configuration* configuration_new (void);
Configuration* configuration_construct (GType object_type);
gboolean configuration_get_invalid (Configuration* self);
const gchar* configuration_get_device (Configuration* self);
void configuration_set_device (Configuration* self,
                               const gchar* value);
static void configuration_finalize (GObject * obj);
static void _vala_configuration_get_property (GObject * object,
                                       guint property_id,
                                       GValue * value,
                                       GParamSpec * pspec);
static void _vala_configuration_set_property (GObject * object,
                                       guint property_id,
                                       const GValue * value,
                                       GParamSpec * pspec);
GType fake_serializable_get_type (void) G_GNUC_CONST;
FakeSerializable* fake_serializable_new (void);
FakeSerializable* fake_serializable_construct (GType object_type);
const gchar* fake_serializable_get_none (FakeSerializable* self);
void fake_serializable_set_none (FakeSerializable* self,
                                 const gchar* value);
static void fake_serializable_finalize (GObject * obj);
static void _vala_fake_serializable_get_property (GObject * object,
                                           guint property_id,
                                           GValue * value,
                                           GParamSpec * pspec);
static void _vala_fake_serializable_set_property (GObject * object,
                                           guint property_id,
                                           const GValue * value,
                                           GParamSpec * pspec);
GType unknown_attribute_get_type (void) G_GNUC_CONST;
static gboolean unknown_attribute_real_get_enable_unknown_serializable_property (GXmlSerializableObjectModel* base);
UnknownAttribute* unknown_attribute_new (void);
UnknownAttribute* unknown_attribute_construct (GType object_type);
const gchar* unknown_attribute_get_name (UnknownAttribute* self);
void unknown_attribute_set_name (UnknownAttribute* self,
                                 const gchar* value);
GeeArrayList* unknown_attribute_get_array (UnknownAttribute* self);
void unknown_attribute_set_array (UnknownAttribute* self,
                                  GeeArrayList* value);
FakeSerializable* unknown_attribute_get_fake (UnknownAttribute* self);
void unknown_attribute_set_fake (UnknownAttribute* self,
                                 FakeSerializable* value);
static void unknown_attribute_finalize (GObject * obj);
static void _vala_unknown_attribute_get_property (GObject * object,
                                           guint property_id,
                                           GValue * value,
                                           GParamSpec * pspec);
static void _vala_unknown_attribute_set_property (GObject * object,
                                           guint property_id,
                                           const GValue * value,
                                           GParamSpec * pspec);
GType name_space_get_type (void) G_GNUC_CONST;
static gboolean name_space_real_set_default_namespace (GXmlSerializableObjectModel* base,
                                                GXmlNode* node);
static gchar* name_space_real_to_string (GXmlSerializableObjectModel* base);
NameSpace* name_space_new (void);
NameSpace* name_space_construct (GType object_type);
gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType serializable_object_model_test_get_type (void) G_GNUC_CONST;
void serializable_object_model_test_add_tests (void);
static void __lambda264_ (void);
static void ___lambda264__gtest_func (void);
static void __lambda265_ (void);
static void ___lambda265__gtest_func (void);
static void __lambda266_ (void);
static void ___lambda266__gtest_func (void);
static void __lambda267_ (void);
static void serializable_object_model_test_serialize_manual_check (GXmlGElement* element,
                                                            Manual* manual);
static void ___lambda267__gtest_func (void);
static void __lambda268_ (void);
static void ___lambda268__gtest_func (void);
static void __lambda269_ (void);
static void ___lambda269__gtest_func (void);
static void __lambda270_ (void);
static void ___lambda270__gtest_func (void);
static void __lambda271_ (void);
static void ___lambda271__gtest_func (void);
static void __lambda272_ (void);
static void ___lambda272__gtest_func (void);
static void __lambda273_ (void);
static void ___lambda273__gtest_func (void);
static void __lambda274_ (void);
static void ___lambda274__gtest_func (void);
static void __lambda275_ (void);
static void ___lambda275__gtest_func (void);
static void __lambda276_ (void);
static void ___lambda276__gtest_func (void);
static void __lambda277_ (void);
static void ___lambda277__gtest_func (void);
static void __lambda278_ (void);
static void ___lambda278__gtest_func (void);
static void __lambda279_ (void);
static void ___lambda279__gtest_func (void);
static void __lambda280_ (void);
static void ___lambda280__gtest_func (void);
static void __lambda281_ (void);
static void ___lambda281__gtest_func (void);
static void __lambda282_ (void);
static void ___lambda282__gtest_func (void);
SerializableObjectModelTest* serializable_object_model_test_new (void);
SerializableObjectModelTest* serializable_object_model_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static void _vala_array_destroy (gpointer array,
                          gint array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gint array_length,
                       GDestroyNotify destroy_func);

static gpointer
_g_param_spec_ref0 (gpointer self)
{
#line 60 "SerializableObjectModelTest.vala"
	return self ? g_param_spec_ref (self) : NULL;
#line 750 "SerializableObjectModelTest.c"
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result = NULL;
#line 1516 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1517 "glib-2.0.vapi"
	result = self;
#line 1517 "glib-2.0.vapi"
	return result;
#line 763 "SerializableObjectModelTest.c"
}

static gchar*
object_model_real_to_string (GXmlSerializableObjectModel* base)
{
	ObjectModel * self;
	gchar* result = NULL;
	GParamSpec** lp = NULL;
	gint _tmp0_ = 0;
	GParamSpec** _tmp1_;
	gint lp_length1;
	gint _lp_size_;
	gchar* ret = NULL;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	GParamSpec** _tmp4_;
	gint _tmp4__length1;
	const gchar* _tmp27_;
	gchar* _tmp28_;
	GError* _inner_error0_ = NULL;
#line 56 "SerializableObjectModelTest.vala"
	self = (ObjectModel*) base;
#line 58 "SerializableObjectModelTest.vala"
	_tmp1_ = gxml_serializable_object_model_list_serializable_properties ((GXmlSerializableObjectModel*) self, &_tmp0_);
#line 58 "SerializableObjectModelTest.vala"
	lp = _tmp1_;
#line 58 "SerializableObjectModelTest.vala"
	lp_length1 = _tmp0_;
#line 58 "SerializableObjectModelTest.vala"
	_lp_size_ = lp_length1;
#line 59 "SerializableObjectModelTest.vala"
	_tmp2_ = g_type_name (G_TYPE_FROM_INSTANCE ((GObject*) self));
#line 59 "SerializableObjectModelTest.vala"
	_tmp3_ = g_strconcat (_tmp2_, "{Properties:\n", NULL);
#line 59 "SerializableObjectModelTest.vala"
	ret = _tmp3_;
#line 60 "SerializableObjectModelTest.vala"
	_tmp4_ = lp;
#line 60 "SerializableObjectModelTest.vala"
	_tmp4__length1 = lp_length1;
#line 804 "SerializableObjectModelTest.c"
	{
		GParamSpec** p_collection = NULL;
		gint p_collection_length1 = 0;
		gint _p_collection_size_ = 0;
		gint p_it = 0;
#line 60 "SerializableObjectModelTest.vala"
		p_collection = _tmp4_;
#line 60 "SerializableObjectModelTest.vala"
		p_collection_length1 = _tmp4__length1;
#line 60 "SerializableObjectModelTest.vala"
		for (p_it = 0; p_it < _tmp4__length1; p_it = p_it + 1) {
#line 816 "SerializableObjectModelTest.c"
			GParamSpec* _tmp5_;
			GParamSpec* p = NULL;
#line 60 "SerializableObjectModelTest.vala"
			_tmp5_ = _g_param_spec_ref0 (p_collection[p_it]);
#line 60 "SerializableObjectModelTest.vala"
			p = _tmp5_;
#line 823 "SerializableObjectModelTest.c"
			{
				GValue v = {0};
				GParamSpec* _tmp6_;
				GValue _tmp7_ = {0};
				GParamSpec* _tmp8_;
				const gchar* _tmp9_;
				gchar* t = NULL;
				const gchar* _tmp15_;
				GParamSpec* _tmp16_;
				const gchar* _tmp17_;
				const gchar* _tmp18_;
				gchar* _tmp19_;
				gchar* _tmp20_;
				const gchar* _tmp21_;
				gchar* _tmp22_;
				gchar* _tmp23_;
				gchar* _tmp24_;
				gchar* _tmp25_;
				gchar* _tmp26_;
#line 61 "SerializableObjectModelTest.vala"
				_tmp6_ = p;
#line 61 "SerializableObjectModelTest.vala"
				g_value_init (&_tmp7_, _tmp6_->value_type);
#line 61 "SerializableObjectModelTest.vala"
				v = _tmp7_;
#line 62 "SerializableObjectModelTest.vala"
				_tmp8_ = p;
#line 62 "SerializableObjectModelTest.vala"
				_tmp9_ = _tmp8_->name;
#line 62 "SerializableObjectModelTest.vala"
				g_object_get_property ((GObject*) self, _tmp9_, &v);
#line 855 "SerializableObjectModelTest.c"
				{
					gchar* _tmp10_ = NULL;
					GValue _tmp11_;
					gchar* _tmp12_;
					gchar* _tmp13_;
#line 64 "SerializableObjectModelTest.vala"
					_tmp11_ = v;
#line 64 "SerializableObjectModelTest.vala"
					_tmp12_ = gxml_serializable_gvalue_to_string (&_tmp11_, &_inner_error0_);
#line 64 "SerializableObjectModelTest.vala"
					_tmp10_ = _tmp12_;
#line 64 "SerializableObjectModelTest.vala"
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 869 "SerializableObjectModelTest.c"
						goto __catch316_g_error;
					}
#line 64 "SerializableObjectModelTest.vala"
					_tmp13_ = _tmp10_;
#line 64 "SerializableObjectModelTest.vala"
					_tmp10_ = NULL;
#line 64 "SerializableObjectModelTest.vala"
					_g_free0 (t);
#line 64 "SerializableObjectModelTest.vala"
					t = _tmp13_;
#line 64 "SerializableObjectModelTest.vala"
					_g_free0 (_tmp10_);
#line 882 "SerializableObjectModelTest.c"
				}
				goto __finally316;
				__catch316_g_error:
				{
					gchar* _tmp14_;
#line 64 "SerializableObjectModelTest.vala"
					g_clear_error (&_inner_error0_);
#line 64 "SerializableObjectModelTest.vala"
					_inner_error0_ = NULL;
#line 64 "SerializableObjectModelTest.vala"
					_tmp14_ = g_strdup ("[CANT_TRANSFORM]");
#line 64 "SerializableObjectModelTest.vala"
					_g_free0 (t);
#line 64 "SerializableObjectModelTest.vala"
					t = _tmp14_;
#line 898 "SerializableObjectModelTest.c"
				}
				__finally316:
#line 64 "SerializableObjectModelTest.vala"
				if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 64 "SerializableObjectModelTest.vala"
					_g_free0 (t);
#line 64 "SerializableObjectModelTest.vala"
					G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
#line 64 "SerializableObjectModelTest.vala"
					_g_param_spec_unref0 (p);
#line 64 "SerializableObjectModelTest.vala"
					_g_free0 (ret);
#line 64 "SerializableObjectModelTest.vala"
					lp = (_vala_array_free (lp, lp_length1, (GDestroyNotify) g_param_spec_unref), NULL);
#line 64 "SerializableObjectModelTest.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 64 "SerializableObjectModelTest.vala"
					g_clear_error (&_inner_error0_);
#line 64 "SerializableObjectModelTest.vala"
					return NULL;
#line 919 "SerializableObjectModelTest.c"
				}
#line 65 "SerializableObjectModelTest.vala"
				_tmp15_ = ret;
#line 65 "SerializableObjectModelTest.vala"
				_tmp16_ = p;
#line 65 "SerializableObjectModelTest.vala"
				_tmp17_ = _tmp16_->name;
#line 65 "SerializableObjectModelTest.vala"
				_tmp18_ = string_to_string (_tmp17_);
#line 65 "SerializableObjectModelTest.vala"
				_tmp19_ = g_strconcat ("[", _tmp18_, "]{", NULL);
#line 65 "SerializableObjectModelTest.vala"
				_tmp20_ = _tmp19_;
#line 65 "SerializableObjectModelTest.vala"
				_tmp21_ = t;
#line 65 "SerializableObjectModelTest.vala"
				_tmp22_ = g_strconcat (_tmp20_, _tmp21_, NULL);
#line 65 "SerializableObjectModelTest.vala"
				_tmp23_ = _tmp22_;
#line 65 "SerializableObjectModelTest.vala"
				_tmp24_ = g_strconcat (_tmp23_, "}\n", NULL);
#line 65 "SerializableObjectModelTest.vala"
				_tmp25_ = _tmp24_;
#line 65 "SerializableObjectModelTest.vala"
				_tmp26_ = g_strconcat (_tmp15_, _tmp25_, NULL);
#line 65 "SerializableObjectModelTest.vala"
				_g_free0 (ret);
#line 65 "SerializableObjectModelTest.vala"
				ret = _tmp26_;
#line 65 "SerializableObjectModelTest.vala"
				_g_free0 (_tmp25_);
#line 65 "SerializableObjectModelTest.vala"
				_g_free0 (_tmp23_);
#line 65 "SerializableObjectModelTest.vala"
				_g_free0 (_tmp20_);
#line 60 "SerializableObjectModelTest.vala"
				_g_free0 (t);
#line 60 "SerializableObjectModelTest.vala"
				G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
#line 60 "SerializableObjectModelTest.vala"
				_g_param_spec_unref0 (p);
#line 961 "SerializableObjectModelTest.c"
			}
		}
	}
#line 67 "SerializableObjectModelTest.vala"
	_tmp27_ = ret;
#line 67 "SerializableObjectModelTest.vala"
	_tmp28_ = g_strconcat (_tmp27_, "}", NULL);
#line 67 "SerializableObjectModelTest.vala"
	result = _tmp28_;
#line 67 "SerializableObjectModelTest.vala"
	_g_free0 (ret);
#line 67 "SerializableObjectModelTest.vala"
	lp = (_vala_array_free (lp, lp_length1, (GDestroyNotify) g_param_spec_unref), NULL);
#line 67 "SerializableObjectModelTest.vala"
	return result;
#line 977 "SerializableObjectModelTest.c"
}

ObjectModel*
object_model_construct (GType object_type)
{
	ObjectModel * self = NULL;
#line 54 "SerializableObjectModelTest.vala"
	self = (ObjectModel*) gxml_serializable_object_model_construct (object_type);
#line 54 "SerializableObjectModelTest.vala"
	return self;
#line 988 "SerializableObjectModelTest.c"
}

ObjectModel*
object_model_new (void)
{
#line 54 "SerializableObjectModelTest.vala"
	return object_model_construct (TYPE_OBJECT_MODEL);
#line 996 "SerializableObjectModelTest.c"
}

static void
object_model_class_init (ObjectModelClass * klass,
                         gpointer klass_data)
{
#line 54 "SerializableObjectModelTest.vala"
	object_model_parent_class = g_type_class_peek_parent (klass);
#line 54 "SerializableObjectModelTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) object_model_real_to_string;
#line 1007 "SerializableObjectModelTest.c"
}

static void
object_model_instance_init (ObjectModel * self,
                            gpointer klass)
{
}

GType
object_model_get_type (void)
{
	static volatile gsize object_model_type_id__volatile = 0;
	if (g_once_init_enter (&object_model_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ObjectModelClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) object_model_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ObjectModel), 0, (GInstanceInitFunc) object_model_instance_init, NULL };
		GType object_model_type_id;
		object_model_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "ObjectModel", &g_define_type_info, 0);
		g_once_init_leave (&object_model_type_id__volatile, object_model_type_id);
	}
	return object_model_type_id__volatile;
}

static inline gpointer
computer_get_instance_private (Computer* self)
{
	return G_STRUCT_MEMBER_P (self, Computer_private_offset);
}

Computer*
computer_construct (GType object_type)
{
	Computer * self = NULL;
#line 79 "SerializableObjectModelTest.vala"
	self = (Computer*) object_model_construct (object_type);
#line 81 "SerializableObjectModelTest.vala"
	computer_set_manufacturer (self, "MexicanLaptop, Inc.");
#line 82 "SerializableObjectModelTest.vala"
	computer_set_model (self, "LQ59678");
#line 83 "SerializableObjectModelTest.vala"
	computer_set_cores (self, 8);
#line 84 "SerializableObjectModelTest.vala"
	computer_set_ghz (self, (gfloat) 3.5);
#line 79 "SerializableObjectModelTest.vala"
	return self;
#line 1051 "SerializableObjectModelTest.c"
}

Computer*
computer_new (void)
{
#line 79 "SerializableObjectModelTest.vala"
	return computer_construct (TYPE_COMPUTER);
#line 1059 "SerializableObjectModelTest.c"
}

const gchar*
computer_get_manufacturer (Computer* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 73 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 73 "SerializableObjectModelTest.vala"
	_tmp0_ = self->priv->_manufacturer;
#line 73 "SerializableObjectModelTest.vala"
	result = _tmp0_;
#line 73 "SerializableObjectModelTest.vala"
	return result;
#line 1075 "SerializableObjectModelTest.c"
}

void
computer_set_manufacturer (Computer* self,
                           const gchar* value)
{
#line 73 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 73 "SerializableObjectModelTest.vala"
	if (g_strcmp0 (value, computer_get_manufacturer (self)) != 0) {
#line 1086 "SerializableObjectModelTest.c"
		gchar* _tmp0_;
#line 73 "SerializableObjectModelTest.vala"
		_tmp0_ = g_strdup (value);
#line 73 "SerializableObjectModelTest.vala"
		_g_free0 (self->priv->_manufacturer);
#line 73 "SerializableObjectModelTest.vala"
		self->priv->_manufacturer = _tmp0_;
#line 73 "SerializableObjectModelTest.vala"
		g_object_notify_by_pspec ((GObject *) self, computer_properties[COMPUTER_MANUFACTURER_PROPERTY]);
#line 1096 "SerializableObjectModelTest.c"
	}
}

const gchar*
computer_get_model (Computer* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 74 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 74 "SerializableObjectModelTest.vala"
	_tmp0_ = self->priv->_model;
#line 74 "SerializableObjectModelTest.vala"
	result = _tmp0_;
#line 74 "SerializableObjectModelTest.vala"
	return result;
#line 1113 "SerializableObjectModelTest.c"
}

void
computer_set_model (Computer* self,
                    const gchar* value)
{
#line 74 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 74 "SerializableObjectModelTest.vala"
	if (g_strcmp0 (value, computer_get_model (self)) != 0) {
#line 1124 "SerializableObjectModelTest.c"
		gchar* _tmp0_;
#line 74 "SerializableObjectModelTest.vala"
		_tmp0_ = g_strdup (value);
#line 74 "SerializableObjectModelTest.vala"
		_g_free0 (self->priv->_model);
#line 74 "SerializableObjectModelTest.vala"
		self->priv->_model = _tmp0_;
#line 74 "SerializableObjectModelTest.vala"
		g_object_notify_by_pspec ((GObject *) self, computer_properties[COMPUTER_MODEL_PROPERTY]);
#line 1134 "SerializableObjectModelTest.c"
	}
}

gint
computer_get_cores (Computer* self)
{
	gint result;
#line 75 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 75 "SerializableObjectModelTest.vala"
	result = self->priv->_cores;
#line 75 "SerializableObjectModelTest.vala"
	return result;
#line 1148 "SerializableObjectModelTest.c"
}

void
computer_set_cores (Computer* self,
                    gint value)
{
#line 75 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 75 "SerializableObjectModelTest.vala"
	if (computer_get_cores (self) != value) {
#line 75 "SerializableObjectModelTest.vala"
		self->priv->_cores = value;
#line 75 "SerializableObjectModelTest.vala"
		g_object_notify_by_pspec ((GObject *) self, computer_properties[COMPUTER_CORES_PROPERTY]);
#line 1163 "SerializableObjectModelTest.c"
	}
}

gfloat
computer_get_ghz (Computer* self)
{
	gfloat result;
#line 76 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, 0.0F);
#line 76 "SerializableObjectModelTest.vala"
	result = self->priv->_ghz;
#line 76 "SerializableObjectModelTest.vala"
	return result;
#line 1177 "SerializableObjectModelTest.c"
}

void
computer_set_ghz (Computer* self,
                  gfloat value)
{
#line 76 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 76 "SerializableObjectModelTest.vala"
	if (computer_get_ghz (self) != value) {
#line 76 "SerializableObjectModelTest.vala"
		self->priv->_ghz = value;
#line 76 "SerializableObjectModelTest.vala"
		g_object_notify_by_pspec ((GObject *) self, computer_properties[COMPUTER_GHZ_PROPERTY]);
#line 1192 "SerializableObjectModelTest.c"
	}
}

guint
computer_get_quantity (Computer* self)
{
	guint result;
#line 77 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, 0U);
#line 77 "SerializableObjectModelTest.vala"
	result = self->priv->_quantity;
#line 77 "SerializableObjectModelTest.vala"
	return result;
#line 1206 "SerializableObjectModelTest.c"
}

void
computer_set_quantity (Computer* self,
                       guint value)
{
#line 77 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 77 "SerializableObjectModelTest.vala"
	if (computer_get_quantity (self) != value) {
#line 77 "SerializableObjectModelTest.vala"
		self->priv->_quantity = value;
#line 77 "SerializableObjectModelTest.vala"
		g_object_notify_by_pspec ((GObject *) self, computer_properties[COMPUTER_QUANTITY_PROPERTY]);
#line 1221 "SerializableObjectModelTest.c"
	}
}

static void
computer_class_init (ComputerClass * klass,
                     gpointer klass_data)
{
#line 70 "SerializableObjectModelTest.vala"
	computer_parent_class = g_type_class_peek_parent (klass);
#line 70 "SerializableObjectModelTest.vala"
	g_type_class_adjust_private_offset (klass, &Computer_private_offset);
#line 70 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_computer_get_property;
#line 70 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_computer_set_property;
#line 70 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->finalize = computer_finalize;
#line 70 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), COMPUTER_MANUFACTURER_PROPERTY, computer_properties[COMPUTER_MANUFACTURER_PROPERTY] = g_param_spec_string ("manufacturer", "Manufacturer", "manufacturer", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 70 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), COMPUTER_MODEL_PROPERTY, computer_properties[COMPUTER_MODEL_PROPERTY] = g_param_spec_string ("model", "model", "model", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 70 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), COMPUTER_CORES_PROPERTY, computer_properties[COMPUTER_CORES_PROPERTY] = g_param_spec_int ("cores", "cores", "cores", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 70 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), COMPUTER_GHZ_PROPERTY, computer_properties[COMPUTER_GHZ_PROPERTY] = g_param_spec_float ("ghz", "ghz", "ghz", -G_MAXFLOAT, G_MAXFLOAT, 0.0F, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 70 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), COMPUTER_QUANTITY_PROPERTY, computer_properties[COMPUTER_QUANTITY_PROPERTY] = g_param_spec_uint ("quantity", "quantity", "quantity", 0, G_MAXUINT, 0U, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1249 "SerializableObjectModelTest.c"
}

static void
computer_instance_init (Computer * self,
                        gpointer klass)
{
#line 70 "SerializableObjectModelTest.vala"
	self->priv = computer_get_instance_private (self);
#line 1258 "SerializableObjectModelTest.c"
}

static void
computer_finalize (GObject * obj)
{
	Computer * self;
#line 70 "SerializableObjectModelTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_COMPUTER, Computer);
#line 73 "SerializableObjectModelTest.vala"
	_g_free0 (self->priv->_manufacturer);
#line 74 "SerializableObjectModelTest.vala"
	_g_free0 (self->priv->_model);
#line 70 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (computer_parent_class)->finalize (obj);
#line 1273 "SerializableObjectModelTest.c"
}

GType
computer_get_type (void)
{
	static volatile gsize computer_type_id__volatile = 0;
	if (g_once_init_enter (&computer_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ComputerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) computer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Computer), 0, (GInstanceInitFunc) computer_instance_init, NULL };
		GType computer_type_id;
		computer_type_id = g_type_register_static (TYPE_OBJECT_MODEL, "Computer", &g_define_type_info, 0);
		Computer_private_offset = g_type_add_instance_private (computer_type_id, sizeof (ComputerPrivate));
		g_once_init_leave (&computer_type_id__volatile, computer_type_id);
	}
	return computer_type_id__volatile;
}

static void
_vala_computer_get_property (GObject * object,
                             guint property_id,
                             GValue * value,
                             GParamSpec * pspec)
{
	Computer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_COMPUTER, Computer);
#line 70 "SerializableObjectModelTest.vala"
	switch (property_id) {
#line 70 "SerializableObjectModelTest.vala"
		case COMPUTER_MANUFACTURER_PROPERTY:
#line 70 "SerializableObjectModelTest.vala"
		g_value_set_string (value, computer_get_manufacturer (self));
#line 70 "SerializableObjectModelTest.vala"
		break;
#line 70 "SerializableObjectModelTest.vala"
		case COMPUTER_MODEL_PROPERTY:
#line 70 "SerializableObjectModelTest.vala"
		g_value_set_string (value, computer_get_model (self));
#line 70 "SerializableObjectModelTest.vala"
		break;
#line 70 "SerializableObjectModelTest.vala"
		case COMPUTER_CORES_PROPERTY:
#line 70 "SerializableObjectModelTest.vala"
		g_value_set_int (value, computer_get_cores (self));
#line 70 "SerializableObjectModelTest.vala"
		break;
#line 70 "SerializableObjectModelTest.vala"
		case COMPUTER_GHZ_PROPERTY:
#line 70 "SerializableObjectModelTest.vala"
		g_value_set_float (value, computer_get_ghz (self));
#line 70 "SerializableObjectModelTest.vala"
		break;
#line 70 "SerializableObjectModelTest.vala"
		case COMPUTER_QUANTITY_PROPERTY:
#line 70 "SerializableObjectModelTest.vala"
		g_value_set_uint (value, computer_get_quantity (self));
#line 70 "SerializableObjectModelTest.vala"
		break;
#line 1330 "SerializableObjectModelTest.c"
		default:
#line 70 "SerializableObjectModelTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 70 "SerializableObjectModelTest.vala"
		break;
#line 1336 "SerializableObjectModelTest.c"
	}
}

static void
_vala_computer_set_property (GObject * object,
                             guint property_id,
                             const GValue * value,
                             GParamSpec * pspec)
{
	Computer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_COMPUTER, Computer);
#line 70 "SerializableObjectModelTest.vala"
	switch (property_id) {
#line 70 "SerializableObjectModelTest.vala"
		case COMPUTER_MANUFACTURER_PROPERTY:
#line 70 "SerializableObjectModelTest.vala"
		computer_set_manufacturer (self, g_value_get_string (value));
#line 70 "SerializableObjectModelTest.vala"
		break;
#line 70 "SerializableObjectModelTest.vala"
		case COMPUTER_MODEL_PROPERTY:
#line 70 "SerializableObjectModelTest.vala"
		computer_set_model (self, g_value_get_string (value));
#line 70 "SerializableObjectModelTest.vala"
		break;
#line 70 "SerializableObjectModelTest.vala"
		case COMPUTER_CORES_PROPERTY:
#line 70 "SerializableObjectModelTest.vala"
		computer_set_cores (self, g_value_get_int (value));
#line 70 "SerializableObjectModelTest.vala"
		break;
#line 70 "SerializableObjectModelTest.vala"
		case COMPUTER_GHZ_PROPERTY:
#line 70 "SerializableObjectModelTest.vala"
		computer_set_ghz (self, g_value_get_float (value));
#line 70 "SerializableObjectModelTest.vala"
		break;
#line 70 "SerializableObjectModelTest.vala"
		case COMPUTER_QUANTITY_PROPERTY:
#line 70 "SerializableObjectModelTest.vala"
		computer_set_quantity (self, g_value_get_uint (value));
#line 70 "SerializableObjectModelTest.vala"
		break;
#line 1380 "SerializableObjectModelTest.c"
		default:
#line 70 "SerializableObjectModelTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 70 "SerializableObjectModelTest.vala"
		break;
#line 1386 "SerializableObjectModelTest.c"
	}
}

static inline gpointer
manual_get_instance_private (Manual* self)
{
	return G_STRUCT_MEMBER_P (self, Manual_private_offset);
}

gchar*
manual_get_contents (Manual* self)
{
	gchar* result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
#line 92 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 92 "SerializableObjectModelTest.vala"
	_tmp0_ = gxml_serializable_get_serialized_xml_node_value ((GXmlSerializable*) self);
#line 92 "SerializableObjectModelTest.vala"
	_tmp1_ = _tmp0_;
#line 92 "SerializableObjectModelTest.vala"
	result = _tmp1_;
#line 92 "SerializableObjectModelTest.vala"
	return result;
#line 1412 "SerializableObjectModelTest.c"
}

void
manual_set_contents (Manual* self,
                     const gchar* val)
{
#line 93 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 93 "SerializableObjectModelTest.vala"
	g_return_if_fail (val != NULL);
#line 93 "SerializableObjectModelTest.vala"
	gxml_serializable_set_serialized_xml_node_value ((GXmlSerializable*) self, val);
#line 1425 "SerializableObjectModelTest.c"
}

Manual*
manual_construct (GType object_type)
{
	Manual * self = NULL;
#line 95 "SerializableObjectModelTest.vala"
	self = (Manual*) object_model_construct (object_type);
#line 97 "SerializableObjectModelTest.vala"
	manual_set_document (self, "MANUAL DOCUMENTATION");
#line 98 "SerializableObjectModelTest.vala"
	manual_set_pages (self, 3);
#line 99 "SerializableObjectModelTest.vala"
	manual_set_contents (self, "TEXT INTO THE MANUAL DOCUMENT");
#line 95 "SerializableObjectModelTest.vala"
	return self;
#line 1442 "SerializableObjectModelTest.c"
}

Manual*
manual_new (void)
{
#line 95 "SerializableObjectModelTest.vala"
	return manual_construct (TYPE_MANUAL);
#line 1450 "SerializableObjectModelTest.c"
}

static gchar*
manual_real_to_string (GXmlSerializableObjectModel* base)
{
	Manual * self;
	gchar* result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
#line 102 "SerializableObjectModelTest.vala"
	self = (Manual*) base;
#line 104 "SerializableObjectModelTest.vala"
	_tmp0_ = GXML_SERIALIZABLE_OBJECT_MODEL_CLASS (manual_parent_class)->to_string ((GXmlSerializableObjectModel*) G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_OBJECT_MODEL, ObjectModel));
#line 104 "SerializableObjectModelTest.vala"
	_tmp1_ = _tmp0_;
#line 104 "SerializableObjectModelTest.vala"
	_tmp2_ = manual_get_contents (self);
#line 104 "SerializableObjectModelTest.vala"
	_tmp3_ = _tmp2_;
#line 104 "SerializableObjectModelTest.vala"
	_tmp4_ = string_to_string (_tmp3_);
#line 104 "SerializableObjectModelTest.vala"
	_tmp5_ = g_strconcat ("CONTENTS: { ", _tmp4_, "}", NULL);
#line 104 "SerializableObjectModelTest.vala"
	_tmp6_ = _tmp5_;
#line 104 "SerializableObjectModelTest.vala"
	_tmp7_ = g_strconcat (_tmp1_, _tmp6_, NULL);
#line 104 "SerializableObjectModelTest.vala"
	_tmp8_ = _tmp7_;
#line 104 "SerializableObjectModelTest.vala"
	_g_free0 (_tmp6_);
#line 104 "SerializableObjectModelTest.vala"
	_g_free0 (_tmp3_);
#line 104 "SerializableObjectModelTest.vala"
	_g_free0 (_tmp1_);
#line 104 "SerializableObjectModelTest.vala"
	result = _tmp8_;
#line 104 "SerializableObjectModelTest.vala"
	return result;
#line 1497 "SerializableObjectModelTest.c"
}

static gboolean
manual_real_serialize_use_xml_node_value (GXmlSerializableObjectModel* base)
{
	Manual * self;
	gboolean result = FALSE;
#line 106 "SerializableObjectModelTest.vala"
	self = (Manual*) base;
#line 106 "SerializableObjectModelTest.vala"
	result = TRUE;
#line 106 "SerializableObjectModelTest.vala"
	return result;
#line 1511 "SerializableObjectModelTest.c"
}

const gchar*
manual_get_document (Manual* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 90 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 90 "SerializableObjectModelTest.vala"
	_tmp0_ = self->priv->_document;
#line 90 "SerializableObjectModelTest.vala"
	result = _tmp0_;
#line 90 "SerializableObjectModelTest.vala"
	return result;
#line 1527 "SerializableObjectModelTest.c"
}

void
manual_set_document (Manual* self,
                     const gchar* value)
{
#line 90 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 90 "SerializableObjectModelTest.vala"
	if (g_strcmp0 (value, manual_get_document (self)) != 0) {
#line 1538 "SerializableObjectModelTest.c"
		gchar* _tmp0_;
#line 90 "SerializableObjectModelTest.vala"
		_tmp0_ = g_strdup (value);
#line 90 "SerializableObjectModelTest.vala"
		_g_free0 (self->priv->_document);
#line 90 "SerializableObjectModelTest.vala"
		self->priv->_document = _tmp0_;
#line 90 "SerializableObjectModelTest.vala"
		g_object_notify_by_pspec ((GObject *) self, manual_properties[MANUAL_DOCUMENT_PROPERTY]);
#line 1548 "SerializableObjectModelTest.c"
	}
}

gint
manual_get_pages (Manual* self)
{
	gint result;
#line 91 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 91 "SerializableObjectModelTest.vala"
	result = self->priv->_pages;
#line 91 "SerializableObjectModelTest.vala"
	return result;
#line 1562 "SerializableObjectModelTest.c"
}

void
manual_set_pages (Manual* self,
                  gint value)
{
#line 91 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 91 "SerializableObjectModelTest.vala"
	if (manual_get_pages (self) != value) {
#line 91 "SerializableObjectModelTest.vala"
		self->priv->_pages = value;
#line 91 "SerializableObjectModelTest.vala"
		g_object_notify_by_pspec ((GObject *) self, manual_properties[MANUAL_PAGES_PROPERTY]);
#line 1577 "SerializableObjectModelTest.c"
	}
}

static void
manual_class_init (ManualClass * klass,
                   gpointer klass_data)
{
#line 88 "SerializableObjectModelTest.vala"
	manual_parent_class = g_type_class_peek_parent (klass);
#line 88 "SerializableObjectModelTest.vala"
	g_type_class_adjust_private_offset (klass, &Manual_private_offset);
#line 88 "SerializableObjectModelTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) manual_real_to_string;
#line 88 "SerializableObjectModelTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->serialize_use_xml_node_value = (gboolean (*) (GXmlSerializableObjectModel*)) manual_real_serialize_use_xml_node_value;
#line 88 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_manual_get_property;
#line 88 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_manual_set_property;
#line 88 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->finalize = manual_finalize;
#line 88 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), MANUAL_DOCUMENT_PROPERTY, manual_properties[MANUAL_DOCUMENT_PROPERTY] = g_param_spec_string ("document", "document", "document", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 88 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), MANUAL_PAGES_PROPERTY, manual_properties[MANUAL_PAGES_PROPERTY] = g_param_spec_int ("pages", "pages", "pages", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1603 "SerializableObjectModelTest.c"
}

static void
manual_instance_init (Manual * self,
                      gpointer klass)
{
#line 88 "SerializableObjectModelTest.vala"
	self->priv = manual_get_instance_private (self);
#line 1612 "SerializableObjectModelTest.c"
}

static void
manual_finalize (GObject * obj)
{
	Manual * self;
#line 88 "SerializableObjectModelTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_MANUAL, Manual);
#line 90 "SerializableObjectModelTest.vala"
	_g_free0 (self->priv->_document);
#line 88 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (manual_parent_class)->finalize (obj);
#line 1625 "SerializableObjectModelTest.c"
}

GType
manual_get_type (void)
{
	static volatile gsize manual_type_id__volatile = 0;
	if (g_once_init_enter (&manual_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ManualClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) manual_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Manual), 0, (GInstanceInitFunc) manual_instance_init, NULL };
		GType manual_type_id;
		manual_type_id = g_type_register_static (TYPE_OBJECT_MODEL, "Manual", &g_define_type_info, 0);
		Manual_private_offset = g_type_add_instance_private (manual_type_id, sizeof (ManualPrivate));
		g_once_init_leave (&manual_type_id__volatile, manual_type_id);
	}
	return manual_type_id__volatile;
}

static void
_vala_manual_get_property (GObject * object,
                           guint property_id,
                           GValue * value,
                           GParamSpec * pspec)
{
	Manual * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_MANUAL, Manual);
#line 88 "SerializableObjectModelTest.vala"
	switch (property_id) {
#line 88 "SerializableObjectModelTest.vala"
		case MANUAL_DOCUMENT_PROPERTY:
#line 88 "SerializableObjectModelTest.vala"
		g_value_set_string (value, manual_get_document (self));
#line 88 "SerializableObjectModelTest.vala"
		break;
#line 88 "SerializableObjectModelTest.vala"
		case MANUAL_PAGES_PROPERTY:
#line 88 "SerializableObjectModelTest.vala"
		g_value_set_int (value, manual_get_pages (self));
#line 88 "SerializableObjectModelTest.vala"
		break;
#line 1664 "SerializableObjectModelTest.c"
		default:
#line 88 "SerializableObjectModelTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 88 "SerializableObjectModelTest.vala"
		break;
#line 1670 "SerializableObjectModelTest.c"
	}
}

static void
_vala_manual_set_property (GObject * object,
                           guint property_id,
                           const GValue * value,
                           GParamSpec * pspec)
{
	Manual * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_MANUAL, Manual);
#line 88 "SerializableObjectModelTest.vala"
	switch (property_id) {
#line 88 "SerializableObjectModelTest.vala"
		case MANUAL_DOCUMENT_PROPERTY:
#line 88 "SerializableObjectModelTest.vala"
		manual_set_document (self, g_value_get_string (value));
#line 88 "SerializableObjectModelTest.vala"
		break;
#line 88 "SerializableObjectModelTest.vala"
		case MANUAL_PAGES_PROPERTY:
#line 88 "SerializableObjectModelTest.vala"
		manual_set_pages (self, g_value_get_int (value));
#line 88 "SerializableObjectModelTest.vala"
		break;
#line 1696 "SerializableObjectModelTest.c"
		default:
#line 88 "SerializableObjectModelTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 88 "SerializableObjectModelTest.vala"
		break;
#line 1702 "SerializableObjectModelTest.c"
	}
}

static inline gpointer
package_get_instance_private (Package* self)
{
	return G_STRUCT_MEMBER_P (self, Package_private_offset);
}

static void
_g_free0_ (gpointer var)
{
#line 111 "SerializableObjectModelTest.vala"
	var = (g_free (var), NULL);
#line 1717 "SerializableObjectModelTest.c"
}

static void
_vala_gchar_free_function_content_of (gpointer data)
{
	gchar* self;
#line 111 "SerializableObjectModelTest.vala"
	self = *((gchar**) data);
#line 111 "SerializableObjectModelTest.vala"
	_g_free0_ (self);
#line 1728 "SerializableObjectModelTest.c"
}

static gboolean
package_real_property_use_nick (GXmlSerializableObjectModel* base)
{
	Package * self;
	gboolean result = FALSE;
#line 119 "SerializableObjectModelTest.vala"
	self = (Package*) base;
#line 119 "SerializableObjectModelTest.vala"
	result = TRUE;
#line 119 "SerializableObjectModelTest.vala"
	return result;
#line 1742 "SerializableObjectModelTest.c"
}

static gboolean
package_real_get_enable_unknown_serializable_property (GXmlSerializableObjectModel* base)
{
	Package * self;
	gboolean result = FALSE;
#line 120 "SerializableObjectModelTest.vala"
	self = (Package*) base;
#line 120 "SerializableObjectModelTest.vala"
	result = TRUE;
#line 120 "SerializableObjectModelTest.vala"
	return result;
#line 1756 "SerializableObjectModelTest.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 135 "SerializableObjectModelTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 1764 "SerializableObjectModelTest.c"
}

static void
__lambda262_ (Package* self,
              GXmlNode* element,
              GParamSpec* prop,
              GXmlNode* * node)
{
	GXmlNode* _vala_node = NULL;
	const gchar* _tmp0_;
	GError* _inner_error0_ = NULL;
#line 128 "SerializableObjectModelTest.vala"
	g_return_if_fail (element != NULL);
#line 128 "SerializableObjectModelTest.vala"
	g_return_if_fail (prop != NULL);
#line 129 "SerializableObjectModelTest.vala"
	_g_object_unref0 (_vala_node);
#line 129 "SerializableObjectModelTest.vala"
	_vala_node = NULL;
#line 131 "SerializableObjectModelTest.vala"
	_tmp0_ = prop->name;
#line 131 "SerializableObjectModelTest.vala"
	if (g_strcmp0 (_tmp0_, "tags") == 0) {
#line 1788 "SerializableObjectModelTest.c"
		{
			gint i = 0;
#line 133 "SerializableObjectModelTest.vala"
			i = 0;
#line 1793 "SerializableObjectModelTest.c"
			{
				gboolean _tmp1_ = FALSE;
#line 133 "SerializableObjectModelTest.vala"
				_tmp1_ = TRUE;
#line 133 "SerializableObjectModelTest.vala"
				while (TRUE) {
#line 1800 "SerializableObjectModelTest.c"
					GArray* _tmp3_;
					GArray* _tmp4_;
					gchar* str = NULL;
					GArray* _tmp5_;
					GArray* _tmp6_;
					const gchar* _tmp7_;
					gchar* _tmp8_;
					GXmlNode* _tmp17_;
					const gchar* _tmp18_;
					GeeBidirList* _tmp19_;
					GeeBidirList* _tmp20_;
					GeeBidirList* _tmp21_;
					GXmlNode* _tmp22_;
#line 133 "SerializableObjectModelTest.vala"
					if (!_tmp1_) {
#line 1816 "SerializableObjectModelTest.c"
						gint _tmp2_;
#line 133 "SerializableObjectModelTest.vala"
						_tmp2_ = i;
#line 133 "SerializableObjectModelTest.vala"
						i = _tmp2_ + 1;
#line 1822 "SerializableObjectModelTest.c"
					}
#line 133 "SerializableObjectModelTest.vala"
					_tmp1_ = FALSE;
#line 133 "SerializableObjectModelTest.vala"
					_tmp3_ = package_get_tags (self);
#line 133 "SerializableObjectModelTest.vala"
					_tmp4_ = _tmp3_;
#line 133 "SerializableObjectModelTest.vala"
					if (!(((guint) i) < _tmp4_->len)) {
#line 133 "SerializableObjectModelTest.vala"
						break;
#line 1834 "SerializableObjectModelTest.c"
					}
#line 134 "SerializableObjectModelTest.vala"
					_tmp5_ = package_get_tags (self);
#line 134 "SerializableObjectModelTest.vala"
					_tmp6_ = _tmp5_;
#line 134 "SerializableObjectModelTest.vala"
					_tmp7_ = g_array_index (_tmp6_, gchar*, (guint) i);
#line 134 "SerializableObjectModelTest.vala"
					_tmp8_ = g_strdup (_tmp7_);
#line 134 "SerializableObjectModelTest.vala"
					str = _tmp8_;
#line 1846 "SerializableObjectModelTest.c"
					{
						GXmlNode* _tmp9_ = NULL;
						GXmlDocument* _tmp10_;
						GXmlDocument* _tmp11_;
						GXmlNode* _tmp12_;
						GXmlNode* _tmp13_;
#line 135 "SerializableObjectModelTest.vala"
						_tmp10_ = gxml_node_get_document (element);
#line 135 "SerializableObjectModelTest.vala"
						_tmp11_ = _tmp10_;
#line 135 "SerializableObjectModelTest.vala"
						_tmp12_ = gxml_document_create_element (_tmp11_, "tag", &_inner_error0_);
#line 135 "SerializableObjectModelTest.vala"
						_tmp9_ = _tmp12_;
#line 135 "SerializableObjectModelTest.vala"
						if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1863 "SerializableObjectModelTest.c"
							goto __catch317_g_error;
						}
#line 135 "SerializableObjectModelTest.vala"
						_tmp13_ = _g_object_ref0 ((GXmlNode*) G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GXML_TYPE_ELEMENT, GXmlElement));
#line 135 "SerializableObjectModelTest.vala"
						_g_object_unref0 (_vala_node);
#line 135 "SerializableObjectModelTest.vala"
						_vala_node = _tmp13_;
#line 135 "SerializableObjectModelTest.vala"
						_g_object_unref0 (_tmp9_);
#line 1874 "SerializableObjectModelTest.c"
					}
					goto __finally317;
					__catch317_g_error:
					{
						GError* e = NULL;
						const gchar* _tmp14_;
						gchar* _tmp15_;
						gchar* _tmp16_;
#line 135 "SerializableObjectModelTest.vala"
						e = _inner_error0_;
#line 135 "SerializableObjectModelTest.vala"
						_inner_error0_ = NULL;
#line 137 "SerializableObjectModelTest.vala"
						_tmp14_ = e->message;
#line 137 "SerializableObjectModelTest.vala"
						_tmp15_ = g_strconcat ("Error: ", _tmp14_, NULL);
#line 137 "SerializableObjectModelTest.vala"
						_tmp16_ = _tmp15_;
#line 137 "SerializableObjectModelTest.vala"
						g_message ("SerializableObjectModelTest.vala:137: %s", _tmp16_);
#line 137 "SerializableObjectModelTest.vala"
						_g_free0 (_tmp16_);
#line 138 "SerializableObjectModelTest.vala"
						g_assert_not_reached ();
#line 135 "SerializableObjectModelTest.vala"
						_g_error_free0 (e);
#line 1901 "SerializableObjectModelTest.c"
					}
					__finally317:
#line 135 "SerializableObjectModelTest.vala"
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 135 "SerializableObjectModelTest.vala"
						_g_free0 (str);
#line 135 "SerializableObjectModelTest.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 135 "SerializableObjectModelTest.vala"
						g_clear_error (&_inner_error0_);
#line 135 "SerializableObjectModelTest.vala"
						return;
#line 1914 "SerializableObjectModelTest.c"
					}
#line 140 "SerializableObjectModelTest.vala"
					_tmp17_ = _vala_node;
#line 140 "SerializableObjectModelTest.vala"
					_tmp18_ = str;
#line 140 "SerializableObjectModelTest.vala"
					gxml_element_set_content (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, GXML_TYPE_ELEMENT, GXmlElement), _tmp18_);
#line 141 "SerializableObjectModelTest.vala"
					_tmp19_ = gxml_node_get_children_nodes (element);
#line 141 "SerializableObjectModelTest.vala"
					_tmp20_ = _tmp19_;
#line 141 "SerializableObjectModelTest.vala"
					_tmp21_ = _tmp20_;
#line 141 "SerializableObjectModelTest.vala"
					_tmp22_ = _vala_node;
#line 141 "SerializableObjectModelTest.vala"
					gee_collection_add ((GeeCollection*) _tmp21_, _tmp22_);
#line 141 "SerializableObjectModelTest.vala"
					_g_object_unref0 (_tmp21_);
#line 133 "SerializableObjectModelTest.vala"
					_g_free0 (str);
#line 1936 "SerializableObjectModelTest.c"
				}
			}
		}
	}
#line 128 "SerializableObjectModelTest.vala"
	if (node) {
#line 128 "SerializableObjectModelTest.vala"
		*node = _vala_node;
#line 1945 "SerializableObjectModelTest.c"
	} else {
#line 128 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_vala_node);
#line 1949 "SerializableObjectModelTest.c"
	}
}

static void
___lambda262__gxml_serializable_serialize_unknown_property (GXmlSerializable* _sender,
                                                            GXmlNode* element,
                                                            GParamSpec* prop,
                                                            GXmlNode* * node,
                                                            gpointer self)
{
#line 128 "SerializableObjectModelTest.vala"
	__lambda262_ ((Package*) self, element, prop, node);
#line 1962 "SerializableObjectModelTest.c"
}

static void
__lambda263_ (Package* self,
              GXmlNode* element,
              GParamSpec* prop)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gboolean _tmp3_;
#line 145 "SerializableObjectModelTest.vala"
	g_return_if_fail (element != NULL);
#line 145 "SerializableObjectModelTest.vala"
	g_return_if_fail (prop != NULL);
#line 147 "SerializableObjectModelTest.vala"
	_tmp0_ = gxml_node_get_name (element);
#line 147 "SerializableObjectModelTest.vala"
	_tmp1_ = _tmp0_;
#line 147 "SerializableObjectModelTest.vala"
	_tmp2_ = _tmp1_;
#line 147 "SerializableObjectModelTest.vala"
	_tmp3_ = g_strcmp0 (_tmp2_, "tag") == 0;
#line 147 "SerializableObjectModelTest.vala"
	_g_free0 (_tmp2_);
#line 147 "SerializableObjectModelTest.vala"
	if (_tmp3_) {
#line 1990 "SerializableObjectModelTest.c"
		GArray* _tmp4_;
		GArray* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
#line 148 "SerializableObjectModelTest.vala"
		_tmp4_ = package_get_tags (self);
#line 148 "SerializableObjectModelTest.vala"
		_tmp5_ = _tmp4_;
#line 148 "SerializableObjectModelTest.vala"
		_tmp6_ = gxml_element_get_content ((GXmlElement*) G_TYPE_CHECK_INSTANCE_CAST (element, GXML_TYPE_GELEMENT, GXmlGElement));
#line 148 "SerializableObjectModelTest.vala"
		_tmp7_ = _tmp6_;
#line 148 "SerializableObjectModelTest.vala"
		g_array_append_val (_tmp5_, _tmp7_);
#line 2005 "SerializableObjectModelTest.c"
	}
}

static void
___lambda263__gxml_serializable_deserialize_unknown_property (GXmlSerializable* _sender,
                                                              GXmlNode* node,
                                                              GParamSpec* prop,
                                                              gpointer self)
{
#line 145 "SerializableObjectModelTest.vala"
	__lambda263_ ((Package*) self, node, prop);
#line 2017 "SerializableObjectModelTest.c"
}

Package*
package_construct (GType object_type)
{
	Package * self = NULL;
	Computer* _tmp0_;
	Computer* _tmp1_;
	Manual* _tmp2_;
	Manual* _tmp3_;
#line 122 "SerializableObjectModelTest.vala"
	self = (Package*) object_model_construct (object_type);
#line 124 "SerializableObjectModelTest.vala"
	_tmp0_ = computer_new ();
#line 124 "SerializableObjectModelTest.vala"
	_tmp1_ = _tmp0_;
#line 124 "SerializableObjectModelTest.vala"
	package_set_computer (self, _tmp1_);
#line 124 "SerializableObjectModelTest.vala"
	_g_object_unref0 (_tmp1_);
#line 125 "SerializableObjectModelTest.vala"
	_tmp2_ = manual_new ();
#line 125 "SerializableObjectModelTest.vala"
	_tmp3_ = _tmp2_;
#line 125 "SerializableObjectModelTest.vala"
	package_set_manual (self, _tmp3_);
#line 125 "SerializableObjectModelTest.vala"
	_g_object_unref0 (_tmp3_);
#line 126 "SerializableObjectModelTest.vala"
	package_set_source (self, "Mexico");
#line 127 "SerializableObjectModelTest.vala"
	package_set_destiny (self, "World");
#line 128 "SerializableObjectModelTest.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, GXML_TYPE_SERIALIZABLE, GXmlSerializable), "serialize-unknown-property", (GCallback) ___lambda262__gxml_serializable_serialize_unknown_property, self, 0);
#line 145 "SerializableObjectModelTest.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, GXML_TYPE_SERIALIZABLE, GXmlSerializable), "deserialize-unknown-property", (GCallback) ___lambda263__gxml_serializable_deserialize_unknown_property, self, 0);
#line 122 "SerializableObjectModelTest.vala"
	return self;
#line 2056 "SerializableObjectModelTest.c"
}

Package*
package_new (void)
{
#line 122 "SerializableObjectModelTest.vala"
	return package_construct (TYPE_PACKAGE);
#line 2064 "SerializableObjectModelTest.c"
}

gchar*
package_unknown_to_string (Package* self)
{
	gchar* result = NULL;
	gchar* t = NULL;
	gchar* _tmp0_;
	const gchar* _tmp17_;
	const gchar* _tmp18_;
	gchar* _tmp19_;
#line 153 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 155 "SerializableObjectModelTest.vala"
	_tmp0_ = g_strdup ("");
#line 155 "SerializableObjectModelTest.vala"
	t = _tmp0_;
#line 2082 "SerializableObjectModelTest.c"
	{
		GeeIterator* _node_it = NULL;
		GeeMap* _tmp1_;
		GeeMap* _tmp2_;
		GeeMap* _tmp3_;
		GeeCollection* _tmp4_;
		GeeCollection* _tmp5_;
		GeeCollection* _tmp6_;
		GeeIterator* _tmp7_;
		GeeIterator* _tmp8_;
#line 156 "SerializableObjectModelTest.vala"
		_tmp1_ = gxml_serializable_get_unknown_serializable_properties ((GXmlSerializable*) self);
#line 156 "SerializableObjectModelTest.vala"
		_tmp2_ = _tmp1_;
#line 156 "SerializableObjectModelTest.vala"
		_tmp3_ = _tmp2_;
#line 156 "SerializableObjectModelTest.vala"
		_tmp4_ = gee_map_get_values (_tmp3_);
#line 156 "SerializableObjectModelTest.vala"
		_tmp5_ = _tmp4_;
#line 156 "SerializableObjectModelTest.vala"
		_tmp6_ = _tmp5_;
#line 156 "SerializableObjectModelTest.vala"
		_tmp7_ = gee_iterable_iterator ((GeeIterable*) _tmp6_);
#line 156 "SerializableObjectModelTest.vala"
		_tmp8_ = _tmp7_;
#line 156 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp6_);
#line 156 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp3_);
#line 156 "SerializableObjectModelTest.vala"
		_node_it = _tmp8_;
#line 156 "SerializableObjectModelTest.vala"
		while (TRUE) {
#line 2117 "SerializableObjectModelTest.c"
			GeeIterator* _tmp9_;
			GXmlAttribute* node = NULL;
			GeeIterator* _tmp10_;
			gpointer _tmp11_;
			const gchar* _tmp12_;
			GXmlAttribute* _tmp13_;
			gchar* _tmp14_;
			gchar* _tmp15_;
			gchar* _tmp16_;
#line 156 "SerializableObjectModelTest.vala"
			_tmp9_ = _node_it;
#line 156 "SerializableObjectModelTest.vala"
			if (!gee_iterator_next (_tmp9_)) {
#line 156 "SerializableObjectModelTest.vala"
				break;
#line 2133 "SerializableObjectModelTest.c"
			}
#line 156 "SerializableObjectModelTest.vala"
			_tmp10_ = _node_it;
#line 156 "SerializableObjectModelTest.vala"
			_tmp11_ = gee_iterator_get (_tmp10_);
#line 156 "SerializableObjectModelTest.vala"
			node = (GXmlAttribute*) _tmp11_;
#line 158 "SerializableObjectModelTest.vala"
			_tmp12_ = t;
#line 158 "SerializableObjectModelTest.vala"
			_tmp13_ = node;
#line 158 "SerializableObjectModelTest.vala"
			_tmp14_ = gxml_node_to_string ((GXmlNode*) _tmp13_);
#line 158 "SerializableObjectModelTest.vala"
			_tmp15_ = _tmp14_;
#line 158 "SerializableObjectModelTest.vala"
			_tmp16_ = g_strconcat (_tmp12_, _tmp15_, NULL);
#line 158 "SerializableObjectModelTest.vala"
			_g_free0 (t);
#line 158 "SerializableObjectModelTest.vala"
			t = _tmp16_;
#line 158 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp15_);
#line 156 "SerializableObjectModelTest.vala"
			_g_object_unref0 (node);
#line 2159 "SerializableObjectModelTest.c"
		}
#line 156 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_node_it);
#line 2163 "SerializableObjectModelTest.c"
	}
#line 160 "SerializableObjectModelTest.vala"
	_tmp17_ = t;
#line 160 "SerializableObjectModelTest.vala"
	_tmp18_ = string_to_string (_tmp17_);
#line 160 "SerializableObjectModelTest.vala"
	_tmp19_ = g_strconcat ("Unknown Properties: {", _tmp18_, "}", NULL);
#line 160 "SerializableObjectModelTest.vala"
	result = _tmp19_;
#line 160 "SerializableObjectModelTest.vala"
	_g_free0 (t);
#line 160 "SerializableObjectModelTest.vala"
	return result;
#line 2177 "SerializableObjectModelTest.c"
}

Computer*
package_get_computer (Package* self)
{
	Computer* result;
	Computer* _tmp0_;
#line 112 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 112 "SerializableObjectModelTest.vala"
	_tmp0_ = self->priv->_computer;
#line 112 "SerializableObjectModelTest.vala"
	result = _tmp0_;
#line 112 "SerializableObjectModelTest.vala"
	return result;
#line 2193 "SerializableObjectModelTest.c"
}

void
package_set_computer (Package* self,
                      Computer* value)
{
#line 112 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 112 "SerializableObjectModelTest.vala"
	if (package_get_computer (self) != value) {
#line 2204 "SerializableObjectModelTest.c"
		Computer* _tmp0_;
#line 112 "SerializableObjectModelTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 112 "SerializableObjectModelTest.vala"
		_g_object_unref0 (self->priv->_computer);
#line 112 "SerializableObjectModelTest.vala"
		self->priv->_computer = _tmp0_;
#line 112 "SerializableObjectModelTest.vala"
		g_object_notify_by_pspec ((GObject *) self, package_properties[PACKAGE_COMPUTER_PROPERTY]);
#line 2214 "SerializableObjectModelTest.c"
	}
}

Manual*
package_get_manual (Package* self)
{
	Manual* result;
	Manual* _tmp0_;
#line 113 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 113 "SerializableObjectModelTest.vala"
	_tmp0_ = self->priv->_manual;
#line 113 "SerializableObjectModelTest.vala"
	result = _tmp0_;
#line 113 "SerializableObjectModelTest.vala"
	return result;
#line 2231 "SerializableObjectModelTest.c"
}

void
package_set_manual (Package* self,
                    Manual* value)
{
#line 113 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 113 "SerializableObjectModelTest.vala"
	if (package_get_manual (self) != value) {
#line 2242 "SerializableObjectModelTest.c"
		Manual* _tmp0_;
#line 113 "SerializableObjectModelTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 113 "SerializableObjectModelTest.vala"
		_g_object_unref0 (self->priv->_manual);
#line 113 "SerializableObjectModelTest.vala"
		self->priv->_manual = _tmp0_;
#line 113 "SerializableObjectModelTest.vala"
		g_object_notify_by_pspec ((GObject *) self, package_properties[PACKAGE_MANUAL_PROPERTY]);
#line 2252 "SerializableObjectModelTest.c"
	}
}

const gchar*
package_get_source (Package* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 114 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 114 "SerializableObjectModelTest.vala"
	_tmp0_ = self->priv->_source;
#line 114 "SerializableObjectModelTest.vala"
	result = _tmp0_;
#line 114 "SerializableObjectModelTest.vala"
	return result;
#line 2269 "SerializableObjectModelTest.c"
}

void
package_set_source (Package* self,
                    const gchar* value)
{
#line 114 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 114 "SerializableObjectModelTest.vala"
	if (g_strcmp0 (value, package_get_source (self)) != 0) {
#line 2280 "SerializableObjectModelTest.c"
		gchar* _tmp0_;
#line 114 "SerializableObjectModelTest.vala"
		_tmp0_ = g_strdup (value);
#line 114 "SerializableObjectModelTest.vala"
		_g_free0 (self->priv->_source);
#line 114 "SerializableObjectModelTest.vala"
		self->priv->_source = _tmp0_;
#line 114 "SerializableObjectModelTest.vala"
		g_object_notify_by_pspec ((GObject *) self, package_properties[PACKAGE_SOURCE_PROPERTY]);
#line 2290 "SerializableObjectModelTest.c"
	}
}

const gchar*
package_get_destiny (Package* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 115 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 115 "SerializableObjectModelTest.vala"
	_tmp0_ = self->priv->_destiny;
#line 115 "SerializableObjectModelTest.vala"
	result = _tmp0_;
#line 115 "SerializableObjectModelTest.vala"
	return result;
#line 2307 "SerializableObjectModelTest.c"
}

void
package_set_destiny (Package* self,
                     const gchar* value)
{
#line 115 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 115 "SerializableObjectModelTest.vala"
	if (g_strcmp0 (value, package_get_destiny (self)) != 0) {
#line 2318 "SerializableObjectModelTest.c"
		gchar* _tmp0_;
#line 115 "SerializableObjectModelTest.vala"
		_tmp0_ = g_strdup (value);
#line 115 "SerializableObjectModelTest.vala"
		_g_free0 (self->priv->_destiny);
#line 115 "SerializableObjectModelTest.vala"
		self->priv->_destiny = _tmp0_;
#line 115 "SerializableObjectModelTest.vala"
		g_object_notify_by_pspec ((GObject *) self, package_properties[PACKAGE_DESTINY_PROPERTY]);
#line 2328 "SerializableObjectModelTest.c"
	}
}

GArray*
package_get_tags (Package* self)
{
	GArray* result;
	GArray* _tmp0_;
#line 117 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 117 "SerializableObjectModelTest.vala"
	_tmp0_ = self->priv->_tags;
#line 117 "SerializableObjectModelTest.vala"
	result = _tmp0_;
#line 117 "SerializableObjectModelTest.vala"
	return result;
#line 2345 "SerializableObjectModelTest.c"
}

static void
package_class_init (PackageClass * klass,
                    gpointer klass_data)
{
#line 109 "SerializableObjectModelTest.vala"
	package_parent_class = g_type_class_peek_parent (klass);
#line 109 "SerializableObjectModelTest.vala"
	g_type_class_adjust_private_offset (klass, &Package_private_offset);
#line 109 "SerializableObjectModelTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->property_use_nick = (gboolean (*) (GXmlSerializableObjectModel*)) package_real_property_use_nick;
#line 109 "SerializableObjectModelTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->get_enable_unknown_serializable_property = (gboolean (*) (GXmlSerializableObjectModel*)) package_real_get_enable_unknown_serializable_property;
#line 109 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_package_get_property;
#line 109 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_package_set_property;
#line 109 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->finalize = package_finalize;
#line 109 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), PACKAGE_COMPUTER_PROPERTY, package_properties[PACKAGE_COMPUTER_PROPERTY] = g_param_spec_object ("computer", "computer", "computer", TYPE_COMPUTER, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 109 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), PACKAGE_MANUAL_PROPERTY, package_properties[PACKAGE_MANUAL_PROPERTY] = g_param_spec_object ("manual", "manual", "manual", TYPE_MANUAL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 109 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), PACKAGE_SOURCE_PROPERTY, package_properties[PACKAGE_SOURCE_PROPERTY] = g_param_spec_string ("source", "source", "source", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 109 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), PACKAGE_DESTINY_PROPERTY, package_properties[PACKAGE_DESTINY_PROPERTY] = g_param_spec_string ("destiny", "destiny", "destiny", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 109 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), PACKAGE_TAGS_PROPERTY, package_properties[PACKAGE_TAGS_PROPERTY] = g_param_spec_boxed ("tags", "tag", "tags in package", G_TYPE_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
#line 2376 "SerializableObjectModelTest.c"
}

static void
package_instance_init (Package * self,
                       gpointer klass)
{
	GArray* _tmp0_;
#line 109 "SerializableObjectModelTest.vala"
	self->priv = package_get_instance_private (self);
#line 111 "SerializableObjectModelTest.vala"
	_tmp0_ = g_array_new (TRUE, TRUE, sizeof (gchar*));
#line 111 "SerializableObjectModelTest.vala"
	g_array_set_clear_func (_tmp0_, (GDestroyNotify) _vala_gchar_free_function_content_of);
#line 111 "SerializableObjectModelTest.vala"
	self->priv->_tags = _tmp0_;
#line 2392 "SerializableObjectModelTest.c"
}

static void
package_finalize (GObject * obj)
{
	Package * self;
#line 109 "SerializableObjectModelTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PACKAGE, Package);
#line 111 "SerializableObjectModelTest.vala"
	_g_array_unref0 (self->priv->_tags);
#line 112 "SerializableObjectModelTest.vala"
	_g_object_unref0 (self->priv->_computer);
#line 113 "SerializableObjectModelTest.vala"
	_g_object_unref0 (self->priv->_manual);
#line 114 "SerializableObjectModelTest.vala"
	_g_free0 (self->priv->_source);
#line 115 "SerializableObjectModelTest.vala"
	_g_free0 (self->priv->_destiny);
#line 109 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (package_parent_class)->finalize (obj);
#line 2413 "SerializableObjectModelTest.c"
}

GType
package_get_type (void)
{
	static volatile gsize package_type_id__volatile = 0;
	if (g_once_init_enter (&package_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PackageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) package_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Package), 0, (GInstanceInitFunc) package_instance_init, NULL };
		GType package_type_id;
		package_type_id = g_type_register_static (TYPE_OBJECT_MODEL, "Package", &g_define_type_info, 0);
		Package_private_offset = g_type_add_instance_private (package_type_id, sizeof (PackagePrivate));
		g_once_init_leave (&package_type_id__volatile, package_type_id);
	}
	return package_type_id__volatile;
}

static void
_vala_package_get_property (GObject * object,
                            guint property_id,
                            GValue * value,
                            GParamSpec * pspec)
{
	Package * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_PACKAGE, Package);
#line 109 "SerializableObjectModelTest.vala"
	switch (property_id) {
#line 109 "SerializableObjectModelTest.vala"
		case PACKAGE_COMPUTER_PROPERTY:
#line 109 "SerializableObjectModelTest.vala"
		g_value_set_object (value, package_get_computer (self));
#line 109 "SerializableObjectModelTest.vala"
		break;
#line 109 "SerializableObjectModelTest.vala"
		case PACKAGE_MANUAL_PROPERTY:
#line 109 "SerializableObjectModelTest.vala"
		g_value_set_object (value, package_get_manual (self));
#line 109 "SerializableObjectModelTest.vala"
		break;
#line 109 "SerializableObjectModelTest.vala"
		case PACKAGE_SOURCE_PROPERTY:
#line 109 "SerializableObjectModelTest.vala"
		g_value_set_string (value, package_get_source (self));
#line 109 "SerializableObjectModelTest.vala"
		break;
#line 109 "SerializableObjectModelTest.vala"
		case PACKAGE_DESTINY_PROPERTY:
#line 109 "SerializableObjectModelTest.vala"
		g_value_set_string (value, package_get_destiny (self));
#line 109 "SerializableObjectModelTest.vala"
		break;
#line 109 "SerializableObjectModelTest.vala"
		case PACKAGE_TAGS_PROPERTY:
#line 109 "SerializableObjectModelTest.vala"
		g_value_set_boxed (value, package_get_tags (self));
#line 109 "SerializableObjectModelTest.vala"
		break;
#line 2470 "SerializableObjectModelTest.c"
		default:
#line 109 "SerializableObjectModelTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 109 "SerializableObjectModelTest.vala"
		break;
#line 2476 "SerializableObjectModelTest.c"
	}
}

static void
_vala_package_set_property (GObject * object,
                            guint property_id,
                            const GValue * value,
                            GParamSpec * pspec)
{
	Package * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_PACKAGE, Package);
#line 109 "SerializableObjectModelTest.vala"
	switch (property_id) {
#line 109 "SerializableObjectModelTest.vala"
		case PACKAGE_COMPUTER_PROPERTY:
#line 109 "SerializableObjectModelTest.vala"
		package_set_computer (self, g_value_get_object (value));
#line 109 "SerializableObjectModelTest.vala"
		break;
#line 109 "SerializableObjectModelTest.vala"
		case PACKAGE_MANUAL_PROPERTY:
#line 109 "SerializableObjectModelTest.vala"
		package_set_manual (self, g_value_get_object (value));
#line 109 "SerializableObjectModelTest.vala"
		break;
#line 109 "SerializableObjectModelTest.vala"
		case PACKAGE_SOURCE_PROPERTY:
#line 109 "SerializableObjectModelTest.vala"
		package_set_source (self, g_value_get_string (value));
#line 109 "SerializableObjectModelTest.vala"
		break;
#line 109 "SerializableObjectModelTest.vala"
		case PACKAGE_DESTINY_PROPERTY:
#line 109 "SerializableObjectModelTest.vala"
		package_set_destiny (self, g_value_get_string (value));
#line 109 "SerializableObjectModelTest.vala"
		break;
#line 2514 "SerializableObjectModelTest.c"
		default:
#line 109 "SerializableObjectModelTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 109 "SerializableObjectModelTest.vala"
		break;
#line 2520 "SerializableObjectModelTest.c"
	}
}

static inline gpointer
monitor_get_instance_private (Monitor* self)
{
	return G_STRUCT_MEMBER_P (self, Monitor_private_offset);
}

static gboolean
monitor_real_property_use_nick (GXmlSerializableObjectModel* base)
{
	Monitor * self;
	gboolean result = FALSE;
#line 172 "SerializableObjectModelTest.vala"
	self = (Monitor*) base;
#line 172 "SerializableObjectModelTest.vala"
	result = TRUE;
#line 172 "SerializableObjectModelTest.vala"
	return result;
#line 2541 "SerializableObjectModelTest.c"
}

Monitor*
monitor_construct (GType object_type)
{
	Monitor * self = NULL;
#line 164 "SerializableObjectModelTest.vala"
	self = (Monitor*) object_model_construct (object_type);
#line 164 "SerializableObjectModelTest.vala"
	return self;
#line 2552 "SerializableObjectModelTest.c"
}

Monitor*
monitor_new (void)
{
#line 164 "SerializableObjectModelTest.vala"
	return monitor_construct (TYPE_MONITOR);
#line 2560 "SerializableObjectModelTest.c"
}

const gchar*
monitor_get_resolution (Monitor* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 166 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 166 "SerializableObjectModelTest.vala"
	_tmp0_ = self->priv->_resolution;
#line 166 "SerializableObjectModelTest.vala"
	result = _tmp0_;
#line 166 "SerializableObjectModelTest.vala"
	return result;
#line 2576 "SerializableObjectModelTest.c"
}

void
monitor_set_resolution (Monitor* self,
                        const gchar* value)
{
#line 166 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 166 "SerializableObjectModelTest.vala"
	if (g_strcmp0 (value, monitor_get_resolution (self)) != 0) {
#line 2587 "SerializableObjectModelTest.c"
		gchar* _tmp0_;
#line 166 "SerializableObjectModelTest.vala"
		_tmp0_ = g_strdup (value);
#line 166 "SerializableObjectModelTest.vala"
		_g_free0 (self->priv->_resolution);
#line 166 "SerializableObjectModelTest.vala"
		self->priv->_resolution = _tmp0_;
#line 166 "SerializableObjectModelTest.vala"
		g_object_notify_by_pspec ((GObject *) self, monitor_properties[MONITOR_RESOLUTION_PROPERTY]);
#line 2597 "SerializableObjectModelTest.c"
	}
}

gint
monitor_get_ac_power (Monitor* self)
{
	gint result;
#line 168 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 168 "SerializableObjectModelTest.vala"
	result = self->priv->_ac_power;
#line 168 "SerializableObjectModelTest.vala"
	return result;
#line 2611 "SerializableObjectModelTest.c"
}

void
monitor_set_ac_power (Monitor* self,
                      gint value)
{
#line 168 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 168 "SerializableObjectModelTest.vala"
	if (monitor_get_ac_power (self) != value) {
#line 168 "SerializableObjectModelTest.vala"
		self->priv->_ac_power = value;
#line 168 "SerializableObjectModelTest.vala"
		g_object_notify_by_pspec ((GObject *) self, monitor_properties[MONITOR_AC_POWER_PROPERTY]);
#line 2626 "SerializableObjectModelTest.c"
	}
}

gint
monitor_get_dc_power (Monitor* self)
{
	gint result;
#line 170 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 170 "SerializableObjectModelTest.vala"
	result = self->priv->_dc_power;
#line 170 "SerializableObjectModelTest.vala"
	return result;
#line 2640 "SerializableObjectModelTest.c"
}

void
monitor_set_dc_power (Monitor* self,
                      gint value)
{
#line 170 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 170 "SerializableObjectModelTest.vala"
	if (monitor_get_dc_power (self) != value) {
#line 170 "SerializableObjectModelTest.vala"
		self->priv->_dc_power = value;
#line 170 "SerializableObjectModelTest.vala"
		g_object_notify_by_pspec ((GObject *) self, monitor_properties[MONITOR_DC_POWER_PROPERTY]);
#line 2655 "SerializableObjectModelTest.c"
	}
}

static void
monitor_class_init (MonitorClass * klass,
                    gpointer klass_data)
{
#line 164 "SerializableObjectModelTest.vala"
	monitor_parent_class = g_type_class_peek_parent (klass);
#line 164 "SerializableObjectModelTest.vala"
	g_type_class_adjust_private_offset (klass, &Monitor_private_offset);
#line 164 "SerializableObjectModelTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->property_use_nick = (gboolean (*) (GXmlSerializableObjectModel*)) monitor_real_property_use_nick;
#line 164 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_monitor_get_property;
#line 164 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_monitor_set_property;
#line 164 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->finalize = monitor_finalize;
#line 164 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), MONITOR_RESOLUTION_PROPERTY, monitor_properties[MONITOR_RESOLUTION_PROPERTY] = g_param_spec_string ("resolution", "resolution", "resolution", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 164 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), MONITOR_AC_POWER_PROPERTY, monitor_properties[MONITOR_AC_POWER_PROPERTY] = g_param_spec_int ("ac-power", "AcPower", "ac-power", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 164 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), MONITOR_DC_POWER_PROPERTY, monitor_properties[MONITOR_DC_POWER_PROPERTY] = g_param_spec_int ("dc-power", "DcPower", "dc-power", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2681 "SerializableObjectModelTest.c"
}

static void
monitor_instance_init (Monitor * self,
                       gpointer klass)
{
#line 164 "SerializableObjectModelTest.vala"
	self->priv = monitor_get_instance_private (self);
#line 2690 "SerializableObjectModelTest.c"
}

static void
monitor_finalize (GObject * obj)
{
	Monitor * self;
#line 164 "SerializableObjectModelTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_MONITOR, Monitor);
#line 166 "SerializableObjectModelTest.vala"
	_g_free0 (self->priv->_resolution);
#line 164 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (monitor_parent_class)->finalize (obj);
#line 2703 "SerializableObjectModelTest.c"
}

GType
monitor_get_type (void)
{
	static volatile gsize monitor_type_id__volatile = 0;
	if (g_once_init_enter (&monitor_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (MonitorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) monitor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Monitor), 0, (GInstanceInitFunc) monitor_instance_init, NULL };
		GType monitor_type_id;
		monitor_type_id = g_type_register_static (TYPE_OBJECT_MODEL, "Monitor", &g_define_type_info, 0);
		Monitor_private_offset = g_type_add_instance_private (monitor_type_id, sizeof (MonitorPrivate));
		g_once_init_leave (&monitor_type_id__volatile, monitor_type_id);
	}
	return monitor_type_id__volatile;
}

static void
_vala_monitor_get_property (GObject * object,
                            guint property_id,
                            GValue * value,
                            GParamSpec * pspec)
{
	Monitor * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_MONITOR, Monitor);
#line 164 "SerializableObjectModelTest.vala"
	switch (property_id) {
#line 164 "SerializableObjectModelTest.vala"
		case MONITOR_RESOLUTION_PROPERTY:
#line 164 "SerializableObjectModelTest.vala"
		g_value_set_string (value, monitor_get_resolution (self));
#line 164 "SerializableObjectModelTest.vala"
		break;
#line 164 "SerializableObjectModelTest.vala"
		case MONITOR_AC_POWER_PROPERTY:
#line 164 "SerializableObjectModelTest.vala"
		g_value_set_int (value, monitor_get_ac_power (self));
#line 164 "SerializableObjectModelTest.vala"
		break;
#line 164 "SerializableObjectModelTest.vala"
		case MONITOR_DC_POWER_PROPERTY:
#line 164 "SerializableObjectModelTest.vala"
		g_value_set_int (value, monitor_get_dc_power (self));
#line 164 "SerializableObjectModelTest.vala"
		break;
#line 2748 "SerializableObjectModelTest.c"
		default:
#line 164 "SerializableObjectModelTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 164 "SerializableObjectModelTest.vala"
		break;
#line 2754 "SerializableObjectModelTest.c"
	}
}

static void
_vala_monitor_set_property (GObject * object,
                            guint property_id,
                            const GValue * value,
                            GParamSpec * pspec)
{
	Monitor * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_MONITOR, Monitor);
#line 164 "SerializableObjectModelTest.vala"
	switch (property_id) {
#line 164 "SerializableObjectModelTest.vala"
		case MONITOR_RESOLUTION_PROPERTY:
#line 164 "SerializableObjectModelTest.vala"
		monitor_set_resolution (self, g_value_get_string (value));
#line 164 "SerializableObjectModelTest.vala"
		break;
#line 164 "SerializableObjectModelTest.vala"
		case MONITOR_AC_POWER_PROPERTY:
#line 164 "SerializableObjectModelTest.vala"
		monitor_set_ac_power (self, g_value_get_int (value));
#line 164 "SerializableObjectModelTest.vala"
		break;
#line 164 "SerializableObjectModelTest.vala"
		case MONITOR_DC_POWER_PROPERTY:
#line 164 "SerializableObjectModelTest.vala"
		monitor_set_dc_power (self, g_value_get_int (value));
#line 164 "SerializableObjectModelTest.vala"
		break;
#line 2786 "SerializableObjectModelTest.c"
		default:
#line 164 "SerializableObjectModelTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 164 "SerializableObjectModelTest.vala"
		break;
#line 2792 "SerializableObjectModelTest.c"
	}
}

static inline gpointer
cpu_get_instance_private (Cpu* self)
{
	return G_STRUCT_MEMBER_P (self, Cpu_private_offset);
}

Cpu*
cpu_construct (GType object_type)
{
	Cpu * self = NULL;
	GeeArrayList* _tmp0_;
	GeeArrayList* _tmp1_;
#line 181 "SerializableObjectModelTest.vala"
	self = (Cpu*) object_model_construct (object_type);
#line 183 "SerializableObjectModelTest.vala"
	_tmp0_ = gee_array_list_new (G_TYPE_INT, NULL, NULL, NULL, NULL, NULL);
#line 183 "SerializableObjectModelTest.vala"
	_tmp1_ = _tmp0_;
#line 183 "SerializableObjectModelTest.vala"
	cpu_set_piles (self, _tmp1_);
#line 183 "SerializableObjectModelTest.vala"
	_g_object_unref0 (_tmp1_);
#line 181 "SerializableObjectModelTest.vala"
	return self;
#line 2820 "SerializableObjectModelTest.c"
}

Cpu*
cpu_new (void)
{
#line 181 "SerializableObjectModelTest.vala"
	return cpu_construct (TYPE_CPU);
#line 2828 "SerializableObjectModelTest.c"
}

gchar*
cpu_piles_to_string (Cpu* self)
{
	gchar* result = NULL;
	gchar* str = NULL;
	gchar* _tmp0_;
	gint i = 0;
#line 213 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 215 "SerializableObjectModelTest.vala"
	_tmp0_ = g_strdup ("");
#line 215 "SerializableObjectModelTest.vala"
	str = _tmp0_;
#line 216 "SerializableObjectModelTest.vala"
	i = 0;
#line 217 "SerializableObjectModelTest.vala"
	while (TRUE) {
#line 2848 "SerializableObjectModelTest.c"
		GeeArrayList* _tmp1_;
		gint _tmp2_;
		gint _tmp3_;
		const gchar* _tmp4_;
		GeeArrayList* _tmp5_;
		gpointer _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		GeeArrayList* _tmp10_;
		gint _tmp11_;
		gint _tmp12_;
		gint _tmp15_;
#line 217 "SerializableObjectModelTest.vala"
		_tmp1_ = self->priv->_piles;
#line 217 "SerializableObjectModelTest.vala"
		_tmp2_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp1_);
#line 217 "SerializableObjectModelTest.vala"
		_tmp3_ = _tmp2_;
#line 217 "SerializableObjectModelTest.vala"
		if (!(i < _tmp3_)) {
#line 217 "SerializableObjectModelTest.vala"
			break;
#line 2872 "SerializableObjectModelTest.c"
		}
#line 218 "SerializableObjectModelTest.vala"
		_tmp4_ = str;
#line 218 "SerializableObjectModelTest.vala"
		_tmp5_ = self->priv->_piles;
#line 218 "SerializableObjectModelTest.vala"
		_tmp6_ = gee_abstract_list_get ((GeeAbstractList*) _tmp5_, i);
#line 218 "SerializableObjectModelTest.vala"
		_tmp7_ = g_strdup_printf ("%i", (gint) ((gintptr) _tmp6_));
#line 218 "SerializableObjectModelTest.vala"
		_tmp8_ = _tmp7_;
#line 218 "SerializableObjectModelTest.vala"
		_tmp9_ = g_strconcat (_tmp4_, _tmp8_, NULL);
#line 218 "SerializableObjectModelTest.vala"
		_g_free0 (str);
#line 218 "SerializableObjectModelTest.vala"
		str = _tmp9_;
#line 218 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp8_);
#line 219 "SerializableObjectModelTest.vala"
		_tmp10_ = self->priv->_piles;
#line 219 "SerializableObjectModelTest.vala"
		_tmp11_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp10_);
#line 219 "SerializableObjectModelTest.vala"
		_tmp12_ = _tmp11_;
#line 219 "SerializableObjectModelTest.vala"
		if ((i + 1) < _tmp12_) {
#line 2900 "SerializableObjectModelTest.c"
			const gchar* _tmp13_;
			gchar* _tmp14_;
#line 220 "SerializableObjectModelTest.vala"
			_tmp13_ = str;
#line 220 "SerializableObjectModelTest.vala"
			_tmp14_ = g_strconcat (_tmp13_, ",", NULL);
#line 220 "SerializableObjectModelTest.vala"
			_g_free0 (str);
#line 220 "SerializableObjectModelTest.vala"
			str = _tmp14_;
#line 2911 "SerializableObjectModelTest.c"
		}
#line 221 "SerializableObjectModelTest.vala"
		_tmp15_ = i;
#line 221 "SerializableObjectModelTest.vala"
		i = _tmp15_ + 1;
#line 2917 "SerializableObjectModelTest.c"
	}
#line 223 "SerializableObjectModelTest.vala"
	result = str;
#line 223 "SerializableObjectModelTest.vala"
	return result;
#line 2923 "SerializableObjectModelTest.c"
}

gfloat
cpu_get_ghz (Cpu* self)
{
	gfloat result;
#line 178 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, 0.0F);
#line 178 "SerializableObjectModelTest.vala"
	result = self->priv->_ghz;
#line 178 "SerializableObjectModelTest.vala"
	return result;
#line 2936 "SerializableObjectModelTest.c"
}

void
cpu_set_ghz (Cpu* self,
             gfloat value)
{
#line 178 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 178 "SerializableObjectModelTest.vala"
	if (cpu_get_ghz (self) != value) {
#line 178 "SerializableObjectModelTest.vala"
		self->priv->_ghz = value;
#line 178 "SerializableObjectModelTest.vala"
		g_object_notify_by_pspec ((GObject *) self, cpu_properties[CPU_GHZ_PROPERTY]);
#line 2951 "SerializableObjectModelTest.c"
	}
}

GeeArrayList*
cpu_get_piles (Cpu* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
#line 179 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 179 "SerializableObjectModelTest.vala"
	_tmp0_ = self->priv->_piles;
#line 179 "SerializableObjectModelTest.vala"
	result = _tmp0_;
#line 179 "SerializableObjectModelTest.vala"
	return result;
#line 2968 "SerializableObjectModelTest.c"
}

void
cpu_set_piles (Cpu* self,
               GeeArrayList* value)
{
#line 179 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 179 "SerializableObjectModelTest.vala"
	if (cpu_get_piles (self) != value) {
#line 2979 "SerializableObjectModelTest.c"
		GeeArrayList* _tmp0_;
#line 179 "SerializableObjectModelTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 179 "SerializableObjectModelTest.vala"
		_g_object_unref0 (self->priv->_piles);
#line 179 "SerializableObjectModelTest.vala"
		self->priv->_piles = _tmp0_;
#line 179 "SerializableObjectModelTest.vala"
		g_object_notify_by_pspec ((GObject *) self, cpu_properties[CPU_PILES_PROPERTY]);
#line 2989 "SerializableObjectModelTest.c"
	}
}

static void
cpu_class_init (CpuClass * klass,
                gpointer klass_data)
{
#line 176 "SerializableObjectModelTest.vala"
	cpu_parent_class = g_type_class_peek_parent (klass);
#line 176 "SerializableObjectModelTest.vala"
	g_type_class_adjust_private_offset (klass, &Cpu_private_offset);
#line 176 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_cpu_get_property;
#line 176 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_cpu_set_property;
#line 176 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->finalize = cpu_finalize;
#line 176 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), CPU_GHZ_PROPERTY, cpu_properties[CPU_GHZ_PROPERTY] = g_param_spec_float ("ghz", "ghz", "ghz", -G_MAXFLOAT, G_MAXFLOAT, (gfloat) 0.0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 176 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), CPU_PILES_PROPERTY, cpu_properties[CPU_PILES_PROPERTY] = g_param_spec_object ("piles", "piles", "piles", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3011 "SerializableObjectModelTest.c"
}

static void
cpu_instance_init (Cpu * self,
                   gpointer klass)
{
#line 176 "SerializableObjectModelTest.vala"
	self->priv = cpu_get_instance_private (self);
#line 178 "SerializableObjectModelTest.vala"
	self->priv->_ghz = (gfloat) 0.0;
#line 3022 "SerializableObjectModelTest.c"
}

static void
cpu_finalize (GObject * obj)
{
	Cpu * self;
#line 176 "SerializableObjectModelTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_CPU, Cpu);
#line 179 "SerializableObjectModelTest.vala"
	_g_object_unref0 (self->priv->_piles);
#line 176 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (cpu_parent_class)->finalize (obj);
#line 3035 "SerializableObjectModelTest.c"
}

GType
cpu_get_type (void)
{
	static volatile gsize cpu_type_id__volatile = 0;
	if (g_once_init_enter (&cpu_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (CpuClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) cpu_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Cpu), 0, (GInstanceInitFunc) cpu_instance_init, NULL };
		GType cpu_type_id;
		cpu_type_id = g_type_register_static (TYPE_OBJECT_MODEL, "Cpu", &g_define_type_info, 0);
		Cpu_private_offset = g_type_add_instance_private (cpu_type_id, sizeof (CpuPrivate));
		g_once_init_leave (&cpu_type_id__volatile, cpu_type_id);
	}
	return cpu_type_id__volatile;
}

static void
_vala_cpu_get_property (GObject * object,
                        guint property_id,
                        GValue * value,
                        GParamSpec * pspec)
{
	Cpu * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_CPU, Cpu);
#line 176 "SerializableObjectModelTest.vala"
	switch (property_id) {
#line 176 "SerializableObjectModelTest.vala"
		case CPU_GHZ_PROPERTY:
#line 176 "SerializableObjectModelTest.vala"
		g_value_set_float (value, cpu_get_ghz (self));
#line 176 "SerializableObjectModelTest.vala"
		break;
#line 176 "SerializableObjectModelTest.vala"
		case CPU_PILES_PROPERTY:
#line 176 "SerializableObjectModelTest.vala"
		g_value_set_object (value, cpu_get_piles (self));
#line 176 "SerializableObjectModelTest.vala"
		break;
#line 3074 "SerializableObjectModelTest.c"
		default:
#line 176 "SerializableObjectModelTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 176 "SerializableObjectModelTest.vala"
		break;
#line 3080 "SerializableObjectModelTest.c"
	}
}

static void
_vala_cpu_set_property (GObject * object,
                        guint property_id,
                        const GValue * value,
                        GParamSpec * pspec)
{
	Cpu * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_CPU, Cpu);
#line 176 "SerializableObjectModelTest.vala"
	switch (property_id) {
#line 176 "SerializableObjectModelTest.vala"
		case CPU_GHZ_PROPERTY:
#line 176 "SerializableObjectModelTest.vala"
		cpu_set_ghz (self, g_value_get_float (value));
#line 176 "SerializableObjectModelTest.vala"
		break;
#line 176 "SerializableObjectModelTest.vala"
		case CPU_PILES_PROPERTY:
#line 176 "SerializableObjectModelTest.vala"
		cpu_set_piles (self, g_value_get_object (value));
#line 176 "SerializableObjectModelTest.vala"
		break;
#line 3106 "SerializableObjectModelTest.c"
		default:
#line 176 "SerializableObjectModelTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 176 "SerializableObjectModelTest.vala"
		break;
#line 3112 "SerializableObjectModelTest.c"
	}
}

static inline gpointer
node_name_get_instance_private (NodeName* self)
{
	return G_STRUCT_MEMBER_P (self, NodeName_private_offset);
}

static gchar*
node_name_real_node_name (GXmlSerializableObjectModel* base)
{
	NodeName * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 230 "SerializableObjectModelTest.vala"
	self = (NodeName*) base;
#line 230 "SerializableObjectModelTest.vala"
	_tmp0_ = g_strdup ("NodeName");
#line 230 "SerializableObjectModelTest.vala"
	result = _tmp0_;
#line 230 "SerializableObjectModelTest.vala"
	return result;
#line 3136 "SerializableObjectModelTest.c"
}

NodeName*
node_name_construct (GType object_type)
{
	NodeName * self = NULL;
#line 227 "SerializableObjectModelTest.vala"
	self = (NodeName*) object_model_construct (object_type);
#line 227 "SerializableObjectModelTest.vala"
	return self;
#line 3147 "SerializableObjectModelTest.c"
}

NodeName*
node_name_new (void)
{
#line 227 "SerializableObjectModelTest.vala"
	return node_name_construct (TYPE_NODE_NAME);
#line 3155 "SerializableObjectModelTest.c"
}

gboolean
node_name_get_invalid (NodeName* self)
{
	gboolean result;
#line 229 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 229 "SerializableObjectModelTest.vala"
	result = self->priv->_invalid;
#line 229 "SerializableObjectModelTest.vala"
	return result;
#line 3168 "SerializableObjectModelTest.c"
}

void
node_name_set_invalid (NodeName* self,
                       gboolean value)
{
#line 229 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 229 "SerializableObjectModelTest.vala"
	if (node_name_get_invalid (self) != value) {
#line 229 "SerializableObjectModelTest.vala"
		self->priv->_invalid = value;
#line 229 "SerializableObjectModelTest.vala"
		g_object_notify_by_pspec ((GObject *) self, node_name_properties[NODE_NAME_INVALID_PROPERTY]);
#line 3183 "SerializableObjectModelTest.c"
	}
}

static void
node_name_class_init (NodeNameClass * klass,
                      gpointer klass_data)
{
#line 227 "SerializableObjectModelTest.vala"
	node_name_parent_class = g_type_class_peek_parent (klass);
#line 227 "SerializableObjectModelTest.vala"
	g_type_class_adjust_private_offset (klass, &NodeName_private_offset);
#line 227 "SerializableObjectModelTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) node_name_real_node_name;
#line 227 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_node_name_get_property;
#line 227 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_node_name_set_property;
#line 227 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->finalize = node_name_finalize;
#line 227 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), NODE_NAME_INVALID_PROPERTY, node_name_properties[NODE_NAME_INVALID_PROPERTY] = g_param_spec_boolean ("invalid", "invalid", "invalid", TRUE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3205 "SerializableObjectModelTest.c"
}

static void
node_name_instance_init (NodeName * self,
                         gpointer klass)
{
#line 227 "SerializableObjectModelTest.vala"
	self->priv = node_name_get_instance_private (self);
#line 229 "SerializableObjectModelTest.vala"
	self->priv->_invalid = TRUE;
#line 3216 "SerializableObjectModelTest.c"
}

static void
node_name_finalize (GObject * obj)
{
	NodeName * self;
#line 227 "SerializableObjectModelTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_NODE_NAME, NodeName);
#line 227 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (node_name_parent_class)->finalize (obj);
#line 3227 "SerializableObjectModelTest.c"
}

GType
node_name_get_type (void)
{
	static volatile gsize node_name_type_id__volatile = 0;
	if (g_once_init_enter (&node_name_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (NodeNameClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) node_name_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (NodeName), 0, (GInstanceInitFunc) node_name_instance_init, NULL };
		GType node_name_type_id;
		node_name_type_id = g_type_register_static (TYPE_OBJECT_MODEL, "NodeName", &g_define_type_info, 0);
		NodeName_private_offset = g_type_add_instance_private (node_name_type_id, sizeof (NodeNamePrivate));
		g_once_init_leave (&node_name_type_id__volatile, node_name_type_id);
	}
	return node_name_type_id__volatile;
}

static void
_vala_node_name_get_property (GObject * object,
                              guint property_id,
                              GValue * value,
                              GParamSpec * pspec)
{
	NodeName * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_NODE_NAME, NodeName);
#line 227 "SerializableObjectModelTest.vala"
	switch (property_id) {
#line 227 "SerializableObjectModelTest.vala"
		case NODE_NAME_INVALID_PROPERTY:
#line 227 "SerializableObjectModelTest.vala"
		g_value_set_boolean (value, node_name_get_invalid (self));
#line 227 "SerializableObjectModelTest.vala"
		break;
#line 3260 "SerializableObjectModelTest.c"
		default:
#line 227 "SerializableObjectModelTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 227 "SerializableObjectModelTest.vala"
		break;
#line 3266 "SerializableObjectModelTest.c"
	}
}

static void
_vala_node_name_set_property (GObject * object,
                              guint property_id,
                              const GValue * value,
                              GParamSpec * pspec)
{
	NodeName * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_NODE_NAME, NodeName);
#line 227 "SerializableObjectModelTest.vala"
	switch (property_id) {
#line 227 "SerializableObjectModelTest.vala"
		case NODE_NAME_INVALID_PROPERTY:
#line 227 "SerializableObjectModelTest.vala"
		node_name_set_invalid (self, g_value_get_boolean (value));
#line 227 "SerializableObjectModelTest.vala"
		break;
#line 3286 "SerializableObjectModelTest.c"
		default:
#line 227 "SerializableObjectModelTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 227 "SerializableObjectModelTest.vala"
		break;
#line 3292 "SerializableObjectModelTest.c"
	}
}

static inline gpointer
configuration_get_instance_private (Configuration* self)
{
	return G_STRUCT_MEMBER_P (self, Configuration_private_offset);
}

static gchar*
configuration_real_node_name (GXmlSerializableObjectModel* base)
{
	Configuration * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 237 "SerializableObjectModelTest.vala"
	self = (Configuration*) base;
#line 237 "SerializableObjectModelTest.vala"
	_tmp0_ = g_strdup ("Configuration");
#line 237 "SerializableObjectModelTest.vala"
	result = _tmp0_;
#line 237 "SerializableObjectModelTest.vala"
	return result;
#line 3316 "SerializableObjectModelTest.c"
}

static gboolean
configuration_real_property_use_nick (GXmlSerializableObjectModel* base)
{
	Configuration * self;
	gboolean result = FALSE;
#line 238 "SerializableObjectModelTest.vala"
	self = (Configuration*) base;
#line 238 "SerializableObjectModelTest.vala"
	result = TRUE;
#line 238 "SerializableObjectModelTest.vala"
	return result;
#line 3330 "SerializableObjectModelTest.c"
}

static void
_g_param_spec_unref0_ (gpointer var)
{
#line 243 "SerializableObjectModelTest.vala"
	(var == NULL) ? NULL : (var = (g_param_spec_unref (var), NULL));
#line 3338 "SerializableObjectModelTest.c"
}

static void
_vala_array_add1 (GParamSpec** * array,
                  int* length,
                  int* size,
                  GParamSpec* value)
{
#line 248 "SerializableObjectModelTest.vala"
	if ((*length) == (*size)) {
#line 248 "SerializableObjectModelTest.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 248 "SerializableObjectModelTest.vala"
		*array = g_renew (GParamSpec*, *array, (*size) + 1);
#line 3353 "SerializableObjectModelTest.c"
	}
#line 248 "SerializableObjectModelTest.vala"
	(*array)[(*length)++] = value;
#line 248 "SerializableObjectModelTest.vala"
	(*array)[*length] = NULL;
#line 3359 "SerializableObjectModelTest.c"
}

static GParamSpec**
configuration_real_list_serializable_properties (GXmlSerializableObjectModel* base,
                                                 gint* result_length1)
{
	Configuration * self;
	GParamSpec** result = NULL;
	GParamSpec** props = NULL;
	GParamSpec** _tmp0_;
	gint props_length1;
	gint _props_size_;
	GHashTable* l = NULL;
	GHashFunc _tmp1_;
	GEqualFunc _tmp2_;
	GHashTable* _tmp3_;
	GHashTable* _tmp4_;
	gchar* _tmp5_;
	GObjectClass* _tmp6_;
	GParamSpec* _tmp7_;
	GParamSpec* _tmp8_;
	gint _tmp9_ = 0;
	GParamSpec** _tmp10_;
	GParamSpec** _tmp18_;
	gint _tmp18__length1;
#line 240 "SerializableObjectModelTest.vala"
	self = (Configuration*) base;
#line 242 "SerializableObjectModelTest.vala"
	_tmp0_ = g_new0 (GParamSpec*, 0 + 1);
#line 242 "SerializableObjectModelTest.vala"
	props = _tmp0_;
#line 242 "SerializableObjectModelTest.vala"
	props_length1 = 0;
#line 242 "SerializableObjectModelTest.vala"
	_props_size_ = props_length1;
#line 243 "SerializableObjectModelTest.vala"
	_tmp1_ = g_str_hash;
#line 243 "SerializableObjectModelTest.vala"
	_tmp2_ = g_str_equal;
#line 243 "SerializableObjectModelTest.vala"
	_tmp3_ = g_hash_table_new_full (_tmp1_, _tmp2_, _g_free0_, _g_param_spec_unref0_);
#line 243 "SerializableObjectModelTest.vala"
	l = _tmp3_;
#line 244 "SerializableObjectModelTest.vala"
	_tmp4_ = l;
#line 244 "SerializableObjectModelTest.vala"
	_tmp5_ = g_strdup ("invalid");
#line 244 "SerializableObjectModelTest.vala"
	_tmp6_ = G_OBJECT_GET_CLASS ((GObject*) self);
#line 244 "SerializableObjectModelTest.vala"
	_tmp7_ = g_object_class_find_property (_tmp6_, "invalid");
#line 244 "SerializableObjectModelTest.vala"
	_tmp8_ = _g_param_spec_ref0 (_tmp7_);
#line 244 "SerializableObjectModelTest.vala"
	g_hash_table_insert (_tmp4_, _tmp5_, _tmp8_);
#line 246 "SerializableObjectModelTest.vala"
	_tmp10_ = gxml_serializable_default_list_serializable_properties ((GXmlSerializable*) self, &_tmp9_);
#line 3417 "SerializableObjectModelTest.c"
	{
		GParamSpec** spec_collection = NULL;
		gint spec_collection_length1 = 0;
		gint _spec_collection_size_ = 0;
		gint spec_it = 0;
#line 246 "SerializableObjectModelTest.vala"
		spec_collection = _tmp10_;
#line 246 "SerializableObjectModelTest.vala"
		spec_collection_length1 = _tmp9_;
#line 246 "SerializableObjectModelTest.vala"
		for (spec_it = 0; spec_it < _tmp9_; spec_it = spec_it + 1) {
#line 3429 "SerializableObjectModelTest.c"
			GParamSpec* _tmp11_;
			GParamSpec* spec = NULL;
#line 246 "SerializableObjectModelTest.vala"
			_tmp11_ = _g_param_spec_ref0 (spec_collection[spec_it]);
#line 246 "SerializableObjectModelTest.vala"
			spec = _tmp11_;
#line 3436 "SerializableObjectModelTest.c"
			{
				GHashTable* _tmp12_;
				GParamSpec* _tmp13_;
				const gchar* _tmp14_;
#line 247 "SerializableObjectModelTest.vala"
				_tmp12_ = l;
#line 247 "SerializableObjectModelTest.vala"
				_tmp13_ = spec;
#line 247 "SerializableObjectModelTest.vala"
				_tmp14_ = _tmp13_->name;
#line 247 "SerializableObjectModelTest.vala"
				if (!g_hash_table_contains (_tmp12_, _tmp14_)) {
#line 3449 "SerializableObjectModelTest.c"
					GParamSpec** _tmp15_;
					gint _tmp15__length1;
					GParamSpec* _tmp16_;
					GParamSpec* _tmp17_;
#line 248 "SerializableObjectModelTest.vala"
					_tmp15_ = props;
#line 248 "SerializableObjectModelTest.vala"
					_tmp15__length1 = props_length1;
#line 248 "SerializableObjectModelTest.vala"
					_tmp16_ = spec;
#line 248 "SerializableObjectModelTest.vala"
					_tmp17_ = _g_param_spec_ref0 (_tmp16_);
#line 248 "SerializableObjectModelTest.vala"
					_vala_array_add1 (&props, &props_length1, &_props_size_, _tmp17_);
#line 3464 "SerializableObjectModelTest.c"
				}
#line 246 "SerializableObjectModelTest.vala"
				_g_param_spec_unref0 (spec);
#line 3468 "SerializableObjectModelTest.c"
			}
		}
#line 246 "SerializableObjectModelTest.vala"
		spec_collection = (_vala_array_free (spec_collection, spec_collection_length1, (GDestroyNotify) g_param_spec_unref), NULL);
#line 3473 "SerializableObjectModelTest.c"
	}
#line 251 "SerializableObjectModelTest.vala"
	_tmp18_ = props;
#line 251 "SerializableObjectModelTest.vala"
	_tmp18__length1 = props_length1;
#line 251 "SerializableObjectModelTest.vala"
	if (result_length1) {
#line 251 "SerializableObjectModelTest.vala"
		*result_length1 = _tmp18__length1;
#line 3483 "SerializableObjectModelTest.c"
	}
#line 251 "SerializableObjectModelTest.vala"
	result = _tmp18_;
#line 251 "SerializableObjectModelTest.vala"
	_g_hash_table_unref0 (l);
#line 251 "SerializableObjectModelTest.vala"
	return result;
#line 3491 "SerializableObjectModelTest.c"
}

static GXmlNode*
configuration_real_serialize (GXmlSerializableObjectModel* base,
                              GXmlNode* node,
                              GError** error)
{
	Configuration * self;
	GXmlNode* result = NULL;
	GXmlNode* n = NULL;
	GXmlNode* _tmp0_;
	GXmlNode* _tmp1_;
	GError* _inner_error0_ = NULL;
#line 253 "SerializableObjectModelTest.vala"
	self = (Configuration*) base;
#line 253 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (node != NULL, NULL);
#line 255 "SerializableObjectModelTest.vala"
	_tmp0_ = gxml_serializable_object_model_default_serialize ((GXmlSerializableObjectModel*) self, node, &_inner_error0_);
#line 255 "SerializableObjectModelTest.vala"
	n = _tmp0_;
#line 255 "SerializableObjectModelTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 255 "SerializableObjectModelTest.vala"
		g_propagate_error (error, _inner_error0_);
#line 255 "SerializableObjectModelTest.vala"
		return NULL;
#line 3519 "SerializableObjectModelTest.c"
	}
#line 256 "SerializableObjectModelTest.vala"
	gxml_node_set_namespace (n, "http://www.gnome.org/gxml/0.4", "om");
#line 257 "SerializableObjectModelTest.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (n, GXML_TYPE_NODE, GXmlNode));
#line 257 "SerializableObjectModelTest.vala"
	result = _tmp1_;
#line 257 "SerializableObjectModelTest.vala"
	_g_object_unref0 (n);
#line 257 "SerializableObjectModelTest.vala"
	return result;
#line 3531 "SerializableObjectModelTest.c"
}

static gboolean
configuration_real_deserialize (GXmlSerializableObjectModel* base,
                                GXmlNode* node,
                                GError** error)
{
	Configuration * self;
	gboolean result = FALSE;
	GXmlNode* n = NULL;
	gboolean _tmp21_ = FALSE;
	GError* _inner_error0_ = NULL;
#line 259 "SerializableObjectModelTest.vala"
	self = (Configuration*) base;
#line 259 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (node != NULL, FALSE);
#line 265 "SerializableObjectModelTest.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOCUMENT)) {
#line 3550 "SerializableObjectModelTest.c"
		GXmlNode* _tmp0_;
		GXmlNode* _tmp1_;
#line 266 "SerializableObjectModelTest.vala"
		_tmp0_ = gxml_document_get_root (G_TYPE_CHECK_INSTANCE_CAST (node, GXML_TYPE_DOCUMENT, GXmlDocument));
#line 266 "SerializableObjectModelTest.vala"
		_tmp1_ = _tmp0_;
#line 266 "SerializableObjectModelTest.vala"
		_g_object_unref0 (n);
#line 266 "SerializableObjectModelTest.vala"
		n = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_NODE, GXmlNode);
#line 3561 "SerializableObjectModelTest.c"
	} else {
		GXmlNode* _tmp2_;
#line 268 "SerializableObjectModelTest.vala"
		_tmp2_ = _g_object_ref0 (node);
#line 268 "SerializableObjectModelTest.vala"
		_g_object_unref0 (n);
#line 268 "SerializableObjectModelTest.vala"
		n = _tmp2_;
#line 3570 "SerializableObjectModelTest.c"
	}
	{
		GeeList* _ns_list = NULL;
		GXmlNode* _tmp3_;
		GeeList* _tmp4_;
		GeeList* _tmp5_;
		gint _ns_size = 0;
		GeeList* _tmp6_;
		gint _tmp7_;
		gint _tmp8_;
		gint _ns_index = 0;
#line 272 "SerializableObjectModelTest.vala"
		_tmp3_ = n;
#line 272 "SerializableObjectModelTest.vala"
		_tmp4_ = gxml_node_get_namespaces (_tmp3_);
#line 272 "SerializableObjectModelTest.vala"
		_tmp5_ = _tmp4_;
#line 272 "SerializableObjectModelTest.vala"
		_ns_list = _tmp5_;
#line 272 "SerializableObjectModelTest.vala"
		_tmp6_ = _ns_list;
#line 272 "SerializableObjectModelTest.vala"
		_tmp7_ = gee_collection_get_size ((GeeCollection*) _tmp6_);
#line 272 "SerializableObjectModelTest.vala"
		_tmp8_ = _tmp7_;
#line 272 "SerializableObjectModelTest.vala"
		_ns_size = _tmp8_;
#line 272 "SerializableObjectModelTest.vala"
		_ns_index = -1;
#line 272 "SerializableObjectModelTest.vala"
		while (TRUE) {
#line 3602 "SerializableObjectModelTest.c"
			GXmlNamespace* ns = NULL;
			GeeList* _tmp9_;
			gpointer _tmp10_;
			gboolean _tmp11_ = FALSE;
			GXmlNamespace* _tmp12_;
			gchar* _tmp13_;
			gchar* _tmp14_;
			gchar* _tmp15_;
			gboolean _tmp16_;
#line 272 "SerializableObjectModelTest.vala"
			_ns_index = _ns_index + 1;
#line 272 "SerializableObjectModelTest.vala"
			if (!(_ns_index < _ns_size)) {
#line 272 "SerializableObjectModelTest.vala"
				break;
#line 3618 "SerializableObjectModelTest.c"
			}
#line 272 "SerializableObjectModelTest.vala"
			_tmp9_ = _ns_list;
#line 272 "SerializableObjectModelTest.vala"
			_tmp10_ = gee_list_get (_tmp9_, _ns_index);
#line 272 "SerializableObjectModelTest.vala"
			ns = (GXmlNamespace*) _tmp10_;
#line 276 "SerializableObjectModelTest.vala"
			_tmp12_ = ns;
#line 276 "SerializableObjectModelTest.vala"
			_tmp13_ = gxml_namespace_get_prefix (_tmp12_);
#line 276 "SerializableObjectModelTest.vala"
			_tmp14_ = _tmp13_;
#line 276 "SerializableObjectModelTest.vala"
			_tmp15_ = _tmp14_;
#line 276 "SerializableObjectModelTest.vala"
			_tmp16_ = g_strcmp0 (_tmp15_, "om") == 0;
#line 276 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp15_);
#line 276 "SerializableObjectModelTest.vala"
			if (_tmp16_) {
#line 3640 "SerializableObjectModelTest.c"
				GXmlNamespace* _tmp17_;
				gchar* _tmp18_;
				gchar* _tmp19_;
				gchar* _tmp20_;
#line 276 "SerializableObjectModelTest.vala"
				_tmp17_ = ns;
#line 276 "SerializableObjectModelTest.vala"
				_tmp18_ = gxml_namespace_get_uri (_tmp17_);
#line 276 "SerializableObjectModelTest.vala"
				_tmp19_ = _tmp18_;
#line 276 "SerializableObjectModelTest.vala"
				_tmp20_ = _tmp19_;
#line 276 "SerializableObjectModelTest.vala"
				_tmp11_ = g_strcmp0 (_tmp20_, "http://www.gnome.org/gxml/0.4") == 0;
#line 276 "SerializableObjectModelTest.vala"
				_g_free0 (_tmp20_);
#line 3657 "SerializableObjectModelTest.c"
			} else {
#line 276 "SerializableObjectModelTest.vala"
				_tmp11_ = FALSE;
#line 3661 "SerializableObjectModelTest.c"
			}
#line 276 "SerializableObjectModelTest.vala"
			if (_tmp11_) {
#line 277 "SerializableObjectModelTest.vala"
				configuration_set_invalid (self, FALSE);
#line 3667 "SerializableObjectModelTest.c"
			}
#line 272 "SerializableObjectModelTest.vala"
			_g_object_unref0 (ns);
#line 3671 "SerializableObjectModelTest.c"
		}
#line 272 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_ns_list);
#line 3675 "SerializableObjectModelTest.c"
	}
#line 279 "SerializableObjectModelTest.vala"
	_tmp21_ = gxml_serializable_object_model_default_deserialize ((GXmlSerializableObjectModel*) self, node, &_inner_error0_);
#line 279 "SerializableObjectModelTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 3681 "SerializableObjectModelTest.c"
		gboolean _tmp22_ = FALSE;
#line 279 "SerializableObjectModelTest.vala"
		g_propagate_error (error, _inner_error0_);
#line 279 "SerializableObjectModelTest.vala"
		_g_object_unref0 (n);
#line 279 "SerializableObjectModelTest.vala"
		return _tmp22_;
#line 3689 "SerializableObjectModelTest.c"
	}
#line 279 "SerializableObjectModelTest.vala"
	result = _tmp21_;
#line 279 "SerializableObjectModelTest.vala"
	_g_object_unref0 (n);
#line 279 "SerializableObjectModelTest.vala"
	return result;
#line 3697 "SerializableObjectModelTest.c"
}

Configuration*
configuration_construct (GType object_type)
{
	Configuration * self = NULL;
#line 233 "SerializableObjectModelTest.vala"
	self = (Configuration*) object_model_construct (object_type);
#line 233 "SerializableObjectModelTest.vala"
	return self;
#line 3708 "SerializableObjectModelTest.c"
}

Configuration*
configuration_new (void)
{
#line 233 "SerializableObjectModelTest.vala"
	return configuration_construct (TYPE_CONFIGURATION);
#line 3716 "SerializableObjectModelTest.c"
}

gboolean
configuration_get_invalid (Configuration* self)
{
	gboolean result;
#line 235 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 235 "SerializableObjectModelTest.vala"
	result = self->priv->_invalid;
#line 235 "SerializableObjectModelTest.vala"
	return result;
#line 3729 "SerializableObjectModelTest.c"
}

void
configuration_set_invalid (Configuration* self,
                           gboolean value)
{
#line 235 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 235 "SerializableObjectModelTest.vala"
	if (configuration_get_invalid (self) != value) {
#line 235 "SerializableObjectModelTest.vala"
		self->priv->_invalid = value;
#line 235 "SerializableObjectModelTest.vala"
		g_object_notify_by_pspec ((GObject *) self, configuration_properties[CONFIGURATION_INVALID_PROPERTY]);
#line 3744 "SerializableObjectModelTest.c"
	}
}

const gchar*
configuration_get_device (Configuration* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 236 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 236 "SerializableObjectModelTest.vala"
	_tmp0_ = self->priv->_device;
#line 236 "SerializableObjectModelTest.vala"
	result = _tmp0_;
#line 236 "SerializableObjectModelTest.vala"
	return result;
#line 3761 "SerializableObjectModelTest.c"
}

void
configuration_set_device (Configuration* self,
                          const gchar* value)
{
#line 236 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 236 "SerializableObjectModelTest.vala"
	if (g_strcmp0 (value, configuration_get_device (self)) != 0) {
#line 3772 "SerializableObjectModelTest.c"
		gchar* _tmp0_;
#line 236 "SerializableObjectModelTest.vala"
		_tmp0_ = g_strdup (value);
#line 236 "SerializableObjectModelTest.vala"
		_g_free0 (self->priv->_device);
#line 236 "SerializableObjectModelTest.vala"
		self->priv->_device = _tmp0_;
#line 236 "SerializableObjectModelTest.vala"
		g_object_notify_by_pspec ((GObject *) self, configuration_properties[CONFIGURATION_DEVICE_PROPERTY]);
#line 3782 "SerializableObjectModelTest.c"
	}
}

static void
configuration_class_init (ConfigurationClass * klass,
                          gpointer klass_data)
{
#line 233 "SerializableObjectModelTest.vala"
	configuration_parent_class = g_type_class_peek_parent (klass);
#line 233 "SerializableObjectModelTest.vala"
	g_type_class_adjust_private_offset (klass, &Configuration_private_offset);
#line 233 "SerializableObjectModelTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) configuration_real_node_name;
#line 233 "SerializableObjectModelTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->property_use_nick = (gboolean (*) (GXmlSerializableObjectModel*)) configuration_real_property_use_nick;
#line 233 "SerializableObjectModelTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->list_serializable_properties = (GParamSpec** (*) (GXmlSerializableObjectModel*, gint*)) configuration_real_list_serializable_properties;
#line 233 "SerializableObjectModelTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->serialize = (GXmlNode* (*) (GXmlSerializableObjectModel*, GXmlNode*, GError**)) configuration_real_serialize;
#line 233 "SerializableObjectModelTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->deserialize = (gboolean (*) (GXmlSerializableObjectModel*, GXmlNode*, GError**)) configuration_real_deserialize;
#line 233 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_configuration_get_property;
#line 233 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_configuration_set_property;
#line 233 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->finalize = configuration_finalize;
#line 233 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), CONFIGURATION_INVALID_PROPERTY, configuration_properties[CONFIGURATION_INVALID_PROPERTY] = g_param_spec_boolean ("invalid", "invalid", "invalid", TRUE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 233 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), CONFIGURATION_DEVICE_PROPERTY, configuration_properties[CONFIGURATION_DEVICE_PROPERTY] = g_param_spec_string ("device", "device", "device", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3814 "SerializableObjectModelTest.c"
}

static void
configuration_instance_init (Configuration * self,
                             gpointer klass)
{
#line 233 "SerializableObjectModelTest.vala"
	self->priv = configuration_get_instance_private (self);
#line 235 "SerializableObjectModelTest.vala"
	self->priv->_invalid = TRUE;
#line 3825 "SerializableObjectModelTest.c"
}

static void
configuration_finalize (GObject * obj)
{
	Configuration * self;
#line 233 "SerializableObjectModelTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_CONFIGURATION, Configuration);
#line 236 "SerializableObjectModelTest.vala"
	_g_free0 (self->priv->_device);
#line 233 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (configuration_parent_class)->finalize (obj);
#line 3838 "SerializableObjectModelTest.c"
}

GType
configuration_get_type (void)
{
	static volatile gsize configuration_type_id__volatile = 0;
	if (g_once_init_enter (&configuration_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ConfigurationClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) configuration_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Configuration), 0, (GInstanceInitFunc) configuration_instance_init, NULL };
		GType configuration_type_id;
		configuration_type_id = g_type_register_static (TYPE_OBJECT_MODEL, "Configuration", &g_define_type_info, 0);
		Configuration_private_offset = g_type_add_instance_private (configuration_type_id, sizeof (ConfigurationPrivate));
		g_once_init_leave (&configuration_type_id__volatile, configuration_type_id);
	}
	return configuration_type_id__volatile;
}

static void
_vala_configuration_get_property (GObject * object,
                                  guint property_id,
                                  GValue * value,
                                  GParamSpec * pspec)
{
	Configuration * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_CONFIGURATION, Configuration);
#line 233 "SerializableObjectModelTest.vala"
	switch (property_id) {
#line 233 "SerializableObjectModelTest.vala"
		case CONFIGURATION_INVALID_PROPERTY:
#line 233 "SerializableObjectModelTest.vala"
		g_value_set_boolean (value, configuration_get_invalid (self));
#line 233 "SerializableObjectModelTest.vala"
		break;
#line 233 "SerializableObjectModelTest.vala"
		case CONFIGURATION_DEVICE_PROPERTY:
#line 233 "SerializableObjectModelTest.vala"
		g_value_set_string (value, configuration_get_device (self));
#line 233 "SerializableObjectModelTest.vala"
		break;
#line 3877 "SerializableObjectModelTest.c"
		default:
#line 233 "SerializableObjectModelTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 233 "SerializableObjectModelTest.vala"
		break;
#line 3883 "SerializableObjectModelTest.c"
	}
}

static void
_vala_configuration_set_property (GObject * object,
                                  guint property_id,
                                  const GValue * value,
                                  GParamSpec * pspec)
{
	Configuration * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_CONFIGURATION, Configuration);
#line 233 "SerializableObjectModelTest.vala"
	switch (property_id) {
#line 233 "SerializableObjectModelTest.vala"
		case CONFIGURATION_INVALID_PROPERTY:
#line 233 "SerializableObjectModelTest.vala"
		configuration_set_invalid (self, g_value_get_boolean (value));
#line 233 "SerializableObjectModelTest.vala"
		break;
#line 233 "SerializableObjectModelTest.vala"
		case CONFIGURATION_DEVICE_PROPERTY:
#line 233 "SerializableObjectModelTest.vala"
		configuration_set_device (self, g_value_get_string (value));
#line 233 "SerializableObjectModelTest.vala"
		break;
#line 3909 "SerializableObjectModelTest.c"
		default:
#line 233 "SerializableObjectModelTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 233 "SerializableObjectModelTest.vala"
		break;
#line 3915 "SerializableObjectModelTest.c"
	}
}

static inline gpointer
fake_serializable_get_instance_private (FakeSerializable* self)
{
	return G_STRUCT_MEMBER_P (self, FakeSerializable_private_offset);
}

FakeSerializable*
fake_serializable_construct (GType object_type)
{
	FakeSerializable * self = NULL;
#line 283 "SerializableObjectModelTest.vala"
	self = (FakeSerializable*) object_model_construct (object_type);
#line 283 "SerializableObjectModelTest.vala"
	return self;
#line 3933 "SerializableObjectModelTest.c"
}

FakeSerializable*
fake_serializable_new (void)
{
#line 283 "SerializableObjectModelTest.vala"
	return fake_serializable_construct (TYPE_FAKE_SERIALIZABLE);
#line 3941 "SerializableObjectModelTest.c"
}

const gchar*
fake_serializable_get_none (FakeSerializable* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 285 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 285 "SerializableObjectModelTest.vala"
	_tmp0_ = self->priv->_none;
#line 285 "SerializableObjectModelTest.vala"
	result = _tmp0_;
#line 285 "SerializableObjectModelTest.vala"
	return result;
#line 3957 "SerializableObjectModelTest.c"
}

void
fake_serializable_set_none (FakeSerializable* self,
                            const gchar* value)
{
#line 285 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 285 "SerializableObjectModelTest.vala"
	if (g_strcmp0 (value, fake_serializable_get_none (self)) != 0) {
#line 3968 "SerializableObjectModelTest.c"
		gchar* _tmp0_;
#line 285 "SerializableObjectModelTest.vala"
		_tmp0_ = g_strdup (value);
#line 285 "SerializableObjectModelTest.vala"
		_g_free0 (self->priv->_none);
#line 285 "SerializableObjectModelTest.vala"
		self->priv->_none = _tmp0_;
#line 285 "SerializableObjectModelTest.vala"
		g_object_notify_by_pspec ((GObject *) self, fake_serializable_properties[FAKE_SERIALIZABLE_NONE_PROPERTY]);
#line 3978 "SerializableObjectModelTest.c"
	}
}

static void
fake_serializable_class_init (FakeSerializableClass * klass,
                              gpointer klass_data)
{
#line 283 "SerializableObjectModelTest.vala"
	fake_serializable_parent_class = g_type_class_peek_parent (klass);
#line 283 "SerializableObjectModelTest.vala"
	g_type_class_adjust_private_offset (klass, &FakeSerializable_private_offset);
#line 283 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_fake_serializable_get_property;
#line 283 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_fake_serializable_set_property;
#line 283 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->finalize = fake_serializable_finalize;
#line 283 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), FAKE_SERIALIZABLE_NONE_PROPERTY, fake_serializable_properties[FAKE_SERIALIZABLE_NONE_PROPERTY] = g_param_spec_string ("none", "none", "none", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3998 "SerializableObjectModelTest.c"
}

static void
fake_serializable_instance_init (FakeSerializable * self,
                                 gpointer klass)
{
#line 283 "SerializableObjectModelTest.vala"
	self->priv = fake_serializable_get_instance_private (self);
#line 4007 "SerializableObjectModelTest.c"
}

static void
fake_serializable_finalize (GObject * obj)
{
	FakeSerializable * self;
#line 283 "SerializableObjectModelTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_FAKE_SERIALIZABLE, FakeSerializable);
#line 285 "SerializableObjectModelTest.vala"
	_g_free0 (self->priv->_none);
#line 283 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (fake_serializable_parent_class)->finalize (obj);
#line 4020 "SerializableObjectModelTest.c"
}

GType
fake_serializable_get_type (void)
{
	static volatile gsize fake_serializable_type_id__volatile = 0;
	if (g_once_init_enter (&fake_serializable_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (FakeSerializableClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) fake_serializable_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (FakeSerializable), 0, (GInstanceInitFunc) fake_serializable_instance_init, NULL };
		GType fake_serializable_type_id;
		fake_serializable_type_id = g_type_register_static (TYPE_OBJECT_MODEL, "FakeSerializable", &g_define_type_info, 0);
		FakeSerializable_private_offset = g_type_add_instance_private (fake_serializable_type_id, sizeof (FakeSerializablePrivate));
		g_once_init_leave (&fake_serializable_type_id__volatile, fake_serializable_type_id);
	}
	return fake_serializable_type_id__volatile;
}

static void
_vala_fake_serializable_get_property (GObject * object,
                                      guint property_id,
                                      GValue * value,
                                      GParamSpec * pspec)
{
	FakeSerializable * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_FAKE_SERIALIZABLE, FakeSerializable);
#line 283 "SerializableObjectModelTest.vala"
	switch (property_id) {
#line 283 "SerializableObjectModelTest.vala"
		case FAKE_SERIALIZABLE_NONE_PROPERTY:
#line 283 "SerializableObjectModelTest.vala"
		g_value_set_string (value, fake_serializable_get_none (self));
#line 283 "SerializableObjectModelTest.vala"
		break;
#line 4053 "SerializableObjectModelTest.c"
		default:
#line 283 "SerializableObjectModelTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 283 "SerializableObjectModelTest.vala"
		break;
#line 4059 "SerializableObjectModelTest.c"
	}
}

static void
_vala_fake_serializable_set_property (GObject * object,
                                      guint property_id,
                                      const GValue * value,
                                      GParamSpec * pspec)
{
	FakeSerializable * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_FAKE_SERIALIZABLE, FakeSerializable);
#line 283 "SerializableObjectModelTest.vala"
	switch (property_id) {
#line 283 "SerializableObjectModelTest.vala"
		case FAKE_SERIALIZABLE_NONE_PROPERTY:
#line 283 "SerializableObjectModelTest.vala"
		fake_serializable_set_none (self, g_value_get_string (value));
#line 283 "SerializableObjectModelTest.vala"
		break;
#line 4079 "SerializableObjectModelTest.c"
		default:
#line 283 "SerializableObjectModelTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 283 "SerializableObjectModelTest.vala"
		break;
#line 4085 "SerializableObjectModelTest.c"
	}
}

static inline gpointer
unknown_attribute_get_instance_private (UnknownAttribute* self)
{
	return G_STRUCT_MEMBER_P (self, UnknownAttribute_private_offset);
}

static gboolean
unknown_attribute_real_get_enable_unknown_serializable_property (GXmlSerializableObjectModel* base)
{
	UnknownAttribute * self;
	gboolean result = FALSE;
#line 292 "SerializableObjectModelTest.vala"
	self = (UnknownAttribute*) base;
#line 292 "SerializableObjectModelTest.vala"
	result = TRUE;
#line 292 "SerializableObjectModelTest.vala"
	return result;
#line 4106 "SerializableObjectModelTest.c"
}

UnknownAttribute*
unknown_attribute_construct (GType object_type)
{
	UnknownAttribute * self = NULL;
#line 287 "SerializableObjectModelTest.vala"
	self = (UnknownAttribute*) object_model_construct (object_type);
#line 287 "SerializableObjectModelTest.vala"
	return self;
#line 4117 "SerializableObjectModelTest.c"
}

UnknownAttribute*
unknown_attribute_new (void)
{
#line 287 "SerializableObjectModelTest.vala"
	return unknown_attribute_construct (TYPE_UNKNOWN_ATTRIBUTE);
#line 4125 "SerializableObjectModelTest.c"
}

const gchar*
unknown_attribute_get_name (UnknownAttribute* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 289 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 289 "SerializableObjectModelTest.vala"
	_tmp0_ = self->priv->_name;
#line 289 "SerializableObjectModelTest.vala"
	result = _tmp0_;
#line 289 "SerializableObjectModelTest.vala"
	return result;
#line 4141 "SerializableObjectModelTest.c"
}

void
unknown_attribute_set_name (UnknownAttribute* self,
                            const gchar* value)
{
#line 289 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 289 "SerializableObjectModelTest.vala"
	if (g_strcmp0 (value, unknown_attribute_get_name (self)) != 0) {
#line 4152 "SerializableObjectModelTest.c"
		gchar* _tmp0_;
#line 289 "SerializableObjectModelTest.vala"
		_tmp0_ = g_strdup (value);
#line 289 "SerializableObjectModelTest.vala"
		_g_free0 (self->priv->_name);
#line 289 "SerializableObjectModelTest.vala"
		self->priv->_name = _tmp0_;
#line 289 "SerializableObjectModelTest.vala"
		g_object_notify_by_pspec ((GObject *) self, unknown_attribute_properties[UNKNOWN_ATTRIBUTE_NAME_PROPERTY]);
#line 4162 "SerializableObjectModelTest.c"
	}
}

GeeArrayList*
unknown_attribute_get_array (UnknownAttribute* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
#line 290 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 290 "SerializableObjectModelTest.vala"
	_tmp0_ = self->priv->_array;
#line 290 "SerializableObjectModelTest.vala"
	result = _tmp0_;
#line 290 "SerializableObjectModelTest.vala"
	return result;
#line 4179 "SerializableObjectModelTest.c"
}

void
unknown_attribute_set_array (UnknownAttribute* self,
                             GeeArrayList* value)
{
#line 290 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 290 "SerializableObjectModelTest.vala"
	if (unknown_attribute_get_array (self) != value) {
#line 4190 "SerializableObjectModelTest.c"
		GeeArrayList* _tmp0_;
#line 290 "SerializableObjectModelTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 290 "SerializableObjectModelTest.vala"
		_g_object_unref0 (self->priv->_array);
#line 290 "SerializableObjectModelTest.vala"
		self->priv->_array = _tmp0_;
#line 290 "SerializableObjectModelTest.vala"
		g_object_notify_by_pspec ((GObject *) self, unknown_attribute_properties[UNKNOWN_ATTRIBUTE_ARRAY_PROPERTY]);
#line 4200 "SerializableObjectModelTest.c"
	}
}

FakeSerializable*
unknown_attribute_get_fake (UnknownAttribute* self)
{
	FakeSerializable* result;
	FakeSerializable* _tmp0_;
#line 291 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 291 "SerializableObjectModelTest.vala"
	_tmp0_ = self->priv->_fake;
#line 291 "SerializableObjectModelTest.vala"
	result = _tmp0_;
#line 291 "SerializableObjectModelTest.vala"
	return result;
#line 4217 "SerializableObjectModelTest.c"
}

void
unknown_attribute_set_fake (UnknownAttribute* self,
                            FakeSerializable* value)
{
#line 291 "SerializableObjectModelTest.vala"
	g_return_if_fail (self != NULL);
#line 291 "SerializableObjectModelTest.vala"
	if (unknown_attribute_get_fake (self) != value) {
#line 4228 "SerializableObjectModelTest.c"
		FakeSerializable* _tmp0_;
#line 291 "SerializableObjectModelTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 291 "SerializableObjectModelTest.vala"
		_g_object_unref0 (self->priv->_fake);
#line 291 "SerializableObjectModelTest.vala"
		self->priv->_fake = _tmp0_;
#line 291 "SerializableObjectModelTest.vala"
		g_object_notify_by_pspec ((GObject *) self, unknown_attribute_properties[UNKNOWN_ATTRIBUTE_FAKE_PROPERTY]);
#line 4238 "SerializableObjectModelTest.c"
	}
}

static void
unknown_attribute_class_init (UnknownAttributeClass * klass,
                              gpointer klass_data)
{
#line 287 "SerializableObjectModelTest.vala"
	unknown_attribute_parent_class = g_type_class_peek_parent (klass);
#line 287 "SerializableObjectModelTest.vala"
	g_type_class_adjust_private_offset (klass, &UnknownAttribute_private_offset);
#line 287 "SerializableObjectModelTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->get_enable_unknown_serializable_property = (gboolean (*) (GXmlSerializableObjectModel*)) unknown_attribute_real_get_enable_unknown_serializable_property;
#line 287 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_unknown_attribute_get_property;
#line 287 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_unknown_attribute_set_property;
#line 287 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (klass)->finalize = unknown_attribute_finalize;
#line 287 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), UNKNOWN_ATTRIBUTE_NAME_PROPERTY, unknown_attribute_properties[UNKNOWN_ATTRIBUTE_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 287 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), UNKNOWN_ATTRIBUTE_ARRAY_PROPERTY, unknown_attribute_properties[UNKNOWN_ATTRIBUTE_ARRAY_PROPERTY] = g_param_spec_object ("array", "array", "array", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 287 "SerializableObjectModelTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), UNKNOWN_ATTRIBUTE_FAKE_PROPERTY, unknown_attribute_properties[UNKNOWN_ATTRIBUTE_FAKE_PROPERTY] = g_param_spec_object ("fake", "fake", "fake", TYPE_FAKE_SERIALIZABLE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4264 "SerializableObjectModelTest.c"
}

static void
unknown_attribute_instance_init (UnknownAttribute * self,
                                 gpointer klass)
{
#line 287 "SerializableObjectModelTest.vala"
	self->priv = unknown_attribute_get_instance_private (self);
#line 4273 "SerializableObjectModelTest.c"
}

static void
unknown_attribute_finalize (GObject * obj)
{
	UnknownAttribute * self;
#line 287 "SerializableObjectModelTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_UNKNOWN_ATTRIBUTE, UnknownAttribute);
#line 289 "SerializableObjectModelTest.vala"
	_g_free0 (self->priv->_name);
#line 290 "SerializableObjectModelTest.vala"
	_g_object_unref0 (self->priv->_array);
#line 291 "SerializableObjectModelTest.vala"
	_g_object_unref0 (self->priv->_fake);
#line 287 "SerializableObjectModelTest.vala"
	G_OBJECT_CLASS (unknown_attribute_parent_class)->finalize (obj);
#line 4290 "SerializableObjectModelTest.c"
}

GType
unknown_attribute_get_type (void)
{
	static volatile gsize unknown_attribute_type_id__volatile = 0;
	if (g_once_init_enter (&unknown_attribute_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (UnknownAttributeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) unknown_attribute_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (UnknownAttribute), 0, (GInstanceInitFunc) unknown_attribute_instance_init, NULL };
		GType unknown_attribute_type_id;
		unknown_attribute_type_id = g_type_register_static (TYPE_OBJECT_MODEL, "UnknownAttribute", &g_define_type_info, 0);
		UnknownAttribute_private_offset = g_type_add_instance_private (unknown_attribute_type_id, sizeof (UnknownAttributePrivate));
		g_once_init_leave (&unknown_attribute_type_id__volatile, unknown_attribute_type_id);
	}
	return unknown_attribute_type_id__volatile;
}

static void
_vala_unknown_attribute_get_property (GObject * object,
                                      guint property_id,
                                      GValue * value,
                                      GParamSpec * pspec)
{
	UnknownAttribute * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_UNKNOWN_ATTRIBUTE, UnknownAttribute);
#line 287 "SerializableObjectModelTest.vala"
	switch (property_id) {
#line 287 "SerializableObjectModelTest.vala"
		case UNKNOWN_ATTRIBUTE_NAME_PROPERTY:
#line 287 "SerializableObjectModelTest.vala"
		g_value_set_string (value, unknown_attribute_get_name (self));
#line 287 "SerializableObjectModelTest.vala"
		break;
#line 287 "SerializableObjectModelTest.vala"
		case UNKNOWN_ATTRIBUTE_ARRAY_PROPERTY:
#line 287 "SerializableObjectModelTest.vala"
		g_value_set_object (value, unknown_attribute_get_array (self));
#line 287 "SerializableObjectModelTest.vala"
		break;
#line 287 "SerializableObjectModelTest.vala"
		case UNKNOWN_ATTRIBUTE_FAKE_PROPERTY:
#line 287 "SerializableObjectModelTest.vala"
		g_value_set_object (value, unknown_attribute_get_fake (self));
#line 287 "SerializableObjectModelTest.vala"
		break;
#line 4335 "SerializableObjectModelTest.c"
		default:
#line 287 "SerializableObjectModelTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 287 "SerializableObjectModelTest.vala"
		break;
#line 4341 "SerializableObjectModelTest.c"
	}
}

static void
_vala_unknown_attribute_set_property (GObject * object,
                                      guint property_id,
                                      const GValue * value,
                                      GParamSpec * pspec)
{
	UnknownAttribute * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_UNKNOWN_ATTRIBUTE, UnknownAttribute);
#line 287 "SerializableObjectModelTest.vala"
	switch (property_id) {
#line 287 "SerializableObjectModelTest.vala"
		case UNKNOWN_ATTRIBUTE_NAME_PROPERTY:
#line 287 "SerializableObjectModelTest.vala"
		unknown_attribute_set_name (self, g_value_get_string (value));
#line 287 "SerializableObjectModelTest.vala"
		break;
#line 287 "SerializableObjectModelTest.vala"
		case UNKNOWN_ATTRIBUTE_ARRAY_PROPERTY:
#line 287 "SerializableObjectModelTest.vala"
		unknown_attribute_set_array (self, g_value_get_object (value));
#line 287 "SerializableObjectModelTest.vala"
		break;
#line 287 "SerializableObjectModelTest.vala"
		case UNKNOWN_ATTRIBUTE_FAKE_PROPERTY:
#line 287 "SerializableObjectModelTest.vala"
		unknown_attribute_set_fake (self, g_value_get_object (value));
#line 287 "SerializableObjectModelTest.vala"
		break;
#line 4373 "SerializableObjectModelTest.c"
		default:
#line 287 "SerializableObjectModelTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 287 "SerializableObjectModelTest.vala"
		break;
#line 4379 "SerializableObjectModelTest.c"
	}
}

static gboolean
name_space_real_set_default_namespace (GXmlSerializableObjectModel* base,
                                       GXmlNode* node)
{
	NameSpace * self;
	gboolean result = FALSE;
#line 297 "SerializableObjectModelTest.vala"
	self = (NameSpace*) base;
#line 297 "SerializableObjectModelTest.vala"
	g_return_val_if_fail (node != NULL, FALSE);
#line 299 "SerializableObjectModelTest.vala"
	g_test_message ("Setting default namespace");
#line 300 "SerializableObjectModelTest.vala"
	gxml_node_set_namespace (node, "http://www.gnome.org/GXml", "gxml");
#line 301 "SerializableObjectModelTest.vala"
	result = TRUE;
#line 301 "SerializableObjectModelTest.vala"
	return result;
#line 4401 "SerializableObjectModelTest.c"
}

static gchar*
name_space_real_to_string (GXmlSerializableObjectModel* base)
{
	NameSpace * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 303 "SerializableObjectModelTest.vala"
	self = (NameSpace*) base;
#line 305 "SerializableObjectModelTest.vala"
	_tmp0_ = g_strdup ("");
#line 305 "SerializableObjectModelTest.vala"
	result = _tmp0_;
#line 305 "SerializableObjectModelTest.vala"
	return result;
#line 4418 "SerializableObjectModelTest.c"
}

NameSpace*
name_space_construct (GType object_type)
{
	NameSpace * self = NULL;
#line 295 "SerializableObjectModelTest.vala"
	self = (NameSpace*) gxml_serializable_object_model_construct (object_type);
#line 295 "SerializableObjectModelTest.vala"
	return self;
#line 4429 "SerializableObjectModelTest.c"
}

NameSpace*
name_space_new (void)
{
#line 295 "SerializableObjectModelTest.vala"
	return name_space_construct (TYPE_NAME_SPACE);
#line 4437 "SerializableObjectModelTest.c"
}

static void
name_space_class_init (NameSpaceClass * klass,
                       gpointer klass_data)
{
#line 295 "SerializableObjectModelTest.vala"
	name_space_parent_class = g_type_class_peek_parent (klass);
#line 295 "SerializableObjectModelTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->set_default_namespace = (gboolean (*) (GXmlSerializableObjectModel*, GXmlNode*)) name_space_real_set_default_namespace;
#line 295 "SerializableObjectModelTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) name_space_real_to_string;
#line 4450 "SerializableObjectModelTest.c"
}

static void
name_space_instance_init (NameSpace * self,
                          gpointer klass)
{
}

GType
name_space_get_type (void)
{
	static volatile gsize name_space_type_id__volatile = 0;
	if (g_once_init_enter (&name_space_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (NameSpaceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) name_space_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (NameSpace), 0, (GInstanceInitFunc) name_space_instance_init, NULL };
		GType name_space_type_id;
		name_space_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "NameSpace", &g_define_type_info, 0);
		g_once_init_leave (&name_space_type_id__volatile, name_space_type_id);
	}
	return name_space_type_id__volatile;
}

static gdouble
double_parse (const gchar* str)
{
	gdouble result = 0.0;
#line 944 "glib-2.0.vapi"
	g_return_val_if_fail (str != NULL, 0.0);
#line 945 "glib-2.0.vapi"
	result = g_ascii_strtod (str, NULL);
#line 945 "glib-2.0.vapi"
	return result;
#line 4482 "SerializableObjectModelTest.c"
}

static void
__lambda264_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		Computer* computer = NULL;
		Computer* _tmp0_;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_;
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		gboolean _tmp12_;
		GXmlNode* m = NULL;
		GXmlNode* _tmp14_;
		GXmlNode* _tmp15_;
		GXmlElement* _tmp16_;
		GXmlElement* _tmp17_;
		GXmlNode* _tmp18_;
		GXmlNode* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
		gboolean _tmp23_;
		GXmlNode* mod = NULL;
		GXmlNode* _tmp25_;
		GXmlNode* _tmp26_;
		GXmlElement* _tmp27_;
		GXmlElement* _tmp28_;
		GXmlNode* _tmp29_;
		GXmlNode* _tmp30_;
		gchar* _tmp31_;
		gchar* _tmp32_;
		gchar* _tmp33_;
		gboolean _tmp34_;
		GXmlNode* c = NULL;
		GXmlNode* _tmp36_;
		GXmlNode* _tmp37_;
		GXmlElement* _tmp38_;
		GXmlElement* _tmp39_;
		GXmlNode* _tmp40_;
		GXmlNode* _tmp41_;
		gchar* _tmp42_;
		gchar* _tmp43_;
		gchar* _tmp44_;
		gboolean _tmp45_;
		GXmlNode* g = NULL;
		GXmlNode* _tmp47_;
		GXmlNode* _tmp48_;
		GXmlElement* _tmp49_;
		GXmlElement* _tmp50_;
		GXmlNode* _tmp51_;
		GXmlNode* _tmp52_;
		gchar* _tmp53_;
		gchar* _tmp54_;
		gchar* _tmp55_;
		gboolean _tmp56_;
#line 316 "SerializableObjectModelTest.vala"
		_tmp0_ = computer_new ();
#line 316 "SerializableObjectModelTest.vala"
		computer = _tmp0_;
#line 317 "SerializableObjectModelTest.vala"
		_tmp1_ = gxml_gdocument_new ();
#line 317 "SerializableObjectModelTest.vala"
		doc = _tmp1_;
#line 318 "SerializableObjectModelTest.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) computer, (GXmlNode*) doc, &_inner_error0_);
#line 318 "SerializableObjectModelTest.vala"
		_tmp3_ = _tmp2_;
#line 318 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp3_);
#line 318 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 318 "SerializableObjectModelTest.vala"
			_g_object_unref0 (doc);
#line 318 "SerializableObjectModelTest.vala"
			_g_object_unref0 (computer);
#line 4569 "SerializableObjectModelTest.c"
			goto __catch318_g_error;
		}
#line 319 "SerializableObjectModelTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 319 "SerializableObjectModelTest.vala"
		_tmp5_ = _tmp4_;
#line 319 "SerializableObjectModelTest.vala"
		_tmp6_ = _tmp5_;
#line 319 "SerializableObjectModelTest.vala"
		_tmp7_ = gxml_node_get_name (_tmp6_);
#line 319 "SerializableObjectModelTest.vala"
		_tmp8_ = _tmp7_;
#line 319 "SerializableObjectModelTest.vala"
		_tmp9_ = _tmp8_;
#line 319 "SerializableObjectModelTest.vala"
		_tmp10_ = g_utf8_strdown (_tmp9_, (gssize) -1);
#line 319 "SerializableObjectModelTest.vala"
		_tmp11_ = _tmp10_;
#line 319 "SerializableObjectModelTest.vala"
		_tmp12_ = g_strcmp0 (_tmp11_, "computer") != 0;
#line 319 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp11_);
#line 319 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp9_);
#line 319 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp6_);
#line 319 "SerializableObjectModelTest.vala"
		if (_tmp12_) {
#line 4598 "SerializableObjectModelTest.c"
			FILE* _tmp13_;
#line 320 "SerializableObjectModelTest.vala"
			_tmp13_ = stdout;
#line 320 "SerializableObjectModelTest.vala"
			fprintf (_tmp13_, "ERROR XML_COMPUTER: computer\n");
#line 321 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 4606 "SerializableObjectModelTest.c"
		}
#line 323 "SerializableObjectModelTest.vala"
		_tmp14_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 323 "SerializableObjectModelTest.vala"
		_tmp15_ = _tmp14_;
#line 323 "SerializableObjectModelTest.vala"
		_tmp16_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp15_) : NULL;
#line 323 "SerializableObjectModelTest.vala"
		if (_tmp16_ == NULL) {
#line 323 "SerializableObjectModelTest.vala"
			_g_object_unref0 (_tmp15_);
#line 4618 "SerializableObjectModelTest.c"
		}
#line 323 "SerializableObjectModelTest.vala"
		_tmp17_ = _tmp16_;
#line 323 "SerializableObjectModelTest.vala"
		_tmp18_ = gxml_element_get_attr (_tmp17_, "manufacturer");
#line 323 "SerializableObjectModelTest.vala"
		_tmp19_ = _tmp18_;
#line 323 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp17_);
#line 323 "SerializableObjectModelTest.vala"
		m = _tmp19_;
#line 324 "SerializableObjectModelTest.vala"
		if (m == NULL) {
#line 324 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 4634 "SerializableObjectModelTest.c"
		}
#line 325 "SerializableObjectModelTest.vala"
		_tmp20_ = gxml_node_get_value (m);
#line 325 "SerializableObjectModelTest.vala"
		_tmp21_ = _tmp20_;
#line 325 "SerializableObjectModelTest.vala"
		_tmp22_ = _tmp21_;
#line 325 "SerializableObjectModelTest.vala"
		_tmp23_ = g_strcmp0 (_tmp22_, "MexicanLaptop, Inc.") != 0;
#line 325 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp22_);
#line 325 "SerializableObjectModelTest.vala"
		if (_tmp23_) {
#line 4648 "SerializableObjectModelTest.c"
			FILE* _tmp24_;
#line 326 "SerializableObjectModelTest.vala"
			_tmp24_ = stdout;
#line 326 "SerializableObjectModelTest.vala"
			fprintf (_tmp24_, "ERROR XML_COMPUTER: manufacturer\n");
#line 327 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 4656 "SerializableObjectModelTest.c"
		}
#line 329 "SerializableObjectModelTest.vala"
		_tmp25_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 329 "SerializableObjectModelTest.vala"
		_tmp26_ = _tmp25_;
#line 329 "SerializableObjectModelTest.vala"
		_tmp27_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp26_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp26_) : NULL;
#line 329 "SerializableObjectModelTest.vala"
		if (_tmp27_ == NULL) {
#line 329 "SerializableObjectModelTest.vala"
			_g_object_unref0 (_tmp26_);
#line 4668 "SerializableObjectModelTest.c"
		}
#line 329 "SerializableObjectModelTest.vala"
		_tmp28_ = _tmp27_;
#line 329 "SerializableObjectModelTest.vala"
		_tmp29_ = gxml_element_get_attr (_tmp28_, "model");
#line 329 "SerializableObjectModelTest.vala"
		_tmp30_ = _tmp29_;
#line 329 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp28_);
#line 329 "SerializableObjectModelTest.vala"
		mod = _tmp30_;
#line 330 "SerializableObjectModelTest.vala"
		if (mod == NULL) {
#line 330 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 4684 "SerializableObjectModelTest.c"
		}
#line 331 "SerializableObjectModelTest.vala"
		_tmp31_ = gxml_node_get_value (mod);
#line 331 "SerializableObjectModelTest.vala"
		_tmp32_ = _tmp31_;
#line 331 "SerializableObjectModelTest.vala"
		_tmp33_ = _tmp32_;
#line 331 "SerializableObjectModelTest.vala"
		_tmp34_ = g_strcmp0 (_tmp33_, "LQ59678") != 0;
#line 331 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp33_);
#line 331 "SerializableObjectModelTest.vala"
		if (_tmp34_) {
#line 4698 "SerializableObjectModelTest.c"
			FILE* _tmp35_;
#line 332 "SerializableObjectModelTest.vala"
			_tmp35_ = stdout;
#line 332 "SerializableObjectModelTest.vala"
			fprintf (_tmp35_, "ERROR XML_COMPUTER: model\n");
#line 333 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 4706 "SerializableObjectModelTest.c"
		}
#line 335 "SerializableObjectModelTest.vala"
		_tmp36_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 335 "SerializableObjectModelTest.vala"
		_tmp37_ = _tmp36_;
#line 335 "SerializableObjectModelTest.vala"
		_tmp38_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp37_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp37_) : NULL;
#line 335 "SerializableObjectModelTest.vala"
		if (_tmp38_ == NULL) {
#line 335 "SerializableObjectModelTest.vala"
			_g_object_unref0 (_tmp37_);
#line 4718 "SerializableObjectModelTest.c"
		}
#line 335 "SerializableObjectModelTest.vala"
		_tmp39_ = _tmp38_;
#line 335 "SerializableObjectModelTest.vala"
		_tmp40_ = gxml_element_get_attr (_tmp39_, "cores");
#line 335 "SerializableObjectModelTest.vala"
		_tmp41_ = _tmp40_;
#line 335 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp39_);
#line 335 "SerializableObjectModelTest.vala"
		c = _tmp41_;
#line 336 "SerializableObjectModelTest.vala"
		if (c == NULL) {
#line 336 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 4734 "SerializableObjectModelTest.c"
		}
#line 337 "SerializableObjectModelTest.vala"
		_tmp42_ = gxml_node_get_value (c);
#line 337 "SerializableObjectModelTest.vala"
		_tmp43_ = _tmp42_;
#line 337 "SerializableObjectModelTest.vala"
		_tmp44_ = _tmp43_;
#line 337 "SerializableObjectModelTest.vala"
		_tmp45_ = g_strcmp0 (_tmp44_, "8") != 0;
#line 337 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp44_);
#line 337 "SerializableObjectModelTest.vala"
		if (_tmp45_) {
#line 4748 "SerializableObjectModelTest.c"
			FILE* _tmp46_;
#line 338 "SerializableObjectModelTest.vala"
			_tmp46_ = stdout;
#line 338 "SerializableObjectModelTest.vala"
			fprintf (_tmp46_, "ERROR XML_COMPUTER: cores val\n");
#line 339 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 4756 "SerializableObjectModelTest.c"
		}
#line 341 "SerializableObjectModelTest.vala"
		_tmp47_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 341 "SerializableObjectModelTest.vala"
		_tmp48_ = _tmp47_;
#line 341 "SerializableObjectModelTest.vala"
		_tmp49_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp48_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp48_) : NULL;
#line 341 "SerializableObjectModelTest.vala"
		if (_tmp49_ == NULL) {
#line 341 "SerializableObjectModelTest.vala"
			_g_object_unref0 (_tmp48_);
#line 4768 "SerializableObjectModelTest.c"
		}
#line 341 "SerializableObjectModelTest.vala"
		_tmp50_ = _tmp49_;
#line 341 "SerializableObjectModelTest.vala"
		_tmp51_ = gxml_element_get_attr (_tmp50_, "ghz");
#line 341 "SerializableObjectModelTest.vala"
		_tmp52_ = _tmp51_;
#line 341 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp50_);
#line 341 "SerializableObjectModelTest.vala"
		g = _tmp52_;
#line 342 "SerializableObjectModelTest.vala"
		if (g == NULL) {
#line 342 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 4784 "SerializableObjectModelTest.c"
		}
#line 343 "SerializableObjectModelTest.vala"
		_tmp53_ = gxml_node_get_value (g);
#line 343 "SerializableObjectModelTest.vala"
		_tmp54_ = _tmp53_;
#line 343 "SerializableObjectModelTest.vala"
		_tmp55_ = _tmp54_;
#line 343 "SerializableObjectModelTest.vala"
		_tmp56_ = double_parse (_tmp55_) != ((gdouble) 3.5);
#line 343 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp55_);
#line 343 "SerializableObjectModelTest.vala"
		if (_tmp56_) {
#line 4798 "SerializableObjectModelTest.c"
			FILE* _tmp57_;
#line 344 "SerializableObjectModelTest.vala"
			_tmp57_ = stdout;
#line 344 "SerializableObjectModelTest.vala"
			fprintf (_tmp57_, "ERROR XML_COMPUTER: ghz val\n");
#line 345 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 4806 "SerializableObjectModelTest.c"
		}
#line 315 "SerializableObjectModelTest.vala"
		_g_object_unref0 (g);
#line 315 "SerializableObjectModelTest.vala"
		_g_object_unref0 (c);
#line 315 "SerializableObjectModelTest.vala"
		_g_object_unref0 (mod);
#line 315 "SerializableObjectModelTest.vala"
		_g_object_unref0 (m);
#line 315 "SerializableObjectModelTest.vala"
		_g_object_unref0 (doc);
#line 315 "SerializableObjectModelTest.vala"
		_g_object_unref0 (computer);
#line 4820 "SerializableObjectModelTest.c"
	}
	goto __finally318;
	__catch318_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp58_;
#line 315 "SerializableObjectModelTest.vala"
		e = _inner_error0_;
#line 315 "SerializableObjectModelTest.vala"
		_inner_error0_ = NULL;
#line 350 "SerializableObjectModelTest.vala"
		_tmp58_ = e->message;
#line 350 "SerializableObjectModelTest.vala"
		g_message ("SerializableObjectModelTest.vala:350: %s", _tmp58_);
#line 351 "SerializableObjectModelTest.vala"
		g_assert_not_reached ();
#line 315 "SerializableObjectModelTest.vala"
		_g_error_free0 (e);
#line 4839 "SerializableObjectModelTest.c"
	}
	__finally318:
#line 315 "SerializableObjectModelTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 315 "SerializableObjectModelTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 315 "SerializableObjectModelTest.vala"
		g_clear_error (&_inner_error0_);
#line 315 "SerializableObjectModelTest.vala"
		return;
#line 4850 "SerializableObjectModelTest.c"
	}
}

static void
___lambda264__gtest_func (void)
{
#line 313 "SerializableObjectModelTest.vala"
	__lambda264_ ();
#line 4859 "SerializableObjectModelTest.c"
}

static void
__lambda265_ (void)
{
	Computer* computer = NULL;
	Computer* _tmp0_;
	GError* _inner_error0_ = NULL;
#line 357 "SerializableObjectModelTest.vala"
	_tmp0_ = computer_new ();
#line 357 "SerializableObjectModelTest.vala"
	computer = _tmp0_;
#line 4872 "SerializableObjectModelTest.c"
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_;
		Computer* _tmp2_;
		GXmlGDocument* _tmp3_;
		Computer* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		Computer* _tmp14_;
		const gchar* _tmp15_;
		const gchar* _tmp16_;
		Computer* _tmp24_;
		gint _tmp25_;
		gint _tmp26_;
		Computer* _tmp35_;
		gfloat _tmp36_;
		gfloat _tmp37_;
#line 359 "SerializableObjectModelTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string (XML_COMPUTER_FILE, 0, &_inner_error0_);
#line 359 "SerializableObjectModelTest.vala"
		doc = _tmp1_;
#line 359 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 4896 "SerializableObjectModelTest.c"
			goto __catch319_g_error;
		}
#line 360 "SerializableObjectModelTest.vala"
		_tmp2_ = computer;
#line 360 "SerializableObjectModelTest.vala"
		_tmp3_ = doc;
#line 360 "SerializableObjectModelTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 360 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 360 "SerializableObjectModelTest.vala"
			_g_object_unref0 (doc);
#line 4909 "SerializableObjectModelTest.c"
			goto __catch319_g_error;
		}
#line 361 "SerializableObjectModelTest.vala"
		_tmp4_ = computer;
#line 361 "SerializableObjectModelTest.vala"
		_tmp5_ = computer_get_manufacturer (_tmp4_);
#line 361 "SerializableObjectModelTest.vala"
		_tmp6_ = _tmp5_;
#line 361 "SerializableObjectModelTest.vala"
		if (g_strcmp0 (_tmp6_, "ThecnicalGroup") != 0) {
#line 4920 "SerializableObjectModelTest.c"
			FILE* _tmp7_;
			Computer* _tmp8_;
			const gchar* _tmp9_;
			const gchar* _tmp10_;
			const gchar* _tmp11_;
			gchar* _tmp12_;
			gchar* _tmp13_;
#line 362 "SerializableObjectModelTest.vala"
			_tmp7_ = stdout;
#line 362 "SerializableObjectModelTest.vala"
			_tmp8_ = computer;
#line 362 "SerializableObjectModelTest.vala"
			_tmp9_ = computer_get_manufacturer (_tmp8_);
#line 362 "SerializableObjectModelTest.vala"
			_tmp10_ = _tmp9_;
#line 362 "SerializableObjectModelTest.vala"
			_tmp11_ = string_to_string (_tmp10_);
#line 362 "SerializableObjectModelTest.vala"
			_tmp12_ = g_strconcat ("ERROR XML_COMPUTER: manufacturer val: ", _tmp11_, "\n", NULL);
#line 362 "SerializableObjectModelTest.vala"
			_tmp13_ = _tmp12_;
#line 362 "SerializableObjectModelTest.vala"
			fprintf (_tmp7_, "%s", _tmp13_);
#line 362 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp13_);
#line 363 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 4948 "SerializableObjectModelTest.c"
		}
#line 365 "SerializableObjectModelTest.vala"
		_tmp14_ = computer;
#line 365 "SerializableObjectModelTest.vala"
		_tmp15_ = computer_get_model (_tmp14_);
#line 365 "SerializableObjectModelTest.vala"
		_tmp16_ = _tmp15_;
#line 365 "SerializableObjectModelTest.vala"
		if (g_strcmp0 (_tmp16_, "YH576G") != 0) {
#line 4958 "SerializableObjectModelTest.c"
			FILE* _tmp17_;
			Computer* _tmp18_;
			const gchar* _tmp19_;
			const gchar* _tmp20_;
			const gchar* _tmp21_;
			gchar* _tmp22_;
			gchar* _tmp23_;
#line 366 "SerializableObjectModelTest.vala"
			_tmp17_ = stdout;
#line 366 "SerializableObjectModelTest.vala"
			_tmp18_ = computer;
#line 366 "SerializableObjectModelTest.vala"
			_tmp19_ = computer_get_model (_tmp18_);
#line 366 "SerializableObjectModelTest.vala"
			_tmp20_ = _tmp19_;
#line 366 "SerializableObjectModelTest.vala"
			_tmp21_ = string_to_string (_tmp20_);
#line 366 "SerializableObjectModelTest.vala"
			_tmp22_ = g_strconcat ("ERROR XML_COMPUTER: model val: ", _tmp21_, "\n", NULL);
#line 366 "SerializableObjectModelTest.vala"
			_tmp23_ = _tmp22_;
#line 366 "SerializableObjectModelTest.vala"
			fprintf (_tmp17_, "%s", _tmp23_);
#line 366 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp23_);
#line 367 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 4986 "SerializableObjectModelTest.c"
		}
#line 369 "SerializableObjectModelTest.vala"
		_tmp24_ = computer;
#line 369 "SerializableObjectModelTest.vala"
		_tmp25_ = computer_get_cores (_tmp24_);
#line 369 "SerializableObjectModelTest.vala"
		_tmp26_ = _tmp25_;
#line 369 "SerializableObjectModelTest.vala"
		if (_tmp26_ != 4) {
#line 4996 "SerializableObjectModelTest.c"
			FILE* _tmp27_;
			Computer* _tmp28_;
			gint _tmp29_;
			gint _tmp30_;
			gchar* _tmp31_;
			gchar* _tmp32_;
			gchar* _tmp33_;
			gchar* _tmp34_;
#line 370 "SerializableObjectModelTest.vala"
			_tmp27_ = stdout;
#line 370 "SerializableObjectModelTest.vala"
			_tmp28_ = computer;
#line 370 "SerializableObjectModelTest.vala"
			_tmp29_ = computer_get_cores (_tmp28_);
#line 370 "SerializableObjectModelTest.vala"
			_tmp30_ = _tmp29_;
#line 370 "SerializableObjectModelTest.vala"
			_tmp31_ = g_strdup_printf ("%i", _tmp30_);
#line 370 "SerializableObjectModelTest.vala"
			_tmp32_ = _tmp31_;
#line 370 "SerializableObjectModelTest.vala"
			_tmp33_ = g_strconcat ("ERROR XML_COMPUTER: cores val: ", _tmp32_, "\n", NULL);
#line 370 "SerializableObjectModelTest.vala"
			_tmp34_ = _tmp33_;
#line 370 "SerializableObjectModelTest.vala"
			fprintf (_tmp27_, "%s", _tmp34_);
#line 370 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp34_);
#line 370 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp32_);
#line 371 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 5029 "SerializableObjectModelTest.c"
		}
#line 373 "SerializableObjectModelTest.vala"
		_tmp35_ = computer;
#line 373 "SerializableObjectModelTest.vala"
		_tmp36_ = computer_get_ghz (_tmp35_);
#line 373 "SerializableObjectModelTest.vala"
		_tmp37_ = _tmp36_;
#line 373 "SerializableObjectModelTest.vala"
		if (_tmp37_ != ((gfloat) 2.8)) {
#line 5039 "SerializableObjectModelTest.c"
			FILE* _tmp38_;
			Computer* _tmp39_;
			gfloat _tmp40_;
			gfloat _tmp41_;
			gchar* _tmp42_;
			gchar* _tmp43_;
			gchar* _tmp44_;
			gchar* _tmp45_;
#line 374 "SerializableObjectModelTest.vala"
			_tmp38_ = stdout;
#line 374 "SerializableObjectModelTest.vala"
			_tmp39_ = computer;
#line 374 "SerializableObjectModelTest.vala"
			_tmp40_ = computer_get_ghz (_tmp39_);
#line 374 "SerializableObjectModelTest.vala"
			_tmp41_ = _tmp40_;
#line 374 "SerializableObjectModelTest.vala"
			_tmp42_ = g_strdup_printf ("%g", _tmp41_);
#line 374 "SerializableObjectModelTest.vala"
			_tmp43_ = _tmp42_;
#line 374 "SerializableObjectModelTest.vala"
			_tmp44_ = g_strconcat ("ERROR XML_COMPUTER: ghz val: ", _tmp43_, "\n", NULL);
#line 374 "SerializableObjectModelTest.vala"
			_tmp45_ = _tmp44_;
#line 374 "SerializableObjectModelTest.vala"
			fprintf (_tmp38_, "%s", _tmp45_);
#line 374 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp45_);
#line 374 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp43_);
#line 375 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 5072 "SerializableObjectModelTest.c"
		}
#line 358 "SerializableObjectModelTest.vala"
		_g_object_unref0 (doc);
#line 5076 "SerializableObjectModelTest.c"
	}
	goto __finally319;
	__catch319_g_error:
	{
		GError* e = NULL;
		Computer* _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
		const gchar* _tmp49_;
		const gchar* _tmp50_;
		const gchar* _tmp51_;
		gchar* _tmp52_;
		gchar* _tmp53_;
#line 358 "SerializableObjectModelTest.vala"
		e = _inner_error0_;
#line 358 "SerializableObjectModelTest.vala"
		_inner_error0_ = NULL;
#line 379 "SerializableObjectModelTest.vala"
		_tmp46_ = computer;
#line 379 "SerializableObjectModelTest.vala"
		_tmp47_ = gxml_serializable_object_model_to_string ((GXmlSerializableObjectModel*) _tmp46_);
#line 379 "SerializableObjectModelTest.vala"
		_tmp48_ = _tmp47_;
#line 379 "SerializableObjectModelTest.vala"
		_tmp49_ = string_to_string (_tmp48_);
#line 379 "SerializableObjectModelTest.vala"
		_tmp50_ = e->message;
#line 379 "SerializableObjectModelTest.vala"
		_tmp51_ = string_to_string (_tmp50_);
#line 379 "SerializableObjectModelTest.vala"
		_tmp52_ = g_strconcat ("GHz : ", _tmp49_, " ERROR: ", _tmp51_, NULL);
#line 379 "SerializableObjectModelTest.vala"
		_tmp53_ = _tmp52_;
#line 379 "SerializableObjectModelTest.vala"
		g_message ("SerializableObjectModelTest.vala:379: %s", _tmp53_);
#line 379 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp53_);
#line 379 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp48_);
#line 380 "SerializableObjectModelTest.vala"
		g_assert_not_reached ();
#line 358 "SerializableObjectModelTest.vala"
		_g_error_free0 (e);
#line 5120 "SerializableObjectModelTest.c"
	}
	__finally319:
#line 358 "SerializableObjectModelTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 358 "SerializableObjectModelTest.vala"
		_g_object_unref0 (computer);
#line 358 "SerializableObjectModelTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 358 "SerializableObjectModelTest.vala"
		g_clear_error (&_inner_error0_);
#line 358 "SerializableObjectModelTest.vala"
		return;
#line 5133 "SerializableObjectModelTest.c"
	}
#line 356 "SerializableObjectModelTest.vala"
	_g_object_unref0 (computer);
#line 5137 "SerializableObjectModelTest.c"
}

static void
___lambda265__gtest_func (void)
{
#line 355 "SerializableObjectModelTest.vala"
	__lambda265_ ();
#line 5145 "SerializableObjectModelTest.c"
}

static void
__lambda266_ (void)
{
	Manual* manual = NULL;
	Manual* _tmp0_;
	GError* _inner_error0_ = NULL;
#line 386 "SerializableObjectModelTest.vala"
	_tmp0_ = manual_new ();
#line 386 "SerializableObjectModelTest.vala"
	manual = _tmp0_;
#line 5158 "SerializableObjectModelTest.c"
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_;
		Manual* _tmp2_;
		GXmlGDocument* _tmp3_;
		Manual* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		Manual* _tmp14_;
		gint _tmp15_;
		gint _tmp16_;
		Manual* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		gboolean _tmp28_;
#line 388 "SerializableObjectModelTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <manual document=\"Specification\" pages=\"3\">" \
"This is an Specification file</manual>", 0, &_inner_error0_);
#line 388 "SerializableObjectModelTest.vala"
		doc = _tmp1_;
#line 388 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 5180 "SerializableObjectModelTest.c"
			goto __catch320_g_error;
		}
#line 390 "SerializableObjectModelTest.vala"
		_tmp2_ = manual;
#line 390 "SerializableObjectModelTest.vala"
		_tmp3_ = doc;
#line 390 "SerializableObjectModelTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 390 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 390 "SerializableObjectModelTest.vala"
			_g_object_unref0 (doc);
#line 5193 "SerializableObjectModelTest.c"
			goto __catch320_g_error;
		}
#line 391 "SerializableObjectModelTest.vala"
		_tmp4_ = manual;
#line 391 "SerializableObjectModelTest.vala"
		_tmp5_ = manual_get_document (_tmp4_);
#line 391 "SerializableObjectModelTest.vala"
		_tmp6_ = _tmp5_;
#line 391 "SerializableObjectModelTest.vala"
		if (g_strcmp0 (_tmp6_, "Specification") != 0) {
#line 5204 "SerializableObjectModelTest.c"
			FILE* _tmp7_;
			Manual* _tmp8_;
			const gchar* _tmp9_;
			const gchar* _tmp10_;
			const gchar* _tmp11_;
			gchar* _tmp12_;
			gchar* _tmp13_;
#line 392 "SerializableObjectModelTest.vala"
			_tmp7_ = stdout;
#line 392 "SerializableObjectModelTest.vala"
			_tmp8_ = manual;
#line 392 "SerializableObjectModelTest.vala"
			_tmp9_ = manual_get_document (_tmp8_);
#line 392 "SerializableObjectModelTest.vala"
			_tmp10_ = _tmp9_;
#line 392 "SerializableObjectModelTest.vala"
			_tmp11_ = string_to_string (_tmp10_);
#line 392 "SerializableObjectModelTest.vala"
			_tmp12_ = g_strconcat ("ERROR MANUAL:  Bad document value. Expected 'Specification', got: ", _tmp11_, "\n", NULL);
#line 392 "SerializableObjectModelTest.vala"
			_tmp13_ = _tmp12_;
#line 392 "SerializableObjectModelTest.vala"
			fprintf (_tmp7_, "%s", _tmp13_);
#line 392 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp13_);
#line 393 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 5232 "SerializableObjectModelTest.c"
		}
#line 395 "SerializableObjectModelTest.vala"
		_tmp14_ = manual;
#line 395 "SerializableObjectModelTest.vala"
		_tmp15_ = manual_get_pages (_tmp14_);
#line 395 "SerializableObjectModelTest.vala"
		_tmp16_ = _tmp15_;
#line 395 "SerializableObjectModelTest.vala"
		if (_tmp16_ != 3) {
#line 5242 "SerializableObjectModelTest.c"
			FILE* _tmp17_;
			Manual* _tmp18_;
			gint _tmp19_;
			gint _tmp20_;
			gchar* _tmp21_;
			gchar* _tmp22_;
			gchar* _tmp23_;
			gchar* _tmp24_;
#line 396 "SerializableObjectModelTest.vala"
			_tmp17_ = stdout;
#line 396 "SerializableObjectModelTest.vala"
			_tmp18_ = manual;
#line 396 "SerializableObjectModelTest.vala"
			_tmp19_ = manual_get_pages (_tmp18_);
#line 396 "SerializableObjectModelTest.vala"
			_tmp20_ = _tmp19_;
#line 396 "SerializableObjectModelTest.vala"
			_tmp21_ = g_strdup_printf ("%i", _tmp20_);
#line 396 "SerializableObjectModelTest.vala"
			_tmp22_ = _tmp21_;
#line 396 "SerializableObjectModelTest.vala"
			_tmp23_ = g_strconcat ("ERROR MANUAL:  Bad pages value. Expected '3', got: ", _tmp22_, "\n", NULL);
#line 396 "SerializableObjectModelTest.vala"
			_tmp24_ = _tmp23_;
#line 396 "SerializableObjectModelTest.vala"
			fprintf (_tmp17_, "%s", _tmp24_);
#line 396 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp24_);
#line 396 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp22_);
#line 397 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 5275 "SerializableObjectModelTest.c"
		}
#line 399 "SerializableObjectModelTest.vala"
		_tmp25_ = manual;
#line 399 "SerializableObjectModelTest.vala"
		_tmp26_ = manual_get_contents (_tmp25_);
#line 399 "SerializableObjectModelTest.vala"
		_tmp27_ = _tmp26_;
#line 399 "SerializableObjectModelTest.vala"
		_tmp28_ = g_strcmp0 (_tmp27_, "This is an Specification file") != 0;
#line 399 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp27_);
#line 399 "SerializableObjectModelTest.vala"
		if (_tmp28_) {
#line 5289 "SerializableObjectModelTest.c"
			FILE* _tmp29_;
			Manual* _tmp30_;
			gchar* _tmp31_;
			gchar* _tmp32_;
			const gchar* _tmp33_;
			gchar* _tmp34_;
			gchar* _tmp35_;
#line 400 "SerializableObjectModelTest.vala"
			_tmp29_ = stdout;
#line 400 "SerializableObjectModelTest.vala"
			_tmp30_ = manual;
#line 400 "SerializableObjectModelTest.vala"
			_tmp31_ = manual_get_contents (_tmp30_);
#line 400 "SerializableObjectModelTest.vala"
			_tmp32_ = _tmp31_;
#line 400 "SerializableObjectModelTest.vala"
			_tmp33_ = string_to_string (_tmp32_);
#line 400 "SerializableObjectModelTest.vala"
			_tmp34_ = g_strconcat ("ERROR MANUAL:  Bad GElement content value. Expected 'This is an Specif" \
"ication file', got: ", _tmp33_, "\n", NULL);
#line 400 "SerializableObjectModelTest.vala"
			_tmp35_ = _tmp34_;
#line 400 "SerializableObjectModelTest.vala"
			fprintf (_tmp29_, "%s", _tmp35_);
#line 400 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp35_);
#line 400 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp32_);
#line 401 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 5319 "SerializableObjectModelTest.c"
		}
#line 387 "SerializableObjectModelTest.vala"
		_g_object_unref0 (doc);
#line 5323 "SerializableObjectModelTest.c"
	}
	goto __finally320;
	__catch320_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp36_;
		const gchar* _tmp37_;
		gchar* _tmp38_;
		gchar* _tmp39_;
#line 387 "SerializableObjectModelTest.vala"
		e = _inner_error0_;
#line 387 "SerializableObjectModelTest.vala"
		_inner_error0_ = NULL;
#line 405 "SerializableObjectModelTest.vala"
		_tmp36_ = e->message;
#line 405 "SerializableObjectModelTest.vala"
		_tmp37_ = string_to_string (_tmp36_);
#line 405 "SerializableObjectModelTest.vala"
		_tmp38_ = g_strconcat ("Error: ", _tmp37_, NULL);
#line 405 "SerializableObjectModelTest.vala"
		_tmp39_ = _tmp38_;
#line 405 "SerializableObjectModelTest.vala"
		g_message ("SerializableObjectModelTest.vala:405: %s", _tmp39_);
#line 405 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp39_);
#line 406 "SerializableObjectModelTest.vala"
		g_assert_not_reached ();
#line 387 "SerializableObjectModelTest.vala"
		_g_error_free0 (e);
#line 5353 "SerializableObjectModelTest.c"
	}
	__finally320:
#line 387 "SerializableObjectModelTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 387 "SerializableObjectModelTest.vala"
		_g_object_unref0 (manual);
#line 387 "SerializableObjectModelTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 387 "SerializableObjectModelTest.vala"
		g_clear_error (&_inner_error0_);
#line 387 "SerializableObjectModelTest.vala"
		return;
#line 5366 "SerializableObjectModelTest.c"
	}
#line 385 "SerializableObjectModelTest.vala"
	_g_object_unref0 (manual);
#line 5370 "SerializableObjectModelTest.c"
}

static void
___lambda266__gtest_func (void)
{
#line 384 "SerializableObjectModelTest.vala"
	__lambda266_ ();
#line 5378 "SerializableObjectModelTest.c"
}

static void
__lambda267_ (void)
{
	GXmlGDocument* doc = NULL;
	GXmlGDocument* _tmp0_;
	Manual* manual = NULL;
	Manual* _tmp1_;
	GError* _inner_error0_ = NULL;
#line 412 "SerializableObjectModelTest.vala"
	_tmp0_ = gxml_gdocument_new ();
#line 412 "SerializableObjectModelTest.vala"
	doc = _tmp0_;
#line 413 "SerializableObjectModelTest.vala"
	_tmp1_ = manual_new ();
#line 413 "SerializableObjectModelTest.vala"
	manual = _tmp1_;
#line 5397 "SerializableObjectModelTest.c"
	{
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		GXmlNode* _tmp7_;
		GXmlNode* _tmp8_;
		GXmlNode* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		GXmlGElement* element = NULL;
		GXmlNode* _tmp13_;
		GXmlNode* _tmp14_;
		GXmlGElement* _tmp15_;
#line 415 "SerializableObjectModelTest.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) manual, (GXmlNode*) doc, &_inner_error0_);
#line 415 "SerializableObjectModelTest.vala"
		_tmp3_ = _tmp2_;
#line 415 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp3_);
#line 415 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 5422 "SerializableObjectModelTest.c"
			goto __catch321_g_error;
		}
#line 416 "SerializableObjectModelTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 416 "SerializableObjectModelTest.vala"
		_tmp5_ = _tmp4_;
#line 416 "SerializableObjectModelTest.vala"
		_tmp6_ = _tmp5_;
#line 416 "SerializableObjectModelTest.vala"
		_vala_assert (_tmp6_ != NULL, "doc.root != null");
#line 416 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp6_);
#line 417 "SerializableObjectModelTest.vala"
		_tmp7_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 417 "SerializableObjectModelTest.vala"
		_tmp8_ = _tmp7_;
#line 417 "SerializableObjectModelTest.vala"
		_tmp9_ = _tmp8_;
#line 417 "SerializableObjectModelTest.vala"
		_tmp10_ = gxml_node_get_name (_tmp9_);
#line 417 "SerializableObjectModelTest.vala"
		_tmp11_ = _tmp10_;
#line 417 "SerializableObjectModelTest.vala"
		_tmp12_ = _tmp11_;
#line 417 "SerializableObjectModelTest.vala"
		_vala_assert (g_strcmp0 (_tmp12_, "manual") == 0, "doc.root.name == \"manual\"");
#line 417 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp12_);
#line 417 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp9_);
#line 418 "SerializableObjectModelTest.vala"
		_tmp13_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 418 "SerializableObjectModelTest.vala"
		_tmp14_ = _tmp13_;
#line 418 "SerializableObjectModelTest.vala"
		_tmp15_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp14_, GXML_TYPE_GELEMENT) ? ((GXmlGElement*) _tmp14_) : NULL;
#line 418 "SerializableObjectModelTest.vala"
		if (_tmp15_ == NULL) {
#line 418 "SerializableObjectModelTest.vala"
			_g_object_unref0 (_tmp14_);
#line 5463 "SerializableObjectModelTest.c"
		}
#line 418 "SerializableObjectModelTest.vala"
		element = _tmp15_;
#line 419 "SerializableObjectModelTest.vala"
		serializable_object_model_test_serialize_manual_check (element, manual);
#line 414 "SerializableObjectModelTest.vala"
		_g_object_unref0 (element);
#line 5471 "SerializableObjectModelTest.c"
	}
	goto __finally321;
	__catch321_g_error:
	{
		GError* e = NULL;
		FILE* _tmp16_;
		const gchar* _tmp17_;
		const gchar* _tmp18_;
#line 414 "SerializableObjectModelTest.vala"
		e = _inner_error0_;
#line 414 "SerializableObjectModelTest.vala"
		_inner_error0_ = NULL;
#line 421 "SerializableObjectModelTest.vala"
		_tmp16_ = stdout;
#line 421 "SerializableObjectModelTest.vala"
		_tmp17_ = e->message;
#line 421 "SerializableObjectModelTest.vala"
		_tmp18_ = string_to_string (_tmp17_);
#line 421 "SerializableObjectModelTest.vala"
		fprintf (_tmp16_, "%s", _tmp18_);
#line 422 "SerializableObjectModelTest.vala"
		g_assert_not_reached ();
#line 414 "SerializableObjectModelTest.vala"
		_g_error_free0 (e);
#line 5496 "SerializableObjectModelTest.c"
	}
	__finally321:
#line 414 "SerializableObjectModelTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 414 "SerializableObjectModelTest.vala"
		_g_object_unref0 (manual);
#line 414 "SerializableObjectModelTest.vala"
		_g_object_unref0 (doc);
#line 414 "SerializableObjectModelTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 414 "SerializableObjectModelTest.vala"
		g_clear_error (&_inner_error0_);
#line 414 "SerializableObjectModelTest.vala"
		return;
#line 5511 "SerializableObjectModelTest.c"
	}
#line 411 "SerializableObjectModelTest.vala"
	_g_object_unref0 (manual);
#line 411 "SerializableObjectModelTest.vala"
	_g_object_unref0 (doc);
#line 5517 "SerializableObjectModelTest.c"
}

static void
___lambda267__gtest_func (void)
{
#line 410 "SerializableObjectModelTest.vala"
	__lambda267_ ();
#line 5525 "SerializableObjectModelTest.c"
}

static void
__lambda268_ (void)
{
	Package* package = NULL;
	Package* _tmp0_;
	GError* _inner_error0_ = NULL;
#line 428 "SerializableObjectModelTest.vala"
	_tmp0_ = package_new ();
#line 428 "SerializableObjectModelTest.vala"
	package = _tmp0_;
#line 5538 "SerializableObjectModelTest.c"
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_;
		Package* _tmp2_;
		GXmlGDocument* _tmp3_;
		Package* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		Package* _tmp14_;
		const gchar* _tmp15_;
		const gchar* _tmp16_;
		Package* _tmp24_;
		Manual* _tmp25_;
		Manual* _tmp26_;
		const gchar* _tmp27_;
		const gchar* _tmp28_;
		Package* _tmp38_;
		Manual* _tmp39_;
		Manual* _tmp40_;
		gint _tmp41_;
		gint _tmp42_;
		Package* _tmp53_;
		Manual* _tmp54_;
		Manual* _tmp55_;
		gchar* _tmp56_;
		gchar* _tmp57_;
		gboolean _tmp58_;
		Package* _tmp68_;
		Computer* _tmp69_;
		Computer* _tmp70_;
		const gchar* _tmp71_;
		const gchar* _tmp72_;
		Package* _tmp82_;
		Computer* _tmp83_;
		Computer* _tmp84_;
		const gchar* _tmp85_;
		const gchar* _tmp86_;
		Package* _tmp96_;
		Computer* _tmp97_;
		Computer* _tmp98_;
		gint _tmp99_;
		gint _tmp100_;
		Package* _tmp111_;
		Computer* _tmp112_;
		Computer* _tmp113_;
		gfloat _tmp114_;
		gfloat _tmp115_;
#line 430 "SerializableObjectModelTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string (XML_PACKAGE_FILE, 0, &_inner_error0_);
#line 430 "SerializableObjectModelTest.vala"
		doc = _tmp1_;
#line 430 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 5592 "SerializableObjectModelTest.c"
			goto __catch322_g_error;
		}
#line 431 "SerializableObjectModelTest.vala"
		_tmp2_ = package;
#line 431 "SerializableObjectModelTest.vala"
		_tmp3_ = doc;
#line 431 "SerializableObjectModelTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 431 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 431 "SerializableObjectModelTest.vala"
			_g_object_unref0 (doc);
#line 5605 "SerializableObjectModelTest.c"
			goto __catch322_g_error;
		}
#line 432 "SerializableObjectModelTest.vala"
		_tmp4_ = package;
#line 432 "SerializableObjectModelTest.vala"
		_tmp5_ = package_get_source (_tmp4_);
#line 432 "SerializableObjectModelTest.vala"
		_tmp6_ = _tmp5_;
#line 432 "SerializableObjectModelTest.vala"
		if (g_strcmp0 (_tmp6_, "Mexico/Central") != 0) {
#line 5616 "SerializableObjectModelTest.c"
			FILE* _tmp7_;
			Package* _tmp8_;
			const gchar* _tmp9_;
			const gchar* _tmp10_;
			const gchar* _tmp11_;
			gchar* _tmp12_;
			gchar* _tmp13_;
#line 433 "SerializableObjectModelTest.vala"
			_tmp7_ = stdout;
#line 433 "SerializableObjectModelTest.vala"
			_tmp8_ = package;
#line 433 "SerializableObjectModelTest.vala"
			_tmp9_ = package_get_source (_tmp8_);
#line 433 "SerializableObjectModelTest.vala"
			_tmp10_ = _tmp9_;
#line 433 "SerializableObjectModelTest.vala"
			_tmp11_ = string_to_string (_tmp10_);
#line 433 "SerializableObjectModelTest.vala"
			_tmp12_ = g_strconcat ("ERROR PACKAGE: source: ", _tmp11_, "\n", NULL);
#line 433 "SerializableObjectModelTest.vala"
			_tmp13_ = _tmp12_;
#line 433 "SerializableObjectModelTest.vala"
			fprintf (_tmp7_, "%s", _tmp13_);
#line 433 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp13_);
#line 434 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 5644 "SerializableObjectModelTest.c"
		}
#line 436 "SerializableObjectModelTest.vala"
		_tmp14_ = package;
#line 436 "SerializableObjectModelTest.vala"
		_tmp15_ = package_get_destiny (_tmp14_);
#line 436 "SerializableObjectModelTest.vala"
		_tmp16_ = _tmp15_;
#line 436 "SerializableObjectModelTest.vala"
		if (g_strcmp0 (_tmp16_, "Japan") != 0) {
#line 5654 "SerializableObjectModelTest.c"
			FILE* _tmp17_;
			Package* _tmp18_;
			const gchar* _tmp19_;
			const gchar* _tmp20_;
			const gchar* _tmp21_;
			gchar* _tmp22_;
			gchar* _tmp23_;
#line 437 "SerializableObjectModelTest.vala"
			_tmp17_ = stdout;
#line 437 "SerializableObjectModelTest.vala"
			_tmp18_ = package;
#line 437 "SerializableObjectModelTest.vala"
			_tmp19_ = package_get_destiny (_tmp18_);
#line 437 "SerializableObjectModelTest.vala"
			_tmp20_ = _tmp19_;
#line 437 "SerializableObjectModelTest.vala"
			_tmp21_ = string_to_string (_tmp20_);
#line 437 "SerializableObjectModelTest.vala"
			_tmp22_ = g_strconcat ("ERROR PACKAGE: destiny: ", _tmp21_, "\n", NULL);
#line 437 "SerializableObjectModelTest.vala"
			_tmp23_ = _tmp22_;
#line 437 "SerializableObjectModelTest.vala"
			fprintf (_tmp17_, "%s", _tmp23_);
#line 437 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp23_);
#line 438 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 5682 "SerializableObjectModelTest.c"
		}
#line 444 "SerializableObjectModelTest.vala"
		_tmp24_ = package;
#line 444 "SerializableObjectModelTest.vala"
		_tmp25_ = package_get_manual (_tmp24_);
#line 444 "SerializableObjectModelTest.vala"
		_tmp26_ = _tmp25_;
#line 444 "SerializableObjectModelTest.vala"
		_tmp27_ = manual_get_document (_tmp26_);
#line 444 "SerializableObjectModelTest.vala"
		_tmp28_ = _tmp27_;
#line 444 "SerializableObjectModelTest.vala"
		if (g_strcmp0 (_tmp28_, "Specification") != 0) {
#line 5696 "SerializableObjectModelTest.c"
			FILE* _tmp29_;
			Package* _tmp30_;
			Manual* _tmp31_;
			Manual* _tmp32_;
			const gchar* _tmp33_;
			const gchar* _tmp34_;
			const gchar* _tmp35_;
			gchar* _tmp36_;
			gchar* _tmp37_;
#line 445 "SerializableObjectModelTest.vala"
			_tmp29_ = stdout;
#line 445 "SerializableObjectModelTest.vala"
			_tmp30_ = package;
#line 445 "SerializableObjectModelTest.vala"
			_tmp31_ = package_get_manual (_tmp30_);
#line 445 "SerializableObjectModelTest.vala"
			_tmp32_ = _tmp31_;
#line 445 "SerializableObjectModelTest.vala"
			_tmp33_ = manual_get_document (_tmp32_);
#line 445 "SerializableObjectModelTest.vala"
			_tmp34_ = _tmp33_;
#line 445 "SerializableObjectModelTest.vala"
			_tmp35_ = string_to_string (_tmp34_);
#line 445 "SerializableObjectModelTest.vala"
			_tmp36_ = g_strconcat ("ERROR PACKAGE: manual document: ", _tmp35_, "\n", NULL);
#line 445 "SerializableObjectModelTest.vala"
			_tmp37_ = _tmp36_;
#line 445 "SerializableObjectModelTest.vala"
			fprintf (_tmp29_, "%s", _tmp37_);
#line 445 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp37_);
#line 446 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 5730 "SerializableObjectModelTest.c"
		}
#line 448 "SerializableObjectModelTest.vala"
		_tmp38_ = package;
#line 448 "SerializableObjectModelTest.vala"
		_tmp39_ = package_get_manual (_tmp38_);
#line 448 "SerializableObjectModelTest.vala"
		_tmp40_ = _tmp39_;
#line 448 "SerializableObjectModelTest.vala"
		_tmp41_ = manual_get_pages (_tmp40_);
#line 448 "SerializableObjectModelTest.vala"
		_tmp42_ = _tmp41_;
#line 448 "SerializableObjectModelTest.vala"
		if (_tmp42_ != 3) {
#line 5744 "SerializableObjectModelTest.c"
			FILE* _tmp43_;
			Package* _tmp44_;
			Manual* _tmp45_;
			Manual* _tmp46_;
			gint _tmp47_;
			gint _tmp48_;
			gchar* _tmp49_;
			gchar* _tmp50_;
			gchar* _tmp51_;
			gchar* _tmp52_;
#line 449 "SerializableObjectModelTest.vala"
			_tmp43_ = stdout;
#line 449 "SerializableObjectModelTest.vala"
			_tmp44_ = package;
#line 449 "SerializableObjectModelTest.vala"
			_tmp45_ = package_get_manual (_tmp44_);
#line 449 "SerializableObjectModelTest.vala"
			_tmp46_ = _tmp45_;
#line 449 "SerializableObjectModelTest.vala"
			_tmp47_ = manual_get_pages (_tmp46_);
#line 449 "SerializableObjectModelTest.vala"
			_tmp48_ = _tmp47_;
#line 449 "SerializableObjectModelTest.vala"
			_tmp49_ = g_strdup_printf ("%i", _tmp48_);
#line 449 "SerializableObjectModelTest.vala"
			_tmp50_ = _tmp49_;
#line 449 "SerializableObjectModelTest.vala"
			_tmp51_ = g_strconcat ("ERROR PACKAGE: manual pages: ", _tmp50_, "\n", NULL);
#line 449 "SerializableObjectModelTest.vala"
			_tmp52_ = _tmp51_;
#line 449 "SerializableObjectModelTest.vala"
			fprintf (_tmp43_, "%s", _tmp52_);
#line 449 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp52_);
#line 449 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp50_);
#line 450 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 5783 "SerializableObjectModelTest.c"
		}
#line 452 "SerializableObjectModelTest.vala"
		_tmp53_ = package;
#line 452 "SerializableObjectModelTest.vala"
		_tmp54_ = package_get_manual (_tmp53_);
#line 452 "SerializableObjectModelTest.vala"
		_tmp55_ = _tmp54_;
#line 452 "SerializableObjectModelTest.vala"
		_tmp56_ = manual_get_contents (_tmp55_);
#line 452 "SerializableObjectModelTest.vala"
		_tmp57_ = _tmp56_;
#line 452 "SerializableObjectModelTest.vala"
		_tmp58_ = g_strcmp0 (_tmp57_, "This is an Specification file") != 0;
#line 452 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp57_);
#line 452 "SerializableObjectModelTest.vala"
		if (_tmp58_) {
#line 5801 "SerializableObjectModelTest.c"
			FILE* _tmp59_;
			Package* _tmp60_;
			Manual* _tmp61_;
			Manual* _tmp62_;
			gchar* _tmp63_;
			gchar* _tmp64_;
			const gchar* _tmp65_;
			gchar* _tmp66_;
			gchar* _tmp67_;
#line 453 "SerializableObjectModelTest.vala"
			_tmp59_ = stdout;
#line 453 "SerializableObjectModelTest.vala"
			_tmp60_ = package;
#line 453 "SerializableObjectModelTest.vala"
			_tmp61_ = package_get_manual (_tmp60_);
#line 453 "SerializableObjectModelTest.vala"
			_tmp62_ = _tmp61_;
#line 453 "SerializableObjectModelTest.vala"
			_tmp63_ = manual_get_contents (_tmp62_);
#line 453 "SerializableObjectModelTest.vala"
			_tmp64_ = _tmp63_;
#line 453 "SerializableObjectModelTest.vala"
			_tmp65_ = string_to_string (_tmp64_);
#line 453 "SerializableObjectModelTest.vala"
			_tmp66_ = g_strconcat ("ERROR PACKAGE: manual value: ", _tmp65_, "\n", NULL);
#line 453 "SerializableObjectModelTest.vala"
			_tmp67_ = _tmp66_;
#line 453 "SerializableObjectModelTest.vala"
			fprintf (_tmp59_, "%s", _tmp67_);
#line 453 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp67_);
#line 453 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp64_);
#line 454 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 5837 "SerializableObjectModelTest.c"
		}
#line 456 "SerializableObjectModelTest.vala"
		_tmp68_ = package;
#line 456 "SerializableObjectModelTest.vala"
		_tmp69_ = package_get_computer (_tmp68_);
#line 456 "SerializableObjectModelTest.vala"
		_tmp70_ = _tmp69_;
#line 456 "SerializableObjectModelTest.vala"
		_tmp71_ = computer_get_manufacturer (_tmp70_);
#line 456 "SerializableObjectModelTest.vala"
		_tmp72_ = _tmp71_;
#line 456 "SerializableObjectModelTest.vala"
		if (g_strcmp0 (_tmp72_, "LanCorop") != 0) {
#line 5851 "SerializableObjectModelTest.c"
			FILE* _tmp73_;
			Package* _tmp74_;
			Computer* _tmp75_;
			Computer* _tmp76_;
			const gchar* _tmp77_;
			const gchar* _tmp78_;
			const gchar* _tmp79_;
			gchar* _tmp80_;
			gchar* _tmp81_;
#line 457 "SerializableObjectModelTest.vala"
			_tmp73_ = stdout;
#line 457 "SerializableObjectModelTest.vala"
			_tmp74_ = package;
#line 457 "SerializableObjectModelTest.vala"
			_tmp75_ = package_get_computer (_tmp74_);
#line 457 "SerializableObjectModelTest.vala"
			_tmp76_ = _tmp75_;
#line 457 "SerializableObjectModelTest.vala"
			_tmp77_ = computer_get_manufacturer (_tmp76_);
#line 457 "SerializableObjectModelTest.vala"
			_tmp78_ = _tmp77_;
#line 457 "SerializableObjectModelTest.vala"
			_tmp79_ = string_to_string (_tmp78_);
#line 457 "SerializableObjectModelTest.vala"
			_tmp80_ = g_strconcat ("ERROR PACKAGE: computer manufacturer: ", _tmp79_, "\n", NULL);
#line 457 "SerializableObjectModelTest.vala"
			_tmp81_ = _tmp80_;
#line 457 "SerializableObjectModelTest.vala"
			fprintf (_tmp73_, "%s", _tmp81_);
#line 457 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp81_);
#line 458 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 5885 "SerializableObjectModelTest.c"
		}
#line 460 "SerializableObjectModelTest.vala"
		_tmp82_ = package;
#line 460 "SerializableObjectModelTest.vala"
		_tmp83_ = package_get_computer (_tmp82_);
#line 460 "SerializableObjectModelTest.vala"
		_tmp84_ = _tmp83_;
#line 460 "SerializableObjectModelTest.vala"
		_tmp85_ = computer_get_model (_tmp84_);
#line 460 "SerializableObjectModelTest.vala"
		_tmp86_ = _tmp85_;
#line 460 "SerializableObjectModelTest.vala"
		if (g_strcmp0 (_tmp86_, "Lap39120") != 0) {
#line 5899 "SerializableObjectModelTest.c"
			FILE* _tmp87_;
			Package* _tmp88_;
			Computer* _tmp89_;
			Computer* _tmp90_;
			const gchar* _tmp91_;
			const gchar* _tmp92_;
			const gchar* _tmp93_;
			gchar* _tmp94_;
			gchar* _tmp95_;
#line 461 "SerializableObjectModelTest.vala"
			_tmp87_ = stdout;
#line 461 "SerializableObjectModelTest.vala"
			_tmp88_ = package;
#line 461 "SerializableObjectModelTest.vala"
			_tmp89_ = package_get_computer (_tmp88_);
#line 461 "SerializableObjectModelTest.vala"
			_tmp90_ = _tmp89_;
#line 461 "SerializableObjectModelTest.vala"
			_tmp91_ = computer_get_model (_tmp90_);
#line 461 "SerializableObjectModelTest.vala"
			_tmp92_ = _tmp91_;
#line 461 "SerializableObjectModelTest.vala"
			_tmp93_ = string_to_string (_tmp92_);
#line 461 "SerializableObjectModelTest.vala"
			_tmp94_ = g_strconcat ("ERROR PACKAGE: computer model: ", _tmp93_, "\n", NULL);
#line 461 "SerializableObjectModelTest.vala"
			_tmp95_ = _tmp94_;
#line 461 "SerializableObjectModelTest.vala"
			fprintf (_tmp87_, "%s", _tmp95_);
#line 461 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp95_);
#line 462 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 5933 "SerializableObjectModelTest.c"
		}
#line 464 "SerializableObjectModelTest.vala"
		_tmp96_ = package;
#line 464 "SerializableObjectModelTest.vala"
		_tmp97_ = package_get_computer (_tmp96_);
#line 464 "SerializableObjectModelTest.vala"
		_tmp98_ = _tmp97_;
#line 464 "SerializableObjectModelTest.vala"
		_tmp99_ = computer_get_cores (_tmp98_);
#line 464 "SerializableObjectModelTest.vala"
		_tmp100_ = _tmp99_;
#line 464 "SerializableObjectModelTest.vala"
		if (_tmp100_ != 16) {
#line 5947 "SerializableObjectModelTest.c"
			FILE* _tmp101_;
			Package* _tmp102_;
			Computer* _tmp103_;
			Computer* _tmp104_;
			gint _tmp105_;
			gint _tmp106_;
			gchar* _tmp107_;
			gchar* _tmp108_;
			gchar* _tmp109_;
			gchar* _tmp110_;
#line 465 "SerializableObjectModelTest.vala"
			_tmp101_ = stdout;
#line 465 "SerializableObjectModelTest.vala"
			_tmp102_ = package;
#line 465 "SerializableObjectModelTest.vala"
			_tmp103_ = package_get_computer (_tmp102_);
#line 465 "SerializableObjectModelTest.vala"
			_tmp104_ = _tmp103_;
#line 465 "SerializableObjectModelTest.vala"
			_tmp105_ = computer_get_cores (_tmp104_);
#line 465 "SerializableObjectModelTest.vala"
			_tmp106_ = _tmp105_;
#line 465 "SerializableObjectModelTest.vala"
			_tmp107_ = g_strdup_printf ("%i", _tmp106_);
#line 465 "SerializableObjectModelTest.vala"
			_tmp108_ = _tmp107_;
#line 465 "SerializableObjectModelTest.vala"
			_tmp109_ = g_strconcat ("ERROR PACKAGE: computer cores: ", _tmp108_, "\n", NULL);
#line 465 "SerializableObjectModelTest.vala"
			_tmp110_ = _tmp109_;
#line 465 "SerializableObjectModelTest.vala"
			fprintf (_tmp101_, "%s", _tmp110_);
#line 465 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp110_);
#line 465 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp108_);
#line 466 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 5986 "SerializableObjectModelTest.c"
		}
#line 468 "SerializableObjectModelTest.vala"
		_tmp111_ = package;
#line 468 "SerializableObjectModelTest.vala"
		_tmp112_ = package_get_computer (_tmp111_);
#line 468 "SerializableObjectModelTest.vala"
		_tmp113_ = _tmp112_;
#line 468 "SerializableObjectModelTest.vala"
		_tmp114_ = computer_get_ghz (_tmp113_);
#line 468 "SerializableObjectModelTest.vala"
		_tmp115_ = _tmp114_;
#line 468 "SerializableObjectModelTest.vala"
		if (_tmp115_ != ((gfloat) 3.5)) {
#line 6000 "SerializableObjectModelTest.c"
			FILE* _tmp116_;
			Package* _tmp117_;
			Computer* _tmp118_;
			Computer* _tmp119_;
			gfloat _tmp120_;
			gfloat _tmp121_;
			gchar* _tmp122_;
			gchar* _tmp123_;
			gchar* _tmp124_;
			gchar* _tmp125_;
#line 469 "SerializableObjectModelTest.vala"
			_tmp116_ = stdout;
#line 469 "SerializableObjectModelTest.vala"
			_tmp117_ = package;
#line 469 "SerializableObjectModelTest.vala"
			_tmp118_ = package_get_computer (_tmp117_);
#line 469 "SerializableObjectModelTest.vala"
			_tmp119_ = _tmp118_;
#line 469 "SerializableObjectModelTest.vala"
			_tmp120_ = computer_get_ghz (_tmp119_);
#line 469 "SerializableObjectModelTest.vala"
			_tmp121_ = _tmp120_;
#line 469 "SerializableObjectModelTest.vala"
			_tmp122_ = g_strdup_printf ("%g", _tmp121_);
#line 469 "SerializableObjectModelTest.vala"
			_tmp123_ = _tmp122_;
#line 469 "SerializableObjectModelTest.vala"
			_tmp124_ = g_strconcat ("ERROR PACKAGE: computer ghz ", _tmp123_, "\n", NULL);
#line 469 "SerializableObjectModelTest.vala"
			_tmp125_ = _tmp124_;
#line 469 "SerializableObjectModelTest.vala"
			fprintf (_tmp116_, "%s", _tmp125_);
#line 469 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp125_);
#line 469 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp123_);
#line 470 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 6039 "SerializableObjectModelTest.c"
		}
#line 429 "SerializableObjectModelTest.vala"
		_g_object_unref0 (doc);
#line 6043 "SerializableObjectModelTest.c"
	}
	goto __finally322;
	__catch322_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp126_;
		const gchar* _tmp127_;
		gchar* _tmp128_;
		gchar* _tmp129_;
#line 429 "SerializableObjectModelTest.vala"
		e = _inner_error0_;
#line 429 "SerializableObjectModelTest.vala"
		_inner_error0_ = NULL;
#line 474 "SerializableObjectModelTest.vala"
		_tmp126_ = e->message;
#line 474 "SerializableObjectModelTest.vala"
		_tmp127_ = string_to_string (_tmp126_);
#line 474 "SerializableObjectModelTest.vala"
		_tmp128_ = g_strconcat ("Error: ", _tmp127_, NULL);
#line 474 "SerializableObjectModelTest.vala"
		_tmp129_ = _tmp128_;
#line 474 "SerializableObjectModelTest.vala"
		g_message ("SerializableObjectModelTest.vala:474: %s", _tmp129_);
#line 474 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp129_);
#line 475 "SerializableObjectModelTest.vala"
		g_assert_not_reached ();
#line 429 "SerializableObjectModelTest.vala"
		_g_error_free0 (e);
#line 6073 "SerializableObjectModelTest.c"
	}
	__finally322:
#line 429 "SerializableObjectModelTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 429 "SerializableObjectModelTest.vala"
		_g_object_unref0 (package);
#line 429 "SerializableObjectModelTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 429 "SerializableObjectModelTest.vala"
		g_clear_error (&_inner_error0_);
#line 429 "SerializableObjectModelTest.vala"
		return;
#line 6086 "SerializableObjectModelTest.c"
	}
#line 427 "SerializableObjectModelTest.vala"
	_g_object_unref0 (package);
#line 6090 "SerializableObjectModelTest.c"
}

static void
___lambda268__gtest_func (void)
{
#line 426 "SerializableObjectModelTest.vala"
	__lambda268_ ();
#line 6098 "SerializableObjectModelTest.c"
}

static void
__lambda269_ (void)
{
	GXmlGDocument* doc = NULL;
	GXmlGDocument* _tmp0_;
	Package* package = NULL;
	Package* _tmp1_;
	GError* _inner_error0_ = NULL;
#line 481 "SerializableObjectModelTest.vala"
	_tmp0_ = gxml_gdocument_new ();
#line 481 "SerializableObjectModelTest.vala"
	doc = _tmp0_;
#line 482 "SerializableObjectModelTest.vala"
	_tmp1_ = package_new ();
#line 482 "SerializableObjectModelTest.vala"
	package = _tmp1_;
#line 6117 "SerializableObjectModelTest.c"
	{
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gboolean _tmp10_;
		GXmlElement* element = NULL;
		GXmlNode* _tmp21_;
		GXmlNode* _tmp22_;
		GXmlElement* _tmp23_;
		GXmlNode* source = NULL;
		GXmlNode* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		gboolean _tmp28_;
		GXmlNode* destiny = NULL;
		GXmlNode* _tmp36_;
		gchar* _tmp37_;
		gchar* _tmp38_;
		gchar* _tmp39_;
		gboolean _tmp40_;
#line 484 "SerializableObjectModelTest.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) package, (GXmlNode*) doc, &_inner_error0_);
#line 484 "SerializableObjectModelTest.vala"
		_tmp3_ = _tmp2_;
#line 484 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp3_);
#line 484 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 6152 "SerializableObjectModelTest.c"
			goto __catch323_g_error;
		}
#line 485 "SerializableObjectModelTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 485 "SerializableObjectModelTest.vala"
		_tmp5_ = _tmp4_;
#line 485 "SerializableObjectModelTest.vala"
		_tmp6_ = _tmp5_;
#line 485 "SerializableObjectModelTest.vala"
		_tmp7_ = gxml_node_get_name (_tmp6_);
#line 485 "SerializableObjectModelTest.vala"
		_tmp8_ = _tmp7_;
#line 485 "SerializableObjectModelTest.vala"
		_tmp9_ = _tmp8_;
#line 485 "SerializableObjectModelTest.vala"
		_tmp10_ = g_strcmp0 (_tmp9_, "package") != 0;
#line 485 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp9_);
#line 485 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp6_);
#line 485 "SerializableObjectModelTest.vala"
		if (_tmp10_) {
#line 6175 "SerializableObjectModelTest.c"
			FILE* _tmp11_;
			GXmlNode* _tmp12_;
			GXmlNode* _tmp13_;
			GXmlNode* _tmp14_;
			gchar* _tmp15_;
			gchar* _tmp16_;
			gchar* _tmp17_;
			const gchar* _tmp18_;
			gchar* _tmp19_;
			gchar* _tmp20_;
#line 486 "SerializableObjectModelTest.vala"
			_tmp11_ = stdout;
#line 486 "SerializableObjectModelTest.vala"
			_tmp12_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 486 "SerializableObjectModelTest.vala"
			_tmp13_ = _tmp12_;
#line 486 "SerializableObjectModelTest.vala"
			_tmp14_ = _tmp13_;
#line 486 "SerializableObjectModelTest.vala"
			_tmp15_ = gxml_node_get_name (_tmp14_);
#line 486 "SerializableObjectModelTest.vala"
			_tmp16_ = _tmp15_;
#line 486 "SerializableObjectModelTest.vala"
			_tmp17_ = _tmp16_;
#line 486 "SerializableObjectModelTest.vala"
			_tmp18_ = string_to_string (_tmp17_);
#line 486 "SerializableObjectModelTest.vala"
			_tmp19_ = g_strconcat ("ERROR MANUAL:  GElement: ", _tmp18_, "\n", NULL);
#line 486 "SerializableObjectModelTest.vala"
			_tmp20_ = _tmp19_;
#line 486 "SerializableObjectModelTest.vala"
			fprintf (_tmp11_, "%s", _tmp20_);
#line 486 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp20_);
#line 486 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp17_);
#line 486 "SerializableObjectModelTest.vala"
			_g_object_unref0 (_tmp14_);
#line 487 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 6216 "SerializableObjectModelTest.c"
		}
#line 489 "SerializableObjectModelTest.vala"
		_tmp21_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 489 "SerializableObjectModelTest.vala"
		_tmp22_ = _tmp21_;
#line 489 "SerializableObjectModelTest.vala"
		_tmp23_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp22_) : NULL;
#line 489 "SerializableObjectModelTest.vala"
		if (_tmp23_ == NULL) {
#line 489 "SerializableObjectModelTest.vala"
			_g_object_unref0 (_tmp22_);
#line 6228 "SerializableObjectModelTest.c"
		}
#line 489 "SerializableObjectModelTest.vala"
		element = _tmp23_;
#line 490 "SerializableObjectModelTest.vala"
		_tmp24_ = gxml_element_get_attr (element, "source");
#line 490 "SerializableObjectModelTest.vala"
		source = _tmp24_;
#line 491 "SerializableObjectModelTest.vala"
		if (source == NULL) {
#line 491 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 6240 "SerializableObjectModelTest.c"
		}
#line 492 "SerializableObjectModelTest.vala"
		_tmp25_ = gxml_node_get_value (source);
#line 492 "SerializableObjectModelTest.vala"
		_tmp26_ = _tmp25_;
#line 492 "SerializableObjectModelTest.vala"
		_tmp27_ = _tmp26_;
#line 492 "SerializableObjectModelTest.vala"
		_tmp28_ = g_strcmp0 (_tmp27_, "Mexico") != 0;
#line 492 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp27_);
#line 492 "SerializableObjectModelTest.vala"
		if (_tmp28_) {
#line 6254 "SerializableObjectModelTest.c"
			FILE* _tmp29_;
			gchar* _tmp30_;
			gchar* _tmp31_;
			gchar* _tmp32_;
			const gchar* _tmp33_;
			gchar* _tmp34_;
			gchar* _tmp35_;
#line 493 "SerializableObjectModelTest.vala"
			_tmp29_ = stdout;
#line 493 "SerializableObjectModelTest.vala"
			_tmp30_ = gxml_node_get_value (source);
#line 493 "SerializableObjectModelTest.vala"
			_tmp31_ = _tmp30_;
#line 493 "SerializableObjectModelTest.vala"
			_tmp32_ = _tmp31_;
#line 493 "SerializableObjectModelTest.vala"
			_tmp33_ = string_to_string (_tmp32_);
#line 493 "SerializableObjectModelTest.vala"
			_tmp34_ = g_strconcat ("ERROR PACKAGE: source: ", _tmp33_, "\n", NULL);
#line 493 "SerializableObjectModelTest.vala"
			_tmp35_ = _tmp34_;
#line 493 "SerializableObjectModelTest.vala"
			fprintf (_tmp29_, "%s", _tmp35_);
#line 493 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp35_);
#line 493 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp32_);
#line 494 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 6284 "SerializableObjectModelTest.c"
		}
#line 496 "SerializableObjectModelTest.vala"
		_tmp36_ = gxml_element_get_attr (element, "destiny");
#line 496 "SerializableObjectModelTest.vala"
		destiny = _tmp36_;
#line 497 "SerializableObjectModelTest.vala"
		if (destiny == NULL) {
#line 497 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 6294 "SerializableObjectModelTest.c"
		}
#line 498 "SerializableObjectModelTest.vala"
		_tmp37_ = gxml_node_get_value (destiny);
#line 498 "SerializableObjectModelTest.vala"
		_tmp38_ = _tmp37_;
#line 498 "SerializableObjectModelTest.vala"
		_tmp39_ = _tmp38_;
#line 498 "SerializableObjectModelTest.vala"
		_tmp40_ = g_strcmp0 (_tmp39_, "World") != 0;
#line 498 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp39_);
#line 498 "SerializableObjectModelTest.vala"
		if (_tmp40_) {
#line 6308 "SerializableObjectModelTest.c"
			FILE* _tmp41_;
			gchar* _tmp42_;
			gchar* _tmp43_;
			gchar* _tmp44_;
			const gchar* _tmp45_;
			gchar* _tmp46_;
			gchar* _tmp47_;
#line 499 "SerializableObjectModelTest.vala"
			_tmp41_ = stdout;
#line 499 "SerializableObjectModelTest.vala"
			_tmp42_ = gxml_node_get_value (destiny);
#line 499 "SerializableObjectModelTest.vala"
			_tmp43_ = _tmp42_;
#line 499 "SerializableObjectModelTest.vala"
			_tmp44_ = _tmp43_;
#line 499 "SerializableObjectModelTest.vala"
			_tmp45_ = string_to_string (_tmp44_);
#line 499 "SerializableObjectModelTest.vala"
			_tmp46_ = g_strconcat ("ERROR PACKAGE: source: ", _tmp45_, "\n", NULL);
#line 499 "SerializableObjectModelTest.vala"
			_tmp47_ = _tmp46_;
#line 499 "SerializableObjectModelTest.vala"
			fprintf (_tmp41_, "%s", _tmp47_);
#line 499 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp47_);
#line 499 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp44_);
#line 500 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 6338 "SerializableObjectModelTest.c"
		}
#line 483 "SerializableObjectModelTest.vala"
		_g_object_unref0 (destiny);
#line 483 "SerializableObjectModelTest.vala"
		_g_object_unref0 (source);
#line 483 "SerializableObjectModelTest.vala"
		_g_object_unref0 (element);
#line 6346 "SerializableObjectModelTest.c"
	}
	goto __finally323;
	__catch323_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp48_;
		const gchar* _tmp49_;
		gchar* _tmp50_;
		gchar* _tmp51_;
#line 483 "SerializableObjectModelTest.vala"
		e = _inner_error0_;
#line 483 "SerializableObjectModelTest.vala"
		_inner_error0_ = NULL;
#line 504 "SerializableObjectModelTest.vala"
		_tmp48_ = e->message;
#line 504 "SerializableObjectModelTest.vala"
		_tmp49_ = string_to_string (_tmp48_);
#line 504 "SerializableObjectModelTest.vala"
		_tmp50_ = g_strconcat ("Error: ", _tmp49_, NULL);
#line 504 "SerializableObjectModelTest.vala"
		_tmp51_ = _tmp50_;
#line 504 "SerializableObjectModelTest.vala"
		g_message ("SerializableObjectModelTest.vala:504: %s", _tmp51_);
#line 504 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp51_);
#line 505 "SerializableObjectModelTest.vala"
		g_assert_not_reached ();
#line 483 "SerializableObjectModelTest.vala"
		_g_error_free0 (e);
#line 6376 "SerializableObjectModelTest.c"
	}
	__finally323:
#line 483 "SerializableObjectModelTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 483 "SerializableObjectModelTest.vala"
		_g_object_unref0 (package);
#line 483 "SerializableObjectModelTest.vala"
		_g_object_unref0 (doc);
#line 483 "SerializableObjectModelTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 483 "SerializableObjectModelTest.vala"
		g_clear_error (&_inner_error0_);
#line 483 "SerializableObjectModelTest.vala"
		return;
#line 6391 "SerializableObjectModelTest.c"
	}
#line 480 "SerializableObjectModelTest.vala"
	_g_object_unref0 (package);
#line 480 "SerializableObjectModelTest.vala"
	_g_object_unref0 (doc);
#line 6397 "SerializableObjectModelTest.c"
}

static void
___lambda269__gtest_func (void)
{
#line 479 "SerializableObjectModelTest.vala"
	__lambda269_ ();
#line 6405 "SerializableObjectModelTest.c"
}

static void
__lambda270_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		Package* package = NULL;
		Package* _tmp1_;
		Package* _tmp2_;
		GXmlGDocument* _tmp3_;
		Package* _tmp4_;
		GArray* _tmp5_;
		GArray* _tmp6_;
		Package* _tmp15_;
		GArray* _tmp16_;
		GArray* _tmp17_;
		const gchar* _tmp18_;
		Package* _tmp27_;
		GArray* _tmp28_;
		GArray* _tmp29_;
		const gchar* _tmp30_;
		Package* _tmp39_;
		GArray* _tmp40_;
		GArray* _tmp41_;
		const gchar* _tmp42_;
#line 512 "SerializableObjectModelTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string (XML_PACKAGE_FILE, 0, &_inner_error0_);
#line 512 "SerializableObjectModelTest.vala"
		doc = _tmp0_;
#line 512 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 6440 "SerializableObjectModelTest.c"
			goto __catch324_g_error;
		}
#line 513 "SerializableObjectModelTest.vala"
		_tmp1_ = package_new ();
#line 513 "SerializableObjectModelTest.vala"
		package = _tmp1_;
#line 514 "SerializableObjectModelTest.vala"
		_tmp2_ = package;
#line 514 "SerializableObjectModelTest.vala"
		_tmp3_ = doc;
#line 514 "SerializableObjectModelTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 514 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 514 "SerializableObjectModelTest.vala"
			_g_object_unref0 (package);
#line 514 "SerializableObjectModelTest.vala"
			_g_object_unref0 (doc);
#line 6459 "SerializableObjectModelTest.c"
			goto __catch324_g_error;
		}
#line 515 "SerializableObjectModelTest.vala"
		_tmp4_ = package;
#line 515 "SerializableObjectModelTest.vala"
		_tmp5_ = package_get_tags (_tmp4_);
#line 515 "SerializableObjectModelTest.vala"
		_tmp6_ = _tmp5_;
#line 515 "SerializableObjectModelTest.vala"
		if (_tmp6_->len != ((guint) 3)) {
#line 6470 "SerializableObjectModelTest.c"
			FILE* _tmp7_;
			Package* _tmp8_;
			GArray* _tmp9_;
			GArray* _tmp10_;
			gchar* _tmp11_;
			gchar* _tmp12_;
			gchar* _tmp13_;
			gchar* _tmp14_;
#line 516 "SerializableObjectModelTest.vala"
			_tmp7_ = stdout;
#line 516 "SerializableObjectModelTest.vala"
			_tmp8_ = package;
#line 516 "SerializableObjectModelTest.vala"
			_tmp9_ = package_get_tags (_tmp8_);
#line 516 "SerializableObjectModelTest.vala"
			_tmp10_ = _tmp9_;
#line 516 "SerializableObjectModelTest.vala"
			_tmp11_ = g_strdup_printf ("%u", _tmp10_->len);
#line 516 "SerializableObjectModelTest.vala"
			_tmp12_ = _tmp11_;
#line 516 "SerializableObjectModelTest.vala"
			_tmp13_ = g_strconcat ("ERROR PACKAGE: tags length: ", _tmp12_, NULL);
#line 516 "SerializableObjectModelTest.vala"
			_tmp14_ = _tmp13_;
#line 516 "SerializableObjectModelTest.vala"
			fprintf (_tmp7_, "%s", _tmp14_);
#line 516 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp14_);
#line 516 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp12_);
#line 517 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 6503 "SerializableObjectModelTest.c"
		}
#line 519 "SerializableObjectModelTest.vala"
		_tmp15_ = package;
#line 519 "SerializableObjectModelTest.vala"
		_tmp16_ = package_get_tags (_tmp15_);
#line 519 "SerializableObjectModelTest.vala"
		_tmp17_ = _tmp16_;
#line 519 "SerializableObjectModelTest.vala"
		_tmp18_ = g_array_index (_tmp17_, gchar*, (guint) 0);
#line 519 "SerializableObjectModelTest.vala"
		if (g_strcmp0 (_tmp18_, "Printer") != 0) {
#line 6515 "SerializableObjectModelTest.c"
			FILE* _tmp19_;
			Package* _tmp20_;
			GArray* _tmp21_;
			GArray* _tmp22_;
			const gchar* _tmp23_;
			const gchar* _tmp24_;
			gchar* _tmp25_;
			gchar* _tmp26_;
#line 520 "SerializableObjectModelTest.vala"
			_tmp19_ = stdout;
#line 520 "SerializableObjectModelTest.vala"
			_tmp20_ = package;
#line 520 "SerializableObjectModelTest.vala"
			_tmp21_ = package_get_tags (_tmp20_);
#line 520 "SerializableObjectModelTest.vala"
			_tmp22_ = _tmp21_;
#line 520 "SerializableObjectModelTest.vala"
			_tmp23_ = g_array_index (_tmp22_, gchar*, (guint) 0);
#line 520 "SerializableObjectModelTest.vala"
			_tmp24_ = string_to_string (_tmp23_);
#line 520 "SerializableObjectModelTest.vala"
			_tmp25_ = g_strconcat ("ERROR PACKAGE: tags index 0: ", _tmp24_, NULL);
#line 520 "SerializableObjectModelTest.vala"
			_tmp26_ = _tmp25_;
#line 520 "SerializableObjectModelTest.vala"
			fprintf (_tmp19_, "%s", _tmp26_);
#line 520 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp26_);
#line 521 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 6546 "SerializableObjectModelTest.c"
		}
#line 523 "SerializableObjectModelTest.vala"
		_tmp27_ = package;
#line 523 "SerializableObjectModelTest.vala"
		_tmp28_ = package_get_tags (_tmp27_);
#line 523 "SerializableObjectModelTest.vala"
		_tmp29_ = _tmp28_;
#line 523 "SerializableObjectModelTest.vala"
		_tmp30_ = g_array_index (_tmp29_, gchar*, (guint) 1);
#line 523 "SerializableObjectModelTest.vala"
		if (g_strcmp0 (_tmp30_, "Partner") != 0) {
#line 6558 "SerializableObjectModelTest.c"
			FILE* _tmp31_;
			Package* _tmp32_;
			GArray* _tmp33_;
			GArray* _tmp34_;
			const gchar* _tmp35_;
			const gchar* _tmp36_;
			gchar* _tmp37_;
			gchar* _tmp38_;
#line 524 "SerializableObjectModelTest.vala"
			_tmp31_ = stdout;
#line 524 "SerializableObjectModelTest.vala"
			_tmp32_ = package;
#line 524 "SerializableObjectModelTest.vala"
			_tmp33_ = package_get_tags (_tmp32_);
#line 524 "SerializableObjectModelTest.vala"
			_tmp34_ = _tmp33_;
#line 524 "SerializableObjectModelTest.vala"
			_tmp35_ = g_array_index (_tmp34_, gchar*, (guint) 1);
#line 524 "SerializableObjectModelTest.vala"
			_tmp36_ = string_to_string (_tmp35_);
#line 524 "SerializableObjectModelTest.vala"
			_tmp37_ = g_strconcat ("ERROR PACKAGE: tags index 1: ", _tmp36_, NULL);
#line 524 "SerializableObjectModelTest.vala"
			_tmp38_ = _tmp37_;
#line 524 "SerializableObjectModelTest.vala"
			fprintf (_tmp31_, "%s", _tmp38_);
#line 524 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp38_);
#line 525 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 6589 "SerializableObjectModelTest.c"
		}
#line 527 "SerializableObjectModelTest.vala"
		_tmp39_ = package;
#line 527 "SerializableObjectModelTest.vala"
		_tmp40_ = package_get_tags (_tmp39_);
#line 527 "SerializableObjectModelTest.vala"
		_tmp41_ = _tmp40_;
#line 527 "SerializableObjectModelTest.vala"
		_tmp42_ = g_array_index (_tmp41_, gchar*, (guint) 2);
#line 527 "SerializableObjectModelTest.vala"
		if (g_strcmp0 (_tmp42_, "Support") != 0) {
#line 6601 "SerializableObjectModelTest.c"
			FILE* _tmp43_;
			Package* _tmp44_;
			GArray* _tmp45_;
			GArray* _tmp46_;
			const gchar* _tmp47_;
			const gchar* _tmp48_;
			gchar* _tmp49_;
			gchar* _tmp50_;
#line 528 "SerializableObjectModelTest.vala"
			_tmp43_ = stdout;
#line 528 "SerializableObjectModelTest.vala"
			_tmp44_ = package;
#line 528 "SerializableObjectModelTest.vala"
			_tmp45_ = package_get_tags (_tmp44_);
#line 528 "SerializableObjectModelTest.vala"
			_tmp46_ = _tmp45_;
#line 528 "SerializableObjectModelTest.vala"
			_tmp47_ = g_array_index (_tmp46_, gchar*, (guint) 2);
#line 528 "SerializableObjectModelTest.vala"
			_tmp48_ = string_to_string (_tmp47_);
#line 528 "SerializableObjectModelTest.vala"
			_tmp49_ = g_strconcat ("ERROR PACKAGE: tags index 0: ", _tmp48_, NULL);
#line 528 "SerializableObjectModelTest.vala"
			_tmp50_ = _tmp49_;
#line 528 "SerializableObjectModelTest.vala"
			fprintf (_tmp43_, "%s", _tmp50_);
#line 528 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp50_);
#line 529 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 6632 "SerializableObjectModelTest.c"
		}
#line 511 "SerializableObjectModelTest.vala"
		_g_object_unref0 (package);
#line 511 "SerializableObjectModelTest.vala"
		_g_object_unref0 (doc);
#line 6638 "SerializableObjectModelTest.c"
	}
	goto __finally324;
	__catch324_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp51_;
		const gchar* _tmp52_;
		gchar* _tmp53_;
		gchar* _tmp54_;
#line 511 "SerializableObjectModelTest.vala"
		e = _inner_error0_;
#line 511 "SerializableObjectModelTest.vala"
		_inner_error0_ = NULL;
#line 533 "SerializableObjectModelTest.vala"
		_tmp51_ = e->message;
#line 533 "SerializableObjectModelTest.vala"
		_tmp52_ = string_to_string (_tmp51_);
#line 533 "SerializableObjectModelTest.vala"
		_tmp53_ = g_strconcat ("Error: ", _tmp52_, NULL);
#line 533 "SerializableObjectModelTest.vala"
		_tmp54_ = _tmp53_;
#line 533 "SerializableObjectModelTest.vala"
		g_message ("SerializableObjectModelTest.vala:533: %s", _tmp54_);
#line 533 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp54_);
#line 534 "SerializableObjectModelTest.vala"
		g_assert_not_reached ();
#line 511 "SerializableObjectModelTest.vala"
		_g_error_free0 (e);
#line 6668 "SerializableObjectModelTest.c"
	}
	__finally324:
#line 511 "SerializableObjectModelTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 511 "SerializableObjectModelTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 511 "SerializableObjectModelTest.vala"
		g_clear_error (&_inner_error0_);
#line 511 "SerializableObjectModelTest.vala"
		return;
#line 6679 "SerializableObjectModelTest.c"
	}
}

static void
___lambda270__gtest_func (void)
{
#line 509 "SerializableObjectModelTest.vala"
	__lambda270_ ();
#line 6688 "SerializableObjectModelTest.c"
}

static void
__lambda271_ (void)
{
	GXmlGDocument* doc = NULL;
	GXmlGDocument* _tmp0_;
	Package* package = NULL;
	Package* _tmp1_;
	GArray* _tmp2_;
	GArray* _tmp3_;
	gchar* _tmp4_;
	GArray* _tmp5_;
	GArray* _tmp6_;
	gchar* _tmp7_;
	GArray* _tmp8_;
	GArray* _tmp9_;
	gchar* _tmp10_;
	GError* _inner_error0_ = NULL;
#line 539 "SerializableObjectModelTest.vala"
	_tmp0_ = gxml_gdocument_new ();
#line 539 "SerializableObjectModelTest.vala"
	doc = _tmp0_;
#line 540 "SerializableObjectModelTest.vala"
	_tmp1_ = package_new ();
#line 540 "SerializableObjectModelTest.vala"
	package = _tmp1_;
#line 541 "SerializableObjectModelTest.vala"
	_tmp2_ = package_get_tags (package);
#line 541 "SerializableObjectModelTest.vala"
	_tmp3_ = _tmp2_;
#line 541 "SerializableObjectModelTest.vala"
	_tmp4_ = g_strdup ("Computer");
#line 541 "SerializableObjectModelTest.vala"
	g_array_append_val (_tmp3_, _tmp4_);
#line 542 "SerializableObjectModelTest.vala"
	_tmp5_ = package_get_tags (package);
#line 542 "SerializableObjectModelTest.vala"
	_tmp6_ = _tmp5_;
#line 542 "SerializableObjectModelTest.vala"
	_tmp7_ = g_strdup ("Customer");
#line 542 "SerializableObjectModelTest.vala"
	g_array_append_val (_tmp6_, _tmp7_);
#line 543 "SerializableObjectModelTest.vala"
	_tmp8_ = package_get_tags (package);
#line 543 "SerializableObjectModelTest.vala"
	_tmp9_ = _tmp8_;
#line 543 "SerializableObjectModelTest.vala"
	_tmp10_ = g_strdup ("Sale");
#line 543 "SerializableObjectModelTest.vala"
	g_array_append_val (_tmp9_, _tmp10_);
#line 6740 "SerializableObjectModelTest.c"
	{
		GXmlNode* _tmp11_;
		GXmlNode* _tmp12_;
		GXmlNode* _tmp13_;
		GXmlNode* _tmp14_;
		GXmlNode* _tmp15_;
		gchar* _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_;
		gboolean _tmp19_;
		GXmlElement* element = NULL;
		GXmlNode* _tmp20_;
		GXmlNode* _tmp21_;
		GXmlElement* _tmp22_;
		gboolean com = FALSE;
		gboolean cus = FALSE;
		gboolean sal = FALSE;
#line 545 "SerializableObjectModelTest.vala"
		_tmp11_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) package, (GXmlNode*) doc, &_inner_error0_);
#line 545 "SerializableObjectModelTest.vala"
		_tmp12_ = _tmp11_;
#line 545 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp12_);
#line 545 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 6766 "SerializableObjectModelTest.c"
			goto __catch325_g_error;
		}
#line 547 "SerializableObjectModelTest.vala"
		_tmp13_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 547 "SerializableObjectModelTest.vala"
		_tmp14_ = _tmp13_;
#line 547 "SerializableObjectModelTest.vala"
		_tmp15_ = _tmp14_;
#line 547 "SerializableObjectModelTest.vala"
		_tmp16_ = gxml_node_get_name (_tmp15_);
#line 547 "SerializableObjectModelTest.vala"
		_tmp17_ = _tmp16_;
#line 547 "SerializableObjectModelTest.vala"
		_tmp18_ = _tmp17_;
#line 547 "SerializableObjectModelTest.vala"
		_tmp19_ = g_strcmp0 (_tmp18_, "package") != 0;
#line 547 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp18_);
#line 547 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp15_);
#line 547 "SerializableObjectModelTest.vala"
		if (_tmp19_) {
#line 548 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 6791 "SerializableObjectModelTest.c"
		}
#line 549 "SerializableObjectModelTest.vala"
		_tmp20_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 549 "SerializableObjectModelTest.vala"
		_tmp21_ = _tmp20_;
#line 549 "SerializableObjectModelTest.vala"
		_tmp22_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp21_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp21_) : NULL;
#line 549 "SerializableObjectModelTest.vala"
		if (_tmp22_ == NULL) {
#line 549 "SerializableObjectModelTest.vala"
			_g_object_unref0 (_tmp21_);
#line 6803 "SerializableObjectModelTest.c"
		}
#line 549 "SerializableObjectModelTest.vala"
		element = _tmp22_;
#line 550 "SerializableObjectModelTest.vala"
		com = FALSE;
#line 551 "SerializableObjectModelTest.vala"
		cus = FALSE;
#line 552 "SerializableObjectModelTest.vala"
		sal = FALSE;
#line 6813 "SerializableObjectModelTest.c"
		{
			GeeBidirList* _n_list = NULL;
			GXmlElement* _tmp23_;
			GeeBidirList* _tmp24_;
			GeeBidirList* _tmp25_;
			gint _n_size = 0;
			GeeBidirList* _tmp26_;
			gint _tmp27_;
			gint _tmp28_;
			gint _n_index = 0;
#line 553 "SerializableObjectModelTest.vala"
			_tmp23_ = element;
#line 553 "SerializableObjectModelTest.vala"
			_tmp24_ = gxml_node_get_children_nodes ((GXmlNode*) _tmp23_);
#line 553 "SerializableObjectModelTest.vala"
			_tmp25_ = _tmp24_;
#line 553 "SerializableObjectModelTest.vala"
			_n_list = _tmp25_;
#line 553 "SerializableObjectModelTest.vala"
			_tmp26_ = _n_list;
#line 553 "SerializableObjectModelTest.vala"
			_tmp27_ = gee_collection_get_size ((GeeCollection*) _tmp26_);
#line 553 "SerializableObjectModelTest.vala"
			_tmp28_ = _tmp27_;
#line 553 "SerializableObjectModelTest.vala"
			_n_size = _tmp28_;
#line 553 "SerializableObjectModelTest.vala"
			_n_index = -1;
#line 553 "SerializableObjectModelTest.vala"
			while (TRUE) {
#line 6844 "SerializableObjectModelTest.c"
				GXmlNode* n = NULL;
				GeeBidirList* _tmp29_;
				gpointer _tmp30_;
				GXmlNode* _tmp31_;
				gchar* _tmp32_;
				gchar* _tmp33_;
				gchar* _tmp34_;
				gboolean _tmp35_;
#line 553 "SerializableObjectModelTest.vala"
				_n_index = _n_index + 1;
#line 553 "SerializableObjectModelTest.vala"
				if (!(_n_index < _n_size)) {
#line 553 "SerializableObjectModelTest.vala"
					break;
#line 6859 "SerializableObjectModelTest.c"
				}
#line 553 "SerializableObjectModelTest.vala"
				_tmp29_ = _n_list;
#line 553 "SerializableObjectModelTest.vala"
				_tmp30_ = gee_list_get ((GeeList*) _tmp29_, _n_index);
#line 553 "SerializableObjectModelTest.vala"
				n = (GXmlNode*) _tmp30_;
#line 555 "SerializableObjectModelTest.vala"
				_tmp31_ = n;
#line 555 "SerializableObjectModelTest.vala"
				_tmp32_ = gxml_node_get_name (_tmp31_);
#line 555 "SerializableObjectModelTest.vala"
				_tmp33_ = _tmp32_;
#line 555 "SerializableObjectModelTest.vala"
				_tmp34_ = _tmp33_;
#line 555 "SerializableObjectModelTest.vala"
				_tmp35_ = g_strcmp0 (_tmp34_, "tag") == 0;
#line 555 "SerializableObjectModelTest.vala"
				_g_free0 (_tmp34_);
#line 555 "SerializableObjectModelTest.vala"
				if (_tmp35_) {
#line 6881 "SerializableObjectModelTest.c"
					GXmlNode* _tmp36_;
					gchar* _tmp37_;
					gchar* _tmp38_;
					gchar* _tmp39_;
					gboolean _tmp40_;
					GXmlNode* _tmp41_;
					gchar* _tmp42_;
					gchar* _tmp43_;
					gchar* _tmp44_;
					gboolean _tmp45_;
					GXmlNode* _tmp46_;
					gchar* _tmp47_;
					gchar* _tmp48_;
					gchar* _tmp49_;
					gboolean _tmp50_;
#line 557 "SerializableObjectModelTest.vala"
					_tmp36_ = n;
#line 557 "SerializableObjectModelTest.vala"
					_tmp37_ = gxml_element_get_content ((GXmlElement*) G_TYPE_CHECK_INSTANCE_CAST (_tmp36_, GXML_TYPE_GELEMENT, GXmlGElement));
#line 557 "SerializableObjectModelTest.vala"
					_tmp38_ = _tmp37_;
#line 557 "SerializableObjectModelTest.vala"
					_tmp39_ = _tmp38_;
#line 557 "SerializableObjectModelTest.vala"
					_tmp40_ = g_strcmp0 (_tmp39_, "Computer") == 0;
#line 557 "SerializableObjectModelTest.vala"
					_g_free0 (_tmp39_);
#line 557 "SerializableObjectModelTest.vala"
					if (_tmp40_) {
#line 558 "SerializableObjectModelTest.vala"
						com = TRUE;
#line 6913 "SerializableObjectModelTest.c"
					}
#line 559 "SerializableObjectModelTest.vala"
					_tmp41_ = n;
#line 559 "SerializableObjectModelTest.vala"
					_tmp42_ = gxml_element_get_content ((GXmlElement*) G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, GXML_TYPE_GELEMENT, GXmlGElement));
#line 559 "SerializableObjectModelTest.vala"
					_tmp43_ = _tmp42_;
#line 559 "SerializableObjectModelTest.vala"
					_tmp44_ = _tmp43_;
#line 559 "SerializableObjectModelTest.vala"
					_tmp45_ = g_strcmp0 (_tmp44_, "Customer") == 0;
#line 559 "SerializableObjectModelTest.vala"
					_g_free0 (_tmp44_);
#line 559 "SerializableObjectModelTest.vala"
					if (_tmp45_) {
#line 560 "SerializableObjectModelTest.vala"
						cus = TRUE;
#line 6931 "SerializableObjectModelTest.c"
					}
#line 561 "SerializableObjectModelTest.vala"
					_tmp46_ = n;
#line 561 "SerializableObjectModelTest.vala"
					_tmp47_ = gxml_element_get_content ((GXmlElement*) G_TYPE_CHECK_INSTANCE_CAST (_tmp46_, GXML_TYPE_GELEMENT, GXmlGElement));
#line 561 "SerializableObjectModelTest.vala"
					_tmp48_ = _tmp47_;
#line 561 "SerializableObjectModelTest.vala"
					_tmp49_ = _tmp48_;
#line 561 "SerializableObjectModelTest.vala"
					_tmp50_ = g_strcmp0 (_tmp49_, "Sale") == 0;
#line 561 "SerializableObjectModelTest.vala"
					_g_free0 (_tmp49_);
#line 561 "SerializableObjectModelTest.vala"
					if (_tmp50_) {
#line 562 "SerializableObjectModelTest.vala"
						sal = TRUE;
#line 6949 "SerializableObjectModelTest.c"
					}
				}
#line 553 "SerializableObjectModelTest.vala"
				_g_object_unref0 (n);
#line 6954 "SerializableObjectModelTest.c"
			}
#line 553 "SerializableObjectModelTest.vala"
			_g_object_unref0 (_n_list);
#line 6958 "SerializableObjectModelTest.c"
		}
#line 565 "SerializableObjectModelTest.vala"
		if (!com) {
#line 6962 "SerializableObjectModelTest.c"
			FILE* _tmp51_;
#line 566 "SerializableObjectModelTest.vala"
			_tmp51_ = stdout;
#line 566 "SerializableObjectModelTest.vala"
			fprintf (_tmp51_, "%s", "ERROR PACKAGE tag Computer not found!");
#line 567 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 6970 "SerializableObjectModelTest.c"
		}
#line 569 "SerializableObjectModelTest.vala"
		if (!cus) {
#line 6974 "SerializableObjectModelTest.c"
			FILE* _tmp52_;
#line 570 "SerializableObjectModelTest.vala"
			_tmp52_ = stdout;
#line 570 "SerializableObjectModelTest.vala"
			fprintf (_tmp52_, "%s", "ERROR PACKAGE tag Customer not found!");
#line 571 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 6982 "SerializableObjectModelTest.c"
		}
#line 573 "SerializableObjectModelTest.vala"
		if (!sal) {
#line 6986 "SerializableObjectModelTest.c"
			FILE* _tmp53_;
#line 574 "SerializableObjectModelTest.vala"
			_tmp53_ = stdout;
#line 574 "SerializableObjectModelTest.vala"
			fprintf (_tmp53_, "%s", "ERROR PACKAGE tag Sale not found!");
#line 575 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 6994 "SerializableObjectModelTest.c"
		}
#line 544 "SerializableObjectModelTest.vala"
		_g_object_unref0 (element);
#line 6998 "SerializableObjectModelTest.c"
	}
	goto __finally325;
	__catch325_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp54_;
		const gchar* _tmp55_;
		gchar* _tmp56_;
		gchar* _tmp57_;
#line 544 "SerializableObjectModelTest.vala"
		e = _inner_error0_;
#line 544 "SerializableObjectModelTest.vala"
		_inner_error0_ = NULL;
#line 579 "SerializableObjectModelTest.vala"
		_tmp54_ = e->message;
#line 579 "SerializableObjectModelTest.vala"
		_tmp55_ = string_to_string (_tmp54_);
#line 579 "SerializableObjectModelTest.vala"
		_tmp56_ = g_strconcat ("Error: ", _tmp55_, NULL);
#line 579 "SerializableObjectModelTest.vala"
		_tmp57_ = _tmp56_;
#line 579 "SerializableObjectModelTest.vala"
		g_message ("SerializableObjectModelTest.vala:579: %s", _tmp57_);
#line 579 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp57_);
#line 580 "SerializableObjectModelTest.vala"
		g_assert_not_reached ();
#line 544 "SerializableObjectModelTest.vala"
		_g_error_free0 (e);
#line 7028 "SerializableObjectModelTest.c"
	}
	__finally325:
#line 544 "SerializableObjectModelTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 544 "SerializableObjectModelTest.vala"
		_g_object_unref0 (package);
#line 544 "SerializableObjectModelTest.vala"
		_g_object_unref0 (doc);
#line 544 "SerializableObjectModelTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 544 "SerializableObjectModelTest.vala"
		g_clear_error (&_inner_error0_);
#line 544 "SerializableObjectModelTest.vala"
		return;
#line 7043 "SerializableObjectModelTest.c"
	}
#line 538 "SerializableObjectModelTest.vala"
	_g_object_unref0 (package);
#line 538 "SerializableObjectModelTest.vala"
	_g_object_unref0 (doc);
#line 7049 "SerializableObjectModelTest.c"
}

static void
___lambda271__gtest_func (void)
{
#line 537 "SerializableObjectModelTest.vala"
	__lambda271_ ();
#line 7057 "SerializableObjectModelTest.c"
}

static void
__lambda272_ (void)
{
	GXmlGDocument* doc = NULL;
	GXmlGDocument* _tmp0_;
	Monitor* monitor = NULL;
	Monitor* _tmp1_;
	GError* _inner_error0_ = NULL;
#line 586 "SerializableObjectModelTest.vala"
	_tmp0_ = gxml_gdocument_new ();
#line 586 "SerializableObjectModelTest.vala"
	doc = _tmp0_;
#line 587 "SerializableObjectModelTest.vala"
	_tmp1_ = monitor_new ();
#line 587 "SerializableObjectModelTest.vala"
	monitor = _tmp1_;
#line 7076 "SerializableObjectModelTest.c"
	{
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		gboolean _tmp7_;
		GXmlElement* element = NULL;
		GXmlNode* _tmp9_;
		GXmlNode* _tmp10_;
		GXmlElement* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
		gboolean _tmp15_;
		GXmlNode* ac = NULL;
		GXmlNode* _tmp23_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		gboolean _tmp28_;
		GXmlNode* dc = NULL;
		GXmlNode* _tmp36_;
		gchar* _tmp38_;
		gchar* _tmp39_;
		gchar* _tmp40_;
		gboolean _tmp41_;
		GXmlNode* r = NULL;
		GXmlNode* _tmp49_;
		gchar* _tmp51_;
		gchar* _tmp52_;
		gchar* _tmp53_;
		gboolean _tmp54_;
#line 589 "SerializableObjectModelTest.vala"
		monitor_set_resolution (monitor, "1204x720");
#line 590 "SerializableObjectModelTest.vala"
		monitor_set_ac_power (monitor, 120);
#line 591 "SerializableObjectModelTest.vala"
		monitor_set_dc_power (monitor, 125);
#line 592 "SerializableObjectModelTest.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) monitor, (GXmlNode*) doc, &_inner_error0_);
#line 592 "SerializableObjectModelTest.vala"
		_tmp3_ = _tmp2_;
#line 592 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp3_);
#line 592 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 7124 "SerializableObjectModelTest.c"
			goto __catch326_g_error;
		}
#line 594 "SerializableObjectModelTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 594 "SerializableObjectModelTest.vala"
		_tmp5_ = _tmp4_;
#line 594 "SerializableObjectModelTest.vala"
		_tmp6_ = _tmp5_;
#line 594 "SerializableObjectModelTest.vala"
		_tmp7_ = _tmp6_ == NULL;
#line 594 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp6_);
#line 594 "SerializableObjectModelTest.vala"
		if (_tmp7_) {
#line 7139 "SerializableObjectModelTest.c"
			FILE* _tmp8_;
#line 595 "SerializableObjectModelTest.vala"
			_tmp8_ = stdout;
#line 595 "SerializableObjectModelTest.vala"
			fprintf (_tmp8_, "ERROR MONITOR: No root GElement");
#line 596 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 7147 "SerializableObjectModelTest.c"
		}
#line 598 "SerializableObjectModelTest.vala"
		_tmp9_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 598 "SerializableObjectModelTest.vala"
		_tmp10_ = _tmp9_;
#line 598 "SerializableObjectModelTest.vala"
		_tmp11_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp10_) : NULL;
#line 598 "SerializableObjectModelTest.vala"
		if (_tmp11_ == NULL) {
#line 598 "SerializableObjectModelTest.vala"
			_g_object_unref0 (_tmp10_);
#line 7159 "SerializableObjectModelTest.c"
		}
#line 598 "SerializableObjectModelTest.vala"
		element = _tmp11_;
#line 599 "SerializableObjectModelTest.vala"
		_tmp12_ = gxml_node_get_name ((GXmlNode*) element);
#line 599 "SerializableObjectModelTest.vala"
		_tmp13_ = _tmp12_;
#line 599 "SerializableObjectModelTest.vala"
		_tmp14_ = _tmp13_;
#line 599 "SerializableObjectModelTest.vala"
		_tmp15_ = g_strcmp0 (_tmp14_, "monitor") != 0;
#line 599 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp14_);
#line 599 "SerializableObjectModelTest.vala"
		if (_tmp15_) {
#line 7175 "SerializableObjectModelTest.c"
			FILE* _tmp16_;
			gchar* _tmp17_;
			gchar* _tmp18_;
			gchar* _tmp19_;
			const gchar* _tmp20_;
			gchar* _tmp21_;
			gchar* _tmp22_;
#line 600 "SerializableObjectModelTest.vala"
			_tmp16_ = stdout;
#line 600 "SerializableObjectModelTest.vala"
			_tmp17_ = gxml_node_get_name ((GXmlNode*) element);
#line 600 "SerializableObjectModelTest.vala"
			_tmp18_ = _tmp17_;
#line 600 "SerializableObjectModelTest.vala"
			_tmp19_ = _tmp18_;
#line 600 "SerializableObjectModelTest.vala"
			_tmp20_ = string_to_string (_tmp19_);
#line 600 "SerializableObjectModelTest.vala"
			_tmp21_ = g_strconcat ("ERROR MONITOR: root GElement ", _tmp20_, NULL);
#line 600 "SerializableObjectModelTest.vala"
			_tmp22_ = _tmp21_;
#line 600 "SerializableObjectModelTest.vala"
			fprintf (_tmp16_, "%s", _tmp22_);
#line 600 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp22_);
#line 600 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp19_);
#line 601 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 7205 "SerializableObjectModelTest.c"
		}
#line 603 "SerializableObjectModelTest.vala"
		_tmp23_ = gxml_element_get_attr (element, "AcPower");
#line 603 "SerializableObjectModelTest.vala"
		ac = _tmp23_;
#line 604 "SerializableObjectModelTest.vala"
		if (ac == NULL) {
#line 7213 "SerializableObjectModelTest.c"
			FILE* _tmp24_;
#line 605 "SerializableObjectModelTest.vala"
			_tmp24_ = stdout;
#line 605 "SerializableObjectModelTest.vala"
			fprintf (_tmp24_, "%s", "ERROR MONITOR: attribute AcPower not found");
#line 606 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 7221 "SerializableObjectModelTest.c"
		}
#line 608 "SerializableObjectModelTest.vala"
		_tmp25_ = gxml_node_get_value (ac);
#line 608 "SerializableObjectModelTest.vala"
		_tmp26_ = _tmp25_;
#line 608 "SerializableObjectModelTest.vala"
		_tmp27_ = _tmp26_;
#line 608 "SerializableObjectModelTest.vala"
		_tmp28_ = g_strcmp0 (_tmp27_, "120") != 0;
#line 608 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp27_);
#line 608 "SerializableObjectModelTest.vala"
		if (_tmp28_) {
#line 7235 "SerializableObjectModelTest.c"
			FILE* _tmp29_;
			gchar* _tmp30_;
			gchar* _tmp31_;
			gchar* _tmp32_;
			const gchar* _tmp33_;
			gchar* _tmp34_;
			gchar* _tmp35_;
#line 609 "SerializableObjectModelTest.vala"
			_tmp29_ = stdout;
#line 609 "SerializableObjectModelTest.vala"
			_tmp30_ = gxml_node_get_value (ac);
#line 609 "SerializableObjectModelTest.vala"
			_tmp31_ = _tmp30_;
#line 609 "SerializableObjectModelTest.vala"
			_tmp32_ = _tmp31_;
#line 609 "SerializableObjectModelTest.vala"
			_tmp33_ = string_to_string (_tmp32_);
#line 609 "SerializableObjectModelTest.vala"
			_tmp34_ = g_strconcat ("ERROR MONITOR: AcPower value ", _tmp33_, NULL);
#line 609 "SerializableObjectModelTest.vala"
			_tmp35_ = _tmp34_;
#line 609 "SerializableObjectModelTest.vala"
			fprintf (_tmp29_, "%s", _tmp35_);
#line 609 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp35_);
#line 609 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp32_);
#line 610 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 7265 "SerializableObjectModelTest.c"
		}
#line 612 "SerializableObjectModelTest.vala"
		_tmp36_ = gxml_element_get_attr (element, "DcPower");
#line 612 "SerializableObjectModelTest.vala"
		dc = _tmp36_;
#line 613 "SerializableObjectModelTest.vala"
		if (dc == NULL) {
#line 7273 "SerializableObjectModelTest.c"
			FILE* _tmp37_;
#line 614 "SerializableObjectModelTest.vala"
			_tmp37_ = stdout;
#line 614 "SerializableObjectModelTest.vala"
			fprintf (_tmp37_, "%s", "ERROR MONITOR: attribute DcPower not found");
#line 615 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 7281 "SerializableObjectModelTest.c"
		}
#line 617 "SerializableObjectModelTest.vala"
		_tmp38_ = gxml_node_get_value (dc);
#line 617 "SerializableObjectModelTest.vala"
		_tmp39_ = _tmp38_;
#line 617 "SerializableObjectModelTest.vala"
		_tmp40_ = _tmp39_;
#line 617 "SerializableObjectModelTest.vala"
		_tmp41_ = g_strcmp0 (_tmp40_, "125") != 0;
#line 617 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp40_);
#line 617 "SerializableObjectModelTest.vala"
		if (_tmp41_) {
#line 7295 "SerializableObjectModelTest.c"
			FILE* _tmp42_;
			gchar* _tmp43_;
			gchar* _tmp44_;
			gchar* _tmp45_;
			const gchar* _tmp46_;
			gchar* _tmp47_;
			gchar* _tmp48_;
#line 618 "SerializableObjectModelTest.vala"
			_tmp42_ = stdout;
#line 618 "SerializableObjectModelTest.vala"
			_tmp43_ = gxml_node_get_value (dc);
#line 618 "SerializableObjectModelTest.vala"
			_tmp44_ = _tmp43_;
#line 618 "SerializableObjectModelTest.vala"
			_tmp45_ = _tmp44_;
#line 618 "SerializableObjectModelTest.vala"
			_tmp46_ = string_to_string (_tmp45_);
#line 618 "SerializableObjectModelTest.vala"
			_tmp47_ = g_strconcat ("ERROR MONITOR: AcPower value ", _tmp46_, NULL);
#line 618 "SerializableObjectModelTest.vala"
			_tmp48_ = _tmp47_;
#line 618 "SerializableObjectModelTest.vala"
			fprintf (_tmp42_, "%s", _tmp48_);
#line 618 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp48_);
#line 618 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp45_);
#line 619 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 7325 "SerializableObjectModelTest.c"
		}
#line 621 "SerializableObjectModelTest.vala"
		_tmp49_ = gxml_element_get_attr (element, "resolution");
#line 621 "SerializableObjectModelTest.vala"
		r = _tmp49_;
#line 622 "SerializableObjectModelTest.vala"
		if (r == NULL) {
#line 7333 "SerializableObjectModelTest.c"
			FILE* _tmp50_;
#line 623 "SerializableObjectModelTest.vala"
			_tmp50_ = stdout;
#line 623 "SerializableObjectModelTest.vala"
			fprintf (_tmp50_, "%s", "ERROR MONITOR: attribute resolution not found");
#line 624 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 7341 "SerializableObjectModelTest.c"
		}
#line 626 "SerializableObjectModelTest.vala"
		_tmp51_ = gxml_node_get_value (r);
#line 626 "SerializableObjectModelTest.vala"
		_tmp52_ = _tmp51_;
#line 626 "SerializableObjectModelTest.vala"
		_tmp53_ = _tmp52_;
#line 626 "SerializableObjectModelTest.vala"
		_tmp54_ = g_strcmp0 (_tmp53_, "1204x720") != 0;
#line 626 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp53_);
#line 626 "SerializableObjectModelTest.vala"
		if (_tmp54_) {
#line 7355 "SerializableObjectModelTest.c"
			FILE* _tmp55_;
			gchar* _tmp56_;
			gchar* _tmp57_;
			gchar* _tmp58_;
			const gchar* _tmp59_;
			gchar* _tmp60_;
			gchar* _tmp61_;
#line 627 "SerializableObjectModelTest.vala"
			_tmp55_ = stdout;
#line 627 "SerializableObjectModelTest.vala"
			_tmp56_ = gxml_node_get_value (r);
#line 627 "SerializableObjectModelTest.vala"
			_tmp57_ = _tmp56_;
#line 627 "SerializableObjectModelTest.vala"
			_tmp58_ = _tmp57_;
#line 627 "SerializableObjectModelTest.vala"
			_tmp59_ = string_to_string (_tmp58_);
#line 627 "SerializableObjectModelTest.vala"
			_tmp60_ = g_strconcat ("ERROR MONITOR: resolution value ", _tmp59_, NULL);
#line 627 "SerializableObjectModelTest.vala"
			_tmp61_ = _tmp60_;
#line 627 "SerializableObjectModelTest.vala"
			fprintf (_tmp55_, "%s", _tmp61_);
#line 627 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp61_);
#line 627 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp58_);
#line 628 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 7385 "SerializableObjectModelTest.c"
		}
#line 588 "SerializableObjectModelTest.vala"
		_g_object_unref0 (r);
#line 588 "SerializableObjectModelTest.vala"
		_g_object_unref0 (dc);
#line 588 "SerializableObjectModelTest.vala"
		_g_object_unref0 (ac);
#line 588 "SerializableObjectModelTest.vala"
		_g_object_unref0 (element);
#line 7395 "SerializableObjectModelTest.c"
	}
	goto __finally326;
	__catch326_g_error:
	{
		GError* e = NULL;
		FILE* _tmp62_;
		const gchar* _tmp63_;
		const gchar* _tmp64_;
		gchar* _tmp65_;
		gchar* _tmp66_;
#line 588 "SerializableObjectModelTest.vala"
		e = _inner_error0_;
#line 588 "SerializableObjectModelTest.vala"
		_inner_error0_ = NULL;
#line 632 "SerializableObjectModelTest.vala"
		_tmp62_ = stdout;
#line 632 "SerializableObjectModelTest.vala"
		_tmp63_ = e->message;
#line 632 "SerializableObjectModelTest.vala"
		_tmp64_ = string_to_string (_tmp63_);
#line 632 "SerializableObjectModelTest.vala"
		_tmp65_ = g_strconcat ("Error: ", _tmp64_, NULL);
#line 632 "SerializableObjectModelTest.vala"
		_tmp66_ = _tmp65_;
#line 632 "SerializableObjectModelTest.vala"
		fprintf (_tmp62_, "%s", _tmp66_);
#line 632 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp66_);
#line 633 "SerializableObjectModelTest.vala"
		g_assert_not_reached ();
#line 588 "SerializableObjectModelTest.vala"
		_g_error_free0 (e);
#line 7428 "SerializableObjectModelTest.c"
	}
	__finally326:
#line 588 "SerializableObjectModelTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 588 "SerializableObjectModelTest.vala"
		_g_object_unref0 (monitor);
#line 588 "SerializableObjectModelTest.vala"
		_g_object_unref0 (doc);
#line 588 "SerializableObjectModelTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 588 "SerializableObjectModelTest.vala"
		g_clear_error (&_inner_error0_);
#line 588 "SerializableObjectModelTest.vala"
		return;
#line 7443 "SerializableObjectModelTest.c"
	}
#line 585 "SerializableObjectModelTest.vala"
	_g_object_unref0 (monitor);
#line 585 "SerializableObjectModelTest.vala"
	_g_object_unref0 (doc);
#line 7449 "SerializableObjectModelTest.c"
}

static void
___lambda272__gtest_func (void)
{
#line 584 "SerializableObjectModelTest.vala"
	__lambda272_ ();
#line 7457 "SerializableObjectModelTest.c"
}

static void
__lambda273_ (void)
{
	GXmlGDocument* doc = NULL;
	GXmlGDocument* _tmp0_;
	Configuration* configuration = NULL;
	Configuration* _tmp1_;
	GError* _inner_error0_ = NULL;
#line 715 "SerializableObjectModelTest.vala"
	_tmp0_ = gxml_gdocument_new ();
#line 715 "SerializableObjectModelTest.vala"
	doc = _tmp0_;
#line 716 "SerializableObjectModelTest.vala"
	_tmp1_ = configuration_new ();
#line 716 "SerializableObjectModelTest.vala"
	configuration = _tmp1_;
#line 717 "SerializableObjectModelTest.vala"
	configuration_set_device (configuration, "Controller");
#line 7478 "SerializableObjectModelTest.c"
	{
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		gboolean _tmp7_;
		GXmlElement* element = NULL;
		GXmlNode* _tmp8_;
		GXmlNode* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gboolean _tmp13_;
		gboolean found = FALSE;
#line 719 "SerializableObjectModelTest.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) configuration, (GXmlNode*) doc, &_inner_error0_);
#line 719 "SerializableObjectModelTest.vala"
		_tmp3_ = _tmp2_;
#line 719 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp3_);
#line 719 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 7502 "SerializableObjectModelTest.c"
			goto __catch327_g_error;
		}
#line 721 "SerializableObjectModelTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 721 "SerializableObjectModelTest.vala"
		_tmp5_ = _tmp4_;
#line 721 "SerializableObjectModelTest.vala"
		_tmp6_ = _tmp5_;
#line 721 "SerializableObjectModelTest.vala"
		_tmp7_ = _tmp6_ == NULL;
#line 721 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp6_);
#line 721 "SerializableObjectModelTest.vala"
		if (_tmp7_) {
#line 725 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 7519 "SerializableObjectModelTest.c"
		}
#line 727 "SerializableObjectModelTest.vala"
		_tmp8_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 727 "SerializableObjectModelTest.vala"
		_tmp9_ = _tmp8_;
#line 727 "SerializableObjectModelTest.vala"
		element = G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GXML_TYPE_ELEMENT, GXmlElement);
#line 728 "SerializableObjectModelTest.vala"
		_tmp10_ = gxml_node_get_name ((GXmlNode*) element);
#line 728 "SerializableObjectModelTest.vala"
		_tmp11_ = _tmp10_;
#line 728 "SerializableObjectModelTest.vala"
		_tmp12_ = _tmp11_;
#line 728 "SerializableObjectModelTest.vala"
		_tmp13_ = g_strcmp0 (_tmp12_, "Configuration") != 0;
#line 728 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp12_);
#line 728 "SerializableObjectModelTest.vala"
		if (_tmp13_) {
#line 732 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 7541 "SerializableObjectModelTest.c"
		}
#line 734 "SerializableObjectModelTest.vala"
		found = FALSE;
#line 7545 "SerializableObjectModelTest.c"
		{
			GeeList* _n_list = NULL;
			GeeList* _tmp14_;
			GeeList* _tmp15_;
			gint _n_size = 0;
			GeeList* _tmp16_;
			gint _tmp17_;
			gint _tmp18_;
			gint _n_index = 0;
#line 735 "SerializableObjectModelTest.vala"
			_tmp14_ = gxml_node_get_namespaces ((GXmlNode*) element);
#line 735 "SerializableObjectModelTest.vala"
			_tmp15_ = _tmp14_;
#line 735 "SerializableObjectModelTest.vala"
			_n_list = _tmp15_;
#line 735 "SerializableObjectModelTest.vala"
			_tmp16_ = _n_list;
#line 735 "SerializableObjectModelTest.vala"
			_tmp17_ = gee_collection_get_size ((GeeCollection*) _tmp16_);
#line 735 "SerializableObjectModelTest.vala"
			_tmp18_ = _tmp17_;
#line 735 "SerializableObjectModelTest.vala"
			_n_size = _tmp18_;
#line 735 "SerializableObjectModelTest.vala"
			_n_index = -1;
#line 735 "SerializableObjectModelTest.vala"
			while (TRUE) {
#line 7573 "SerializableObjectModelTest.c"
				GXmlNamespace* n = NULL;
				GeeList* _tmp19_;
				gpointer _tmp20_;
				gboolean _tmp21_ = FALSE;
				GXmlNamespace* _tmp22_;
				gchar* _tmp23_;
				gchar* _tmp24_;
				gchar* _tmp25_;
				gboolean _tmp26_;
#line 735 "SerializableObjectModelTest.vala"
				_n_index = _n_index + 1;
#line 735 "SerializableObjectModelTest.vala"
				if (!(_n_index < _n_size)) {
#line 735 "SerializableObjectModelTest.vala"
					break;
#line 7589 "SerializableObjectModelTest.c"
				}
#line 735 "SerializableObjectModelTest.vala"
				_tmp19_ = _n_list;
#line 735 "SerializableObjectModelTest.vala"
				_tmp20_ = gee_list_get (_tmp19_, _n_index);
#line 735 "SerializableObjectModelTest.vala"
				n = (GXmlNamespace*) _tmp20_;
#line 737 "SerializableObjectModelTest.vala"
				_tmp22_ = n;
#line 737 "SerializableObjectModelTest.vala"
				_tmp23_ = gxml_namespace_get_prefix (_tmp22_);
#line 737 "SerializableObjectModelTest.vala"
				_tmp24_ = _tmp23_;
#line 737 "SerializableObjectModelTest.vala"
				_tmp25_ = _tmp24_;
#line 737 "SerializableObjectModelTest.vala"
				_tmp26_ = g_strcmp0 (_tmp25_, "om") == 0;
#line 737 "SerializableObjectModelTest.vala"
				_g_free0 (_tmp25_);
#line 737 "SerializableObjectModelTest.vala"
				if (_tmp26_) {
#line 7611 "SerializableObjectModelTest.c"
					GXmlNamespace* _tmp27_;
					gchar* _tmp28_;
					gchar* _tmp29_;
					gchar* _tmp30_;
#line 737 "SerializableObjectModelTest.vala"
					_tmp27_ = n;
#line 737 "SerializableObjectModelTest.vala"
					_tmp28_ = gxml_namespace_get_uri (_tmp27_);
#line 737 "SerializableObjectModelTest.vala"
					_tmp29_ = _tmp28_;
#line 737 "SerializableObjectModelTest.vala"
					_tmp30_ = _tmp29_;
#line 737 "SerializableObjectModelTest.vala"
					_tmp21_ = g_strcmp0 (_tmp30_, "http://www.gnome.org/gxml/0.4") == 0;
#line 737 "SerializableObjectModelTest.vala"
					_g_free0 (_tmp30_);
#line 7628 "SerializableObjectModelTest.c"
				} else {
#line 737 "SerializableObjectModelTest.vala"
					_tmp21_ = FALSE;
#line 7632 "SerializableObjectModelTest.c"
				}
#line 737 "SerializableObjectModelTest.vala"
				if (_tmp21_) {
#line 738 "SerializableObjectModelTest.vala"
					found = TRUE;
#line 7638 "SerializableObjectModelTest.c"
				}
#line 735 "SerializableObjectModelTest.vala"
				_g_object_unref0 (n);
#line 7642 "SerializableObjectModelTest.c"
			}
#line 735 "SerializableObjectModelTest.vala"
			_g_object_unref0 (_n_list);
#line 7646 "SerializableObjectModelTest.c"
		}
#line 740 "SerializableObjectModelTest.vala"
		if (!found) {
#line 747 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 7652 "SerializableObjectModelTest.c"
		}
#line 718 "SerializableObjectModelTest.vala"
		_g_object_unref0 (element);
#line 7656 "SerializableObjectModelTest.c"
	}
	goto __finally327;
	__catch327_g_error:
	{
		GError* e = NULL;
		FILE* _tmp31_;
		const gchar* _tmp32_;
		const gchar* _tmp33_;
		gchar* _tmp34_;
		gchar* _tmp35_;
#line 718 "SerializableObjectModelTest.vala"
		e = _inner_error0_;
#line 718 "SerializableObjectModelTest.vala"
		_inner_error0_ = NULL;
#line 751 "SerializableObjectModelTest.vala"
		_tmp31_ = stdout;
#line 751 "SerializableObjectModelTest.vala"
		_tmp32_ = e->message;
#line 751 "SerializableObjectModelTest.vala"
		_tmp33_ = string_to_string (_tmp32_);
#line 751 "SerializableObjectModelTest.vala"
		_tmp34_ = g_strconcat ("Error: ", _tmp33_, NULL);
#line 751 "SerializableObjectModelTest.vala"
		_tmp35_ = _tmp34_;
#line 751 "SerializableObjectModelTest.vala"
		fprintf (_tmp31_, "%s", _tmp35_);
#line 751 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp35_);
#line 752 "SerializableObjectModelTest.vala"
		g_assert_not_reached ();
#line 718 "SerializableObjectModelTest.vala"
		_g_error_free0 (e);
#line 7689 "SerializableObjectModelTest.c"
	}
	__finally327:
#line 718 "SerializableObjectModelTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 718 "SerializableObjectModelTest.vala"
		_g_object_unref0 (configuration);
#line 718 "SerializableObjectModelTest.vala"
		_g_object_unref0 (doc);
#line 718 "SerializableObjectModelTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 718 "SerializableObjectModelTest.vala"
		g_clear_error (&_inner_error0_);
#line 718 "SerializableObjectModelTest.vala"
		return;
#line 7704 "SerializableObjectModelTest.c"
	}
#line 714 "SerializableObjectModelTest.vala"
	_g_object_unref0 (configuration);
#line 714 "SerializableObjectModelTest.vala"
	_g_object_unref0 (doc);
#line 7710 "SerializableObjectModelTest.c"
}

static void
___lambda273__gtest_func (void)
{
#line 713 "SerializableObjectModelTest.vala"
	__lambda273_ ();
#line 7718 "SerializableObjectModelTest.c"
}

static void
__lambda274_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		Configuration* configuration = NULL;
		Configuration* _tmp1_;
		Configuration* _tmp2_;
		GXmlGDocument* _tmp3_;
		Configuration* _tmp4_;
		gboolean _tmp5_;
		gboolean _tmp6_;
#line 758 "SerializableObjectModelTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"       <Configuration xmlns:om=\"http://www.gnome.org/gxml/0.4\" devic" \
"e=\"Sampler\"/>", 0, &_inner_error0_);
#line 758 "SerializableObjectModelTest.vala"
		doc = _tmp0_;
#line 758 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 7741 "SerializableObjectModelTest.c"
			goto __catch328_g_error;
		}
#line 760 "SerializableObjectModelTest.vala"
		_tmp1_ = configuration_new ();
#line 760 "SerializableObjectModelTest.vala"
		configuration = _tmp1_;
#line 764 "SerializableObjectModelTest.vala"
		_tmp2_ = configuration;
#line 764 "SerializableObjectModelTest.vala"
		_tmp3_ = doc;
#line 764 "SerializableObjectModelTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 764 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 764 "SerializableObjectModelTest.vala"
			_g_object_unref0 (configuration);
#line 764 "SerializableObjectModelTest.vala"
			_g_object_unref0 (doc);
#line 7760 "SerializableObjectModelTest.c"
			goto __catch328_g_error;
		}
#line 768 "SerializableObjectModelTest.vala"
		_tmp4_ = configuration;
#line 768 "SerializableObjectModelTest.vala"
		_tmp5_ = configuration_get_invalid (_tmp4_);
#line 768 "SerializableObjectModelTest.vala"
		_tmp6_ = _tmp5_;
#line 768 "SerializableObjectModelTest.vala"
		if (_tmp6_ == TRUE) {
#line 775 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 7773 "SerializableObjectModelTest.c"
		}
#line 757 "SerializableObjectModelTest.vala"
		_g_object_unref0 (configuration);
#line 757 "SerializableObjectModelTest.vala"
		_g_object_unref0 (doc);
#line 7779 "SerializableObjectModelTest.c"
	}
	goto __finally328;
	__catch328_g_error:
	{
		GError* e = NULL;
		FILE* _tmp7_;
		const gchar* _tmp8_;
		const gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
#line 757 "SerializableObjectModelTest.vala"
		e = _inner_error0_;
#line 757 "SerializableObjectModelTest.vala"
		_inner_error0_ = NULL;
#line 779 "SerializableObjectModelTest.vala"
		_tmp7_ = stdout;
#line 779 "SerializableObjectModelTest.vala"
		_tmp8_ = e->message;
#line 779 "SerializableObjectModelTest.vala"
		_tmp9_ = string_to_string (_tmp8_);
#line 779 "SerializableObjectModelTest.vala"
		_tmp10_ = g_strconcat ("Error: ", _tmp9_, NULL);
#line 779 "SerializableObjectModelTest.vala"
		_tmp11_ = _tmp10_;
#line 779 "SerializableObjectModelTest.vala"
		fprintf (_tmp7_, "%s", _tmp11_);
#line 779 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp11_);
#line 780 "SerializableObjectModelTest.vala"
		g_assert_not_reached ();
#line 757 "SerializableObjectModelTest.vala"
		_g_error_free0 (e);
#line 7812 "SerializableObjectModelTest.c"
	}
	__finally328:
#line 757 "SerializableObjectModelTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 757 "SerializableObjectModelTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 757 "SerializableObjectModelTest.vala"
		g_clear_error (&_inner_error0_);
#line 757 "SerializableObjectModelTest.vala"
		return;
#line 7823 "SerializableObjectModelTest.c"
	}
}

static void
___lambda274__gtest_func (void)
{
#line 755 "SerializableObjectModelTest.vala"
	__lambda274_ ();
#line 7832 "SerializableObjectModelTest.c"
}

static void
__lambda275_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		NodeName* nodename = NULL;
		NodeName* _tmp1_;
		NodeName* _tmp2_;
		GXmlGDocument* _tmp3_;
#line 786 "SerializableObjectModelTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?><NodeName />", 0, &_inner_error0_);
#line 786 "SerializableObjectModelTest.vala"
		doc = _tmp0_;
#line 786 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 7852 "SerializableObjectModelTest.c"
			goto __catch329_g_error;
		}
#line 787 "SerializableObjectModelTest.vala"
		_tmp1_ = node_name_new ();
#line 787 "SerializableObjectModelTest.vala"
		nodename = _tmp1_;
#line 788 "SerializableObjectModelTest.vala"
		_tmp2_ = nodename;
#line 788 "SerializableObjectModelTest.vala"
		_tmp3_ = doc;
#line 788 "SerializableObjectModelTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 788 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 788 "SerializableObjectModelTest.vala"
			_g_object_unref0 (nodename);
#line 788 "SerializableObjectModelTest.vala"
			_g_object_unref0 (doc);
#line 7871 "SerializableObjectModelTest.c"
			goto __catch329_g_error;
		}
#line 785 "SerializableObjectModelTest.vala"
		_g_object_unref0 (nodename);
#line 785 "SerializableObjectModelTest.vala"
		_g_object_unref0 (doc);
#line 7878 "SerializableObjectModelTest.c"
	}
	goto __finally329;
	__catch329_g_error:
	{
		GError* e = NULL;
		FILE* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
#line 785 "SerializableObjectModelTest.vala"
		e = _inner_error0_;
#line 785 "SerializableObjectModelTest.vala"
		_inner_error0_ = NULL;
#line 791 "SerializableObjectModelTest.vala"
		_tmp4_ = stdout;
#line 791 "SerializableObjectModelTest.vala"
		_tmp5_ = e->message;
#line 791 "SerializableObjectModelTest.vala"
		_tmp6_ = string_to_string (_tmp5_);
#line 791 "SerializableObjectModelTest.vala"
		_tmp7_ = g_strconcat ("Error: ", _tmp6_, NULL);
#line 791 "SerializableObjectModelTest.vala"
		_tmp8_ = _tmp7_;
#line 791 "SerializableObjectModelTest.vala"
		fprintf (_tmp4_, "%s", _tmp8_);
#line 791 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp8_);
#line 792 "SerializableObjectModelTest.vala"
		g_assert_not_reached ();
#line 785 "SerializableObjectModelTest.vala"
		_g_error_free0 (e);
#line 7911 "SerializableObjectModelTest.c"
	}
	__finally329:
#line 785 "SerializableObjectModelTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 785 "SerializableObjectModelTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 785 "SerializableObjectModelTest.vala"
		g_clear_error (&_inner_error0_);
#line 785 "SerializableObjectModelTest.vala"
		return;
#line 7922 "SerializableObjectModelTest.c"
	}
}

static void
___lambda275__gtest_func (void)
{
#line 783 "SerializableObjectModelTest.vala"
	__lambda275_ ();
#line 7931 "SerializableObjectModelTest.c"
}

static gchar*
bool_to_string (gboolean self)
{
	gchar* result = NULL;
#line 37 "glib-2.0.vapi"
	if (self) {
#line 7940 "SerializableObjectModelTest.c"
		gchar* _tmp0_;
#line 38 "glib-2.0.vapi"
		_tmp0_ = g_strdup ("true");
#line 38 "glib-2.0.vapi"
		result = _tmp0_;
#line 38 "glib-2.0.vapi"
		return result;
#line 7948 "SerializableObjectModelTest.c"
	} else {
		gchar* _tmp1_;
#line 40 "glib-2.0.vapi"
		_tmp1_ = g_strdup ("false");
#line 40 "glib-2.0.vapi"
		result = _tmp1_;
#line 40 "glib-2.0.vapi"
		return result;
#line 7957 "SerializableObjectModelTest.c"
	}
}

static void
__lambda276_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		UnknownAttribute* unknown_property = NULL;
		UnknownAttribute* _tmp1_;
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlNode* name = NULL;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlGElement* _tmp6_;
		GXmlGElement* _tmp7_;
		GXmlNode* _tmp8_;
		GXmlNode* _tmp9_;
		GXmlNode* array = NULL;
		GXmlNode* _tmp17_;
		GXmlNode* _tmp18_;
		GXmlElement* _tmp19_;
		GXmlElement* _tmp20_;
		GXmlNode* _tmp21_;
		GXmlNode* _tmp22_;
		GXmlNode* _tmp30_;
		GXmlNode* _tmp31_;
		GXmlNode* _tmp32_;
		GeeBidirList* _tmp33_;
		GeeBidirList* _tmp34_;
		GeeBidirList* _tmp35_;
		gint _tmp36_;
		gint _tmp37_;
		gboolean _tmp38_;
#line 798 "SerializableObjectModelTest.vala"
		_tmp0_ = gxml_gdocument_new ();
#line 798 "SerializableObjectModelTest.vala"
		doc = _tmp0_;
#line 799 "SerializableObjectModelTest.vala"
		_tmp1_ = unknown_attribute_new ();
#line 799 "SerializableObjectModelTest.vala"
		unknown_property = _tmp1_;
#line 800 "SerializableObjectModelTest.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) unknown_property, (GXmlNode*) doc, &_inner_error0_);
#line 800 "SerializableObjectModelTest.vala"
		_tmp3_ = _tmp2_;
#line 800 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp3_);
#line 800 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 800 "SerializableObjectModelTest.vala"
			_g_object_unref0 (unknown_property);
#line 800 "SerializableObjectModelTest.vala"
			_g_object_unref0 (doc);
#line 8015 "SerializableObjectModelTest.c"
			goto __catch330_g_error;
		}
#line 802 "SerializableObjectModelTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 802 "SerializableObjectModelTest.vala"
		_tmp5_ = _tmp4_;
#line 802 "SerializableObjectModelTest.vala"
		_tmp6_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GXML_TYPE_GELEMENT) ? ((GXmlGElement*) _tmp5_) : NULL;
#line 802 "SerializableObjectModelTest.vala"
		if (_tmp6_ == NULL) {
#line 802 "SerializableObjectModelTest.vala"
			_g_object_unref0 (_tmp5_);
#line 8028 "SerializableObjectModelTest.c"
		}
#line 802 "SerializableObjectModelTest.vala"
		_tmp7_ = _tmp6_;
#line 802 "SerializableObjectModelTest.vala"
		_tmp8_ = gxml_element_get_attr ((GXmlElement*) _tmp7_, "name");
#line 802 "SerializableObjectModelTest.vala"
		_tmp9_ = _tmp8_;
#line 802 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp7_);
#line 802 "SerializableObjectModelTest.vala"
		name = _tmp9_;
#line 803 "SerializableObjectModelTest.vala"
		if (name != NULL) {
#line 8042 "SerializableObjectModelTest.c"
			FILE* _tmp10_;
			gchar* _tmp11_;
			gchar* _tmp12_;
			gchar* _tmp13_;
			const gchar* _tmp14_;
			gchar* _tmp15_;
			gchar* _tmp16_;
#line 804 "SerializableObjectModelTest.vala"
			_tmp10_ = stdout;
#line 804 "SerializableObjectModelTest.vala"
			_tmp11_ = gxml_node_get_name (name);
#line 804 "SerializableObjectModelTest.vala"
			_tmp12_ = _tmp11_;
#line 804 "SerializableObjectModelTest.vala"
			_tmp13_ = _tmp12_;
#line 804 "SerializableObjectModelTest.vala"
			_tmp14_ = string_to_string (_tmp13_);
#line 804 "SerializableObjectModelTest.vala"
			_tmp15_ = g_strconcat ("ERROR: NULL ATTRIBUTE SERIALIZATION: name found ", _tmp14_, NULL);
#line 804 "SerializableObjectModelTest.vala"
			_tmp16_ = _tmp15_;
#line 804 "SerializableObjectModelTest.vala"
			fprintf (_tmp10_, "%s", _tmp16_);
#line 804 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp16_);
#line 804 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp13_);
#line 805 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 8072 "SerializableObjectModelTest.c"
		}
#line 807 "SerializableObjectModelTest.vala"
		_tmp17_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 807 "SerializableObjectModelTest.vala"
		_tmp18_ = _tmp17_;
#line 807 "SerializableObjectModelTest.vala"
		_tmp19_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp18_) : NULL;
#line 807 "SerializableObjectModelTest.vala"
		if (_tmp19_ == NULL) {
#line 807 "SerializableObjectModelTest.vala"
			_g_object_unref0 (_tmp18_);
#line 8084 "SerializableObjectModelTest.c"
		}
#line 807 "SerializableObjectModelTest.vala"
		_tmp20_ = _tmp19_;
#line 807 "SerializableObjectModelTest.vala"
		_tmp21_ = gxml_element_get_attr (_tmp20_, "array");
#line 807 "SerializableObjectModelTest.vala"
		_tmp22_ = _tmp21_;
#line 807 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp20_);
#line 807 "SerializableObjectModelTest.vala"
		array = _tmp22_;
#line 808 "SerializableObjectModelTest.vala"
		if (array != NULL) {
#line 8098 "SerializableObjectModelTest.c"
			FILE* _tmp23_;
			gchar* _tmp24_;
			gchar* _tmp25_;
			gchar* _tmp26_;
			const gchar* _tmp27_;
			gchar* _tmp28_;
			gchar* _tmp29_;
#line 809 "SerializableObjectModelTest.vala"
			_tmp23_ = stdout;
#line 809 "SerializableObjectModelTest.vala"
			_tmp24_ = gxml_node_get_name (array);
#line 809 "SerializableObjectModelTest.vala"
			_tmp25_ = _tmp24_;
#line 809 "SerializableObjectModelTest.vala"
			_tmp26_ = _tmp25_;
#line 809 "SerializableObjectModelTest.vala"
			_tmp27_ = string_to_string (_tmp26_);
#line 809 "SerializableObjectModelTest.vala"
			_tmp28_ = g_strconcat ("ERROR: NULL ATTRIBUTE SERIALIZATION: array found ", _tmp27_, NULL);
#line 809 "SerializableObjectModelTest.vala"
			_tmp29_ = _tmp28_;
#line 809 "SerializableObjectModelTest.vala"
			fprintf (_tmp23_, "%s", _tmp29_);
#line 809 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp29_);
#line 809 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp26_);
#line 810 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 8128 "SerializableObjectModelTest.c"
		}
#line 812 "SerializableObjectModelTest.vala"
		_tmp30_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 812 "SerializableObjectModelTest.vala"
		_tmp31_ = _tmp30_;
#line 812 "SerializableObjectModelTest.vala"
		_tmp32_ = _tmp31_;
#line 812 "SerializableObjectModelTest.vala"
		_tmp33_ = gxml_node_get_children_nodes (_tmp32_);
#line 812 "SerializableObjectModelTest.vala"
		_tmp34_ = _tmp33_;
#line 812 "SerializableObjectModelTest.vala"
		_tmp35_ = _tmp34_;
#line 812 "SerializableObjectModelTest.vala"
		_tmp36_ = gee_collection_get_size ((GeeCollection*) _tmp35_);
#line 812 "SerializableObjectModelTest.vala"
		_tmp37_ = _tmp36_;
#line 812 "SerializableObjectModelTest.vala"
		_tmp38_ = _tmp37_ > 0;
#line 812 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp35_);
#line 812 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp32_);
#line 812 "SerializableObjectModelTest.vala"
		if (_tmp38_) {
#line 8154 "SerializableObjectModelTest.c"
			FILE* _tmp39_;
			GXmlNode* _tmp40_;
			GXmlNode* _tmp41_;
			GXmlNode* _tmp42_;
			GeeBidirList* _tmp43_;
			GeeBidirList* _tmp44_;
			GeeBidirList* _tmp45_;
			gint _tmp46_;
			gint _tmp47_;
			gchar* _tmp48_;
			gchar* _tmp49_;
			gchar* _tmp50_;
			gchar* _tmp51_;
#line 813 "SerializableObjectModelTest.vala"
			_tmp39_ = stdout;
#line 813 "SerializableObjectModelTest.vala"
			_tmp40_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 813 "SerializableObjectModelTest.vala"
			_tmp41_ = _tmp40_;
#line 813 "SerializableObjectModelTest.vala"
			_tmp42_ = _tmp41_;
#line 813 "SerializableObjectModelTest.vala"
			_tmp43_ = gxml_node_get_children_nodes (_tmp42_);
#line 813 "SerializableObjectModelTest.vala"
			_tmp44_ = _tmp43_;
#line 813 "SerializableObjectModelTest.vala"
			_tmp45_ = _tmp44_;
#line 813 "SerializableObjectModelTest.vala"
			_tmp46_ = gee_collection_get_size ((GeeCollection*) _tmp45_);
#line 813 "SerializableObjectModelTest.vala"
			_tmp47_ = _tmp46_;
#line 813 "SerializableObjectModelTest.vala"
			_tmp48_ = bool_to_string (_tmp47_ > 0);
#line 813 "SerializableObjectModelTest.vala"
			_tmp49_ = _tmp48_;
#line 813 "SerializableObjectModelTest.vala"
			_tmp50_ = g_strconcat ("ERROR: NULL ATTRIBUTE SERIALIZATION: Nodes found ", _tmp49_, NULL);
#line 813 "SerializableObjectModelTest.vala"
			_tmp51_ = _tmp50_;
#line 813 "SerializableObjectModelTest.vala"
			fprintf (_tmp39_, "%s", _tmp51_);
#line 813 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp51_);
#line 813 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp49_);
#line 813 "SerializableObjectModelTest.vala"
			_g_object_unref0 (_tmp45_);
#line 813 "SerializableObjectModelTest.vala"
			_g_object_unref0 (_tmp42_);
#line 814 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 8206 "SerializableObjectModelTest.c"
		}
#line 797 "SerializableObjectModelTest.vala"
		_g_object_unref0 (array);
#line 797 "SerializableObjectModelTest.vala"
		_g_object_unref0 (name);
#line 797 "SerializableObjectModelTest.vala"
		_g_object_unref0 (unknown_property);
#line 797 "SerializableObjectModelTest.vala"
		_g_object_unref0 (doc);
#line 8216 "SerializableObjectModelTest.c"
	}
	goto __finally330;
	__catch330_g_error:
	{
		GError* e = NULL;
		FILE* _tmp52_;
		const gchar* _tmp53_;
		const gchar* _tmp54_;
		gchar* _tmp55_;
		gchar* _tmp56_;
#line 797 "SerializableObjectModelTest.vala"
		e = _inner_error0_;
#line 797 "SerializableObjectModelTest.vala"
		_inner_error0_ = NULL;
#line 818 "SerializableObjectModelTest.vala"
		_tmp52_ = stdout;
#line 818 "SerializableObjectModelTest.vala"
		_tmp53_ = e->message;
#line 818 "SerializableObjectModelTest.vala"
		_tmp54_ = string_to_string (_tmp53_);
#line 818 "SerializableObjectModelTest.vala"
		_tmp55_ = g_strconcat ("Error: ", _tmp54_, NULL);
#line 818 "SerializableObjectModelTest.vala"
		_tmp56_ = _tmp55_;
#line 818 "SerializableObjectModelTest.vala"
		fprintf (_tmp52_, "%s", _tmp56_);
#line 818 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp56_);
#line 819 "SerializableObjectModelTest.vala"
		g_assert_not_reached ();
#line 797 "SerializableObjectModelTest.vala"
		_g_error_free0 (e);
#line 8249 "SerializableObjectModelTest.c"
	}
	__finally330:
#line 797 "SerializableObjectModelTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 797 "SerializableObjectModelTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 797 "SerializableObjectModelTest.vala"
		g_clear_error (&_inner_error0_);
#line 797 "SerializableObjectModelTest.vala"
		return;
#line 8260 "SerializableObjectModelTest.c"
	}
}

static void
___lambda276__gtest_func (void)
{
#line 795 "SerializableObjectModelTest.vala"
	__lambda276_ ();
#line 8269 "SerializableObjectModelTest.c"
}

static void
__lambda277_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlGDocument* _tmp1_;
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlGDocument* _tmp5_;
		GXmlNode* _tmp6_;
		GXmlNode* _tmp7_;
		GXmlNode* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		GXmlGDocument* _tmp12_;
		GXmlNode* _tmp13_;
		GXmlNode* _tmp14_;
		GXmlNode* _tmp15_;
		GeeBidirList* _tmp16_;
		GeeBidirList* _tmp17_;
		GeeBidirList* _tmp18_;
		gint _tmp19_;
		gint _tmp20_;
		UnknownAttribute* unknown_property = NULL;
		UnknownAttribute* _tmp21_;
		UnknownAttribute* _tmp22_;
		GXmlGDocument* _tmp23_;
		GeeMap* ukp = NULL;
		UnknownAttribute* _tmp24_;
		GeeMap* _tmp25_;
		GeeMap* _tmp26_;
		GeeMap* _tmp27_;
		gint _tmp28_;
		gint _tmp29_;
		GXmlAttribute* ignore = NULL;
		GeeMap* _tmp30_;
		gpointer _tmp31_;
		GXmlAttribute* _tmp32_;
		GXmlAttribute* ignore2 = NULL;
		GeeMap* _tmp33_;
		gpointer _tmp34_;
		GXmlAttribute* _tmp35_;
		UnknownAttribute* _tmp36_;
		GeeCollection* _tmp37_;
		GeeCollection* _tmp38_;
		GeeCollection* _tmp39_;
		gint _tmp40_;
		gint _tmp41_;
		gboolean foundn = FALSE;
		gboolean foundt = FALSE;
#line 825 "SerializableObjectModelTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"      <UnknownAttribute ignore=\"true\" ignore2=\"test\"><UnknownNode " \
"toignore = \"true\" />TEXT</UnknownAttribute>", 0, &_inner_error0_);
#line 825 "SerializableObjectModelTest.vala"
		doc = _tmp0_;
#line 825 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 8332 "SerializableObjectModelTest.c"
			goto __catch331_g_error;
		}
#line 827 "SerializableObjectModelTest.vala"
		_tmp1_ = doc;
#line 827 "SerializableObjectModelTest.vala"
		_tmp2_ = gxml_document_get_root ((GXmlDocument*) _tmp1_);
#line 827 "SerializableObjectModelTest.vala"
		_tmp3_ = _tmp2_;
#line 827 "SerializableObjectModelTest.vala"
		_tmp4_ = _tmp3_;
#line 827 "SerializableObjectModelTest.vala"
		_vala_assert (_tmp4_ != NULL, "doc.root != null");
#line 827 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp4_);
#line 828 "SerializableObjectModelTest.vala"
		_tmp5_ = doc;
#line 828 "SerializableObjectModelTest.vala"
		_tmp6_ = gxml_document_get_root ((GXmlDocument*) _tmp5_);
#line 828 "SerializableObjectModelTest.vala"
		_tmp7_ = _tmp6_;
#line 828 "SerializableObjectModelTest.vala"
		_tmp8_ = _tmp7_;
#line 828 "SerializableObjectModelTest.vala"
		_tmp9_ = gxml_node_get_name (_tmp8_);
#line 828 "SerializableObjectModelTest.vala"
		_tmp10_ = _tmp9_;
#line 828 "SerializableObjectModelTest.vala"
		_tmp11_ = _tmp10_;
#line 828 "SerializableObjectModelTest.vala"
		_vala_assert (g_strcmp0 (_tmp11_, "UnknownAttribute") == 0, "doc.root.name == \"UnknownAttribute\"");
#line 828 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp11_);
#line 828 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp8_);
#line 836 "SerializableObjectModelTest.vala"
		_tmp12_ = doc;
#line 836 "SerializableObjectModelTest.vala"
		_tmp13_ = gxml_document_get_root ((GXmlDocument*) _tmp12_);
#line 836 "SerializableObjectModelTest.vala"
		_tmp14_ = _tmp13_;
#line 836 "SerializableObjectModelTest.vala"
		_tmp15_ = _tmp14_;
#line 836 "SerializableObjectModelTest.vala"
		_tmp16_ = gxml_node_get_children_nodes (_tmp15_);
#line 836 "SerializableObjectModelTest.vala"
		_tmp17_ = _tmp16_;
#line 836 "SerializableObjectModelTest.vala"
		_tmp18_ = _tmp17_;
#line 836 "SerializableObjectModelTest.vala"
		_tmp19_ = gee_collection_get_size ((GeeCollection*) _tmp18_);
#line 836 "SerializableObjectModelTest.vala"
		_tmp20_ = _tmp19_;
#line 836 "SerializableObjectModelTest.vala"
		_vala_assert (_tmp20_ == 2, "doc.root.children_nodes.size == 2");
#line 836 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp18_);
#line 836 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp15_);
#line 837 "SerializableObjectModelTest.vala"
		_tmp21_ = unknown_attribute_new ();
#line 837 "SerializableObjectModelTest.vala"
		unknown_property = _tmp21_;
#line 838 "SerializableObjectModelTest.vala"
		_tmp22_ = unknown_property;
#line 838 "SerializableObjectModelTest.vala"
		_tmp23_ = doc;
#line 838 "SerializableObjectModelTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp22_, (GXmlNode*) _tmp23_, &_inner_error0_);
#line 838 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 838 "SerializableObjectModelTest.vala"
			_g_object_unref0 (unknown_property);
#line 838 "SerializableObjectModelTest.vala"
			_g_object_unref0 (doc);
#line 8407 "SerializableObjectModelTest.c"
			goto __catch331_g_error;
		}
#line 849 "SerializableObjectModelTest.vala"
		_tmp24_ = unknown_property;
#line 849 "SerializableObjectModelTest.vala"
		_tmp25_ = gxml_serializable_get_unknown_serializable_properties ((GXmlSerializable*) _tmp24_);
#line 849 "SerializableObjectModelTest.vala"
		_tmp26_ = _tmp25_;
#line 849 "SerializableObjectModelTest.vala"
		ukp = _tmp26_;
#line 850 "SerializableObjectModelTest.vala"
		_tmp27_ = ukp;
#line 850 "SerializableObjectModelTest.vala"
		_tmp28_ = gee_map_get_size (_tmp27_);
#line 850 "SerializableObjectModelTest.vala"
		_tmp29_ = _tmp28_;
#line 850 "SerializableObjectModelTest.vala"
		_vala_assert (_tmp29_ == 2, "ukp.size == 2");
#line 851 "SerializableObjectModelTest.vala"
		_tmp30_ = ukp;
#line 851 "SerializableObjectModelTest.vala"
		_tmp31_ = gee_map_get (_tmp30_, "ignore");
#line 851 "SerializableObjectModelTest.vala"
		ignore = (GXmlAttribute*) _tmp31_;
#line 852 "SerializableObjectModelTest.vala"
		_tmp32_ = ignore;
#line 852 "SerializableObjectModelTest.vala"
		_vala_assert (_tmp32_ != NULL, "ignore != null");
#line 853 "SerializableObjectModelTest.vala"
		_tmp33_ = ukp;
#line 853 "SerializableObjectModelTest.vala"
		_tmp34_ = gee_map_get (_tmp33_, "ignore2");
#line 853 "SerializableObjectModelTest.vala"
		ignore2 = (GXmlAttribute*) _tmp34_;
#line 854 "SerializableObjectModelTest.vala"
		_tmp35_ = ignore2;
#line 854 "SerializableObjectModelTest.vala"
		_vala_assert (_tmp35_ != NULL, "ignore2 != null");
#line 858 "SerializableObjectModelTest.vala"
		_tmp36_ = unknown_property;
#line 858 "SerializableObjectModelTest.vala"
		_tmp37_ = gxml_serializable_get_unknown_serializable_nodes ((GXmlSerializable*) _tmp36_);
#line 858 "SerializableObjectModelTest.vala"
		_tmp38_ = _tmp37_;
#line 858 "SerializableObjectModelTest.vala"
		_tmp39_ = _tmp38_;
#line 858 "SerializableObjectModelTest.vala"
		_tmp40_ = gee_collection_get_size (_tmp39_);
#line 858 "SerializableObjectModelTest.vala"
		_tmp41_ = _tmp40_;
#line 858 "SerializableObjectModelTest.vala"
		_vala_assert (_tmp41_ == 2, "unknown_property.unknown_serializable_nodes.size == 2");
#line 858 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp39_);
#line 859 "SerializableObjectModelTest.vala"
		foundn = FALSE;
#line 860 "SerializableObjectModelTest.vala"
		foundt = FALSE;
#line 8466 "SerializableObjectModelTest.c"
		{
			GeeIterator* _n_it = NULL;
			UnknownAttribute* _tmp42_;
			GeeCollection* _tmp43_;
			GeeCollection* _tmp44_;
			GeeCollection* _tmp45_;
			GeeIterator* _tmp46_;
			GeeIterator* _tmp47_;
#line 861 "SerializableObjectModelTest.vala"
			_tmp42_ = unknown_property;
#line 861 "SerializableObjectModelTest.vala"
			_tmp43_ = gxml_serializable_get_unknown_serializable_nodes ((GXmlSerializable*) _tmp42_);
#line 861 "SerializableObjectModelTest.vala"
			_tmp44_ = _tmp43_;
#line 861 "SerializableObjectModelTest.vala"
			_tmp45_ = _tmp44_;
#line 861 "SerializableObjectModelTest.vala"
			_tmp46_ = gee_iterable_iterator ((GeeIterable*) _tmp45_);
#line 861 "SerializableObjectModelTest.vala"
			_tmp47_ = _tmp46_;
#line 861 "SerializableObjectModelTest.vala"
			_g_object_unref0 (_tmp45_);
#line 861 "SerializableObjectModelTest.vala"
			_n_it = _tmp47_;
#line 861 "SerializableObjectModelTest.vala"
			while (TRUE) {
#line 8493 "SerializableObjectModelTest.c"
				GeeIterator* _tmp48_;
				GXmlNode* n = NULL;
				GeeIterator* _tmp49_;
				gpointer _tmp50_;
				GXmlNode* _tmp51_;
				gchar* _tmp52_;
				gchar* _tmp53_;
				gchar* _tmp54_;
				gboolean _tmp55_;
				GXmlNode* _tmp71_;
#line 861 "SerializableObjectModelTest.vala"
				_tmp48_ = _n_it;
#line 861 "SerializableObjectModelTest.vala"
				if (!gee_iterator_next (_tmp48_)) {
#line 861 "SerializableObjectModelTest.vala"
					break;
#line 8510 "SerializableObjectModelTest.c"
				}
#line 861 "SerializableObjectModelTest.vala"
				_tmp49_ = _n_it;
#line 861 "SerializableObjectModelTest.vala"
				_tmp50_ = gee_iterator_get (_tmp49_);
#line 861 "SerializableObjectModelTest.vala"
				n = (GXmlNode*) _tmp50_;
#line 862 "SerializableObjectModelTest.vala"
				_tmp51_ = n;
#line 862 "SerializableObjectModelTest.vala"
				_tmp52_ = gxml_node_get_name (_tmp51_);
#line 862 "SerializableObjectModelTest.vala"
				_tmp53_ = _tmp52_;
#line 862 "SerializableObjectModelTest.vala"
				_tmp54_ = _tmp53_;
#line 862 "SerializableObjectModelTest.vala"
				_tmp55_ = g_strcmp0 (_tmp54_, "UnknownNode") == 0;
#line 862 "SerializableObjectModelTest.vala"
				_g_free0 (_tmp54_);
#line 862 "SerializableObjectModelTest.vala"
				if (_tmp55_) {
#line 8532 "SerializableObjectModelTest.c"
					GXmlNode* _tmp56_;
					GeeMap* _tmp57_;
					GeeMap* _tmp58_;
					GeeMap* _tmp59_;
					gpointer _tmp60_;
					GXmlNode* _tmp61_;
					GXmlNode* _tmp62_;
					GeeMap* _tmp63_;
					GeeMap* _tmp64_;
					GeeMap* _tmp65_;
					gpointer _tmp66_;
					GXmlNode* _tmp67_;
					gchar* _tmp68_;
					gchar* _tmp69_;
					gchar* _tmp70_;
#line 863 "SerializableObjectModelTest.vala"
					foundn = TRUE;
#line 864 "SerializableObjectModelTest.vala"
					_tmp56_ = n;
#line 864 "SerializableObjectModelTest.vala"
					_tmp57_ = gxml_node_get_attrs (_tmp56_);
#line 864 "SerializableObjectModelTest.vala"
					_tmp58_ = _tmp57_;
#line 864 "SerializableObjectModelTest.vala"
					_tmp59_ = _tmp58_;
#line 864 "SerializableObjectModelTest.vala"
					_tmp60_ = gee_map_get (_tmp59_, "toignore");
#line 864 "SerializableObjectModelTest.vala"
					_tmp61_ = (GXmlNode*) _tmp60_;
#line 864 "SerializableObjectModelTest.vala"
					_vala_assert (_tmp61_ != NULL, "n.attrs.get (\"toignore\") != null");
#line 864 "SerializableObjectModelTest.vala"
					_g_object_unref0 (_tmp61_);
#line 864 "SerializableObjectModelTest.vala"
					_g_object_unref0 (_tmp59_);
#line 865 "SerializableObjectModelTest.vala"
					_tmp62_ = n;
#line 865 "SerializableObjectModelTest.vala"
					_tmp63_ = gxml_node_get_attrs (_tmp62_);
#line 865 "SerializableObjectModelTest.vala"
					_tmp64_ = _tmp63_;
#line 865 "SerializableObjectModelTest.vala"
					_tmp65_ = _tmp64_;
#line 865 "SerializableObjectModelTest.vala"
					_tmp66_ = gee_map_get (_tmp65_, "toignore");
#line 865 "SerializableObjectModelTest.vala"
					_tmp67_ = (GXmlNode*) _tmp66_;
#line 865 "SerializableObjectModelTest.vala"
					_tmp68_ = gxml_node_get_value (_tmp67_);
#line 865 "SerializableObjectModelTest.vala"
					_tmp69_ = _tmp68_;
#line 865 "SerializableObjectModelTest.vala"
					_tmp70_ = _tmp69_;
#line 865 "SerializableObjectModelTest.vala"
					_vala_assert (g_strcmp0 (_tmp70_, "true") == 0, "n.attrs.get (\"toignore\").value == \"true\"");
#line 865 "SerializableObjectModelTest.vala"
					_g_free0 (_tmp70_);
#line 865 "SerializableObjectModelTest.vala"
					_g_object_unref0 (_tmp67_);
#line 865 "SerializableObjectModelTest.vala"
					_g_object_unref0 (_tmp65_);
#line 8594 "SerializableObjectModelTest.c"
				}
#line 867 "SerializableObjectModelTest.vala"
				_tmp71_ = n;
#line 867 "SerializableObjectModelTest.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp71_, GXML_TYPE_TEXT)) {
#line 8600 "SerializableObjectModelTest.c"
					GXmlNode* _tmp72_;
					gchar* _tmp73_;
					gchar* _tmp74_;
					gchar* _tmp75_;
#line 868 "SerializableObjectModelTest.vala"
					foundt = TRUE;
#line 869 "SerializableObjectModelTest.vala"
					_tmp72_ = n;
#line 869 "SerializableObjectModelTest.vala"
					_tmp73_ = gxml_node_get_value (_tmp72_);
#line 869 "SerializableObjectModelTest.vala"
					_tmp74_ = _tmp73_;
#line 869 "SerializableObjectModelTest.vala"
					_tmp75_ = _tmp74_;
#line 869 "SerializableObjectModelTest.vala"
					_vala_assert (g_strcmp0 (_tmp75_, "TEXT") == 0, "n.value == \"TEXT\"");
#line 869 "SerializableObjectModelTest.vala"
					_g_free0 (_tmp75_);
#line 8619 "SerializableObjectModelTest.c"
				}
#line 861 "SerializableObjectModelTest.vala"
				_g_object_unref0 (n);
#line 8623 "SerializableObjectModelTest.c"
			}
#line 861 "SerializableObjectModelTest.vala"
			_g_object_unref0 (_n_it);
#line 8627 "SerializableObjectModelTest.c"
		}
#line 872 "SerializableObjectModelTest.vala"
		_vala_assert (foundn, "foundn");
#line 873 "SerializableObjectModelTest.vala"
		_vala_assert (foundt, "foundt");
#line 824 "SerializableObjectModelTest.vala"
		_g_object_unref0 (ignore2);
#line 824 "SerializableObjectModelTest.vala"
		_g_object_unref0 (ignore);
#line 824 "SerializableObjectModelTest.vala"
		_g_object_unref0 (ukp);
#line 824 "SerializableObjectModelTest.vala"
		_g_object_unref0 (unknown_property);
#line 824 "SerializableObjectModelTest.vala"
		_g_object_unref0 (doc);
#line 8643 "SerializableObjectModelTest.c"
	}
	goto __finally331;
	__catch331_g_error:
	{
		GError* e = NULL;
		FILE* _tmp76_;
		const gchar* _tmp77_;
		const gchar* _tmp78_;
		gchar* _tmp79_;
		gchar* _tmp80_;
#line 824 "SerializableObjectModelTest.vala"
		e = _inner_error0_;
#line 824 "SerializableObjectModelTest.vala"
		_inner_error0_ = NULL;
#line 876 "SerializableObjectModelTest.vala"
		_tmp76_ = stdout;
#line 876 "SerializableObjectModelTest.vala"
		_tmp77_ = e->message;
#line 876 "SerializableObjectModelTest.vala"
		_tmp78_ = string_to_string (_tmp77_);
#line 876 "SerializableObjectModelTest.vala"
		_tmp79_ = g_strconcat ("Error: ", _tmp78_, NULL);
#line 876 "SerializableObjectModelTest.vala"
		_tmp80_ = _tmp79_;
#line 876 "SerializableObjectModelTest.vala"
		fprintf (_tmp76_, "%s", _tmp80_);
#line 876 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp80_);
#line 877 "SerializableObjectModelTest.vala"
		g_assert_not_reached ();
#line 824 "SerializableObjectModelTest.vala"
		_g_error_free0 (e);
#line 8676 "SerializableObjectModelTest.c"
	}
	__finally331:
#line 824 "SerializableObjectModelTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 824 "SerializableObjectModelTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 824 "SerializableObjectModelTest.vala"
		g_clear_error (&_inner_error0_);
#line 824 "SerializableObjectModelTest.vala"
		return;
#line 8687 "SerializableObjectModelTest.c"
	}
}

static void
___lambda277__gtest_func (void)
{
#line 822 "SerializableObjectModelTest.vala"
	__lambda277_ ();
#line 8696 "SerializableObjectModelTest.c"
}

static void
__lambda278_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlGDocument* _tmp1_;
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlNode* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		GXmlGDocument* _tmp8_;
		GXmlNode* _tmp9_;
		GXmlNode* _tmp10_;
		GXmlNode* _tmp11_;
		GeeBidirList* _tmp12_;
		GeeBidirList* _tmp13_;
		GeeBidirList* _tmp14_;
		gint _tmp15_;
		gint _tmp16_;
		GXmlGDocument* _tmp17_;
		GXmlNode* _tmp18_;
		GXmlNode* _tmp19_;
		GXmlNode* _tmp20_;
		GeeBidirList* _tmp21_;
		GeeBidirList* _tmp22_;
		GeeBidirList* _tmp23_;
		gpointer _tmp24_;
		GXmlNode* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
		GXmlGDocument* _tmp29_;
		GXmlNode* _tmp30_;
		GXmlNode* _tmp31_;
		GXmlNode* _tmp32_;
		GeeBidirList* _tmp33_;
		GeeBidirList* _tmp34_;
		GeeBidirList* _tmp35_;
		gpointer _tmp36_;
		GXmlNode* _tmp37_;
		gchar* _tmp38_;
		gchar* _tmp39_;
		gchar* _tmp40_;
		GXmlGDocument* _tmp41_;
		GXmlNode* _tmp42_;
		GXmlNode* _tmp43_;
		GXmlNode* _tmp44_;
		GeeBidirList* _tmp45_;
		GeeBidirList* _tmp46_;
		GeeBidirList* _tmp47_;
		gpointer _tmp48_;
		GXmlNode* _tmp49_;
		GeeBidirList* _tmp50_;
		GeeBidirList* _tmp51_;
		GeeBidirList* _tmp52_;
		gint _tmp53_;
		gint _tmp54_;
		GXmlGDocument* _tmp55_;
		GXmlNode* _tmp56_;
		GXmlNode* _tmp57_;
		GXmlNode* _tmp58_;
		GeeBidirList* _tmp59_;
		GeeBidirList* _tmp60_;
		GeeBidirList* _tmp61_;
		gpointer _tmp62_;
		GXmlNode* _tmp63_;
		GeeBidirList* _tmp64_;
		GeeBidirList* _tmp65_;
		GeeBidirList* _tmp66_;
		gpointer _tmp67_;
		GXmlNode* _tmp68_;
		gchar* _tmp69_;
		gchar* _tmp70_;
		gchar* _tmp71_;
		GXmlGDocument* _tmp72_;
		GXmlNode* _tmp73_;
		GXmlNode* _tmp74_;
		GXmlNode* _tmp75_;
		GeeBidirList* _tmp76_;
		GeeBidirList* _tmp77_;
		GeeBidirList* _tmp78_;
		gpointer _tmp79_;
		GXmlNode* _tmp80_;
		GeeBidirList* _tmp81_;
		GeeBidirList* _tmp82_;
		GeeBidirList* _tmp83_;
		gpointer _tmp84_;
		GXmlNode* _tmp85_;
		GeeBidirList* _tmp86_;
		GeeBidirList* _tmp87_;
		GeeBidirList* _tmp88_;
		gint _tmp89_;
		gint _tmp90_;
		GXmlGDocument* _tmp91_;
		GXmlNode* _tmp92_;
		GXmlNode* _tmp93_;
		GXmlNode* _tmp94_;
		GeeBidirList* _tmp95_;
		GeeBidirList* _tmp96_;
		GeeBidirList* _tmp97_;
		gpointer _tmp98_;
		GXmlNode* _tmp99_;
		GeeBidirList* _tmp100_;
		GeeBidirList* _tmp101_;
		GeeBidirList* _tmp102_;
		gpointer _tmp103_;
		GXmlNode* _tmp104_;
		GeeBidirList* _tmp105_;
		GeeBidirList* _tmp106_;
		GeeBidirList* _tmp107_;
		gpointer _tmp108_;
		GXmlNode* _tmp109_;
		gchar* _tmp110_;
		gchar* _tmp111_;
		gchar* _tmp112_;
		GXmlGDocument* _tmp113_;
		GXmlNode* _tmp114_;
		GXmlNode* _tmp115_;
		GXmlNode* _tmp116_;
		GeeBidirList* _tmp117_;
		GeeBidirList* _tmp118_;
		GeeBidirList* _tmp119_;
		gpointer _tmp120_;
		GXmlNode* _tmp121_;
		GeeBidirList* _tmp122_;
		GeeBidirList* _tmp123_;
		GeeBidirList* _tmp124_;
		gpointer _tmp125_;
		GXmlNode* _tmp126_;
		GeeBidirList* _tmp127_;
		GeeBidirList* _tmp128_;
		GeeBidirList* _tmp129_;
		gpointer _tmp130_;
		GXmlNode* _tmp131_;
		GeeBidirList* _tmp132_;
		GeeBidirList* _tmp133_;
		GeeBidirList* _tmp134_;
		gint _tmp135_;
		gint _tmp136_;
		GXmlGDocument* _tmp137_;
		GXmlNode* _tmp138_;
		GXmlNode* _tmp139_;
		GXmlNode* _tmp140_;
		GeeBidirList* _tmp141_;
		GeeBidirList* _tmp142_;
		GeeBidirList* _tmp143_;
		gpointer _tmp144_;
		GXmlNode* _tmp145_;
		GeeBidirList* _tmp146_;
		GeeBidirList* _tmp147_;
		GeeBidirList* _tmp148_;
		gpointer _tmp149_;
		GXmlNode* _tmp150_;
		GeeBidirList* _tmp151_;
		GeeBidirList* _tmp152_;
		GeeBidirList* _tmp153_;
		gpointer _tmp154_;
		GXmlNode* _tmp155_;
		GeeBidirList* _tmp156_;
		GeeBidirList* _tmp157_;
		GeeBidirList* _tmp158_;
		gpointer _tmp159_;
		GXmlNode* _tmp160_;
		GXmlGDocument* _tmp161_;
		GXmlNode* _tmp162_;
		GXmlNode* _tmp163_;
		GXmlNode* _tmp164_;
		GeeBidirList* _tmp165_;
		GeeBidirList* _tmp166_;
		GeeBidirList* _tmp167_;
		gpointer _tmp168_;
		GXmlNode* _tmp169_;
		GeeBidirList* _tmp170_;
		GeeBidirList* _tmp171_;
		GeeBidirList* _tmp172_;
		gpointer _tmp173_;
		GXmlNode* _tmp174_;
		GeeBidirList* _tmp175_;
		GeeBidirList* _tmp176_;
		GeeBidirList* _tmp177_;
		gpointer _tmp178_;
		GXmlNode* _tmp179_;
		GeeBidirList* _tmp180_;
		GeeBidirList* _tmp181_;
		GeeBidirList* _tmp182_;
		gpointer _tmp183_;
		GXmlNode* _tmp184_;
		gchar* _tmp185_;
		gchar* _tmp186_;
		gchar* _tmp187_;
		UnknownAttribute* unknown_property = NULL;
		UnknownAttribute* _tmp188_;
		UnknownAttribute* _tmp189_;
		GXmlGDocument* _tmp190_;
		GXmlGDocument* doc2 = NULL;
		GXmlGDocument* _tmp191_;
		UnknownAttribute* _tmp192_;
		GXmlGDocument* _tmp193_;
		GXmlNode* _tmp194_;
		GXmlNode* _tmp195_;
		GXmlGDocument* _tmp196_;
		GXmlNode* _tmp197_;
		GXmlNode* _tmp198_;
		GXmlNode* _tmp199_;
		GXmlGDocument* _tmp200_;
		GXmlNode* _tmp201_;
		GXmlNode* _tmp202_;
		GXmlNode* _tmp203_;
		gchar* _tmp204_;
		gchar* _tmp205_;
		gchar* _tmp206_;
		GXmlGDocument* _tmp207_;
		GXmlNode* _tmp208_;
		GXmlNode* _tmp209_;
		GXmlNode* _tmp210_;
		GeeBidirList* _tmp211_;
		GeeBidirList* _tmp212_;
		GeeBidirList* _tmp213_;
		gint _tmp214_;
		gint _tmp215_;
		GXmlGDocument* _tmp216_;
		GXmlNode* _tmp217_;
		GXmlNode* _tmp218_;
		GXmlNode* _tmp219_;
		GeeBidirList* _tmp220_;
		GeeBidirList* _tmp221_;
		GeeBidirList* _tmp222_;
		gpointer _tmp223_;
		GXmlNode* _tmp224_;
		gchar* _tmp225_;
		gchar* _tmp226_;
		gchar* _tmp227_;
		GXmlGDocument* _tmp228_;
		GXmlNode* _tmp229_;
		GXmlNode* _tmp230_;
		GXmlNode* _tmp231_;
		GeeBidirList* _tmp232_;
		GeeBidirList* _tmp233_;
		GeeBidirList* _tmp234_;
		gpointer _tmp235_;
		GXmlNode* _tmp236_;
		GeeBidirList* _tmp237_;
		GeeBidirList* _tmp238_;
		GeeBidirList* _tmp239_;
		gint _tmp240_;
		gint _tmp241_;
		GXmlGDocument* _tmp242_;
		GXmlNode* _tmp243_;
		GXmlNode* _tmp244_;
		GXmlNode* _tmp245_;
		GeeBidirList* _tmp246_;
		GeeBidirList* _tmp247_;
		GeeBidirList* _tmp248_;
		gpointer _tmp249_;
		GXmlNode* _tmp250_;
		gchar* _tmp251_;
		gchar* _tmp252_;
		gchar* _tmp253_;
		GXmlGDocument* _tmp254_;
		GXmlNode* _tmp255_;
		GXmlNode* _tmp256_;
		GXmlNode* _tmp257_;
		GeeBidirList* _tmp258_;
		GeeBidirList* _tmp259_;
		GeeBidirList* _tmp260_;
		gpointer _tmp261_;
		GXmlNode* _tmp262_;
		GeeBidirList* _tmp263_;
		GeeBidirList* _tmp264_;
		GeeBidirList* _tmp265_;
		gpointer _tmp266_;
		GXmlNode* _tmp267_;
		gchar* _tmp268_;
		gchar* _tmp269_;
		gchar* _tmp270_;
		GXmlGDocument* _tmp271_;
		GXmlNode* _tmp272_;
		GXmlNode* _tmp273_;
		GXmlNode* _tmp274_;
		GeeBidirList* _tmp275_;
		GeeBidirList* _tmp276_;
		GeeBidirList* _tmp277_;
		gpointer _tmp278_;
		GXmlNode* _tmp279_;
		GeeBidirList* _tmp280_;
		GeeBidirList* _tmp281_;
		GeeBidirList* _tmp282_;
		gpointer _tmp283_;
		GXmlNode* _tmp284_;
		GeeBidirList* _tmp285_;
		GeeBidirList* _tmp286_;
		GeeBidirList* _tmp287_;
		gpointer _tmp288_;
		GXmlNode* _tmp289_;
		gchar* _tmp290_;
		gchar* _tmp291_;
		gchar* _tmp292_;
		GXmlGDocument* _tmp293_;
		GXmlNode* _tmp294_;
		GXmlNode* _tmp295_;
		GXmlNode* _tmp296_;
		GeeBidirList* _tmp297_;
		GeeBidirList* _tmp298_;
		GeeBidirList* _tmp299_;
		gpointer _tmp300_;
		GXmlNode* _tmp301_;
		GeeBidirList* _tmp302_;
		GeeBidirList* _tmp303_;
		GeeBidirList* _tmp304_;
		gpointer _tmp305_;
		GXmlNode* _tmp306_;
		GeeBidirList* _tmp307_;
		GeeBidirList* _tmp308_;
		GeeBidirList* _tmp309_;
		gint _tmp310_;
		gint _tmp311_;
		GXmlGDocument* _tmp312_;
		GXmlNode* _tmp313_;
		GXmlNode* _tmp314_;
		GXmlNode* _tmp315_;
		GeeBidirList* _tmp316_;
		GeeBidirList* _tmp317_;
		GeeBidirList* _tmp318_;
		gpointer _tmp319_;
		GXmlNode* _tmp320_;
		GeeBidirList* _tmp321_;
		GeeBidirList* _tmp322_;
		GeeBidirList* _tmp323_;
		gpointer _tmp324_;
		GXmlNode* _tmp325_;
		GeeBidirList* _tmp326_;
		GeeBidirList* _tmp327_;
		GeeBidirList* _tmp328_;
		gpointer _tmp329_;
		GXmlNode* _tmp330_;
		GeeBidirList* _tmp331_;
		GeeBidirList* _tmp332_;
		GeeBidirList* _tmp333_;
		gint _tmp334_;
		gint _tmp335_;
		GXmlGDocument* _tmp336_;
		GXmlNode* _tmp337_;
		GXmlNode* _tmp338_;
		GXmlNode* _tmp339_;
		GeeBidirList* _tmp340_;
		GeeBidirList* _tmp341_;
		GeeBidirList* _tmp342_;
		gpointer _tmp343_;
		GXmlNode* _tmp344_;
		GeeBidirList* _tmp345_;
		GeeBidirList* _tmp346_;
		GeeBidirList* _tmp347_;
		gpointer _tmp348_;
		GXmlNode* _tmp349_;
		GeeBidirList* _tmp350_;
		GeeBidirList* _tmp351_;
		GeeBidirList* _tmp352_;
		gpointer _tmp353_;
		GXmlNode* _tmp354_;
		GeeBidirList* _tmp355_;
		GeeBidirList* _tmp356_;
		GeeBidirList* _tmp357_;
		gpointer _tmp358_;
		GXmlNode* _tmp359_;
		GXmlGDocument* _tmp360_;
		GXmlNode* _tmp361_;
		GXmlNode* _tmp362_;
		GXmlNode* _tmp363_;
		GeeBidirList* _tmp364_;
		GeeBidirList* _tmp365_;
		GeeBidirList* _tmp366_;
		gpointer _tmp367_;
		GXmlNode* _tmp368_;
		GeeBidirList* _tmp369_;
		GeeBidirList* _tmp370_;
		GeeBidirList* _tmp371_;
		gpointer _tmp372_;
		GXmlNode* _tmp373_;
		GeeBidirList* _tmp374_;
		GeeBidirList* _tmp375_;
		GeeBidirList* _tmp376_;
		gpointer _tmp377_;
		GXmlNode* _tmp378_;
		GeeBidirList* _tmp379_;
		GeeBidirList* _tmp380_;
		GeeBidirList* _tmp381_;
		gpointer _tmp382_;
		GXmlNode* _tmp383_;
		gchar* _tmp384_;
		gchar* _tmp385_;
		gchar* _tmp386_;
#line 883 "SerializableObjectModelTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"       <UnknownAttribute ignore=\"true\" ignore2=\"test\">\n" \
"        <UnknownNode direction = \"fordward\">\n" \
"         <UnknownChild t = \"test\">\n" \
"          <UnknownChildTwo t = \"test\">SECOND FAKE TEXT</UnknownChild" \
"Two>\n" \
"         </UnknownChild>\n" \
"       </UnknownNode>FAKE TEXT</UnknownAttribute>", 0, &_inner_error0_);
#line 883 "SerializableObjectModelTest.vala"
		doc = _tmp0_;
#line 883 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 9100 "SerializableObjectModelTest.c"
			goto __catch332_g_error;
		}
#line 890 "SerializableObjectModelTest.vala"
		_tmp1_ = doc;
#line 890 "SerializableObjectModelTest.vala"
		_tmp2_ = gxml_document_get_root ((GXmlDocument*) _tmp1_);
#line 890 "SerializableObjectModelTest.vala"
		_tmp3_ = _tmp2_;
#line 890 "SerializableObjectModelTest.vala"
		_tmp4_ = _tmp3_;
#line 890 "SerializableObjectModelTest.vala"
		_tmp5_ = gxml_node_get_name (_tmp4_);
#line 890 "SerializableObjectModelTest.vala"
		_tmp6_ = _tmp5_;
#line 890 "SerializableObjectModelTest.vala"
		_tmp7_ = _tmp6_;
#line 890 "SerializableObjectModelTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "UnknownAttribute") == 0, "doc.root.name == \"UnknownAttribute\"");
#line 890 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp7_);
#line 890 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp4_);
#line 891 "SerializableObjectModelTest.vala"
		_tmp8_ = doc;
#line 891 "SerializableObjectModelTest.vala"
		_tmp9_ = gxml_document_get_root ((GXmlDocument*) _tmp8_);
#line 891 "SerializableObjectModelTest.vala"
		_tmp10_ = _tmp9_;
#line 891 "SerializableObjectModelTest.vala"
		_tmp11_ = _tmp10_;
#line 891 "SerializableObjectModelTest.vala"
		_tmp12_ = gxml_node_get_children_nodes (_tmp11_);
#line 891 "SerializableObjectModelTest.vala"
		_tmp13_ = _tmp12_;
#line 891 "SerializableObjectModelTest.vala"
		_tmp14_ = _tmp13_;
#line 891 "SerializableObjectModelTest.vala"
		_tmp15_ = gee_collection_get_size ((GeeCollection*) _tmp14_);
#line 891 "SerializableObjectModelTest.vala"
		_tmp16_ = _tmp15_;
#line 891 "SerializableObjectModelTest.vala"
		_vala_assert (_tmp16_ == 3, "doc.root.children_nodes.size == 3");
#line 891 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp14_);
#line 891 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp11_);
#line 892 "SerializableObjectModelTest.vala"
		_tmp17_ = doc;
#line 892 "SerializableObjectModelTest.vala"
		_tmp18_ = gxml_document_get_root ((GXmlDocument*) _tmp17_);
#line 892 "SerializableObjectModelTest.vala"
		_tmp19_ = _tmp18_;
#line 892 "SerializableObjectModelTest.vala"
		_tmp20_ = _tmp19_;
#line 892 "SerializableObjectModelTest.vala"
		_tmp21_ = gxml_node_get_children_nodes (_tmp20_);
#line 892 "SerializableObjectModelTest.vala"
		_tmp22_ = _tmp21_;
#line 892 "SerializableObjectModelTest.vala"
		_tmp23_ = _tmp22_;
#line 892 "SerializableObjectModelTest.vala"
		_tmp24_ = gee_list_get ((GeeList*) _tmp23_, 1);
#line 892 "SerializableObjectModelTest.vala"
		_tmp25_ = (GXmlNode*) _tmp24_;
#line 892 "SerializableObjectModelTest.vala"
		_tmp26_ = gxml_node_get_name (_tmp25_);
#line 892 "SerializableObjectModelTest.vala"
		_tmp27_ = _tmp26_;
#line 892 "SerializableObjectModelTest.vala"
		_tmp28_ = _tmp27_;
#line 892 "SerializableObjectModelTest.vala"
		_vala_assert (g_strcmp0 (_tmp28_, "UnknownNode") == 0, "doc.root.children_nodes[1].name == \"UnknownNode\"");
#line 892 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp28_);
#line 892 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp25_);
#line 892 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp23_);
#line 892 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp20_);
#line 893 "SerializableObjectModelTest.vala"
		_tmp29_ = doc;
#line 893 "SerializableObjectModelTest.vala"
		_tmp30_ = gxml_document_get_root ((GXmlDocument*) _tmp29_);
#line 893 "SerializableObjectModelTest.vala"
		_tmp31_ = _tmp30_;
#line 893 "SerializableObjectModelTest.vala"
		_tmp32_ = _tmp31_;
#line 893 "SerializableObjectModelTest.vala"
		_tmp33_ = gxml_node_get_children_nodes (_tmp32_);
#line 893 "SerializableObjectModelTest.vala"
		_tmp34_ = _tmp33_;
#line 893 "SerializableObjectModelTest.vala"
		_tmp35_ = _tmp34_;
#line 893 "SerializableObjectModelTest.vala"
		_tmp36_ = gee_list_get ((GeeList*) _tmp35_, 2);
#line 893 "SerializableObjectModelTest.vala"
		_tmp37_ = (GXmlNode*) _tmp36_;
#line 893 "SerializableObjectModelTest.vala"
		_tmp38_ = gxml_node_get_value (_tmp37_);
#line 893 "SerializableObjectModelTest.vala"
		_tmp39_ = _tmp38_;
#line 893 "SerializableObjectModelTest.vala"
		_tmp40_ = _tmp39_;
#line 893 "SerializableObjectModelTest.vala"
		_vala_assert (g_strcmp0 (_tmp40_, "FAKE TEXT") == 0, "doc.root.children_nodes[2].value == \"FAKE TEXT\"");
#line 893 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp40_);
#line 893 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp37_);
#line 893 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp35_);
#line 893 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp32_);
#line 894 "SerializableObjectModelTest.vala"
		_tmp41_ = doc;
#line 894 "SerializableObjectModelTest.vala"
		_tmp42_ = gxml_document_get_root ((GXmlDocument*) _tmp41_);
#line 894 "SerializableObjectModelTest.vala"
		_tmp43_ = _tmp42_;
#line 894 "SerializableObjectModelTest.vala"
		_tmp44_ = _tmp43_;
#line 894 "SerializableObjectModelTest.vala"
		_tmp45_ = gxml_node_get_children_nodes (_tmp44_);
#line 894 "SerializableObjectModelTest.vala"
		_tmp46_ = _tmp45_;
#line 894 "SerializableObjectModelTest.vala"
		_tmp47_ = _tmp46_;
#line 894 "SerializableObjectModelTest.vala"
		_tmp48_ = gee_list_get ((GeeList*) _tmp47_, 1);
#line 894 "SerializableObjectModelTest.vala"
		_tmp49_ = (GXmlNode*) _tmp48_;
#line 894 "SerializableObjectModelTest.vala"
		_tmp50_ = gxml_node_get_children_nodes (_tmp49_);
#line 894 "SerializableObjectModelTest.vala"
		_tmp51_ = _tmp50_;
#line 894 "SerializableObjectModelTest.vala"
		_tmp52_ = _tmp51_;
#line 894 "SerializableObjectModelTest.vala"
		_tmp53_ = gee_collection_get_size ((GeeCollection*) _tmp52_);
#line 894 "SerializableObjectModelTest.vala"
		_tmp54_ = _tmp53_;
#line 894 "SerializableObjectModelTest.vala"
		_vala_assert (_tmp54_ == 3, "doc.root.children_nodes[1].children_nodes.size == 3");
#line 894 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp52_);
#line 894 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp49_);
#line 894 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp47_);
#line 894 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp44_);
#line 895 "SerializableObjectModelTest.vala"
		_tmp55_ = doc;
#line 895 "SerializableObjectModelTest.vala"
		_tmp56_ = gxml_document_get_root ((GXmlDocument*) _tmp55_);
#line 895 "SerializableObjectModelTest.vala"
		_tmp57_ = _tmp56_;
#line 895 "SerializableObjectModelTest.vala"
		_tmp58_ = _tmp57_;
#line 895 "SerializableObjectModelTest.vala"
		_tmp59_ = gxml_node_get_children_nodes (_tmp58_);
#line 895 "SerializableObjectModelTest.vala"
		_tmp60_ = _tmp59_;
#line 895 "SerializableObjectModelTest.vala"
		_tmp61_ = _tmp60_;
#line 895 "SerializableObjectModelTest.vala"
		_tmp62_ = gee_list_get ((GeeList*) _tmp61_, 1);
#line 895 "SerializableObjectModelTest.vala"
		_tmp63_ = (GXmlNode*) _tmp62_;
#line 895 "SerializableObjectModelTest.vala"
		_tmp64_ = gxml_node_get_children_nodes (_tmp63_);
#line 895 "SerializableObjectModelTest.vala"
		_tmp65_ = _tmp64_;
#line 895 "SerializableObjectModelTest.vala"
		_tmp66_ = _tmp65_;
#line 895 "SerializableObjectModelTest.vala"
		_tmp67_ = gee_list_get ((GeeList*) _tmp66_, 1);
#line 895 "SerializableObjectModelTest.vala"
		_tmp68_ = (GXmlNode*) _tmp67_;
#line 895 "SerializableObjectModelTest.vala"
		_tmp69_ = gxml_node_get_name (_tmp68_);
#line 895 "SerializableObjectModelTest.vala"
		_tmp70_ = _tmp69_;
#line 895 "SerializableObjectModelTest.vala"
		_tmp71_ = _tmp70_;
#line 895 "SerializableObjectModelTest.vala"
		_vala_assert (g_strcmp0 (_tmp71_, "UnknownChild") == 0, "doc.root.children_nodes[1].children_nodes[1].name == \"UnknownChild\"");
#line 895 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp71_);
#line 895 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp68_);
#line 895 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp66_);
#line 895 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp63_);
#line 895 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp61_);
#line 895 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp58_);
#line 896 "SerializableObjectModelTest.vala"
		_tmp72_ = doc;
#line 896 "SerializableObjectModelTest.vala"
		_tmp73_ = gxml_document_get_root ((GXmlDocument*) _tmp72_);
#line 896 "SerializableObjectModelTest.vala"
		_tmp74_ = _tmp73_;
#line 896 "SerializableObjectModelTest.vala"
		_tmp75_ = _tmp74_;
#line 896 "SerializableObjectModelTest.vala"
		_tmp76_ = gxml_node_get_children_nodes (_tmp75_);
#line 896 "SerializableObjectModelTest.vala"
		_tmp77_ = _tmp76_;
#line 896 "SerializableObjectModelTest.vala"
		_tmp78_ = _tmp77_;
#line 896 "SerializableObjectModelTest.vala"
		_tmp79_ = gee_list_get ((GeeList*) _tmp78_, 1);
#line 896 "SerializableObjectModelTest.vala"
		_tmp80_ = (GXmlNode*) _tmp79_;
#line 896 "SerializableObjectModelTest.vala"
		_tmp81_ = gxml_node_get_children_nodes (_tmp80_);
#line 896 "SerializableObjectModelTest.vala"
		_tmp82_ = _tmp81_;
#line 896 "SerializableObjectModelTest.vala"
		_tmp83_ = _tmp82_;
#line 896 "SerializableObjectModelTest.vala"
		_tmp84_ = gee_list_get ((GeeList*) _tmp83_, 1);
#line 896 "SerializableObjectModelTest.vala"
		_tmp85_ = (GXmlNode*) _tmp84_;
#line 896 "SerializableObjectModelTest.vala"
		_tmp86_ = gxml_node_get_children_nodes (_tmp85_);
#line 896 "SerializableObjectModelTest.vala"
		_tmp87_ = _tmp86_;
#line 896 "SerializableObjectModelTest.vala"
		_tmp88_ = _tmp87_;
#line 896 "SerializableObjectModelTest.vala"
		_tmp89_ = gee_collection_get_size ((GeeCollection*) _tmp88_);
#line 896 "SerializableObjectModelTest.vala"
		_tmp90_ = _tmp89_;
#line 896 "SerializableObjectModelTest.vala"
		_vala_assert (_tmp90_ == 3, "doc.root.children_nodes[1].children_nodes[1].children_nodes.size == 3");
#line 896 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp88_);
#line 896 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp85_);
#line 896 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp83_);
#line 896 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp80_);
#line 896 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp78_);
#line 896 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp75_);
#line 897 "SerializableObjectModelTest.vala"
		_tmp91_ = doc;
#line 897 "SerializableObjectModelTest.vala"
		_tmp92_ = gxml_document_get_root ((GXmlDocument*) _tmp91_);
#line 897 "SerializableObjectModelTest.vala"
		_tmp93_ = _tmp92_;
#line 897 "SerializableObjectModelTest.vala"
		_tmp94_ = _tmp93_;
#line 897 "SerializableObjectModelTest.vala"
		_tmp95_ = gxml_node_get_children_nodes (_tmp94_);
#line 897 "SerializableObjectModelTest.vala"
		_tmp96_ = _tmp95_;
#line 897 "SerializableObjectModelTest.vala"
		_tmp97_ = _tmp96_;
#line 897 "SerializableObjectModelTest.vala"
		_tmp98_ = gee_list_get ((GeeList*) _tmp97_, 1);
#line 897 "SerializableObjectModelTest.vala"
		_tmp99_ = (GXmlNode*) _tmp98_;
#line 897 "SerializableObjectModelTest.vala"
		_tmp100_ = gxml_node_get_children_nodes (_tmp99_);
#line 897 "SerializableObjectModelTest.vala"
		_tmp101_ = _tmp100_;
#line 897 "SerializableObjectModelTest.vala"
		_tmp102_ = _tmp101_;
#line 897 "SerializableObjectModelTest.vala"
		_tmp103_ = gee_list_get ((GeeList*) _tmp102_, 1);
#line 897 "SerializableObjectModelTest.vala"
		_tmp104_ = (GXmlNode*) _tmp103_;
#line 897 "SerializableObjectModelTest.vala"
		_tmp105_ = gxml_node_get_children_nodes (_tmp104_);
#line 897 "SerializableObjectModelTest.vala"
		_tmp106_ = _tmp105_;
#line 897 "SerializableObjectModelTest.vala"
		_tmp107_ = _tmp106_;
#line 897 "SerializableObjectModelTest.vala"
		_tmp108_ = gee_list_get ((GeeList*) _tmp107_, 1);
#line 897 "SerializableObjectModelTest.vala"
		_tmp109_ = (GXmlNode*) _tmp108_;
#line 897 "SerializableObjectModelTest.vala"
		_tmp110_ = gxml_node_get_name (_tmp109_);
#line 897 "SerializableObjectModelTest.vala"
		_tmp111_ = _tmp110_;
#line 897 "SerializableObjectModelTest.vala"
		_tmp112_ = _tmp111_;
#line 897 "SerializableObjectModelTest.vala"
		_vala_assert (g_strcmp0 (_tmp112_, "UnknownChildTwo") == 0, "doc.root.children_nodes[1].children_nodes[1].children_nodes[1].name == \"UnknownChildTwo\"");
#line 897 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp112_);
#line 897 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp109_);
#line 897 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp107_);
#line 897 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp104_);
#line 897 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp102_);
#line 897 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp99_);
#line 897 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp97_);
#line 897 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp94_);
#line 898 "SerializableObjectModelTest.vala"
		_tmp113_ = doc;
#line 898 "SerializableObjectModelTest.vala"
		_tmp114_ = gxml_document_get_root ((GXmlDocument*) _tmp113_);
#line 898 "SerializableObjectModelTest.vala"
		_tmp115_ = _tmp114_;
#line 898 "SerializableObjectModelTest.vala"
		_tmp116_ = _tmp115_;
#line 898 "SerializableObjectModelTest.vala"
		_tmp117_ = gxml_node_get_children_nodes (_tmp116_);
#line 898 "SerializableObjectModelTest.vala"
		_tmp118_ = _tmp117_;
#line 898 "SerializableObjectModelTest.vala"
		_tmp119_ = _tmp118_;
#line 898 "SerializableObjectModelTest.vala"
		_tmp120_ = gee_list_get ((GeeList*) _tmp119_, 1);
#line 898 "SerializableObjectModelTest.vala"
		_tmp121_ = (GXmlNode*) _tmp120_;
#line 898 "SerializableObjectModelTest.vala"
		_tmp122_ = gxml_node_get_children_nodes (_tmp121_);
#line 898 "SerializableObjectModelTest.vala"
		_tmp123_ = _tmp122_;
#line 898 "SerializableObjectModelTest.vala"
		_tmp124_ = _tmp123_;
#line 898 "SerializableObjectModelTest.vala"
		_tmp125_ = gee_list_get ((GeeList*) _tmp124_, 1);
#line 898 "SerializableObjectModelTest.vala"
		_tmp126_ = (GXmlNode*) _tmp125_;
#line 898 "SerializableObjectModelTest.vala"
		_tmp127_ = gxml_node_get_children_nodes (_tmp126_);
#line 898 "SerializableObjectModelTest.vala"
		_tmp128_ = _tmp127_;
#line 898 "SerializableObjectModelTest.vala"
		_tmp129_ = _tmp128_;
#line 898 "SerializableObjectModelTest.vala"
		_tmp130_ = gee_list_get ((GeeList*) _tmp129_, 1);
#line 898 "SerializableObjectModelTest.vala"
		_tmp131_ = (GXmlNode*) _tmp130_;
#line 898 "SerializableObjectModelTest.vala"
		_tmp132_ = gxml_node_get_children_nodes (_tmp131_);
#line 898 "SerializableObjectModelTest.vala"
		_tmp133_ = _tmp132_;
#line 898 "SerializableObjectModelTest.vala"
		_tmp134_ = _tmp133_;
#line 898 "SerializableObjectModelTest.vala"
		_tmp135_ = gee_collection_get_size ((GeeCollection*) _tmp134_);
#line 898 "SerializableObjectModelTest.vala"
		_tmp136_ = _tmp135_;
#line 898 "SerializableObjectModelTest.vala"
		_vala_assert (_tmp136_ == 1, "doc.root.children_nodes[1].children_nodes[1].children_nodes[1].children_nodes.size == 1");
#line 898 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp134_);
#line 898 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp131_);
#line 898 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp129_);
#line 898 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp126_);
#line 898 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp124_);
#line 898 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp121_);
#line 898 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp119_);
#line 898 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp116_);
#line 899 "SerializableObjectModelTest.vala"
		_tmp137_ = doc;
#line 899 "SerializableObjectModelTest.vala"
		_tmp138_ = gxml_document_get_root ((GXmlDocument*) _tmp137_);
#line 899 "SerializableObjectModelTest.vala"
		_tmp139_ = _tmp138_;
#line 899 "SerializableObjectModelTest.vala"
		_tmp140_ = _tmp139_;
#line 899 "SerializableObjectModelTest.vala"
		_tmp141_ = gxml_node_get_children_nodes (_tmp140_);
#line 899 "SerializableObjectModelTest.vala"
		_tmp142_ = _tmp141_;
#line 899 "SerializableObjectModelTest.vala"
		_tmp143_ = _tmp142_;
#line 899 "SerializableObjectModelTest.vala"
		_tmp144_ = gee_list_get ((GeeList*) _tmp143_, 1);
#line 899 "SerializableObjectModelTest.vala"
		_tmp145_ = (GXmlNode*) _tmp144_;
#line 899 "SerializableObjectModelTest.vala"
		_tmp146_ = gxml_node_get_children_nodes (_tmp145_);
#line 899 "SerializableObjectModelTest.vala"
		_tmp147_ = _tmp146_;
#line 899 "SerializableObjectModelTest.vala"
		_tmp148_ = _tmp147_;
#line 899 "SerializableObjectModelTest.vala"
		_tmp149_ = gee_list_get ((GeeList*) _tmp148_, 1);
#line 899 "SerializableObjectModelTest.vala"
		_tmp150_ = (GXmlNode*) _tmp149_;
#line 899 "SerializableObjectModelTest.vala"
		_tmp151_ = gxml_node_get_children_nodes (_tmp150_);
#line 899 "SerializableObjectModelTest.vala"
		_tmp152_ = _tmp151_;
#line 899 "SerializableObjectModelTest.vala"
		_tmp153_ = _tmp152_;
#line 899 "SerializableObjectModelTest.vala"
		_tmp154_ = gee_list_get ((GeeList*) _tmp153_, 1);
#line 899 "SerializableObjectModelTest.vala"
		_tmp155_ = (GXmlNode*) _tmp154_;
#line 899 "SerializableObjectModelTest.vala"
		_tmp156_ = gxml_node_get_children_nodes (_tmp155_);
#line 899 "SerializableObjectModelTest.vala"
		_tmp157_ = _tmp156_;
#line 899 "SerializableObjectModelTest.vala"
		_tmp158_ = _tmp157_;
#line 899 "SerializableObjectModelTest.vala"
		_tmp159_ = gee_list_get ((GeeList*) _tmp158_, 0);
#line 899 "SerializableObjectModelTest.vala"
		_tmp160_ = (GXmlNode*) _tmp159_;
#line 899 "SerializableObjectModelTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp160_, GXML_TYPE_TEXT), "doc.root.children_nodes[1].children_nodes[1].children_nodes[1].children_nodes[0] is GXml.Text");
#line 899 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp160_);
#line 899 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp158_);
#line 899 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp155_);
#line 899 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp153_);
#line 899 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp150_);
#line 899 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp148_);
#line 899 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp145_);
#line 899 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp143_);
#line 899 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp140_);
#line 900 "SerializableObjectModelTest.vala"
		_tmp161_ = doc;
#line 900 "SerializableObjectModelTest.vala"
		_tmp162_ = gxml_document_get_root ((GXmlDocument*) _tmp161_);
#line 900 "SerializableObjectModelTest.vala"
		_tmp163_ = _tmp162_;
#line 900 "SerializableObjectModelTest.vala"
		_tmp164_ = _tmp163_;
#line 900 "SerializableObjectModelTest.vala"
		_tmp165_ = gxml_node_get_children_nodes (_tmp164_);
#line 900 "SerializableObjectModelTest.vala"
		_tmp166_ = _tmp165_;
#line 900 "SerializableObjectModelTest.vala"
		_tmp167_ = _tmp166_;
#line 900 "SerializableObjectModelTest.vala"
		_tmp168_ = gee_list_get ((GeeList*) _tmp167_, 1);
#line 900 "SerializableObjectModelTest.vala"
		_tmp169_ = (GXmlNode*) _tmp168_;
#line 900 "SerializableObjectModelTest.vala"
		_tmp170_ = gxml_node_get_children_nodes (_tmp169_);
#line 900 "SerializableObjectModelTest.vala"
		_tmp171_ = _tmp170_;
#line 900 "SerializableObjectModelTest.vala"
		_tmp172_ = _tmp171_;
#line 900 "SerializableObjectModelTest.vala"
		_tmp173_ = gee_list_get ((GeeList*) _tmp172_, 1);
#line 900 "SerializableObjectModelTest.vala"
		_tmp174_ = (GXmlNode*) _tmp173_;
#line 900 "SerializableObjectModelTest.vala"
		_tmp175_ = gxml_node_get_children_nodes (_tmp174_);
#line 900 "SerializableObjectModelTest.vala"
		_tmp176_ = _tmp175_;
#line 900 "SerializableObjectModelTest.vala"
		_tmp177_ = _tmp176_;
#line 900 "SerializableObjectModelTest.vala"
		_tmp178_ = gee_list_get ((GeeList*) _tmp177_, 1);
#line 900 "SerializableObjectModelTest.vala"
		_tmp179_ = (GXmlNode*) _tmp178_;
#line 900 "SerializableObjectModelTest.vala"
		_tmp180_ = gxml_node_get_children_nodes (_tmp179_);
#line 900 "SerializableObjectModelTest.vala"
		_tmp181_ = _tmp180_;
#line 900 "SerializableObjectModelTest.vala"
		_tmp182_ = _tmp181_;
#line 900 "SerializableObjectModelTest.vala"
		_tmp183_ = gee_list_get ((GeeList*) _tmp182_, 0);
#line 900 "SerializableObjectModelTest.vala"
		_tmp184_ = (GXmlNode*) _tmp183_;
#line 900 "SerializableObjectModelTest.vala"
		_tmp185_ = gxml_node_get_value (_tmp184_);
#line 900 "SerializableObjectModelTest.vala"
		_tmp186_ = _tmp185_;
#line 900 "SerializableObjectModelTest.vala"
		_tmp187_ = _tmp186_;
#line 900 "SerializableObjectModelTest.vala"
		_vala_assert (g_strcmp0 (_tmp187_, "SECOND FAKE TEXT") == 0, "doc.root.children_nodes[1].children_nodes[1].children_nodes[1].children_nodes[0].value == \"SECOND FAKE TEXT\"");
#line 900 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp187_);
#line 900 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp184_);
#line 900 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp182_);
#line 900 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp179_);
#line 900 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp177_);
#line 900 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp174_);
#line 900 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp172_);
#line 900 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp169_);
#line 900 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp167_);
#line 900 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp164_);
#line 901 "SerializableObjectModelTest.vala"
		_tmp188_ = unknown_attribute_new ();
#line 901 "SerializableObjectModelTest.vala"
		unknown_property = _tmp188_;
#line 902 "SerializableObjectModelTest.vala"
		_tmp189_ = unknown_property;
#line 902 "SerializableObjectModelTest.vala"
		_tmp190_ = doc;
#line 902 "SerializableObjectModelTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp189_, (GXmlNode*) _tmp190_, &_inner_error0_);
#line 902 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 902 "SerializableObjectModelTest.vala"
			_g_object_unref0 (unknown_property);
#line 902 "SerializableObjectModelTest.vala"
			_g_object_unref0 (doc);
#line 9641 "SerializableObjectModelTest.c"
			goto __catch332_g_error;
		}
#line 903 "SerializableObjectModelTest.vala"
		_tmp191_ = gxml_gdocument_new ();
#line 903 "SerializableObjectModelTest.vala"
		doc2 = _tmp191_;
#line 904 "SerializableObjectModelTest.vala"
		_tmp192_ = unknown_property;
#line 904 "SerializableObjectModelTest.vala"
		_tmp193_ = doc2;
#line 904 "SerializableObjectModelTest.vala"
		_tmp194_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp192_, (GXmlNode*) _tmp193_, &_inner_error0_);
#line 904 "SerializableObjectModelTest.vala"
		_tmp195_ = _tmp194_;
#line 904 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp195_);
#line 904 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 904 "SerializableObjectModelTest.vala"
			_g_object_unref0 (doc2);
#line 904 "SerializableObjectModelTest.vala"
			_g_object_unref0 (unknown_property);
#line 904 "SerializableObjectModelTest.vala"
			_g_object_unref0 (doc);
#line 9666 "SerializableObjectModelTest.c"
			goto __catch332_g_error;
		}
#line 914 "SerializableObjectModelTest.vala"
		_tmp196_ = doc2;
#line 914 "SerializableObjectModelTest.vala"
		_tmp197_ = gxml_document_get_root ((GXmlDocument*) _tmp196_);
#line 914 "SerializableObjectModelTest.vala"
		_tmp198_ = _tmp197_;
#line 914 "SerializableObjectModelTest.vala"
		_tmp199_ = _tmp198_;
#line 914 "SerializableObjectModelTest.vala"
		_vala_assert (_tmp199_ != NULL, "doc2.root != null");
#line 914 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp199_);
#line 915 "SerializableObjectModelTest.vala"
		_tmp200_ = doc;
#line 915 "SerializableObjectModelTest.vala"
		_tmp201_ = gxml_document_get_root ((GXmlDocument*) _tmp200_);
#line 915 "SerializableObjectModelTest.vala"
		_tmp202_ = _tmp201_;
#line 915 "SerializableObjectModelTest.vala"
		_tmp203_ = _tmp202_;
#line 915 "SerializableObjectModelTest.vala"
		_tmp204_ = gxml_node_get_name (_tmp203_);
#line 915 "SerializableObjectModelTest.vala"
		_tmp205_ = _tmp204_;
#line 915 "SerializableObjectModelTest.vala"
		_tmp206_ = _tmp205_;
#line 915 "SerializableObjectModelTest.vala"
		_vala_assert (g_strcmp0 (_tmp206_, "UnknownAttribute") == 0, "doc.root.name == \"UnknownAttribute\"");
#line 915 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp206_);
#line 915 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp203_);
#line 916 "SerializableObjectModelTest.vala"
		_tmp207_ = doc2;
#line 916 "SerializableObjectModelTest.vala"
		_tmp208_ = gxml_document_get_root ((GXmlDocument*) _tmp207_);
#line 916 "SerializableObjectModelTest.vala"
		_tmp209_ = _tmp208_;
#line 916 "SerializableObjectModelTest.vala"
		_tmp210_ = _tmp209_;
#line 916 "SerializableObjectModelTest.vala"
		_tmp211_ = gxml_node_get_children_nodes (_tmp210_);
#line 916 "SerializableObjectModelTest.vala"
		_tmp212_ = _tmp211_;
#line 916 "SerializableObjectModelTest.vala"
		_tmp213_ = _tmp212_;
#line 916 "SerializableObjectModelTest.vala"
		_tmp214_ = gee_collection_get_size ((GeeCollection*) _tmp213_);
#line 916 "SerializableObjectModelTest.vala"
		_tmp215_ = _tmp214_;
#line 916 "SerializableObjectModelTest.vala"
		_vala_assert (_tmp215_ == 3, "doc2.root.children_nodes.size == 3");
#line 916 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp213_);
#line 916 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp210_);
#line 917 "SerializableObjectModelTest.vala"
		_tmp216_ = doc2;
#line 917 "SerializableObjectModelTest.vala"
		_tmp217_ = gxml_document_get_root ((GXmlDocument*) _tmp216_);
#line 917 "SerializableObjectModelTest.vala"
		_tmp218_ = _tmp217_;
#line 917 "SerializableObjectModelTest.vala"
		_tmp219_ = _tmp218_;
#line 917 "SerializableObjectModelTest.vala"
		_tmp220_ = gxml_node_get_children_nodes (_tmp219_);
#line 917 "SerializableObjectModelTest.vala"
		_tmp221_ = _tmp220_;
#line 917 "SerializableObjectModelTest.vala"
		_tmp222_ = _tmp221_;
#line 917 "SerializableObjectModelTest.vala"
		_tmp223_ = gee_list_get ((GeeList*) _tmp222_, 1);
#line 917 "SerializableObjectModelTest.vala"
		_tmp224_ = (GXmlNode*) _tmp223_;
#line 917 "SerializableObjectModelTest.vala"
		_tmp225_ = gxml_node_get_name (_tmp224_);
#line 917 "SerializableObjectModelTest.vala"
		_tmp226_ = _tmp225_;
#line 917 "SerializableObjectModelTest.vala"
		_tmp227_ = _tmp226_;
#line 917 "SerializableObjectModelTest.vala"
		_vala_assert (g_strcmp0 (_tmp227_, "UnknownNode") == 0, "doc2.root.children_nodes[1].name == \"UnknownNode\"");
#line 917 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp227_);
#line 917 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp224_);
#line 917 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp222_);
#line 917 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp219_);
#line 918 "SerializableObjectModelTest.vala"
		_tmp228_ = doc2;
#line 918 "SerializableObjectModelTest.vala"
		_tmp229_ = gxml_document_get_root ((GXmlDocument*) _tmp228_);
#line 918 "SerializableObjectModelTest.vala"
		_tmp230_ = _tmp229_;
#line 918 "SerializableObjectModelTest.vala"
		_tmp231_ = _tmp230_;
#line 918 "SerializableObjectModelTest.vala"
		_tmp232_ = gxml_node_get_children_nodes (_tmp231_);
#line 918 "SerializableObjectModelTest.vala"
		_tmp233_ = _tmp232_;
#line 918 "SerializableObjectModelTest.vala"
		_tmp234_ = _tmp233_;
#line 918 "SerializableObjectModelTest.vala"
		_tmp235_ = gee_list_get ((GeeList*) _tmp234_, 1);
#line 918 "SerializableObjectModelTest.vala"
		_tmp236_ = (GXmlNode*) _tmp235_;
#line 918 "SerializableObjectModelTest.vala"
		_tmp237_ = gxml_node_get_children_nodes (_tmp236_);
#line 918 "SerializableObjectModelTest.vala"
		_tmp238_ = _tmp237_;
#line 918 "SerializableObjectModelTest.vala"
		_tmp239_ = _tmp238_;
#line 918 "SerializableObjectModelTest.vala"
		_tmp240_ = gee_collection_get_size ((GeeCollection*) _tmp239_);
#line 918 "SerializableObjectModelTest.vala"
		_tmp241_ = _tmp240_;
#line 918 "SerializableObjectModelTest.vala"
		_vala_assert (_tmp241_ == 3, "doc2.root.children_nodes[1].children_nodes.size == 3");
#line 918 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp239_);
#line 918 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp236_);
#line 918 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp234_);
#line 918 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp231_);
#line 919 "SerializableObjectModelTest.vala"
		_tmp242_ = doc2;
#line 919 "SerializableObjectModelTest.vala"
		_tmp243_ = gxml_document_get_root ((GXmlDocument*) _tmp242_);
#line 919 "SerializableObjectModelTest.vala"
		_tmp244_ = _tmp243_;
#line 919 "SerializableObjectModelTest.vala"
		_tmp245_ = _tmp244_;
#line 919 "SerializableObjectModelTest.vala"
		_tmp246_ = gxml_node_get_children_nodes (_tmp245_);
#line 919 "SerializableObjectModelTest.vala"
		_tmp247_ = _tmp246_;
#line 919 "SerializableObjectModelTest.vala"
		_tmp248_ = _tmp247_;
#line 919 "SerializableObjectModelTest.vala"
		_tmp249_ = gee_list_get ((GeeList*) _tmp248_, 2);
#line 919 "SerializableObjectModelTest.vala"
		_tmp250_ = (GXmlNode*) _tmp249_;
#line 919 "SerializableObjectModelTest.vala"
		_tmp251_ = gxml_node_get_value (_tmp250_);
#line 919 "SerializableObjectModelTest.vala"
		_tmp252_ = _tmp251_;
#line 919 "SerializableObjectModelTest.vala"
		_tmp253_ = _tmp252_;
#line 919 "SerializableObjectModelTest.vala"
		_vala_assert (g_strcmp0 (_tmp253_, "FAKE TEXT") == 0, "doc2.root.children_nodes[2].value == \"FAKE TEXT\"");
#line 919 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp253_);
#line 919 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp250_);
#line 919 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp248_);
#line 919 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp245_);
#line 920 "SerializableObjectModelTest.vala"
		_tmp254_ = doc2;
#line 920 "SerializableObjectModelTest.vala"
		_tmp255_ = gxml_document_get_root ((GXmlDocument*) _tmp254_);
#line 920 "SerializableObjectModelTest.vala"
		_tmp256_ = _tmp255_;
#line 920 "SerializableObjectModelTest.vala"
		_tmp257_ = _tmp256_;
#line 920 "SerializableObjectModelTest.vala"
		_tmp258_ = gxml_node_get_children_nodes (_tmp257_);
#line 920 "SerializableObjectModelTest.vala"
		_tmp259_ = _tmp258_;
#line 920 "SerializableObjectModelTest.vala"
		_tmp260_ = _tmp259_;
#line 920 "SerializableObjectModelTest.vala"
		_tmp261_ = gee_list_get ((GeeList*) _tmp260_, 1);
#line 920 "SerializableObjectModelTest.vala"
		_tmp262_ = (GXmlNode*) _tmp261_;
#line 920 "SerializableObjectModelTest.vala"
		_tmp263_ = gxml_node_get_children_nodes (_tmp262_);
#line 920 "SerializableObjectModelTest.vala"
		_tmp264_ = _tmp263_;
#line 920 "SerializableObjectModelTest.vala"
		_tmp265_ = _tmp264_;
#line 920 "SerializableObjectModelTest.vala"
		_tmp266_ = gee_list_get ((GeeList*) _tmp265_, 1);
#line 920 "SerializableObjectModelTest.vala"
		_tmp267_ = (GXmlNode*) _tmp266_;
#line 920 "SerializableObjectModelTest.vala"
		_tmp268_ = gxml_node_get_name (_tmp267_);
#line 920 "SerializableObjectModelTest.vala"
		_tmp269_ = _tmp268_;
#line 920 "SerializableObjectModelTest.vala"
		_tmp270_ = _tmp269_;
#line 920 "SerializableObjectModelTest.vala"
		_vala_assert (g_strcmp0 (_tmp270_, "UnknownChild") == 0, "doc2.root.children_nodes[1].children_nodes[1].name == \"UnknownChild\"");
#line 920 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp270_);
#line 920 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp267_);
#line 920 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp265_);
#line 920 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp262_);
#line 920 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp260_);
#line 920 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp257_);
#line 921 "SerializableObjectModelTest.vala"
		_tmp271_ = doc2;
#line 921 "SerializableObjectModelTest.vala"
		_tmp272_ = gxml_document_get_root ((GXmlDocument*) _tmp271_);
#line 921 "SerializableObjectModelTest.vala"
		_tmp273_ = _tmp272_;
#line 921 "SerializableObjectModelTest.vala"
		_tmp274_ = _tmp273_;
#line 921 "SerializableObjectModelTest.vala"
		_tmp275_ = gxml_node_get_children_nodes (_tmp274_);
#line 921 "SerializableObjectModelTest.vala"
		_tmp276_ = _tmp275_;
#line 921 "SerializableObjectModelTest.vala"
		_tmp277_ = _tmp276_;
#line 921 "SerializableObjectModelTest.vala"
		_tmp278_ = gee_list_get ((GeeList*) _tmp277_, 1);
#line 921 "SerializableObjectModelTest.vala"
		_tmp279_ = (GXmlNode*) _tmp278_;
#line 921 "SerializableObjectModelTest.vala"
		_tmp280_ = gxml_node_get_children_nodes (_tmp279_);
#line 921 "SerializableObjectModelTest.vala"
		_tmp281_ = _tmp280_;
#line 921 "SerializableObjectModelTest.vala"
		_tmp282_ = _tmp281_;
#line 921 "SerializableObjectModelTest.vala"
		_tmp283_ = gee_list_get ((GeeList*) _tmp282_, 1);
#line 921 "SerializableObjectModelTest.vala"
		_tmp284_ = (GXmlNode*) _tmp283_;
#line 921 "SerializableObjectModelTest.vala"
		_tmp285_ = gxml_node_get_children_nodes (_tmp284_);
#line 921 "SerializableObjectModelTest.vala"
		_tmp286_ = _tmp285_;
#line 921 "SerializableObjectModelTest.vala"
		_tmp287_ = _tmp286_;
#line 921 "SerializableObjectModelTest.vala"
		_tmp288_ = gee_list_get ((GeeList*) _tmp287_, 1);
#line 921 "SerializableObjectModelTest.vala"
		_tmp289_ = (GXmlNode*) _tmp288_;
#line 921 "SerializableObjectModelTest.vala"
		_tmp290_ = gxml_node_get_name (_tmp289_);
#line 921 "SerializableObjectModelTest.vala"
		_tmp291_ = _tmp290_;
#line 921 "SerializableObjectModelTest.vala"
		_tmp292_ = _tmp291_;
#line 921 "SerializableObjectModelTest.vala"
		_vala_assert (g_strcmp0 (_tmp292_, "UnknownChildTwo") == 0, "doc2.root.children_nodes[1].children_nodes[1].children_nodes[1].name == \"UnknownChildTwo\"");
#line 921 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp292_);
#line 921 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp289_);
#line 921 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp287_);
#line 921 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp284_);
#line 921 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp282_);
#line 921 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp279_);
#line 921 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp277_);
#line 921 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp274_);
#line 922 "SerializableObjectModelTest.vala"
		_tmp293_ = doc2;
#line 922 "SerializableObjectModelTest.vala"
		_tmp294_ = gxml_document_get_root ((GXmlDocument*) _tmp293_);
#line 922 "SerializableObjectModelTest.vala"
		_tmp295_ = _tmp294_;
#line 922 "SerializableObjectModelTest.vala"
		_tmp296_ = _tmp295_;
#line 922 "SerializableObjectModelTest.vala"
		_tmp297_ = gxml_node_get_children_nodes (_tmp296_);
#line 922 "SerializableObjectModelTest.vala"
		_tmp298_ = _tmp297_;
#line 922 "SerializableObjectModelTest.vala"
		_tmp299_ = _tmp298_;
#line 922 "SerializableObjectModelTest.vala"
		_tmp300_ = gee_list_get ((GeeList*) _tmp299_, 1);
#line 922 "SerializableObjectModelTest.vala"
		_tmp301_ = (GXmlNode*) _tmp300_;
#line 922 "SerializableObjectModelTest.vala"
		_tmp302_ = gxml_node_get_children_nodes (_tmp301_);
#line 922 "SerializableObjectModelTest.vala"
		_tmp303_ = _tmp302_;
#line 922 "SerializableObjectModelTest.vala"
		_tmp304_ = _tmp303_;
#line 922 "SerializableObjectModelTest.vala"
		_tmp305_ = gee_list_get ((GeeList*) _tmp304_, 1);
#line 922 "SerializableObjectModelTest.vala"
		_tmp306_ = (GXmlNode*) _tmp305_;
#line 922 "SerializableObjectModelTest.vala"
		_tmp307_ = gxml_node_get_children_nodes (_tmp306_);
#line 922 "SerializableObjectModelTest.vala"
		_tmp308_ = _tmp307_;
#line 922 "SerializableObjectModelTest.vala"
		_tmp309_ = _tmp308_;
#line 922 "SerializableObjectModelTest.vala"
		_tmp310_ = gee_collection_get_size ((GeeCollection*) _tmp309_);
#line 922 "SerializableObjectModelTest.vala"
		_tmp311_ = _tmp310_;
#line 922 "SerializableObjectModelTest.vala"
		_vala_assert (_tmp311_ == 3, "doc2.root.children_nodes[1].children_nodes[1].children_nodes.size == 3");
#line 922 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp309_);
#line 922 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp306_);
#line 922 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp304_);
#line 922 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp301_);
#line 922 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp299_);
#line 922 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp296_);
#line 923 "SerializableObjectModelTest.vala"
		_tmp312_ = doc2;
#line 923 "SerializableObjectModelTest.vala"
		_tmp313_ = gxml_document_get_root ((GXmlDocument*) _tmp312_);
#line 923 "SerializableObjectModelTest.vala"
		_tmp314_ = _tmp313_;
#line 923 "SerializableObjectModelTest.vala"
		_tmp315_ = _tmp314_;
#line 923 "SerializableObjectModelTest.vala"
		_tmp316_ = gxml_node_get_children_nodes (_tmp315_);
#line 923 "SerializableObjectModelTest.vala"
		_tmp317_ = _tmp316_;
#line 923 "SerializableObjectModelTest.vala"
		_tmp318_ = _tmp317_;
#line 923 "SerializableObjectModelTest.vala"
		_tmp319_ = gee_list_get ((GeeList*) _tmp318_, 1);
#line 923 "SerializableObjectModelTest.vala"
		_tmp320_ = (GXmlNode*) _tmp319_;
#line 923 "SerializableObjectModelTest.vala"
		_tmp321_ = gxml_node_get_children_nodes (_tmp320_);
#line 923 "SerializableObjectModelTest.vala"
		_tmp322_ = _tmp321_;
#line 923 "SerializableObjectModelTest.vala"
		_tmp323_ = _tmp322_;
#line 923 "SerializableObjectModelTest.vala"
		_tmp324_ = gee_list_get ((GeeList*) _tmp323_, 1);
#line 923 "SerializableObjectModelTest.vala"
		_tmp325_ = (GXmlNode*) _tmp324_;
#line 923 "SerializableObjectModelTest.vala"
		_tmp326_ = gxml_node_get_children_nodes (_tmp325_);
#line 923 "SerializableObjectModelTest.vala"
		_tmp327_ = _tmp326_;
#line 923 "SerializableObjectModelTest.vala"
		_tmp328_ = _tmp327_;
#line 923 "SerializableObjectModelTest.vala"
		_tmp329_ = gee_list_get ((GeeList*) _tmp328_, 1);
#line 923 "SerializableObjectModelTest.vala"
		_tmp330_ = (GXmlNode*) _tmp329_;
#line 923 "SerializableObjectModelTest.vala"
		_tmp331_ = gxml_node_get_children_nodes (_tmp330_);
#line 923 "SerializableObjectModelTest.vala"
		_tmp332_ = _tmp331_;
#line 923 "SerializableObjectModelTest.vala"
		_tmp333_ = _tmp332_;
#line 923 "SerializableObjectModelTest.vala"
		_tmp334_ = gee_collection_get_size ((GeeCollection*) _tmp333_);
#line 923 "SerializableObjectModelTest.vala"
		_tmp335_ = _tmp334_;
#line 923 "SerializableObjectModelTest.vala"
		_vala_assert (_tmp335_ == 1, "doc2.root.children_nodes[1].children_nodes[1].children_nodes[1].children_nodes.size == 1");
#line 923 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp333_);
#line 923 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp330_);
#line 923 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp328_);
#line 923 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp325_);
#line 923 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp323_);
#line 923 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp320_);
#line 923 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp318_);
#line 923 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp315_);
#line 924 "SerializableObjectModelTest.vala"
		_tmp336_ = doc2;
#line 924 "SerializableObjectModelTest.vala"
		_tmp337_ = gxml_document_get_root ((GXmlDocument*) _tmp336_);
#line 924 "SerializableObjectModelTest.vala"
		_tmp338_ = _tmp337_;
#line 924 "SerializableObjectModelTest.vala"
		_tmp339_ = _tmp338_;
#line 924 "SerializableObjectModelTest.vala"
		_tmp340_ = gxml_node_get_children_nodes (_tmp339_);
#line 924 "SerializableObjectModelTest.vala"
		_tmp341_ = _tmp340_;
#line 924 "SerializableObjectModelTest.vala"
		_tmp342_ = _tmp341_;
#line 924 "SerializableObjectModelTest.vala"
		_tmp343_ = gee_list_get ((GeeList*) _tmp342_, 1);
#line 924 "SerializableObjectModelTest.vala"
		_tmp344_ = (GXmlNode*) _tmp343_;
#line 924 "SerializableObjectModelTest.vala"
		_tmp345_ = gxml_node_get_children_nodes (_tmp344_);
#line 924 "SerializableObjectModelTest.vala"
		_tmp346_ = _tmp345_;
#line 924 "SerializableObjectModelTest.vala"
		_tmp347_ = _tmp346_;
#line 924 "SerializableObjectModelTest.vala"
		_tmp348_ = gee_list_get ((GeeList*) _tmp347_, 1);
#line 924 "SerializableObjectModelTest.vala"
		_tmp349_ = (GXmlNode*) _tmp348_;
#line 924 "SerializableObjectModelTest.vala"
		_tmp350_ = gxml_node_get_children_nodes (_tmp349_);
#line 924 "SerializableObjectModelTest.vala"
		_tmp351_ = _tmp350_;
#line 924 "SerializableObjectModelTest.vala"
		_tmp352_ = _tmp351_;
#line 924 "SerializableObjectModelTest.vala"
		_tmp353_ = gee_list_get ((GeeList*) _tmp352_, 1);
#line 924 "SerializableObjectModelTest.vala"
		_tmp354_ = (GXmlNode*) _tmp353_;
#line 924 "SerializableObjectModelTest.vala"
		_tmp355_ = gxml_node_get_children_nodes (_tmp354_);
#line 924 "SerializableObjectModelTest.vala"
		_tmp356_ = _tmp355_;
#line 924 "SerializableObjectModelTest.vala"
		_tmp357_ = _tmp356_;
#line 924 "SerializableObjectModelTest.vala"
		_tmp358_ = gee_list_get ((GeeList*) _tmp357_, 0);
#line 924 "SerializableObjectModelTest.vala"
		_tmp359_ = (GXmlNode*) _tmp358_;
#line 924 "SerializableObjectModelTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp359_, GXML_TYPE_TEXT), "doc2.root.children_nodes[1].children_nodes[1].children_nodes[1].children_nodes[0] is GXml.Text");
#line 924 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp359_);
#line 924 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp357_);
#line 924 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp354_);
#line 924 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp352_);
#line 924 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp349_);
#line 924 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp347_);
#line 924 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp344_);
#line 924 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp342_);
#line 924 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp339_);
#line 925 "SerializableObjectModelTest.vala"
		_tmp360_ = doc2;
#line 925 "SerializableObjectModelTest.vala"
		_tmp361_ = gxml_document_get_root ((GXmlDocument*) _tmp360_);
#line 925 "SerializableObjectModelTest.vala"
		_tmp362_ = _tmp361_;
#line 925 "SerializableObjectModelTest.vala"
		_tmp363_ = _tmp362_;
#line 925 "SerializableObjectModelTest.vala"
		_tmp364_ = gxml_node_get_children_nodes (_tmp363_);
#line 925 "SerializableObjectModelTest.vala"
		_tmp365_ = _tmp364_;
#line 925 "SerializableObjectModelTest.vala"
		_tmp366_ = _tmp365_;
#line 925 "SerializableObjectModelTest.vala"
		_tmp367_ = gee_list_get ((GeeList*) _tmp366_, 1);
#line 925 "SerializableObjectModelTest.vala"
		_tmp368_ = (GXmlNode*) _tmp367_;
#line 925 "SerializableObjectModelTest.vala"
		_tmp369_ = gxml_node_get_children_nodes (_tmp368_);
#line 925 "SerializableObjectModelTest.vala"
		_tmp370_ = _tmp369_;
#line 925 "SerializableObjectModelTest.vala"
		_tmp371_ = _tmp370_;
#line 925 "SerializableObjectModelTest.vala"
		_tmp372_ = gee_list_get ((GeeList*) _tmp371_, 1);
#line 925 "SerializableObjectModelTest.vala"
		_tmp373_ = (GXmlNode*) _tmp372_;
#line 925 "SerializableObjectModelTest.vala"
		_tmp374_ = gxml_node_get_children_nodes (_tmp373_);
#line 925 "SerializableObjectModelTest.vala"
		_tmp375_ = _tmp374_;
#line 925 "SerializableObjectModelTest.vala"
		_tmp376_ = _tmp375_;
#line 925 "SerializableObjectModelTest.vala"
		_tmp377_ = gee_list_get ((GeeList*) _tmp376_, 1);
#line 925 "SerializableObjectModelTest.vala"
		_tmp378_ = (GXmlNode*) _tmp377_;
#line 925 "SerializableObjectModelTest.vala"
		_tmp379_ = gxml_node_get_children_nodes (_tmp378_);
#line 925 "SerializableObjectModelTest.vala"
		_tmp380_ = _tmp379_;
#line 925 "SerializableObjectModelTest.vala"
		_tmp381_ = _tmp380_;
#line 925 "SerializableObjectModelTest.vala"
		_tmp382_ = gee_list_get ((GeeList*) _tmp381_, 0);
#line 925 "SerializableObjectModelTest.vala"
		_tmp383_ = (GXmlNode*) _tmp382_;
#line 925 "SerializableObjectModelTest.vala"
		_tmp384_ = gxml_node_get_value (_tmp383_);
#line 925 "SerializableObjectModelTest.vala"
		_tmp385_ = _tmp384_;
#line 925 "SerializableObjectModelTest.vala"
		_tmp386_ = _tmp385_;
#line 925 "SerializableObjectModelTest.vala"
		_vala_assert (g_strcmp0 (_tmp386_, "SECOND FAKE TEXT") == 0, "doc2.root.children_nodes[1].children_nodes[1].children_nodes[1].children_nodes[0].value == \"SECOND FAKE TEXT\"");
#line 925 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp386_);
#line 925 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp383_);
#line 925 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp381_);
#line 925 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp378_);
#line 925 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp376_);
#line 925 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp373_);
#line 925 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp371_);
#line 925 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp368_);
#line 925 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp366_);
#line 925 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp363_);
#line 882 "SerializableObjectModelTest.vala"
		_g_object_unref0 (doc2);
#line 882 "SerializableObjectModelTest.vala"
		_g_object_unref0 (unknown_property);
#line 882 "SerializableObjectModelTest.vala"
		_g_object_unref0 (doc);
#line 10209 "SerializableObjectModelTest.c"
	}
	goto __finally332;
	__catch332_g_error:
	{
		GError* e = NULL;
		FILE* _tmp387_;
		const gchar* _tmp388_;
		const gchar* _tmp389_;
		gchar* _tmp390_;
		gchar* _tmp391_;
#line 882 "SerializableObjectModelTest.vala"
		e = _inner_error0_;
#line 882 "SerializableObjectModelTest.vala"
		_inner_error0_ = NULL;
#line 928 "SerializableObjectModelTest.vala"
		_tmp387_ = stdout;
#line 928 "SerializableObjectModelTest.vala"
		_tmp388_ = e->message;
#line 928 "SerializableObjectModelTest.vala"
		_tmp389_ = string_to_string (_tmp388_);
#line 928 "SerializableObjectModelTest.vala"
		_tmp390_ = g_strconcat ("Error: ", _tmp389_, NULL);
#line 928 "SerializableObjectModelTest.vala"
		_tmp391_ = _tmp390_;
#line 928 "SerializableObjectModelTest.vala"
		fprintf (_tmp387_, "%s", _tmp391_);
#line 928 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp391_);
#line 929 "SerializableObjectModelTest.vala"
		g_assert_not_reached ();
#line 882 "SerializableObjectModelTest.vala"
		_g_error_free0 (e);
#line 10242 "SerializableObjectModelTest.c"
	}
	__finally332:
#line 882 "SerializableObjectModelTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 882 "SerializableObjectModelTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 882 "SerializableObjectModelTest.vala"
		g_clear_error (&_inner_error0_);
#line 882 "SerializableObjectModelTest.vala"
		return;
#line 10253 "SerializableObjectModelTest.c"
	}
}

static void
___lambda278__gtest_func (void)
{
#line 880 "SerializableObjectModelTest.vala"
	__lambda278_ ();
#line 10262 "SerializableObjectModelTest.c"
}

static void
__lambda279_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		UnknownAttribute* unknown_property = NULL;
		UnknownAttribute* _tmp1_;
		UnknownAttribute* _tmp2_;
		GXmlGDocument* _tmp3_;
		GXmlGDocument* ndoc = NULL;
		GXmlGDocument* _tmp4_;
		UnknownAttribute* _tmp5_;
		GXmlGDocument* _tmp6_;
		GXmlNode* _tmp7_;
		GXmlNode* _tmp8_;
		GXmlGDocument* _tmp9_;
		GXmlNode* _tmp10_;
		GXmlNode* _tmp11_;
		GXmlNode* _tmp12_;
		GeeBidirList* _tmp13_;
		GeeBidirList* _tmp14_;
		GeeBidirList* _tmp15_;
		gint _tmp16_;
		gint _tmp17_;
		gboolean _tmp18_;
#line 935 "SerializableObjectModelTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"<UnknownAttribute ignore=\"true\" ignore2=\"test\"><UnknownNode toigno" \
"re = \"true\" />TEXT</UnknownAttribute>", 0, &_inner_error0_);
#line 935 "SerializableObjectModelTest.vala"
		doc = _tmp0_;
#line 935 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 10298 "SerializableObjectModelTest.c"
			goto __catch333_g_error;
		}
#line 937 "SerializableObjectModelTest.vala"
		_tmp1_ = unknown_attribute_new ();
#line 937 "SerializableObjectModelTest.vala"
		unknown_property = _tmp1_;
#line 938 "SerializableObjectModelTest.vala"
		_tmp2_ = unknown_property;
#line 938 "SerializableObjectModelTest.vala"
		_tmp3_ = doc;
#line 938 "SerializableObjectModelTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 938 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 938 "SerializableObjectModelTest.vala"
			_g_object_unref0 (unknown_property);
#line 938 "SerializableObjectModelTest.vala"
			_g_object_unref0 (doc);
#line 10317 "SerializableObjectModelTest.c"
			goto __catch333_g_error;
		}
#line 939 "SerializableObjectModelTest.vala"
		_tmp4_ = gxml_gdocument_new ();
#line 939 "SerializableObjectModelTest.vala"
		ndoc = _tmp4_;
#line 940 "SerializableObjectModelTest.vala"
		_tmp5_ = unknown_property;
#line 940 "SerializableObjectModelTest.vala"
		_tmp6_ = ndoc;
#line 940 "SerializableObjectModelTest.vala"
		_tmp7_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp5_, (GXmlNode*) _tmp6_, &_inner_error0_);
#line 940 "SerializableObjectModelTest.vala"
		_tmp8_ = _tmp7_;
#line 940 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp8_);
#line 940 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 940 "SerializableObjectModelTest.vala"
			_g_object_unref0 (ndoc);
#line 940 "SerializableObjectModelTest.vala"
			_g_object_unref0 (unknown_property);
#line 940 "SerializableObjectModelTest.vala"
			_g_object_unref0 (doc);
#line 10342 "SerializableObjectModelTest.c"
			goto __catch333_g_error;
		}
#line 941 "SerializableObjectModelTest.vala"
		_tmp9_ = ndoc;
#line 941 "SerializableObjectModelTest.vala"
		_tmp10_ = gxml_document_get_root ((GXmlDocument*) _tmp9_);
#line 941 "SerializableObjectModelTest.vala"
		_tmp11_ = _tmp10_;
#line 941 "SerializableObjectModelTest.vala"
		_tmp12_ = _tmp11_;
#line 941 "SerializableObjectModelTest.vala"
		_tmp13_ = gxml_node_get_children_nodes (_tmp12_);
#line 941 "SerializableObjectModelTest.vala"
		_tmp14_ = _tmp13_;
#line 941 "SerializableObjectModelTest.vala"
		_tmp15_ = _tmp14_;
#line 941 "SerializableObjectModelTest.vala"
		_tmp16_ = gee_collection_get_size ((GeeCollection*) _tmp15_);
#line 941 "SerializableObjectModelTest.vala"
		_tmp17_ = _tmp16_;
#line 941 "SerializableObjectModelTest.vala"
		_tmp18_ = _tmp17_ != 2;
#line 941 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp15_);
#line 941 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp12_);
#line 941 "SerializableObjectModelTest.vala"
		if (_tmp18_) {
#line 10371 "SerializableObjectModelTest.c"
			FILE* _tmp19_;
			GXmlGDocument* _tmp20_;
			GXmlNode* _tmp21_;
			GXmlNode* _tmp22_;
			GXmlNode* _tmp23_;
			GeeBidirList* _tmp24_;
			GeeBidirList* _tmp25_;
			GeeBidirList* _tmp26_;
			gint _tmp27_;
			gint _tmp28_;
			gchar* _tmp29_;
			gchar* _tmp30_;
			gchar* _tmp31_;
			gchar* _tmp32_;
			FILE* _tmp64_;
			GXmlGDocument* _tmp65_;
			gchar* _tmp66_;
			gchar* _tmp67_;
			gchar* _tmp68_;
			gchar* _tmp69_;
#line 942 "SerializableObjectModelTest.vala"
			_tmp19_ = stdout;
#line 942 "SerializableObjectModelTest.vala"
			_tmp20_ = doc;
#line 942 "SerializableObjectModelTest.vala"
			_tmp21_ = gxml_document_get_root ((GXmlDocument*) _tmp20_);
#line 942 "SerializableObjectModelTest.vala"
			_tmp22_ = _tmp21_;
#line 942 "SerializableObjectModelTest.vala"
			_tmp23_ = _tmp22_;
#line 942 "SerializableObjectModelTest.vala"
			_tmp24_ = gxml_node_get_children_nodes (_tmp23_);
#line 942 "SerializableObjectModelTest.vala"
			_tmp25_ = _tmp24_;
#line 942 "SerializableObjectModelTest.vala"
			_tmp26_ = _tmp25_;
#line 942 "SerializableObjectModelTest.vala"
			_tmp27_ = gee_collection_get_size ((GeeCollection*) _tmp26_);
#line 942 "SerializableObjectModelTest.vala"
			_tmp28_ = _tmp27_;
#line 942 "SerializableObjectModelTest.vala"
			_tmp29_ = g_strdup_printf ("%i", _tmp28_);
#line 942 "SerializableObjectModelTest.vala"
			_tmp30_ = _tmp29_;
#line 942 "SerializableObjectModelTest.vala"
			_tmp31_ = g_strconcat ("ERROR: Root incorrect child node number: found '", _tmp30_, "\n", NULL);
#line 942 "SerializableObjectModelTest.vala"
			_tmp32_ = _tmp31_;
#line 942 "SerializableObjectModelTest.vala"
			fprintf (_tmp19_, "%s", _tmp32_);
#line 942 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp32_);
#line 942 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp30_);
#line 942 "SerializableObjectModelTest.vala"
			_g_object_unref0 (_tmp26_);
#line 942 "SerializableObjectModelTest.vala"
			_g_object_unref0 (_tmp23_);
#line 10430 "SerializableObjectModelTest.c"
			{
				GeeBidirList* _rn_list = NULL;
				GXmlGDocument* _tmp33_;
				GXmlNode* _tmp34_;
				GXmlNode* _tmp35_;
				GXmlNode* _tmp36_;
				GeeBidirList* _tmp37_;
				GeeBidirList* _tmp38_;
				GeeBidirList* _tmp39_;
				gint _rn_size = 0;
				GeeBidirList* _tmp40_;
				gint _tmp41_;
				gint _tmp42_;
				gint _rn_index = 0;
#line 943 "SerializableObjectModelTest.vala"
				_tmp33_ = ndoc;
#line 943 "SerializableObjectModelTest.vala"
				_tmp34_ = gxml_document_get_root ((GXmlDocument*) _tmp33_);
#line 943 "SerializableObjectModelTest.vala"
				_tmp35_ = _tmp34_;
#line 943 "SerializableObjectModelTest.vala"
				_tmp36_ = _tmp35_;
#line 943 "SerializableObjectModelTest.vala"
				_tmp37_ = gxml_node_get_children_nodes (_tmp36_);
#line 943 "SerializableObjectModelTest.vala"
				_tmp38_ = _tmp37_;
#line 943 "SerializableObjectModelTest.vala"
				_tmp39_ = _tmp38_;
#line 943 "SerializableObjectModelTest.vala"
				_g_object_unref0 (_tmp36_);
#line 943 "SerializableObjectModelTest.vala"
				_rn_list = _tmp39_;
#line 943 "SerializableObjectModelTest.vala"
				_tmp40_ = _rn_list;
#line 943 "SerializableObjectModelTest.vala"
				_tmp41_ = gee_collection_get_size ((GeeCollection*) _tmp40_);
#line 943 "SerializableObjectModelTest.vala"
				_tmp42_ = _tmp41_;
#line 943 "SerializableObjectModelTest.vala"
				_rn_size = _tmp42_;
#line 943 "SerializableObjectModelTest.vala"
				_rn_index = -1;
#line 943 "SerializableObjectModelTest.vala"
				while (TRUE) {
#line 10475 "SerializableObjectModelTest.c"
					GXmlNode* rn = NULL;
					GeeBidirList* _tmp43_;
					gpointer _tmp44_;
					gchar* nv = NULL;
					gchar* _tmp45_;
					GXmlNode* _tmp46_;
					gchar* _tmp47_;
					gchar* _tmp48_;
					gchar* _tmp49_;
					gboolean _tmp50_;
					FILE* _tmp54_;
					GXmlNode* _tmp55_;
					gchar* _tmp56_;
					gchar* _tmp57_;
					gchar* _tmp58_;
					const gchar* _tmp59_;
					const gchar* _tmp60_;
					const gchar* _tmp61_;
					gchar* _tmp62_;
					gchar* _tmp63_;
#line 943 "SerializableObjectModelTest.vala"
					_rn_index = _rn_index + 1;
#line 943 "SerializableObjectModelTest.vala"
					if (!(_rn_index < _rn_size)) {
#line 943 "SerializableObjectModelTest.vala"
						break;
#line 10502 "SerializableObjectModelTest.c"
					}
#line 943 "SerializableObjectModelTest.vala"
					_tmp43_ = _rn_list;
#line 943 "SerializableObjectModelTest.vala"
					_tmp44_ = gee_list_get ((GeeList*) _tmp43_, _rn_index);
#line 943 "SerializableObjectModelTest.vala"
					rn = (GXmlNode*) _tmp44_;
#line 944 "SerializableObjectModelTest.vala"
					_tmp45_ = g_strdup ("__NULL__");
#line 944 "SerializableObjectModelTest.vala"
					nv = _tmp45_;
#line 945 "SerializableObjectModelTest.vala"
					_tmp46_ = rn;
#line 945 "SerializableObjectModelTest.vala"
					_tmp47_ = gxml_node_get_value (_tmp46_);
#line 945 "SerializableObjectModelTest.vala"
					_tmp48_ = _tmp47_;
#line 945 "SerializableObjectModelTest.vala"
					_tmp49_ = _tmp48_;
#line 945 "SerializableObjectModelTest.vala"
					_tmp50_ = _tmp49_ != NULL;
#line 945 "SerializableObjectModelTest.vala"
					_g_free0 (_tmp49_);
#line 945 "SerializableObjectModelTest.vala"
					if (_tmp50_) {
#line 10528 "SerializableObjectModelTest.c"
						GXmlNode* _tmp51_;
						gchar* _tmp52_;
						gchar* _tmp53_;
#line 946 "SerializableObjectModelTest.vala"
						_tmp51_ = rn;
#line 946 "SerializableObjectModelTest.vala"
						_tmp52_ = gxml_node_get_value (_tmp51_);
#line 946 "SerializableObjectModelTest.vala"
						_tmp53_ = _tmp52_;
#line 946 "SerializableObjectModelTest.vala"
						_g_free0 (nv);
#line 946 "SerializableObjectModelTest.vala"
						nv = _tmp53_;
#line 10542 "SerializableObjectModelTest.c"
					}
#line 947 "SerializableObjectModelTest.vala"
					_tmp54_ = stdout;
#line 947 "SerializableObjectModelTest.vala"
					_tmp55_ = rn;
#line 947 "SerializableObjectModelTest.vala"
					_tmp56_ = gxml_node_get_name (_tmp55_);
#line 947 "SerializableObjectModelTest.vala"
					_tmp57_ = _tmp56_;
#line 947 "SerializableObjectModelTest.vala"
					_tmp58_ = _tmp57_;
#line 947 "SerializableObjectModelTest.vala"
					_tmp59_ = string_to_string (_tmp58_);
#line 947 "SerializableObjectModelTest.vala"
					_tmp60_ = nv;
#line 947 "SerializableObjectModelTest.vala"
					_tmp61_ = string_to_string (_tmp60_);
#line 947 "SerializableObjectModelTest.vala"
					_tmp62_ = g_strconcat ("Node: ", _tmp59_, " / Value: '", _tmp61_, "'\n", NULL);
#line 947 "SerializableObjectModelTest.vala"
					_tmp63_ = _tmp62_;
#line 947 "SerializableObjectModelTest.vala"
					fprintf (_tmp54_, "%s", _tmp63_);
#line 947 "SerializableObjectModelTest.vala"
					_g_free0 (_tmp63_);
#line 947 "SerializableObjectModelTest.vala"
					_g_free0 (_tmp58_);
#line 943 "SerializableObjectModelTest.vala"
					_g_free0 (nv);
#line 943 "SerializableObjectModelTest.vala"
					_g_object_unref0 (rn);
#line 10574 "SerializableObjectModelTest.c"
				}
#line 943 "SerializableObjectModelTest.vala"
				_g_object_unref0 (_rn_list);
#line 10578 "SerializableObjectModelTest.c"
			}
#line 949 "SerializableObjectModelTest.vala"
			_tmp64_ = stdout;
#line 949 "SerializableObjectModelTest.vala"
			_tmp65_ = ndoc;
#line 949 "SerializableObjectModelTest.vala"
			_tmp66_ = gxml_gnode_to_string ((GXmlGNode*) _tmp65_);
#line 949 "SerializableObjectModelTest.vala"
			_tmp67_ = _tmp66_;
#line 949 "SerializableObjectModelTest.vala"
			_tmp68_ = g_strconcat (_tmp67_, "\n", NULL);
#line 949 "SerializableObjectModelTest.vala"
			_tmp69_ = _tmp68_;
#line 949 "SerializableObjectModelTest.vala"
			fprintf (_tmp64_, "%s", _tmp69_);
#line 949 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp69_);
#line 949 "SerializableObjectModelTest.vala"
			_g_free0 (_tmp67_);
#line 950 "SerializableObjectModelTest.vala"
			g_assert_not_reached ();
#line 10600 "SerializableObjectModelTest.c"
		}
		{
			GeeBidirList* _n_list = NULL;
			GXmlGDocument* _tmp70_;
			GXmlNode* _tmp71_;
			GXmlNode* _tmp72_;
			GXmlNode* _tmp73_;
			GeeBidirList* _tmp74_;
			GeeBidirList* _tmp75_;
			GeeBidirList* _tmp76_;
			gint _n_size = 0;
			GeeBidirList* _tmp77_;
			gint _tmp78_;
			gint _tmp79_;
			gint _n_index = 0;
#line 952 "SerializableObjectModelTest.vala"
			_tmp70_ = ndoc;
#line 952 "SerializableObjectModelTest.vala"
			_tmp71_ = gxml_document_get_root ((GXmlDocument*) _tmp70_);
#line 952 "SerializableObjectModelTest.vala"
			_tmp72_ = _tmp71_;
#line 952 "SerializableObjectModelTest.vala"
			_tmp73_ = _tmp72_;
#line 952 "SerializableObjectModelTest.vala"
			_tmp74_ = gxml_node_get_children_nodes (_tmp73_);
#line 952 "SerializableObjectModelTest.vala"
			_tmp75_ = _tmp74_;
#line 952 "SerializableObjectModelTest.vala"
			_tmp76_ = _tmp75_;
#line 952 "SerializableObjectModelTest.vala"
			_g_object_unref0 (_tmp73_);
#line 952 "SerializableObjectModelTest.vala"
			_n_list = _tmp76_;
#line 952 "SerializableObjectModelTest.vala"
			_tmp77_ = _n_list;
#line 952 "SerializableObjectModelTest.vala"
			_tmp78_ = gee_collection_get_size ((GeeCollection*) _tmp77_);
#line 952 "SerializableObjectModelTest.vala"
			_tmp79_ = _tmp78_;
#line 952 "SerializableObjectModelTest.vala"
			_n_size = _tmp79_;
#line 952 "SerializableObjectModelTest.vala"
			_n_index = -1;
#line 952 "SerializableObjectModelTest.vala"
			while (TRUE) {
#line 10646 "SerializableObjectModelTest.c"
				GXmlNode* n = NULL;
				GeeBidirList* _tmp80_;
				gpointer _tmp81_;
				GXmlNode* _tmp82_;
#line 952 "SerializableObjectModelTest.vala"
				_n_index = _n_index + 1;
#line 952 "SerializableObjectModelTest.vala"
				if (!(_n_index < _n_size)) {
#line 952 "SerializableObjectModelTest.vala"
					break;
#line 10657 "SerializableObjectModelTest.c"
				}
#line 952 "SerializableObjectModelTest.vala"
				_tmp80_ = _n_list;
#line 952 "SerializableObjectModelTest.vala"
				_tmp81_ = gee_list_get ((GeeList*) _tmp80_, _n_index);
#line 952 "SerializableObjectModelTest.vala"
				n = (GXmlNode*) _tmp81_;
#line 953 "SerializableObjectModelTest.vala"
				_tmp82_ = n;
#line 953 "SerializableObjectModelTest.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp82_, GXML_TYPE_TEXT)) {
#line 10669 "SerializableObjectModelTest.c"
					GXmlNode* _tmp83_;
					gchar* _tmp84_;
					gchar* _tmp85_;
					gchar* _tmp86_;
					gboolean _tmp87_;
#line 954 "SerializableObjectModelTest.vala"
					_tmp83_ = n;
#line 954 "SerializableObjectModelTest.vala"
					_tmp84_ = gxml_node_get_value (_tmp83_);
#line 954 "SerializableObjectModelTest.vala"
					_tmp85_ = _tmp84_;
#line 954 "SerializableObjectModelTest.vala"
					_tmp86_ = _tmp85_;
#line 954 "SerializableObjectModelTest.vala"
					_tmp87_ = g_strcmp0 (_tmp86_, "TEXT") != 0;
#line 954 "SerializableObjectModelTest.vala"
					_g_free0 (_tmp86_);
#line 954 "SerializableObjectModelTest.vala"
					if (_tmp87_) {
#line 10689 "SerializableObjectModelTest.c"
						FILE* _tmp88_;
						GXmlNode* _tmp89_;
						gchar* _tmp90_;
						gchar* _tmp91_;
						gchar* _tmp92_;
						const gchar* _tmp93_;
						gchar* _tmp94_;
						gchar* _tmp95_;
#line 955 "SerializableObjectModelTest.vala"
						_tmp88_ = stdout;
#line 955 "SerializableObjectModelTest.vala"
						_tmp89_ = n;
#line 955 "SerializableObjectModelTest.vala"
						_tmp90_ = gxml_node_get_value (_tmp89_);
#line 955 "SerializableObjectModelTest.vala"
						_tmp91_ = _tmp90_;
#line 955 "SerializableObjectModelTest.vala"
						_tmp92_ = _tmp91_;
#line 955 "SerializableObjectModelTest.vala"
						_tmp93_ = string_to_string (_tmp92_);
#line 955 "SerializableObjectModelTest.vala"
						_tmp94_ = g_strconcat ("ERROR: Unknown Text GElement not set: found '", _tmp93_, "\n", NULL);
#line 955 "SerializableObjectModelTest.vala"
						_tmp95_ = _tmp94_;
#line 955 "SerializableObjectModelTest.vala"
						fprintf (_tmp88_, "%s", _tmp95_);
#line 955 "SerializableObjectModelTest.vala"
						_g_free0 (_tmp95_);
#line 955 "SerializableObjectModelTest.vala"
						_g_free0 (_tmp92_);
#line 956 "SerializableObjectModelTest.vala"
						g_assert_not_reached ();
#line 10722 "SerializableObjectModelTest.c"
					}
				}
#line 952 "SerializableObjectModelTest.vala"
				_g_object_unref0 (n);
#line 10727 "SerializableObjectModelTest.c"
			}
#line 952 "SerializableObjectModelTest.vala"
			_g_object_unref0 (_n_list);
#line 10731 "SerializableObjectModelTest.c"
		}
#line 934 "SerializableObjectModelTest.vala"
		_g_object_unref0 (ndoc);
#line 934 "SerializableObjectModelTest.vala"
		_g_object_unref0 (unknown_property);
#line 934 "SerializableObjectModelTest.vala"
		_g_object_unref0 (doc);
#line 10739 "SerializableObjectModelTest.c"
	}
	goto __finally333;
	__catch333_g_error:
	{
		GError* e = NULL;
		FILE* _tmp96_;
		const gchar* _tmp97_;
		const gchar* _tmp98_;
		gchar* _tmp99_;
		gchar* _tmp100_;
#line 934 "SerializableObjectModelTest.vala"
		e = _inner_error0_;
#line 934 "SerializableObjectModelTest.vala"
		_inner_error0_ = NULL;
#line 961 "SerializableObjectModelTest.vala"
		_tmp96_ = stdout;
#line 961 "SerializableObjectModelTest.vala"
		_tmp97_ = e->message;
#line 961 "SerializableObjectModelTest.vala"
		_tmp98_ = string_to_string (_tmp97_);
#line 961 "SerializableObjectModelTest.vala"
		_tmp99_ = g_strconcat ("ERROR: ", _tmp98_, "\n", NULL);
#line 961 "SerializableObjectModelTest.vala"
		_tmp100_ = _tmp99_;
#line 961 "SerializableObjectModelTest.vala"
		fprintf (_tmp96_, "%s", _tmp100_);
#line 961 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp100_);
#line 962 "SerializableObjectModelTest.vala"
		g_assert_not_reached ();
#line 934 "SerializableObjectModelTest.vala"
		_g_error_free0 (e);
#line 10772 "SerializableObjectModelTest.c"
	}
	__finally333:
#line 934 "SerializableObjectModelTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 934 "SerializableObjectModelTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 934 "SerializableObjectModelTest.vala"
		g_clear_error (&_inner_error0_);
#line 934 "SerializableObjectModelTest.vala"
		return;
#line 10783 "SerializableObjectModelTest.c"
	}
}

static void
___lambda279__gtest_func (void)
{
#line 932 "SerializableObjectModelTest.vala"
	__lambda279_ ();
#line 10792 "SerializableObjectModelTest.c"
}

static void
__lambda280_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlGDocument* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		Package* pkg = NULL;
		Package* _tmp6_;
		Package* _tmp7_;
		GXmlGDocument* _tmp8_;
#line 968 "SerializableObjectModelTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                            <PACKAGE source=\"Mexico/North\" destiny=\"" \
"Brazil\" Hope=\"2/4.04\">\n" \
"                            <manual document=\"Sales Card\" pages=\"1\"" \
">Selling Card Specification</manual>\n" \
"                            <Computer manufacturer=\"BoxingLAN\" model" \
"=\"J24-EX9\" cores=\"32.5\" ghz=\"1.8\" quantity=\"0.2\" />\n" \
"                            <Box size=\"1\" volume=\"33.15\" units=\"c" \
"m3\" />\n" \
"                            </PACKAGE>", 0, &_inner_error0_);
#line 968 "SerializableObjectModelTest.vala"
		doc = _tmp0_;
#line 968 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 10817 "SerializableObjectModelTest.c"
			goto __catch334_g_error;
		}
#line 975 "SerializableObjectModelTest.vala"
		_tmp1_ = doc;
#line 975 "SerializableObjectModelTest.vala"
		_tmp2_ = gxml_gnode_to_string ((GXmlGNode*) _tmp1_);
#line 975 "SerializableObjectModelTest.vala"
		_tmp3_ = _tmp2_;
#line 975 "SerializableObjectModelTest.vala"
		_tmp4_ = g_strconcat ("XML:\n", _tmp3_, NULL);
#line 975 "SerializableObjectModelTest.vala"
		_tmp5_ = _tmp4_;
#line 975 "SerializableObjectModelTest.vala"
		g_test_message ("%s", _tmp5_);
#line 975 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp5_);
#line 975 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp3_);
#line 976 "SerializableObjectModelTest.vala"
		_tmp6_ = package_new ();
#line 976 "SerializableObjectModelTest.vala"
		pkg = _tmp6_;
#line 977 "SerializableObjectModelTest.vala"
		_tmp7_ = pkg;
#line 977 "SerializableObjectModelTest.vala"
		_tmp8_ = doc;
#line 977 "SerializableObjectModelTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp7_, (GXmlNode*) _tmp8_, &_inner_error0_);
#line 977 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 977 "SerializableObjectModelTest.vala"
			_g_object_unref0 (pkg);
#line 977 "SerializableObjectModelTest.vala"
			_g_object_unref0 (doc);
#line 10852 "SerializableObjectModelTest.c"
			goto __catch334_g_error;
		}
#line 967 "SerializableObjectModelTest.vala"
		_g_object_unref0 (pkg);
#line 967 "SerializableObjectModelTest.vala"
		_g_object_unref0 (doc);
#line 10859 "SerializableObjectModelTest.c"
	}
	goto __finally334;
	__catch334_g_error:
	{
		GError* e = NULL;
#line 967 "SerializableObjectModelTest.vala"
		e = _inner_error0_;
#line 967 "SerializableObjectModelTest.vala"
		_inner_error0_ = NULL;
#line 980 "SerializableObjectModelTest.vala"
		g_test_message ("Error thrown for invalid string to guint");
#line 981 "SerializableObjectModelTest.vala"
		g_assert_not_reached ();
#line 967 "SerializableObjectModelTest.vala"
		_g_error_free0 (e);
#line 10875 "SerializableObjectModelTest.c"
	}
	__finally334:
#line 967 "SerializableObjectModelTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 967 "SerializableObjectModelTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 967 "SerializableObjectModelTest.vala"
		g_clear_error (&_inner_error0_);
#line 967 "SerializableObjectModelTest.vala"
		return;
#line 10886 "SerializableObjectModelTest.c"
	}
}

static void
___lambda280__gtest_func (void)
{
#line 965 "SerializableObjectModelTest.vala"
	__lambda280_ ();
#line 10895 "SerializableObjectModelTest.c"
}

static void
__lambda281_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		NameSpace* ns = NULL;
		NameSpace* _tmp0_;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_;
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		GXmlNode* _tmp8_;
		GXmlNode* _tmp9_;
		GXmlNode* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
#line 987 "SerializableObjectModelTest.vala"
		_tmp0_ = name_space_new ();
#line 987 "SerializableObjectModelTest.vala"
		ns = _tmp0_;
#line 988 "SerializableObjectModelTest.vala"
		_tmp1_ = gxml_gdocument_new ();
#line 988 "SerializableObjectModelTest.vala"
		doc = _tmp1_;
#line 989 "SerializableObjectModelTest.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) ns, (GXmlNode*) doc, &_inner_error0_);
#line 989 "SerializableObjectModelTest.vala"
		_tmp3_ = _tmp2_;
#line 989 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp3_);
#line 989 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 989 "SerializableObjectModelTest.vala"
			_g_object_unref0 (doc);
#line 989 "SerializableObjectModelTest.vala"
			_g_object_unref0 (ns);
#line 10938 "SerializableObjectModelTest.c"
			goto __catch335_g_error;
		}
#line 990 "SerializableObjectModelTest.vala"
		_tmp4_ = gxml_gnode_to_string ((GXmlGNode*) doc);
#line 990 "SerializableObjectModelTest.vala"
		_tmp5_ = _tmp4_;
#line 990 "SerializableObjectModelTest.vala"
		_tmp6_ = g_strconcat ("DOC ROOT: ", _tmp5_, NULL);
#line 990 "SerializableObjectModelTest.vala"
		_tmp7_ = _tmp6_;
#line 990 "SerializableObjectModelTest.vala"
		g_test_message ("%s", _tmp7_);
#line 990 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp7_);
#line 990 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp5_);
#line 991 "SerializableObjectModelTest.vala"
		_tmp8_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 991 "SerializableObjectModelTest.vala"
		_tmp9_ = _tmp8_;
#line 991 "SerializableObjectModelTest.vala"
		_tmp10_ = _tmp9_;
#line 991 "SerializableObjectModelTest.vala"
		_tmp11_ = gxml_node_to_string (_tmp10_);
#line 991 "SerializableObjectModelTest.vala"
		_tmp12_ = _tmp11_;
#line 991 "SerializableObjectModelTest.vala"
		_vala_assert (g_strcmp0 (_tmp12_, "<namespace xmlns:gxml=\"http://www.gnome.org/GXml\"/>") == 0, "doc.root.to_string () == \"<namespace xmlns:gxml=\\\"http://www.gnome.org/GXml\\\"/>\"");
#line 991 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp12_);
#line 991 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp10_);
#line 986 "SerializableObjectModelTest.vala"
		_g_object_unref0 (doc);
#line 986 "SerializableObjectModelTest.vala"
		_g_object_unref0 (ns);
#line 10975 "SerializableObjectModelTest.c"
	}
	goto __finally335;
	__catch335_g_error:
	{
		GError* e = NULL;
#line 986 "SerializableObjectModelTest.vala"
		e = _inner_error0_;
#line 986 "SerializableObjectModelTest.vala"
		_inner_error0_ = NULL;
#line 996 "SerializableObjectModelTest.vala"
		g_assert_not_reached ();
#line 986 "SerializableObjectModelTest.vala"
		_g_error_free0 (e);
#line 10989 "SerializableObjectModelTest.c"
	}
	__finally335:
#line 986 "SerializableObjectModelTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 986 "SerializableObjectModelTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 986 "SerializableObjectModelTest.vala"
		g_clear_error (&_inner_error0_);
#line 986 "SerializableObjectModelTest.vala"
		return;
#line 11000 "SerializableObjectModelTest.c"
	}
}

static void
___lambda281__gtest_func (void)
{
#line 985 "SerializableObjectModelTest.vala"
	__lambda281_ ();
#line 11009 "SerializableObjectModelTest.c"
}

static void
__lambda282_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		Package* p = NULL;
		Package* _tmp0_;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_;
		Package* _tmp2_;
		GXmlGDocument* _tmp3_;
		Package* _tmp4_;
		GeeMap* _tmp5_;
		GeeMap* _tmp6_;
		GeeMap* _tmp7_;
		GXmlAttribute* ukattr = NULL;
		Package* _tmp8_;
		GeeMap* _tmp9_;
		GeeMap* _tmp10_;
		GeeMap* _tmp11_;
		gpointer _tmp12_;
		GXmlAttribute* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		gchar* _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_;
		gchar* _tmp19_;
#line 1001 "SerializableObjectModelTest.vala"
		_tmp0_ = package_new ();
#line 1001 "SerializableObjectModelTest.vala"
		p = _tmp0_;
#line 1002 "SerializableObjectModelTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"<PACKAGE source=\"Mexico/North\" destiny=\"Brazil\" Unknown=\"2/4.04\"" \
">\n" \
"<manual document=\"Sales Card\" pages=\"1\">Selling Card Specification" \
"</manual>\n" \
"<Computer manufacturer=\"BoxingLAN\" model=\"J24-EX9\" cores=\"32\" gh" \
"z=\"1.8\"/>\n" \
"<Box size=\"1\" volume=\"33.15\" units=\"cm3\" />\n" \
"UNKNOWN CONTENT\n" \
"</PACKAGE>", 0, &_inner_error0_);
#line 1002 "SerializableObjectModelTest.vala"
		doc = _tmp1_;
#line 1002 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1002 "SerializableObjectModelTest.vala"
			_g_object_unref0 (p);
#line 11052 "SerializableObjectModelTest.c"
			goto __catch336_g_error;
		}
#line 1009 "SerializableObjectModelTest.vala"
		_tmp2_ = p;
#line 1009 "SerializableObjectModelTest.vala"
		_tmp3_ = doc;
#line 1009 "SerializableObjectModelTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 1009 "SerializableObjectModelTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1009 "SerializableObjectModelTest.vala"
			_g_object_unref0 (doc);
#line 1009 "SerializableObjectModelTest.vala"
			_g_object_unref0 (p);
#line 11067 "SerializableObjectModelTest.c"
			goto __catch336_g_error;
		}
#line 1010 "SerializableObjectModelTest.vala"
		_tmp4_ = p;
#line 1010 "SerializableObjectModelTest.vala"
		_tmp5_ = gxml_serializable_get_unknown_serializable_properties ((GXmlSerializable*) _tmp4_);
#line 1010 "SerializableObjectModelTest.vala"
		_tmp6_ = _tmp5_;
#line 1010 "SerializableObjectModelTest.vala"
		_tmp7_ = _tmp6_;
#line 1010 "SerializableObjectModelTest.vala"
		_vala_assert (_tmp7_ != NULL, "p.unknown_serializable_properties != null");
#line 1010 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp7_);
#line 1011 "SerializableObjectModelTest.vala"
		_tmp8_ = p;
#line 1011 "SerializableObjectModelTest.vala"
		_tmp9_ = gxml_serializable_get_unknown_serializable_properties ((GXmlSerializable*) _tmp8_);
#line 1011 "SerializableObjectModelTest.vala"
		_tmp10_ = _tmp9_;
#line 1011 "SerializableObjectModelTest.vala"
		_tmp11_ = _tmp10_;
#line 1011 "SerializableObjectModelTest.vala"
		_tmp12_ = gee_map_get (_tmp11_, "Unknown");
#line 1011 "SerializableObjectModelTest.vala"
		_tmp13_ = (GXmlAttribute*) _tmp12_;
#line 1011 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_tmp11_);
#line 1011 "SerializableObjectModelTest.vala"
		ukattr = _tmp13_;
#line 1012 "SerializableObjectModelTest.vala"
		_vala_assert (ukattr != NULL, "ukattr != null");
#line 1013 "SerializableObjectModelTest.vala"
		_tmp14_ = gxml_node_get_name ((GXmlNode*) ukattr);
#line 1013 "SerializableObjectModelTest.vala"
		_tmp15_ = _tmp14_;
#line 1013 "SerializableObjectModelTest.vala"
		_tmp16_ = _tmp15_;
#line 1013 "SerializableObjectModelTest.vala"
		_vala_assert (g_strcmp0 (_tmp16_, "Unknown") == 0, "ukattr.name == \"Unknown\"");
#line 1013 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp16_);
#line 1014 "SerializableObjectModelTest.vala"
		_tmp17_ = gxml_node_get_value ((GXmlNode*) ukattr);
#line 1014 "SerializableObjectModelTest.vala"
		_tmp18_ = _tmp17_;
#line 1014 "SerializableObjectModelTest.vala"
		_tmp19_ = _tmp18_;
#line 1014 "SerializableObjectModelTest.vala"
		_vala_assert (g_strcmp0 (_tmp19_, "2/4.04") == 0, "ukattr.value == \"2/4.04\"");
#line 1014 "SerializableObjectModelTest.vala"
		_g_free0 (_tmp19_);
#line 1000 "SerializableObjectModelTest.vala"
		_g_object_unref0 (ukattr);
#line 1000 "SerializableObjectModelTest.vala"
		_g_object_unref0 (doc);
#line 1000 "SerializableObjectModelTest.vala"
		_g_object_unref0 (p);
#line 11126 "SerializableObjectModelTest.c"
	}
	goto __finally336;
	__catch336_g_error:
	{
		GError* e = NULL;
#line 1000 "SerializableObjectModelTest.vala"
		e = _inner_error0_;
#line 1000 "SerializableObjectModelTest.vala"
		_inner_error0_ = NULL;
#line 1019 "SerializableObjectModelTest.vala"
		g_assert_not_reached ();
#line 1000 "SerializableObjectModelTest.vala"
		_g_error_free0 (e);
#line 11140 "SerializableObjectModelTest.c"
	}
	__finally336:
#line 1000 "SerializableObjectModelTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1000 "SerializableObjectModelTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 1000 "SerializableObjectModelTest.vala"
		g_clear_error (&_inner_error0_);
#line 1000 "SerializableObjectModelTest.vala"
		return;
#line 11151 "SerializableObjectModelTest.c"
	}
}

static void
___lambda282__gtest_func (void)
{
#line 999 "SerializableObjectModelTest.vala"
	__lambda282_ ();
#line 11160 "SerializableObjectModelTest.c"
}

void
serializable_object_model_test_add_tests (void)
{
#line 313 "SerializableObjectModelTest.vala"
	g_test_add_func ("/gxml/serializable/object_model/serialize/simple_object", ___lambda264__gtest_func);
#line 355 "SerializableObjectModelTest.vala"
	g_test_add_func ("/gxml/serializable/object_model/deserialize_simple_object", ___lambda265__gtest_func);
#line 384 "SerializableObjectModelTest.vala"
	g_test_add_func ("/gxml/serializable/object_model/deserialize_object_contents", ___lambda266__gtest_func);
#line 410 "SerializableObjectModelTest.vala"
	g_test_add_func ("/gxml/serializable/object_model/serialize_object_contents", ___lambda267__gtest_func);
#line 426 "SerializableObjectModelTest.vala"
	g_test_add_func ("/gxml/serializable/object_model/deserialize_serializable_properties", ___lambda268__gtest_func);
#line 479 "SerializableObjectModelTest.vala"
	g_test_add_func ("/gxml/serializable/object_model/serialize_serializable_properties", ___lambda269__gtest_func);
#line 509 "SerializableObjectModelTest.vala"
	g_test_add_func ("/gxml/serializable/object_model/deserialize_array_property", ___lambda270__gtest_func);
#line 537 "SerializableObjectModelTest.vala"
	g_test_add_func ("/gxml/serializable/object_model/serialize_array_property", ___lambda271__gtest_func);
#line 584 "SerializableObjectModelTest.vala"
	g_test_add_func ("/gxml/serializable/object_model/serialize_property_nick", ___lambda272__gtest_func);
#line 713 "SerializableObjectModelTest.vala"
	g_test_add_func ("/gxml/serializable/object_model/override_serialize", ___lambda273__gtest_func);
#line 755 "SerializableObjectModelTest.vala"
	g_test_add_func ("/gxml/serializable/object_model/override_deserialize", ___lambda274__gtest_func);
#line 783 "SerializableObjectModelTest.vala"
	g_test_add_func ("/gxml/serializable/object_model/custome_node_name", ___lambda275__gtest_func);
#line 795 "SerializableObjectModelTest.vala"
	g_test_add_func ("/gxml/serializable/object_model/no_serialize_null_property", ___lambda276__gtest_func);
#line 822 "SerializableObjectModelTest.vala"
	g_test_add_func ("/gxml/serializable/object_model/unknown_property", ___lambda277__gtest_func);
#line 880 "SerializableObjectModelTest.vala"
	g_test_add_func ("/gxml/serializable/object_model/deserialize_unknown_property", ___lambda278__gtest_func);
#line 932 "SerializableObjectModelTest.vala"
	g_test_add_func ("/gxml/serializable/object_model/serialize_unknown_property", ___lambda279__gtest_func);
#line 965 "SerializableObjectModelTest.vala"
	g_test_add_func ("/gxml/serializable/object_model/deserialize_incorrect_uint", ___lambda280__gtest_func);
#line 985 "SerializableObjectModelTest.vala"
	g_test_add_func ("/gxml/serializable/object_model/set_namespace", ___lambda281__gtest_func);
#line 999 "SerializableObjectModelTest.vala"
	g_test_add_func ("/gxml/serializable/object_model/find-unknown_property", ___lambda282__gtest_func);
#line 11204 "SerializableObjectModelTest.c"
}

static void
serializable_object_model_test_serialize_manual_check (GXmlGElement* element,
                                                       Manual* manual)
{
	GXmlNode* document = NULL;
	GXmlNode* _tmp0_;
	GXmlNode* _tmp1_;
	GXmlNode* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	GXmlNode* pages = NULL;
	GXmlNode* _tmp8_;
	GXmlNode* _tmp9_;
	GXmlNode* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	gint _tmp14_;
	gint _tmp15_;
	gboolean found = FALSE;
#line 1023 "SerializableObjectModelTest.vala"
	g_return_if_fail (element != NULL);
#line 1023 "SerializableObjectModelTest.vala"
	g_return_if_fail (manual != NULL);
#line 1024 "SerializableObjectModelTest.vala"
	_tmp0_ = gxml_element_get_attr ((GXmlElement*) element, "document");
#line 1024 "SerializableObjectModelTest.vala"
	document = _tmp0_;
#line 1025 "SerializableObjectModelTest.vala"
	_tmp1_ = document;
#line 1025 "SerializableObjectModelTest.vala"
	_vala_assert (_tmp1_ != NULL, "document != null");
#line 1026 "SerializableObjectModelTest.vala"
	_tmp2_ = document;
#line 1026 "SerializableObjectModelTest.vala"
	_tmp3_ = gxml_node_get_value (_tmp2_);
#line 1026 "SerializableObjectModelTest.vala"
	_tmp4_ = _tmp3_;
#line 1026 "SerializableObjectModelTest.vala"
	_tmp5_ = _tmp4_;
#line 1026 "SerializableObjectModelTest.vala"
	_tmp6_ = manual_get_document (manual);
#line 1026 "SerializableObjectModelTest.vala"
	_tmp7_ = _tmp6_;
#line 1026 "SerializableObjectModelTest.vala"
	_vala_assert (g_strcmp0 (_tmp5_, _tmp7_) == 0, "document.value == manual.document");
#line 1026 "SerializableObjectModelTest.vala"
	_g_free0 (_tmp5_);
#line 1027 "SerializableObjectModelTest.vala"
	_tmp8_ = gxml_element_get_attr ((GXmlElement*) element, "pages");
#line 1027 "SerializableObjectModelTest.vala"
	pages = _tmp8_;
#line 1028 "SerializableObjectModelTest.vala"
	_tmp9_ = pages;
#line 1028 "SerializableObjectModelTest.vala"
	_vala_assert (_tmp9_ != NULL, "pages != null");
#line 1029 "SerializableObjectModelTest.vala"
	_tmp10_ = pages;
#line 1029 "SerializableObjectModelTest.vala"
	_tmp11_ = gxml_node_get_value (_tmp10_);
#line 1029 "SerializableObjectModelTest.vala"
	_tmp12_ = _tmp11_;
#line 1029 "SerializableObjectModelTest.vala"
	_tmp13_ = _tmp12_;
#line 1029 "SerializableObjectModelTest.vala"
	_tmp14_ = manual_get_pages (manual);
#line 1029 "SerializableObjectModelTest.vala"
	_tmp15_ = _tmp14_;
#line 1029 "SerializableObjectModelTest.vala"
	_vala_assert (atoi (_tmp13_) == _tmp15_, "int.parse (pages.value) == manual.pages");
#line 1029 "SerializableObjectModelTest.vala"
	_g_free0 (_tmp13_);
#line 1030 "SerializableObjectModelTest.vala"
	found = FALSE;
#line 11284 "SerializableObjectModelTest.c"
	{
		GeeBidirList* _n_list = NULL;
		GeeBidirList* _tmp16_;
		GeeBidirList* _tmp17_;
		gint _n_size = 0;
		GeeBidirList* _tmp18_;
		gint _tmp19_;
		gint _tmp20_;
		gint _n_index = 0;
#line 1031 "SerializableObjectModelTest.vala"
		_tmp16_ = gxml_gnode_get_children_nodes ((GXmlGNode*) element);
#line 1031 "SerializableObjectModelTest.vala"
		_tmp17_ = _tmp16_;
#line 1031 "SerializableObjectModelTest.vala"
		_n_list = _tmp17_;
#line 1031 "SerializableObjectModelTest.vala"
		_tmp18_ = _n_list;
#line 1031 "SerializableObjectModelTest.vala"
		_tmp19_ = gee_collection_get_size ((GeeCollection*) _tmp18_);
#line 1031 "SerializableObjectModelTest.vala"
		_tmp20_ = _tmp19_;
#line 1031 "SerializableObjectModelTest.vala"
		_n_size = _tmp20_;
#line 1031 "SerializableObjectModelTest.vala"
		_n_index = -1;
#line 1031 "SerializableObjectModelTest.vala"
		while (TRUE) {
#line 11312 "SerializableObjectModelTest.c"
			GXmlNode* n = NULL;
			GeeBidirList* _tmp21_;
			gpointer _tmp22_;
			GXmlNode* _tmp23_;
#line 1031 "SerializableObjectModelTest.vala"
			_n_index = _n_index + 1;
#line 1031 "SerializableObjectModelTest.vala"
			if (!(_n_index < _n_size)) {
#line 1031 "SerializableObjectModelTest.vala"
				break;
#line 11323 "SerializableObjectModelTest.c"
			}
#line 1031 "SerializableObjectModelTest.vala"
			_tmp21_ = _n_list;
#line 1031 "SerializableObjectModelTest.vala"
			_tmp22_ = gee_list_get ((GeeList*) _tmp21_, _n_index);
#line 1031 "SerializableObjectModelTest.vala"
			n = (GXmlNode*) _tmp22_;
#line 1032 "SerializableObjectModelTest.vala"
			_tmp23_ = n;
#line 1032 "SerializableObjectModelTest.vala"
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, GXML_TYPE_TEXT)) {
#line 11335 "SerializableObjectModelTest.c"
				GXmlNode* _tmp24_;
				gchar* _tmp25_;
				gchar* _tmp26_;
				gchar* _tmp27_;
				gchar* _tmp28_;
				gchar* _tmp29_;
				gboolean _tmp30_;
#line 1033 "SerializableObjectModelTest.vala"
				_tmp24_ = n;
#line 1033 "SerializableObjectModelTest.vala"
				_tmp25_ = gxml_node_get_value (_tmp24_);
#line 1033 "SerializableObjectModelTest.vala"
				_tmp26_ = _tmp25_;
#line 1033 "SerializableObjectModelTest.vala"
				_tmp27_ = _tmp26_;
#line 1033 "SerializableObjectModelTest.vala"
				_tmp28_ = manual_get_contents (manual);
#line 1033 "SerializableObjectModelTest.vala"
				_tmp29_ = _tmp28_;
#line 1033 "SerializableObjectModelTest.vala"
				_tmp30_ = g_strcmp0 (_tmp27_, _tmp29_) == 0;
#line 1033 "SerializableObjectModelTest.vala"
				_g_free0 (_tmp29_);
#line 1033 "SerializableObjectModelTest.vala"
				_g_free0 (_tmp27_);
#line 1033 "SerializableObjectModelTest.vala"
				if (_tmp30_) {
#line 1033 "SerializableObjectModelTest.vala"
					found = TRUE;
#line 11365 "SerializableObjectModelTest.c"
				}
			}
#line 1031 "SerializableObjectModelTest.vala"
			_g_object_unref0 (n);
#line 11370 "SerializableObjectModelTest.c"
		}
#line 1031 "SerializableObjectModelTest.vala"
		_g_object_unref0 (_n_list);
#line 11374 "SerializableObjectModelTest.c"
	}
#line 1035 "SerializableObjectModelTest.vala"
	_vala_assert (found, "found");
#line 1023 "SerializableObjectModelTest.vala"
	_g_object_unref0 (pages);
#line 1023 "SerializableObjectModelTest.vala"
	_g_object_unref0 (document);
#line 11382 "SerializableObjectModelTest.c"
}

SerializableObjectModelTest*
serializable_object_model_test_construct (GType object_type)
{
	SerializableObjectModelTest* self = NULL;
#line 309 "SerializableObjectModelTest.vala"
	self = (SerializableObjectModelTest*) gxml_test_construct (object_type);
#line 309 "SerializableObjectModelTest.vala"
	return self;
#line 11393 "SerializableObjectModelTest.c"
}

SerializableObjectModelTest*
serializable_object_model_test_new (void)
{
#line 309 "SerializableObjectModelTest.vala"
	return serializable_object_model_test_construct (TYPE_SERIALIZABLE_OBJECT_MODEL_TEST);
#line 11401 "SerializableObjectModelTest.c"
}

static void
serializable_object_model_test_class_init (SerializableObjectModelTestClass * klass,
                                           gpointer klass_data)
{
#line 309 "SerializableObjectModelTest.vala"
	serializable_object_model_test_parent_class = g_type_class_peek_parent (klass);
#line 11410 "SerializableObjectModelTest.c"
}

static void
serializable_object_model_test_instance_init (SerializableObjectModelTest * self,
                                              gpointer klass)
{
}

GType
serializable_object_model_test_get_type (void)
{
	static volatile gsize serializable_object_model_test_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_object_model_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableObjectModelTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_object_model_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableObjectModelTest), 0, (GInstanceInitFunc) serializable_object_model_test_instance_init, NULL };
		GType serializable_object_model_test_type_id;
		serializable_object_model_test_type_id = g_type_register_static (TYPE_GXML_TEST, "SerializableObjectModelTest", &g_define_type_info, 0);
		g_once_init_leave (&serializable_object_model_test_type_id__volatile, serializable_object_model_test_type_id);
	}
	return serializable_object_model_test_type_id__volatile;
}

static void
_vala_array_destroy (gpointer array,
                     gint array_length,
                     GDestroyNotify destroy_func)
{
#line 356 "GomSerializationTest.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 11439 "SerializableObjectModelTest.c"
		int i;
#line 356 "GomSerializationTest.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 356 "GomSerializationTest.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 356 "GomSerializationTest.vala"
				destroy_func (((gpointer*) array)[i]);
#line 11447 "SerializableObjectModelTest.c"
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gint array_length,
                  GDestroyNotify destroy_func)
{
#line 356 "GomSerializationTest.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 356 "GomSerializationTest.vala"
	g_free (array);
#line 11462 "SerializableObjectModelTest.c"
}

