/* SerializableGeeTreeMapTest.c generated by valac 0.44.3, the Vala compiler
 * generated from SerializableGeeTreeMapTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */

#include <glib-object.h>
#include <glib.h>
#include <gxml/gxml.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <stdio.h>

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_SERIALIZABLE_GEE_TREE_MAP_TEST (serializable_gee_tree_map_test_get_type ())
#define SERIALIZABLE_GEE_TREE_MAP_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_GEE_TREE_MAP_TEST, SerializableGeeTreeMapTest))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_GEE_TREE_MAP_TEST, SerializableGeeTreeMapTestClass))
#define IS_SERIALIZABLE_GEE_TREE_MAP_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_GEE_TREE_MAP_TEST))
#define IS_SERIALIZABLE_GEE_TREE_MAP_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_GEE_TREE_MAP_TEST))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_GEE_TREE_MAP_TEST, SerializableGeeTreeMapTestClass))

typedef struct _SerializableGeeTreeMapTest SerializableGeeTreeMapTest;
typedef struct _SerializableGeeTreeMapTestClass SerializableGeeTreeMapTestClass;
typedef struct _SerializableGeeTreeMapTestPrivate SerializableGeeTreeMapTestPrivate;

#define SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE (serializable_gee_tree_map_test_space_get_type ())
#define SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE, SerializableGeeTreeMapTestSpace))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE, SerializableGeeTreeMapTestSpaceClass))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_IS_SPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_IS_SPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE, SerializableGeeTreeMapTestSpaceClass))

typedef struct _SerializableGeeTreeMapTestSpace SerializableGeeTreeMapTestSpace;
typedef struct _SerializableGeeTreeMapTestSpaceClass SerializableGeeTreeMapTestSpaceClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE_CONTAINER (serializable_gee_tree_map_test_space_container_get_type ())
#define SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_CONTAINER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE_CONTAINER, SerializableGeeTreeMapTestSpaceContainer))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_CONTAINER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE_CONTAINER, SerializableGeeTreeMapTestSpaceContainerClass))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_IS_SPACE_CONTAINER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE_CONTAINER))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_IS_SPACE_CONTAINER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE_CONTAINER))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_CONTAINER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE_CONTAINER, SerializableGeeTreeMapTestSpaceContainerClass))

typedef struct _SerializableGeeTreeMapTestSpaceContainer SerializableGeeTreeMapTestSpaceContainer;
typedef struct _SerializableGeeTreeMapTestSpaceContainerClass SerializableGeeTreeMapTestSpaceContainerClass;

#define SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_TYPE_COLLECTION (serializable_gee_tree_map_test_space_collection_get_type ())
#define SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_TYPE_COLLECTION, SerializableGeeTreeMapTestSpaceCollection))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_TYPE_COLLECTION, SerializableGeeTreeMapTestSpaceCollectionClass))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_TYPE_COLLECTION))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_TYPE_COLLECTION))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_TYPE_COLLECTION, SerializableGeeTreeMapTestSpaceCollectionClass))

typedef struct _SerializableGeeTreeMapTestSpaceCollection SerializableGeeTreeMapTestSpaceCollection;
typedef struct _SerializableGeeTreeMapTestSpaceCollectionClass SerializableGeeTreeMapTestSpaceCollectionClass;

#define TYPE_BOOK_STORE (book_store_get_type ())
#define BOOK_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BOOK_STORE, BookStore))
#define BOOK_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BOOK_STORE, BookStoreClass))
#define IS_BOOK_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BOOK_STORE))
#define IS_BOOK_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BOOK_STORE))
#define BOOK_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BOOK_STORE, BookStoreClass))

typedef struct _BookStore BookStore;
typedef struct _BookStoreClass BookStoreClass;

#define BOOK_TYPE_ARRAY (book_array_get_type ())
#define BOOK_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOOK_TYPE_ARRAY, BookArray))
#define BOOK_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOOK_TYPE_ARRAY, BookArrayClass))
#define BOOK_IS_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOOK_TYPE_ARRAY))
#define BOOK_IS_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOOK_TYPE_ARRAY))
#define BOOK_ARRAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOOK_TYPE_ARRAY, BookArrayClass))

typedef struct _BookArray BookArray;
typedef struct _BookArrayClass BookArrayClass;

#define TYPE_BOOK (book_get_type ())
#define BOOK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BOOK, Book))
#define BOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BOOK, BookClass))
#define IS_BOOK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BOOK))
#define IS_BOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BOOK))
#define BOOK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BOOK, BookClass))

typedef struct _Book Book;
typedef struct _BookClass BookClass;

#define TYPE_NAME (name_get_type ())
#define NAME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_NAME, Name))
#define NAME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_NAME, NameClass))
#define IS_NAME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_NAME))
#define IS_NAME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_NAME))
#define NAME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_NAME, NameClass))

typedef struct _Name Name;
typedef struct _NameClass NameClass;

#define TYPE_AUTHORS (authors_get_type ())
#define AUTHORS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_AUTHORS, Authors))
#define AUTHORS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_AUTHORS, AuthorsClass))
#define IS_AUTHORS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_AUTHORS))
#define IS_AUTHORS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_AUTHORS))
#define AUTHORS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_AUTHORS, AuthorsClass))

typedef struct _Authors Authors;
typedef struct _AuthorsClass AuthorsClass;

#define AUTHOR_TYPE_ARRAY (author_array_get_type ())
#define AUTHOR_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), AUTHOR_TYPE_ARRAY, AuthorArray))
#define AUTHOR_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), AUTHOR_TYPE_ARRAY, AuthorArrayClass))
#define AUTHOR_IS_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), AUTHOR_TYPE_ARRAY))
#define AUTHOR_IS_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), AUTHOR_TYPE_ARRAY))
#define AUTHOR_ARRAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), AUTHOR_TYPE_ARRAY, AuthorArrayClass))

typedef struct _AuthorArray AuthorArray;
typedef struct _AuthorArrayClass AuthorArrayClass;

#define RESUME_TYPE_MAP (resume_map_get_type ())
#define RESUME_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), RESUME_TYPE_MAP, ResumeMap))
#define RESUME_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), RESUME_TYPE_MAP, ResumeMapClass))
#define RESUME_IS_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), RESUME_TYPE_MAP))
#define RESUME_IS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), RESUME_TYPE_MAP))
#define RESUME_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), RESUME_TYPE_MAP, ResumeMapClass))

typedef struct _ResumeMap ResumeMap;
typedef struct _ResumeMapClass ResumeMapClass;

#define TYPE_RESUME (resume_get_type ())
#define RESUME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_RESUME, Resume))
#define RESUME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_RESUME, ResumeClass))
#define IS_RESUME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_RESUME))
#define IS_RESUME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_RESUME))
#define RESUME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_RESUME, ResumeClass))

typedef struct _Resume Resume;
typedef struct _ResumeClass ResumeClass;

#define SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BIG_BAG (serializable_gee_tree_map_test_big_bag_get_type ())
#define SERIALIZABLE_GEE_TREE_MAP_TEST_BIG_BAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BIG_BAG, SerializableGeeTreeMapTestBigBag))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_BIG_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BIG_BAG, SerializableGeeTreeMapTestBigBagClass))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_IS_BIG_BAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BIG_BAG))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_IS_BIG_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BIG_BAG))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_BIG_BAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BIG_BAG, SerializableGeeTreeMapTestBigBagClass))

typedef struct _SerializableGeeTreeMapTestBigBag SerializableGeeTreeMapTestBigBag;
typedef struct _SerializableGeeTreeMapTestBigBagClass SerializableGeeTreeMapTestBigBagClass;

#define SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_TYPE_TREE_MAP (serializable_gee_tree_map_test_small_bag_tree_map_get_type ())
#define SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_TREE_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_TYPE_TREE_MAP, SerializableGeeTreeMapTestSmallBagTreeMap))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_TREE_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_TYPE_TREE_MAP, SerializableGeeTreeMapTestSmallBagTreeMapClass))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_IS_TREE_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_TYPE_TREE_MAP))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_IS_TREE_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_TYPE_TREE_MAP))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_TREE_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_TYPE_TREE_MAP, SerializableGeeTreeMapTestSmallBagTreeMapClass))

typedef struct _SerializableGeeTreeMapTestSmallBagTreeMap SerializableGeeTreeMapTestSmallBagTreeMap;
typedef struct _SerializableGeeTreeMapTestSmallBagTreeMapClass SerializableGeeTreeMapTestSmallBagTreeMapClass;

#define SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SMALL_BAG (serializable_gee_tree_map_test_small_bag_get_type ())
#define SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeTreeMapTestSmallBag))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeTreeMapTestSmallBagClass))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_IS_SMALL_BAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SMALL_BAG))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_IS_SMALL_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SMALL_BAG))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeTreeMapTestSmallBagClass))

typedef struct _SerializableGeeTreeMapTestSmallBag SerializableGeeTreeMapTestSmallBag;
typedef struct _SerializableGeeTreeMapTestSmallBagClass SerializableGeeTreeMapTestSmallBagClass;

#define SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_TYPE_TREE_MAP (serializable_gee_tree_map_test_ball_tree_map_get_type ())
#define SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_TREE_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_TYPE_TREE_MAP, SerializableGeeTreeMapTestBallTreeMap))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_TREE_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_TYPE_TREE_MAP, SerializableGeeTreeMapTestBallTreeMapClass))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_IS_TREE_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_TYPE_TREE_MAP))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_IS_TREE_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_TYPE_TREE_MAP))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_TREE_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_TYPE_TREE_MAP, SerializableGeeTreeMapTestBallTreeMapClass))

typedef struct _SerializableGeeTreeMapTestBallTreeMap SerializableGeeTreeMapTestBallTreeMap;
typedef struct _SerializableGeeTreeMapTestBallTreeMapClass SerializableGeeTreeMapTestBallTreeMapClass;

#define SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BALL (serializable_gee_tree_map_test_ball_get_type ())
#define SERIALIZABLE_GEE_TREE_MAP_TEST_BALL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BALL, SerializableGeeTreeMapTestBall))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BALL, SerializableGeeTreeMapTestBallClass))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_IS_BALL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BALL))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_IS_BALL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BALL))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BALL, SerializableGeeTreeMapTestBallClass))

typedef struct _SerializableGeeTreeMapTestBall SerializableGeeTreeMapTestBall;
typedef struct _SerializableGeeTreeMapTestBallClass SerializableGeeTreeMapTestBallClass;

#define SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BALL_FILL (serializable_gee_tree_map_test_ball_fill_get_type ())
#define SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_FILL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BALL_FILL, SerializableGeeTreeMapTestBallFill))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_FILL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BALL_FILL, SerializableGeeTreeMapTestBallFillClass))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_IS_BALL_FILL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BALL_FILL))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_IS_BALL_FILL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BALL_FILL))
#define SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_FILL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BALL_FILL, SerializableGeeTreeMapTestBallFillClass))

typedef struct _SerializableGeeTreeMapTestBallFill SerializableGeeTreeMapTestBallFill;
typedef struct _SerializableGeeTreeMapTestBallFillClass SerializableGeeTreeMapTestBallFillClass;
typedef struct _SerializableGeeTreeMapTestSpacePrivate SerializableGeeTreeMapTestSpacePrivate;
enum  {
	SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_0_PROPERTY,
	SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_NAME_PROPERTY,
	SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_tree_map_test_space_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_NUM_PROPERTIES];
typedef struct _SerializableGeeTreeMapTestSpaceCollectionPrivate SerializableGeeTreeMapTestSpaceCollectionPrivate;
enum  {
	SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_COLLECTION_0_PROPERTY,
	SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_COLLECTION_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_tree_map_test_space_collection_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_COLLECTION_NUM_PROPERTIES];
typedef struct _SerializableGeeTreeMapTestSpaceContainerPrivate SerializableGeeTreeMapTestSpaceContainerPrivate;
enum  {
	SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_CONTAINER_0_PROPERTY,
	SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_CONTAINER_OWNER_PROPERTY,
	SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_CONTAINER_STORAGE_PROPERTY,
	SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_CONTAINER_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_tree_map_test_space_container_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_CONTAINER_NUM_PROPERTIES];
typedef struct _SerializableGeeTreeMapTestBallFillPrivate SerializableGeeTreeMapTestBallFillPrivate;
enum  {
	SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_FILL_0_PROPERTY,
	SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_FILL_NAME_PROPERTY,
	SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_FILL_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_tree_map_test_ball_fill_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_FILL_NUM_PROPERTIES];
typedef struct _SerializableGeeTreeMapTestBallPrivate SerializableGeeTreeMapTestBallPrivate;
enum  {
	SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_0_PROPERTY,
	SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_NAME_PROPERTY,
	SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_BALLFILL_PROPERTY,
	SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_tree_map_test_ball_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_NUM_PROPERTIES];
typedef struct _SerializableGeeTreeMapTestBallTreeMapPrivate SerializableGeeTreeMapTestBallTreeMapPrivate;
enum  {
	SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_TREE_MAP_0_PROPERTY,
	SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_TREE_MAP_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_tree_map_test_ball_tree_map_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_TREE_MAP_NUM_PROPERTIES];
typedef struct _SerializableGeeTreeMapTestSmallBagPrivate SerializableGeeTreeMapTestSmallBagPrivate;
enum  {
	SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_0_PROPERTY,
	SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_NAME_PROPERTY,
	SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_BALLS_PROPERTY,
	SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_tree_map_test_small_bag_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_NUM_PROPERTIES];
typedef struct _SerializableGeeTreeMapTestSmallBagTreeMapPrivate SerializableGeeTreeMapTestSmallBagTreeMapPrivate;
enum  {
	SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_TREE_MAP_0_PROPERTY,
	SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_TREE_MAP_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_tree_map_test_small_bag_tree_map_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_TREE_MAP_NUM_PROPERTIES];
typedef struct _SerializableGeeTreeMapTestBigBagPrivate SerializableGeeTreeMapTestBigBagPrivate;
enum  {
	SERIALIZABLE_GEE_TREE_MAP_TEST_BIG_BAG_0_PROPERTY,
	SERIALIZABLE_GEE_TREE_MAP_TEST_BIG_BAG_NAME_PROPERTY,
	SERIALIZABLE_GEE_TREE_MAP_TEST_BIG_BAG_BAGS_PROPERTY,
	SERIALIZABLE_GEE_TREE_MAP_TEST_BIG_BAG_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_tree_map_test_big_bag_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_BIG_BAG_NUM_PROPERTIES];
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _SerializableGeeTreeMapTest {
	GXmlTest parent_instance;
	SerializableGeeTreeMapTestPrivate * priv;
};

struct _SerializableGeeTreeMapTestClass {
	GXmlTestClass parent_class;
};

struct _SerializableGeeTreeMapTestSpace {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeTreeMapTestSpacePrivate * priv;
};

struct _SerializableGeeTreeMapTestSpaceClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeTreeMapTestSpacePrivate {
	gchar* _name;
};

struct _SerializableGeeTreeMapTestSpaceCollection {
	GXmlSerializableTreeMap parent_instance;
	SerializableGeeTreeMapTestSpaceCollectionPrivate * priv;
};

struct _SerializableGeeTreeMapTestSpaceCollectionClass {
	GXmlSerializableTreeMapClass parent_class;
};

struct _SerializableGeeTreeMapTestSpaceContainer {
	GXmlSerializableContainer parent_instance;
	SerializableGeeTreeMapTestSpaceContainerPrivate * priv;
};

struct _SerializableGeeTreeMapTestSpaceContainerClass {
	GXmlSerializableContainerClass parent_class;
};

struct _SerializableGeeTreeMapTestSpaceContainerPrivate {
	gchar* _owner;
	SerializableGeeTreeMapTestSpaceCollection* _storage;
};

struct _SerializableGeeTreeMapTestBallFill {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeTreeMapTestBallFillPrivate * priv;
};

struct _SerializableGeeTreeMapTestBallFillClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeTreeMapTestBallFillPrivate {
	gchar* _name;
};

struct _SerializableGeeTreeMapTestBall {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeTreeMapTestBallPrivate * priv;
};

struct _SerializableGeeTreeMapTestBallClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeTreeMapTestBallPrivate {
	gchar* _name;
	SerializableGeeTreeMapTestBallFill* _ballfill;
};

struct _SerializableGeeTreeMapTestBallTreeMap {
	GXmlSerializableTreeMap parent_instance;
	SerializableGeeTreeMapTestBallTreeMapPrivate * priv;
};

struct _SerializableGeeTreeMapTestBallTreeMapClass {
	GXmlSerializableTreeMapClass parent_class;
};

struct _SerializableGeeTreeMapTestSmallBag {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeTreeMapTestSmallBagPrivate * priv;
};

struct _SerializableGeeTreeMapTestSmallBagClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeTreeMapTestSmallBagPrivate {
	gchar* _name;
	SerializableGeeTreeMapTestBallTreeMap* _balls;
};

struct _SerializableGeeTreeMapTestSmallBagTreeMap {
	GXmlSerializableTreeMap parent_instance;
	SerializableGeeTreeMapTestSmallBagTreeMapPrivate * priv;
};

struct _SerializableGeeTreeMapTestSmallBagTreeMapClass {
	GXmlSerializableTreeMapClass parent_class;
};

struct _SerializableGeeTreeMapTestBigBag {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeTreeMapTestBigBagPrivate * priv;
};

struct _SerializableGeeTreeMapTestBigBagClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeTreeMapTestBigBagPrivate {
	gchar* _name;
	SerializableGeeTreeMapTestSmallBagTreeMap* _bags;
};

static gpointer serializable_gee_tree_map_test_parent_class = NULL;
static gint SerializableGeeTreeMapTestSpace_private_offset;
static gpointer serializable_gee_tree_map_test_space_parent_class = NULL;
static gpointer serializable_gee_tree_map_test_space_collection_parent_class = NULL;
static GXmlSerializableMapKeyIface * serializable_gee_tree_map_test_space_gxml_serializable_map_key_parent_iface = NULL;
static gint SerializableGeeTreeMapTestSpaceContainer_private_offset;
static gpointer serializable_gee_tree_map_test_space_container_parent_class = NULL;
static gint SerializableGeeTreeMapTestBallFill_private_offset;
static gpointer serializable_gee_tree_map_test_ball_fill_parent_class = NULL;
static gint SerializableGeeTreeMapTestBall_private_offset;
static gpointer serializable_gee_tree_map_test_ball_parent_class = NULL;
static gpointer serializable_gee_tree_map_test_ball_tree_map_parent_class = NULL;
static GXmlSerializableMapKeyIface * serializable_gee_tree_map_test_ball_gxml_serializable_map_key_parent_iface = NULL;
static gint SerializableGeeTreeMapTestSmallBag_private_offset;
static gpointer serializable_gee_tree_map_test_small_bag_parent_class = NULL;
static gpointer serializable_gee_tree_map_test_small_bag_tree_map_parent_class = NULL;
static GXmlSerializableMapKeyIface * serializable_gee_tree_map_test_small_bag_gxml_serializable_map_key_parent_iface = NULL;
static gint SerializableGeeTreeMapTestBigBag_private_offset;
static gpointer serializable_gee_tree_map_test_big_bag_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType serializable_gee_tree_map_test_get_type (void) G_GNUC_CONST;
void serializable_gee_tree_map_test_add_tests (void);
static void __lambda292_ (void);
static GType serializable_gee_tree_map_test_space_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeTreeMapTestSpace* serializable_gee_tree_map_test_space_new_named (const gchar* name);
static SerializableGeeTreeMapTestSpace* serializable_gee_tree_map_test_space_construct_named (GType object_type,
                                                                                       const gchar* name);
static const gchar* serializable_gee_tree_map_test_space_get_name (SerializableGeeTreeMapTestSpace* self);
static void ___lambda292__gtest_func (void);
static void __lambda293_ (void);
static void ___lambda293__gtest_func (void);
static void __lambda294_ (void);
static void ___lambda294__gtest_func (void);
static void __lambda295_ (void);
static GType serializable_gee_tree_map_test_space_container_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeTreeMapTestSpaceContainer* serializable_gee_tree_map_test_space_container_new (void);
static SerializableGeeTreeMapTestSpaceContainer* serializable_gee_tree_map_test_space_container_construct (GType object_type);
static const gchar* serializable_gee_tree_map_test_space_container_get_owner (SerializableGeeTreeMapTestSpaceContainer* self);
GType serializable_gee_tree_map_test_space_collection_get_type (void) G_GNUC_CONST;
static SerializableGeeTreeMapTestSpaceCollection* serializable_gee_tree_map_test_space_container_get_storage (SerializableGeeTreeMapTestSpaceContainer* self);
static void ___lambda295__gtest_func (void);
static void __lambda296_ (void);
static SerializableGeeTreeMapTestSpaceCollection* serializable_gee_tree_map_test_space_collection_new (void);
static SerializableGeeTreeMapTestSpaceCollection* serializable_gee_tree_map_test_space_collection_construct (GType object_type);
static void serializable_gee_tree_map_test_space_container_set_storage (SerializableGeeTreeMapTestSpaceContainer* self,
                                                                 SerializableGeeTreeMapTestSpaceCollection* value);
static void ___lambda296__gtest_func (void);
static void __lambda297_ (void);
GType book_store_get_type (void) G_GNUC_CONST;
BookStore* book_store_new (void);
BookStore* book_store_construct (GType object_type);
const gchar* book_store_get_name (BookStore* self);
GType book_array_get_type (void) G_GNUC_CONST;
BookArray* book_store_get_books (BookStore* self);
GType book_get_type (void) G_GNUC_CONST;
GType name_get_type (void) G_GNUC_CONST;
Name* book_get_name (Book* self);
gchar* name_get_name (Name* self);
const gchar* book_get_year (Book* self);
GType authors_get_type (void) G_GNUC_CONST;
Authors* book_get_authors (Book* self);
GType author_array_get_type (void) G_GNUC_CONST;
AuthorArray* authors_get_array (Authors* self);
GType resume_map_get_type (void) G_GNUC_CONST;
ResumeMap* book_get_resumes (Book* self);
GType resume_get_type (void) G_GNUC_CONST;
const gchar* resume_get_chapter (Resume* self);
const gchar* resume_get_text (Resume* self);
static void ___lambda297__gtest_func (void);
static void __lambda298_ (void);
static GType serializable_gee_tree_map_test_big_bag_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeTreeMapTestBigBag* serializable_gee_tree_map_test_big_bag_new (void);
static SerializableGeeTreeMapTestBigBag* serializable_gee_tree_map_test_big_bag_construct (GType object_type);
GType serializable_gee_tree_map_test_small_bag_tree_map_get_type (void) G_GNUC_CONST;
static SerializableGeeTreeMapTestSmallBagTreeMap* serializable_gee_tree_map_test_big_bag_get_bags (SerializableGeeTreeMapTestBigBag* self);
static GType serializable_gee_tree_map_test_small_bag_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeTreeMapTestSmallBag* serializable_gee_tree_map_test_small_bag_new (void);
static SerializableGeeTreeMapTestSmallBag* serializable_gee_tree_map_test_small_bag_construct (GType object_type);
static void serializable_gee_tree_map_test_small_bag_set_name (SerializableGeeTreeMapTestSmallBag* self,
                                                        const gchar* value);
GType serializable_gee_tree_map_test_ball_tree_map_get_type (void) G_GNUC_CONST;
static SerializableGeeTreeMapTestBallTreeMap* serializable_gee_tree_map_test_small_bag_get_balls (SerializableGeeTreeMapTestSmallBag* self);
static GType serializable_gee_tree_map_test_ball_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeTreeMapTestBall* serializable_gee_tree_map_test_ball_new (void);
static SerializableGeeTreeMapTestBall* serializable_gee_tree_map_test_ball_construct (GType object_type);
static void serializable_gee_tree_map_test_ball_set_name (SerializableGeeTreeMapTestBall* self,
                                                   const gchar* value);
static SerializableGeeTreeMapTestBallFill* serializable_gee_tree_map_test_ball_fill_new (void);
static SerializableGeeTreeMapTestBallFill* serializable_gee_tree_map_test_ball_fill_construct (GType object_type);
static GType serializable_gee_tree_map_test_ball_fill_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static void serializable_gee_tree_map_test_ball_set_ballfill (SerializableGeeTreeMapTestBall* self,
                                                       SerializableGeeTreeMapTestBallFill* value);
static SerializableGeeTreeMapTestBallFill* serializable_gee_tree_map_test_ball_get_ballfill (SerializableGeeTreeMapTestBall* self);
static void serializable_gee_tree_map_test_ball_fill_set_text (SerializableGeeTreeMapTestBallFill* self,
                                                        const gchar* txt);
static const gchar* serializable_gee_tree_map_test_ball_get_name (SerializableGeeTreeMapTestBall* self);
static const gchar* serializable_gee_tree_map_test_small_bag_get_name (SerializableGeeTreeMapTestSmallBag* self);
static void ___lambda298__gtest_func (void);
SerializableGeeTreeMapTest* serializable_gee_tree_map_test_new (void);
SerializableGeeTreeMapTest* serializable_gee_tree_map_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static gchar* serializable_gee_tree_map_test_space_real_get_map_key (GXmlSerializableMapKey* base);
static void serializable_gee_tree_map_test_space_set_name (SerializableGeeTreeMapTestSpace* self,
                                                    const gchar* value);
static gchar* serializable_gee_tree_map_test_space_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_tree_map_test_space_real_to_string (GXmlSerializableObjectModel* base);
static SerializableGeeTreeMapTestSpace* serializable_gee_tree_map_test_space_new (void);
static SerializableGeeTreeMapTestSpace* serializable_gee_tree_map_test_space_construct (GType object_type);
static void serializable_gee_tree_map_test_space_finalize (GObject * obj);
static void _vala_serializable_gee_tree_map_test_space_get_property (GObject * object,
                                                              guint property_id,
                                                              GValue * value,
                                                              GParamSpec * pspec);
static void _vala_serializable_gee_tree_map_test_space_set_property (GObject * object,
                                                              guint property_id,
                                                              const GValue * value,
                                                              GParamSpec * pspec);
static gchar* serializable_gee_tree_map_test_space_container_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_tree_map_test_space_container_real_to_string (GXmlSerializableObjectModel* base);
static void serializable_gee_tree_map_test_space_container_real_init_containers (GXmlSerializableContainer* base);
static void serializable_gee_tree_map_test_space_container_set_owner (SerializableGeeTreeMapTestSpaceContainer* self,
                                                               const gchar* value);
static void serializable_gee_tree_map_test_space_container_finalize (GObject * obj);
static void _vala_serializable_gee_tree_map_test_space_container_get_property (GObject * object,
                                                                        guint property_id,
                                                                        GValue * value,
                                                                        GParamSpec * pspec);
static void _vala_serializable_gee_tree_map_test_space_container_set_property (GObject * object,
                                                                        guint property_id,
                                                                        const GValue * value,
                                                                        GParamSpec * pspec);
static gchar* serializable_gee_tree_map_test_ball_fill_real_to_string (GXmlSerializableObjectModel* base);
static const gchar* serializable_gee_tree_map_test_ball_fill_get_name (SerializableGeeTreeMapTestBallFill* self);
static gchar* serializable_gee_tree_map_test_ball_fill_real_node_name (GXmlSerializableObjectModel* base);
static gboolean serializable_gee_tree_map_test_ball_fill_real_serialize_use_xml_node_value (GXmlSerializableObjectModel* base);
static void serializable_gee_tree_map_test_ball_fill_set_name (SerializableGeeTreeMapTestBallFill* self,
                                                        const gchar* value);
static void serializable_gee_tree_map_test_ball_fill_finalize (GObject * obj);
static void _vala_serializable_gee_tree_map_test_ball_fill_get_property (GObject * object,
                                                                  guint property_id,
                                                                  GValue * value,
                                                                  GParamSpec * pspec);
static void _vala_serializable_gee_tree_map_test_ball_fill_set_property (GObject * object,
                                                                  guint property_id,
                                                                  const GValue * value,
                                                                  GParamSpec * pspec);
static gchar* serializable_gee_tree_map_test_ball_real_to_string (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_tree_map_test_ball_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_tree_map_test_ball_real_get_map_key (GXmlSerializableMapKey* base);
static gboolean serializable_gee_tree_map_test_ball_tree_map_real_deserialize_proceed (GXmlSerializableTreeMap* base);
static SerializableGeeTreeMapTestBallTreeMap* serializable_gee_tree_map_test_ball_tree_map_new (void);
static SerializableGeeTreeMapTestBallTreeMap* serializable_gee_tree_map_test_ball_tree_map_construct (GType object_type);
static void serializable_gee_tree_map_test_ball_finalize (GObject * obj);
static void _vala_serializable_gee_tree_map_test_ball_get_property (GObject * object,
                                                             guint property_id,
                                                             GValue * value,
                                                             GParamSpec * pspec);
static void _vala_serializable_gee_tree_map_test_ball_set_property (GObject * object,
                                                             guint property_id,
                                                             const GValue * value,
                                                             GParamSpec * pspec);
static gchar* serializable_gee_tree_map_test_small_bag_real_to_string (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_tree_map_test_small_bag_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_tree_map_test_small_bag_real_get_map_key (GXmlSerializableMapKey* base);
static void serializable_gee_tree_map_test_small_bag_set_balls (SerializableGeeTreeMapTestSmallBag* self,
                                                         SerializableGeeTreeMapTestBallTreeMap* value);
static gboolean serializable_gee_tree_map_test_small_bag_tree_map_real_deserialize_proceed (GXmlSerializableTreeMap* base);
static SerializableGeeTreeMapTestSmallBagTreeMap* serializable_gee_tree_map_test_small_bag_tree_map_new (void);
static SerializableGeeTreeMapTestSmallBagTreeMap* serializable_gee_tree_map_test_small_bag_tree_map_construct (GType object_type);
static void serializable_gee_tree_map_test_small_bag_finalize (GObject * obj);
static void _vala_serializable_gee_tree_map_test_small_bag_get_property (GObject * object,
                                                                  guint property_id,
                                                                  GValue * value,
                                                                  GParamSpec * pspec);
static void _vala_serializable_gee_tree_map_test_small_bag_set_property (GObject * object,
                                                                  guint property_id,
                                                                  const GValue * value,
                                                                  GParamSpec * pspec);
static gchar* serializable_gee_tree_map_test_big_bag_real_to_string (GXmlSerializableObjectModel* base);
static const gchar* serializable_gee_tree_map_test_big_bag_get_name (SerializableGeeTreeMapTestBigBag* self);
static gchar* serializable_gee_tree_map_test_big_bag_real_node_name (GXmlSerializableObjectModel* base);
static void serializable_gee_tree_map_test_big_bag_set_name (SerializableGeeTreeMapTestBigBag* self,
                                                      const gchar* value);
static void serializable_gee_tree_map_test_big_bag_set_bags (SerializableGeeTreeMapTestBigBag* self,
                                                      SerializableGeeTreeMapTestSmallBagTreeMap* value);
static void serializable_gee_tree_map_test_big_bag_finalize (GObject * obj);
static void _vala_serializable_gee_tree_map_test_big_bag_get_property (GObject * object,
                                                                guint property_id,
                                                                GValue * value,
                                                                GParamSpec * pspec);
static void _vala_serializable_gee_tree_map_test_big_bag_set_property (GObject * object,
                                                                guint property_id,
                                                                const GValue * value,
                                                                GParamSpec * pspec);

static void
__lambda292_ (void)
{
	GXmlSerializableTreeMap* c = NULL;
	GXmlSerializableTreeMap* _tmp0_;
	SerializableGeeTreeMapTestSpace* o1 = NULL;
	SerializableGeeTreeMapTestSpace* _tmp1_;
	SerializableGeeTreeMapTestSpace* o2 = NULL;
	SerializableGeeTreeMapTestSpace* _tmp2_;
	GXmlSerializableTreeMap* _tmp3_;
	SerializableGeeTreeMapTestSpace* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	SerializableGeeTreeMapTestSpace* _tmp7_;
	GXmlSerializableTreeMap* _tmp8_;
	SerializableGeeTreeMapTestSpace* _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	SerializableGeeTreeMapTestSpace* _tmp12_;
	gboolean found1 = FALSE;
	gboolean found2 = FALSE;
#line 101 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = gxml_serializable_tree_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 101 "SerializableGeeTreeMapTest.vala"
	c = _tmp0_;
#line 102 "SerializableGeeTreeMapTest.vala"
	_tmp1_ = serializable_gee_tree_map_test_space_new_named ("Big");
#line 102 "SerializableGeeTreeMapTest.vala"
	o1 = _tmp1_;
#line 103 "SerializableGeeTreeMapTest.vala"
	_tmp2_ = serializable_gee_tree_map_test_space_new_named ("Small");
#line 103 "SerializableGeeTreeMapTest.vala"
	o2 = _tmp2_;
#line 104 "SerializableGeeTreeMapTest.vala"
	_tmp3_ = c;
#line 104 "SerializableGeeTreeMapTest.vala"
	_tmp4_ = o1;
#line 104 "SerializableGeeTreeMapTest.vala"
	_tmp5_ = serializable_gee_tree_map_test_space_get_name (_tmp4_);
#line 104 "SerializableGeeTreeMapTest.vala"
	_tmp6_ = _tmp5_;
#line 104 "SerializableGeeTreeMapTest.vala"
	_tmp7_ = o1;
#line 104 "SerializableGeeTreeMapTest.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp3_, _tmp6_, _tmp7_);
#line 105 "SerializableGeeTreeMapTest.vala"
	_tmp8_ = c;
#line 105 "SerializableGeeTreeMapTest.vala"
	_tmp9_ = o2;
#line 105 "SerializableGeeTreeMapTest.vala"
	_tmp10_ = serializable_gee_tree_map_test_space_get_name (_tmp9_);
#line 105 "SerializableGeeTreeMapTest.vala"
	_tmp11_ = _tmp10_;
#line 105 "SerializableGeeTreeMapTest.vala"
	_tmp12_ = o2;
#line 105 "SerializableGeeTreeMapTest.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp8_, _tmp11_, _tmp12_);
#line 106 "SerializableGeeTreeMapTest.vala"
	found1 = FALSE;
#line 107 "SerializableGeeTreeMapTest.vala"
	found2 = FALSE;
#line 677 "SerializableGeeTreeMapTest.c"
	{
		GeeIterator* _o_it = NULL;
		GXmlSerializableTreeMap* _tmp13_;
		GeeCollection* _tmp14_;
		GeeCollection* _tmp15_;
		GeeCollection* _tmp16_;
		GeeIterator* _tmp17_;
		GeeIterator* _tmp18_;
#line 108 "SerializableGeeTreeMapTest.vala"
		_tmp13_ = c;
#line 108 "SerializableGeeTreeMapTest.vala"
		_tmp14_ = gee_abstract_map_get_values ((GeeAbstractMap*) _tmp13_);
#line 108 "SerializableGeeTreeMapTest.vala"
		_tmp15_ = _tmp14_;
#line 108 "SerializableGeeTreeMapTest.vala"
		_tmp16_ = _tmp15_;
#line 108 "SerializableGeeTreeMapTest.vala"
		_tmp17_ = gee_iterable_iterator ((GeeIterable*) _tmp16_);
#line 108 "SerializableGeeTreeMapTest.vala"
		_tmp18_ = _tmp17_;
#line 108 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp16_);
#line 108 "SerializableGeeTreeMapTest.vala"
		_o_it = _tmp18_;
#line 108 "SerializableGeeTreeMapTest.vala"
		while (TRUE) {
#line 704 "SerializableGeeTreeMapTest.c"
			GeeIterator* _tmp19_;
			SerializableGeeTreeMapTestSpace* o = NULL;
			GeeIterator* _tmp20_;
			gpointer _tmp21_;
			SerializableGeeTreeMapTestSpace* _tmp22_;
			const gchar* _tmp23_;
			const gchar* _tmp24_;
			SerializableGeeTreeMapTestSpace* _tmp25_;
			const gchar* _tmp26_;
			const gchar* _tmp27_;
#line 108 "SerializableGeeTreeMapTest.vala"
			_tmp19_ = _o_it;
#line 108 "SerializableGeeTreeMapTest.vala"
			if (!gee_iterator_next (_tmp19_)) {
#line 108 "SerializableGeeTreeMapTest.vala"
				break;
#line 721 "SerializableGeeTreeMapTest.c"
			}
#line 108 "SerializableGeeTreeMapTest.vala"
			_tmp20_ = _o_it;
#line 108 "SerializableGeeTreeMapTest.vala"
			_tmp21_ = gee_iterator_get (_tmp20_);
#line 108 "SerializableGeeTreeMapTest.vala"
			o = (SerializableGeeTreeMapTestSpace*) _tmp21_;
#line 109 "SerializableGeeTreeMapTest.vala"
			_tmp22_ = o;
#line 109 "SerializableGeeTreeMapTest.vala"
			_tmp23_ = serializable_gee_tree_map_test_space_get_name (_tmp22_);
#line 109 "SerializableGeeTreeMapTest.vala"
			_tmp24_ = _tmp23_;
#line 109 "SerializableGeeTreeMapTest.vala"
			if (g_strcmp0 (_tmp24_, "Big") == 0) {
#line 109 "SerializableGeeTreeMapTest.vala"
				found1 = TRUE;
#line 739 "SerializableGeeTreeMapTest.c"
			}
#line 110 "SerializableGeeTreeMapTest.vala"
			_tmp25_ = o;
#line 110 "SerializableGeeTreeMapTest.vala"
			_tmp26_ = serializable_gee_tree_map_test_space_get_name (_tmp25_);
#line 110 "SerializableGeeTreeMapTest.vala"
			_tmp27_ = _tmp26_;
#line 110 "SerializableGeeTreeMapTest.vala"
			if (g_strcmp0 (_tmp27_, "Small") == 0) {
#line 110 "SerializableGeeTreeMapTest.vala"
				found2 = TRUE;
#line 751 "SerializableGeeTreeMapTest.c"
			}
#line 108 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (o);
#line 755 "SerializableGeeTreeMapTest.c"
		}
#line 108 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_o_it);
#line 759 "SerializableGeeTreeMapTest.c"
	}
#line 112 "SerializableGeeTreeMapTest.vala"
	if (!found1) {
#line 763 "SerializableGeeTreeMapTest.c"
		FILE* _tmp28_;
#line 113 "SerializableGeeTreeMapTest.vala"
		_tmp28_ = stdout;
#line 113 "SerializableGeeTreeMapTest.vala"
		fprintf (_tmp28_, "%s", "Big is not found\n");
#line 114 "SerializableGeeTreeMapTest.vala"
		g_assert_not_reached ();
#line 771 "SerializableGeeTreeMapTest.c"
	}
#line 116 "SerializableGeeTreeMapTest.vala"
	if (!found2) {
#line 775 "SerializableGeeTreeMapTest.c"
		FILE* _tmp29_;
#line 117 "SerializableGeeTreeMapTest.vala"
		_tmp29_ = stdout;
#line 117 "SerializableGeeTreeMapTest.vala"
		fprintf (_tmp29_, "%s", "Small is not found\n");
#line 118 "SerializableGeeTreeMapTest.vala"
		g_assert_not_reached ();
#line 783 "SerializableGeeTreeMapTest.c"
	}
#line 120 "SerializableGeeTreeMapTest.vala"
	found2 = FALSE;
#line 120 "SerializableGeeTreeMapTest.vala"
	found1 = found2;
#line 789 "SerializableGeeTreeMapTest.c"
	{
		GeeIterator* _k_it = NULL;
		GXmlSerializableTreeMap* _tmp30_;
		GeeSet* _tmp31_;
		GeeSet* _tmp32_;
		GeeSet* _tmp33_;
		GeeIterator* _tmp34_;
		GeeIterator* _tmp35_;
#line 121 "SerializableGeeTreeMapTest.vala"
		_tmp30_ = c;
#line 121 "SerializableGeeTreeMapTest.vala"
		_tmp31_ = gee_abstract_map_get_keys ((GeeAbstractMap*) _tmp30_);
#line 121 "SerializableGeeTreeMapTest.vala"
		_tmp32_ = _tmp31_;
#line 121 "SerializableGeeTreeMapTest.vala"
		_tmp33_ = _tmp32_;
#line 121 "SerializableGeeTreeMapTest.vala"
		_tmp34_ = gee_iterable_iterator ((GeeIterable*) _tmp33_);
#line 121 "SerializableGeeTreeMapTest.vala"
		_tmp35_ = _tmp34_;
#line 121 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp33_);
#line 121 "SerializableGeeTreeMapTest.vala"
		_k_it = _tmp35_;
#line 121 "SerializableGeeTreeMapTest.vala"
		while (TRUE) {
#line 816 "SerializableGeeTreeMapTest.c"
			GeeIterator* _tmp36_;
			gchar* k = NULL;
			GeeIterator* _tmp37_;
			gpointer _tmp38_;
			GXmlSerializableTreeMap* _tmp39_;
			const gchar* _tmp40_;
			gpointer _tmp41_;
			SerializableGeeTreeMapTestSpace* _tmp42_;
			const gchar* _tmp43_;
			const gchar* _tmp44_;
			gboolean _tmp45_;
			GXmlSerializableTreeMap* _tmp46_;
			const gchar* _tmp47_;
			gpointer _tmp48_;
			SerializableGeeTreeMapTestSpace* _tmp49_;
			const gchar* _tmp50_;
			const gchar* _tmp51_;
			gboolean _tmp52_;
#line 121 "SerializableGeeTreeMapTest.vala"
			_tmp36_ = _k_it;
#line 121 "SerializableGeeTreeMapTest.vala"
			if (!gee_iterator_next (_tmp36_)) {
#line 121 "SerializableGeeTreeMapTest.vala"
				break;
#line 841 "SerializableGeeTreeMapTest.c"
			}
#line 121 "SerializableGeeTreeMapTest.vala"
			_tmp37_ = _k_it;
#line 121 "SerializableGeeTreeMapTest.vala"
			_tmp38_ = gee_iterator_get (_tmp37_);
#line 121 "SerializableGeeTreeMapTest.vala"
			k = (gchar*) _tmp38_;
#line 122 "SerializableGeeTreeMapTest.vala"
			_tmp39_ = c;
#line 122 "SerializableGeeTreeMapTest.vala"
			_tmp40_ = k;
#line 122 "SerializableGeeTreeMapTest.vala"
			_tmp41_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp39_, _tmp40_);
#line 122 "SerializableGeeTreeMapTest.vala"
			_tmp42_ = (SerializableGeeTreeMapTestSpace*) _tmp41_;
#line 122 "SerializableGeeTreeMapTest.vala"
			_tmp43_ = serializable_gee_tree_map_test_space_get_name (_tmp42_);
#line 122 "SerializableGeeTreeMapTest.vala"
			_tmp44_ = _tmp43_;
#line 122 "SerializableGeeTreeMapTest.vala"
			_tmp45_ = g_strcmp0 (_tmp44_, "Big") == 0;
#line 122 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (_tmp42_);
#line 122 "SerializableGeeTreeMapTest.vala"
			if (_tmp45_) {
#line 122 "SerializableGeeTreeMapTest.vala"
				found1 = TRUE;
#line 869 "SerializableGeeTreeMapTest.c"
			}
#line 123 "SerializableGeeTreeMapTest.vala"
			_tmp46_ = c;
#line 123 "SerializableGeeTreeMapTest.vala"
			_tmp47_ = k;
#line 123 "SerializableGeeTreeMapTest.vala"
			_tmp48_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp46_, _tmp47_);
#line 123 "SerializableGeeTreeMapTest.vala"
			_tmp49_ = (SerializableGeeTreeMapTestSpace*) _tmp48_;
#line 123 "SerializableGeeTreeMapTest.vala"
			_tmp50_ = serializable_gee_tree_map_test_space_get_name (_tmp49_);
#line 123 "SerializableGeeTreeMapTest.vala"
			_tmp51_ = _tmp50_;
#line 123 "SerializableGeeTreeMapTest.vala"
			_tmp52_ = g_strcmp0 (_tmp51_, "Small") == 0;
#line 123 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (_tmp49_);
#line 123 "SerializableGeeTreeMapTest.vala"
			if (_tmp52_) {
#line 123 "SerializableGeeTreeMapTest.vala"
				found2 = TRUE;
#line 891 "SerializableGeeTreeMapTest.c"
			}
#line 121 "SerializableGeeTreeMapTest.vala"
			_g_free0 (k);
#line 895 "SerializableGeeTreeMapTest.c"
		}
#line 121 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_k_it);
#line 899 "SerializableGeeTreeMapTest.c"
	}
#line 125 "SerializableGeeTreeMapTest.vala"
	if (!found1) {
#line 903 "SerializableGeeTreeMapTest.c"
		FILE* _tmp53_;
#line 126 "SerializableGeeTreeMapTest.vala"
		_tmp53_ = stdout;
#line 126 "SerializableGeeTreeMapTest.vala"
		fprintf (_tmp53_, "%s", "Big key value is not found\n");
#line 127 "SerializableGeeTreeMapTest.vala"
		g_assert_not_reached ();
#line 911 "SerializableGeeTreeMapTest.c"
	}
#line 129 "SerializableGeeTreeMapTest.vala"
	if (!found2) {
#line 915 "SerializableGeeTreeMapTest.c"
		FILE* _tmp54_;
#line 130 "SerializableGeeTreeMapTest.vala"
		_tmp54_ = stdout;
#line 130 "SerializableGeeTreeMapTest.vala"
		fprintf (_tmp54_, "%s", "Small key value is not found\n");
#line 131 "SerializableGeeTreeMapTest.vala"
		g_assert_not_reached ();
#line 923 "SerializableGeeTreeMapTest.c"
	}
#line 100 "SerializableGeeTreeMapTest.vala"
	_g_object_unref0 (o2);
#line 100 "SerializableGeeTreeMapTest.vala"
	_g_object_unref0 (o1);
#line 100 "SerializableGeeTreeMapTest.vala"
	_g_object_unref0 (c);
#line 931 "SerializableGeeTreeMapTest.c"
}

static void
___lambda292__gtest_func (void)
{
#line 99 "SerializableGeeTreeMapTest.vala"
	__lambda292_ ();
#line 939 "SerializableGeeTreeMapTest.c"
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result = NULL;
#line 1516 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1517 "glib-2.0.vapi"
	result = self;
#line 1517 "glib-2.0.vapi"
	return result;
#line 952 "SerializableGeeTreeMapTest.c"
}

static void
__lambda293_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlSerializableTreeMap* c = NULL;
		GXmlSerializableTreeMap* _tmp0_;
		SerializableGeeTreeMapTestSpace* o1 = NULL;
		SerializableGeeTreeMapTestSpace* _tmp1_;
		SerializableGeeTreeMapTestSpace* o2 = NULL;
		SerializableGeeTreeMapTestSpace* _tmp2_;
		GXmlSerializableTreeMap* _tmp3_;
		SerializableGeeTreeMapTestSpace* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		SerializableGeeTreeMapTestSpace* _tmp7_;
		GXmlSerializableTreeMap* _tmp8_;
		SerializableGeeTreeMapTestSpace* _tmp9_;
		const gchar* _tmp10_;
		const gchar* _tmp11_;
		SerializableGeeTreeMapTestSpace* _tmp12_;
		GXmlTDocument* doc = NULL;
		GXmlTDocument* _tmp13_;
		GXmlNode* root = NULL;
		GXmlTDocument* _tmp14_;
		GXmlNode* _tmp15_;
		GXmlTDocument* _tmp16_;
		GeeBidirList* _tmp17_;
		GeeBidirList* _tmp18_;
		GeeBidirList* _tmp19_;
		GXmlNode* _tmp20_;
		GXmlSerializableTreeMap* _tmp21_;
		GXmlNode* _tmp22_;
		GXmlNode* _tmp23_;
		GXmlNode* _tmp24_;
		GXmlNode* _tmp25_;
		GeeBidirList* _tmp26_;
		GeeBidirList* _tmp27_;
		GeeBidirList* _tmp28_;
		gint _tmp29_;
		gint _tmp30_;
		gboolean found1 = FALSE;
		gboolean found2 = FALSE;
#line 137 "SerializableGeeTreeMapTest.vala"
		_tmp0_ = gxml_serializable_tree_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 137 "SerializableGeeTreeMapTest.vala"
		c = _tmp0_;
#line 138 "SerializableGeeTreeMapTest.vala"
		_tmp1_ = serializable_gee_tree_map_test_space_new_named ("Big");
#line 138 "SerializableGeeTreeMapTest.vala"
		o1 = _tmp1_;
#line 139 "SerializableGeeTreeMapTest.vala"
		_tmp2_ = serializable_gee_tree_map_test_space_new_named ("Small");
#line 139 "SerializableGeeTreeMapTest.vala"
		o2 = _tmp2_;
#line 140 "SerializableGeeTreeMapTest.vala"
		_tmp3_ = c;
#line 140 "SerializableGeeTreeMapTest.vala"
		_tmp4_ = o1;
#line 140 "SerializableGeeTreeMapTest.vala"
		_tmp5_ = serializable_gee_tree_map_test_space_get_name (_tmp4_);
#line 140 "SerializableGeeTreeMapTest.vala"
		_tmp6_ = _tmp5_;
#line 140 "SerializableGeeTreeMapTest.vala"
		_tmp7_ = o1;
#line 140 "SerializableGeeTreeMapTest.vala"
		gee_abstract_map_set ((GeeAbstractMap*) _tmp3_, _tmp6_, _tmp7_);
#line 141 "SerializableGeeTreeMapTest.vala"
		_tmp8_ = c;
#line 141 "SerializableGeeTreeMapTest.vala"
		_tmp9_ = o2;
#line 141 "SerializableGeeTreeMapTest.vala"
		_tmp10_ = serializable_gee_tree_map_test_space_get_name (_tmp9_);
#line 141 "SerializableGeeTreeMapTest.vala"
		_tmp11_ = _tmp10_;
#line 141 "SerializableGeeTreeMapTest.vala"
		_tmp12_ = o2;
#line 141 "SerializableGeeTreeMapTest.vala"
		gee_abstract_map_set ((GeeAbstractMap*) _tmp8_, _tmp11_, _tmp12_);
#line 142 "SerializableGeeTreeMapTest.vala"
		_tmp13_ = gxml_tdocument_new ();
#line 142 "SerializableGeeTreeMapTest.vala"
		doc = _tmp13_;
#line 143 "SerializableGeeTreeMapTest.vala"
		_tmp14_ = doc;
#line 143 "SerializableGeeTreeMapTest.vala"
		_tmp15_ = gxml_document_create_element ((GXmlDocument*) _tmp14_, "root", &_inner_error0_);
#line 143 "SerializableGeeTreeMapTest.vala"
		root = _tmp15_;
#line 143 "SerializableGeeTreeMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 143 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (doc);
#line 143 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (o2);
#line 143 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (o1);
#line 143 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (c);
#line 1054 "SerializableGeeTreeMapTest.c"
			goto __catch346_g_error;
		}
#line 144 "SerializableGeeTreeMapTest.vala"
		_tmp16_ = doc;
#line 144 "SerializableGeeTreeMapTest.vala"
		_tmp17_ = gxml_tnode_get_children_nodes ((GXmlTNode*) _tmp16_);
#line 144 "SerializableGeeTreeMapTest.vala"
		_tmp18_ = _tmp17_;
#line 144 "SerializableGeeTreeMapTest.vala"
		_tmp19_ = _tmp18_;
#line 144 "SerializableGeeTreeMapTest.vala"
		_tmp20_ = root;
#line 144 "SerializableGeeTreeMapTest.vala"
		gee_collection_add ((GeeCollection*) _tmp19_, _tmp20_);
#line 144 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp19_);
#line 145 "SerializableGeeTreeMapTest.vala"
		_tmp21_ = c;
#line 145 "SerializableGeeTreeMapTest.vala"
		_tmp22_ = root;
#line 145 "SerializableGeeTreeMapTest.vala"
		_tmp23_ = gxml_serializable_tree_map_serialize (_tmp21_, _tmp22_, &_inner_error0_);
#line 145 "SerializableGeeTreeMapTest.vala"
		_tmp24_ = _tmp23_;
#line 145 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp24_);
#line 145 "SerializableGeeTreeMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 145 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (root);
#line 145 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (doc);
#line 145 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (o2);
#line 145 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (o1);
#line 145 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (c);
#line 1093 "SerializableGeeTreeMapTest.c"
			goto __catch346_g_error;
		}
#line 146 "SerializableGeeTreeMapTest.vala"
		_tmp25_ = root;
#line 146 "SerializableGeeTreeMapTest.vala"
		_tmp26_ = gxml_node_get_children_nodes (_tmp25_);
#line 146 "SerializableGeeTreeMapTest.vala"
		_tmp27_ = _tmp26_;
#line 146 "SerializableGeeTreeMapTest.vala"
		_tmp28_ = _tmp27_;
#line 146 "SerializableGeeTreeMapTest.vala"
		_tmp29_ = gee_collection_get_size ((GeeCollection*) _tmp28_);
#line 146 "SerializableGeeTreeMapTest.vala"
		_tmp30_ = _tmp29_;
#line 146 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp30_ == 2, "root.children_nodes.size == 2");
#line 146 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp28_);
#line 147 "SerializableGeeTreeMapTest.vala"
		found1 = FALSE;
#line 148 "SerializableGeeTreeMapTest.vala"
		found2 = FALSE;
#line 1116 "SerializableGeeTreeMapTest.c"
		{
			GeeBidirList* _n_list = NULL;
			GXmlNode* _tmp31_;
			GeeBidirList* _tmp32_;
			GeeBidirList* _tmp33_;
			gint _n_size = 0;
			GeeBidirList* _tmp34_;
			gint _tmp35_;
			gint _tmp36_;
			gint _n_index = 0;
#line 149 "SerializableGeeTreeMapTest.vala"
			_tmp31_ = root;
#line 149 "SerializableGeeTreeMapTest.vala"
			_tmp32_ = gxml_node_get_children_nodes (_tmp31_);
#line 149 "SerializableGeeTreeMapTest.vala"
			_tmp33_ = _tmp32_;
#line 149 "SerializableGeeTreeMapTest.vala"
			_n_list = _tmp33_;
#line 149 "SerializableGeeTreeMapTest.vala"
			_tmp34_ = _n_list;
#line 149 "SerializableGeeTreeMapTest.vala"
			_tmp35_ = gee_collection_get_size ((GeeCollection*) _tmp34_);
#line 149 "SerializableGeeTreeMapTest.vala"
			_tmp36_ = _tmp35_;
#line 149 "SerializableGeeTreeMapTest.vala"
			_n_size = _tmp36_;
#line 149 "SerializableGeeTreeMapTest.vala"
			_n_index = -1;
#line 149 "SerializableGeeTreeMapTest.vala"
			while (TRUE) {
#line 1147 "SerializableGeeTreeMapTest.c"
				GXmlNode* n = NULL;
				GeeBidirList* _tmp37_;
				gpointer _tmp38_;
				gboolean _tmp39_ = FALSE;
				GXmlNode* _tmp40_;
#line 149 "SerializableGeeTreeMapTest.vala"
				_n_index = _n_index + 1;
#line 149 "SerializableGeeTreeMapTest.vala"
				if (!(_n_index < _n_size)) {
#line 149 "SerializableGeeTreeMapTest.vala"
					break;
#line 1159 "SerializableGeeTreeMapTest.c"
				}
#line 149 "SerializableGeeTreeMapTest.vala"
				_tmp37_ = _n_list;
#line 149 "SerializableGeeTreeMapTest.vala"
				_tmp38_ = gee_list_get ((GeeList*) _tmp37_, _n_index);
#line 149 "SerializableGeeTreeMapTest.vala"
				n = (GXmlNode*) _tmp38_;
#line 150 "SerializableGeeTreeMapTest.vala"
				_tmp40_ = n;
#line 150 "SerializableGeeTreeMapTest.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp40_, GXML_TYPE_ELEMENT)) {
#line 1171 "SerializableGeeTreeMapTest.c"
					GXmlNode* _tmp41_;
					gchar* _tmp42_;
					gchar* _tmp43_;
					gchar* _tmp44_;
#line 150 "SerializableGeeTreeMapTest.vala"
					_tmp41_ = n;
#line 150 "SerializableGeeTreeMapTest.vala"
					_tmp42_ = gxml_node_get_name (_tmp41_);
#line 150 "SerializableGeeTreeMapTest.vala"
					_tmp43_ = _tmp42_;
#line 150 "SerializableGeeTreeMapTest.vala"
					_tmp44_ = _tmp43_;
#line 150 "SerializableGeeTreeMapTest.vala"
					_tmp39_ = g_strcmp0 (_tmp44_, "space") == 0;
#line 150 "SerializableGeeTreeMapTest.vala"
					_g_free0 (_tmp44_);
#line 1188 "SerializableGeeTreeMapTest.c"
				} else {
#line 150 "SerializableGeeTreeMapTest.vala"
					_tmp39_ = FALSE;
#line 1192 "SerializableGeeTreeMapTest.c"
				}
#line 150 "SerializableGeeTreeMapTest.vala"
				if (_tmp39_) {
#line 1196 "SerializableGeeTreeMapTest.c"
					GXmlNode* name = NULL;
					GXmlNode* _tmp45_;
					GeeMap* _tmp46_;
					GeeMap* _tmp47_;
					GeeMap* _tmp48_;
					gpointer _tmp49_;
					GXmlNode* _tmp50_;
					GXmlNode* _tmp51_;
#line 151 "SerializableGeeTreeMapTest.vala"
					_tmp45_ = n;
#line 151 "SerializableGeeTreeMapTest.vala"
					_tmp46_ = gxml_node_get_attrs (_tmp45_);
#line 151 "SerializableGeeTreeMapTest.vala"
					_tmp47_ = _tmp46_;
#line 151 "SerializableGeeTreeMapTest.vala"
					_tmp48_ = _tmp47_;
#line 151 "SerializableGeeTreeMapTest.vala"
					_tmp49_ = gee_map_get (_tmp48_, "name");
#line 151 "SerializableGeeTreeMapTest.vala"
					_tmp50_ = (GXmlNode*) _tmp49_;
#line 151 "SerializableGeeTreeMapTest.vala"
					_g_object_unref0 (_tmp48_);
#line 151 "SerializableGeeTreeMapTest.vala"
					name = _tmp50_;
#line 152 "SerializableGeeTreeMapTest.vala"
					_tmp51_ = name;
#line 152 "SerializableGeeTreeMapTest.vala"
					if (_tmp51_ != NULL) {
#line 1225 "SerializableGeeTreeMapTest.c"
						GXmlNode* _tmp52_;
						gchar* _tmp53_;
						gchar* _tmp54_;
						gchar* _tmp55_;
						gboolean _tmp56_;
						GXmlNode* _tmp57_;
						gchar* _tmp58_;
						gchar* _tmp59_;
						gchar* _tmp60_;
						gboolean _tmp61_;
#line 153 "SerializableGeeTreeMapTest.vala"
						_tmp52_ = name;
#line 153 "SerializableGeeTreeMapTest.vala"
						_tmp53_ = gxml_node_get_value (_tmp52_);
#line 153 "SerializableGeeTreeMapTest.vala"
						_tmp54_ = _tmp53_;
#line 153 "SerializableGeeTreeMapTest.vala"
						_tmp55_ = _tmp54_;
#line 153 "SerializableGeeTreeMapTest.vala"
						_tmp56_ = g_strcmp0 (_tmp55_, "Big") == 0;
#line 153 "SerializableGeeTreeMapTest.vala"
						_g_free0 (_tmp55_);
#line 153 "SerializableGeeTreeMapTest.vala"
						if (_tmp56_) {
#line 153 "SerializableGeeTreeMapTest.vala"
							found1 = TRUE;
#line 1252 "SerializableGeeTreeMapTest.c"
						}
#line 154 "SerializableGeeTreeMapTest.vala"
						_tmp57_ = name;
#line 154 "SerializableGeeTreeMapTest.vala"
						_tmp58_ = gxml_node_get_value (_tmp57_);
#line 154 "SerializableGeeTreeMapTest.vala"
						_tmp59_ = _tmp58_;
#line 154 "SerializableGeeTreeMapTest.vala"
						_tmp60_ = _tmp59_;
#line 154 "SerializableGeeTreeMapTest.vala"
						_tmp61_ = g_strcmp0 (_tmp60_, "Small") == 0;
#line 154 "SerializableGeeTreeMapTest.vala"
						_g_free0 (_tmp60_);
#line 154 "SerializableGeeTreeMapTest.vala"
						if (_tmp61_) {
#line 154 "SerializableGeeTreeMapTest.vala"
							found2 = TRUE;
#line 1270 "SerializableGeeTreeMapTest.c"
						}
					}
#line 150 "SerializableGeeTreeMapTest.vala"
					_g_object_unref0 (name);
#line 1275 "SerializableGeeTreeMapTest.c"
				}
#line 149 "SerializableGeeTreeMapTest.vala"
				_g_object_unref0 (n);
#line 1279 "SerializableGeeTreeMapTest.c"
			}
#line 149 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (_n_list);
#line 1283 "SerializableGeeTreeMapTest.c"
		}
#line 158 "SerializableGeeTreeMapTest.vala"
		if (!found1) {
#line 1287 "SerializableGeeTreeMapTest.c"
			FILE* _tmp62_;
			GXmlTDocument* _tmp63_;
			gchar* _tmp64_;
			gchar* _tmp65_;
			gchar* _tmp66_;
			gchar* _tmp67_;
#line 159 "SerializableGeeTreeMapTest.vala"
			_tmp62_ = stdout;
#line 159 "SerializableGeeTreeMapTest.vala"
			_tmp63_ = doc;
#line 159 "SerializableGeeTreeMapTest.vala"
			_tmp64_ = gxml_tnode_to_string ((GXmlTNode*) _tmp63_);
#line 159 "SerializableGeeTreeMapTest.vala"
			_tmp65_ = _tmp64_;
#line 159 "SerializableGeeTreeMapTest.vala"
			_tmp66_ = g_strconcat ("ERROR: Big space node is not found\n", _tmp65_, "\n", NULL);
#line 159 "SerializableGeeTreeMapTest.vala"
			_tmp67_ = _tmp66_;
#line 159 "SerializableGeeTreeMapTest.vala"
			fprintf (_tmp62_, "%s", _tmp67_);
#line 159 "SerializableGeeTreeMapTest.vala"
			_g_free0 (_tmp67_);
#line 159 "SerializableGeeTreeMapTest.vala"
			_g_free0 (_tmp65_);
#line 160 "SerializableGeeTreeMapTest.vala"
			g_assert_not_reached ();
#line 1314 "SerializableGeeTreeMapTest.c"
		}
#line 162 "SerializableGeeTreeMapTest.vala"
		if (!found2) {
#line 1318 "SerializableGeeTreeMapTest.c"
			FILE* _tmp68_;
			GXmlTDocument* _tmp69_;
			gchar* _tmp70_;
			gchar* _tmp71_;
			gchar* _tmp72_;
			gchar* _tmp73_;
#line 163 "SerializableGeeTreeMapTest.vala"
			_tmp68_ = stdout;
#line 163 "SerializableGeeTreeMapTest.vala"
			_tmp69_ = doc;
#line 163 "SerializableGeeTreeMapTest.vala"
			_tmp70_ = gxml_tnode_to_string ((GXmlTNode*) _tmp69_);
#line 163 "SerializableGeeTreeMapTest.vala"
			_tmp71_ = _tmp70_;
#line 163 "SerializableGeeTreeMapTest.vala"
			_tmp72_ = g_strconcat ("ERROR: Small space node is not found\n", _tmp71_, "\n", NULL);
#line 163 "SerializableGeeTreeMapTest.vala"
			_tmp73_ = _tmp72_;
#line 163 "SerializableGeeTreeMapTest.vala"
			fprintf (_tmp68_, "%s", _tmp73_);
#line 163 "SerializableGeeTreeMapTest.vala"
			_g_free0 (_tmp73_);
#line 163 "SerializableGeeTreeMapTest.vala"
			_g_free0 (_tmp71_);
#line 164 "SerializableGeeTreeMapTest.vala"
			g_assert_not_reached ();
#line 1345 "SerializableGeeTreeMapTest.c"
		}
#line 136 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (root);
#line 136 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (doc);
#line 136 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (o2);
#line 136 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (o1);
#line 136 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (c);
#line 1357 "SerializableGeeTreeMapTest.c"
	}
	goto __finally346;
	__catch346_g_error:
	{
		GError* e = NULL;
		FILE* _tmp74_;
		const gchar* _tmp75_;
		const gchar* _tmp76_;
		gchar* _tmp77_;
		gchar* _tmp78_;
#line 136 "SerializableGeeTreeMapTest.vala"
		e = _inner_error0_;
#line 136 "SerializableGeeTreeMapTest.vala"
		_inner_error0_ = NULL;
#line 168 "SerializableGeeTreeMapTest.vala"
		_tmp74_ = stdout;
#line 168 "SerializableGeeTreeMapTest.vala"
		_tmp75_ = e->message;
#line 168 "SerializableGeeTreeMapTest.vala"
		_tmp76_ = string_to_string (_tmp75_);
#line 168 "SerializableGeeTreeMapTest.vala"
		_tmp77_ = g_strconcat ("ERROR: ", _tmp76_, NULL);
#line 168 "SerializableGeeTreeMapTest.vala"
		_tmp78_ = _tmp77_;
#line 168 "SerializableGeeTreeMapTest.vala"
		fprintf (_tmp74_, "%s", _tmp78_);
#line 168 "SerializableGeeTreeMapTest.vala"
		_g_free0 (_tmp78_);
#line 169 "SerializableGeeTreeMapTest.vala"
		g_assert_not_reached ();
#line 136 "SerializableGeeTreeMapTest.vala"
		_g_error_free0 (e);
#line 1390 "SerializableGeeTreeMapTest.c"
	}
	__finally346:
#line 136 "SerializableGeeTreeMapTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 136 "SerializableGeeTreeMapTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 136 "SerializableGeeTreeMapTest.vala"
		g_clear_error (&_inner_error0_);
#line 136 "SerializableGeeTreeMapTest.vala"
		return;
#line 1401 "SerializableGeeTreeMapTest.c"
	}
}

static void
___lambda293__gtest_func (void)
{
#line 134 "SerializableGeeTreeMapTest.vala"
	__lambda293_ ();
#line 1410 "SerializableGeeTreeMapTest.c"
}

static void
__lambda294_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlSerializableTreeMap* c = NULL;
		GXmlSerializableTreeMap* _tmp1_;
		GXmlSerializableTreeMap* _tmp2_;
		GXmlGDocument* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		GXmlSerializableTreeMap* _tmp7_;
		gint _tmp8_;
		gint _tmp9_;
		gboolean found1 = FALSE;
		gboolean found2 = FALSE;
#line 175 "SerializableGeeTreeMapTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"  <root><space name=\"Big\"/><space name=\"Small\"/></root>", 0, &_inner_error0_);
#line 175 "SerializableGeeTreeMapTest.vala"
		doc = _tmp0_;
#line 175 "SerializableGeeTreeMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1438 "SerializableGeeTreeMapTest.c"
			goto __catch347_g_error;
		}
#line 177 "SerializableGeeTreeMapTest.vala"
		_tmp1_ = gxml_serializable_tree_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 177 "SerializableGeeTreeMapTest.vala"
		c = _tmp1_;
#line 178 "SerializableGeeTreeMapTest.vala"
		_tmp2_ = c;
#line 178 "SerializableGeeTreeMapTest.vala"
		_tmp3_ = doc;
#line 178 "SerializableGeeTreeMapTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) _tmp3_);
#line 178 "SerializableGeeTreeMapTest.vala"
		_tmp5_ = _tmp4_;
#line 178 "SerializableGeeTreeMapTest.vala"
		_tmp6_ = _tmp5_;
#line 178 "SerializableGeeTreeMapTest.vala"
		gxml_serializable_tree_map_deserialize (_tmp2_, _tmp6_, &_inner_error0_);
#line 178 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp6_);
#line 178 "SerializableGeeTreeMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 178 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (c);
#line 178 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (doc);
#line 1465 "SerializableGeeTreeMapTest.c"
			goto __catch347_g_error;
		}
#line 179 "SerializableGeeTreeMapTest.vala"
		_tmp7_ = c;
#line 179 "SerializableGeeTreeMapTest.vala"
		_tmp8_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp7_);
#line 179 "SerializableGeeTreeMapTest.vala"
		_tmp9_ = _tmp8_;
#line 179 "SerializableGeeTreeMapTest.vala"
		if (_tmp9_ != 2) {
#line 1476 "SerializableGeeTreeMapTest.c"
			FILE* _tmp10_;
			GXmlSerializableTreeMap* _tmp11_;
			gint _tmp12_;
			gint _tmp13_;
			gchar* _tmp14_;
			gchar* _tmp15_;
			gchar* _tmp16_;
			gchar* _tmp17_;
#line 180 "SerializableGeeTreeMapTest.vala"
			_tmp10_ = stdout;
#line 180 "SerializableGeeTreeMapTest.vala"
			_tmp11_ = c;
#line 180 "SerializableGeeTreeMapTest.vala"
			_tmp12_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp11_);
#line 180 "SerializableGeeTreeMapTest.vala"
			_tmp13_ = _tmp12_;
#line 180 "SerializableGeeTreeMapTest.vala"
			_tmp14_ = g_strdup_printf ("%i", _tmp13_);
#line 180 "SerializableGeeTreeMapTest.vala"
			_tmp15_ = _tmp14_;
#line 180 "SerializableGeeTreeMapTest.vala"
			_tmp16_ = g_strconcat ("ERROR: incorrect size must be 2 got: ", _tmp15_, "\n", NULL);
#line 180 "SerializableGeeTreeMapTest.vala"
			_tmp17_ = _tmp16_;
#line 180 "SerializableGeeTreeMapTest.vala"
			fprintf (_tmp10_, "%s", _tmp17_);
#line 180 "SerializableGeeTreeMapTest.vala"
			_g_free0 (_tmp17_);
#line 180 "SerializableGeeTreeMapTest.vala"
			_g_free0 (_tmp15_);
#line 181 "SerializableGeeTreeMapTest.vala"
			g_assert_not_reached ();
#line 1509 "SerializableGeeTreeMapTest.c"
		}
#line 183 "SerializableGeeTreeMapTest.vala"
		found1 = FALSE;
#line 184 "SerializableGeeTreeMapTest.vala"
		found2 = FALSE;
#line 1515 "SerializableGeeTreeMapTest.c"
		{
			GeeIterator* _k_it = NULL;
			GXmlSerializableTreeMap* _tmp18_;
			GeeSet* _tmp19_;
			GeeSet* _tmp20_;
			GeeSet* _tmp21_;
			GeeIterator* _tmp22_;
			GeeIterator* _tmp23_;
#line 185 "SerializableGeeTreeMapTest.vala"
			_tmp18_ = c;
#line 185 "SerializableGeeTreeMapTest.vala"
			_tmp19_ = gee_abstract_map_get_keys ((GeeAbstractMap*) _tmp18_);
#line 185 "SerializableGeeTreeMapTest.vala"
			_tmp20_ = _tmp19_;
#line 185 "SerializableGeeTreeMapTest.vala"
			_tmp21_ = _tmp20_;
#line 185 "SerializableGeeTreeMapTest.vala"
			_tmp22_ = gee_iterable_iterator ((GeeIterable*) _tmp21_);
#line 185 "SerializableGeeTreeMapTest.vala"
			_tmp23_ = _tmp22_;
#line 185 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (_tmp21_);
#line 185 "SerializableGeeTreeMapTest.vala"
			_k_it = _tmp23_;
#line 185 "SerializableGeeTreeMapTest.vala"
			while (TRUE) {
#line 1542 "SerializableGeeTreeMapTest.c"
				GeeIterator* _tmp24_;
				gchar* k = NULL;
				GeeIterator* _tmp25_;
				gpointer _tmp26_;
				GXmlSerializableTreeMap* _tmp27_;
				const gchar* _tmp28_;
				gpointer _tmp29_;
				SerializableGeeTreeMapTestSpace* _tmp30_;
				const gchar* _tmp31_;
				const gchar* _tmp32_;
				gboolean _tmp33_;
				GXmlSerializableTreeMap* _tmp34_;
				const gchar* _tmp35_;
				gpointer _tmp36_;
				SerializableGeeTreeMapTestSpace* _tmp37_;
				const gchar* _tmp38_;
				const gchar* _tmp39_;
				gboolean _tmp40_;
#line 185 "SerializableGeeTreeMapTest.vala"
				_tmp24_ = _k_it;
#line 185 "SerializableGeeTreeMapTest.vala"
				if (!gee_iterator_next (_tmp24_)) {
#line 185 "SerializableGeeTreeMapTest.vala"
					break;
#line 1567 "SerializableGeeTreeMapTest.c"
				}
#line 185 "SerializableGeeTreeMapTest.vala"
				_tmp25_ = _k_it;
#line 185 "SerializableGeeTreeMapTest.vala"
				_tmp26_ = gee_iterator_get (_tmp25_);
#line 185 "SerializableGeeTreeMapTest.vala"
				k = (gchar*) _tmp26_;
#line 186 "SerializableGeeTreeMapTest.vala"
				_tmp27_ = c;
#line 186 "SerializableGeeTreeMapTest.vala"
				_tmp28_ = k;
#line 186 "SerializableGeeTreeMapTest.vala"
				_tmp29_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp27_, _tmp28_);
#line 186 "SerializableGeeTreeMapTest.vala"
				_tmp30_ = (SerializableGeeTreeMapTestSpace*) _tmp29_;
#line 186 "SerializableGeeTreeMapTest.vala"
				_tmp31_ = serializable_gee_tree_map_test_space_get_name (_tmp30_);
#line 186 "SerializableGeeTreeMapTest.vala"
				_tmp32_ = _tmp31_;
#line 186 "SerializableGeeTreeMapTest.vala"
				_tmp33_ = g_strcmp0 (_tmp32_, "Big") == 0;
#line 186 "SerializableGeeTreeMapTest.vala"
				_g_object_unref0 (_tmp30_);
#line 186 "SerializableGeeTreeMapTest.vala"
				if (_tmp33_) {
#line 186 "SerializableGeeTreeMapTest.vala"
					found1 = TRUE;
#line 1595 "SerializableGeeTreeMapTest.c"
				}
#line 187 "SerializableGeeTreeMapTest.vala"
				_tmp34_ = c;
#line 187 "SerializableGeeTreeMapTest.vala"
				_tmp35_ = k;
#line 187 "SerializableGeeTreeMapTest.vala"
				_tmp36_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp34_, _tmp35_);
#line 187 "SerializableGeeTreeMapTest.vala"
				_tmp37_ = (SerializableGeeTreeMapTestSpace*) _tmp36_;
#line 187 "SerializableGeeTreeMapTest.vala"
				_tmp38_ = serializable_gee_tree_map_test_space_get_name (_tmp37_);
#line 187 "SerializableGeeTreeMapTest.vala"
				_tmp39_ = _tmp38_;
#line 187 "SerializableGeeTreeMapTest.vala"
				_tmp40_ = g_strcmp0 (_tmp39_, "Small") == 0;
#line 187 "SerializableGeeTreeMapTest.vala"
				_g_object_unref0 (_tmp37_);
#line 187 "SerializableGeeTreeMapTest.vala"
				if (_tmp40_) {
#line 187 "SerializableGeeTreeMapTest.vala"
					found2 = TRUE;
#line 1617 "SerializableGeeTreeMapTest.c"
				}
#line 185 "SerializableGeeTreeMapTest.vala"
				_g_free0 (k);
#line 1621 "SerializableGeeTreeMapTest.c"
			}
#line 185 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (_k_it);
#line 1625 "SerializableGeeTreeMapTest.c"
		}
#line 189 "SerializableGeeTreeMapTest.vala"
		if (!found1) {
#line 1629 "SerializableGeeTreeMapTest.c"
			FILE* _tmp41_;
#line 190 "SerializableGeeTreeMapTest.vala"
			_tmp41_ = stdout;
#line 190 "SerializableGeeTreeMapTest.vala"
			fprintf (_tmp41_, "%s", "ERROR: Big key value is not found\n");
#line 191 "SerializableGeeTreeMapTest.vala"
			g_assert_not_reached ();
#line 1637 "SerializableGeeTreeMapTest.c"
		}
#line 193 "SerializableGeeTreeMapTest.vala"
		if (!found2) {
#line 1641 "SerializableGeeTreeMapTest.c"
			FILE* _tmp42_;
#line 194 "SerializableGeeTreeMapTest.vala"
			_tmp42_ = stdout;
#line 194 "SerializableGeeTreeMapTest.vala"
			fprintf (_tmp42_, "%s", "ERROR: Small key value is not found\n");
#line 195 "SerializableGeeTreeMapTest.vala"
			g_assert_not_reached ();
#line 1649 "SerializableGeeTreeMapTest.c"
		}
#line 174 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (c);
#line 174 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (doc);
#line 1655 "SerializableGeeTreeMapTest.c"
	}
	goto __finally347;
	__catch347_g_error:
	{
		GError* e = NULL;
		FILE* _tmp43_;
		const gchar* _tmp44_;
		const gchar* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
#line 174 "SerializableGeeTreeMapTest.vala"
		e = _inner_error0_;
#line 174 "SerializableGeeTreeMapTest.vala"
		_inner_error0_ = NULL;
#line 199 "SerializableGeeTreeMapTest.vala"
		_tmp43_ = stdout;
#line 199 "SerializableGeeTreeMapTest.vala"
		_tmp44_ = e->message;
#line 199 "SerializableGeeTreeMapTest.vala"
		_tmp45_ = string_to_string (_tmp44_);
#line 199 "SerializableGeeTreeMapTest.vala"
		_tmp46_ = g_strconcat ("ERROR: ", _tmp45_, NULL);
#line 199 "SerializableGeeTreeMapTest.vala"
		_tmp47_ = _tmp46_;
#line 199 "SerializableGeeTreeMapTest.vala"
		fprintf (_tmp43_, "%s", _tmp47_);
#line 199 "SerializableGeeTreeMapTest.vala"
		_g_free0 (_tmp47_);
#line 200 "SerializableGeeTreeMapTest.vala"
		g_assert_not_reached ();
#line 174 "SerializableGeeTreeMapTest.vala"
		_g_error_free0 (e);
#line 1688 "SerializableGeeTreeMapTest.c"
	}
	__finally347:
#line 174 "SerializableGeeTreeMapTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 174 "SerializableGeeTreeMapTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 174 "SerializableGeeTreeMapTest.vala"
		g_clear_error (&_inner_error0_);
#line 174 "SerializableGeeTreeMapTest.vala"
		return;
#line 1699 "SerializableGeeTreeMapTest.c"
	}
}

static void
___lambda294__gtest_func (void)
{
#line 172 "SerializableGeeTreeMapTest.vala"
	__lambda294_ ();
#line 1708 "SerializableGeeTreeMapTest.c"
}

static void
__lambda295_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		SerializableGeeTreeMapTestSpaceContainer* c = NULL;
		SerializableGeeTreeMapTestSpaceContainer* _tmp1_;
		SerializableGeeTreeMapTestSpaceContainer* _tmp2_;
		GXmlGDocument* _tmp3_;
		SerializableGeeTreeMapTestSpaceContainer* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		SerializableGeeTreeMapTestSpaceContainer* _tmp17_;
		SerializableGeeTreeMapTestSpaceCollection* _tmp18_;
		SerializableGeeTreeMapTestSpaceCollection* _tmp19_;
		SerializableGeeTreeMapTestSpaceContainer* _tmp26_;
		SerializableGeeTreeMapTestSpaceCollection* _tmp27_;
		SerializableGeeTreeMapTestSpaceCollection* _tmp28_;
		gint _tmp29_;
		gint _tmp30_;
		gboolean found1 = FALSE;
		gboolean found2 = FALSE;
#line 206 "SerializableGeeTreeMapTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"  <spacecontainer owner=\"Earth\"><space name=\"Big\"/><space name=\"S" \
"mall\"/></spacecontainer>", 0, &_inner_error0_);
#line 206 "SerializableGeeTreeMapTest.vala"
		doc = _tmp0_;
#line 206 "SerializableGeeTreeMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1741 "SerializableGeeTreeMapTest.c"
			goto __catch348_g_error;
		}
#line 208 "SerializableGeeTreeMapTest.vala"
		_tmp1_ = serializable_gee_tree_map_test_space_container_new ();
#line 208 "SerializableGeeTreeMapTest.vala"
		c = _tmp1_;
#line 209 "SerializableGeeTreeMapTest.vala"
		_tmp2_ = c;
#line 209 "SerializableGeeTreeMapTest.vala"
		_tmp3_ = doc;
#line 209 "SerializableGeeTreeMapTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 209 "SerializableGeeTreeMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 209 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (c);
#line 209 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (doc);
#line 1760 "SerializableGeeTreeMapTest.c"
			goto __catch348_g_error;
		}
#line 210 "SerializableGeeTreeMapTest.vala"
		_tmp4_ = c;
#line 210 "SerializableGeeTreeMapTest.vala"
		_tmp5_ = serializable_gee_tree_map_test_space_container_get_owner (_tmp4_);
#line 210 "SerializableGeeTreeMapTest.vala"
		_tmp6_ = _tmp5_;
#line 210 "SerializableGeeTreeMapTest.vala"
		if (g_strcmp0 (_tmp6_, "Earth") != 0) {
#line 1771 "SerializableGeeTreeMapTest.c"
			FILE* _tmp7_;
			SerializableGeeTreeMapTestSpaceContainer* _tmp8_;
			const gchar* _tmp9_;
			const gchar* _tmp10_;
			const gchar* _tmp11_;
			GXmlGDocument* _tmp12_;
			gchar* _tmp13_;
			gchar* _tmp14_;
			gchar* _tmp15_;
			gchar* _tmp16_;
#line 211 "SerializableGeeTreeMapTest.vala"
			_tmp7_ = stdout;
#line 211 "SerializableGeeTreeMapTest.vala"
			_tmp8_ = c;
#line 211 "SerializableGeeTreeMapTest.vala"
			_tmp9_ = serializable_gee_tree_map_test_space_container_get_owner (_tmp8_);
#line 211 "SerializableGeeTreeMapTest.vala"
			_tmp10_ = _tmp9_;
#line 211 "SerializableGeeTreeMapTest.vala"
			_tmp11_ = string_to_string (_tmp10_);
#line 211 "SerializableGeeTreeMapTest.vala"
			_tmp12_ = doc;
#line 211 "SerializableGeeTreeMapTest.vala"
			_tmp13_ = gxml_gnode_to_string ((GXmlGNode*) _tmp12_);
#line 211 "SerializableGeeTreeMapTest.vala"
			_tmp14_ = _tmp13_;
#line 211 "SerializableGeeTreeMapTest.vala"
			_tmp15_ = g_strconcat ("ERROR: owner must be 'Earth' got: ", _tmp11_, "\n", _tmp14_, "\n", NULL);
#line 211 "SerializableGeeTreeMapTest.vala"
			_tmp16_ = _tmp15_;
#line 211 "SerializableGeeTreeMapTest.vala"
			fprintf (_tmp7_, "%s", _tmp16_);
#line 211 "SerializableGeeTreeMapTest.vala"
			_g_free0 (_tmp16_);
#line 211 "SerializableGeeTreeMapTest.vala"
			_g_free0 (_tmp14_);
#line 212 "SerializableGeeTreeMapTest.vala"
			g_assert_not_reached ();
#line 1810 "SerializableGeeTreeMapTest.c"
		}
#line 214 "SerializableGeeTreeMapTest.vala"
		_tmp17_ = c;
#line 214 "SerializableGeeTreeMapTest.vala"
		_tmp18_ = serializable_gee_tree_map_test_space_container_get_storage (_tmp17_);
#line 214 "SerializableGeeTreeMapTest.vala"
		_tmp19_ = _tmp18_;
#line 214 "SerializableGeeTreeMapTest.vala"
		if (_tmp19_ == NULL) {
#line 1820 "SerializableGeeTreeMapTest.c"
			FILE* _tmp20_;
			GXmlGDocument* _tmp21_;
			gchar* _tmp22_;
			gchar* _tmp23_;
			gchar* _tmp24_;
			gchar* _tmp25_;
#line 215 "SerializableGeeTreeMapTest.vala"
			_tmp20_ = stdout;
#line 215 "SerializableGeeTreeMapTest.vala"
			_tmp21_ = doc;
#line 215 "SerializableGeeTreeMapTest.vala"
			_tmp22_ = gxml_gnode_to_string ((GXmlGNode*) _tmp21_);
#line 215 "SerializableGeeTreeMapTest.vala"
			_tmp23_ = _tmp22_;
#line 215 "SerializableGeeTreeMapTest.vala"
			_tmp24_ = g_strconcat ("ERROR: storage doesn't exist\n", _tmp23_, "\n", NULL);
#line 215 "SerializableGeeTreeMapTest.vala"
			_tmp25_ = _tmp24_;
#line 215 "SerializableGeeTreeMapTest.vala"
			fprintf (_tmp20_, "%s", _tmp25_);
#line 215 "SerializableGeeTreeMapTest.vala"
			_g_free0 (_tmp25_);
#line 215 "SerializableGeeTreeMapTest.vala"
			_g_free0 (_tmp23_);
#line 216 "SerializableGeeTreeMapTest.vala"
			g_assert_not_reached ();
#line 1847 "SerializableGeeTreeMapTest.c"
		}
#line 218 "SerializableGeeTreeMapTest.vala"
		_tmp26_ = c;
#line 218 "SerializableGeeTreeMapTest.vala"
		_tmp27_ = serializable_gee_tree_map_test_space_container_get_storage (_tmp26_);
#line 218 "SerializableGeeTreeMapTest.vala"
		_tmp28_ = _tmp27_;
#line 218 "SerializableGeeTreeMapTest.vala"
		_tmp29_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp28_);
#line 218 "SerializableGeeTreeMapTest.vala"
		_tmp30_ = _tmp29_;
#line 218 "SerializableGeeTreeMapTest.vala"
		if (_tmp30_ != 2) {
#line 1861 "SerializableGeeTreeMapTest.c"
			FILE* _tmp31_;
			SerializableGeeTreeMapTestSpaceContainer* _tmp32_;
			SerializableGeeTreeMapTestSpaceCollection* _tmp33_;
			SerializableGeeTreeMapTestSpaceCollection* _tmp34_;
			gint _tmp35_;
			gint _tmp36_;
			gchar* _tmp37_;
			gchar* _tmp38_;
			GXmlGDocument* _tmp39_;
			gchar* _tmp40_;
			gchar* _tmp41_;
			gchar* _tmp42_;
			gchar* _tmp43_;
#line 219 "SerializableGeeTreeMapTest.vala"
			_tmp31_ = stdout;
#line 219 "SerializableGeeTreeMapTest.vala"
			_tmp32_ = c;
#line 219 "SerializableGeeTreeMapTest.vala"
			_tmp33_ = serializable_gee_tree_map_test_space_container_get_storage (_tmp32_);
#line 219 "SerializableGeeTreeMapTest.vala"
			_tmp34_ = _tmp33_;
#line 219 "SerializableGeeTreeMapTest.vala"
			_tmp35_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp34_);
#line 219 "SerializableGeeTreeMapTest.vala"
			_tmp36_ = _tmp35_;
#line 219 "SerializableGeeTreeMapTest.vala"
			_tmp37_ = g_strdup_printf ("%i", _tmp36_);
#line 219 "SerializableGeeTreeMapTest.vala"
			_tmp38_ = _tmp37_;
#line 219 "SerializableGeeTreeMapTest.vala"
			_tmp39_ = doc;
#line 219 "SerializableGeeTreeMapTest.vala"
			_tmp40_ = gxml_gnode_to_string ((GXmlGNode*) _tmp39_);
#line 219 "SerializableGeeTreeMapTest.vala"
			_tmp41_ = _tmp40_;
#line 219 "SerializableGeeTreeMapTest.vala"
			_tmp42_ = g_strconcat ("ERROR: Size must be 2 got: ", _tmp38_, "\n", _tmp41_, "\n", NULL);
#line 219 "SerializableGeeTreeMapTest.vala"
			_tmp43_ = _tmp42_;
#line 219 "SerializableGeeTreeMapTest.vala"
			fprintf (_tmp31_, "%s", _tmp43_);
#line 219 "SerializableGeeTreeMapTest.vala"
			_g_free0 (_tmp43_);
#line 219 "SerializableGeeTreeMapTest.vala"
			_g_free0 (_tmp41_);
#line 219 "SerializableGeeTreeMapTest.vala"
			_g_free0 (_tmp38_);
#line 220 "SerializableGeeTreeMapTest.vala"
			g_assert_not_reached ();
#line 1911 "SerializableGeeTreeMapTest.c"
		}
#line 222 "SerializableGeeTreeMapTest.vala"
		found1 = FALSE;
#line 223 "SerializableGeeTreeMapTest.vala"
		found2 = FALSE;
#line 1917 "SerializableGeeTreeMapTest.c"
		{
			GeeIterator* _k_it = NULL;
			SerializableGeeTreeMapTestSpaceContainer* _tmp44_;
			SerializableGeeTreeMapTestSpaceCollection* _tmp45_;
			SerializableGeeTreeMapTestSpaceCollection* _tmp46_;
			GeeSet* _tmp47_;
			GeeSet* _tmp48_;
			GeeSet* _tmp49_;
			GeeIterator* _tmp50_;
			GeeIterator* _tmp51_;
#line 224 "SerializableGeeTreeMapTest.vala"
			_tmp44_ = c;
#line 224 "SerializableGeeTreeMapTest.vala"
			_tmp45_ = serializable_gee_tree_map_test_space_container_get_storage (_tmp44_);
#line 224 "SerializableGeeTreeMapTest.vala"
			_tmp46_ = _tmp45_;
#line 224 "SerializableGeeTreeMapTest.vala"
			_tmp47_ = gee_abstract_map_get_keys ((GeeAbstractMap*) _tmp46_);
#line 224 "SerializableGeeTreeMapTest.vala"
			_tmp48_ = _tmp47_;
#line 224 "SerializableGeeTreeMapTest.vala"
			_tmp49_ = _tmp48_;
#line 224 "SerializableGeeTreeMapTest.vala"
			_tmp50_ = gee_iterable_iterator ((GeeIterable*) _tmp49_);
#line 224 "SerializableGeeTreeMapTest.vala"
			_tmp51_ = _tmp50_;
#line 224 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (_tmp49_);
#line 224 "SerializableGeeTreeMapTest.vala"
			_k_it = _tmp51_;
#line 224 "SerializableGeeTreeMapTest.vala"
			while (TRUE) {
#line 1950 "SerializableGeeTreeMapTest.c"
				GeeIterator* _tmp52_;
				gchar* k = NULL;
				GeeIterator* _tmp53_;
				gpointer _tmp54_;
				SerializableGeeTreeMapTestSpaceContainer* _tmp55_;
				SerializableGeeTreeMapTestSpaceCollection* _tmp56_;
				SerializableGeeTreeMapTestSpaceCollection* _tmp57_;
				const gchar* _tmp58_;
				gpointer _tmp59_;
				SerializableGeeTreeMapTestSpace* _tmp60_;
				const gchar* _tmp61_;
				const gchar* _tmp62_;
				gboolean _tmp63_;
				SerializableGeeTreeMapTestSpaceContainer* _tmp64_;
				SerializableGeeTreeMapTestSpaceCollection* _tmp65_;
				SerializableGeeTreeMapTestSpaceCollection* _tmp66_;
				const gchar* _tmp67_;
				gpointer _tmp68_;
				SerializableGeeTreeMapTestSpace* _tmp69_;
				const gchar* _tmp70_;
				const gchar* _tmp71_;
				gboolean _tmp72_;
#line 224 "SerializableGeeTreeMapTest.vala"
				_tmp52_ = _k_it;
#line 224 "SerializableGeeTreeMapTest.vala"
				if (!gee_iterator_next (_tmp52_)) {
#line 224 "SerializableGeeTreeMapTest.vala"
					break;
#line 1979 "SerializableGeeTreeMapTest.c"
				}
#line 224 "SerializableGeeTreeMapTest.vala"
				_tmp53_ = _k_it;
#line 224 "SerializableGeeTreeMapTest.vala"
				_tmp54_ = gee_iterator_get (_tmp53_);
#line 224 "SerializableGeeTreeMapTest.vala"
				k = (gchar*) _tmp54_;
#line 225 "SerializableGeeTreeMapTest.vala"
				_tmp55_ = c;
#line 225 "SerializableGeeTreeMapTest.vala"
				_tmp56_ = serializable_gee_tree_map_test_space_container_get_storage (_tmp55_);
#line 225 "SerializableGeeTreeMapTest.vala"
				_tmp57_ = _tmp56_;
#line 225 "SerializableGeeTreeMapTest.vala"
				_tmp58_ = k;
#line 225 "SerializableGeeTreeMapTest.vala"
				_tmp59_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp57_, _tmp58_);
#line 225 "SerializableGeeTreeMapTest.vala"
				_tmp60_ = (SerializableGeeTreeMapTestSpace*) _tmp59_;
#line 225 "SerializableGeeTreeMapTest.vala"
				_tmp61_ = serializable_gee_tree_map_test_space_get_name (_tmp60_);
#line 225 "SerializableGeeTreeMapTest.vala"
				_tmp62_ = _tmp61_;
#line 225 "SerializableGeeTreeMapTest.vala"
				_tmp63_ = g_strcmp0 (_tmp62_, "Big") == 0;
#line 225 "SerializableGeeTreeMapTest.vala"
				_g_object_unref0 (_tmp60_);
#line 225 "SerializableGeeTreeMapTest.vala"
				if (_tmp63_) {
#line 225 "SerializableGeeTreeMapTest.vala"
					found1 = TRUE;
#line 2011 "SerializableGeeTreeMapTest.c"
				}
#line 226 "SerializableGeeTreeMapTest.vala"
				_tmp64_ = c;
#line 226 "SerializableGeeTreeMapTest.vala"
				_tmp65_ = serializable_gee_tree_map_test_space_container_get_storage (_tmp64_);
#line 226 "SerializableGeeTreeMapTest.vala"
				_tmp66_ = _tmp65_;
#line 226 "SerializableGeeTreeMapTest.vala"
				_tmp67_ = k;
#line 226 "SerializableGeeTreeMapTest.vala"
				_tmp68_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp66_, _tmp67_);
#line 226 "SerializableGeeTreeMapTest.vala"
				_tmp69_ = (SerializableGeeTreeMapTestSpace*) _tmp68_;
#line 226 "SerializableGeeTreeMapTest.vala"
				_tmp70_ = serializable_gee_tree_map_test_space_get_name (_tmp69_);
#line 226 "SerializableGeeTreeMapTest.vala"
				_tmp71_ = _tmp70_;
#line 226 "SerializableGeeTreeMapTest.vala"
				_tmp72_ = g_strcmp0 (_tmp71_, "Small") == 0;
#line 226 "SerializableGeeTreeMapTest.vala"
				_g_object_unref0 (_tmp69_);
#line 226 "SerializableGeeTreeMapTest.vala"
				if (_tmp72_) {
#line 226 "SerializableGeeTreeMapTest.vala"
					found2 = TRUE;
#line 2037 "SerializableGeeTreeMapTest.c"
				}
#line 224 "SerializableGeeTreeMapTest.vala"
				_g_free0 (k);
#line 2041 "SerializableGeeTreeMapTest.c"
			}
#line 224 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (_k_it);
#line 2045 "SerializableGeeTreeMapTest.c"
		}
#line 228 "SerializableGeeTreeMapTest.vala"
		if (!found1) {
#line 2049 "SerializableGeeTreeMapTest.c"
			FILE* _tmp73_;
#line 229 "SerializableGeeTreeMapTest.vala"
			_tmp73_ = stdout;
#line 229 "SerializableGeeTreeMapTest.vala"
			fprintf (_tmp73_, "%s", "ERROR: Big key value is not found\n");
#line 230 "SerializableGeeTreeMapTest.vala"
			g_assert_not_reached ();
#line 2057 "SerializableGeeTreeMapTest.c"
		}
#line 232 "SerializableGeeTreeMapTest.vala"
		if (!found2) {
#line 2061 "SerializableGeeTreeMapTest.c"
			FILE* _tmp74_;
#line 233 "SerializableGeeTreeMapTest.vala"
			_tmp74_ = stdout;
#line 233 "SerializableGeeTreeMapTest.vala"
			fprintf (_tmp74_, "%s", "ERROR: Small key value is not found\n");
#line 234 "SerializableGeeTreeMapTest.vala"
			g_assert_not_reached ();
#line 2069 "SerializableGeeTreeMapTest.c"
		}
#line 205 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (c);
#line 205 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (doc);
#line 2075 "SerializableGeeTreeMapTest.c"
	}
	goto __finally348;
	__catch348_g_error:
	{
		GError* e = NULL;
		FILE* _tmp75_;
		const gchar* _tmp76_;
		const gchar* _tmp77_;
		gchar* _tmp78_;
		gchar* _tmp79_;
#line 205 "SerializableGeeTreeMapTest.vala"
		e = _inner_error0_;
#line 205 "SerializableGeeTreeMapTest.vala"
		_inner_error0_ = NULL;
#line 238 "SerializableGeeTreeMapTest.vala"
		_tmp75_ = stdout;
#line 238 "SerializableGeeTreeMapTest.vala"
		_tmp76_ = e->message;
#line 238 "SerializableGeeTreeMapTest.vala"
		_tmp77_ = string_to_string (_tmp76_);
#line 238 "SerializableGeeTreeMapTest.vala"
		_tmp78_ = g_strconcat ("ERROR: ", _tmp77_, NULL);
#line 238 "SerializableGeeTreeMapTest.vala"
		_tmp79_ = _tmp78_;
#line 238 "SerializableGeeTreeMapTest.vala"
		fprintf (_tmp75_, "%s", _tmp79_);
#line 238 "SerializableGeeTreeMapTest.vala"
		_g_free0 (_tmp79_);
#line 239 "SerializableGeeTreeMapTest.vala"
		g_assert_not_reached ();
#line 205 "SerializableGeeTreeMapTest.vala"
		_g_error_free0 (e);
#line 2108 "SerializableGeeTreeMapTest.c"
	}
	__finally348:
#line 205 "SerializableGeeTreeMapTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 205 "SerializableGeeTreeMapTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 205 "SerializableGeeTreeMapTest.vala"
		g_clear_error (&_inner_error0_);
#line 205 "SerializableGeeTreeMapTest.vala"
		return;
#line 2119 "SerializableGeeTreeMapTest.c"
	}
}

static void
___lambda295__gtest_func (void)
{
#line 203 "SerializableGeeTreeMapTest.vala"
	__lambda295_ ();
#line 2128 "SerializableGeeTreeMapTest.c"
}

static void
__lambda296_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		SerializableGeeTreeMapTestSpaceContainer* c = NULL;
		SerializableGeeTreeMapTestSpaceContainer* _tmp0_;
		SerializableGeeTreeMapTestSpace* o1 = NULL;
		SerializableGeeTreeMapTestSpace* _tmp1_;
		SerializableGeeTreeMapTestSpace* o2 = NULL;
		SerializableGeeTreeMapTestSpace* _tmp2_;
		SerializableGeeTreeMapTestSpaceCollection* _tmp3_;
		SerializableGeeTreeMapTestSpaceCollection* _tmp4_;
		SerializableGeeTreeMapTestSpaceCollection* _tmp5_;
		SerializableGeeTreeMapTestSpaceCollection* _tmp6_;
		const gchar* _tmp7_;
		const gchar* _tmp8_;
		SerializableGeeTreeMapTestSpaceCollection* _tmp9_;
		SerializableGeeTreeMapTestSpaceCollection* _tmp10_;
		const gchar* _tmp11_;
		const gchar* _tmp12_;
		GXmlTDocument* doc = NULL;
		GXmlTDocument* _tmp13_;
		GXmlNode* _tmp14_;
		GXmlNode* _tmp15_;
		GXmlNode* _tmp16_;
		GXmlNode* _tmp17_;
		GXmlNode* _tmp18_;
		gboolean _tmp19_;
		GXmlNode* _tmp25_;
		GXmlNode* _tmp26_;
		GXmlNode* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
		gchar* _tmp30_;
		gboolean _tmp31_;
		GXmlNode* root = NULL;
		GXmlNode* _tmp44_;
		GXmlNode* _tmp45_;
		GXmlNode* _tmp46_;
		GeeBidirList* _tmp47_;
		GeeBidirList* _tmp48_;
		GeeBidirList* _tmp49_;
		gint _tmp50_;
		gint _tmp51_;
		gboolean found1 = FALSE;
		gboolean found2 = FALSE;
#line 245 "SerializableGeeTreeMapTest.vala"
		_tmp0_ = serializable_gee_tree_map_test_space_container_new ();
#line 245 "SerializableGeeTreeMapTest.vala"
		c = _tmp0_;
#line 246 "SerializableGeeTreeMapTest.vala"
		_tmp1_ = serializable_gee_tree_map_test_space_new_named ("Big");
#line 246 "SerializableGeeTreeMapTest.vala"
		o1 = _tmp1_;
#line 247 "SerializableGeeTreeMapTest.vala"
		_tmp2_ = serializable_gee_tree_map_test_space_new_named ("Small");
#line 247 "SerializableGeeTreeMapTest.vala"
		o2 = _tmp2_;
#line 248 "SerializableGeeTreeMapTest.vala"
		_tmp3_ = serializable_gee_tree_map_test_space_collection_new ();
#line 248 "SerializableGeeTreeMapTest.vala"
		_tmp4_ = _tmp3_;
#line 248 "SerializableGeeTreeMapTest.vala"
		serializable_gee_tree_map_test_space_container_set_storage (c, _tmp4_);
#line 248 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp4_);
#line 249 "SerializableGeeTreeMapTest.vala"
		_tmp5_ = serializable_gee_tree_map_test_space_container_get_storage (c);
#line 249 "SerializableGeeTreeMapTest.vala"
		_tmp6_ = _tmp5_;
#line 249 "SerializableGeeTreeMapTest.vala"
		_tmp7_ = serializable_gee_tree_map_test_space_get_name (o1);
#line 249 "SerializableGeeTreeMapTest.vala"
		_tmp8_ = _tmp7_;
#line 249 "SerializableGeeTreeMapTest.vala"
		gee_abstract_map_set ((GeeAbstractMap*) _tmp6_, _tmp8_, o1);
#line 250 "SerializableGeeTreeMapTest.vala"
		_tmp9_ = serializable_gee_tree_map_test_space_container_get_storage (c);
#line 250 "SerializableGeeTreeMapTest.vala"
		_tmp10_ = _tmp9_;
#line 250 "SerializableGeeTreeMapTest.vala"
		_tmp11_ = serializable_gee_tree_map_test_space_get_name (o2);
#line 250 "SerializableGeeTreeMapTest.vala"
		_tmp12_ = _tmp11_;
#line 250 "SerializableGeeTreeMapTest.vala"
		gee_abstract_map_set ((GeeAbstractMap*) _tmp10_, _tmp12_, o2);
#line 251 "SerializableGeeTreeMapTest.vala"
		_tmp13_ = gxml_tdocument_new ();
#line 251 "SerializableGeeTreeMapTest.vala"
		doc = _tmp13_;
#line 252 "SerializableGeeTreeMapTest.vala"
		_tmp14_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) c, (GXmlNode*) doc, &_inner_error0_);
#line 252 "SerializableGeeTreeMapTest.vala"
		_tmp15_ = _tmp14_;
#line 252 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp15_);
#line 252 "SerializableGeeTreeMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 252 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (doc);
#line 252 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (o2);
#line 252 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (o1);
#line 252 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (c);
#line 2238 "SerializableGeeTreeMapTest.c"
			goto __catch349_g_error;
		}
#line 253 "SerializableGeeTreeMapTest.vala"
		_tmp16_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 253 "SerializableGeeTreeMapTest.vala"
		_tmp17_ = _tmp16_;
#line 253 "SerializableGeeTreeMapTest.vala"
		_tmp18_ = _tmp17_;
#line 253 "SerializableGeeTreeMapTest.vala"
		_tmp19_ = _tmp18_ == NULL;
#line 253 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp18_);
#line 253 "SerializableGeeTreeMapTest.vala"
		if (_tmp19_) {
#line 2253 "SerializableGeeTreeMapTest.c"
			FILE* _tmp20_;
			gchar* _tmp21_;
			gchar* _tmp22_;
			gchar* _tmp23_;
			gchar* _tmp24_;
#line 254 "SerializableGeeTreeMapTest.vala"
			_tmp20_ = stdout;
#line 254 "SerializableGeeTreeMapTest.vala"
			_tmp21_ = gxml_tnode_to_string ((GXmlTNode*) doc);
#line 254 "SerializableGeeTreeMapTest.vala"
			_tmp22_ = _tmp21_;
#line 254 "SerializableGeeTreeMapTest.vala"
			_tmp23_ = g_strconcat ("ERROR: doc have no root node\n", _tmp22_, "\n", NULL);
#line 254 "SerializableGeeTreeMapTest.vala"
			_tmp24_ = _tmp23_;
#line 254 "SerializableGeeTreeMapTest.vala"
			fprintf (_tmp20_, "%s", _tmp24_);
#line 254 "SerializableGeeTreeMapTest.vala"
			_g_free0 (_tmp24_);
#line 254 "SerializableGeeTreeMapTest.vala"
			_g_free0 (_tmp22_);
#line 255 "SerializableGeeTreeMapTest.vala"
			g_assert_not_reached ();
#line 2277 "SerializableGeeTreeMapTest.c"
		}
#line 257 "SerializableGeeTreeMapTest.vala"
		_tmp25_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 257 "SerializableGeeTreeMapTest.vala"
		_tmp26_ = _tmp25_;
#line 257 "SerializableGeeTreeMapTest.vala"
		_tmp27_ = _tmp26_;
#line 257 "SerializableGeeTreeMapTest.vala"
		_tmp28_ = gxml_node_get_name (_tmp27_);
#line 257 "SerializableGeeTreeMapTest.vala"
		_tmp29_ = _tmp28_;
#line 257 "SerializableGeeTreeMapTest.vala"
		_tmp30_ = _tmp29_;
#line 257 "SerializableGeeTreeMapTest.vala"
		_tmp31_ = g_strcmp0 (_tmp30_, "spacecontainer") != 0;
#line 257 "SerializableGeeTreeMapTest.vala"
		_g_free0 (_tmp30_);
#line 257 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp27_);
#line 257 "SerializableGeeTreeMapTest.vala"
		if (_tmp31_) {
#line 2299 "SerializableGeeTreeMapTest.c"
			FILE* _tmp32_;
			GXmlNode* _tmp33_;
			GXmlNode* _tmp34_;
			GXmlNode* _tmp35_;
			gchar* _tmp36_;
			gchar* _tmp37_;
			gchar* _tmp38_;
			const gchar* _tmp39_;
			gchar* _tmp40_;
			gchar* _tmp41_;
			gchar* _tmp42_;
			gchar* _tmp43_;
#line 258 "SerializableGeeTreeMapTest.vala"
			_tmp32_ = stdout;
#line 258 "SerializableGeeTreeMapTest.vala"
			_tmp33_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 258 "SerializableGeeTreeMapTest.vala"
			_tmp34_ = _tmp33_;
#line 258 "SerializableGeeTreeMapTest.vala"
			_tmp35_ = _tmp34_;
#line 258 "SerializableGeeTreeMapTest.vala"
			_tmp36_ = gxml_node_get_name (_tmp35_);
#line 258 "SerializableGeeTreeMapTest.vala"
			_tmp37_ = _tmp36_;
#line 258 "SerializableGeeTreeMapTest.vala"
			_tmp38_ = _tmp37_;
#line 258 "SerializableGeeTreeMapTest.vala"
			_tmp39_ = string_to_string (_tmp38_);
#line 258 "SerializableGeeTreeMapTest.vala"
			_tmp40_ = gxml_tnode_to_string ((GXmlTNode*) doc);
#line 258 "SerializableGeeTreeMapTest.vala"
			_tmp41_ = _tmp40_;
#line 258 "SerializableGeeTreeMapTest.vala"
			_tmp42_ = g_strconcat ("ERROR: bad doc root node's name: ", _tmp39_, "\n", _tmp41_, "\n", NULL);
#line 258 "SerializableGeeTreeMapTest.vala"
			_tmp43_ = _tmp42_;
#line 258 "SerializableGeeTreeMapTest.vala"
			fprintf (_tmp32_, "%s", _tmp43_);
#line 258 "SerializableGeeTreeMapTest.vala"
			_g_free0 (_tmp43_);
#line 258 "SerializableGeeTreeMapTest.vala"
			_g_free0 (_tmp41_);
#line 258 "SerializableGeeTreeMapTest.vala"
			_g_free0 (_tmp38_);
#line 258 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (_tmp35_);
#line 259 "SerializableGeeTreeMapTest.vala"
			g_assert_not_reached ();
#line 2348 "SerializableGeeTreeMapTest.c"
		}
#line 261 "SerializableGeeTreeMapTest.vala"
		_tmp44_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 261 "SerializableGeeTreeMapTest.vala"
		_tmp45_ = _tmp44_;
#line 261 "SerializableGeeTreeMapTest.vala"
		root = _tmp45_;
#line 262 "SerializableGeeTreeMapTest.vala"
		_tmp46_ = root;
#line 262 "SerializableGeeTreeMapTest.vala"
		_tmp47_ = gxml_node_get_children_nodes (_tmp46_);
#line 262 "SerializableGeeTreeMapTest.vala"
		_tmp48_ = _tmp47_;
#line 262 "SerializableGeeTreeMapTest.vala"
		_tmp49_ = _tmp48_;
#line 262 "SerializableGeeTreeMapTest.vala"
		_tmp50_ = gee_collection_get_size ((GeeCollection*) _tmp49_);
#line 262 "SerializableGeeTreeMapTest.vala"
		_tmp51_ = _tmp50_;
#line 262 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp51_ == 2, "root.children_nodes.size == 2");
#line 262 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp49_);
#line 263 "SerializableGeeTreeMapTest.vala"
		found1 = FALSE;
#line 264 "SerializableGeeTreeMapTest.vala"
		found2 = FALSE;
#line 2376 "SerializableGeeTreeMapTest.c"
		{
			GeeBidirList* _n_list = NULL;
			GXmlNode* _tmp52_;
			GeeBidirList* _tmp53_;
			GeeBidirList* _tmp54_;
			gint _n_size = 0;
			GeeBidirList* _tmp55_;
			gint _tmp56_;
			gint _tmp57_;
			gint _n_index = 0;
#line 265 "SerializableGeeTreeMapTest.vala"
			_tmp52_ = root;
#line 265 "SerializableGeeTreeMapTest.vala"
			_tmp53_ = gxml_node_get_children_nodes (_tmp52_);
#line 265 "SerializableGeeTreeMapTest.vala"
			_tmp54_ = _tmp53_;
#line 265 "SerializableGeeTreeMapTest.vala"
			_n_list = _tmp54_;
#line 265 "SerializableGeeTreeMapTest.vala"
			_tmp55_ = _n_list;
#line 265 "SerializableGeeTreeMapTest.vala"
			_tmp56_ = gee_collection_get_size ((GeeCollection*) _tmp55_);
#line 265 "SerializableGeeTreeMapTest.vala"
			_tmp57_ = _tmp56_;
#line 265 "SerializableGeeTreeMapTest.vala"
			_n_size = _tmp57_;
#line 265 "SerializableGeeTreeMapTest.vala"
			_n_index = -1;
#line 265 "SerializableGeeTreeMapTest.vala"
			while (TRUE) {
#line 2407 "SerializableGeeTreeMapTest.c"
				GXmlNode* n = NULL;
				GeeBidirList* _tmp58_;
				gpointer _tmp59_;
				gboolean _tmp60_ = FALSE;
				GXmlNode* _tmp61_;
#line 265 "SerializableGeeTreeMapTest.vala"
				_n_index = _n_index + 1;
#line 265 "SerializableGeeTreeMapTest.vala"
				if (!(_n_index < _n_size)) {
#line 265 "SerializableGeeTreeMapTest.vala"
					break;
#line 2419 "SerializableGeeTreeMapTest.c"
				}
#line 265 "SerializableGeeTreeMapTest.vala"
				_tmp58_ = _n_list;
#line 265 "SerializableGeeTreeMapTest.vala"
				_tmp59_ = gee_list_get ((GeeList*) _tmp58_, _n_index);
#line 265 "SerializableGeeTreeMapTest.vala"
				n = (GXmlNode*) _tmp59_;
#line 266 "SerializableGeeTreeMapTest.vala"
				_tmp61_ = n;
#line 266 "SerializableGeeTreeMapTest.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp61_, GXML_TYPE_ELEMENT)) {
#line 2431 "SerializableGeeTreeMapTest.c"
					GXmlNode* _tmp62_;
					gchar* _tmp63_;
					gchar* _tmp64_;
					gchar* _tmp65_;
#line 266 "SerializableGeeTreeMapTest.vala"
					_tmp62_ = n;
#line 266 "SerializableGeeTreeMapTest.vala"
					_tmp63_ = gxml_node_get_name (_tmp62_);
#line 266 "SerializableGeeTreeMapTest.vala"
					_tmp64_ = _tmp63_;
#line 266 "SerializableGeeTreeMapTest.vala"
					_tmp65_ = _tmp64_;
#line 266 "SerializableGeeTreeMapTest.vala"
					_tmp60_ = g_strcmp0 (_tmp65_, "space") == 0;
#line 266 "SerializableGeeTreeMapTest.vala"
					_g_free0 (_tmp65_);
#line 2448 "SerializableGeeTreeMapTest.c"
				} else {
#line 266 "SerializableGeeTreeMapTest.vala"
					_tmp60_ = FALSE;
#line 2452 "SerializableGeeTreeMapTest.c"
				}
#line 266 "SerializableGeeTreeMapTest.vala"
				if (_tmp60_) {
#line 2456 "SerializableGeeTreeMapTest.c"
					GXmlNode* name = NULL;
					GXmlNode* _tmp66_;
					GeeMap* _tmp67_;
					GeeMap* _tmp68_;
					GeeMap* _tmp69_;
					gpointer _tmp70_;
					GXmlNode* _tmp71_;
					GXmlNode* _tmp72_;
#line 267 "SerializableGeeTreeMapTest.vala"
					_tmp66_ = n;
#line 267 "SerializableGeeTreeMapTest.vala"
					_tmp67_ = gxml_node_get_attrs (_tmp66_);
#line 267 "SerializableGeeTreeMapTest.vala"
					_tmp68_ = _tmp67_;
#line 267 "SerializableGeeTreeMapTest.vala"
					_tmp69_ = _tmp68_;
#line 267 "SerializableGeeTreeMapTest.vala"
					_tmp70_ = gee_map_get (_tmp69_, "name");
#line 267 "SerializableGeeTreeMapTest.vala"
					_tmp71_ = (GXmlNode*) _tmp70_;
#line 267 "SerializableGeeTreeMapTest.vala"
					_g_object_unref0 (_tmp69_);
#line 267 "SerializableGeeTreeMapTest.vala"
					name = _tmp71_;
#line 268 "SerializableGeeTreeMapTest.vala"
					_tmp72_ = name;
#line 268 "SerializableGeeTreeMapTest.vala"
					if (_tmp72_ != NULL) {
#line 2485 "SerializableGeeTreeMapTest.c"
						GXmlNode* _tmp73_;
						gchar* _tmp74_;
						gchar* _tmp75_;
						gchar* _tmp76_;
						gboolean _tmp77_;
						GXmlNode* _tmp78_;
						gchar* _tmp79_;
						gchar* _tmp80_;
						gchar* _tmp81_;
						gboolean _tmp82_;
#line 269 "SerializableGeeTreeMapTest.vala"
						_tmp73_ = name;
#line 269 "SerializableGeeTreeMapTest.vala"
						_tmp74_ = gxml_node_get_value (_tmp73_);
#line 269 "SerializableGeeTreeMapTest.vala"
						_tmp75_ = _tmp74_;
#line 269 "SerializableGeeTreeMapTest.vala"
						_tmp76_ = _tmp75_;
#line 269 "SerializableGeeTreeMapTest.vala"
						_tmp77_ = g_strcmp0 (_tmp76_, "Big") == 0;
#line 269 "SerializableGeeTreeMapTest.vala"
						_g_free0 (_tmp76_);
#line 269 "SerializableGeeTreeMapTest.vala"
						if (_tmp77_) {
#line 269 "SerializableGeeTreeMapTest.vala"
							found1 = TRUE;
#line 2512 "SerializableGeeTreeMapTest.c"
						}
#line 270 "SerializableGeeTreeMapTest.vala"
						_tmp78_ = name;
#line 270 "SerializableGeeTreeMapTest.vala"
						_tmp79_ = gxml_node_get_value (_tmp78_);
#line 270 "SerializableGeeTreeMapTest.vala"
						_tmp80_ = _tmp79_;
#line 270 "SerializableGeeTreeMapTest.vala"
						_tmp81_ = _tmp80_;
#line 270 "SerializableGeeTreeMapTest.vala"
						_tmp82_ = g_strcmp0 (_tmp81_, "Small") == 0;
#line 270 "SerializableGeeTreeMapTest.vala"
						_g_free0 (_tmp81_);
#line 270 "SerializableGeeTreeMapTest.vala"
						if (_tmp82_) {
#line 270 "SerializableGeeTreeMapTest.vala"
							found2 = TRUE;
#line 2530 "SerializableGeeTreeMapTest.c"
						}
					}
#line 266 "SerializableGeeTreeMapTest.vala"
					_g_object_unref0 (name);
#line 2535 "SerializableGeeTreeMapTest.c"
				}
#line 265 "SerializableGeeTreeMapTest.vala"
				_g_object_unref0 (n);
#line 2539 "SerializableGeeTreeMapTest.c"
			}
#line 265 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (_n_list);
#line 2543 "SerializableGeeTreeMapTest.c"
		}
#line 274 "SerializableGeeTreeMapTest.vala"
		if (!found1) {
#line 2547 "SerializableGeeTreeMapTest.c"
			FILE* _tmp83_;
			gchar* _tmp84_;
			gchar* _tmp85_;
			gchar* _tmp86_;
			gchar* _tmp87_;
#line 275 "SerializableGeeTreeMapTest.vala"
			_tmp83_ = stdout;
#line 275 "SerializableGeeTreeMapTest.vala"
			_tmp84_ = gxml_tnode_to_string ((GXmlTNode*) doc);
#line 275 "SerializableGeeTreeMapTest.vala"
			_tmp85_ = _tmp84_;
#line 275 "SerializableGeeTreeMapTest.vala"
			_tmp86_ = g_strconcat ("ERROR: Big space node is not found\n", _tmp85_, "\n", NULL);
#line 275 "SerializableGeeTreeMapTest.vala"
			_tmp87_ = _tmp86_;
#line 275 "SerializableGeeTreeMapTest.vala"
			fprintf (_tmp83_, "%s", _tmp87_);
#line 275 "SerializableGeeTreeMapTest.vala"
			_g_free0 (_tmp87_);
#line 275 "SerializableGeeTreeMapTest.vala"
			_g_free0 (_tmp85_);
#line 276 "SerializableGeeTreeMapTest.vala"
			g_assert_not_reached ();
#line 2571 "SerializableGeeTreeMapTest.c"
		}
#line 278 "SerializableGeeTreeMapTest.vala"
		if (!found2) {
#line 2575 "SerializableGeeTreeMapTest.c"
			FILE* _tmp88_;
			gchar* _tmp89_;
			gchar* _tmp90_;
			gchar* _tmp91_;
			gchar* _tmp92_;
#line 279 "SerializableGeeTreeMapTest.vala"
			_tmp88_ = stdout;
#line 279 "SerializableGeeTreeMapTest.vala"
			_tmp89_ = gxml_tnode_to_string ((GXmlTNode*) doc);
#line 279 "SerializableGeeTreeMapTest.vala"
			_tmp90_ = _tmp89_;
#line 279 "SerializableGeeTreeMapTest.vala"
			_tmp91_ = g_strconcat ("ERROR: Small space node is not found\n", _tmp90_, "\n", NULL);
#line 279 "SerializableGeeTreeMapTest.vala"
			_tmp92_ = _tmp91_;
#line 279 "SerializableGeeTreeMapTest.vala"
			fprintf (_tmp88_, "%s", _tmp92_);
#line 279 "SerializableGeeTreeMapTest.vala"
			_g_free0 (_tmp92_);
#line 279 "SerializableGeeTreeMapTest.vala"
			_g_free0 (_tmp90_);
#line 280 "SerializableGeeTreeMapTest.vala"
			g_assert_not_reached ();
#line 2599 "SerializableGeeTreeMapTest.c"
		}
#line 244 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (root);
#line 244 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (doc);
#line 244 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (o2);
#line 244 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (o1);
#line 244 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (c);
#line 2611 "SerializableGeeTreeMapTest.c"
	}
	goto __finally349;
	__catch349_g_error:
	{
		GError* e = NULL;
		FILE* _tmp93_;
		const gchar* _tmp94_;
		const gchar* _tmp95_;
		gchar* _tmp96_;
		gchar* _tmp97_;
#line 244 "SerializableGeeTreeMapTest.vala"
		e = _inner_error0_;
#line 244 "SerializableGeeTreeMapTest.vala"
		_inner_error0_ = NULL;
#line 284 "SerializableGeeTreeMapTest.vala"
		_tmp93_ = stdout;
#line 284 "SerializableGeeTreeMapTest.vala"
		_tmp94_ = e->message;
#line 284 "SerializableGeeTreeMapTest.vala"
		_tmp95_ = string_to_string (_tmp94_);
#line 284 "SerializableGeeTreeMapTest.vala"
		_tmp96_ = g_strconcat ("ERROR: ", _tmp95_, NULL);
#line 284 "SerializableGeeTreeMapTest.vala"
		_tmp97_ = _tmp96_;
#line 284 "SerializableGeeTreeMapTest.vala"
		fprintf (_tmp93_, "%s", _tmp97_);
#line 284 "SerializableGeeTreeMapTest.vala"
		_g_free0 (_tmp97_);
#line 285 "SerializableGeeTreeMapTest.vala"
		g_assert_not_reached ();
#line 244 "SerializableGeeTreeMapTest.vala"
		_g_error_free0 (e);
#line 2644 "SerializableGeeTreeMapTest.c"
	}
	__finally349:
#line 244 "SerializableGeeTreeMapTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 244 "SerializableGeeTreeMapTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 244 "SerializableGeeTreeMapTest.vala"
		g_clear_error (&_inner_error0_);
#line 244 "SerializableGeeTreeMapTest.vala"
		return;
#line 2655 "SerializableGeeTreeMapTest.c"
	}
}

static void
___lambda296__gtest_func (void)
{
#line 242 "SerializableGeeTreeMapTest.vala"
	__lambda296_ ();
#line 2664 "SerializableGeeTreeMapTest.c"
}

static void
__lambda297_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* d = NULL;
		GXmlGDocument* _tmp0_;
		BookStore* bs = NULL;
		BookStore* _tmp1_;
		BookStore* _tmp2_;
		GXmlGDocument* _tmp3_;
		BookStore* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		BookStore* _tmp7_;
		BookArray* _tmp8_;
		BookArray* _tmp9_;
		gint _tmp10_;
		gint _tmp11_;
		Book* b = NULL;
		BookStore* _tmp12_;
		BookArray* _tmp13_;
		BookArray* _tmp14_;
		gpointer _tmp15_;
		Name* _tmp16_;
		Name* _tmp17_;
		Name* _tmp18_;
		Name* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		const gchar* _tmp22_;
		const gchar* _tmp23_;
		Authors* _tmp24_;
		Authors* _tmp25_;
		Authors* _tmp26_;
		Authors* _tmp27_;
		AuthorArray* _tmp28_;
		AuthorArray* _tmp29_;
		Authors* _tmp30_;
		Authors* _tmp31_;
		AuthorArray* _tmp32_;
		AuthorArray* _tmp33_;
		gint _tmp34_;
		gint _tmp35_;
		ResumeMap* _tmp36_;
		ResumeMap* _tmp37_;
		ResumeMap* _tmp38_;
		ResumeMap* _tmp39_;
		gint _tmp40_;
		gint _tmp41_;
		Resume* r = NULL;
		ResumeMap* _tmp42_;
		ResumeMap* _tmp43_;
		gpointer _tmp44_;
		const gchar* _tmp45_;
		const gchar* _tmp46_;
		const gchar* _tmp47_;
		const gchar* _tmp48_;
#line 291 "SerializableGeeTreeMapTest.vala"
		_tmp0_ = gxml_gdocument_new_from_path (TEST_DIR "/test-collection.xml", 0, &_inner_error0_);
#line 291 "SerializableGeeTreeMapTest.vala"
		d = _tmp0_;
#line 291 "SerializableGeeTreeMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2731 "SerializableGeeTreeMapTest.c"
			goto __catch350_g_error;
		}
#line 292 "SerializableGeeTreeMapTest.vala"
		_tmp1_ = book_store_new ();
#line 292 "SerializableGeeTreeMapTest.vala"
		bs = _tmp1_;
#line 293 "SerializableGeeTreeMapTest.vala"
		_tmp2_ = bs;
#line 293 "SerializableGeeTreeMapTest.vala"
		_tmp3_ = d;
#line 293 "SerializableGeeTreeMapTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 293 "SerializableGeeTreeMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 293 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bs);
#line 293 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (d);
#line 2750 "SerializableGeeTreeMapTest.c"
			goto __catch350_g_error;
		}
#line 294 "SerializableGeeTreeMapTest.vala"
		_tmp4_ = bs;
#line 294 "SerializableGeeTreeMapTest.vala"
		_tmp5_ = book_store_get_name (_tmp4_);
#line 294 "SerializableGeeTreeMapTest.vala"
		_tmp6_ = _tmp5_;
#line 294 "SerializableGeeTreeMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp6_, "The Great Book") == 0, "bs.name == \"The Great Book\"");
#line 295 "SerializableGeeTreeMapTest.vala"
		_tmp7_ = bs;
#line 295 "SerializableGeeTreeMapTest.vala"
		_tmp8_ = book_store_get_books (_tmp7_);
#line 295 "SerializableGeeTreeMapTest.vala"
		_tmp9_ = _tmp8_;
#line 295 "SerializableGeeTreeMapTest.vala"
		_tmp10_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp9_);
#line 295 "SerializableGeeTreeMapTest.vala"
		_tmp11_ = _tmp10_;
#line 295 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp11_ == 3, "bs.books.size == 3");
#line 296 "SerializableGeeTreeMapTest.vala"
		_tmp12_ = bs;
#line 296 "SerializableGeeTreeMapTest.vala"
		_tmp13_ = book_store_get_books (_tmp12_);
#line 296 "SerializableGeeTreeMapTest.vala"
		_tmp14_ = _tmp13_;
#line 296 "SerializableGeeTreeMapTest.vala"
		_tmp15_ = gee_list_first ((GeeList*) _tmp14_);
#line 296 "SerializableGeeTreeMapTest.vala"
		b = (Book*) _tmp15_;
#line 297 "SerializableGeeTreeMapTest.vala"
		_vala_assert (b != NULL, "b != null");
#line 298 "SerializableGeeTreeMapTest.vala"
		_tmp16_ = book_get_name (b);
#line 298 "SerializableGeeTreeMapTest.vala"
		_tmp17_ = _tmp16_;
#line 298 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp17_ != NULL, "b.name != null");
#line 299 "SerializableGeeTreeMapTest.vala"
		_tmp18_ = book_get_name (b);
#line 299 "SerializableGeeTreeMapTest.vala"
		_tmp19_ = _tmp18_;
#line 299 "SerializableGeeTreeMapTest.vala"
		_tmp20_ = name_get_name (_tmp19_);
#line 299 "SerializableGeeTreeMapTest.vala"
		_tmp21_ = _tmp20_;
#line 299 "SerializableGeeTreeMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp21_, "Book1") == 0, "b.name.get_name () == \"Book1\"");
#line 299 "SerializableGeeTreeMapTest.vala"
		_g_free0 (_tmp21_);
#line 300 "SerializableGeeTreeMapTest.vala"
		_tmp22_ = book_get_year (b);
#line 300 "SerializableGeeTreeMapTest.vala"
		_tmp23_ = _tmp22_;
#line 300 "SerializableGeeTreeMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp23_, "2015") == 0, "b.year == \"2015\"");
#line 301 "SerializableGeeTreeMapTest.vala"
		_tmp24_ = book_get_authors (b);
#line 301 "SerializableGeeTreeMapTest.vala"
		_tmp25_ = _tmp24_;
#line 301 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp25_ != NULL, "b.authors != null");
#line 302 "SerializableGeeTreeMapTest.vala"
		_tmp26_ = book_get_authors (b);
#line 302 "SerializableGeeTreeMapTest.vala"
		_tmp27_ = _tmp26_;
#line 302 "SerializableGeeTreeMapTest.vala"
		_tmp28_ = authors_get_array (_tmp27_);
#line 302 "SerializableGeeTreeMapTest.vala"
		_tmp29_ = _tmp28_;
#line 302 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp29_ != NULL, "b.authors.array != null");
#line 303 "SerializableGeeTreeMapTest.vala"
		_tmp30_ = book_get_authors (b);
#line 303 "SerializableGeeTreeMapTest.vala"
		_tmp31_ = _tmp30_;
#line 303 "SerializableGeeTreeMapTest.vala"
		_tmp32_ = authors_get_array (_tmp31_);
#line 303 "SerializableGeeTreeMapTest.vala"
		_tmp33_ = _tmp32_;
#line 303 "SerializableGeeTreeMapTest.vala"
		_tmp34_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp33_);
#line 303 "SerializableGeeTreeMapTest.vala"
		_tmp35_ = _tmp34_;
#line 303 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp35_ == 2, "b.authors.array.size == 2");
#line 304 "SerializableGeeTreeMapTest.vala"
		_tmp36_ = book_get_resumes (b);
#line 304 "SerializableGeeTreeMapTest.vala"
		_tmp37_ = _tmp36_;
#line 304 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp37_ != NULL, "b.resumes != null");
#line 305 "SerializableGeeTreeMapTest.vala"
		_tmp38_ = book_get_resumes (b);
#line 305 "SerializableGeeTreeMapTest.vala"
		_tmp39_ = _tmp38_;
#line 305 "SerializableGeeTreeMapTest.vala"
		_tmp40_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp39_);
#line 305 "SerializableGeeTreeMapTest.vala"
		_tmp41_ = _tmp40_;
#line 305 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp41_ == 2, "b.resumes.size == 2");
#line 306 "SerializableGeeTreeMapTest.vala"
		_tmp42_ = book_get_resumes (b);
#line 306 "SerializableGeeTreeMapTest.vala"
		_tmp43_ = _tmp42_;
#line 306 "SerializableGeeTreeMapTest.vala"
		_tmp44_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp43_, "II");
#line 306 "SerializableGeeTreeMapTest.vala"
		r = (Resume*) _tmp44_;
#line 307 "SerializableGeeTreeMapTest.vala"
		_vala_assert (r != NULL, "r != null");
#line 308 "SerializableGeeTreeMapTest.vala"
		_tmp45_ = resume_get_chapter (r);
#line 308 "SerializableGeeTreeMapTest.vala"
		_tmp46_ = _tmp45_;
#line 308 "SerializableGeeTreeMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp46_, "II") == 0, "r.chapter == \"II\"");
#line 309 "SerializableGeeTreeMapTest.vala"
		_tmp47_ = resume_get_text (r);
#line 309 "SerializableGeeTreeMapTest.vala"
		_tmp48_ = _tmp47_;
#line 309 "SerializableGeeTreeMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp48_, "Nothing to say") == 0, "r.text == \"Nothing to say\"");
#line 290 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (r);
#line 290 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (b);
#line 290 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (bs);
#line 290 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (d);
#line 2885 "SerializableGeeTreeMapTest.c"
	}
	goto __finally350;
	__catch350_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp49_;
		gchar* _tmp50_;
		gchar* _tmp51_;
#line 290 "SerializableGeeTreeMapTest.vala"
		e = _inner_error0_;
#line 290 "SerializableGeeTreeMapTest.vala"
		_inner_error0_ = NULL;
#line 311 "SerializableGeeTreeMapTest.vala"
		_tmp49_ = e->message;
#line 311 "SerializableGeeTreeMapTest.vala"
		_tmp50_ = g_strconcat ("ERROR: ", _tmp49_, NULL);
#line 311 "SerializableGeeTreeMapTest.vala"
		_tmp51_ = _tmp50_;
#line 311 "SerializableGeeTreeMapTest.vala"
		g_message ("SerializableGeeTreeMapTest.vala:311: %s", _tmp51_);
#line 311 "SerializableGeeTreeMapTest.vala"
		_g_free0 (_tmp51_);
#line 312 "SerializableGeeTreeMapTest.vala"
		g_assert_not_reached ();
#line 290 "SerializableGeeTreeMapTest.vala"
		_g_error_free0 (e);
#line 2912 "SerializableGeeTreeMapTest.c"
	}
	__finally350:
#line 290 "SerializableGeeTreeMapTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 290 "SerializableGeeTreeMapTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 290 "SerializableGeeTreeMapTest.vala"
		g_clear_error (&_inner_error0_);
#line 290 "SerializableGeeTreeMapTest.vala"
		return;
#line 2923 "SerializableGeeTreeMapTest.c"
	}
}

static void
___lambda297__gtest_func (void)
{
#line 288 "SerializableGeeTreeMapTest.vala"
	__lambda297_ ();
#line 2932 "SerializableGeeTreeMapTest.c"
}

static void
__lambda298_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		SerializableGeeTreeMapTestBigBag* bag = NULL;
		SerializableGeeTreeMapTestBigBag* _tmp0_;
		SerializableGeeTreeMapTestBigBag* _tmp1_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp2_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp3_;
		SerializableGeeTreeMapTestBigBag* _tmp48_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp49_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp50_;
		gint _tmp51_;
		gint _tmp52_;
		GXmlGDocument* d = NULL;
		GXmlGDocument* _tmp53_;
		SerializableGeeTreeMapTestBigBag* _tmp54_;
		GXmlGDocument* _tmp55_;
		GXmlNode* _tmp56_;
		GXmlNode* _tmp57_;
		GXmlGDocument* _tmp58_;
		GXmlNode* _tmp59_;
		GXmlNode* _tmp60_;
		GXmlNode* _tmp61_;
		GXmlGDocument* _tmp62_;
		GXmlNode* _tmp63_;
		GXmlNode* _tmp64_;
		GXmlNode* _tmp65_;
		gchar* _tmp66_;
		gchar* _tmp67_;
		gchar* _tmp68_;
		GXmlGDocument* _tmp69_;
		GXmlNode* _tmp70_;
		GXmlNode* _tmp71_;
		GXmlNode* _tmp72_;
		GeeBidirList* _tmp73_;
		GeeBidirList* _tmp74_;
		GeeBidirList* _tmp75_;
		gint _tmp76_;
		gint _tmp77_;
		GXmlGDocument* _tmp78_;
		GXmlNode* _tmp79_;
		GXmlNode* _tmp80_;
		GXmlNode* _tmp81_;
		GeeBidirList* _tmp82_;
		GeeBidirList* _tmp83_;
		GeeBidirList* _tmp84_;
		gpointer _tmp85_;
		GXmlNode* _tmp86_;
		gchar* _tmp87_;
		gchar* _tmp88_;
		gchar* _tmp89_;
		GXmlGDocument* _tmp90_;
		GXmlNode* _tmp91_;
		GXmlNode* _tmp92_;
		GXmlNode* _tmp93_;
		GeeBidirList* _tmp94_;
		GeeBidirList* _tmp95_;
		GeeBidirList* _tmp96_;
		gpointer _tmp97_;
		GXmlNode* _tmp98_;
		GeeBidirList* _tmp99_;
		GeeBidirList* _tmp100_;
		GeeBidirList* _tmp101_;
		gint _tmp102_;
		gint _tmp103_;
		GXmlGDocument* _tmp104_;
		GXmlNode* _tmp105_;
		GXmlNode* _tmp106_;
		GXmlNode* _tmp107_;
		GeeBidirList* _tmp108_;
		GeeBidirList* _tmp109_;
		GeeBidirList* _tmp110_;
		gpointer _tmp111_;
		GXmlNode* _tmp112_;
		GeeBidirList* _tmp113_;
		GeeBidirList* _tmp114_;
		GeeBidirList* _tmp115_;
		gpointer _tmp116_;
		GXmlNode* _tmp117_;
		gchar* _tmp118_;
		gchar* _tmp119_;
		gchar* _tmp120_;
		GXmlGDocument* _tmp121_;
		GXmlNode* _tmp122_;
		GXmlNode* _tmp123_;
		GXmlNode* _tmp124_;
		GeeBidirList* _tmp125_;
		GeeBidirList* _tmp126_;
		GeeBidirList* _tmp127_;
		gpointer _tmp128_;
		GXmlNode* _tmp129_;
		GeeBidirList* _tmp130_;
		GeeBidirList* _tmp131_;
		GeeBidirList* _tmp132_;
		gpointer _tmp133_;
		GXmlNode* _tmp134_;
		GeeBidirList* _tmp135_;
		GeeBidirList* _tmp136_;
		GeeBidirList* _tmp137_;
		gint _tmp138_;
		gint _tmp139_;
		GXmlGDocument* _tmp140_;
		GXmlNode* _tmp141_;
		GXmlNode* _tmp142_;
		GXmlNode* _tmp143_;
		GeeBidirList* _tmp144_;
		GeeBidirList* _tmp145_;
		GeeBidirList* _tmp146_;
		gpointer _tmp147_;
		GXmlNode* _tmp148_;
		GeeBidirList* _tmp149_;
		GeeBidirList* _tmp150_;
		GeeBidirList* _tmp151_;
		gpointer _tmp152_;
		GXmlNode* _tmp153_;
		GeeBidirList* _tmp154_;
		GeeBidirList* _tmp155_;
		GeeBidirList* _tmp156_;
		gpointer _tmp157_;
		GXmlNode* _tmp158_;
		gchar* _tmp159_;
		gchar* _tmp160_;
		gchar* _tmp161_;
		GXmlGDocument* _tmp162_;
		GXmlNode* _tmp163_;
		GXmlNode* _tmp164_;
		GXmlNode* _tmp165_;
		GeeBidirList* _tmp166_;
		GeeBidirList* _tmp167_;
		GeeBidirList* _tmp168_;
		gpointer _tmp169_;
		GXmlNode* _tmp170_;
		GeeBidirList* _tmp171_;
		GeeBidirList* _tmp172_;
		GeeBidirList* _tmp173_;
		gpointer _tmp174_;
		GXmlNode* _tmp175_;
		GeeBidirList* _tmp176_;
		GeeBidirList* _tmp177_;
		GeeBidirList* _tmp178_;
		gpointer _tmp179_;
		GXmlNode* _tmp180_;
		GeeBidirList* _tmp181_;
		GeeBidirList* _tmp182_;
		GeeBidirList* _tmp183_;
		gint _tmp184_;
		gint _tmp185_;
		GXmlGDocument* _tmp186_;
		GXmlNode* _tmp187_;
		GXmlNode* _tmp188_;
		GXmlNode* _tmp189_;
		GeeBidirList* _tmp190_;
		GeeBidirList* _tmp191_;
		GeeBidirList* _tmp192_;
		gpointer _tmp193_;
		GXmlNode* _tmp194_;
		GeeBidirList* _tmp195_;
		GeeBidirList* _tmp196_;
		GeeBidirList* _tmp197_;
		gpointer _tmp198_;
		GXmlNode* _tmp199_;
		GeeBidirList* _tmp200_;
		GeeBidirList* _tmp201_;
		GeeBidirList* _tmp202_;
		gpointer _tmp203_;
		GXmlNode* _tmp204_;
		GeeBidirList* _tmp205_;
		GeeBidirList* _tmp206_;
		GeeBidirList* _tmp207_;
		gpointer _tmp208_;
		GXmlNode* _tmp209_;
		GXmlGDocument* _tmp210_;
		GXmlNode* _tmp211_;
		GXmlNode* _tmp212_;
		GXmlNode* _tmp213_;
		GeeBidirList* _tmp214_;
		GeeBidirList* _tmp215_;
		GeeBidirList* _tmp216_;
		gpointer _tmp217_;
		GXmlNode* _tmp218_;
		GeeBidirList* _tmp219_;
		GeeBidirList* _tmp220_;
		GeeBidirList* _tmp221_;
		gpointer _tmp222_;
		GXmlNode* _tmp223_;
		GeeBidirList* _tmp224_;
		GeeBidirList* _tmp225_;
		GeeBidirList* _tmp226_;
		gpointer _tmp227_;
		GXmlNode* _tmp228_;
		GeeBidirList* _tmp229_;
		GeeBidirList* _tmp230_;
		GeeBidirList* _tmp231_;
		gpointer _tmp232_;
		GXmlNode* _tmp233_;
		gchar* _tmp234_;
		gchar* _tmp235_;
		gchar* _tmp236_;
		SerializableGeeTreeMapTestBigBag* bagt = NULL;
		SerializableGeeTreeMapTestBigBag* _tmp237_;
		SerializableGeeTreeMapTestBigBag* _tmp238_;
		GXmlGDocument* _tmp239_;
		SerializableGeeTreeMapTestBigBag* _tmp240_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp241_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp242_;
		gint _tmp243_;
		gint _tmp244_;
		gboolean _tmp245_ = FALSE;
		SerializableGeeTreeMapTestBigBag* _tmp246_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp247_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp248_;
		SerializableGeeTreeMapTestBigBag* _tmp249_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp250_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp251_;
		gint _tmp252_;
		gint _tmp253_;
		gboolean _tmp254_ = FALSE;
		SerializableGeeTreeMapTestBigBag* _tmp255_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp256_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp257_;
		gpointer _tmp258_;
		SerializableGeeTreeMapTestSmallBag* _tmp259_;
		SerializableGeeTreeMapTestBallTreeMap* _tmp260_;
		SerializableGeeTreeMapTestBallTreeMap* _tmp261_;
		gboolean _tmp262_;
		SerializableGeeTreeMapTestBigBag* _tmp263_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp264_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp265_;
		gpointer _tmp266_;
		SerializableGeeTreeMapTestSmallBag* _tmp267_;
		SerializableGeeTreeMapTestBallTreeMap* _tmp268_;
		SerializableGeeTreeMapTestBallTreeMap* _tmp269_;
		gint _tmp270_;
		gint _tmp271_;
		SerializableGeeTreeMapTestBigBag* _tmp272_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp273_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp274_;
		gpointer _tmp275_;
		SerializableGeeTreeMapTestSmallBag* _tmp276_;
		SerializableGeeTreeMapTestBallTreeMap* _tmp277_;
		SerializableGeeTreeMapTestBallTreeMap* _tmp278_;
		gpointer _tmp279_;
		SerializableGeeTreeMapTestBall* _tmp280_;
		const gchar* _tmp281_;
		const gchar* _tmp282_;
		SerializableGeeTreeMapTestBigBag* _tmp283_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp284_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp285_;
		gpointer _tmp286_;
		SerializableGeeTreeMapTestSmallBag* _tmp287_;
		SerializableGeeTreeMapTestBallTreeMap* _tmp288_;
		SerializableGeeTreeMapTestBallTreeMap* _tmp289_;
		gpointer _tmp290_;
		SerializableGeeTreeMapTestBall* _tmp291_;
		SerializableGeeTreeMapTestBallFill* _tmp292_;
		SerializableGeeTreeMapTestBallFill* _tmp293_;
		SerializableGeeTreeMapTestBigBag* _tmp294_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp295_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp296_;
		gpointer _tmp297_;
		SerializableGeeTreeMapTestSmallBag* _tmp298_;
		SerializableGeeTreeMapTestBallTreeMap* _tmp299_;
		SerializableGeeTreeMapTestBallTreeMap* _tmp300_;
		gpointer _tmp301_;
		SerializableGeeTreeMapTestBall* _tmp302_;
		SerializableGeeTreeMapTestBallFill* _tmp303_;
		SerializableGeeTreeMapTestBallFill* _tmp304_;
		gchar* _tmp305_;
		gchar* _tmp306_;
		gchar* _tmp307_;
		SerializableGeeTreeMapTestBigBag* _tmp308_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp309_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp310_;
		gpointer _tmp311_;
		SerializableGeeTreeMapTestSmallBag* _tmp312_;
		SerializableGeeTreeMapTestBallTreeMap* _tmp313_;
		SerializableGeeTreeMapTestBallTreeMap* _tmp314_;
		gpointer _tmp315_;
		SerializableGeeTreeMapTestBall* _tmp316_;
		SerializableGeeTreeMapTestBallFill* _tmp317_;
		SerializableGeeTreeMapTestBallFill* _tmp318_;
		gchar* _tmp319_;
		gchar* _tmp320_;
		gchar* _tmp321_;
		SerializableGeeTreeMapTestBigBag* bag3 = NULL;
		SerializableGeeTreeMapTestBigBag* _tmp322_;
		SerializableGeeTreeMapTestBigBag* _tmp323_;
		GXmlGDocument* _tmp324_;
		SerializableGeeTreeMapTestBigBag* _tmp325_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp326_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp327_;
		gint _tmp328_;
		gint _tmp329_;
		gboolean _tmp330_ = FALSE;
		SerializableGeeTreeMapTestBigBag* _tmp331_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp332_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp333_;
		SerializableGeeTreeMapTestBigBag* _tmp334_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp335_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp336_;
		gint _tmp337_;
		gint _tmp338_;
		SerializableGeeTreeMapTestBigBag* _tmp339_;
		GXmlGDocument* _tmp340_;
		SerializableGeeTreeMapTestBigBag* _tmp341_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp342_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp343_;
		SerializableGeeTreeMapTestBigBag* bag2 = NULL;
		SerializableGeeTreeMapTestBigBag* _tmp344_;
		SerializableGeeTreeMapTestBigBag* _tmp345_;
		GXmlGDocument* _tmp346_;
		SerializableGeeTreeMapTestBigBag* _tmp347_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp348_;
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp349_;
		GXmlGDocument* d2 = NULL;
		GXmlGDocument* _tmp350_;
		SerializableGeeTreeMapTestBigBag* _tmp351_;
		GXmlGDocument* _tmp352_;
		GXmlNode* _tmp353_;
		GXmlNode* _tmp354_;
		GXmlGDocument* _tmp355_;
		GXmlNode* _tmp356_;
		GXmlNode* _tmp357_;
		GXmlNode* _tmp358_;
		GXmlGDocument* _tmp359_;
		GXmlNode* _tmp360_;
		GXmlNode* _tmp361_;
		GXmlNode* _tmp362_;
		gchar* _tmp363_;
		gchar* _tmp364_;
		gchar* _tmp365_;
		GXmlGDocument* _tmp366_;
		GXmlNode* _tmp367_;
		GXmlNode* _tmp368_;
		GXmlNode* _tmp369_;
		GeeBidirList* _tmp370_;
		GeeBidirList* _tmp371_;
		GeeBidirList* _tmp372_;
		gint _tmp373_;
		gint _tmp374_;
		GXmlGDocument* _tmp375_;
		GXmlNode* _tmp376_;
		GXmlNode* _tmp377_;
		GXmlNode* _tmp378_;
		GeeBidirList* _tmp379_;
		GeeBidirList* _tmp380_;
		GeeBidirList* _tmp381_;
		gpointer _tmp382_;
		GXmlNode* _tmp383_;
		gchar* _tmp384_;
		gchar* _tmp385_;
		gchar* _tmp386_;
		GXmlGDocument* _tmp387_;
		GXmlNode* _tmp388_;
		GXmlNode* _tmp389_;
		GXmlNode* _tmp390_;
		GeeBidirList* _tmp391_;
		GeeBidirList* _tmp392_;
		GeeBidirList* _tmp393_;
		gpointer _tmp394_;
		GXmlNode* _tmp395_;
		GeeBidirList* _tmp396_;
		GeeBidirList* _tmp397_;
		GeeBidirList* _tmp398_;
		gint _tmp399_;
		gint _tmp400_;
		GXmlGDocument* _tmp401_;
		GXmlNode* _tmp402_;
		GXmlNode* _tmp403_;
		GXmlNode* _tmp404_;
		GeeBidirList* _tmp405_;
		GeeBidirList* _tmp406_;
		GeeBidirList* _tmp407_;
		gpointer _tmp408_;
		GXmlNode* _tmp409_;
		GeeBidirList* _tmp410_;
		GeeBidirList* _tmp411_;
		GeeBidirList* _tmp412_;
		gpointer _tmp413_;
		GXmlNode* _tmp414_;
		gchar* _tmp415_;
		gchar* _tmp416_;
		gchar* _tmp417_;
		GXmlGDocument* _tmp418_;
		GXmlNode* _tmp419_;
		GXmlNode* _tmp420_;
		GXmlNode* _tmp421_;
		GeeBidirList* _tmp422_;
		GeeBidirList* _tmp423_;
		GeeBidirList* _tmp424_;
		gpointer _tmp425_;
		GXmlNode* _tmp426_;
		GeeBidirList* _tmp427_;
		GeeBidirList* _tmp428_;
		GeeBidirList* _tmp429_;
		gpointer _tmp430_;
		GXmlNode* _tmp431_;
		GeeBidirList* _tmp432_;
		GeeBidirList* _tmp433_;
		GeeBidirList* _tmp434_;
		gint _tmp435_;
		gint _tmp436_;
		GXmlGDocument* _tmp437_;
		GXmlNode* _tmp438_;
		GXmlNode* _tmp439_;
		GXmlNode* _tmp440_;
		GeeBidirList* _tmp441_;
		GeeBidirList* _tmp442_;
		GeeBidirList* _tmp443_;
		gpointer _tmp444_;
		GXmlNode* _tmp445_;
		GeeBidirList* _tmp446_;
		GeeBidirList* _tmp447_;
		GeeBidirList* _tmp448_;
		gpointer _tmp449_;
		GXmlNode* _tmp450_;
		GeeBidirList* _tmp451_;
		GeeBidirList* _tmp452_;
		GeeBidirList* _tmp453_;
		gpointer _tmp454_;
		GXmlNode* _tmp455_;
		gchar* _tmp456_;
		gchar* _tmp457_;
		gchar* _tmp458_;
		GXmlGDocument* _tmp459_;
		GXmlNode* _tmp460_;
		GXmlNode* _tmp461_;
		GXmlNode* _tmp462_;
		GeeBidirList* _tmp463_;
		GeeBidirList* _tmp464_;
		GeeBidirList* _tmp465_;
		gpointer _tmp466_;
		GXmlNode* _tmp467_;
		GeeBidirList* _tmp468_;
		GeeBidirList* _tmp469_;
		GeeBidirList* _tmp470_;
		gpointer _tmp471_;
		GXmlNode* _tmp472_;
		GeeBidirList* _tmp473_;
		GeeBidirList* _tmp474_;
		GeeBidirList* _tmp475_;
		gpointer _tmp476_;
		GXmlNode* _tmp477_;
		GeeBidirList* _tmp478_;
		GeeBidirList* _tmp479_;
		GeeBidirList* _tmp480_;
		gint _tmp481_;
		gint _tmp482_;
		GXmlGDocument* _tmp483_;
		GXmlNode* _tmp484_;
		GXmlNode* _tmp485_;
		GXmlNode* _tmp486_;
		GeeBidirList* _tmp487_;
		GeeBidirList* _tmp488_;
		GeeBidirList* _tmp489_;
		gpointer _tmp490_;
		GXmlNode* _tmp491_;
		GeeBidirList* _tmp492_;
		GeeBidirList* _tmp493_;
		GeeBidirList* _tmp494_;
		gpointer _tmp495_;
		GXmlNode* _tmp496_;
		GeeBidirList* _tmp497_;
		GeeBidirList* _tmp498_;
		GeeBidirList* _tmp499_;
		gpointer _tmp500_;
		GXmlNode* _tmp501_;
		GeeBidirList* _tmp502_;
		GeeBidirList* _tmp503_;
		GeeBidirList* _tmp504_;
		gpointer _tmp505_;
		GXmlNode* _tmp506_;
		GXmlGDocument* _tmp507_;
		GXmlNode* _tmp508_;
		GXmlNode* _tmp509_;
		GXmlNode* _tmp510_;
		GeeBidirList* _tmp511_;
		GeeBidirList* _tmp512_;
		GeeBidirList* _tmp513_;
		gpointer _tmp514_;
		GXmlNode* _tmp515_;
		GeeBidirList* _tmp516_;
		GeeBidirList* _tmp517_;
		GeeBidirList* _tmp518_;
		gpointer _tmp519_;
		GXmlNode* _tmp520_;
		GeeBidirList* _tmp521_;
		GeeBidirList* _tmp522_;
		GeeBidirList* _tmp523_;
		gpointer _tmp524_;
		GXmlNode* _tmp525_;
		GeeBidirList* _tmp526_;
		GeeBidirList* _tmp527_;
		GeeBidirList* _tmp528_;
		gpointer _tmp529_;
		GXmlNode* _tmp530_;
		gchar* _tmp531_;
		gchar* _tmp532_;
		gchar* _tmp533_;
#line 319 "SerializableGeeTreeMapTest.vala"
		_tmp0_ = serializable_gee_tree_map_test_big_bag_new ();
#line 319 "SerializableGeeTreeMapTest.vala"
		bag = _tmp0_;
#line 320 "SerializableGeeTreeMapTest.vala"
		_tmp1_ = bag;
#line 320 "SerializableGeeTreeMapTest.vala"
		_tmp2_ = serializable_gee_tree_map_test_big_bag_get_bags (_tmp1_);
#line 320 "SerializableGeeTreeMapTest.vala"
		_tmp3_ = _tmp2_;
#line 320 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp3_ != NULL, "bag.bags != null");
#line 3448 "SerializableGeeTreeMapTest.c"
		{
			gint i = 0;
#line 321 "SerializableGeeTreeMapTest.vala"
			i = 0;
#line 3453 "SerializableGeeTreeMapTest.c"
			{
				gboolean _tmp4_ = FALSE;
#line 321 "SerializableGeeTreeMapTest.vala"
				_tmp4_ = TRUE;
#line 321 "SerializableGeeTreeMapTest.vala"
				while (TRUE) {
#line 3460 "SerializableGeeTreeMapTest.c"
					SerializableGeeTreeMapTestSmallBag* sbag = NULL;
					SerializableGeeTreeMapTestSmallBag* _tmp6_;
					SerializableGeeTreeMapTestSmallBag* _tmp7_;
					gchar* _tmp8_;
					gchar* _tmp9_;
					gchar* _tmp10_;
					gchar* _tmp11_;
					SerializableGeeTreeMapTestSmallBag* _tmp12_;
					SerializableGeeTreeMapTestBallTreeMap* _tmp13_;
					SerializableGeeTreeMapTestBallTreeMap* _tmp14_;
					SerializableGeeTreeMapTestSmallBag* _tmp36_;
					SerializableGeeTreeMapTestBallTreeMap* _tmp37_;
					SerializableGeeTreeMapTestBallTreeMap* _tmp38_;
					gint _tmp39_;
					gint _tmp40_;
					SerializableGeeTreeMapTestBigBag* _tmp41_;
					SerializableGeeTreeMapTestSmallBagTreeMap* _tmp42_;
					SerializableGeeTreeMapTestSmallBagTreeMap* _tmp43_;
					SerializableGeeTreeMapTestSmallBag* _tmp44_;
					const gchar* _tmp45_;
					const gchar* _tmp46_;
					SerializableGeeTreeMapTestSmallBag* _tmp47_;
#line 321 "SerializableGeeTreeMapTest.vala"
					if (!_tmp4_) {
#line 3485 "SerializableGeeTreeMapTest.c"
						gint _tmp5_;
#line 321 "SerializableGeeTreeMapTest.vala"
						_tmp5_ = i;
#line 321 "SerializableGeeTreeMapTest.vala"
						i = _tmp5_ + 1;
#line 3491 "SerializableGeeTreeMapTest.c"
					}
#line 321 "SerializableGeeTreeMapTest.vala"
					_tmp4_ = FALSE;
#line 321 "SerializableGeeTreeMapTest.vala"
					if (!(i < 2)) {
#line 321 "SerializableGeeTreeMapTest.vala"
						break;
#line 3499 "SerializableGeeTreeMapTest.c"
					}
#line 322 "SerializableGeeTreeMapTest.vala"
					_tmp6_ = serializable_gee_tree_map_test_small_bag_new ();
#line 322 "SerializableGeeTreeMapTest.vala"
					sbag = _tmp6_;
#line 323 "SerializableGeeTreeMapTest.vala"
					_tmp7_ = sbag;
#line 323 "SerializableGeeTreeMapTest.vala"
					_tmp8_ = g_strdup_printf ("%i", i);
#line 323 "SerializableGeeTreeMapTest.vala"
					_tmp9_ = _tmp8_;
#line 323 "SerializableGeeTreeMapTest.vala"
					_tmp10_ = g_strconcat ("SmallBag", _tmp9_, NULL);
#line 323 "SerializableGeeTreeMapTest.vala"
					_tmp11_ = _tmp10_;
#line 323 "SerializableGeeTreeMapTest.vala"
					serializable_gee_tree_map_test_small_bag_set_name (_tmp7_, _tmp11_);
#line 323 "SerializableGeeTreeMapTest.vala"
					_g_free0 (_tmp11_);
#line 323 "SerializableGeeTreeMapTest.vala"
					_g_free0 (_tmp9_);
#line 324 "SerializableGeeTreeMapTest.vala"
					_tmp12_ = sbag;
#line 324 "SerializableGeeTreeMapTest.vala"
					_tmp13_ = serializable_gee_tree_map_test_small_bag_get_balls (_tmp12_);
#line 324 "SerializableGeeTreeMapTest.vala"
					_tmp14_ = _tmp13_;
#line 324 "SerializableGeeTreeMapTest.vala"
					_vala_assert (_tmp14_ != NULL, "sbag.balls != null");
#line 3529 "SerializableGeeTreeMapTest.c"
					{
						gint j = 0;
#line 325 "SerializableGeeTreeMapTest.vala"
						j = 0;
#line 3534 "SerializableGeeTreeMapTest.c"
						{
							gboolean _tmp15_ = FALSE;
#line 325 "SerializableGeeTreeMapTest.vala"
							_tmp15_ = TRUE;
#line 325 "SerializableGeeTreeMapTest.vala"
							while (TRUE) {
#line 3541 "SerializableGeeTreeMapTest.c"
								SerializableGeeTreeMapTestBall* b = NULL;
								SerializableGeeTreeMapTestBall* _tmp17_;
								SerializableGeeTreeMapTestBall* _tmp18_;
								gchar* _tmp19_;
								gchar* _tmp20_;
								gchar* _tmp21_;
								gchar* _tmp22_;
								SerializableGeeTreeMapTestBall* _tmp23_;
								SerializableGeeTreeMapTestBallFill* _tmp24_;
								SerializableGeeTreeMapTestBallFill* _tmp25_;
								SerializableGeeTreeMapTestBall* _tmp26_;
								SerializableGeeTreeMapTestBallFill* _tmp27_;
								SerializableGeeTreeMapTestBallFill* _tmp28_;
								SerializableGeeTreeMapTestSmallBag* _tmp29_;
								SerializableGeeTreeMapTestBallTreeMap* _tmp30_;
								SerializableGeeTreeMapTestBallTreeMap* _tmp31_;
								SerializableGeeTreeMapTestBall* _tmp32_;
								const gchar* _tmp33_;
								const gchar* _tmp34_;
								SerializableGeeTreeMapTestBall* _tmp35_;
#line 325 "SerializableGeeTreeMapTest.vala"
								if (!_tmp15_) {
#line 3564 "SerializableGeeTreeMapTest.c"
									gint _tmp16_;
#line 325 "SerializableGeeTreeMapTest.vala"
									_tmp16_ = j;
#line 325 "SerializableGeeTreeMapTest.vala"
									j = _tmp16_ + 1;
#line 3570 "SerializableGeeTreeMapTest.c"
								}
#line 325 "SerializableGeeTreeMapTest.vala"
								_tmp15_ = FALSE;
#line 325 "SerializableGeeTreeMapTest.vala"
								if (!(j < 2)) {
#line 325 "SerializableGeeTreeMapTest.vala"
									break;
#line 3578 "SerializableGeeTreeMapTest.c"
								}
#line 326 "SerializableGeeTreeMapTest.vala"
								_tmp17_ = serializable_gee_tree_map_test_ball_new ();
#line 326 "SerializableGeeTreeMapTest.vala"
								b = _tmp17_;
#line 327 "SerializableGeeTreeMapTest.vala"
								_tmp18_ = b;
#line 327 "SerializableGeeTreeMapTest.vala"
								_tmp19_ = g_strdup_printf ("%i", j);
#line 327 "SerializableGeeTreeMapTest.vala"
								_tmp20_ = _tmp19_;
#line 327 "SerializableGeeTreeMapTest.vala"
								_tmp21_ = g_strconcat ("Ball", _tmp20_, NULL);
#line 327 "SerializableGeeTreeMapTest.vala"
								_tmp22_ = _tmp21_;
#line 327 "SerializableGeeTreeMapTest.vala"
								serializable_gee_tree_map_test_ball_set_name (_tmp18_, _tmp22_);
#line 327 "SerializableGeeTreeMapTest.vala"
								_g_free0 (_tmp22_);
#line 327 "SerializableGeeTreeMapTest.vala"
								_g_free0 (_tmp20_);
#line 328 "SerializableGeeTreeMapTest.vala"
								_tmp23_ = b;
#line 328 "SerializableGeeTreeMapTest.vala"
								_tmp24_ = serializable_gee_tree_map_test_ball_fill_new ();
#line 328 "SerializableGeeTreeMapTest.vala"
								_tmp25_ = _tmp24_;
#line 328 "SerializableGeeTreeMapTest.vala"
								serializable_gee_tree_map_test_ball_set_ballfill (_tmp23_, _tmp25_);
#line 328 "SerializableGeeTreeMapTest.vala"
								_g_object_unref0 (_tmp25_);
#line 329 "SerializableGeeTreeMapTest.vala"
								_tmp26_ = b;
#line 329 "SerializableGeeTreeMapTest.vala"
								_tmp27_ = serializable_gee_tree_map_test_ball_get_ballfill (_tmp26_);
#line 329 "SerializableGeeTreeMapTest.vala"
								_tmp28_ = _tmp27_;
#line 329 "SerializableGeeTreeMapTest.vala"
								serializable_gee_tree_map_test_ball_fill_set_text (_tmp28_, "golden dust");
#line 330 "SerializableGeeTreeMapTest.vala"
								_tmp29_ = sbag;
#line 330 "SerializableGeeTreeMapTest.vala"
								_tmp30_ = serializable_gee_tree_map_test_small_bag_get_balls (_tmp29_);
#line 330 "SerializableGeeTreeMapTest.vala"
								_tmp31_ = _tmp30_;
#line 330 "SerializableGeeTreeMapTest.vala"
								_tmp32_ = b;
#line 330 "SerializableGeeTreeMapTest.vala"
								_tmp33_ = serializable_gee_tree_map_test_ball_get_name (_tmp32_);
#line 330 "SerializableGeeTreeMapTest.vala"
								_tmp34_ = _tmp33_;
#line 330 "SerializableGeeTreeMapTest.vala"
								_tmp35_ = b;
#line 330 "SerializableGeeTreeMapTest.vala"
								gee_abstract_map_set ((GeeAbstractMap*) _tmp31_, _tmp34_, _tmp35_);
#line 325 "SerializableGeeTreeMapTest.vala"
								_g_object_unref0 (b);
#line 3636 "SerializableGeeTreeMapTest.c"
							}
						}
					}
#line 332 "SerializableGeeTreeMapTest.vala"
					_tmp36_ = sbag;
#line 332 "SerializableGeeTreeMapTest.vala"
					_tmp37_ = serializable_gee_tree_map_test_small_bag_get_balls (_tmp36_);
#line 332 "SerializableGeeTreeMapTest.vala"
					_tmp38_ = _tmp37_;
#line 332 "SerializableGeeTreeMapTest.vala"
					_tmp39_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp38_);
#line 332 "SerializableGeeTreeMapTest.vala"
					_tmp40_ = _tmp39_;
#line 332 "SerializableGeeTreeMapTest.vala"
					_vala_assert (_tmp40_ == 2, "sbag.balls.size == 2");
#line 333 "SerializableGeeTreeMapTest.vala"
					_tmp41_ = bag;
#line 333 "SerializableGeeTreeMapTest.vala"
					_tmp42_ = serializable_gee_tree_map_test_big_bag_get_bags (_tmp41_);
#line 333 "SerializableGeeTreeMapTest.vala"
					_tmp43_ = _tmp42_;
#line 333 "SerializableGeeTreeMapTest.vala"
					_tmp44_ = sbag;
#line 333 "SerializableGeeTreeMapTest.vala"
					_tmp45_ = serializable_gee_tree_map_test_small_bag_get_name (_tmp44_);
#line 333 "SerializableGeeTreeMapTest.vala"
					_tmp46_ = _tmp45_;
#line 333 "SerializableGeeTreeMapTest.vala"
					_tmp47_ = sbag;
#line 333 "SerializableGeeTreeMapTest.vala"
					gee_abstract_map_set ((GeeAbstractMap*) _tmp43_, _tmp46_, _tmp47_);
#line 321 "SerializableGeeTreeMapTest.vala"
					_g_object_unref0 (sbag);
#line 3670 "SerializableGeeTreeMapTest.c"
				}
			}
		}
#line 335 "SerializableGeeTreeMapTest.vala"
		_tmp48_ = bag;
#line 335 "SerializableGeeTreeMapTest.vala"
		_tmp49_ = serializable_gee_tree_map_test_big_bag_get_bags (_tmp48_);
#line 335 "SerializableGeeTreeMapTest.vala"
		_tmp50_ = _tmp49_;
#line 335 "SerializableGeeTreeMapTest.vala"
		_tmp51_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp50_);
#line 335 "SerializableGeeTreeMapTest.vala"
		_tmp52_ = _tmp51_;
#line 335 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp52_ == 2, "bag.bags.size == 2");
#line 337 "SerializableGeeTreeMapTest.vala"
		_tmp53_ = gxml_gdocument_new ();
#line 337 "SerializableGeeTreeMapTest.vala"
		d = _tmp53_;
#line 338 "SerializableGeeTreeMapTest.vala"
		_tmp54_ = bag;
#line 338 "SerializableGeeTreeMapTest.vala"
		_tmp55_ = d;
#line 338 "SerializableGeeTreeMapTest.vala"
		_tmp56_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp54_, (GXmlNode*) _tmp55_, &_inner_error0_);
#line 338 "SerializableGeeTreeMapTest.vala"
		_tmp57_ = _tmp56_;
#line 338 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp57_);
#line 338 "SerializableGeeTreeMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 338 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (d);
#line 338 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bag);
#line 3706 "SerializableGeeTreeMapTest.c"
			goto __catch351_g_error;
		}
#line 339 "SerializableGeeTreeMapTest.vala"
		_tmp58_ = d;
#line 339 "SerializableGeeTreeMapTest.vala"
		_tmp59_ = gxml_document_get_root ((GXmlDocument*) _tmp58_);
#line 339 "SerializableGeeTreeMapTest.vala"
		_tmp60_ = _tmp59_;
#line 339 "SerializableGeeTreeMapTest.vala"
		_tmp61_ = _tmp60_;
#line 339 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp61_ != NULL, "d.root != null");
#line 339 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp61_);
#line 340 "SerializableGeeTreeMapTest.vala"
		_tmp62_ = d;
#line 340 "SerializableGeeTreeMapTest.vala"
		_tmp63_ = gxml_document_get_root ((GXmlDocument*) _tmp62_);
#line 340 "SerializableGeeTreeMapTest.vala"
		_tmp64_ = _tmp63_;
#line 340 "SerializableGeeTreeMapTest.vala"
		_tmp65_ = _tmp64_;
#line 340 "SerializableGeeTreeMapTest.vala"
		_tmp66_ = gxml_node_get_name (_tmp65_);
#line 340 "SerializableGeeTreeMapTest.vala"
		_tmp67_ = _tmp66_;
#line 340 "SerializableGeeTreeMapTest.vala"
		_tmp68_ = _tmp67_;
#line 340 "SerializableGeeTreeMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp68_, "BigBag") == 0, "d.root.name == \"BigBag\"");
#line 340 "SerializableGeeTreeMapTest.vala"
		_g_free0 (_tmp68_);
#line 340 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp65_);
#line 341 "SerializableGeeTreeMapTest.vala"
		_tmp69_ = d;
#line 341 "SerializableGeeTreeMapTest.vala"
		_tmp70_ = gxml_document_get_root ((GXmlDocument*) _tmp69_);
#line 341 "SerializableGeeTreeMapTest.vala"
		_tmp71_ = _tmp70_;
#line 341 "SerializableGeeTreeMapTest.vala"
		_tmp72_ = _tmp71_;
#line 341 "SerializableGeeTreeMapTest.vala"
		_tmp73_ = gxml_node_get_children_nodes (_tmp72_);
#line 341 "SerializableGeeTreeMapTest.vala"
		_tmp74_ = _tmp73_;
#line 341 "SerializableGeeTreeMapTest.vala"
		_tmp75_ = _tmp74_;
#line 341 "SerializableGeeTreeMapTest.vala"
		_tmp76_ = gee_collection_get_size ((GeeCollection*) _tmp75_);
#line 341 "SerializableGeeTreeMapTest.vala"
		_tmp77_ = _tmp76_;
#line 341 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp77_ == 2, "d.root.children_nodes.size == 2");
#line 341 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp75_);
#line 341 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp72_);
#line 342 "SerializableGeeTreeMapTest.vala"
		_tmp78_ = d;
#line 342 "SerializableGeeTreeMapTest.vala"
		_tmp79_ = gxml_document_get_root ((GXmlDocument*) _tmp78_);
#line 342 "SerializableGeeTreeMapTest.vala"
		_tmp80_ = _tmp79_;
#line 342 "SerializableGeeTreeMapTest.vala"
		_tmp81_ = _tmp80_;
#line 342 "SerializableGeeTreeMapTest.vala"
		_tmp82_ = gxml_node_get_children_nodes (_tmp81_);
#line 342 "SerializableGeeTreeMapTest.vala"
		_tmp83_ = _tmp82_;
#line 342 "SerializableGeeTreeMapTest.vala"
		_tmp84_ = _tmp83_;
#line 342 "SerializableGeeTreeMapTest.vala"
		_tmp85_ = gee_list_get ((GeeList*) _tmp84_, 0);
#line 342 "SerializableGeeTreeMapTest.vala"
		_tmp86_ = (GXmlNode*) _tmp85_;
#line 342 "SerializableGeeTreeMapTest.vala"
		_tmp87_ = gxml_node_get_name (_tmp86_);
#line 342 "SerializableGeeTreeMapTest.vala"
		_tmp88_ = _tmp87_;
#line 342 "SerializableGeeTreeMapTest.vala"
		_tmp89_ = _tmp88_;
#line 342 "SerializableGeeTreeMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp89_, "SmallBag") == 0, "d.root.children_nodes[0].name == \"SmallBag\"");
#line 342 "SerializableGeeTreeMapTest.vala"
		_g_free0 (_tmp89_);
#line 342 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp86_);
#line 342 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp84_);
#line 342 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp81_);
#line 343 "SerializableGeeTreeMapTest.vala"
		_tmp90_ = d;
#line 343 "SerializableGeeTreeMapTest.vala"
		_tmp91_ = gxml_document_get_root ((GXmlDocument*) _tmp90_);
#line 343 "SerializableGeeTreeMapTest.vala"
		_tmp92_ = _tmp91_;
#line 343 "SerializableGeeTreeMapTest.vala"
		_tmp93_ = _tmp92_;
#line 343 "SerializableGeeTreeMapTest.vala"
		_tmp94_ = gxml_node_get_children_nodes (_tmp93_);
#line 343 "SerializableGeeTreeMapTest.vala"
		_tmp95_ = _tmp94_;
#line 343 "SerializableGeeTreeMapTest.vala"
		_tmp96_ = _tmp95_;
#line 343 "SerializableGeeTreeMapTest.vala"
		_tmp97_ = gee_list_get ((GeeList*) _tmp96_, 0);
#line 343 "SerializableGeeTreeMapTest.vala"
		_tmp98_ = (GXmlNode*) _tmp97_;
#line 343 "SerializableGeeTreeMapTest.vala"
		_tmp99_ = gxml_node_get_children_nodes (_tmp98_);
#line 343 "SerializableGeeTreeMapTest.vala"
		_tmp100_ = _tmp99_;
#line 343 "SerializableGeeTreeMapTest.vala"
		_tmp101_ = _tmp100_;
#line 343 "SerializableGeeTreeMapTest.vala"
		_tmp102_ = gee_collection_get_size ((GeeCollection*) _tmp101_);
#line 343 "SerializableGeeTreeMapTest.vala"
		_tmp103_ = _tmp102_;
#line 343 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp103_ == 2, "d.root.children_nodes[0].children_nodes.size == 2");
#line 343 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp101_);
#line 343 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp98_);
#line 343 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp96_);
#line 343 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp93_);
#line 344 "SerializableGeeTreeMapTest.vala"
		_tmp104_ = d;
#line 344 "SerializableGeeTreeMapTest.vala"
		_tmp105_ = gxml_document_get_root ((GXmlDocument*) _tmp104_);
#line 344 "SerializableGeeTreeMapTest.vala"
		_tmp106_ = _tmp105_;
#line 344 "SerializableGeeTreeMapTest.vala"
		_tmp107_ = _tmp106_;
#line 344 "SerializableGeeTreeMapTest.vala"
		_tmp108_ = gxml_node_get_children_nodes (_tmp107_);
#line 344 "SerializableGeeTreeMapTest.vala"
		_tmp109_ = _tmp108_;
#line 344 "SerializableGeeTreeMapTest.vala"
		_tmp110_ = _tmp109_;
#line 344 "SerializableGeeTreeMapTest.vala"
		_tmp111_ = gee_list_get ((GeeList*) _tmp110_, 0);
#line 344 "SerializableGeeTreeMapTest.vala"
		_tmp112_ = (GXmlNode*) _tmp111_;
#line 344 "SerializableGeeTreeMapTest.vala"
		_tmp113_ = gxml_node_get_children_nodes (_tmp112_);
#line 344 "SerializableGeeTreeMapTest.vala"
		_tmp114_ = _tmp113_;
#line 344 "SerializableGeeTreeMapTest.vala"
		_tmp115_ = _tmp114_;
#line 344 "SerializableGeeTreeMapTest.vala"
		_tmp116_ = gee_list_get ((GeeList*) _tmp115_, 0);
#line 344 "SerializableGeeTreeMapTest.vala"
		_tmp117_ = (GXmlNode*) _tmp116_;
#line 344 "SerializableGeeTreeMapTest.vala"
		_tmp118_ = gxml_node_get_name (_tmp117_);
#line 344 "SerializableGeeTreeMapTest.vala"
		_tmp119_ = _tmp118_;
#line 344 "SerializableGeeTreeMapTest.vala"
		_tmp120_ = _tmp119_;
#line 344 "SerializableGeeTreeMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp120_, "Ball") == 0, "d.root.children_nodes[0].children_nodes[0].name == \"Ball\"");
#line 344 "SerializableGeeTreeMapTest.vala"
		_g_free0 (_tmp120_);
#line 344 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp117_);
#line 344 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp115_);
#line 344 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp112_);
#line 344 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp110_);
#line 344 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp107_);
#line 345 "SerializableGeeTreeMapTest.vala"
		_tmp121_ = d;
#line 345 "SerializableGeeTreeMapTest.vala"
		_tmp122_ = gxml_document_get_root ((GXmlDocument*) _tmp121_);
#line 345 "SerializableGeeTreeMapTest.vala"
		_tmp123_ = _tmp122_;
#line 345 "SerializableGeeTreeMapTest.vala"
		_tmp124_ = _tmp123_;
#line 345 "SerializableGeeTreeMapTest.vala"
		_tmp125_ = gxml_node_get_children_nodes (_tmp124_);
#line 345 "SerializableGeeTreeMapTest.vala"
		_tmp126_ = _tmp125_;
#line 345 "SerializableGeeTreeMapTest.vala"
		_tmp127_ = _tmp126_;
#line 345 "SerializableGeeTreeMapTest.vala"
		_tmp128_ = gee_list_get ((GeeList*) _tmp127_, 0);
#line 345 "SerializableGeeTreeMapTest.vala"
		_tmp129_ = (GXmlNode*) _tmp128_;
#line 345 "SerializableGeeTreeMapTest.vala"
		_tmp130_ = gxml_node_get_children_nodes (_tmp129_);
#line 345 "SerializableGeeTreeMapTest.vala"
		_tmp131_ = _tmp130_;
#line 345 "SerializableGeeTreeMapTest.vala"
		_tmp132_ = _tmp131_;
#line 345 "SerializableGeeTreeMapTest.vala"
		_tmp133_ = gee_list_get ((GeeList*) _tmp132_, 0);
#line 345 "SerializableGeeTreeMapTest.vala"
		_tmp134_ = (GXmlNode*) _tmp133_;
#line 345 "SerializableGeeTreeMapTest.vala"
		_tmp135_ = gxml_node_get_children_nodes (_tmp134_);
#line 345 "SerializableGeeTreeMapTest.vala"
		_tmp136_ = _tmp135_;
#line 345 "SerializableGeeTreeMapTest.vala"
		_tmp137_ = _tmp136_;
#line 345 "SerializableGeeTreeMapTest.vala"
		_tmp138_ = gee_collection_get_size ((GeeCollection*) _tmp137_);
#line 345 "SerializableGeeTreeMapTest.vala"
		_tmp139_ = _tmp138_;
#line 345 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp139_ == 1, "d.root.children_nodes[0].children_nodes[0].children_nodes.size == 1");
#line 345 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp137_);
#line 345 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp134_);
#line 345 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp132_);
#line 345 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp129_);
#line 345 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp127_);
#line 345 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp124_);
#line 346 "SerializableGeeTreeMapTest.vala"
		_tmp140_ = d;
#line 346 "SerializableGeeTreeMapTest.vala"
		_tmp141_ = gxml_document_get_root ((GXmlDocument*) _tmp140_);
#line 346 "SerializableGeeTreeMapTest.vala"
		_tmp142_ = _tmp141_;
#line 346 "SerializableGeeTreeMapTest.vala"
		_tmp143_ = _tmp142_;
#line 346 "SerializableGeeTreeMapTest.vala"
		_tmp144_ = gxml_node_get_children_nodes (_tmp143_);
#line 346 "SerializableGeeTreeMapTest.vala"
		_tmp145_ = _tmp144_;
#line 346 "SerializableGeeTreeMapTest.vala"
		_tmp146_ = _tmp145_;
#line 346 "SerializableGeeTreeMapTest.vala"
		_tmp147_ = gee_list_get ((GeeList*) _tmp146_, 0);
#line 346 "SerializableGeeTreeMapTest.vala"
		_tmp148_ = (GXmlNode*) _tmp147_;
#line 346 "SerializableGeeTreeMapTest.vala"
		_tmp149_ = gxml_node_get_children_nodes (_tmp148_);
#line 346 "SerializableGeeTreeMapTest.vala"
		_tmp150_ = _tmp149_;
#line 346 "SerializableGeeTreeMapTest.vala"
		_tmp151_ = _tmp150_;
#line 346 "SerializableGeeTreeMapTest.vala"
		_tmp152_ = gee_list_get ((GeeList*) _tmp151_, 0);
#line 346 "SerializableGeeTreeMapTest.vala"
		_tmp153_ = (GXmlNode*) _tmp152_;
#line 346 "SerializableGeeTreeMapTest.vala"
		_tmp154_ = gxml_node_get_children_nodes (_tmp153_);
#line 346 "SerializableGeeTreeMapTest.vala"
		_tmp155_ = _tmp154_;
#line 346 "SerializableGeeTreeMapTest.vala"
		_tmp156_ = _tmp155_;
#line 346 "SerializableGeeTreeMapTest.vala"
		_tmp157_ = gee_list_get ((GeeList*) _tmp156_, 0);
#line 346 "SerializableGeeTreeMapTest.vala"
		_tmp158_ = (GXmlNode*) _tmp157_;
#line 346 "SerializableGeeTreeMapTest.vala"
		_tmp159_ = gxml_node_get_name (_tmp158_);
#line 346 "SerializableGeeTreeMapTest.vala"
		_tmp160_ = _tmp159_;
#line 346 "SerializableGeeTreeMapTest.vala"
		_tmp161_ = _tmp160_;
#line 346 "SerializableGeeTreeMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp161_, "BallFill") == 0, "d.root.children_nodes[0].children_nodes[0].children_nodes[0].name == \"BallFill\"");
#line 346 "SerializableGeeTreeMapTest.vala"
		_g_free0 (_tmp161_);
#line 346 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp158_);
#line 346 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp156_);
#line 346 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp153_);
#line 346 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp151_);
#line 346 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp148_);
#line 346 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp146_);
#line 346 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp143_);
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp162_ = d;
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp163_ = gxml_document_get_root ((GXmlDocument*) _tmp162_);
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp164_ = _tmp163_;
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp165_ = _tmp164_;
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp166_ = gxml_node_get_children_nodes (_tmp165_);
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp167_ = _tmp166_;
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp168_ = _tmp167_;
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp169_ = gee_list_get ((GeeList*) _tmp168_, 0);
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp170_ = (GXmlNode*) _tmp169_;
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp171_ = gxml_node_get_children_nodes (_tmp170_);
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp172_ = _tmp171_;
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp173_ = _tmp172_;
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp174_ = gee_list_get ((GeeList*) _tmp173_, 0);
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp175_ = (GXmlNode*) _tmp174_;
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp176_ = gxml_node_get_children_nodes (_tmp175_);
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp177_ = _tmp176_;
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp178_ = _tmp177_;
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp179_ = gee_list_get ((GeeList*) _tmp178_, 0);
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp180_ = (GXmlNode*) _tmp179_;
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp181_ = gxml_node_get_children_nodes (_tmp180_);
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp182_ = _tmp181_;
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp183_ = _tmp182_;
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp184_ = gee_collection_get_size ((GeeCollection*) _tmp183_);
#line 347 "SerializableGeeTreeMapTest.vala"
		_tmp185_ = _tmp184_;
#line 347 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp185_ == 1, "d.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes.size == 1");
#line 347 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp183_);
#line 347 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp180_);
#line 347 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp178_);
#line 347 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp175_);
#line 347 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp173_);
#line 347 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp170_);
#line 347 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp168_);
#line 347 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp165_);
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp186_ = d;
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp187_ = gxml_document_get_root ((GXmlDocument*) _tmp186_);
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp188_ = _tmp187_;
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp189_ = _tmp188_;
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp190_ = gxml_node_get_children_nodes (_tmp189_);
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp191_ = _tmp190_;
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp192_ = _tmp191_;
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp193_ = gee_list_get ((GeeList*) _tmp192_, 0);
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp194_ = (GXmlNode*) _tmp193_;
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp195_ = gxml_node_get_children_nodes (_tmp194_);
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp196_ = _tmp195_;
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp197_ = _tmp196_;
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp198_ = gee_list_get ((GeeList*) _tmp197_, 0);
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp199_ = (GXmlNode*) _tmp198_;
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp200_ = gxml_node_get_children_nodes (_tmp199_);
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp201_ = _tmp200_;
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp202_ = _tmp201_;
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp203_ = gee_list_get ((GeeList*) _tmp202_, 0);
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp204_ = (GXmlNode*) _tmp203_;
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp205_ = gxml_node_get_children_nodes (_tmp204_);
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp206_ = _tmp205_;
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp207_ = _tmp206_;
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp208_ = gee_list_get ((GeeList*) _tmp207_, 0);
#line 348 "SerializableGeeTreeMapTest.vala"
		_tmp209_ = (GXmlNode*) _tmp208_;
#line 348 "SerializableGeeTreeMapTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp209_, GXML_TYPE_TEXT), "d.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes[0] is Text");
#line 348 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp209_);
#line 348 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp207_);
#line 348 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp204_);
#line 348 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp202_);
#line 348 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp199_);
#line 348 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp197_);
#line 348 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp194_);
#line 348 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp192_);
#line 348 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp189_);
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp210_ = d;
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp211_ = gxml_document_get_root ((GXmlDocument*) _tmp210_);
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp212_ = _tmp211_;
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp213_ = _tmp212_;
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp214_ = gxml_node_get_children_nodes (_tmp213_);
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp215_ = _tmp214_;
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp216_ = _tmp215_;
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp217_ = gee_list_get ((GeeList*) _tmp216_, 0);
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp218_ = (GXmlNode*) _tmp217_;
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp219_ = gxml_node_get_children_nodes (_tmp218_);
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp220_ = _tmp219_;
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp221_ = _tmp220_;
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp222_ = gee_list_get ((GeeList*) _tmp221_, 0);
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp223_ = (GXmlNode*) _tmp222_;
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp224_ = gxml_node_get_children_nodes (_tmp223_);
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp225_ = _tmp224_;
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp226_ = _tmp225_;
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp227_ = gee_list_get ((GeeList*) _tmp226_, 0);
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp228_ = (GXmlNode*) _tmp227_;
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp229_ = gxml_node_get_children_nodes (_tmp228_);
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp230_ = _tmp229_;
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp231_ = _tmp230_;
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp232_ = gee_list_get ((GeeList*) _tmp231_, 0);
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp233_ = (GXmlNode*) _tmp232_;
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp234_ = gxml_node_get_value (_tmp233_);
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp235_ = _tmp234_;
#line 349 "SerializableGeeTreeMapTest.vala"
		_tmp236_ = _tmp235_;
#line 349 "SerializableGeeTreeMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp236_, "golden dust") == 0, "d.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes[0].value == \"golden dust\"");
#line 349 "SerializableGeeTreeMapTest.vala"
		_g_free0 (_tmp236_);
#line 349 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp233_);
#line 349 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp231_);
#line 349 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp228_);
#line 349 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp226_);
#line 349 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp223_);
#line 349 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp221_);
#line 349 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp218_);
#line 349 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp216_);
#line 349 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp213_);
#line 352 "SerializableGeeTreeMapTest.vala"
		_tmp237_ = serializable_gee_tree_map_test_big_bag_new ();
#line 352 "SerializableGeeTreeMapTest.vala"
		bagt = _tmp237_;
#line 353 "SerializableGeeTreeMapTest.vala"
		_tmp238_ = bagt;
#line 353 "SerializableGeeTreeMapTest.vala"
		_tmp239_ = d;
#line 353 "SerializableGeeTreeMapTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp238_, (GXmlNode*) _tmp239_, &_inner_error0_);
#line 353 "SerializableGeeTreeMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 353 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bagt);
#line 353 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (d);
#line 353 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bag);
#line 4227 "SerializableGeeTreeMapTest.c"
			goto __catch351_g_error;
		}
#line 354 "SerializableGeeTreeMapTest.vala"
		_tmp240_ = bagt;
#line 354 "SerializableGeeTreeMapTest.vala"
		_tmp241_ = serializable_gee_tree_map_test_big_bag_get_bags (_tmp240_);
#line 354 "SerializableGeeTreeMapTest.vala"
		_tmp242_ = _tmp241_;
#line 354 "SerializableGeeTreeMapTest.vala"
		_tmp243_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp242_);
#line 354 "SerializableGeeTreeMapTest.vala"
		_tmp244_ = _tmp243_;
#line 354 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp244_ == 0, "bagt.bags.size == 0");
#line 355 "SerializableGeeTreeMapTest.vala"
		_tmp246_ = bagt;
#line 355 "SerializableGeeTreeMapTest.vala"
		_tmp247_ = serializable_gee_tree_map_test_big_bag_get_bags (_tmp246_);
#line 355 "SerializableGeeTreeMapTest.vala"
		_tmp248_ = _tmp247_;
#line 355 "SerializableGeeTreeMapTest.vala"
		_tmp245_ = gxml_serializable_tree_map_deserialize_children ((GXmlSerializableTreeMap*) _tmp248_, &_inner_error0_);
#line 355 "SerializableGeeTreeMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 355 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bagt);
#line 355 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (d);
#line 355 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bag);
#line 4258 "SerializableGeeTreeMapTest.c"
			goto __catch351_g_error;
		}
#line 355 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp245_, "bagt.bags.deserialize_children ()");
#line 356 "SerializableGeeTreeMapTest.vala"
		_tmp249_ = bagt;
#line 356 "SerializableGeeTreeMapTest.vala"
		_tmp250_ = serializable_gee_tree_map_test_big_bag_get_bags (_tmp249_);
#line 356 "SerializableGeeTreeMapTest.vala"
		_tmp251_ = _tmp250_;
#line 356 "SerializableGeeTreeMapTest.vala"
		_tmp252_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp251_);
#line 356 "SerializableGeeTreeMapTest.vala"
		_tmp253_ = _tmp252_;
#line 356 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp253_ == 2, "bagt.bags.size == 2");
#line 357 "SerializableGeeTreeMapTest.vala"
		_tmp255_ = bagt;
#line 357 "SerializableGeeTreeMapTest.vala"
		_tmp256_ = serializable_gee_tree_map_test_big_bag_get_bags (_tmp255_);
#line 357 "SerializableGeeTreeMapTest.vala"
		_tmp257_ = _tmp256_;
#line 357 "SerializableGeeTreeMapTest.vala"
		_tmp258_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp257_, "SmallBag1");
#line 357 "SerializableGeeTreeMapTest.vala"
		_tmp259_ = (SerializableGeeTreeMapTestSmallBag*) _tmp258_;
#line 357 "SerializableGeeTreeMapTest.vala"
		_tmp260_ = serializable_gee_tree_map_test_small_bag_get_balls (_tmp259_);
#line 357 "SerializableGeeTreeMapTest.vala"
		_tmp261_ = _tmp260_;
#line 357 "SerializableGeeTreeMapTest.vala"
		_tmp262_ = gxml_serializable_tree_map_deserialize_children ((GXmlSerializableTreeMap*) _tmp261_, &_inner_error0_);
#line 357 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp259_);
#line 357 "SerializableGeeTreeMapTest.vala"
		_tmp254_ = _tmp262_;
#line 357 "SerializableGeeTreeMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 357 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bagt);
#line 357 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (d);
#line 357 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bag);
#line 4303 "SerializableGeeTreeMapTest.c"
			goto __catch351_g_error;
		}
#line 357 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp254_, "bagt.bags.get(\"SmallBag1\").balls.deserialize_children ()");
#line 358 "SerializableGeeTreeMapTest.vala"
		_tmp263_ = bagt;
#line 358 "SerializableGeeTreeMapTest.vala"
		_tmp264_ = serializable_gee_tree_map_test_big_bag_get_bags (_tmp263_);
#line 358 "SerializableGeeTreeMapTest.vala"
		_tmp265_ = _tmp264_;
#line 358 "SerializableGeeTreeMapTest.vala"
		_tmp266_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp265_, "SmallBag1");
#line 358 "SerializableGeeTreeMapTest.vala"
		_tmp267_ = (SerializableGeeTreeMapTestSmallBag*) _tmp266_;
#line 358 "SerializableGeeTreeMapTest.vala"
		_tmp268_ = serializable_gee_tree_map_test_small_bag_get_balls (_tmp267_);
#line 358 "SerializableGeeTreeMapTest.vala"
		_tmp269_ = _tmp268_;
#line 358 "SerializableGeeTreeMapTest.vala"
		_tmp270_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp269_);
#line 358 "SerializableGeeTreeMapTest.vala"
		_tmp271_ = _tmp270_;
#line 358 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp271_ == 2, "bagt.bags.get(\"SmallBag1\").balls.size == 2");
#line 358 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp267_);
#line 359 "SerializableGeeTreeMapTest.vala"
		_tmp272_ = bagt;
#line 359 "SerializableGeeTreeMapTest.vala"
		_tmp273_ = serializable_gee_tree_map_test_big_bag_get_bags (_tmp272_);
#line 359 "SerializableGeeTreeMapTest.vala"
		_tmp274_ = _tmp273_;
#line 359 "SerializableGeeTreeMapTest.vala"
		_tmp275_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp274_, "SmallBag1");
#line 359 "SerializableGeeTreeMapTest.vala"
		_tmp276_ = (SerializableGeeTreeMapTestSmallBag*) _tmp275_;
#line 359 "SerializableGeeTreeMapTest.vala"
		_tmp277_ = serializable_gee_tree_map_test_small_bag_get_balls (_tmp276_);
#line 359 "SerializableGeeTreeMapTest.vala"
		_tmp278_ = _tmp277_;
#line 359 "SerializableGeeTreeMapTest.vala"
		_tmp279_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp278_, "Ball1");
#line 359 "SerializableGeeTreeMapTest.vala"
		_tmp280_ = (SerializableGeeTreeMapTestBall*) _tmp279_;
#line 359 "SerializableGeeTreeMapTest.vala"
		_tmp281_ = serializable_gee_tree_map_test_ball_get_name (_tmp280_);
#line 359 "SerializableGeeTreeMapTest.vala"
		_tmp282_ = _tmp281_;
#line 359 "SerializableGeeTreeMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp282_, "Ball1") == 0, "bagt.bags.get(\"SmallBag1\").balls.get(\"Ball1\").name == \"Ball1\"");
#line 359 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp280_);
#line 359 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp276_);
#line 360 "SerializableGeeTreeMapTest.vala"
		_tmp283_ = bagt;
#line 360 "SerializableGeeTreeMapTest.vala"
		_tmp284_ = serializable_gee_tree_map_test_big_bag_get_bags (_tmp283_);
#line 360 "SerializableGeeTreeMapTest.vala"
		_tmp285_ = _tmp284_;
#line 360 "SerializableGeeTreeMapTest.vala"
		_tmp286_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp285_, "SmallBag1");
#line 360 "SerializableGeeTreeMapTest.vala"
		_tmp287_ = (SerializableGeeTreeMapTestSmallBag*) _tmp286_;
#line 360 "SerializableGeeTreeMapTest.vala"
		_tmp288_ = serializable_gee_tree_map_test_small_bag_get_balls (_tmp287_);
#line 360 "SerializableGeeTreeMapTest.vala"
		_tmp289_ = _tmp288_;
#line 360 "SerializableGeeTreeMapTest.vala"
		_tmp290_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp289_, "Ball1");
#line 360 "SerializableGeeTreeMapTest.vala"
		_tmp291_ = (SerializableGeeTreeMapTestBall*) _tmp290_;
#line 360 "SerializableGeeTreeMapTest.vala"
		_tmp292_ = serializable_gee_tree_map_test_ball_get_ballfill (_tmp291_);
#line 360 "SerializableGeeTreeMapTest.vala"
		_tmp293_ = _tmp292_;
#line 360 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp293_ != NULL, "bagt.bags.get(\"SmallBag1\").balls.get(\"Ball1\").ballfill !=null");
#line 360 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp291_);
#line 360 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp287_);
#line 361 "SerializableGeeTreeMapTest.vala"
		_tmp294_ = bagt;
#line 361 "SerializableGeeTreeMapTest.vala"
		_tmp295_ = serializable_gee_tree_map_test_big_bag_get_bags (_tmp294_);
#line 361 "SerializableGeeTreeMapTest.vala"
		_tmp296_ = _tmp295_;
#line 361 "SerializableGeeTreeMapTest.vala"
		_tmp297_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp296_, "SmallBag1");
#line 361 "SerializableGeeTreeMapTest.vala"
		_tmp298_ = (SerializableGeeTreeMapTestSmallBag*) _tmp297_;
#line 361 "SerializableGeeTreeMapTest.vala"
		_tmp299_ = serializable_gee_tree_map_test_small_bag_get_balls (_tmp298_);
#line 361 "SerializableGeeTreeMapTest.vala"
		_tmp300_ = _tmp299_;
#line 361 "SerializableGeeTreeMapTest.vala"
		_tmp301_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp300_, "Ball1");
#line 361 "SerializableGeeTreeMapTest.vala"
		_tmp302_ = (SerializableGeeTreeMapTestBall*) _tmp301_;
#line 361 "SerializableGeeTreeMapTest.vala"
		_tmp303_ = serializable_gee_tree_map_test_ball_get_ballfill (_tmp302_);
#line 361 "SerializableGeeTreeMapTest.vala"
		_tmp304_ = _tmp303_;
#line 361 "SerializableGeeTreeMapTest.vala"
		_tmp305_ = gxml_serializable_get_serialized_xml_node_value ((GXmlSerializable*) _tmp304_);
#line 361 "SerializableGeeTreeMapTest.vala"
		_tmp306_ = _tmp305_;
#line 361 "SerializableGeeTreeMapTest.vala"
		_tmp307_ = _tmp306_;
#line 361 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp307_ != NULL, "bagt.bags.get(\"SmallBag1\").balls.get(\"Ball1\").ballfill.serialized_xml_node_value !=null");
#line 361 "SerializableGeeTreeMapTest.vala"
		_g_free0 (_tmp307_);
#line 361 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp302_);
#line 361 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp298_);
#line 362 "SerializableGeeTreeMapTest.vala"
		_tmp308_ = bagt;
#line 362 "SerializableGeeTreeMapTest.vala"
		_tmp309_ = serializable_gee_tree_map_test_big_bag_get_bags (_tmp308_);
#line 362 "SerializableGeeTreeMapTest.vala"
		_tmp310_ = _tmp309_;
#line 362 "SerializableGeeTreeMapTest.vala"
		_tmp311_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp310_, "SmallBag1");
#line 362 "SerializableGeeTreeMapTest.vala"
		_tmp312_ = (SerializableGeeTreeMapTestSmallBag*) _tmp311_;
#line 362 "SerializableGeeTreeMapTest.vala"
		_tmp313_ = serializable_gee_tree_map_test_small_bag_get_balls (_tmp312_);
#line 362 "SerializableGeeTreeMapTest.vala"
		_tmp314_ = _tmp313_;
#line 362 "SerializableGeeTreeMapTest.vala"
		_tmp315_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp314_, "Ball1");
#line 362 "SerializableGeeTreeMapTest.vala"
		_tmp316_ = (SerializableGeeTreeMapTestBall*) _tmp315_;
#line 362 "SerializableGeeTreeMapTest.vala"
		_tmp317_ = serializable_gee_tree_map_test_ball_get_ballfill (_tmp316_);
#line 362 "SerializableGeeTreeMapTest.vala"
		_tmp318_ = _tmp317_;
#line 362 "SerializableGeeTreeMapTest.vala"
		_tmp319_ = gxml_serializable_get_serialized_xml_node_value ((GXmlSerializable*) _tmp318_);
#line 362 "SerializableGeeTreeMapTest.vala"
		_tmp320_ = _tmp319_;
#line 362 "SerializableGeeTreeMapTest.vala"
		_tmp321_ = _tmp320_;
#line 362 "SerializableGeeTreeMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp321_, "golden dust") == 0, "bagt.bags.get(\"SmallBag1\").balls.get(\"Ball1\").ballfill.serialized_xml_node_value ==\"golden dust\"");
#line 362 "SerializableGeeTreeMapTest.vala"
		_g_free0 (_tmp321_);
#line 362 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp316_);
#line 362 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp312_);
#line 363 "SerializableGeeTreeMapTest.vala"
		_tmp322_ = serializable_gee_tree_map_test_big_bag_new ();
#line 363 "SerializableGeeTreeMapTest.vala"
		bag3 = _tmp322_;
#line 364 "SerializableGeeTreeMapTest.vala"
		_tmp323_ = bag3;
#line 364 "SerializableGeeTreeMapTest.vala"
		_tmp324_ = d;
#line 364 "SerializableGeeTreeMapTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp323_, (GXmlNode*) _tmp324_, &_inner_error0_);
#line 364 "SerializableGeeTreeMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 364 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bag3);
#line 364 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bagt);
#line 364 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (d);
#line 364 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bag);
#line 4478 "SerializableGeeTreeMapTest.c"
			goto __catch351_g_error;
		}
#line 365 "SerializableGeeTreeMapTest.vala"
		_tmp325_ = bag3;
#line 365 "SerializableGeeTreeMapTest.vala"
		_tmp326_ = serializable_gee_tree_map_test_big_bag_get_bags (_tmp325_);
#line 365 "SerializableGeeTreeMapTest.vala"
		_tmp327_ = _tmp326_;
#line 365 "SerializableGeeTreeMapTest.vala"
		_tmp328_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp327_);
#line 365 "SerializableGeeTreeMapTest.vala"
		_tmp329_ = _tmp328_;
#line 365 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp329_ == 0, "bag3.bags.size == 0");
#line 366 "SerializableGeeTreeMapTest.vala"
		_tmp331_ = bag3;
#line 366 "SerializableGeeTreeMapTest.vala"
		_tmp332_ = serializable_gee_tree_map_test_big_bag_get_bags (_tmp331_);
#line 366 "SerializableGeeTreeMapTest.vala"
		_tmp333_ = _tmp332_;
#line 366 "SerializableGeeTreeMapTest.vala"
		_tmp330_ = gxml_serializable_tree_map_deserialize_children ((GXmlSerializableTreeMap*) _tmp333_, &_inner_error0_);
#line 366 "SerializableGeeTreeMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 366 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bag3);
#line 366 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bagt);
#line 366 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (d);
#line 366 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bag);
#line 4511 "SerializableGeeTreeMapTest.c"
			goto __catch351_g_error;
		}
#line 366 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp330_, "bag3.bags.deserialize_children ()");
#line 367 "SerializableGeeTreeMapTest.vala"
		_tmp334_ = bag3;
#line 367 "SerializableGeeTreeMapTest.vala"
		_tmp335_ = serializable_gee_tree_map_test_big_bag_get_bags (_tmp334_);
#line 367 "SerializableGeeTreeMapTest.vala"
		_tmp336_ = _tmp335_;
#line 367 "SerializableGeeTreeMapTest.vala"
		_tmp337_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp336_);
#line 367 "SerializableGeeTreeMapTest.vala"
		_tmp338_ = _tmp337_;
#line 367 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp338_ == 2, "bag3.bags.size == 2");
#line 368 "SerializableGeeTreeMapTest.vala"
		_tmp339_ = bag3;
#line 368 "SerializableGeeTreeMapTest.vala"
		_tmp340_ = d;
#line 368 "SerializableGeeTreeMapTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp339_, (GXmlNode*) _tmp340_, &_inner_error0_);
#line 368 "SerializableGeeTreeMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 368 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bag3);
#line 368 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bagt);
#line 368 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (d);
#line 368 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bag);
#line 4544 "SerializableGeeTreeMapTest.c"
			goto __catch351_g_error;
		}
#line 369 "SerializableGeeTreeMapTest.vala"
		_tmp341_ = bag3;
#line 369 "SerializableGeeTreeMapTest.vala"
		_tmp342_ = serializable_gee_tree_map_test_big_bag_get_bags (_tmp341_);
#line 369 "SerializableGeeTreeMapTest.vala"
		_tmp343_ = _tmp342_;
#line 369 "SerializableGeeTreeMapTest.vala"
		_vala_assert (!gxml_serializable_tree_map_deserialized ((GXmlSerializableTreeMap*) _tmp343_), "!bag3.bags.deserialized ()");
#line 371 "SerializableGeeTreeMapTest.vala"
		_tmp344_ = serializable_gee_tree_map_test_big_bag_new ();
#line 371 "SerializableGeeTreeMapTest.vala"
		bag2 = _tmp344_;
#line 372 "SerializableGeeTreeMapTest.vala"
		_tmp345_ = bag2;
#line 372 "SerializableGeeTreeMapTest.vala"
		_tmp346_ = d;
#line 372 "SerializableGeeTreeMapTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp345_, (GXmlNode*) _tmp346_, &_inner_error0_);
#line 372 "SerializableGeeTreeMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 372 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bag2);
#line 372 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bag3);
#line 372 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bagt);
#line 372 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (d);
#line 372 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bag);
#line 4577 "SerializableGeeTreeMapTest.c"
			goto __catch351_g_error;
		}
#line 373 "SerializableGeeTreeMapTest.vala"
		_tmp347_ = bag2;
#line 373 "SerializableGeeTreeMapTest.vala"
		_tmp348_ = serializable_gee_tree_map_test_big_bag_get_bags (_tmp347_);
#line 373 "SerializableGeeTreeMapTest.vala"
		_tmp349_ = _tmp348_;
#line 373 "SerializableGeeTreeMapTest.vala"
		_vala_assert (!gxml_serializable_tree_map_deserialized ((GXmlSerializableTreeMap*) _tmp349_), "!bag2.bags.deserialized ()");
#line 374 "SerializableGeeTreeMapTest.vala"
		_tmp350_ = gxml_gdocument_new ();
#line 374 "SerializableGeeTreeMapTest.vala"
		d2 = _tmp350_;
#line 375 "SerializableGeeTreeMapTest.vala"
		_tmp351_ = bag2;
#line 375 "SerializableGeeTreeMapTest.vala"
		_tmp352_ = d2;
#line 375 "SerializableGeeTreeMapTest.vala"
		_tmp353_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp351_, (GXmlNode*) _tmp352_, &_inner_error0_);
#line 375 "SerializableGeeTreeMapTest.vala"
		_tmp354_ = _tmp353_;
#line 375 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp354_);
#line 375 "SerializableGeeTreeMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 375 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (d2);
#line 375 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bag2);
#line 375 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bag3);
#line 375 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bagt);
#line 375 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (d);
#line 375 "SerializableGeeTreeMapTest.vala"
			_g_object_unref0 (bag);
#line 4616 "SerializableGeeTreeMapTest.c"
			goto __catch351_g_error;
		}
#line 377 "SerializableGeeTreeMapTest.vala"
		_tmp355_ = d2;
#line 377 "SerializableGeeTreeMapTest.vala"
		_tmp356_ = gxml_document_get_root ((GXmlDocument*) _tmp355_);
#line 377 "SerializableGeeTreeMapTest.vala"
		_tmp357_ = _tmp356_;
#line 377 "SerializableGeeTreeMapTest.vala"
		_tmp358_ = _tmp357_;
#line 377 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp358_ != NULL, "d2.root != null");
#line 377 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp358_);
#line 378 "SerializableGeeTreeMapTest.vala"
		_tmp359_ = d2;
#line 378 "SerializableGeeTreeMapTest.vala"
		_tmp360_ = gxml_document_get_root ((GXmlDocument*) _tmp359_);
#line 378 "SerializableGeeTreeMapTest.vala"
		_tmp361_ = _tmp360_;
#line 378 "SerializableGeeTreeMapTest.vala"
		_tmp362_ = _tmp361_;
#line 378 "SerializableGeeTreeMapTest.vala"
		_tmp363_ = gxml_node_get_name (_tmp362_);
#line 378 "SerializableGeeTreeMapTest.vala"
		_tmp364_ = _tmp363_;
#line 378 "SerializableGeeTreeMapTest.vala"
		_tmp365_ = _tmp364_;
#line 378 "SerializableGeeTreeMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp365_, "BigBag") == 0, "d2.root.name == \"BigBag\"");
#line 378 "SerializableGeeTreeMapTest.vala"
		_g_free0 (_tmp365_);
#line 378 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp362_);
#line 379 "SerializableGeeTreeMapTest.vala"
		_tmp366_ = d2;
#line 379 "SerializableGeeTreeMapTest.vala"
		_tmp367_ = gxml_document_get_root ((GXmlDocument*) _tmp366_);
#line 379 "SerializableGeeTreeMapTest.vala"
		_tmp368_ = _tmp367_;
#line 379 "SerializableGeeTreeMapTest.vala"
		_tmp369_ = _tmp368_;
#line 379 "SerializableGeeTreeMapTest.vala"
		_tmp370_ = gxml_node_get_children_nodes (_tmp369_);
#line 379 "SerializableGeeTreeMapTest.vala"
		_tmp371_ = _tmp370_;
#line 379 "SerializableGeeTreeMapTest.vala"
		_tmp372_ = _tmp371_;
#line 379 "SerializableGeeTreeMapTest.vala"
		_tmp373_ = gee_collection_get_size ((GeeCollection*) _tmp372_);
#line 379 "SerializableGeeTreeMapTest.vala"
		_tmp374_ = _tmp373_;
#line 379 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp374_ == 2, "d2.root.children_nodes.size == 2");
#line 379 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp372_);
#line 379 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp369_);
#line 380 "SerializableGeeTreeMapTest.vala"
		_tmp375_ = d2;
#line 380 "SerializableGeeTreeMapTest.vala"
		_tmp376_ = gxml_document_get_root ((GXmlDocument*) _tmp375_);
#line 380 "SerializableGeeTreeMapTest.vala"
		_tmp377_ = _tmp376_;
#line 380 "SerializableGeeTreeMapTest.vala"
		_tmp378_ = _tmp377_;
#line 380 "SerializableGeeTreeMapTest.vala"
		_tmp379_ = gxml_node_get_children_nodes (_tmp378_);
#line 380 "SerializableGeeTreeMapTest.vala"
		_tmp380_ = _tmp379_;
#line 380 "SerializableGeeTreeMapTest.vala"
		_tmp381_ = _tmp380_;
#line 380 "SerializableGeeTreeMapTest.vala"
		_tmp382_ = gee_list_get ((GeeList*) _tmp381_, 0);
#line 380 "SerializableGeeTreeMapTest.vala"
		_tmp383_ = (GXmlNode*) _tmp382_;
#line 380 "SerializableGeeTreeMapTest.vala"
		_tmp384_ = gxml_node_get_name (_tmp383_);
#line 380 "SerializableGeeTreeMapTest.vala"
		_tmp385_ = _tmp384_;
#line 380 "SerializableGeeTreeMapTest.vala"
		_tmp386_ = _tmp385_;
#line 380 "SerializableGeeTreeMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp386_, "SmallBag") == 0, "d2.root.children_nodes[0].name == \"SmallBag\"");
#line 380 "SerializableGeeTreeMapTest.vala"
		_g_free0 (_tmp386_);
#line 380 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp383_);
#line 380 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp381_);
#line 380 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp378_);
#line 381 "SerializableGeeTreeMapTest.vala"
		_tmp387_ = d2;
#line 381 "SerializableGeeTreeMapTest.vala"
		_tmp388_ = gxml_document_get_root ((GXmlDocument*) _tmp387_);
#line 381 "SerializableGeeTreeMapTest.vala"
		_tmp389_ = _tmp388_;
#line 381 "SerializableGeeTreeMapTest.vala"
		_tmp390_ = _tmp389_;
#line 381 "SerializableGeeTreeMapTest.vala"
		_tmp391_ = gxml_node_get_children_nodes (_tmp390_);
#line 381 "SerializableGeeTreeMapTest.vala"
		_tmp392_ = _tmp391_;
#line 381 "SerializableGeeTreeMapTest.vala"
		_tmp393_ = _tmp392_;
#line 381 "SerializableGeeTreeMapTest.vala"
		_tmp394_ = gee_list_get ((GeeList*) _tmp393_, 0);
#line 381 "SerializableGeeTreeMapTest.vala"
		_tmp395_ = (GXmlNode*) _tmp394_;
#line 381 "SerializableGeeTreeMapTest.vala"
		_tmp396_ = gxml_node_get_children_nodes (_tmp395_);
#line 381 "SerializableGeeTreeMapTest.vala"
		_tmp397_ = _tmp396_;
#line 381 "SerializableGeeTreeMapTest.vala"
		_tmp398_ = _tmp397_;
#line 381 "SerializableGeeTreeMapTest.vala"
		_tmp399_ = gee_collection_get_size ((GeeCollection*) _tmp398_);
#line 381 "SerializableGeeTreeMapTest.vala"
		_tmp400_ = _tmp399_;
#line 381 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp400_ == 2, "d2.root.children_nodes[0].children_nodes.size == 2");
#line 381 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp398_);
#line 381 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp395_);
#line 381 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp393_);
#line 381 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp390_);
#line 382 "SerializableGeeTreeMapTest.vala"
		_tmp401_ = d2;
#line 382 "SerializableGeeTreeMapTest.vala"
		_tmp402_ = gxml_document_get_root ((GXmlDocument*) _tmp401_);
#line 382 "SerializableGeeTreeMapTest.vala"
		_tmp403_ = _tmp402_;
#line 382 "SerializableGeeTreeMapTest.vala"
		_tmp404_ = _tmp403_;
#line 382 "SerializableGeeTreeMapTest.vala"
		_tmp405_ = gxml_node_get_children_nodes (_tmp404_);
#line 382 "SerializableGeeTreeMapTest.vala"
		_tmp406_ = _tmp405_;
#line 382 "SerializableGeeTreeMapTest.vala"
		_tmp407_ = _tmp406_;
#line 382 "SerializableGeeTreeMapTest.vala"
		_tmp408_ = gee_list_get ((GeeList*) _tmp407_, 0);
#line 382 "SerializableGeeTreeMapTest.vala"
		_tmp409_ = (GXmlNode*) _tmp408_;
#line 382 "SerializableGeeTreeMapTest.vala"
		_tmp410_ = gxml_node_get_children_nodes (_tmp409_);
#line 382 "SerializableGeeTreeMapTest.vala"
		_tmp411_ = _tmp410_;
#line 382 "SerializableGeeTreeMapTest.vala"
		_tmp412_ = _tmp411_;
#line 382 "SerializableGeeTreeMapTest.vala"
		_tmp413_ = gee_list_get ((GeeList*) _tmp412_, 0);
#line 382 "SerializableGeeTreeMapTest.vala"
		_tmp414_ = (GXmlNode*) _tmp413_;
#line 382 "SerializableGeeTreeMapTest.vala"
		_tmp415_ = gxml_node_get_name (_tmp414_);
#line 382 "SerializableGeeTreeMapTest.vala"
		_tmp416_ = _tmp415_;
#line 382 "SerializableGeeTreeMapTest.vala"
		_tmp417_ = _tmp416_;
#line 382 "SerializableGeeTreeMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp417_, "Ball") == 0, "d2.root.children_nodes[0].children_nodes[0].name == \"Ball\"");
#line 382 "SerializableGeeTreeMapTest.vala"
		_g_free0 (_tmp417_);
#line 382 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp414_);
#line 382 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp412_);
#line 382 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp409_);
#line 382 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp407_);
#line 382 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp404_);
#line 383 "SerializableGeeTreeMapTest.vala"
		_tmp418_ = d2;
#line 383 "SerializableGeeTreeMapTest.vala"
		_tmp419_ = gxml_document_get_root ((GXmlDocument*) _tmp418_);
#line 383 "SerializableGeeTreeMapTest.vala"
		_tmp420_ = _tmp419_;
#line 383 "SerializableGeeTreeMapTest.vala"
		_tmp421_ = _tmp420_;
#line 383 "SerializableGeeTreeMapTest.vala"
		_tmp422_ = gxml_node_get_children_nodes (_tmp421_);
#line 383 "SerializableGeeTreeMapTest.vala"
		_tmp423_ = _tmp422_;
#line 383 "SerializableGeeTreeMapTest.vala"
		_tmp424_ = _tmp423_;
#line 383 "SerializableGeeTreeMapTest.vala"
		_tmp425_ = gee_list_get ((GeeList*) _tmp424_, 0);
#line 383 "SerializableGeeTreeMapTest.vala"
		_tmp426_ = (GXmlNode*) _tmp425_;
#line 383 "SerializableGeeTreeMapTest.vala"
		_tmp427_ = gxml_node_get_children_nodes (_tmp426_);
#line 383 "SerializableGeeTreeMapTest.vala"
		_tmp428_ = _tmp427_;
#line 383 "SerializableGeeTreeMapTest.vala"
		_tmp429_ = _tmp428_;
#line 383 "SerializableGeeTreeMapTest.vala"
		_tmp430_ = gee_list_get ((GeeList*) _tmp429_, 0);
#line 383 "SerializableGeeTreeMapTest.vala"
		_tmp431_ = (GXmlNode*) _tmp430_;
#line 383 "SerializableGeeTreeMapTest.vala"
		_tmp432_ = gxml_node_get_children_nodes (_tmp431_);
#line 383 "SerializableGeeTreeMapTest.vala"
		_tmp433_ = _tmp432_;
#line 383 "SerializableGeeTreeMapTest.vala"
		_tmp434_ = _tmp433_;
#line 383 "SerializableGeeTreeMapTest.vala"
		_tmp435_ = gee_collection_get_size ((GeeCollection*) _tmp434_);
#line 383 "SerializableGeeTreeMapTest.vala"
		_tmp436_ = _tmp435_;
#line 383 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp436_ == 1, "d2.root.children_nodes[0].children_nodes[0].children_nodes.size == 1");
#line 383 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp434_);
#line 383 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp431_);
#line 383 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp429_);
#line 383 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp426_);
#line 383 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp424_);
#line 383 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp421_);
#line 384 "SerializableGeeTreeMapTest.vala"
		_tmp437_ = d2;
#line 384 "SerializableGeeTreeMapTest.vala"
		_tmp438_ = gxml_document_get_root ((GXmlDocument*) _tmp437_);
#line 384 "SerializableGeeTreeMapTest.vala"
		_tmp439_ = _tmp438_;
#line 384 "SerializableGeeTreeMapTest.vala"
		_tmp440_ = _tmp439_;
#line 384 "SerializableGeeTreeMapTest.vala"
		_tmp441_ = gxml_node_get_children_nodes (_tmp440_);
#line 384 "SerializableGeeTreeMapTest.vala"
		_tmp442_ = _tmp441_;
#line 384 "SerializableGeeTreeMapTest.vala"
		_tmp443_ = _tmp442_;
#line 384 "SerializableGeeTreeMapTest.vala"
		_tmp444_ = gee_list_get ((GeeList*) _tmp443_, 0);
#line 384 "SerializableGeeTreeMapTest.vala"
		_tmp445_ = (GXmlNode*) _tmp444_;
#line 384 "SerializableGeeTreeMapTest.vala"
		_tmp446_ = gxml_node_get_children_nodes (_tmp445_);
#line 384 "SerializableGeeTreeMapTest.vala"
		_tmp447_ = _tmp446_;
#line 384 "SerializableGeeTreeMapTest.vala"
		_tmp448_ = _tmp447_;
#line 384 "SerializableGeeTreeMapTest.vala"
		_tmp449_ = gee_list_get ((GeeList*) _tmp448_, 0);
#line 384 "SerializableGeeTreeMapTest.vala"
		_tmp450_ = (GXmlNode*) _tmp449_;
#line 384 "SerializableGeeTreeMapTest.vala"
		_tmp451_ = gxml_node_get_children_nodes (_tmp450_);
#line 384 "SerializableGeeTreeMapTest.vala"
		_tmp452_ = _tmp451_;
#line 384 "SerializableGeeTreeMapTest.vala"
		_tmp453_ = _tmp452_;
#line 384 "SerializableGeeTreeMapTest.vala"
		_tmp454_ = gee_list_get ((GeeList*) _tmp453_, 0);
#line 384 "SerializableGeeTreeMapTest.vala"
		_tmp455_ = (GXmlNode*) _tmp454_;
#line 384 "SerializableGeeTreeMapTest.vala"
		_tmp456_ = gxml_node_get_name (_tmp455_);
#line 384 "SerializableGeeTreeMapTest.vala"
		_tmp457_ = _tmp456_;
#line 384 "SerializableGeeTreeMapTest.vala"
		_tmp458_ = _tmp457_;
#line 384 "SerializableGeeTreeMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp458_, "BallFill") == 0, "d2.root.children_nodes[0].children_nodes[0].children_nodes[0].name == \"BallFill\"");
#line 384 "SerializableGeeTreeMapTest.vala"
		_g_free0 (_tmp458_);
#line 384 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp455_);
#line 384 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp453_);
#line 384 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp450_);
#line 384 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp448_);
#line 384 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp445_);
#line 384 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp443_);
#line 384 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp440_);
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp459_ = d2;
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp460_ = gxml_document_get_root ((GXmlDocument*) _tmp459_);
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp461_ = _tmp460_;
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp462_ = _tmp461_;
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp463_ = gxml_node_get_children_nodes (_tmp462_);
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp464_ = _tmp463_;
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp465_ = _tmp464_;
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp466_ = gee_list_get ((GeeList*) _tmp465_, 0);
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp467_ = (GXmlNode*) _tmp466_;
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp468_ = gxml_node_get_children_nodes (_tmp467_);
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp469_ = _tmp468_;
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp470_ = _tmp469_;
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp471_ = gee_list_get ((GeeList*) _tmp470_, 0);
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp472_ = (GXmlNode*) _tmp471_;
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp473_ = gxml_node_get_children_nodes (_tmp472_);
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp474_ = _tmp473_;
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp475_ = _tmp474_;
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp476_ = gee_list_get ((GeeList*) _tmp475_, 0);
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp477_ = (GXmlNode*) _tmp476_;
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp478_ = gxml_node_get_children_nodes (_tmp477_);
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp479_ = _tmp478_;
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp480_ = _tmp479_;
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp481_ = gee_collection_get_size ((GeeCollection*) _tmp480_);
#line 385 "SerializableGeeTreeMapTest.vala"
		_tmp482_ = _tmp481_;
#line 385 "SerializableGeeTreeMapTest.vala"
		_vala_assert (_tmp482_ == 1, "d2.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes.size == 1");
#line 385 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp480_);
#line 385 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp477_);
#line 385 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp475_);
#line 385 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp472_);
#line 385 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp470_);
#line 385 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp467_);
#line 385 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp465_);
#line 385 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp462_);
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp483_ = d2;
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp484_ = gxml_document_get_root ((GXmlDocument*) _tmp483_);
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp485_ = _tmp484_;
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp486_ = _tmp485_;
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp487_ = gxml_node_get_children_nodes (_tmp486_);
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp488_ = _tmp487_;
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp489_ = _tmp488_;
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp490_ = gee_list_get ((GeeList*) _tmp489_, 0);
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp491_ = (GXmlNode*) _tmp490_;
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp492_ = gxml_node_get_children_nodes (_tmp491_);
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp493_ = _tmp492_;
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp494_ = _tmp493_;
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp495_ = gee_list_get ((GeeList*) _tmp494_, 0);
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp496_ = (GXmlNode*) _tmp495_;
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp497_ = gxml_node_get_children_nodes (_tmp496_);
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp498_ = _tmp497_;
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp499_ = _tmp498_;
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp500_ = gee_list_get ((GeeList*) _tmp499_, 0);
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp501_ = (GXmlNode*) _tmp500_;
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp502_ = gxml_node_get_children_nodes (_tmp501_);
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp503_ = _tmp502_;
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp504_ = _tmp503_;
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp505_ = gee_list_get ((GeeList*) _tmp504_, 0);
#line 386 "SerializableGeeTreeMapTest.vala"
		_tmp506_ = (GXmlNode*) _tmp505_;
#line 386 "SerializableGeeTreeMapTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp506_, GXML_TYPE_TEXT), "d2.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes[0] is GXml.Text");
#line 386 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp506_);
#line 386 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp504_);
#line 386 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp501_);
#line 386 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp499_);
#line 386 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp496_);
#line 386 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp494_);
#line 386 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp491_);
#line 386 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp489_);
#line 386 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp486_);
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp507_ = d2;
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp508_ = gxml_document_get_root ((GXmlDocument*) _tmp507_);
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp509_ = _tmp508_;
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp510_ = _tmp509_;
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp511_ = gxml_node_get_children_nodes (_tmp510_);
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp512_ = _tmp511_;
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp513_ = _tmp512_;
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp514_ = gee_list_get ((GeeList*) _tmp513_, 0);
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp515_ = (GXmlNode*) _tmp514_;
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp516_ = gxml_node_get_children_nodes (_tmp515_);
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp517_ = _tmp516_;
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp518_ = _tmp517_;
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp519_ = gee_list_get ((GeeList*) _tmp518_, 0);
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp520_ = (GXmlNode*) _tmp519_;
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp521_ = gxml_node_get_children_nodes (_tmp520_);
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp522_ = _tmp521_;
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp523_ = _tmp522_;
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp524_ = gee_list_get ((GeeList*) _tmp523_, 0);
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp525_ = (GXmlNode*) _tmp524_;
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp526_ = gxml_node_get_children_nodes (_tmp525_);
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp527_ = _tmp526_;
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp528_ = _tmp527_;
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp529_ = gee_list_get ((GeeList*) _tmp528_, 0);
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp530_ = (GXmlNode*) _tmp529_;
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp531_ = gxml_node_get_value (_tmp530_);
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp532_ = _tmp531_;
#line 387 "SerializableGeeTreeMapTest.vala"
		_tmp533_ = _tmp532_;
#line 387 "SerializableGeeTreeMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp533_, "golden dust") == 0, "d2.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes[0].value == \"golden dust\"");
#line 387 "SerializableGeeTreeMapTest.vala"
		_g_free0 (_tmp533_);
#line 387 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp530_);
#line 387 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp528_);
#line 387 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp525_);
#line 387 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp523_);
#line 387 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp520_);
#line 387 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp518_);
#line 387 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp515_);
#line 387 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp513_);
#line 387 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp510_);
#line 317 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (d2);
#line 317 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (bag2);
#line 317 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (bag3);
#line 317 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (bagt);
#line 317 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (d);
#line 317 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (bag);
#line 5131 "SerializableGeeTreeMapTest.c"
	}
	goto __finally351;
	__catch351_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp534_;
		gchar* _tmp535_;
		gchar* _tmp536_;
#line 317 "SerializableGeeTreeMapTest.vala"
		e = _inner_error0_;
#line 317 "SerializableGeeTreeMapTest.vala"
		_inner_error0_ = NULL;
#line 389 "SerializableGeeTreeMapTest.vala"
		_tmp534_ = e->message;
#line 389 "SerializableGeeTreeMapTest.vala"
		_tmp535_ = g_strconcat ("ERROR: ", _tmp534_, NULL);
#line 389 "SerializableGeeTreeMapTest.vala"
		_tmp536_ = _tmp535_;
#line 389 "SerializableGeeTreeMapTest.vala"
		g_message ("SerializableGeeTreeMapTest.vala:389: %s", _tmp536_);
#line 389 "SerializableGeeTreeMapTest.vala"
		_g_free0 (_tmp536_);
#line 390 "SerializableGeeTreeMapTest.vala"
		g_assert_not_reached ();
#line 317 "SerializableGeeTreeMapTest.vala"
		_g_error_free0 (e);
#line 5158 "SerializableGeeTreeMapTest.c"
	}
	__finally351:
#line 317 "SerializableGeeTreeMapTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 317 "SerializableGeeTreeMapTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 317 "SerializableGeeTreeMapTest.vala"
		g_clear_error (&_inner_error0_);
#line 317 "SerializableGeeTreeMapTest.vala"
		return;
#line 5169 "SerializableGeeTreeMapTest.c"
	}
}

static void
___lambda298__gtest_func (void)
{
#line 315 "SerializableGeeTreeMapTest.vala"
	__lambda298_ ();
#line 5178 "SerializableGeeTreeMapTest.c"
}

void
serializable_gee_tree_map_test_add_tests (void)
{
#line 99 "SerializableGeeTreeMapTest.vala"
	g_test_add_func ("/gxml/serializable/treemap/api", ___lambda292__gtest_func);
#line 134 "SerializableGeeTreeMapTest.vala"
	g_test_add_func ("/gxml/serializable/treemap/serialize", ___lambda293__gtest_func);
#line 172 "SerializableGeeTreeMapTest.vala"
	g_test_add_func ("/gxml/serializable/treemap/deserialize", ___lambda294__gtest_func);
#line 203 "SerializableGeeTreeMapTest.vala"
	g_test_add_func ("/gxml/serializable/treemap/container_class/deserialize", ___lambda295__gtest_func);
#line 242 "SerializableGeeTreeMapTest.vala"
	g_test_add_func ("/gxml/serializable/treemap/containder_class/serialize", ___lambda296__gtest_func);
#line 288 "SerializableGeeTreeMapTest.vala"
	g_test_add_func ("/gxml/serializable/treemap/deserialize-node-names", ___lambda297__gtest_func);
#line 315 "SerializableGeeTreeMapTest.vala"
	g_test_add_func ("/gxml/serializable/treemap/post-deserialization/serialize/contents", ___lambda298__gtest_func);
#line 5198 "SerializableGeeTreeMapTest.c"
}

SerializableGeeTreeMapTest*
serializable_gee_tree_map_test_construct (GType object_type)
{
	SerializableGeeTreeMapTest* self = NULL;
#line 29 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTest*) gxml_test_construct (object_type);
#line 29 "SerializableGeeTreeMapTest.vala"
	return self;
#line 5209 "SerializableGeeTreeMapTest.c"
}

SerializableGeeTreeMapTest*
serializable_gee_tree_map_test_new (void)
{
#line 29 "SerializableGeeTreeMapTest.vala"
	return serializable_gee_tree_map_test_construct (TYPE_SERIALIZABLE_GEE_TREE_MAP_TEST);
#line 5217 "SerializableGeeTreeMapTest.c"
}

static inline gpointer
serializable_gee_tree_map_test_space_get_instance_private (SerializableGeeTreeMapTestSpace* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeTreeMapTestSpace_private_offset);
}

static gchar*
serializable_gee_tree_map_test_space_real_get_map_key (GXmlSerializableMapKey* base)
{
	SerializableGeeTreeMapTestSpace * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 33 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestSpace*) base;
#line 33 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 33 "SerializableGeeTreeMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 33 "SerializableGeeTreeMapTest.vala"
	result = _tmp1_;
#line 33 "SerializableGeeTreeMapTest.vala"
	return result;
#line 5243 "SerializableGeeTreeMapTest.c"
}

static SerializableGeeTreeMapTestSpace*
serializable_gee_tree_map_test_space_construct_named (GType object_type,
                                                      const gchar* name)
{
	SerializableGeeTreeMapTestSpace * self = NULL;
#line 35 "SerializableGeeTreeMapTest.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 35 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestSpace*) gxml_serializable_object_model_construct (object_type);
#line 35 "SerializableGeeTreeMapTest.vala"
	serializable_gee_tree_map_test_space_set_name (self, name);
#line 35 "SerializableGeeTreeMapTest.vala"
	return self;
#line 5259 "SerializableGeeTreeMapTest.c"
}

static SerializableGeeTreeMapTestSpace*
serializable_gee_tree_map_test_space_new_named (const gchar* name)
{
#line 35 "SerializableGeeTreeMapTest.vala"
	return serializable_gee_tree_map_test_space_construct_named (SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE, name);
#line 5267 "SerializableGeeTreeMapTest.c"
}

static gchar*
serializable_gee_tree_map_test_space_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeTreeMapTestSpace * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 36 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestSpace*) base;
#line 36 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = g_strdup ("space");
#line 36 "SerializableGeeTreeMapTest.vala"
	result = _tmp0_;
#line 36 "SerializableGeeTreeMapTest.vala"
	return result;
#line 5284 "SerializableGeeTreeMapTest.c"
}

static gchar*
serializable_gee_tree_map_test_space_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeTreeMapTestSpace * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 37 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestSpace*) base;
#line 37 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 37 "SerializableGeeTreeMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 37 "SerializableGeeTreeMapTest.vala"
	result = _tmp1_;
#line 37 "SerializableGeeTreeMapTest.vala"
	return result;
#line 5304 "SerializableGeeTreeMapTest.c"
}

static SerializableGeeTreeMapTestSpace*
serializable_gee_tree_map_test_space_construct (GType object_type)
{
	SerializableGeeTreeMapTestSpace * self = NULL;
#line 31 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestSpace*) gxml_serializable_object_model_construct (object_type);
#line 31 "SerializableGeeTreeMapTest.vala"
	return self;
#line 5315 "SerializableGeeTreeMapTest.c"
}

static SerializableGeeTreeMapTestSpace*
serializable_gee_tree_map_test_space_new (void)
{
#line 31 "SerializableGeeTreeMapTest.vala"
	return serializable_gee_tree_map_test_space_construct (SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE);
#line 5323 "SerializableGeeTreeMapTest.c"
}

static const gchar*
serializable_gee_tree_map_test_space_get_name (SerializableGeeTreeMapTestSpace* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 34 "SerializableGeeTreeMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 34 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 34 "SerializableGeeTreeMapTest.vala"
	result = _tmp0_;
#line 34 "SerializableGeeTreeMapTest.vala"
	return result;
#line 5339 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_space_set_name (SerializableGeeTreeMapTestSpace* self,
                                               const gchar* value)
{
#line 34 "SerializableGeeTreeMapTest.vala"
	g_return_if_fail (self != NULL);
#line 34 "SerializableGeeTreeMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_tree_map_test_space_get_name (self)) != 0) {
#line 5350 "SerializableGeeTreeMapTest.c"
		gchar* _tmp0_;
#line 34 "SerializableGeeTreeMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 34 "SerializableGeeTreeMapTest.vala"
		_g_free0 (self->priv->_name);
#line 34 "SerializableGeeTreeMapTest.vala"
		self->priv->_name = _tmp0_;
#line 34 "SerializableGeeTreeMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_tree_map_test_space_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_NAME_PROPERTY]);
#line 5360 "SerializableGeeTreeMapTest.c"
	}
}

static SerializableGeeTreeMapTestSpaceCollection*
serializable_gee_tree_map_test_space_collection_construct (GType object_type)
{
	SerializableGeeTreeMapTestSpaceCollection * self = NULL;
#line 38 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestSpaceCollection*) gxml_serializable_tree_map_construct (object_type, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 38 "SerializableGeeTreeMapTest.vala"
	return self;
#line 5372 "SerializableGeeTreeMapTest.c"
}

static SerializableGeeTreeMapTestSpaceCollection*
serializable_gee_tree_map_test_space_collection_new (void)
{
#line 38 "SerializableGeeTreeMapTest.vala"
	return serializable_gee_tree_map_test_space_collection_construct (SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_TYPE_COLLECTION);
#line 5380 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_space_collection_class_init (SerializableGeeTreeMapTestSpaceCollectionClass * klass,
                                                            gpointer klass_data)
{
#line 38 "SerializableGeeTreeMapTest.vala"
	serializable_gee_tree_map_test_space_collection_parent_class = g_type_class_peek_parent (klass);
#line 5389 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_space_collection_instance_init (SerializableGeeTreeMapTestSpaceCollection * self,
                                                               gpointer klass)
{
}

GType
serializable_gee_tree_map_test_space_collection_get_type (void)
{
	static volatile gsize serializable_gee_tree_map_test_space_collection_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_tree_map_test_space_collection_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeTreeMapTestSpaceCollectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_tree_map_test_space_collection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeTreeMapTestSpaceCollection), 0, (GInstanceInitFunc) serializable_gee_tree_map_test_space_collection_instance_init, NULL };
		GType serializable_gee_tree_map_test_space_collection_type_id;
		serializable_gee_tree_map_test_space_collection_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_TREE_MAP, "SerializableGeeTreeMapTestSpaceCollection", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_tree_map_test_space_collection_type_id__volatile, serializable_gee_tree_map_test_space_collection_type_id);
	}
	return serializable_gee_tree_map_test_space_collection_type_id__volatile;
}

static void
serializable_gee_tree_map_test_space_class_init (SerializableGeeTreeMapTestSpaceClass * klass,
                                                 gpointer klass_data)
{
#line 31 "SerializableGeeTreeMapTest.vala"
	serializable_gee_tree_map_test_space_parent_class = g_type_class_peek_parent (klass);
#line 31 "SerializableGeeTreeMapTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeTreeMapTestSpace_private_offset);
#line 31 "SerializableGeeTreeMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_tree_map_test_space_real_node_name;
#line 31 "SerializableGeeTreeMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_tree_map_test_space_real_to_string;
#line 31 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_tree_map_test_space_get_property;
#line 31 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_tree_map_test_space_set_property;
#line 31 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_tree_map_test_space_finalize;
#line 31 "SerializableGeeTreeMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_NAME_PROPERTY, serializable_gee_tree_map_test_space_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5431 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_space_gxml_serializable_map_key_interface_init (GXmlSerializableMapKeyIface * iface,
                                                                               gpointer iface_data)
{
#line 31 "SerializableGeeTreeMapTest.vala"
	serializable_gee_tree_map_test_space_gxml_serializable_map_key_parent_iface = g_type_interface_peek_parent (iface);
#line 31 "SerializableGeeTreeMapTest.vala"
	iface->get_map_key = (gpointer (*) (GXmlSerializableMapKey*)) serializable_gee_tree_map_test_space_real_get_map_key;
#line 5442 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_space_instance_init (SerializableGeeTreeMapTestSpace * self,
                                                    gpointer klass)
{
#line 31 "SerializableGeeTreeMapTest.vala"
	self->priv = serializable_gee_tree_map_test_space_get_instance_private (self);
#line 5451 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_space_finalize (GObject * obj)
{
	SerializableGeeTreeMapTestSpace * self;
#line 31 "SerializableGeeTreeMapTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE, SerializableGeeTreeMapTestSpace);
#line 34 "SerializableGeeTreeMapTest.vala"
	_g_free0 (self->priv->_name);
#line 31 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (serializable_gee_tree_map_test_space_parent_class)->finalize (obj);
#line 5464 "SerializableGeeTreeMapTest.c"
}

static GType
serializable_gee_tree_map_test_space_get_type (void)
{
	static volatile gsize serializable_gee_tree_map_test_space_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_tree_map_test_space_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeTreeMapTestSpaceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_tree_map_test_space_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeTreeMapTestSpace), 0, (GInstanceInitFunc) serializable_gee_tree_map_test_space_instance_init, NULL };
		static const GInterfaceInfo gxml_serializable_map_key_info = { (GInterfaceInitFunc) serializable_gee_tree_map_test_space_gxml_serializable_map_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType serializable_gee_tree_map_test_space_type_id;
		serializable_gee_tree_map_test_space_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeTreeMapTestSpace", &g_define_type_info, 0);
		g_type_add_interface_static (serializable_gee_tree_map_test_space_type_id, GXML_TYPE_SERIALIZABLE_MAP_KEY, &gxml_serializable_map_key_info);
		SerializableGeeTreeMapTestSpace_private_offset = g_type_add_instance_private (serializable_gee_tree_map_test_space_type_id, sizeof (SerializableGeeTreeMapTestSpacePrivate));
		g_once_init_leave (&serializable_gee_tree_map_test_space_type_id__volatile, serializable_gee_tree_map_test_space_type_id);
	}
	return serializable_gee_tree_map_test_space_type_id__volatile;
}

static void
_vala_serializable_gee_tree_map_test_space_get_property (GObject * object,
                                                         guint property_id,
                                                         GValue * value,
                                                         GParamSpec * pspec)
{
	SerializableGeeTreeMapTestSpace * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE, SerializableGeeTreeMapTestSpace);
#line 31 "SerializableGeeTreeMapTest.vala"
	switch (property_id) {
#line 31 "SerializableGeeTreeMapTest.vala"
		case SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_NAME_PROPERTY:
#line 31 "SerializableGeeTreeMapTest.vala"
		g_value_set_string (value, serializable_gee_tree_map_test_space_get_name (self));
#line 31 "SerializableGeeTreeMapTest.vala"
		break;
#line 5499 "SerializableGeeTreeMapTest.c"
		default:
#line 31 "SerializableGeeTreeMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 31 "SerializableGeeTreeMapTest.vala"
		break;
#line 5505 "SerializableGeeTreeMapTest.c"
	}
}

static void
_vala_serializable_gee_tree_map_test_space_set_property (GObject * object,
                                                         guint property_id,
                                                         const GValue * value,
                                                         GParamSpec * pspec)
{
	SerializableGeeTreeMapTestSpace * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE, SerializableGeeTreeMapTestSpace);
#line 31 "SerializableGeeTreeMapTest.vala"
	switch (property_id) {
#line 31 "SerializableGeeTreeMapTest.vala"
		case SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_NAME_PROPERTY:
#line 31 "SerializableGeeTreeMapTest.vala"
		serializable_gee_tree_map_test_space_set_name (self, g_value_get_string (value));
#line 31 "SerializableGeeTreeMapTest.vala"
		break;
#line 5525 "SerializableGeeTreeMapTest.c"
		default:
#line 31 "SerializableGeeTreeMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 31 "SerializableGeeTreeMapTest.vala"
		break;
#line 5531 "SerializableGeeTreeMapTest.c"
	}
}

static inline gpointer
serializable_gee_tree_map_test_space_container_get_instance_private (SerializableGeeTreeMapTestSpaceContainer* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeTreeMapTestSpaceContainer_private_offset);
}

static gchar*
serializable_gee_tree_map_test_space_container_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeTreeMapTestSpaceContainer * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 45 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestSpaceContainer*) base;
#line 45 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = g_strdup ("spacecontainer");
#line 45 "SerializableGeeTreeMapTest.vala"
	result = _tmp0_;
#line 45 "SerializableGeeTreeMapTest.vala"
	return result;
#line 5555 "SerializableGeeTreeMapTest.c"
}

static gchar*
serializable_gee_tree_map_test_space_container_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeTreeMapTestSpaceContainer * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 46 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestSpaceContainer*) base;
#line 46 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = self->priv->_owner;
#line 46 "SerializableGeeTreeMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 46 "SerializableGeeTreeMapTest.vala"
	result = _tmp1_;
#line 46 "SerializableGeeTreeMapTest.vala"
	return result;
#line 5575 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_space_container_real_init_containers (GXmlSerializableContainer* base)
{
	SerializableGeeTreeMapTestSpaceContainer * self;
	SerializableGeeTreeMapTestSpaceCollection* _tmp0_;
#line 48 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestSpaceContainer*) base;
#line 49 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = self->priv->_storage;
#line 49 "SerializableGeeTreeMapTest.vala"
	if (_tmp0_ == NULL) {
#line 5589 "SerializableGeeTreeMapTest.c"
		SerializableGeeTreeMapTestSpaceCollection* _tmp1_;
		SerializableGeeTreeMapTestSpaceCollection* _tmp2_;
#line 50 "SerializableGeeTreeMapTest.vala"
		_tmp1_ = serializable_gee_tree_map_test_space_collection_new ();
#line 50 "SerializableGeeTreeMapTest.vala"
		_tmp2_ = _tmp1_;
#line 50 "SerializableGeeTreeMapTest.vala"
		serializable_gee_tree_map_test_space_container_set_storage (self, _tmp2_);
#line 50 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (_tmp2_);
#line 5600 "SerializableGeeTreeMapTest.c"
	}
}

static SerializableGeeTreeMapTestSpaceContainer*
serializable_gee_tree_map_test_space_container_construct (GType object_type)
{
	SerializableGeeTreeMapTestSpaceContainer * self = NULL;
#line 41 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestSpaceContainer*) gxml_serializable_container_construct (object_type);
#line 41 "SerializableGeeTreeMapTest.vala"
	return self;
#line 5612 "SerializableGeeTreeMapTest.c"
}

static SerializableGeeTreeMapTestSpaceContainer*
serializable_gee_tree_map_test_space_container_new (void)
{
#line 41 "SerializableGeeTreeMapTest.vala"
	return serializable_gee_tree_map_test_space_container_construct (SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE_CONTAINER);
#line 5620 "SerializableGeeTreeMapTest.c"
}

static const gchar*
serializable_gee_tree_map_test_space_container_get_owner (SerializableGeeTreeMapTestSpaceContainer* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 43 "SerializableGeeTreeMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 43 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = self->priv->_owner;
#line 43 "SerializableGeeTreeMapTest.vala"
	result = _tmp0_;
#line 43 "SerializableGeeTreeMapTest.vala"
	return result;
#line 5636 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_space_container_set_owner (SerializableGeeTreeMapTestSpaceContainer* self,
                                                          const gchar* value)
{
#line 43 "SerializableGeeTreeMapTest.vala"
	g_return_if_fail (self != NULL);
#line 43 "SerializableGeeTreeMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_tree_map_test_space_container_get_owner (self)) != 0) {
#line 5647 "SerializableGeeTreeMapTest.c"
		gchar* _tmp0_;
#line 43 "SerializableGeeTreeMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 43 "SerializableGeeTreeMapTest.vala"
		_g_free0 (self->priv->_owner);
#line 43 "SerializableGeeTreeMapTest.vala"
		self->priv->_owner = _tmp0_;
#line 43 "SerializableGeeTreeMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_tree_map_test_space_container_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_CONTAINER_OWNER_PROPERTY]);
#line 5657 "SerializableGeeTreeMapTest.c"
	}
}

static SerializableGeeTreeMapTestSpaceCollection*
serializable_gee_tree_map_test_space_container_get_storage (SerializableGeeTreeMapTestSpaceContainer* self)
{
	SerializableGeeTreeMapTestSpaceCollection* result;
	SerializableGeeTreeMapTestSpaceCollection* _tmp0_;
#line 44 "SerializableGeeTreeMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 44 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = self->priv->_storage;
#line 44 "SerializableGeeTreeMapTest.vala"
	result = _tmp0_;
#line 44 "SerializableGeeTreeMapTest.vala"
	return result;
#line 5674 "SerializableGeeTreeMapTest.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 44 "SerializableGeeTreeMapTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 5682 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_space_container_set_storage (SerializableGeeTreeMapTestSpaceContainer* self,
                                                            SerializableGeeTreeMapTestSpaceCollection* value)
{
#line 44 "SerializableGeeTreeMapTest.vala"
	g_return_if_fail (self != NULL);
#line 44 "SerializableGeeTreeMapTest.vala"
	if (serializable_gee_tree_map_test_space_container_get_storage (self) != value) {
#line 5693 "SerializableGeeTreeMapTest.c"
		SerializableGeeTreeMapTestSpaceCollection* _tmp0_;
#line 44 "SerializableGeeTreeMapTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 44 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (self->priv->_storage);
#line 44 "SerializableGeeTreeMapTest.vala"
		self->priv->_storage = _tmp0_;
#line 44 "SerializableGeeTreeMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_tree_map_test_space_container_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_CONTAINER_STORAGE_PROPERTY]);
#line 5703 "SerializableGeeTreeMapTest.c"
	}
}

static void
serializable_gee_tree_map_test_space_container_class_init (SerializableGeeTreeMapTestSpaceContainerClass * klass,
                                                           gpointer klass_data)
{
#line 41 "SerializableGeeTreeMapTest.vala"
	serializable_gee_tree_map_test_space_container_parent_class = g_type_class_peek_parent (klass);
#line 41 "SerializableGeeTreeMapTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeTreeMapTestSpaceContainer_private_offset);
#line 41 "SerializableGeeTreeMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_tree_map_test_space_container_real_node_name;
#line 41 "SerializableGeeTreeMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_tree_map_test_space_container_real_to_string;
#line 41 "SerializableGeeTreeMapTest.vala"
	((GXmlSerializableContainerClass *) klass)->init_containers = (void (*) (GXmlSerializableContainer*)) serializable_gee_tree_map_test_space_container_real_init_containers;
#line 41 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_tree_map_test_space_container_get_property;
#line 41 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_tree_map_test_space_container_set_property;
#line 41 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_tree_map_test_space_container_finalize;
#line 41 "SerializableGeeTreeMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_CONTAINER_OWNER_PROPERTY, serializable_gee_tree_map_test_space_container_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_CONTAINER_OWNER_PROPERTY] = g_param_spec_string ("owner", "owner", "owner", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 41 "SerializableGeeTreeMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_CONTAINER_STORAGE_PROPERTY, serializable_gee_tree_map_test_space_container_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_CONTAINER_STORAGE_PROPERTY] = g_param_spec_object ("storage", "storage", "storage", SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_TYPE_COLLECTION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5731 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_space_container_instance_init (SerializableGeeTreeMapTestSpaceContainer * self,
                                                              gpointer klass)
{
#line 41 "SerializableGeeTreeMapTest.vala"
	self->priv = serializable_gee_tree_map_test_space_container_get_instance_private (self);
#line 5740 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_space_container_finalize (GObject * obj)
{
	SerializableGeeTreeMapTestSpaceContainer * self;
#line 41 "SerializableGeeTreeMapTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE_CONTAINER, SerializableGeeTreeMapTestSpaceContainer);
#line 43 "SerializableGeeTreeMapTest.vala"
	_g_free0 (self->priv->_owner);
#line 44 "SerializableGeeTreeMapTest.vala"
	_g_object_unref0 (self->priv->_storage);
#line 41 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (serializable_gee_tree_map_test_space_container_parent_class)->finalize (obj);
#line 5755 "SerializableGeeTreeMapTest.c"
}

static GType
serializable_gee_tree_map_test_space_container_get_type (void)
{
	static volatile gsize serializable_gee_tree_map_test_space_container_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_tree_map_test_space_container_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeTreeMapTestSpaceContainerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_tree_map_test_space_container_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeTreeMapTestSpaceContainer), 0, (GInstanceInitFunc) serializable_gee_tree_map_test_space_container_instance_init, NULL };
		GType serializable_gee_tree_map_test_space_container_type_id;
		serializable_gee_tree_map_test_space_container_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_CONTAINER, "SerializableGeeTreeMapTestSpaceContainer", &g_define_type_info, 0);
		SerializableGeeTreeMapTestSpaceContainer_private_offset = g_type_add_instance_private (serializable_gee_tree_map_test_space_container_type_id, sizeof (SerializableGeeTreeMapTestSpaceContainerPrivate));
		g_once_init_leave (&serializable_gee_tree_map_test_space_container_type_id__volatile, serializable_gee_tree_map_test_space_container_type_id);
	}
	return serializable_gee_tree_map_test_space_container_type_id__volatile;
}

static void
_vala_serializable_gee_tree_map_test_space_container_get_property (GObject * object,
                                                                   guint property_id,
                                                                   GValue * value,
                                                                   GParamSpec * pspec)
{
	SerializableGeeTreeMapTestSpaceContainer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE_CONTAINER, SerializableGeeTreeMapTestSpaceContainer);
#line 41 "SerializableGeeTreeMapTest.vala"
	switch (property_id) {
#line 41 "SerializableGeeTreeMapTest.vala"
		case SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_CONTAINER_OWNER_PROPERTY:
#line 41 "SerializableGeeTreeMapTest.vala"
		g_value_set_string (value, serializable_gee_tree_map_test_space_container_get_owner (self));
#line 41 "SerializableGeeTreeMapTest.vala"
		break;
#line 41 "SerializableGeeTreeMapTest.vala"
		case SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_CONTAINER_STORAGE_PROPERTY:
#line 41 "SerializableGeeTreeMapTest.vala"
		g_value_set_object (value, serializable_gee_tree_map_test_space_container_get_storage (self));
#line 41 "SerializableGeeTreeMapTest.vala"
		break;
#line 5794 "SerializableGeeTreeMapTest.c"
		default:
#line 41 "SerializableGeeTreeMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 41 "SerializableGeeTreeMapTest.vala"
		break;
#line 5800 "SerializableGeeTreeMapTest.c"
	}
}

static void
_vala_serializable_gee_tree_map_test_space_container_set_property (GObject * object,
                                                                   guint property_id,
                                                                   const GValue * value,
                                                                   GParamSpec * pspec)
{
	SerializableGeeTreeMapTestSpaceContainer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SPACE_CONTAINER, SerializableGeeTreeMapTestSpaceContainer);
#line 41 "SerializableGeeTreeMapTest.vala"
	switch (property_id) {
#line 41 "SerializableGeeTreeMapTest.vala"
		case SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_CONTAINER_OWNER_PROPERTY:
#line 41 "SerializableGeeTreeMapTest.vala"
		serializable_gee_tree_map_test_space_container_set_owner (self, g_value_get_string (value));
#line 41 "SerializableGeeTreeMapTest.vala"
		break;
#line 41 "SerializableGeeTreeMapTest.vala"
		case SERIALIZABLE_GEE_TREE_MAP_TEST_SPACE_CONTAINER_STORAGE_PROPERTY:
#line 41 "SerializableGeeTreeMapTest.vala"
		serializable_gee_tree_map_test_space_container_set_storage (self, g_value_get_object (value));
#line 41 "SerializableGeeTreeMapTest.vala"
		break;
#line 5826 "SerializableGeeTreeMapTest.c"
		default:
#line 41 "SerializableGeeTreeMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 41 "SerializableGeeTreeMapTest.vala"
		break;
#line 5832 "SerializableGeeTreeMapTest.c"
	}
}

static inline gpointer
serializable_gee_tree_map_test_ball_fill_get_instance_private (SerializableGeeTreeMapTestBallFill* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeTreeMapTestBallFill_private_offset);
}

static void
serializable_gee_tree_map_test_ball_fill_set_text (SerializableGeeTreeMapTestBallFill* self,
                                                   const gchar* txt)
{
#line 58 "SerializableGeeTreeMapTest.vala"
	g_return_if_fail (self != NULL);
#line 58 "SerializableGeeTreeMapTest.vala"
	g_return_if_fail (txt != NULL);
#line 58 "SerializableGeeTreeMapTest.vala"
	gxml_serializable_set_serialized_xml_node_value ((GXmlSerializable*) self, txt);
#line 5852 "SerializableGeeTreeMapTest.c"
}

static gchar*
serializable_gee_tree_map_test_ball_fill_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeTreeMapTestBallFill * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 59 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestBallFill*) base;
#line 59 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 59 "SerializableGeeTreeMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 59 "SerializableGeeTreeMapTest.vala"
	result = _tmp1_;
#line 59 "SerializableGeeTreeMapTest.vala"
	return result;
#line 5872 "SerializableGeeTreeMapTest.c"
}

static gchar*
serializable_gee_tree_map_test_ball_fill_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeTreeMapTestBallFill * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 60 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestBallFill*) base;
#line 60 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = g_strdup ("BallFill");
#line 60 "SerializableGeeTreeMapTest.vala"
	result = _tmp0_;
#line 60 "SerializableGeeTreeMapTest.vala"
	return result;
#line 5889 "SerializableGeeTreeMapTest.c"
}

static gboolean
serializable_gee_tree_map_test_ball_fill_real_serialize_use_xml_node_value (GXmlSerializableObjectModel* base)
{
	SerializableGeeTreeMapTestBallFill * self;
	gboolean result = FALSE;
#line 61 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestBallFill*) base;
#line 61 "SerializableGeeTreeMapTest.vala"
	result = TRUE;
#line 61 "SerializableGeeTreeMapTest.vala"
	return result;
#line 5903 "SerializableGeeTreeMapTest.c"
}

static SerializableGeeTreeMapTestBallFill*
serializable_gee_tree_map_test_ball_fill_construct (GType object_type)
{
	SerializableGeeTreeMapTestBallFill * self = NULL;
#line 55 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestBallFill*) gxml_serializable_object_model_construct (object_type);
#line 55 "SerializableGeeTreeMapTest.vala"
	return self;
#line 5914 "SerializableGeeTreeMapTest.c"
}

static SerializableGeeTreeMapTestBallFill*
serializable_gee_tree_map_test_ball_fill_new (void)
{
#line 55 "SerializableGeeTreeMapTest.vala"
	return serializable_gee_tree_map_test_ball_fill_construct (SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BALL_FILL);
#line 5922 "SerializableGeeTreeMapTest.c"
}

static const gchar*
serializable_gee_tree_map_test_ball_fill_get_name (SerializableGeeTreeMapTestBallFill* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 57 "SerializableGeeTreeMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 57 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 57 "SerializableGeeTreeMapTest.vala"
	result = _tmp0_;
#line 57 "SerializableGeeTreeMapTest.vala"
	return result;
#line 5938 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_ball_fill_set_name (SerializableGeeTreeMapTestBallFill* self,
                                                   const gchar* value)
{
#line 57 "SerializableGeeTreeMapTest.vala"
	g_return_if_fail (self != NULL);
#line 57 "SerializableGeeTreeMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_tree_map_test_ball_fill_get_name (self)) != 0) {
#line 5949 "SerializableGeeTreeMapTest.c"
		gchar* _tmp0_;
#line 57 "SerializableGeeTreeMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 57 "SerializableGeeTreeMapTest.vala"
		_g_free0 (self->priv->_name);
#line 57 "SerializableGeeTreeMapTest.vala"
		self->priv->_name = _tmp0_;
#line 57 "SerializableGeeTreeMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_tree_map_test_ball_fill_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_FILL_NAME_PROPERTY]);
#line 5959 "SerializableGeeTreeMapTest.c"
	}
}

static void
serializable_gee_tree_map_test_ball_fill_class_init (SerializableGeeTreeMapTestBallFillClass * klass,
                                                     gpointer klass_data)
{
#line 55 "SerializableGeeTreeMapTest.vala"
	serializable_gee_tree_map_test_ball_fill_parent_class = g_type_class_peek_parent (klass);
#line 55 "SerializableGeeTreeMapTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeTreeMapTestBallFill_private_offset);
#line 55 "SerializableGeeTreeMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_tree_map_test_ball_fill_real_to_string;
#line 55 "SerializableGeeTreeMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_tree_map_test_ball_fill_real_node_name;
#line 55 "SerializableGeeTreeMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->serialize_use_xml_node_value = (gboolean (*) (GXmlSerializableObjectModel*)) serializable_gee_tree_map_test_ball_fill_real_serialize_use_xml_node_value;
#line 55 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_tree_map_test_ball_fill_get_property;
#line 55 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_tree_map_test_ball_fill_set_property;
#line 55 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_tree_map_test_ball_fill_finalize;
#line 55 "SerializableGeeTreeMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_FILL_NAME_PROPERTY, serializable_gee_tree_map_test_ball_fill_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_FILL_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5985 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_ball_fill_instance_init (SerializableGeeTreeMapTestBallFill * self,
                                                        gpointer klass)
{
	gchar* _tmp0_;
#line 55 "SerializableGeeTreeMapTest.vala"
	self->priv = serializable_gee_tree_map_test_ball_fill_get_instance_private (self);
#line 57 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = g_strdup ("Fill");
#line 57 "SerializableGeeTreeMapTest.vala"
	self->priv->_name = _tmp0_;
#line 5999 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_ball_fill_finalize (GObject * obj)
{
	SerializableGeeTreeMapTestBallFill * self;
#line 55 "SerializableGeeTreeMapTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BALL_FILL, SerializableGeeTreeMapTestBallFill);
#line 57 "SerializableGeeTreeMapTest.vala"
	_g_free0 (self->priv->_name);
#line 55 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (serializable_gee_tree_map_test_ball_fill_parent_class)->finalize (obj);
#line 6012 "SerializableGeeTreeMapTest.c"
}

static GType
serializable_gee_tree_map_test_ball_fill_get_type (void)
{
	static volatile gsize serializable_gee_tree_map_test_ball_fill_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_tree_map_test_ball_fill_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeTreeMapTestBallFillClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_tree_map_test_ball_fill_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeTreeMapTestBallFill), 0, (GInstanceInitFunc) serializable_gee_tree_map_test_ball_fill_instance_init, NULL };
		GType serializable_gee_tree_map_test_ball_fill_type_id;
		serializable_gee_tree_map_test_ball_fill_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeTreeMapTestBallFill", &g_define_type_info, 0);
		SerializableGeeTreeMapTestBallFill_private_offset = g_type_add_instance_private (serializable_gee_tree_map_test_ball_fill_type_id, sizeof (SerializableGeeTreeMapTestBallFillPrivate));
		g_once_init_leave (&serializable_gee_tree_map_test_ball_fill_type_id__volatile, serializable_gee_tree_map_test_ball_fill_type_id);
	}
	return serializable_gee_tree_map_test_ball_fill_type_id__volatile;
}

static void
_vala_serializable_gee_tree_map_test_ball_fill_get_property (GObject * object,
                                                             guint property_id,
                                                             GValue * value,
                                                             GParamSpec * pspec)
{
	SerializableGeeTreeMapTestBallFill * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BALL_FILL, SerializableGeeTreeMapTestBallFill);
#line 55 "SerializableGeeTreeMapTest.vala"
	switch (property_id) {
#line 55 "SerializableGeeTreeMapTest.vala"
		case SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_FILL_NAME_PROPERTY:
#line 55 "SerializableGeeTreeMapTest.vala"
		g_value_set_string (value, serializable_gee_tree_map_test_ball_fill_get_name (self));
#line 55 "SerializableGeeTreeMapTest.vala"
		break;
#line 6045 "SerializableGeeTreeMapTest.c"
		default:
#line 55 "SerializableGeeTreeMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 55 "SerializableGeeTreeMapTest.vala"
		break;
#line 6051 "SerializableGeeTreeMapTest.c"
	}
}

static void
_vala_serializable_gee_tree_map_test_ball_fill_set_property (GObject * object,
                                                             guint property_id,
                                                             const GValue * value,
                                                             GParamSpec * pspec)
{
	SerializableGeeTreeMapTestBallFill * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BALL_FILL, SerializableGeeTreeMapTestBallFill);
#line 55 "SerializableGeeTreeMapTest.vala"
	switch (property_id) {
#line 55 "SerializableGeeTreeMapTest.vala"
		case SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_FILL_NAME_PROPERTY:
#line 55 "SerializableGeeTreeMapTest.vala"
		serializable_gee_tree_map_test_ball_fill_set_name (self, g_value_get_string (value));
#line 55 "SerializableGeeTreeMapTest.vala"
		break;
#line 6071 "SerializableGeeTreeMapTest.c"
		default:
#line 55 "SerializableGeeTreeMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 55 "SerializableGeeTreeMapTest.vala"
		break;
#line 6077 "SerializableGeeTreeMapTest.c"
	}
}

static inline gpointer
serializable_gee_tree_map_test_ball_get_instance_private (SerializableGeeTreeMapTestBall* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeTreeMapTestBall_private_offset);
}

static gchar*
serializable_gee_tree_map_test_ball_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeTreeMapTestBall * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 68 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestBall*) base;
#line 68 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 68 "SerializableGeeTreeMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 68 "SerializableGeeTreeMapTest.vala"
	result = _tmp1_;
#line 68 "SerializableGeeTreeMapTest.vala"
	return result;
#line 6104 "SerializableGeeTreeMapTest.c"
}

static gchar*
serializable_gee_tree_map_test_ball_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeTreeMapTestBall * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 69 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestBall*) base;
#line 69 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = g_strdup ("Ball");
#line 69 "SerializableGeeTreeMapTest.vala"
	result = _tmp0_;
#line 69 "SerializableGeeTreeMapTest.vala"
	return result;
#line 6121 "SerializableGeeTreeMapTest.c"
}

static gchar*
serializable_gee_tree_map_test_ball_real_get_map_key (GXmlSerializableMapKey* base)
{
	SerializableGeeTreeMapTestBall * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 70 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestBall*) base;
#line 70 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 70 "SerializableGeeTreeMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 70 "SerializableGeeTreeMapTest.vala"
	result = _tmp1_;
#line 70 "SerializableGeeTreeMapTest.vala"
	return result;
#line 6141 "SerializableGeeTreeMapTest.c"
}

static SerializableGeeTreeMapTestBall*
serializable_gee_tree_map_test_ball_construct (GType object_type)
{
	SerializableGeeTreeMapTestBall * self = NULL;
#line 64 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestBall*) gxml_serializable_object_model_construct (object_type);
#line 64 "SerializableGeeTreeMapTest.vala"
	return self;
#line 6152 "SerializableGeeTreeMapTest.c"
}

static SerializableGeeTreeMapTestBall*
serializable_gee_tree_map_test_ball_new (void)
{
#line 64 "SerializableGeeTreeMapTest.vala"
	return serializable_gee_tree_map_test_ball_construct (SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BALL);
#line 6160 "SerializableGeeTreeMapTest.c"
}

static const gchar*
serializable_gee_tree_map_test_ball_get_name (SerializableGeeTreeMapTestBall* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 66 "SerializableGeeTreeMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 66 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 66 "SerializableGeeTreeMapTest.vala"
	result = _tmp0_;
#line 66 "SerializableGeeTreeMapTest.vala"
	return result;
#line 6176 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_ball_set_name (SerializableGeeTreeMapTestBall* self,
                                              const gchar* value)
{
#line 66 "SerializableGeeTreeMapTest.vala"
	g_return_if_fail (self != NULL);
#line 66 "SerializableGeeTreeMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_tree_map_test_ball_get_name (self)) != 0) {
#line 6187 "SerializableGeeTreeMapTest.c"
		gchar* _tmp0_;
#line 66 "SerializableGeeTreeMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 66 "SerializableGeeTreeMapTest.vala"
		_g_free0 (self->priv->_name);
#line 66 "SerializableGeeTreeMapTest.vala"
		self->priv->_name = _tmp0_;
#line 66 "SerializableGeeTreeMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_tree_map_test_ball_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_NAME_PROPERTY]);
#line 6197 "SerializableGeeTreeMapTest.c"
	}
}

static SerializableGeeTreeMapTestBallFill*
serializable_gee_tree_map_test_ball_get_ballfill (SerializableGeeTreeMapTestBall* self)
{
	SerializableGeeTreeMapTestBallFill* result;
	SerializableGeeTreeMapTestBallFill* _tmp0_;
#line 67 "SerializableGeeTreeMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 67 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = self->priv->_ballfill;
#line 67 "SerializableGeeTreeMapTest.vala"
	result = _tmp0_;
#line 67 "SerializableGeeTreeMapTest.vala"
	return result;
#line 6214 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_ball_set_ballfill (SerializableGeeTreeMapTestBall* self,
                                                  SerializableGeeTreeMapTestBallFill* value)
{
#line 67 "SerializableGeeTreeMapTest.vala"
	g_return_if_fail (self != NULL);
#line 67 "SerializableGeeTreeMapTest.vala"
	if (serializable_gee_tree_map_test_ball_get_ballfill (self) != value) {
#line 6225 "SerializableGeeTreeMapTest.c"
		SerializableGeeTreeMapTestBallFill* _tmp0_;
#line 67 "SerializableGeeTreeMapTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 67 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (self->priv->_ballfill);
#line 67 "SerializableGeeTreeMapTest.vala"
		self->priv->_ballfill = _tmp0_;
#line 67 "SerializableGeeTreeMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_tree_map_test_ball_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_BALLFILL_PROPERTY]);
#line 6235 "SerializableGeeTreeMapTest.c"
	}
}

static gboolean
serializable_gee_tree_map_test_ball_tree_map_real_deserialize_proceed (GXmlSerializableTreeMap* base)
{
	SerializableGeeTreeMapTestBallTreeMap * self;
	gboolean result = FALSE;
#line 72 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestBallTreeMap*) base;
#line 72 "SerializableGeeTreeMapTest.vala"
	result = FALSE;
#line 72 "SerializableGeeTreeMapTest.vala"
	return result;
#line 6250 "SerializableGeeTreeMapTest.c"
}

static SerializableGeeTreeMapTestBallTreeMap*
serializable_gee_tree_map_test_ball_tree_map_construct (GType object_type)
{
	SerializableGeeTreeMapTestBallTreeMap * self = NULL;
#line 71 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestBallTreeMap*) gxml_serializable_tree_map_construct (object_type, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BALL, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 71 "SerializableGeeTreeMapTest.vala"
	return self;
#line 6261 "SerializableGeeTreeMapTest.c"
}

static SerializableGeeTreeMapTestBallTreeMap*
serializable_gee_tree_map_test_ball_tree_map_new (void)
{
#line 71 "SerializableGeeTreeMapTest.vala"
	return serializable_gee_tree_map_test_ball_tree_map_construct (SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_TYPE_TREE_MAP);
#line 6269 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_ball_tree_map_class_init (SerializableGeeTreeMapTestBallTreeMapClass * klass,
                                                         gpointer klass_data)
{
#line 71 "SerializableGeeTreeMapTest.vala"
	serializable_gee_tree_map_test_ball_tree_map_parent_class = g_type_class_peek_parent (klass);
#line 71 "SerializableGeeTreeMapTest.vala"
	((GXmlSerializableTreeMapClass *) klass)->deserialize_proceed = (gboolean (*) (GXmlSerializableTreeMap*)) serializable_gee_tree_map_test_ball_tree_map_real_deserialize_proceed;
#line 6280 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_ball_tree_map_instance_init (SerializableGeeTreeMapTestBallTreeMap * self,
                                                            gpointer klass)
{
}

GType
serializable_gee_tree_map_test_ball_tree_map_get_type (void)
{
	static volatile gsize serializable_gee_tree_map_test_ball_tree_map_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_tree_map_test_ball_tree_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeTreeMapTestBallTreeMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_tree_map_test_ball_tree_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeTreeMapTestBallTreeMap), 0, (GInstanceInitFunc) serializable_gee_tree_map_test_ball_tree_map_instance_init, NULL };
		GType serializable_gee_tree_map_test_ball_tree_map_type_id;
		serializable_gee_tree_map_test_ball_tree_map_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_TREE_MAP, "SerializableGeeTreeMapTestBallTreeMap", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_tree_map_test_ball_tree_map_type_id__volatile, serializable_gee_tree_map_test_ball_tree_map_type_id);
	}
	return serializable_gee_tree_map_test_ball_tree_map_type_id__volatile;
}

static void
serializable_gee_tree_map_test_ball_class_init (SerializableGeeTreeMapTestBallClass * klass,
                                                gpointer klass_data)
{
#line 64 "SerializableGeeTreeMapTest.vala"
	serializable_gee_tree_map_test_ball_parent_class = g_type_class_peek_parent (klass);
#line 64 "SerializableGeeTreeMapTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeTreeMapTestBall_private_offset);
#line 64 "SerializableGeeTreeMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_tree_map_test_ball_real_to_string;
#line 64 "SerializableGeeTreeMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_tree_map_test_ball_real_node_name;
#line 64 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_tree_map_test_ball_get_property;
#line 64 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_tree_map_test_ball_set_property;
#line 64 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_tree_map_test_ball_finalize;
#line 64 "SerializableGeeTreeMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_NAME_PROPERTY, serializable_gee_tree_map_test_ball_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 64 "SerializableGeeTreeMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_BALLFILL_PROPERTY, serializable_gee_tree_map_test_ball_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_BALLFILL_PROPERTY] = g_param_spec_object ("ballfill", "ballfill", "ballfill", SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BALL_FILL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6324 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_ball_gxml_serializable_map_key_interface_init (GXmlSerializableMapKeyIface * iface,
                                                                              gpointer iface_data)
{
#line 64 "SerializableGeeTreeMapTest.vala"
	serializable_gee_tree_map_test_ball_gxml_serializable_map_key_parent_iface = g_type_interface_peek_parent (iface);
#line 64 "SerializableGeeTreeMapTest.vala"
	iface->get_map_key = (gpointer (*) (GXmlSerializableMapKey*)) serializable_gee_tree_map_test_ball_real_get_map_key;
#line 6335 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_ball_instance_init (SerializableGeeTreeMapTestBall * self,
                                                   gpointer klass)
{
	gchar* _tmp0_;
#line 64 "SerializableGeeTreeMapTest.vala"
	self->priv = serializable_gee_tree_map_test_ball_get_instance_private (self);
#line 66 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = g_strdup ("Ball");
#line 66 "SerializableGeeTreeMapTest.vala"
	self->priv->_name = _tmp0_;
#line 6349 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_ball_finalize (GObject * obj)
{
	SerializableGeeTreeMapTestBall * self;
#line 64 "SerializableGeeTreeMapTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BALL, SerializableGeeTreeMapTestBall);
#line 66 "SerializableGeeTreeMapTest.vala"
	_g_free0 (self->priv->_name);
#line 67 "SerializableGeeTreeMapTest.vala"
	_g_object_unref0 (self->priv->_ballfill);
#line 64 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (serializable_gee_tree_map_test_ball_parent_class)->finalize (obj);
#line 6364 "SerializableGeeTreeMapTest.c"
}

static GType
serializable_gee_tree_map_test_ball_get_type (void)
{
	static volatile gsize serializable_gee_tree_map_test_ball_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_tree_map_test_ball_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeTreeMapTestBallClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_tree_map_test_ball_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeTreeMapTestBall), 0, (GInstanceInitFunc) serializable_gee_tree_map_test_ball_instance_init, NULL };
		static const GInterfaceInfo gxml_serializable_map_key_info = { (GInterfaceInitFunc) serializable_gee_tree_map_test_ball_gxml_serializable_map_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType serializable_gee_tree_map_test_ball_type_id;
		serializable_gee_tree_map_test_ball_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeTreeMapTestBall", &g_define_type_info, 0);
		g_type_add_interface_static (serializable_gee_tree_map_test_ball_type_id, GXML_TYPE_SERIALIZABLE_MAP_KEY, &gxml_serializable_map_key_info);
		SerializableGeeTreeMapTestBall_private_offset = g_type_add_instance_private (serializable_gee_tree_map_test_ball_type_id, sizeof (SerializableGeeTreeMapTestBallPrivate));
		g_once_init_leave (&serializable_gee_tree_map_test_ball_type_id__volatile, serializable_gee_tree_map_test_ball_type_id);
	}
	return serializable_gee_tree_map_test_ball_type_id__volatile;
}

static void
_vala_serializable_gee_tree_map_test_ball_get_property (GObject * object,
                                                        guint property_id,
                                                        GValue * value,
                                                        GParamSpec * pspec)
{
	SerializableGeeTreeMapTestBall * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BALL, SerializableGeeTreeMapTestBall);
#line 64 "SerializableGeeTreeMapTest.vala"
	switch (property_id) {
#line 64 "SerializableGeeTreeMapTest.vala"
		case SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_NAME_PROPERTY:
#line 64 "SerializableGeeTreeMapTest.vala"
		g_value_set_string (value, serializable_gee_tree_map_test_ball_get_name (self));
#line 64 "SerializableGeeTreeMapTest.vala"
		break;
#line 64 "SerializableGeeTreeMapTest.vala"
		case SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_BALLFILL_PROPERTY:
#line 64 "SerializableGeeTreeMapTest.vala"
		g_value_set_object (value, serializable_gee_tree_map_test_ball_get_ballfill (self));
#line 64 "SerializableGeeTreeMapTest.vala"
		break;
#line 6405 "SerializableGeeTreeMapTest.c"
		default:
#line 64 "SerializableGeeTreeMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 64 "SerializableGeeTreeMapTest.vala"
		break;
#line 6411 "SerializableGeeTreeMapTest.c"
	}
}

static void
_vala_serializable_gee_tree_map_test_ball_set_property (GObject * object,
                                                        guint property_id,
                                                        const GValue * value,
                                                        GParamSpec * pspec)
{
	SerializableGeeTreeMapTestBall * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BALL, SerializableGeeTreeMapTestBall);
#line 64 "SerializableGeeTreeMapTest.vala"
	switch (property_id) {
#line 64 "SerializableGeeTreeMapTest.vala"
		case SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_NAME_PROPERTY:
#line 64 "SerializableGeeTreeMapTest.vala"
		serializable_gee_tree_map_test_ball_set_name (self, g_value_get_string (value));
#line 64 "SerializableGeeTreeMapTest.vala"
		break;
#line 64 "SerializableGeeTreeMapTest.vala"
		case SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_BALLFILL_PROPERTY:
#line 64 "SerializableGeeTreeMapTest.vala"
		serializable_gee_tree_map_test_ball_set_ballfill (self, g_value_get_object (value));
#line 64 "SerializableGeeTreeMapTest.vala"
		break;
#line 6437 "SerializableGeeTreeMapTest.c"
		default:
#line 64 "SerializableGeeTreeMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 64 "SerializableGeeTreeMapTest.vala"
		break;
#line 6443 "SerializableGeeTreeMapTest.c"
	}
}

static inline gpointer
serializable_gee_tree_map_test_small_bag_get_instance_private (SerializableGeeTreeMapTestSmallBag* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeTreeMapTestSmallBag_private_offset);
}

static gchar*
serializable_gee_tree_map_test_small_bag_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeTreeMapTestSmallBag * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 80 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestSmallBag*) base;
#line 80 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 80 "SerializableGeeTreeMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 80 "SerializableGeeTreeMapTest.vala"
	result = _tmp1_;
#line 80 "SerializableGeeTreeMapTest.vala"
	return result;
#line 6470 "SerializableGeeTreeMapTest.c"
}

static gchar*
serializable_gee_tree_map_test_small_bag_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeTreeMapTestSmallBag * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 81 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestSmallBag*) base;
#line 81 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = g_strdup ("SmallBag");
#line 81 "SerializableGeeTreeMapTest.vala"
	result = _tmp0_;
#line 81 "SerializableGeeTreeMapTest.vala"
	return result;
#line 6487 "SerializableGeeTreeMapTest.c"
}

static gchar*
serializable_gee_tree_map_test_small_bag_real_get_map_key (GXmlSerializableMapKey* base)
{
	SerializableGeeTreeMapTestSmallBag * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 82 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestSmallBag*) base;
#line 82 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 82 "SerializableGeeTreeMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 82 "SerializableGeeTreeMapTest.vala"
	result = _tmp1_;
#line 82 "SerializableGeeTreeMapTest.vala"
	return result;
#line 6507 "SerializableGeeTreeMapTest.c"
}

static SerializableGeeTreeMapTestSmallBag*
serializable_gee_tree_map_test_small_bag_construct (GType object_type)
{
	SerializableGeeTreeMapTestSmallBag * self = NULL;
#line 76 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestSmallBag*) gxml_serializable_object_model_construct (object_type);
#line 76 "SerializableGeeTreeMapTest.vala"
	return self;
#line 6518 "SerializableGeeTreeMapTest.c"
}

static SerializableGeeTreeMapTestSmallBag*
serializable_gee_tree_map_test_small_bag_new (void)
{
#line 76 "SerializableGeeTreeMapTest.vala"
	return serializable_gee_tree_map_test_small_bag_construct (SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SMALL_BAG);
#line 6526 "SerializableGeeTreeMapTest.c"
}

static const gchar*
serializable_gee_tree_map_test_small_bag_get_name (SerializableGeeTreeMapTestSmallBag* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 78 "SerializableGeeTreeMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 78 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 78 "SerializableGeeTreeMapTest.vala"
	result = _tmp0_;
#line 78 "SerializableGeeTreeMapTest.vala"
	return result;
#line 6542 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_small_bag_set_name (SerializableGeeTreeMapTestSmallBag* self,
                                                   const gchar* value)
{
#line 78 "SerializableGeeTreeMapTest.vala"
	g_return_if_fail (self != NULL);
#line 78 "SerializableGeeTreeMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_tree_map_test_small_bag_get_name (self)) != 0) {
#line 6553 "SerializableGeeTreeMapTest.c"
		gchar* _tmp0_;
#line 78 "SerializableGeeTreeMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 78 "SerializableGeeTreeMapTest.vala"
		_g_free0 (self->priv->_name);
#line 78 "SerializableGeeTreeMapTest.vala"
		self->priv->_name = _tmp0_;
#line 78 "SerializableGeeTreeMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_tree_map_test_small_bag_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_NAME_PROPERTY]);
#line 6563 "SerializableGeeTreeMapTest.c"
	}
}

static SerializableGeeTreeMapTestBallTreeMap*
serializable_gee_tree_map_test_small_bag_get_balls (SerializableGeeTreeMapTestSmallBag* self)
{
	SerializableGeeTreeMapTestBallTreeMap* result;
	SerializableGeeTreeMapTestBallTreeMap* _tmp0_;
#line 79 "SerializableGeeTreeMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 79 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = self->priv->_balls;
#line 79 "SerializableGeeTreeMapTest.vala"
	result = _tmp0_;
#line 79 "SerializableGeeTreeMapTest.vala"
	return result;
#line 6580 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_small_bag_set_balls (SerializableGeeTreeMapTestSmallBag* self,
                                                    SerializableGeeTreeMapTestBallTreeMap* value)
{
#line 79 "SerializableGeeTreeMapTest.vala"
	g_return_if_fail (self != NULL);
#line 79 "SerializableGeeTreeMapTest.vala"
	if (serializable_gee_tree_map_test_small_bag_get_balls (self) != value) {
#line 6591 "SerializableGeeTreeMapTest.c"
		SerializableGeeTreeMapTestBallTreeMap* _tmp0_;
#line 79 "SerializableGeeTreeMapTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 79 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (self->priv->_balls);
#line 79 "SerializableGeeTreeMapTest.vala"
		self->priv->_balls = _tmp0_;
#line 79 "SerializableGeeTreeMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_tree_map_test_small_bag_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_BALLS_PROPERTY]);
#line 6601 "SerializableGeeTreeMapTest.c"
	}
}

static gboolean
serializable_gee_tree_map_test_small_bag_tree_map_real_deserialize_proceed (GXmlSerializableTreeMap* base)
{
	SerializableGeeTreeMapTestSmallBagTreeMap * self;
	gboolean result = FALSE;
#line 84 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestSmallBagTreeMap*) base;
#line 84 "SerializableGeeTreeMapTest.vala"
	result = FALSE;
#line 84 "SerializableGeeTreeMapTest.vala"
	return result;
#line 6616 "SerializableGeeTreeMapTest.c"
}

static SerializableGeeTreeMapTestSmallBagTreeMap*
serializable_gee_tree_map_test_small_bag_tree_map_construct (GType object_type)
{
	SerializableGeeTreeMapTestSmallBagTreeMap * self = NULL;
#line 83 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestSmallBagTreeMap*) gxml_serializable_tree_map_construct (object_type, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SMALL_BAG, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 83 "SerializableGeeTreeMapTest.vala"
	return self;
#line 6627 "SerializableGeeTreeMapTest.c"
}

static SerializableGeeTreeMapTestSmallBagTreeMap*
serializable_gee_tree_map_test_small_bag_tree_map_new (void)
{
#line 83 "SerializableGeeTreeMapTest.vala"
	return serializable_gee_tree_map_test_small_bag_tree_map_construct (SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_TYPE_TREE_MAP);
#line 6635 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_small_bag_tree_map_class_init (SerializableGeeTreeMapTestSmallBagTreeMapClass * klass,
                                                              gpointer klass_data)
{
#line 83 "SerializableGeeTreeMapTest.vala"
	serializable_gee_tree_map_test_small_bag_tree_map_parent_class = g_type_class_peek_parent (klass);
#line 83 "SerializableGeeTreeMapTest.vala"
	((GXmlSerializableTreeMapClass *) klass)->deserialize_proceed = (gboolean (*) (GXmlSerializableTreeMap*)) serializable_gee_tree_map_test_small_bag_tree_map_real_deserialize_proceed;
#line 6646 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_small_bag_tree_map_instance_init (SerializableGeeTreeMapTestSmallBagTreeMap * self,
                                                                 gpointer klass)
{
}

GType
serializable_gee_tree_map_test_small_bag_tree_map_get_type (void)
{
	static volatile gsize serializable_gee_tree_map_test_small_bag_tree_map_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_tree_map_test_small_bag_tree_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeTreeMapTestSmallBagTreeMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_tree_map_test_small_bag_tree_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeTreeMapTestSmallBagTreeMap), 0, (GInstanceInitFunc) serializable_gee_tree_map_test_small_bag_tree_map_instance_init, NULL };
		GType serializable_gee_tree_map_test_small_bag_tree_map_type_id;
		serializable_gee_tree_map_test_small_bag_tree_map_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_TREE_MAP, "SerializableGeeTreeMapTestSmallBagTreeMap", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_tree_map_test_small_bag_tree_map_type_id__volatile, serializable_gee_tree_map_test_small_bag_tree_map_type_id);
	}
	return serializable_gee_tree_map_test_small_bag_tree_map_type_id__volatile;
}

static void
serializable_gee_tree_map_test_small_bag_class_init (SerializableGeeTreeMapTestSmallBagClass * klass,
                                                     gpointer klass_data)
{
#line 76 "SerializableGeeTreeMapTest.vala"
	serializable_gee_tree_map_test_small_bag_parent_class = g_type_class_peek_parent (klass);
#line 76 "SerializableGeeTreeMapTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeTreeMapTestSmallBag_private_offset);
#line 76 "SerializableGeeTreeMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_tree_map_test_small_bag_real_to_string;
#line 76 "SerializableGeeTreeMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_tree_map_test_small_bag_real_node_name;
#line 76 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_tree_map_test_small_bag_get_property;
#line 76 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_tree_map_test_small_bag_set_property;
#line 76 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_tree_map_test_small_bag_finalize;
#line 76 "SerializableGeeTreeMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_NAME_PROPERTY, serializable_gee_tree_map_test_small_bag_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 76 "SerializableGeeTreeMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_BALLS_PROPERTY, serializable_gee_tree_map_test_small_bag_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_BALLS_PROPERTY] = g_param_spec_object ("balls", "balls", "balls", SERIALIZABLE_GEE_TREE_MAP_TEST_BALL_TYPE_TREE_MAP, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6690 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_small_bag_gxml_serializable_map_key_interface_init (GXmlSerializableMapKeyIface * iface,
                                                                                   gpointer iface_data)
{
#line 76 "SerializableGeeTreeMapTest.vala"
	serializable_gee_tree_map_test_small_bag_gxml_serializable_map_key_parent_iface = g_type_interface_peek_parent (iface);
#line 76 "SerializableGeeTreeMapTest.vala"
	iface->get_map_key = (gpointer (*) (GXmlSerializableMapKey*)) serializable_gee_tree_map_test_small_bag_real_get_map_key;
#line 6701 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_small_bag_instance_init (SerializableGeeTreeMapTestSmallBag * self,
                                                        gpointer klass)
{
	gchar* _tmp0_;
	SerializableGeeTreeMapTestBallTreeMap* _tmp1_;
#line 76 "SerializableGeeTreeMapTest.vala"
	self->priv = serializable_gee_tree_map_test_small_bag_get_instance_private (self);
#line 78 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = g_strdup ("SmallBag");
#line 78 "SerializableGeeTreeMapTest.vala"
	self->priv->_name = _tmp0_;
#line 79 "SerializableGeeTreeMapTest.vala"
	_tmp1_ = serializable_gee_tree_map_test_ball_tree_map_new ();
#line 79 "SerializableGeeTreeMapTest.vala"
	self->priv->_balls = _tmp1_;
#line 6720 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_small_bag_finalize (GObject * obj)
{
	SerializableGeeTreeMapTestSmallBag * self;
#line 76 "SerializableGeeTreeMapTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeTreeMapTestSmallBag);
#line 78 "SerializableGeeTreeMapTest.vala"
	_g_free0 (self->priv->_name);
#line 79 "SerializableGeeTreeMapTest.vala"
	_g_object_unref0 (self->priv->_balls);
#line 76 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (serializable_gee_tree_map_test_small_bag_parent_class)->finalize (obj);
#line 6735 "SerializableGeeTreeMapTest.c"
}

static GType
serializable_gee_tree_map_test_small_bag_get_type (void)
{
	static volatile gsize serializable_gee_tree_map_test_small_bag_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_tree_map_test_small_bag_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeTreeMapTestSmallBagClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_tree_map_test_small_bag_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeTreeMapTestSmallBag), 0, (GInstanceInitFunc) serializable_gee_tree_map_test_small_bag_instance_init, NULL };
		static const GInterfaceInfo gxml_serializable_map_key_info = { (GInterfaceInitFunc) serializable_gee_tree_map_test_small_bag_gxml_serializable_map_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType serializable_gee_tree_map_test_small_bag_type_id;
		serializable_gee_tree_map_test_small_bag_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeTreeMapTestSmallBag", &g_define_type_info, 0);
		g_type_add_interface_static (serializable_gee_tree_map_test_small_bag_type_id, GXML_TYPE_SERIALIZABLE_MAP_KEY, &gxml_serializable_map_key_info);
		SerializableGeeTreeMapTestSmallBag_private_offset = g_type_add_instance_private (serializable_gee_tree_map_test_small_bag_type_id, sizeof (SerializableGeeTreeMapTestSmallBagPrivate));
		g_once_init_leave (&serializable_gee_tree_map_test_small_bag_type_id__volatile, serializable_gee_tree_map_test_small_bag_type_id);
	}
	return serializable_gee_tree_map_test_small_bag_type_id__volatile;
}

static void
_vala_serializable_gee_tree_map_test_small_bag_get_property (GObject * object,
                                                             guint property_id,
                                                             GValue * value,
                                                             GParamSpec * pspec)
{
	SerializableGeeTreeMapTestSmallBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeTreeMapTestSmallBag);
#line 76 "SerializableGeeTreeMapTest.vala"
	switch (property_id) {
#line 76 "SerializableGeeTreeMapTest.vala"
		case SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_NAME_PROPERTY:
#line 76 "SerializableGeeTreeMapTest.vala"
		g_value_set_string (value, serializable_gee_tree_map_test_small_bag_get_name (self));
#line 76 "SerializableGeeTreeMapTest.vala"
		break;
#line 76 "SerializableGeeTreeMapTest.vala"
		case SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_BALLS_PROPERTY:
#line 76 "SerializableGeeTreeMapTest.vala"
		g_value_set_object (value, serializable_gee_tree_map_test_small_bag_get_balls (self));
#line 76 "SerializableGeeTreeMapTest.vala"
		break;
#line 6776 "SerializableGeeTreeMapTest.c"
		default:
#line 76 "SerializableGeeTreeMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 76 "SerializableGeeTreeMapTest.vala"
		break;
#line 6782 "SerializableGeeTreeMapTest.c"
	}
}

static void
_vala_serializable_gee_tree_map_test_small_bag_set_property (GObject * object,
                                                             guint property_id,
                                                             const GValue * value,
                                                             GParamSpec * pspec)
{
	SerializableGeeTreeMapTestSmallBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeTreeMapTestSmallBag);
#line 76 "SerializableGeeTreeMapTest.vala"
	switch (property_id) {
#line 76 "SerializableGeeTreeMapTest.vala"
		case SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_NAME_PROPERTY:
#line 76 "SerializableGeeTreeMapTest.vala"
		serializable_gee_tree_map_test_small_bag_set_name (self, g_value_get_string (value));
#line 76 "SerializableGeeTreeMapTest.vala"
		break;
#line 76 "SerializableGeeTreeMapTest.vala"
		case SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_BALLS_PROPERTY:
#line 76 "SerializableGeeTreeMapTest.vala"
		serializable_gee_tree_map_test_small_bag_set_balls (self, g_value_get_object (value));
#line 76 "SerializableGeeTreeMapTest.vala"
		break;
#line 6808 "SerializableGeeTreeMapTest.c"
		default:
#line 76 "SerializableGeeTreeMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 76 "SerializableGeeTreeMapTest.vala"
		break;
#line 6814 "SerializableGeeTreeMapTest.c"
	}
}

static inline gpointer
serializable_gee_tree_map_test_big_bag_get_instance_private (SerializableGeeTreeMapTestBigBag* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeTreeMapTestBigBag_private_offset);
}

static gchar*
serializable_gee_tree_map_test_big_bag_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeTreeMapTestBigBag * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 92 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestBigBag*) base;
#line 92 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 92 "SerializableGeeTreeMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 92 "SerializableGeeTreeMapTest.vala"
	result = _tmp1_;
#line 92 "SerializableGeeTreeMapTest.vala"
	return result;
#line 6841 "SerializableGeeTreeMapTest.c"
}

static gchar*
serializable_gee_tree_map_test_big_bag_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeTreeMapTestBigBag * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 93 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestBigBag*) base;
#line 93 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = g_strdup ("BigBag");
#line 93 "SerializableGeeTreeMapTest.vala"
	result = _tmp0_;
#line 93 "SerializableGeeTreeMapTest.vala"
	return result;
#line 6858 "SerializableGeeTreeMapTest.c"
}

static SerializableGeeTreeMapTestBigBag*
serializable_gee_tree_map_test_big_bag_construct (GType object_type)
{
	SerializableGeeTreeMapTestBigBag * self = NULL;
#line 88 "SerializableGeeTreeMapTest.vala"
	self = (SerializableGeeTreeMapTestBigBag*) gxml_serializable_object_model_construct (object_type);
#line 88 "SerializableGeeTreeMapTest.vala"
	return self;
#line 6869 "SerializableGeeTreeMapTest.c"
}

static SerializableGeeTreeMapTestBigBag*
serializable_gee_tree_map_test_big_bag_new (void)
{
#line 88 "SerializableGeeTreeMapTest.vala"
	return serializable_gee_tree_map_test_big_bag_construct (SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BIG_BAG);
#line 6877 "SerializableGeeTreeMapTest.c"
}

static const gchar*
serializable_gee_tree_map_test_big_bag_get_name (SerializableGeeTreeMapTestBigBag* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 90 "SerializableGeeTreeMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 90 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 90 "SerializableGeeTreeMapTest.vala"
	result = _tmp0_;
#line 90 "SerializableGeeTreeMapTest.vala"
	return result;
#line 6893 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_big_bag_set_name (SerializableGeeTreeMapTestBigBag* self,
                                                 const gchar* value)
{
#line 90 "SerializableGeeTreeMapTest.vala"
	g_return_if_fail (self != NULL);
#line 90 "SerializableGeeTreeMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_tree_map_test_big_bag_get_name (self)) != 0) {
#line 6904 "SerializableGeeTreeMapTest.c"
		gchar* _tmp0_;
#line 90 "SerializableGeeTreeMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 90 "SerializableGeeTreeMapTest.vala"
		_g_free0 (self->priv->_name);
#line 90 "SerializableGeeTreeMapTest.vala"
		self->priv->_name = _tmp0_;
#line 90 "SerializableGeeTreeMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_tree_map_test_big_bag_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_BIG_BAG_NAME_PROPERTY]);
#line 6914 "SerializableGeeTreeMapTest.c"
	}
}

static SerializableGeeTreeMapTestSmallBagTreeMap*
serializable_gee_tree_map_test_big_bag_get_bags (SerializableGeeTreeMapTestBigBag* self)
{
	SerializableGeeTreeMapTestSmallBagTreeMap* result;
	SerializableGeeTreeMapTestSmallBagTreeMap* _tmp0_;
#line 91 "SerializableGeeTreeMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 91 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = self->priv->_bags;
#line 91 "SerializableGeeTreeMapTest.vala"
	result = _tmp0_;
#line 91 "SerializableGeeTreeMapTest.vala"
	return result;
#line 6931 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_big_bag_set_bags (SerializableGeeTreeMapTestBigBag* self,
                                                 SerializableGeeTreeMapTestSmallBagTreeMap* value)
{
#line 91 "SerializableGeeTreeMapTest.vala"
	g_return_if_fail (self != NULL);
#line 91 "SerializableGeeTreeMapTest.vala"
	if (serializable_gee_tree_map_test_big_bag_get_bags (self) != value) {
#line 6942 "SerializableGeeTreeMapTest.c"
		SerializableGeeTreeMapTestSmallBagTreeMap* _tmp0_;
#line 91 "SerializableGeeTreeMapTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 91 "SerializableGeeTreeMapTest.vala"
		_g_object_unref0 (self->priv->_bags);
#line 91 "SerializableGeeTreeMapTest.vala"
		self->priv->_bags = _tmp0_;
#line 91 "SerializableGeeTreeMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_tree_map_test_big_bag_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_BIG_BAG_BAGS_PROPERTY]);
#line 6952 "SerializableGeeTreeMapTest.c"
	}
}

static void
serializable_gee_tree_map_test_big_bag_class_init (SerializableGeeTreeMapTestBigBagClass * klass,
                                                   gpointer klass_data)
{
#line 88 "SerializableGeeTreeMapTest.vala"
	serializable_gee_tree_map_test_big_bag_parent_class = g_type_class_peek_parent (klass);
#line 88 "SerializableGeeTreeMapTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeTreeMapTestBigBag_private_offset);
#line 88 "SerializableGeeTreeMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_tree_map_test_big_bag_real_to_string;
#line 88 "SerializableGeeTreeMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_tree_map_test_big_bag_real_node_name;
#line 88 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_tree_map_test_big_bag_get_property;
#line 88 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_tree_map_test_big_bag_set_property;
#line 88 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_tree_map_test_big_bag_finalize;
#line 88 "SerializableGeeTreeMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_TREE_MAP_TEST_BIG_BAG_NAME_PROPERTY, serializable_gee_tree_map_test_big_bag_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_BIG_BAG_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 88 "SerializableGeeTreeMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_TREE_MAP_TEST_BIG_BAG_BAGS_PROPERTY, serializable_gee_tree_map_test_big_bag_properties[SERIALIZABLE_GEE_TREE_MAP_TEST_BIG_BAG_BAGS_PROPERTY] = g_param_spec_object ("bags", "bags", "bags", SERIALIZABLE_GEE_TREE_MAP_TEST_SMALL_BAG_TYPE_TREE_MAP, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6978 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_big_bag_instance_init (SerializableGeeTreeMapTestBigBag * self,
                                                      gpointer klass)
{
	gchar* _tmp0_;
	SerializableGeeTreeMapTestSmallBagTreeMap* _tmp1_;
#line 88 "SerializableGeeTreeMapTest.vala"
	self->priv = serializable_gee_tree_map_test_big_bag_get_instance_private (self);
#line 90 "SerializableGeeTreeMapTest.vala"
	_tmp0_ = g_strdup ("ball");
#line 90 "SerializableGeeTreeMapTest.vala"
	self->priv->_name = _tmp0_;
#line 91 "SerializableGeeTreeMapTest.vala"
	_tmp1_ = serializable_gee_tree_map_test_small_bag_tree_map_new ();
#line 91 "SerializableGeeTreeMapTest.vala"
	self->priv->_bags = _tmp1_;
#line 6997 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_big_bag_finalize (GObject * obj)
{
	SerializableGeeTreeMapTestBigBag * self;
#line 88 "SerializableGeeTreeMapTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BIG_BAG, SerializableGeeTreeMapTestBigBag);
#line 90 "SerializableGeeTreeMapTest.vala"
	_g_free0 (self->priv->_name);
#line 91 "SerializableGeeTreeMapTest.vala"
	_g_object_unref0 (self->priv->_bags);
#line 88 "SerializableGeeTreeMapTest.vala"
	G_OBJECT_CLASS (serializable_gee_tree_map_test_big_bag_parent_class)->finalize (obj);
#line 7012 "SerializableGeeTreeMapTest.c"
}

static GType
serializable_gee_tree_map_test_big_bag_get_type (void)
{
	static volatile gsize serializable_gee_tree_map_test_big_bag_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_tree_map_test_big_bag_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeTreeMapTestBigBagClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_tree_map_test_big_bag_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeTreeMapTestBigBag), 0, (GInstanceInitFunc) serializable_gee_tree_map_test_big_bag_instance_init, NULL };
		GType serializable_gee_tree_map_test_big_bag_type_id;
		serializable_gee_tree_map_test_big_bag_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeTreeMapTestBigBag", &g_define_type_info, 0);
		SerializableGeeTreeMapTestBigBag_private_offset = g_type_add_instance_private (serializable_gee_tree_map_test_big_bag_type_id, sizeof (SerializableGeeTreeMapTestBigBagPrivate));
		g_once_init_leave (&serializable_gee_tree_map_test_big_bag_type_id__volatile, serializable_gee_tree_map_test_big_bag_type_id);
	}
	return serializable_gee_tree_map_test_big_bag_type_id__volatile;
}

static void
_vala_serializable_gee_tree_map_test_big_bag_get_property (GObject * object,
                                                           guint property_id,
                                                           GValue * value,
                                                           GParamSpec * pspec)
{
	SerializableGeeTreeMapTestBigBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BIG_BAG, SerializableGeeTreeMapTestBigBag);
#line 88 "SerializableGeeTreeMapTest.vala"
	switch (property_id) {
#line 88 "SerializableGeeTreeMapTest.vala"
		case SERIALIZABLE_GEE_TREE_MAP_TEST_BIG_BAG_NAME_PROPERTY:
#line 88 "SerializableGeeTreeMapTest.vala"
		g_value_set_string (value, serializable_gee_tree_map_test_big_bag_get_name (self));
#line 88 "SerializableGeeTreeMapTest.vala"
		break;
#line 88 "SerializableGeeTreeMapTest.vala"
		case SERIALIZABLE_GEE_TREE_MAP_TEST_BIG_BAG_BAGS_PROPERTY:
#line 88 "SerializableGeeTreeMapTest.vala"
		g_value_set_object (value, serializable_gee_tree_map_test_big_bag_get_bags (self));
#line 88 "SerializableGeeTreeMapTest.vala"
		break;
#line 7051 "SerializableGeeTreeMapTest.c"
		default:
#line 88 "SerializableGeeTreeMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 88 "SerializableGeeTreeMapTest.vala"
		break;
#line 7057 "SerializableGeeTreeMapTest.c"
	}
}

static void
_vala_serializable_gee_tree_map_test_big_bag_set_property (GObject * object,
                                                           guint property_id,
                                                           const GValue * value,
                                                           GParamSpec * pspec)
{
	SerializableGeeTreeMapTestBigBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_TREE_MAP_TEST_TYPE_BIG_BAG, SerializableGeeTreeMapTestBigBag);
#line 88 "SerializableGeeTreeMapTest.vala"
	switch (property_id) {
#line 88 "SerializableGeeTreeMapTest.vala"
		case SERIALIZABLE_GEE_TREE_MAP_TEST_BIG_BAG_NAME_PROPERTY:
#line 88 "SerializableGeeTreeMapTest.vala"
		serializable_gee_tree_map_test_big_bag_set_name (self, g_value_get_string (value));
#line 88 "SerializableGeeTreeMapTest.vala"
		break;
#line 88 "SerializableGeeTreeMapTest.vala"
		case SERIALIZABLE_GEE_TREE_MAP_TEST_BIG_BAG_BAGS_PROPERTY:
#line 88 "SerializableGeeTreeMapTest.vala"
		serializable_gee_tree_map_test_big_bag_set_bags (self, g_value_get_object (value));
#line 88 "SerializableGeeTreeMapTest.vala"
		break;
#line 7083 "SerializableGeeTreeMapTest.c"
		default:
#line 88 "SerializableGeeTreeMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 88 "SerializableGeeTreeMapTest.vala"
		break;
#line 7089 "SerializableGeeTreeMapTest.c"
	}
}

static void
serializable_gee_tree_map_test_class_init (SerializableGeeTreeMapTestClass * klass,
                                           gpointer klass_data)
{
#line 29 "SerializableGeeTreeMapTest.vala"
	serializable_gee_tree_map_test_parent_class = g_type_class_peek_parent (klass);
#line 7099 "SerializableGeeTreeMapTest.c"
}

static void
serializable_gee_tree_map_test_instance_init (SerializableGeeTreeMapTest * self,
                                              gpointer klass)
{
}

/**
 *
 *  GXml.Serializable.BasicTypeTest
 *
 *  Authors:
 *
 *       Daniel Espinosa <esodan@gmail.com>
 *
 *
 *  Copyright (c) 2013-2015 Daniel Espinosa
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
GType
serializable_gee_tree_map_test_get_type (void)
{
	static volatile gsize serializable_gee_tree_map_test_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_tree_map_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeTreeMapTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_tree_map_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeTreeMapTest), 0, (GInstanceInitFunc) serializable_gee_tree_map_test_instance_init, NULL };
		GType serializable_gee_tree_map_test_type_id;
		serializable_gee_tree_map_test_type_id = g_type_register_static (TYPE_GXML_TEST, "SerializableGeeTreeMapTest", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_tree_map_test_type_id__volatile, serializable_gee_tree_map_test_type_id);
	}
	return serializable_gee_tree_map_test_type_id__volatile;
}

