/* GomElement.c generated by valac 0.44.3, the Vala compiler
 * generated from GomElement.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */
/*
 *
 * Copyright (C) 2016  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gee.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>

#define GXML_TYPE_DOM_EVENT_TARGET (gxml_dom_event_target_get_type ())
#define GXML_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTarget))
#define GXML_IS_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_TARGET))
#define GXML_DOM_EVENT_TARGET_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTargetIface))

typedef struct _GXmlDomEventTarget GXmlDomEventTarget;
typedef struct _GXmlDomEventTargetIface GXmlDomEventTargetIface;

#define GXML_TYPE_DOM_EVENT_LISTENER (gxml_dom_event_listener_get_type ())
#define GXML_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListener))
#define GXML_IS_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_LISTENER))
#define GXML_DOM_EVENT_LISTENER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListenerIface))

typedef struct _GXmlDomEventListener GXmlDomEventListener;
typedef struct _GXmlDomEventListenerIface GXmlDomEventListenerIface;

#define GXML_TYPE_DOM_EVENT (gxml_dom_event_get_type ())
#define GXML_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEvent))
#define GXML_IS_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT))
#define GXML_DOM_EVENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEventIface))

typedef struct _GXmlDomEvent GXmlDomEvent;
typedef struct _GXmlDomEventIface GXmlDomEventIface;

#define GXML_TYPE_DOM_TIME_STAMP (gxml_dom_time_stamp_get_type ())
#define GXML_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStamp))
#define GXML_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))
#define GXML_IS_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_IS_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_DOM_TIME_STAMP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))

typedef struct _GXmlDomTimeStamp GXmlDomTimeStamp;
typedef struct _GXmlDomTimeStampClass GXmlDomTimeStampClass;
typedef enum  {
	GXML_DOM_EVENT_PHASE_NONE = 0,
	GXML_DOM_EVENT_PHASE_CAPTURING_PHASE,
	GXML_DOM_EVENT_PHASE_AT_TARGET,
	GXML_DOM_EVENT_PHASE_BUBBLING_PHASE
} GXmlDomEventPhase;

#define GXML_DOM_EVENT_TYPE_PHASE (gxml_dom_event_phase_get_type ())

#define GXML_TYPE_DOM_NODE (gxml_dom_node_get_type ())
#define GXML_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE, GXmlDomNode))
#define GXML_IS_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE))
#define GXML_DOM_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE, GXmlDomNodeIface))

typedef struct _GXmlDomNode GXmlDomNode;
typedef struct _GXmlDomNodeIface GXmlDomNodeIface;
typedef enum  {
	GXML_DOM_NODE_DOCUMENT_POSITION_NONE = 1 << 0,
	GXML_DOM_NODE_DOCUMENT_POSITION_DISCONNECTED = 1 << 1,
	GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING = 1 << 2,
	GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING = 1 << 3,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINS = 1 << 4,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINED_BY = 1 << 5,
	GXML_DOM_NODE_DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC = 1 << 6
} GXmlDomNodeDocumentPosition;

#define GXML_DOM_NODE_TYPE_DOCUMENT_POSITION (gxml_dom_node_document_position_get_type ())
typedef enum  {
	GXML_DOM_NODE_NODE_TYPE_INVALID = 0,
	GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE = 1,
	GXML_DOM_NODE_NODE_TYPE_ATTRIBUTE_NODE,
	GXML_DOM_NODE_NODE_TYPE_TEXT_NODE,
	GXML_DOM_NODE_NODE_TYPE_CDATA_SECTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_REFERENCE_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_NODE,
	GXML_DOM_NODE_NODE_TYPE_PROCESSING_INSTRUCTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_COMMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_FRAGMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_NOTATION_NODE
} GXmlDomNodeNodeType;

#define GXML_DOM_NODE_TYPE_NODE_TYPE (gxml_dom_node_node_type_get_type ())

#define GXML_TYPE_DOM_DOCUMENT (gxml_dom_document_get_type ())
#define GXML_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocument))
#define GXML_IS_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT))
#define GXML_DOM_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocumentIface))

typedef struct _GXmlDomDocument GXmlDomDocument;
typedef struct _GXmlDomDocumentIface GXmlDomDocumentIface;

#define GXML_TYPE_DOM_PARENT_NODE (gxml_dom_parent_node_get_type ())
#define GXML_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNode))
#define GXML_IS_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PARENT_NODE))
#define GXML_DOM_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNodeIface))

typedef struct _GXmlDomParentNode GXmlDomParentNode;
typedef struct _GXmlDomParentNodeIface GXmlDomParentNodeIface;

#define GXML_TYPE_DOM_ELEMENT (gxml_dom_element_get_type ())
#define GXML_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElement))
#define GXML_IS_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT))
#define GXML_DOM_ELEMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElementIface))

typedef struct _GXmlDomElement GXmlDomElement;
typedef struct _GXmlDomElementIface GXmlDomElementIface;

#define GXML_TYPE_DOM_CHILD_NODE (gxml_dom_child_node_get_type ())
#define GXML_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNode))
#define GXML_IS_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHILD_NODE))
#define GXML_DOM_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNodeIface))

typedef struct _GXmlDomChildNode GXmlDomChildNode;
typedef struct _GXmlDomChildNodeIface GXmlDomChildNodeIface;

#define GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE (gxml_dom_non_document_type_child_node_get_type ())
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNode))
#define GXML_IS_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE))
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNodeIface))

typedef struct _GXmlDomNonDocumentTypeChildNode GXmlDomNonDocumentTypeChildNode;
typedef struct _GXmlDomNonDocumentTypeChildNodeIface GXmlDomNonDocumentTypeChildNodeIface;

#define GXML_TYPE_DOM_HTML_COLLECTION (gxml_dom_html_collection_get_type ())
#define GXML_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollection))
#define GXML_IS_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_HTML_COLLECTION))
#define GXML_DOM_HTML_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollectionIface))

typedef struct _GXmlDomHTMLCollection GXmlDomHTMLCollection;
typedef struct _GXmlDomHTMLCollectionIface GXmlDomHTMLCollectionIface;

#define GXML_TYPE_DOM_TOKEN_LIST (gxml_dom_token_list_get_type ())
#define GXML_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenList))
#define GXML_IS_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TOKEN_LIST))
#define GXML_DOM_TOKEN_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenListIface))

typedef struct _GXmlDomTokenList GXmlDomTokenList;
typedef struct _GXmlDomTokenListIface GXmlDomTokenListIface;

#define GXML_TYPE_DOM_NAMED_NODE_MAP (gxml_dom_named_node_map_get_type ())
#define GXML_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMap))
#define GXML_IS_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP))
#define GXML_DOM_NAMED_NODE_MAP_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMapIface))

typedef struct _GXmlDomNamedNodeMap GXmlDomNamedNodeMap;
typedef struct _GXmlDomNamedNodeMapIface GXmlDomNamedNodeMapIface;

#define GXML_TYPE_DOM_NODE_LIST (gxml_dom_node_list_get_type ())
#define GXML_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeList))
#define GXML_IS_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_LIST))
#define GXML_DOM_NODE_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeListIface))

typedef struct _GXmlDomNodeList GXmlDomNodeList;
typedef struct _GXmlDomNodeListIface GXmlDomNodeListIface;

#define GXML_TYPE_DOM_ELEMENT_LIST (gxml_dom_element_list_get_type ())
#define GXML_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementList))
#define GXML_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))
#define GXML_IS_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_IS_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_DOM_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))

typedef struct _GXmlDomElementList GXmlDomElementList;
typedef struct _GXmlDomElementListClass GXmlDomElementListClass;

#define GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE (gxml_dom_non_element_parent_node_get_type ())
#define GXML_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNode))
#define GXML_IS_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE))
#define GXML_DOM_NON_ELEMENT_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNodeIface))

typedef struct _GXmlDomNonElementParentNode GXmlDomNonElementParentNode;
typedef struct _GXmlDomNonElementParentNodeIface GXmlDomNonElementParentNodeIface;

#define GXML_TYPE_DOM_DOCUMENT_FRAGMENT (gxml_dom_document_fragment_get_type ())
#define GXML_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragment))
#define GXML_IS_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT))
#define GXML_DOM_DOCUMENT_FRAGMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragmentIface))

typedef struct _GXmlDomDocumentFragment GXmlDomDocumentFragment;
typedef struct _GXmlDomDocumentFragmentIface GXmlDomDocumentFragmentIface;

#define GXML_TYPE_DOM_TEXT (gxml_dom_text_get_type ())
#define GXML_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TEXT, GXmlDomText))
#define GXML_IS_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TEXT))
#define GXML_DOM_TEXT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TEXT, GXmlDomTextIface))

typedef struct _GXmlDomText GXmlDomText;
typedef struct _GXmlDomTextIface GXmlDomTextIface;

#define GXML_TYPE_DOM_CHARACTER_DATA (gxml_dom_character_data_get_type ())
#define GXML_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterData))
#define GXML_IS_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHARACTER_DATA))
#define GXML_DOM_CHARACTER_DATA_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterDataIface))

typedef struct _GXmlDomCharacterData GXmlDomCharacterData;
typedef struct _GXmlDomCharacterDataIface GXmlDomCharacterDataIface;

#define GXML_TYPE_DOM_COMMENT (gxml_dom_comment_get_type ())
#define GXML_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomComment))
#define GXML_IS_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_COMMENT))
#define GXML_DOM_COMMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomCommentIface))

typedef struct _GXmlDomComment GXmlDomComment;
typedef struct _GXmlDomCommentIface GXmlDomCommentIface;

#define GXML_TYPE_DOM_PROCESSING_INSTRUCTION (gxml_dom_processing_instruction_get_type ())
#define GXML_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstruction))
#define GXML_IS_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION))
#define GXML_DOM_PROCESSING_INSTRUCTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstructionIface))

typedef struct _GXmlDomProcessingInstruction GXmlDomProcessingInstruction;
typedef struct _GXmlDomProcessingInstructionIface GXmlDomProcessingInstructionIface;

#define GXML_TYPE_DOM_RANGE (gxml_dom_range_get_type ())
#define GXML_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRange))
#define GXML_IS_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_RANGE))
#define GXML_DOM_RANGE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRangeIface))

typedef struct _GXmlDomRange GXmlDomRange;
typedef struct _GXmlDomRangeIface GXmlDomRangeIface;
typedef enum  {
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_START = 0,
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_START
} GXmlDomRangeBoundaryPoints;

#define GXML_DOM_RANGE_TYPE_BOUNDARY_POINTS (gxml_dom_range_boundary_points_get_type ())

#define GXML_TYPE_DOM_NODE_FILTER (gxml_dom_node_filter_get_type ())
#define GXML_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilter))
#define GXML_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))
#define GXML_IS_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_IS_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_DOM_NODE_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))

typedef struct _GXmlDomNodeFilter GXmlDomNodeFilter;
typedef struct _GXmlDomNodeFilterClass GXmlDomNodeFilterClass;

#define GXML_TYPE_DOM_NODE_ITERATOR (gxml_dom_node_iterator_get_type ())
#define GXML_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIterator))
#define GXML_IS_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_ITERATOR))
#define GXML_DOM_NODE_ITERATOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIteratorIface))

typedef struct _GXmlDomNodeIterator GXmlDomNodeIterator;
typedef struct _GXmlDomNodeIteratorIface GXmlDomNodeIteratorIface;

#define GXML_TYPE_DOM_TREE_WALKER (gxml_dom_tree_walker_get_type ())
#define GXML_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalker))
#define GXML_IS_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TREE_WALKER))
#define GXML_DOM_TREE_WALKER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalkerIface))

typedef struct _GXmlDomTreeWalker GXmlDomTreeWalker;
typedef struct _GXmlDomTreeWalkerIface GXmlDomTreeWalkerIface;

#define GXML_TYPE_PARSER (gxml_parser_get_type ())
#define GXML_PARSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_PARSER, GXmlParser))
#define GXML_IS_PARSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_PARSER))
#define GXML_PARSER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_PARSER, GXmlParserIface))

typedef struct _GXmlParser GXmlParser;
typedef struct _GXmlParserIface GXmlParserIface;

#define GXML_TYPE_DOM_IMPLEMENTATION (gxml_dom_implementation_get_type ())
#define GXML_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementation))
#define GXML_IS_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_IMPLEMENTATION))
#define GXML_DOM_IMPLEMENTATION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementationIface))

typedef struct _GXmlDomImplementation GXmlDomImplementation;
typedef struct _GXmlDomImplementationIface GXmlDomImplementationIface;

#define GXML_TYPE_DOM_DOCUMENT_TYPE (gxml_dom_document_type_get_type ())
#define GXML_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentType))
#define GXML_IS_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE))
#define GXML_DOM_DOCUMENT_TYPE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentTypeIface))

typedef struct _GXmlDomDocumentType GXmlDomDocumentType;
typedef struct _GXmlDomDocumentTypeIface GXmlDomDocumentTypeIface;

#define GXML_TYPE_DOM_XML_DOCUMENT (gxml_dom_xml_document_get_type ())
#define GXML_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocument))
#define GXML_IS_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_XML_DOCUMENT))
#define GXML_DOM_XML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocumentIface))

typedef struct _GXmlDomXMLDocument GXmlDomXMLDocument;
typedef struct _GXmlDomXMLDocumentIface GXmlDomXMLDocumentIface;

#define GXML_TYPE_DOCUMENT (gxml_document_get_type ())
#define GXML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOCUMENT, GXmlDocument))
#define GXML_IS_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOCUMENT))
#define GXML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOCUMENT, GXmlDocumentIface))

typedef struct _GXmlDocument GXmlDocument;
typedef struct _GXmlDocumentIface GXmlDocumentIface;

#define GXML_TYPE_NODE (gxml_node_get_type ())
#define GXML_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NODE, GXmlNode))
#define GXML_IS_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NODE))
#define GXML_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NODE, GXmlNodeIface))

typedef struct _GXmlNode GXmlNode;
typedef struct _GXmlNodeIface GXmlNodeIface;

#define GXML_TYPE_ELEMENT_LIST (gxml_element_list_get_type ())
#define GXML_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementList))
#define GXML_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))
#define GXML_IS_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_ELEMENT_LIST))
#define GXML_IS_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_ELEMENT_LIST))
#define GXML_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))

typedef struct _GXmlElementList GXmlElementList;
typedef struct _GXmlElementListClass GXmlElementListClass;

#define GXML_TYPE_NAMESPACE (gxml_namespace_get_type ())
#define GXML_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NAMESPACE, GXmlNamespace))
#define GXML_IS_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NAMESPACE))
#define GXML_NAMESPACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NAMESPACE, GXmlNamespaceIface))

typedef struct _GXmlNamespace GXmlNamespace;
typedef struct _GXmlNamespaceIface GXmlNamespaceIface;
typedef enum  {
	GXML_NODE_TYPE_INVALID = 0,
	GXML_NODE_TYPE_ELEMENT = 1,
	GXML_NODE_TYPE_ATTRIBUTE,
	GXML_NODE_TYPE_TEXT,
	GXML_NODE_TYPE_CDATA_SECTION,
	GXML_NODE_TYPE_ENTITY_REFERENCE,
	GXML_NODE_TYPE_ENTITY,
	GXML_NODE_TYPE_PROCESSING_INSTRUCTION,
	GXML_NODE_TYPE_COMMENT,
	GXML_NODE_TYPE_DOCUMENT,
	GXML_NODE_TYPE_DOCUMENT_TYPE,
	GXML_NODE_TYPE_DOCUMENT_FRAGMENT,
	GXML_NODE_TYPE_NOTATION
} GXmlNodeType;

#define GXML_TYPE_NODE_TYPE (gxml_node_type_get_type ())

#define GXML_TYPE_GOM_NODE (gxml_gom_node_get_type ())
#define GXML_GOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_NODE, GXmlGomNode))
#define GXML_GOM_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_NODE, GXmlGomNodeClass))
#define GXML_IS_GOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_NODE))
#define GXML_IS_GOM_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_NODE))
#define GXML_GOM_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_NODE, GXmlGomNodeClass))

typedef struct _GXmlGomNode GXmlGomNode;
typedef struct _GXmlGomNodeClass GXmlGomNodeClass;
typedef struct _GXmlGomNodePrivate GXmlGomNodePrivate;

#define GXML_TYPE_GOM_NODE_LIST (gxml_gom_node_list_get_type ())
#define GXML_GOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_NODE_LIST, GXmlGomNodeList))
#define GXML_GOM_NODE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_NODE_LIST, GXmlGomNodeListClass))
#define GXML_IS_GOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_NODE_LIST))
#define GXML_IS_GOM_NODE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_NODE_LIST))
#define GXML_GOM_NODE_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_NODE_LIST, GXmlGomNodeListClass))

typedef struct _GXmlGomNodeList GXmlGomNodeList;
typedef struct _GXmlGomNodeListClass GXmlGomNodeListClass;

#define GXML_TYPE_GOM_OBJECT (gxml_gom_object_get_type ())
#define GXML_GOM_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_OBJECT, GXmlGomObject))
#define GXML_IS_GOM_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_OBJECT))
#define GXML_GOM_OBJECT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_GOM_OBJECT, GXmlGomObjectIface))

typedef struct _GXmlGomObject GXmlGomObject;
typedef struct _GXmlGomObjectIface GXmlGomObjectIface;

#define GXML_TYPE_GOM_PROPERTY (gxml_gom_property_get_type ())
#define GXML_GOM_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_PROPERTY, GXmlGomProperty))
#define GXML_IS_GOM_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_PROPERTY))
#define GXML_GOM_PROPERTY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_GOM_PROPERTY, GXmlGomPropertyIface))

typedef struct _GXmlGomProperty GXmlGomProperty;
typedef struct _GXmlGomPropertyIface GXmlGomPropertyIface;

#define GXML_TYPE_GOM_ELEMENT (gxml_gom_element_get_type ())
#define GXML_GOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_ELEMENT, GXmlGomElement))
#define GXML_GOM_ELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_ELEMENT, GXmlGomElementClass))
#define GXML_IS_GOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_ELEMENT))
#define GXML_IS_GOM_ELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_ELEMENT))
#define GXML_GOM_ELEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_ELEMENT, GXmlGomElementClass))

typedef struct _GXmlGomElement GXmlGomElement;
typedef struct _GXmlGomElementClass GXmlGomElementClass;
typedef struct _GXmlGomElementPrivate GXmlGomElementPrivate;

#define GXML_GOM_ELEMENT_TYPE_ATTRIBUTES (gxml_gom_element_attributes_get_type ())
#define GXML_GOM_ELEMENT_ATTRIBUTES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_GOM_ELEMENT_TYPE_ATTRIBUTES, GXmlGomElementAttributes))
#define GXML_GOM_ELEMENT_ATTRIBUTES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_GOM_ELEMENT_TYPE_ATTRIBUTES, GXmlGomElementAttributesClass))
#define GXML_GOM_ELEMENT_IS_ATTRIBUTES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_GOM_ELEMENT_TYPE_ATTRIBUTES))
#define GXML_GOM_ELEMENT_IS_ATTRIBUTES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_GOM_ELEMENT_TYPE_ATTRIBUTES))
#define GXML_GOM_ELEMENT_ATTRIBUTES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_GOM_ELEMENT_TYPE_ATTRIBUTES, GXmlGomElementAttributesClass))

typedef struct _GXmlGomElementAttributes GXmlGomElementAttributes;
typedef struct _GXmlGomElementAttributesClass GXmlGomElementAttributesClass;
enum  {
	GXML_GOM_ELEMENT_0_PROPERTY,
	GXML_GOM_ELEMENT_PREVIOUS_ELEMENT_SIBLING_PROPERTY,
	GXML_GOM_ELEMENT_NEXT_ELEMENT_SIBLING_PROPERTY,
	GXML_GOM_ELEMENT_CHILDREN_PROPERTY,
	GXML_GOM_ELEMENT_FIRST_ELEMENT_CHILD_PROPERTY,
	GXML_GOM_ELEMENT_LAST_ELEMENT_CHILD_PROPERTY,
	GXML_GOM_ELEMENT_CHILD_ELEMENT_COUNT_PROPERTY,
	GXML_GOM_ELEMENT_NAMESPACE_URI_PROPERTY,
	GXML_GOM_ELEMENT_PREFIX_PROPERTY,
	GXML_GOM_ELEMENT_LOCAL_NAME_PROPERTY,
	GXML_GOM_ELEMENT_TAG_NAME_PROPERTY,
	GXML_GOM_ELEMENT_ID_PROPERTY,
	GXML_GOM_ELEMENT_CLASS_NAME_PROPERTY,
	GXML_GOM_ELEMENT_CLASS_LIST_PROPERTY,
	GXML_GOM_ELEMENT_ATTRIBUTES_PROPERTY,
	GXML_GOM_ELEMENT_PARSE_CHILDREN_PROPERTY,
	GXML_GOM_ELEMENT_UNPARSED_PROPERTY,
	GXML_GOM_ELEMENT_NUM_PROPERTIES
};
static GParamSpec* gxml_gom_element_properties[GXML_GOM_ELEMENT_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define GXML_TYPE_XPARSER (gxml_xparser_get_type ())
#define GXML_XPARSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_XPARSER, GXmlXParser))
#define GXML_XPARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_XPARSER, GXmlXParserClass))
#define GXML_IS_XPARSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_XPARSER))
#define GXML_IS_XPARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_XPARSER))
#define GXML_XPARSER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_XPARSER, GXmlXParserClass))

typedef struct _GXmlXParser GXmlXParser;
typedef struct _GXmlXParserClass GXmlXParserClass;
typedef struct _GxmlGomElementReadFromFileAsyncData GxmlGomElementReadFromFileAsyncData;
typedef struct _GxmlGomElementReadFromStreamAsyncData GxmlGomElementReadFromStreamAsyncData;
typedef struct _GxmlGomElementReadFromStringAsyncData GxmlGomElementReadFromStringAsyncData;
typedef struct _GxmlGomElementWriteStringAsyncData GxmlGomElementWriteStringAsyncData;

#define GXML_TYPE_GOM_DOCUMENT (gxml_gom_document_get_type ())
#define GXML_GOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_DOCUMENT, GXmlGomDocument))
#define GXML_GOM_DOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_DOCUMENT, GXmlGomDocumentClass))
#define GXML_IS_GOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_DOCUMENT))
#define GXML_IS_GOM_DOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_DOCUMENT))
#define GXML_GOM_DOCUMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_DOCUMENT, GXmlGomDocumentClass))

typedef struct _GXmlGomDocument GXmlGomDocument;
typedef struct _GXmlGomDocumentClass GXmlGomDocumentClass;
typedef struct _GxmlGomElementWriteFileAsyncData GxmlGomElementWriteFileAsyncData;
typedef struct _GxmlGomElementWriteStreamAsyncData GxmlGomElementWriteStreamAsyncData;
typedef struct _GxmlGomElementCreateStreamAsyncData GxmlGomElementCreateStreamAsyncData;

#define GXML_TYPE_DOM_ATTR (gxml_dom_attr_get_type ())
#define GXML_DOM_ATTR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ATTR, GXmlDomAttr))
#define GXML_IS_DOM_ATTR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ATTR))
#define GXML_DOM_ATTR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_ATTR, GXmlDomAttrIface))

typedef struct _GXmlDomAttr GXmlDomAttr;
typedef struct _GXmlDomAttrIface GXmlDomAttrIface;

#define GXML_TYPE_CSS_SELECTOR_PARSER (gxml_css_selector_parser_get_type ())
#define GXML_CSS_SELECTOR_PARSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_CSS_SELECTOR_PARSER, GXmlCssSelectorParser))
#define GXML_CSS_SELECTOR_PARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_CSS_SELECTOR_PARSER, GXmlCssSelectorParserClass))
#define GXML_IS_CSS_SELECTOR_PARSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_CSS_SELECTOR_PARSER))
#define GXML_IS_CSS_SELECTOR_PARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_CSS_SELECTOR_PARSER))
#define GXML_CSS_SELECTOR_PARSER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_CSS_SELECTOR_PARSER, GXmlCssSelectorParserClass))

typedef struct _GXmlCssSelectorParser GXmlCssSelectorParser;
typedef struct _GXmlCssSelectorParserClass GXmlCssSelectorParserClass;

#define GXML_TYPE_GOM_ATTR (gxml_gom_attr_get_type ())
#define GXML_GOM_ATTR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_ATTR, GXmlGomAttr))
#define GXML_GOM_ATTR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_ATTR, GXmlGomAttrClass))
#define GXML_IS_GOM_ATTR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_ATTR))
#define GXML_IS_GOM_ATTR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_ATTR))
#define GXML_GOM_ATTR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_ATTR, GXmlGomAttrClass))

typedef struct _GXmlGomAttr GXmlGomAttr;
typedef struct _GXmlGomAttrClass GXmlGomAttrClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define GXML_TYPE_GDOM_HTML_COLLECTION (gxml_gdom_html_collection_get_type ())
#define GXML_GDOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOM_HTML_COLLECTION, GXmlGDomHTMLCollection))
#define GXML_GDOM_HTML_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOM_HTML_COLLECTION, GXmlGDomHTMLCollectionClass))
#define GXML_IS_GDOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOM_HTML_COLLECTION))
#define GXML_IS_GDOM_HTML_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOM_HTML_COLLECTION))
#define GXML_GDOM_HTML_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOM_HTML_COLLECTION, GXmlGDomHTMLCollectionClass))

typedef struct _GXmlGDomHTMLCollection GXmlGDomHTMLCollection;
typedef struct _GXmlGDomHTMLCollectionClass GXmlGDomHTMLCollectionClass;

#define GXML_TYPE_GDOM_TOKEN_LIST (gxml_gdom_token_list_get_type ())
#define GXML_GDOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOM_TOKEN_LIST, GXmlGDomTokenList))
#define GXML_GDOM_TOKEN_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOM_TOKEN_LIST, GXmlGDomTokenListClass))
#define GXML_IS_GDOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOM_TOKEN_LIST))
#define GXML_IS_GDOM_TOKEN_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOM_TOKEN_LIST))
#define GXML_GDOM_TOKEN_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOM_TOKEN_LIST, GXmlGDomTokenListClass))

typedef struct _GXmlGDomTokenList GXmlGDomTokenList;
typedef struct _GXmlGDomTokenListClass GXmlGDomTokenListClass;
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))

#define GXML_TYPE_GOM_STRING_REF (gxml_gom_string_ref_get_type ())
#define GXML_GOM_STRING_REF(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_STRING_REF, GXmlGomStringRef))
#define GXML_GOM_STRING_REF_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_STRING_REF, GXmlGomStringRefClass))
#define GXML_IS_GOM_STRING_REF(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_STRING_REF))
#define GXML_IS_GOM_STRING_REF_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_STRING_REF))
#define GXML_GOM_STRING_REF_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_STRING_REF, GXmlGomStringRefClass))

typedef struct _GXmlGomStringRef GXmlGomStringRef;
typedef struct _GXmlGomStringRefClass GXmlGomStringRefClass;
typedef struct _GXmlGomElementAttributesPrivate GXmlGomElementAttributesPrivate;
enum  {
	GXML_GOM_ELEMENT_ATTRIBUTES_0_PROPERTY,
	GXML_GOM_ELEMENT_ATTRIBUTES_LENGTH_PROPERTY,
	GXML_GOM_ELEMENT_ATTRIBUTES_NUM_PROPERTIES
};
static GParamSpec* gxml_gom_element_attributes_properties[GXML_GOM_ELEMENT_ATTRIBUTES_NUM_PROPERTIES];
#define _g_param_spec_unref0(var) ((var == NULL) ? NULL : (var = (g_param_spec_unref (var), NULL)))

struct _GXmlDomEventIface {
	GTypeInterface parent_iface;
	void (*stop_propagation) (GXmlDomEvent* self);
	void (*stop_immediate_propagation) (GXmlDomEvent* self);
	void (*prevent_default) (GXmlDomEvent* self);
	void (*init_event) (GXmlDomEvent* self, const gchar* type, gboolean bubbles, gboolean cancelable);
	const gchar* (*get_etype) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_event_target) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_current_target) (GXmlDomEvent* self);
	gboolean (*get_bubbles) (GXmlDomEvent* self);
	gboolean (*get_cancelable) (GXmlDomEvent* self);
	gboolean (*get_is_trusted) (GXmlDomEvent* self);
	GXmlDomTimeStamp* (*get_time_stamp) (GXmlDomEvent* self);
	gboolean (*get_default_prevented) (GXmlDomEvent* self);
	GXmlDomEventPhase (*get_event_phase) (GXmlDomEvent* self);
};

struct _GXmlDomEventListenerIface {
	GTypeInterface parent_iface;
	void (*handle_event) (GXmlDomEventListener* self, GXmlDomEvent* event);
};

struct _GXmlDomEventTargetIface {
	GTypeInterface parent_iface;
	void (*add_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	void (*remove_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	gboolean (*dispatch_event) (GXmlDomEventTarget* self, GXmlDomEvent* event, GError** error);
};

struct _GXmlDomChildNodeIface {
	GTypeInterface parent_iface;
	void (*remove) (GXmlDomChildNode* self);
};

struct _GXmlDomNonDocumentTypeChildNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_previous_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
	GXmlDomElement* (*get_next_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
};

struct _GXmlDomHTMLCollectionIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement** (*to_array) (GXmlDomHTMLCollection* self, gint* result_length1);
	GXmlDomElement* (*item) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement* (*named_item) (GXmlDomHTMLCollection* self, const gchar* name);
	gint (*get_length) (GXmlDomHTMLCollection* self);
};

struct _GXmlDomTokenListIface {
	GTypeInterface parent_iface;
	gchar* (*item) (GXmlDomTokenList* self, gint index);
	gboolean (*contains) (GXmlDomTokenList* self, const gchar* token, GError** error);
	void (*add) (GXmlDomTokenList* self, gchar** tokens, gint tokens_length1, GError** error);
	void (*remove) (GXmlDomTokenList* self, gchar** tokens, gint tokens_length1);
	gboolean (*toggle) (GXmlDomTokenList* self, const gchar* token, gboolean force, gboolean _auto_, GError** error);
	gchar* (*to_string) (GXmlDomTokenList* self);
	gint (*get_length) (GXmlDomTokenList* self);
};

struct _GXmlDomNamedNodeMapIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNamedNodeMap* self, gint index);
	GXmlDomNode* (*get_named_item) (GXmlDomNamedNodeMap* self, const gchar* name);
	GXmlDomNode* (*set_named_item) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*remove_named_item) (GXmlDomNamedNodeMap* self, const gchar* name, GError** error);
	GXmlDomNode* (*remove_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* localName, GError** error);
	GXmlDomNode* (*get_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* local_name, GError** error);
	GXmlDomNode* (*set_named_item_ns) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	gint (*get_length) (GXmlDomNamedNodeMap* self);
};

struct _GXmlDomElementIface {
	GTypeInterface parent_iface;
	gchar* (*get_attribute) (GXmlDomElement* self, const gchar* name);
	gchar* (*get_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	void (*set_attribute) (GXmlDomElement* self, const gchar* name, const gchar* value, GError** error);
	void (*set_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* name, const gchar* value, GError** error);
	void (*remove_attribute) (GXmlDomElement* self, const gchar* name);
	void (*remove_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	gboolean (*has_attribute) (GXmlDomElement* self, const gchar* name);
	gboolean (*has_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomElement* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomElement* self, const gchar* class_names);
	gboolean (*matches) (GXmlDomElement* self, const gchar* selectors, GError** error);
	void (*read_from_uri) (GXmlDomElement* self, const gchar* uri, GError** error);
	void (*read_from_uri_async) (GXmlDomElement* self, const gchar* uri, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_uri_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*read_from_file) (GXmlDomElement* self, GFile* f, GCancellable* cancellable, GError** error);
	void (*read_from_file_async) (GXmlDomElement* self, GFile* f, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_file_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*read_from_stream) (GXmlDomElement* self, GInputStream* istream, GCancellable* cancellable, GError** error);
	void (*read_from_stream_async) (GXmlDomElement* self, GInputStream* istream, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_stream_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*read_from_string) (GXmlDomElement* self, const gchar* str, GCancellable* cancellable, GError** error);
	void (*read_from_string_async) (GXmlDomElement* self, const gchar* str, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_string_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	gchar* (*write_string) (GXmlDomElement* self, GCancellable* cancellable, GError** error);
	void (*write_string_async) (GXmlDomElement* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gchar* (*write_string_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*write_file) (GXmlDomElement* self, GFile* f, GCancellable* cancellable, GError** error);
	void (*write_file_async) (GXmlDomElement* self, GFile* f, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_file_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	void (*write_stream) (GXmlDomElement* self, GOutputStream* stream, GError** error);
	void (*write_stream_async) (GXmlDomElement* self, GOutputStream* stream, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_stream_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	GInputStream* (*create_stream) (GXmlDomElement* self, GError** error);
	void (*create_stream_async) (GXmlDomElement* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GInputStream* (*create_stream_finish) (GXmlDomElement* self, GAsyncResult* _res_, GError** error);
	gchar* (*get_namespace_uri) (GXmlDomElement* self);
	gchar* (*get_prefix) (GXmlDomElement* self);
	gchar* (*get_local_name) (GXmlDomElement* self);
	gchar* (*get_tag_name) (GXmlDomElement* self);
	gchar* (*get_id) (GXmlDomElement* self);
	void (*set_id) (GXmlDomElement* self, const gchar* value);
	gchar* (*get_class_name) (GXmlDomElement* self);
	void (*set_class_name) (GXmlDomElement* self, const gchar* value);
	GXmlDomTokenList* (*get_class_list) (GXmlDomElement* self);
	GXmlDomNamedNodeMap* (*get_attributes) (GXmlDomElement* self);
};

struct _GXmlDomNodeListIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNodeList* self, gint index);
	gint (*get_length) (GXmlDomNodeList* self);
};

struct _GXmlDomParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*query_selector) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomNodeList* (*query_selector_all) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomElementList* (*get_elements_by_property_value) (GXmlDomParentNode* self, const gchar* property, const gchar* value);
	GXmlDomHTMLCollection* (*get_children) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_first_element_child) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_last_element_child) (GXmlDomParentNode* self);
	gint (*get_child_element_count) (GXmlDomParentNode* self);
};

struct _GXmlDomNonElementParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element_by_id) (GXmlDomNonElementParentNode* self, const gchar* element_id, GError** error);
};

struct _GXmlDomDocumentFragmentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomCharacterDataIface {
	GTypeInterface parent_iface;
	gchar* (*substring_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*append_data) (GXmlDomCharacterData* self, const gchar* data);
	void (*insert_data) (GXmlDomCharacterData* self, gint offset, const gchar* data, GError** error);
	void (*delete_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*replace_data) (GXmlDomCharacterData* self, gint offset, gint count, const gchar* data, GError** error);
	gchar* (*get_data) (GXmlDomCharacterData* self);
	void (*set_data) (GXmlDomCharacterData* self, const gchar* value);
	gint (*get_length) (GXmlDomCharacterData* self);
};

struct _GXmlDomTextIface {
	GTypeInterface parent_iface;
	GXmlDomText* (*split_text) (GXmlDomText* self, gint offset, GError** error);
	gchar* (*get_whole_text) (GXmlDomText* self);
};

struct _GXmlDomCommentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomProcessingInstructionIface {
	GTypeInterface parent_iface;
	gchar* (*get_target) (GXmlDomProcessingInstruction* self);
};

struct _GXmlDomRangeIface {
	GTypeInterface parent_iface;
	void (*set_start) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_end) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_start_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_start_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*collapse) (GXmlDomRange* self, gboolean to_start, GError** error);
	void (*select_node) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*select_node_contents) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	gint (*compare_boundary_points) (GXmlDomRange* self, GXmlDomRangeBoundaryPoints how, GXmlDomRange* sourceRange, GError** error);
	void (*delete_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*extract_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*clone_contents) (GXmlDomRange* self, GError** error);
	void (*insert_node) (GXmlDomRange* self, GXmlDomNode* node);
	void (*surround_contents) (GXmlDomRange* self, GXmlDomNode* newParent);
	GXmlDomRange* (*clone_range) (GXmlDomRange* self);
	void (*detach) (GXmlDomRange* self);
	gboolean (*is_point_in_range) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gshort (*compare_point) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gboolean (*intersects_node) (GXmlDomRange* self, GXmlDomNode* node);
	gchar* (*to_string) (GXmlDomRange* self);
	GXmlDomNode* (*get_start_container) (GXmlDomRange* self);
	gint (*get_start_offset) (GXmlDomRange* self);
	GXmlDomNode* (*get_end_container) (GXmlDomRange* self);
	gint (*get_end_offset) (GXmlDomRange* self);
	gboolean (*get_collapsed) (GXmlDomRange* self);
	GXmlDomNode* (*get_common_ancestor_container) (GXmlDomRange* self);
};

struct _GXmlDomNodeIteratorIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*next_node) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*previous_node) (GXmlDomNodeIterator* self);
	void (*detach) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_root) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_reference_node) (GXmlDomNodeIterator* self);
	gboolean (*get_pointer_before_reference_node) (GXmlDomNodeIterator* self);
	gint (*get_what_to_show) (GXmlDomNodeIterator* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomNodeIterator* self);
};

struct _GXmlDomTreeWalkerIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*parent_node) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*first_child) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*last_child) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previous_sibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*next_sibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previous_node) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*next_node) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_root) (GXmlDomTreeWalker* self);
	gint (*get_what_to_show) (GXmlDomTreeWalker* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_current_node) (GXmlDomTreeWalker* self);
};

struct _GXmlParserIface {
	GTypeInterface parent_iface;
	void (*write_file) (GXmlParser* self, GFile* file, GError** error);
	void (*write_file_async) (GXmlParser* self, GFile* file, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_file_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	gchar* (*write_string) (GXmlParser* self, GError** error);
	void (*write_string_async) (GXmlParser* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gchar* (*write_string_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*write_stream) (GXmlParser* self, GOutputStream* stream, GError** error);
	void (*write_stream_async) (GXmlParser* self, GOutputStream* stream, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_stream_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*read_file) (GXmlParser* self, GFile* file, GError** error);
	void (*read_file_async) (GXmlParser* self, GFile* file, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_file_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*read_stream) (GXmlParser* self, GInputStream* stream, GError** error);
	void (*read_stream_async) (GXmlParser* self, GInputStream* stream, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_stream_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*read_string) (GXmlParser* self, const gchar* str, GError** error);
	void (*read_string_async) (GXmlParser* self, const gchar* str, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_string_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	GInputStream* (*create_stream) (GXmlParser* self, GError** error);
	void (*create_stream_async) (GXmlParser* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GInputStream* (*create_stream_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	void (*read_child_nodes) (GXmlParser* self, GXmlDomNode* parent, GError** error);
	void (*read_child_nodes_async) (GXmlParser* self, GXmlDomNode* parent, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_child_nodes_finish) (GXmlParser* self, GAsyncResult* _res_, GError** error);
	gboolean (*read_child_node) (GXmlParser* self, GXmlDomNode* parent, GError** error);
	gboolean (*read_child_element) (GXmlParser* self, GXmlDomNode* parent, GError** error);
	gboolean (*read_element_property) (GXmlParser* self, GXmlDomNode* parent, GXmlDomNode* * element, GError** error);
	gboolean (*add_element_collection) (GXmlParser* self, GXmlDomNode* parent, GXmlDomNode* * element, GError** error);
	void (*read_child_nodes_stream) (GXmlParser* self, GInputStream* istream, GError** error);
	void (*read_child_nodes_string) (GXmlParser* self, const gchar* str, GError** error);
	gchar* (*read_unparsed) (GXmlParser* self, GError** error);
	gboolean (*move_next_node) (GXmlParser* self, GError** error);
	gboolean (*current_is_empty_element) (GXmlParser* self);
	gboolean (*current_is_element) (GXmlParser* self);
	gboolean (*current_is_document) (GXmlParser* self);
	gchar* (*current_node_name) (GXmlParser* self);
	GXmlDomElement* (*create_element) (GXmlParser* self, GXmlDomNode* parent, GError** error);
	void (*read_element) (GXmlParser* self, GXmlDomElement* element, GError** error);
	gboolean (*get_backup) (GXmlParser* self);
	void (*set_backup) (GXmlParser* self, gboolean value);
	gboolean (*get_indent) (GXmlParser* self);
	void (*set_indent) (GXmlParser* self, gboolean value);
	GCancellable* (*get_cancellable) (GXmlParser* self);
	void (*set_cancellable) (GXmlParser* self, GCancellable* value);
	GXmlDomNode* (*get_node) (GXmlParser* self);
};

struct _GXmlDomDocumentTypeIface {
	GTypeInterface parent_iface;
	const gchar* (*get_name) (GXmlDomDocumentType* self);
	const gchar* (*get_public_id) (GXmlDomDocumentType* self);
	const gchar* (*get_system_id) (GXmlDomDocumentType* self);
};

struct _GXmlDomXMLDocumentIface {
	GTypeInterface parent_iface;
};

struct _GXmlNamespaceIface {
	GTypeInterface parent_iface;
	gchar* (*get_uri) (GXmlNamespace* self);
	gchar* (*get_prefix) (GXmlNamespace* self);
};

struct _GXmlNodeIface {
	GTypeInterface parent_iface;
	GXmlNode* (*get) (GXmlNode* self, const gchar* key);
	GXmlElementList* (*get_elements_by_property_value) (GXmlNode* self, const gchar* property, const gchar* value);
	GXmlElementList* (*get_elements_by_name) (GXmlNode* self, const gchar* name);
	GXmlElementList* (*get_elements_by_name_ns) (GXmlNode* self, const gchar* name, const gchar* ns);
	gchar* (*to_string) (GXmlNode* self);
	gboolean (*set_namespace) (GXmlNode* self, const gchar* uri, const gchar* prefix);
	gchar* (*ns_prefix) (GXmlNode* self);
	gchar* (*ns_uri) (GXmlNode* self);
	GeeList* (*get_namespaces) (GXmlNode* self);
	GeeBidirList* (*get_children_nodes) (GXmlNode* self);
	GeeMap* (*get_attrs) (GXmlNode* self);
	gchar* (*get_name) (GXmlNode* self);
	gchar* (*get_value) (GXmlNode* self);
	void (*set_value) (GXmlNode* self, const gchar* value);
	GXmlNodeType (*get_type_node) (GXmlNode* self);
	GXmlDocument* (*get_document) (GXmlNode* self);
	GXmlNode* (*get_parent) (GXmlNode* self);
};

struct _GXmlDocumentIface {
	GTypeInterface parent_iface;
	GXmlNode* (*create_element) (GXmlDocument* self, const gchar* name, GError** error);
	GXmlNode* (*create_text) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_comment) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_cdata) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_pi) (GXmlDocument* self, const gchar* target, const gchar* data);
	gboolean (*save) (GXmlDocument* self, GCancellable* cancellable, GError** error);
	gboolean (*save_as) (GXmlDocument* self, GFile* f, GCancellable* cancellable, GError** error);
	gboolean (*get_indent) (GXmlDocument* self);
	void (*set_indent) (GXmlDocument* self, gboolean value);
	gboolean (*get_ns_top) (GXmlDocument* self);
	void (*set_ns_top) (GXmlDocument* self, gboolean value);
	gboolean (*get_prefix_default_ns) (GXmlDocument* self);
	void (*set_prefix_default_ns) (GXmlDocument* self, gboolean value);
	gboolean (*get_backup) (GXmlDocument* self);
	void (*set_backup) (GXmlDocument* self, gboolean value);
	GXmlNode* (*get_root) (GXmlDocument* self);
	GFile* (*get_file) (GXmlDocument* self);
	void (*set_file) (GXmlDocument* self, GFile* value);
};

struct _GXmlDomImplementationIface {
	GTypeInterface parent_iface;
	GXmlDomDocumentType* (*create_document_type) (GXmlDomImplementation* self, const gchar* qualified_name, const gchar* public_id, const gchar* system_id, GError** error);
	GXmlDomXMLDocument* (*create_document) (GXmlDomImplementation* self, const gchar* nspace, const gchar* qualified_name, GXmlDomDocumentType* doctype, GError** error);
	GXmlDocument* (*create_html_document) (GXmlDomImplementation* self, const gchar* title);
	gboolean (*has_feature) (GXmlDomImplementation* self);
};

struct _GXmlDomDocumentIface {
	GTypeInterface parent_iface;
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomDocument* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomDocument* self, const gchar* classNames);
	GXmlDomElement* (*create_element) (GXmlDomDocument* self, const gchar* local_name, GError** error);
	GXmlDomElement* (*create_element_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* qualified_name, GError** error);
	GXmlDomDocumentFragment* (*create_document_fragment) (GXmlDomDocument* self);
	GXmlDomText* (*create_text_node) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomComment* (*create_comment) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomProcessingInstruction* (*create_processing_instruction) (GXmlDomDocument* self, const gchar* target, const gchar* data, GError** error);
	GXmlDomNode* (*import_node) (GXmlDomDocument* self, GXmlDomNode* node, gboolean deep, GError** error);
	GXmlDomNode* (*adopt_node) (GXmlDomDocument* self, GXmlDomNode* node, GError** error);
	GXmlDomEvent* (*create_event) (GXmlDomDocument* self, const gchar* interface, GError** error);
	GXmlDomRange* (*create_range) (GXmlDomDocument* self);
	GXmlDomNodeIterator* (*create_node_iterator) (GXmlDomDocument* self, GXmlDomNode* root, gint whatToShow, GXmlDomNodeFilter* filter);
	GXmlDomTreeWalker* (*create_tree_walker) (GXmlDomDocument* self, GXmlDomNode* root, gint what_to_show, GXmlDomNodeFilter* filter);
	void (*write_file) (GXmlDomDocument* self, GFile* file, GCancellable* cancellable, GError** error);
	void (*write_file_async) (GXmlDomDocument* self, GFile* file, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_file_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	void (*write_stream) (GXmlDomDocument* self, GOutputStream* stream, GCancellable* cancellable, GError** error);
	void (*write_stream_async) (GXmlDomDocument* self, GOutputStream* stream, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*write_stream_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	GInputStream* (*create_stream) (GXmlDomDocument* self, GError** error);
	void (*create_stream_async) (GXmlDomDocument* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GInputStream* (*create_stream_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	gchar* (*write_string) (GXmlDomDocument* self, GCancellable* cancellable, GError** error);
	void (*write_string_async) (GXmlDomDocument* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gchar* (*write_string_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	void (*read_from_file) (GXmlDomDocument* self, GFile* file, GCancellable* cancellable, GError** error);
	void (*read_from_file_async) (GXmlDomDocument* self, GFile* file, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_file_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	void (*read_from_string) (GXmlDomDocument* self, const gchar* str, GCancellable* cancellable, GError** error);
	void (*read_from_string_async) (GXmlDomDocument* self, const gchar* str, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_string_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	void (*read_from_stream) (GXmlDomDocument* self, GInputStream* stream, GCancellable* cancellable, GError** error);
	void (*read_from_stream_async) (GXmlDomDocument* self, GInputStream* stream, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*read_from_stream_finish) (GXmlDomDocument* self, GAsyncResult* _res_, GError** error);
	GXmlParser* (*get_xml_parser) (GXmlDomDocument* self);
	void (*set_xml_parser) (GXmlDomDocument* self, GXmlParser* parser);
	GXmlDomImplementation* (*get_implementation) (GXmlDomDocument* self);
	const gchar* (*get_url) (GXmlDomDocument* self);
	const gchar* (*get_document_uri) (GXmlDomDocument* self);
	const gchar* (*get_origin) (GXmlDomDocument* self);
	const gchar* (*get_compat_mode) (GXmlDomDocument* self);
	const gchar* (*get_character_set) (GXmlDomDocument* self);
	const gchar* (*get_content_type) (GXmlDomDocument* self);
	GXmlDomDocumentType* (*get_doctype) (GXmlDomDocument* self);
	GXmlDomElement* (*get_document_element) (GXmlDomDocument* self);
};

struct _GXmlDomNodeIface {
	GTypeInterface parent_iface;
	gboolean (*has_child_nodes) (GXmlDomNode* self);
	void (*normalize) (GXmlDomNode* self);
	gboolean (*is_equal_node) (GXmlDomNode* self, GXmlDomNode* node);
	GXmlDomNodeDocumentPosition (*compare_document_position) (GXmlDomNode* self, GXmlDomNode* other);
	gboolean (*contains) (GXmlDomNode* self, GXmlDomNode* other);
	gchar* (*lookup_prefix) (GXmlDomNode* self, const gchar* nspace);
	gchar* (*lookup_namespace_uri) (GXmlDomNode* self, const gchar* prefix);
	gboolean (*is_default_namespace) (GXmlDomNode* self, const gchar* nspace);
	GXmlDomNode* (*insert_before) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*append_child) (GXmlDomNode* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*replace_child) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*remove_child) (GXmlDomNode* self, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*clone_node) (GXmlDomNode* self, gboolean deep, GError** error);
	GXmlDomNodeNodeType (*get_node_type) (GXmlDomNode* self);
	gchar* (*get_node_name) (GXmlDomNode* self);
	const gchar* (*get_base_uri) (GXmlDomNode* self);
	GXmlDomDocument* (*get_owner_document) (GXmlDomNode* self);
	void (*set_owner_document) (GXmlDomNode* self, GXmlDomDocument* value);
	GXmlDomNode* (*get_parent_node) (GXmlDomNode* self);
	GXmlDomElement* (*get_parent_element) (GXmlDomNode* self);
	GXmlDomNodeList* (*get_child_nodes) (GXmlDomNode* self);
	GXmlDomNode* (*get_first_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_last_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_previous_sibling) (GXmlDomNode* self);
	GXmlDomNode* (*get_next_sibling) (GXmlDomNode* self);
	gchar* (*get_node_value) (GXmlDomNode* self);
	void (*set_node_value) (GXmlDomNode* self, const gchar* value);
	gchar* (*get_text_content) (GXmlDomNode* self);
	void (*set_text_content) (GXmlDomNode* self, const gchar* value);
};

struct _GXmlGomNode {
	GObject parent_instance;
	GXmlGomNodePrivate * priv;
	gchar* _local_name;
	gchar* _prefix;
	gchar* _base_uri;
	gchar* _node_value;
	GXmlDomNode* _parent;
	GXmlDomNodeNodeType _node_type;
	GXmlGomNodeList* _child_nodes;
	GXmlDomDocument* _document;
};

struct _GXmlGomNodeClass {
	GObjectClass parent_class;
};

struct _GXmlGomPropertyIface {
	GTypeInterface parent_iface;
	gboolean (*validate_value) (GXmlGomProperty* self, const gchar* val);
	gchar* (*get_value) (GXmlGomProperty* self);
	void (*set_value) (GXmlGomProperty* self, const gchar* value);
};

struct _GXmlGomObjectIface {
	GTypeInterface parent_iface;
	GList* (*get_properties_list) (GXmlGomObject* self);
	GParamSpec* (*find_property_name) (GXmlGomObject* self, const gchar* nick);
	GParamSpec* (*find_object_property_name) (GXmlGomObject* self, const gchar* pname);
	GList* (*get_property_element_list) (GXmlGomObject* self);
	gchar* (*get_property_string) (GXmlGomObject* self, GParamSpec* prop);
	gchar* (*get_attribute) (GXmlGomObject* self, const gchar* name);
	GXmlGomProperty* (*find_property) (GXmlGomObject* self, const gchar* name);
	gboolean (*set_attribute) (GXmlGomObject* self, const gchar* name, const gchar* val);
	GXmlDomElement* (*get_child) (GXmlGomObject* self, const gchar* name);
	GXmlDomElementList* (*find_elements) (GXmlGomObject* self, const gchar* name);
	gboolean (*remove_attribute) (GXmlGomObject* self, const gchar* name);
	gboolean (*set_instance_property) (GXmlGomObject* self, const gchar* name);
	void (*clean_property_elements) (GXmlGomObject* self, const gchar* name, GError** error);
};

struct _GXmlGomElement {
	GXmlGomNode parent_instance;
	GXmlGomElementPrivate * priv;
	GXmlGomElementAttributes* _attributes;
	gchar* _namespace_uri;
};

struct _GXmlGomElementClass {
	GXmlGomNodeClass parent_class;
};

struct _GXmlGomElementPrivate {
	gchar* _id;
	gboolean _parse_children;
	gchar* _unparsed;
};

struct _GxmlGomElementReadFromFileAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	GAsyncReadyCallback _callback_;
	gboolean _task_complete_;
	GXmlGomElement* self;
	GFile* f;
	GCancellable* cancellable;
	GXmlXParser* parser;
	GXmlXParser* _tmp0_;
	GError* _inner_error0_;
};

struct _GxmlGomElementReadFromStreamAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	GAsyncReadyCallback _callback_;
	gboolean _task_complete_;
	GXmlGomElement* self;
	GInputStream* istream;
	GCancellable* cancellable;
	GXmlXParser* parser;
	GXmlXParser* _tmp0_;
	GError* _inner_error0_;
};

struct _GxmlGomElementReadFromStringAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	GAsyncReadyCallback _callback_;
	gboolean _task_complete_;
	GXmlGomElement* self;
	gchar* str;
	GCancellable* cancellable;
	GXmlXParser* parser;
	GXmlXParser* _tmp0_;
	GError* _inner_error0_;
};

struct _GxmlGomElementWriteStringAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	GAsyncReadyCallback _callback_;
	gboolean _task_complete_;
	GXmlGomElement* self;
	GCancellable* cancellable;
	gchar* result;
	GXmlXParser* parser;
	GXmlXParser* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	GError* _inner_error0_;
};

struct _GxmlGomElementWriteFileAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	GAsyncReadyCallback _callback_;
	gboolean _task_complete_;
	GXmlGomElement* self;
	GFile* f;
	GCancellable* cancellable;
	GXmlDomDocument* _tmp0_;
	GXmlDomDocument* _tmp1_;
	GError* _inner_error0_;
};

struct _GxmlGomElementWriteStreamAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	GAsyncReadyCallback _callback_;
	gboolean _task_complete_;
	GXmlGomElement* self;
	GOutputStream* stream;
	GCancellable* cancellable;
	GXmlDomDocument* _tmp0_;
	GXmlDomDocument* _tmp1_;
	GError* _inner_error0_;
};

struct _GxmlGomElementCreateStreamAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	GAsyncReadyCallback _callback_;
	gboolean _task_complete_;
	GXmlGomElement* self;
	GCancellable* cancellable;
	GInputStream* result;
	GInputStream* _tmp0_;
	GXmlDomDocument* _tmp1_;
	GXmlDomDocument* _tmp2_;
	GInputStream* _tmp3_;
	GInputStream* _tmp4_;
	GError* _inner_error0_;
};

struct _GXmlDomAttrIface {
	GTypeInterface parent_iface;
	gchar* (*get_namespace_uri) (GXmlDomAttr* self);
	gchar* (*get_prefix) (GXmlDomAttr* self);
	gchar* (*get_local_name) (GXmlDomAttr* self);
	gchar* (*get_name) (GXmlDomAttr* self);
	gchar* (*get_value) (GXmlDomAttr* self);
	void (*set_value) (GXmlDomAttr* self, const gchar* value);
	gboolean (*get_specified) (GXmlDomAttr* self);
};

typedef enum  {
	GXML_DOM_ERROR_INDEX_SIZE_ERROR = 1,
	GXML_DOM_ERROR_DOMSTRING_SIZE_ERROR,
	GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR,
	GXML_DOM_ERROR_WRONG_DOCUMENT_ERROR,
	GXML_DOM_ERROR_INVALID_CHARACTER_ERROR,
	GXML_DOM_ERROR_NO_DATA_ALLOWED_ERROR,
	GXML_DOM_ERROR_NO_MODIFICATION_ALLOWED_ERROR,
	GXML_DOM_ERROR_NOT_FOUND_ERROR,
	GXML_DOM_ERROR_NOT_SUPPORTED_ERROR,
	GXML_DOM_ERROR_INUSE_ATTRIBUTE_ERROR,
	GXML_DOM_ERROR_INVALID_STATE_ERROR,
	GXML_DOM_ERROR_SYNTAX_ERROR,
	GXML_DOM_ERROR_INVALID_MODIFICATION_ERROR,
	GXML_DOM_ERROR_NAMESPACE_ERROR,
	GXML_DOM_ERROR_INVALID_ACCESS_ERROR,
	GXML_DOM_ERROR_VALIDATION_ERROR,
	GXML_DOM_ERROR_TYPE_MISMATCH_ERROR,
	GXML_DOM_ERROR_SECURITY_ERROR,
	GXML_DOM_ERROR_NETWORK_ERROR,
	GXML_DOM_ERROR_ABORT_ERROR,
	GXML_DOM_ERROR_URL_MISMATCH_ERROR,
	GXML_DOM_ERROR_QUOTA_EXCEEDED_ERROR,
	GXML_DOM_ERROR_TIME_OUT_ERROR,
	GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR,
	GXML_DOM_ERROR_DATA_CLONE_ERROR
} GXmlDomError;
#define GXML_DOM_ERROR gxml_dom_error_quark ()
struct _GXmlGomElementAttributes {
	GeeHashMap parent_instance;
	GXmlGomElementAttributesPrivate * priv;
	GXmlGomElement* _element;
};

struct _GXmlGomElementAttributesClass {
	GeeHashMapClass parent_class;
};

struct _GXmlGomElementAttributesPrivate {
	GeeTreeMap* order;
};

static gint GXmlGomElement_private_offset;
static gpointer gxml_gom_element_parent_class = NULL;
static gint GXmlGomElementAttributes_private_offset;
static gpointer gxml_gom_element_attributes_parent_class = NULL;
static GXmlDomNamedNodeMapIface * gxml_gom_element_attributes_gxml_dom_named_node_map_parent_iface = NULL;
static GXmlDomChildNodeIface * gxml_gom_element_gxml_dom_child_node_parent_iface = NULL;
static GXmlDomNonDocumentTypeChildNodeIface * gxml_gom_element_gxml_dom_non_document_type_child_node_parent_iface = NULL;
static GXmlDomParentNodeIface * gxml_gom_element_gxml_dom_parent_node_parent_iface = NULL;
static GXmlDomElementIface * gxml_gom_element_gxml_dom_element_parent_iface = NULL;
static GXmlGomObjectIface * gxml_gom_element_gxml_gom_object_parent_iface = NULL;

GType gxml_dom_time_stamp_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_phase_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_listener_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_target_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_document_position_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_node_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_document_type_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_html_collection_get_type (void) G_GNUC_CONST;
GType gxml_dom_token_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_named_node_map_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_element_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_fragment_get_type (void) G_GNUC_CONST;
GType gxml_dom_character_data_get_type (void) G_GNUC_CONST;
GType gxml_dom_text_get_type (void) G_GNUC_CONST;
GType gxml_dom_comment_get_type (void) G_GNUC_CONST;
GType gxml_dom_processing_instruction_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_boundary_points_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_filter_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_iterator_get_type (void) G_GNUC_CONST;
GType gxml_dom_tree_walker_get_type (void) G_GNUC_CONST;
GType gxml_parser_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_xml_document_get_type (void) G_GNUC_CONST;
GType gxml_element_list_get_type (void) G_GNUC_CONST;
GType gxml_namespace_get_type (void) G_GNUC_CONST;
GType gxml_node_type_get_type (void) G_GNUC_CONST;
GType gxml_node_get_type (void) G_GNUC_CONST;
GType gxml_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_implementation_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_get_type (void) G_GNUC_CONST;
GType gxml_gom_node_get_type (void) G_GNUC_CONST;
GType gxml_gom_node_list_get_type (void) G_GNUC_CONST;
GType gxml_gom_property_get_type (void) G_GNUC_CONST;
GType gxml_gom_object_get_type (void) G_GNUC_CONST;
GType gxml_gom_element_get_type (void) G_GNUC_CONST;
GType gxml_gom_element_attributes_get_type (void) G_GNUC_CONST;
static void gxml_gom_element_real_read_from_file (GXmlDomElement* base,
                                           GFile* f,
                                           GCancellable* cancellable,
                                           GError** error);
GType gxml_xparser_get_type (void) G_GNUC_CONST;
GXmlXParser* gxml_xparser_new (GXmlDomNode* node);
GXmlXParser* gxml_xparser_construct (GType object_type,
                                     GXmlDomNode* node);
void gxml_parser_set_cancellable (GXmlParser* self,
                                  GCancellable* value);
void gxml_parser_read_file (GXmlParser* self,
                            GFile* file,
                            GError** error);
static void gxml_gom_element_real_read_from_file_async_data_free (gpointer _data);
static void gxml_gom_element_real_read_from_file_async_async_ready_wrapper (GObject *source_object,
                                                                     GAsyncResult *res,
                                                                     void *user_data);
static void gxml_gom_element_real_read_from_file_async (GXmlDomElement* base,
                                                 GFile* f,
                                                 GCancellable* cancellable,
                                                 GAsyncReadyCallback _callback_,
                                                 gpointer _user_data_);
static gboolean gxml_gom_element_real_read_from_file_async_co (GxmlGomElementReadFromFileAsyncData* _data_);
void gxml_parser_read_file_async (GXmlParser* self,
                                  GFile* file,
                                  GAsyncReadyCallback _callback_,
                                  gpointer _user_data_);
void gxml_parser_read_file_finish (GXmlParser* self,
                                   GAsyncResult* _res_,
                                   GError** error);
static void gxml_gom_element_read_from_file_async_ready (GObject* source_object,
                                                  GAsyncResult* _res_,
                                                  gpointer _user_data_);
static void gxml_gom_element_real_read_from_stream (GXmlDomElement* base,
                                             GInputStream* istream,
                                             GCancellable* cancellable,
                                             GError** error);
void gxml_parser_read_stream (GXmlParser* self,
                              GInputStream* stream,
                              GError** error);
static void gxml_gom_element_real_read_from_stream_async_data_free (gpointer _data);
static void gxml_gom_element_real_read_from_stream_async_async_ready_wrapper (GObject *source_object,
                                                                       GAsyncResult *res,
                                                                       void *user_data);
static void gxml_gom_element_real_read_from_stream_async (GXmlDomElement* base,
                                                   GInputStream* istream,
                                                   GCancellable* cancellable,
                                                   GAsyncReadyCallback _callback_,
                                                   gpointer _user_data_);
static gboolean gxml_gom_element_real_read_from_stream_async_co (GxmlGomElementReadFromStreamAsyncData* _data_);
void gxml_parser_read_stream_async (GXmlParser* self,
                                    GInputStream* stream,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_);
void gxml_parser_read_stream_finish (GXmlParser* self,
                                     GAsyncResult* _res_,
                                     GError** error);
static void gxml_gom_element_read_from_stream_async_ready (GObject* source_object,
                                                    GAsyncResult* _res_,
                                                    gpointer _user_data_);
static void gxml_gom_element_real_read_from_string (GXmlDomElement* base,
                                             const gchar* str,
                                             GCancellable* cancellable,
                                             GError** error);
void gxml_parser_read_string (GXmlParser* self,
                              const gchar* str,
                              GError** error);
static void gxml_gom_element_real_read_from_string_async_data_free (gpointer _data);
static void gxml_gom_element_real_read_from_string_async_async_ready_wrapper (GObject *source_object,
                                                                       GAsyncResult *res,
                                                                       void *user_data);
static void gxml_gom_element_real_read_from_string_async (GXmlDomElement* base,
                                                   const gchar* str,
                                                   GCancellable* cancellable,
                                                   GAsyncReadyCallback _callback_,
                                                   gpointer _user_data_);
static gboolean gxml_gom_element_real_read_from_string_async_co (GxmlGomElementReadFromStringAsyncData* _data_);
void gxml_parser_read_string_async (GXmlParser* self,
                                    const gchar* str,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_);
void gxml_parser_read_string_finish (GXmlParser* self,
                                     GAsyncResult* _res_,
                                     GError** error);
static void gxml_gom_element_read_from_string_async_ready (GObject* source_object,
                                                    GAsyncResult* _res_,
                                                    gpointer _user_data_);
static gchar* gxml_gom_element_real_write_string (GXmlDomElement* base,
                                           GCancellable* cancellable,
                                           GError** error);
gchar* gxml_parser_write_string (GXmlParser* self,
                                 GError** error);
static void gxml_gom_element_real_write_string_async_data_free (gpointer _data);
static void gxml_gom_element_real_write_string_async_async_ready_wrapper (GObject *source_object,
                                                                   GAsyncResult *res,
                                                                   void *user_data);
static void gxml_gom_element_real_write_string_async (GXmlDomElement* base,
                                               GCancellable* cancellable,
                                               GAsyncReadyCallback _callback_,
                                               gpointer _user_data_);
static gboolean gxml_gom_element_real_write_string_async_co (GxmlGomElementWriteStringAsyncData* _data_);
void gxml_parser_write_string_async (GXmlParser* self,
                                     GAsyncReadyCallback _callback_,
                                     gpointer _user_data_);
gchar* gxml_parser_write_string_finish (GXmlParser* self,
                                        GAsyncResult* _res_,
                                        GError** error);
static void gxml_gom_element_write_string_async_ready (GObject* source_object,
                                                GAsyncResult* _res_,
                                                gpointer _user_data_);
static void gxml_gom_element_real_write_file (GXmlDomElement* base,
                                       GFile* f,
                                       GCancellable* cancellable,
                                       GError** error);
GXmlDomDocument* gxml_dom_node_get_owner_document (GXmlDomNode* self);
GType gxml_gom_document_get_type (void) G_GNUC_CONST;
void gxml_dom_document_write_file (GXmlDomDocument* self,
                                   GFile* file,
                                   GCancellable* cancellable,
                                   GError** error);
static void gxml_gom_element_real_write_file_async_data_free (gpointer _data);
static void gxml_gom_element_real_write_file_async_async_ready_wrapper (GObject *source_object,
                                                                 GAsyncResult *res,
                                                                 void *user_data);
static void gxml_gom_element_real_write_file_async (GXmlDomElement* base,
                                             GFile* f,
                                             GCancellable* cancellable,
                                             GAsyncReadyCallback _callback_,
                                             gpointer _user_data_);
static gboolean gxml_gom_element_real_write_file_async_co (GxmlGomElementWriteFileAsyncData* _data_);
void gxml_dom_document_write_file_async (GXmlDomDocument* self,
                                         GFile* file,
                                         GCancellable* cancellable,
                                         GAsyncReadyCallback _callback_,
                                         gpointer _user_data_);
void gxml_dom_document_write_file_finish (GXmlDomDocument* self,
                                          GAsyncResult* _res_,
                                          GError** error);
static void gxml_gom_element_write_file_async_ready (GObject* source_object,
                                              GAsyncResult* _res_,
                                              gpointer _user_data_);
static void gxml_gom_element_real_write_stream (GXmlDomElement* base,
                                         GOutputStream* stream,
                                         GError** error);
void gxml_dom_document_write_stream (GXmlDomDocument* self,
                                     GOutputStream* stream,
                                     GCancellable* cancellable,
                                     GError** error);
static void gxml_gom_element_real_write_stream_async_data_free (gpointer _data);
static void gxml_gom_element_real_write_stream_async_async_ready_wrapper (GObject *source_object,
                                                                   GAsyncResult *res,
                                                                   void *user_data);
static void gxml_gom_element_real_write_stream_async (GXmlDomElement* base,
                                               GOutputStream* stream,
                                               GCancellable* cancellable,
                                               GAsyncReadyCallback _callback_,
                                               gpointer _user_data_);
static gboolean gxml_gom_element_real_write_stream_async_co (GxmlGomElementWriteStreamAsyncData* _data_);
void gxml_dom_document_write_stream_async (GXmlDomDocument* self,
                                           GOutputStream* stream,
                                           GCancellable* cancellable,
                                           GAsyncReadyCallback _callback_,
                                           gpointer _user_data_);
void gxml_dom_document_write_stream_finish (GXmlDomDocument* self,
                                            GAsyncResult* _res_,
                                            GError** error);
static void gxml_gom_element_write_stream_async_ready (GObject* source_object,
                                                GAsyncResult* _res_,
                                                gpointer _user_data_);
static GInputStream* gxml_gom_element_real_create_stream (GXmlDomElement* base,
                                                   GError** error);
GInputStream* gxml_dom_document_create_stream (GXmlDomDocument* self,
                                               GError** error);
static void gxml_gom_element_real_create_stream_async_data_free (gpointer _data);
static void gxml_gom_element_real_create_stream_async_async_ready_wrapper (GObject *source_object,
                                                                    GAsyncResult *res,
                                                                    void *user_data);
static void gxml_gom_element_real_create_stream_async (GXmlDomElement* base,
                                                GCancellable* cancellable,
                                                GAsyncReadyCallback _callback_,
                                                gpointer _user_data_);
static gboolean gxml_gom_element_real_create_stream_async_co (GxmlGomElementCreateStreamAsyncData* _data_);
void gxml_dom_document_create_stream_async (GXmlDomDocument* self,
                                            GCancellable* cancellable,
                                            GAsyncReadyCallback _callback_,
                                            gpointer _user_data_);
GInputStream* gxml_dom_document_create_stream_finish (GXmlDomDocument* self,
                                                      GAsyncResult* _res_,
                                                      GError** error);
static void gxml_gom_element_create_stream_async_ready (GObject* source_object,
                                                 GAsyncResult* _res_,
                                                 gpointer _user_data_);
gchar* gxml_gom_element_lookup_prefix (GXmlGomElement* self,
                                       const gchar* nspace);
GType gxml_dom_attr_get_type (void) G_GNUC_CONST;
gchar* gxml_dom_attr_get_value (GXmlDomAttr* self);
GXmlDomNode* gxml_dom_node_get_parent_node (GXmlDomNode* self);
gchar* gxml_dom_node_lookup_prefix (GXmlDomNode* self,
                                    const gchar* nspace);
gchar* gxml_gom_element_lookup_namespace_uri (GXmlGomElement* self,
                                              const gchar* prefix);
GXmlDomNamedNodeMap* gxml_dom_element_get_attributes (GXmlDomElement* self);
gchar* gxml_dom_node_lookup_namespace_uri (GXmlDomNode* self,
                                           const gchar* prefix);
static void gxml_gom_element_real_remove (GXmlDomChildNode* base);
GXmlDomNodeList* gxml_dom_node_get_child_nodes (GXmlDomNode* self);
gint gxml_dom_node_list_get_length (GXmlDomNodeList* self);
static GXmlDomNodeList* gxml_gom_element_real_query_selector_all (GXmlDomParentNode* base,
                                                           const gchar* selectors,
                                                           GError** error);
GType gxml_css_selector_parser_get_type (void) G_GNUC_CONST;
GXmlCssSelectorParser* gxml_css_selector_parser_new (void);
GXmlCssSelectorParser* gxml_css_selector_parser_construct (GType object_type);
void gxml_css_selector_parser_parse (GXmlCssSelectorParser* self,
                                     const gchar* selectors,
                                     GError** error);
GXmlDomNodeList* gxml_css_selector_parser_query_selector_all (GXmlCssSelectorParser* self,
                                                              GXmlDomElement* element,
                                                              GError** error);
void gxml_gom_element_initialize (GXmlGomElement* self,
                                  const gchar* local_name);
void gxml_gom_element_initialize_document (GXmlGomElement* self,
                                           GXmlDomDocument* doc,
                                           const gchar* local_name);
void gxml_gom_element_initialize_with_namespace (GXmlGomElement* self,
                                                 const gchar* namespace_uri,
                                                 const gchar* prefix,
                                                 const gchar* local_name);
void gxml_gom_element_initialize_document_with_namespace (GXmlGomElement* self,
                                                          GXmlDomDocument* doc,
                                                          const gchar* namespace_uri,
                                                          const gchar* prefix,
                                                          const gchar* local_name);
static gchar* gxml_gom_element_real_get_attribute (GXmlDomElement* base,
                                            const gchar* name);
static gchar* gxml_gom_element_real_get_attribute_ns (GXmlDomElement* base,
                                               const gchar* namespace_uri,
                                               const gchar* local_name);
static void gxml_gom_element_real_set_attribute (GXmlDomElement* base,
                                          const gchar* name,
                                          const gchar* value,
                                          GError** error);
GType gxml_gom_attr_get_type (void) G_GNUC_CONST;
GXmlGomAttr* gxml_gom_attr_new (GXmlDomElement* element,
                                const gchar* name,
                                const gchar* val);
GXmlGomAttr* gxml_gom_attr_construct (GType object_type,
                                      GXmlDomElement* element,
                                      const gchar* name,
                                      const gchar* val);
GXmlDomNode* gxml_dom_named_node_map_set_named_item (GXmlDomNamedNodeMap* self,
                                                     GXmlDomNode* node,
                                                     GError** error);
static void gxml_gom_element_real_set_attribute_ns (GXmlDomElement* base,
                                             const gchar* namespace_uri,
                                             const gchar* name,
                                             const gchar* value,
                                             GError** error);
GQuark gxml_dom_error_quark (void);
GXmlGomAttr* gxml_gom_attr_new_namespace (GXmlDomElement* element,
                                          const gchar* namespace_uri,
                                          const gchar* prefix,
                                          const gchar* name,
                                          const gchar* val);
GXmlGomAttr* gxml_gom_attr_construct_namespace (GType object_type,
                                                GXmlDomElement* element,
                                                const gchar* namespace_uri,
                                                const gchar* prefix,
                                                const gchar* name,
                                                const gchar* val);
GXmlDomNode* gxml_dom_named_node_map_set_named_item_ns (GXmlDomNamedNodeMap* self,
                                                        GXmlDomNode* node,
                                                        GError** error);
static void gxml_gom_element_real_remove_attribute (GXmlDomElement* base,
                                             const gchar* name);
GXmlDomNode* gxml_dom_named_node_map_remove_named_item (GXmlDomNamedNodeMap* self,
                                                        const gchar* name,
                                                        GError** error);
static void gxml_gom_element_real_remove_attribute_ns (GXmlDomElement* base,
                                                const gchar* namespace_uri,
                                                const gchar* local_name);
GXmlDomNode* gxml_dom_named_node_map_remove_named_item_ns (GXmlDomNamedNodeMap* self,
                                                           const gchar* namespace_uri,
                                                           const gchar* localName,
                                                           GError** error);
static gboolean gxml_gom_element_real_has_attribute (GXmlDomElement* base,
                                              const gchar* name);
static gboolean gxml_gom_element_real_has_attribute_ns (GXmlDomElement* base,
                                                 const gchar* namespace_uri,
                                                 const gchar* local_name);
static GXmlDomHTMLCollection* gxml_gom_element_real_get_elements_by_tag_name (GXmlDomElement* base,
                                                                       const gchar* local_name);
GType gxml_gdom_html_collection_get_type (void) G_GNUC_CONST;
GXmlGDomHTMLCollection* gxml_gdom_html_collection_new (void);
GXmlGDomHTMLCollection* gxml_gdom_html_collection_construct (GType object_type);
gchar* gxml_dom_node_get_node_name (GXmlDomNode* self);
GXmlDomHTMLCollection* gxml_dom_element_get_elements_by_tag_name (GXmlDomElement* self,
                                                                  const gchar* local_name);
static GXmlDomHTMLCollection* gxml_gom_element_real_get_elements_by_tag_name_ns (GXmlDomElement* base,
                                                                          const gchar* namespace,
                                                                          const gchar* local_name);
gchar* gxml_dom_element_get_namespace_uri (GXmlDomElement* self);
GXmlDomHTMLCollection* gxml_dom_element_get_elements_by_tag_name_ns (GXmlDomElement* self,
                                                                     const gchar* namespace,
                                                                     const gchar* local_name);
static GXmlDomHTMLCollection* gxml_gom_element_real_get_elements_by_class_name (GXmlDomElement* base,
                                                                         const gchar* class_names);
static void _vala_array_add8 (gchar** * array,
                       int* length,
                       int* size,
                       gchar* value);
gchar* gxml_dom_element_get_attribute (GXmlDomElement* self,
                                       const gchar* name);
static void _vala_array_add9 (gchar** * array,
                       int* length,
                       int* size,
                       gchar* value);
GXmlDomHTMLCollection* gxml_dom_element_get_elements_by_class_name (GXmlDomElement* self,
                                                                    const gchar* class_names);
void gxml_gom_element_read_unparsed (GXmlGomElement* self,
                                     GError** error);
const gchar* gxml_gom_element_get_unparsed (GXmlGomElement* self);
void gxml_parser_read_child_nodes_string (GXmlParser* self,
                                          const gchar* str,
                                          GError** error);
void gxml_gom_element_set_unparsed (GXmlGomElement* self,
                                    const gchar* value);
GXmlGomElement* gxml_gom_element_new (void);
GXmlGomElement* gxml_gom_element_construct (GType object_type);
GXmlGomNode* gxml_gom_node_new (void);
GXmlGomNode* gxml_gom_node_construct (GType object_type);
GXmlDomNode* gxml_dom_node_list_item (GXmlDomNodeList* self,
                                      gint index);
GXmlDomHTMLCollection* gxml_dom_parent_node_get_children (GXmlDomParentNode* self);
gboolean gxml_gom_object_set_attribute (GXmlGomObject* self,
                                        const gchar* name,
                                        const gchar* val);
GXmlGDomTokenList* gxml_gdom_token_list_new (GXmlDomElement* e,
                                             const gchar* attr);
GXmlGDomTokenList* gxml_gdom_token_list_construct (GType object_type,
                                                   GXmlDomElement* e,
                                                   const gchar* attr);
GType gxml_gdom_token_list_get_type (void) G_GNUC_CONST;
gboolean gxml_gom_element_get_parse_children (GXmlGomElement* self);
void gxml_gom_element_set_parse_children (GXmlGomElement* self,
                                          gboolean value);
static GObject * gxml_gom_element_constructor (GType type,
                                        guint n_construct_properties,
                                        GObjectConstructParam * construct_properties);
GXmlGomElementAttributes* gxml_gom_element_attributes_new (GXmlGomElement* element);
GXmlGomElementAttributes* gxml_gom_element_attributes_construct (GType object_type,
                                                                 GXmlGomElement* element);
static void _gxml_gom_element___lambda6_ (GXmlGomElement* self,
                                   GParamSpec* pspec);
GXmlGomStringRef* gxml_gom_string_ref_new (GXmlGomObject* obj,
                                           const gchar* name);
GXmlGomStringRef* gxml_gom_string_ref_construct (GType object_type,
                                                 GXmlGomObject* obj,
                                                 const gchar* name);
GType gxml_gom_string_ref_get_type (void) G_GNUC_CONST;
void gxml_gom_element_attributes_add_reference (GXmlGomElementAttributes* self,
                                                const gchar* name);
static void __gxml_gom_element___lambda6__g_object_notify (GObject* _sender,
                                                    GParamSpec* pspec,
                                                    gpointer self);
static GXmlDomNode* gxml_gom_element_attributes_real_item (GXmlDomNamedNodeMap* base,
                                                    gint index);
gchar* gxml_dom_node_get_node_value (GXmlDomNode* self);
static GXmlDomNode* gxml_gom_element_attributes_real_get_named_item (GXmlDomNamedNodeMap* base,
                                                              const gchar* name);
gchar* gxml_gom_object_get_attribute (GXmlGomObject* self,
                                      const gchar* name);
static GXmlDomNode* gxml_gom_element_attributes_real_set_named_item (GXmlDomNamedNodeMap* base,
                                                              GXmlDomNode* node,
                                                              GError** error);
gchar* gxml_dom_attr_get_local_name (GXmlDomAttr* self);
GParamSpec* gxml_gom_object_find_property_name (GXmlGomObject* self,
                                                const gchar* nick);
GXmlGomAttr* gxml_gom_attr_new_reference (GXmlDomElement* element,
                                          const gchar* name);
GXmlGomAttr* gxml_gom_attr_construct_reference (GType object_type,
                                                GXmlDomElement* element,
                                                const gchar* name);
static GXmlDomNode* gxml_gom_element_attributes_real_remove_named_item (GXmlDomNamedNodeMap* base,
                                                                 const gchar* name,
                                                                 GError** error);
void gxml_dom_attr_set_value (GXmlDomAttr* self,
                              const gchar* value);
static glong gxml_gom_element_attributes_index_of (GXmlGomElementAttributes* self,
                                            const gchar* name);
static GXmlDomNode* gxml_gom_element_attributes_real_remove_named_item_ns (GXmlDomNamedNodeMap* base,
                                                                    const gchar* namespace_uri,
                                                                    const gchar* local_name,
                                                                    GError** error);
static GXmlDomNode* gxml_gom_element_attributes_real_get_named_item_ns (GXmlDomNamedNodeMap* base,
                                                                 const gchar* namespace_uri,
                                                                 const gchar* local_name,
                                                                 GError** error);
static GXmlDomNode* gxml_gom_element_attributes_real_set_named_item_ns (GXmlDomNamedNodeMap* base,
                                                                 GXmlDomNode* node,
                                                                 GError** error);
gchar* gxml_dom_attr_get_prefix (GXmlDomAttr* self);
gchar* gxml_dom_attr_get_namespace_uri (GXmlDomAttr* self);
gchar* gxml_dom_element_get_attribute_ns (GXmlDomElement* self,
                                          const gchar* namespace,
                                          const gchar* local_name);
static void gxml_gom_element_attributes_finalize (GObject * obj);
gint gxml_dom_named_node_map_get_length (GXmlDomNamedNodeMap* self);
static void _vala_gxml_gom_element_attributes_get_property (GObject * object,
                                                     guint property_id,
                                                     GValue * value,
                                                     GParamSpec * pspec);
static void gxml_gom_element_finalize (GObject * obj);
GXmlDomElement* gxml_dom_non_document_type_child_node_get_previous_element_sibling (GXmlDomNonDocumentTypeChildNode* self);
GXmlDomElement* gxml_dom_non_document_type_child_node_get_next_element_sibling (GXmlDomNonDocumentTypeChildNode* self);
GXmlDomElement* gxml_dom_parent_node_get_first_element_child (GXmlDomParentNode* self);
GXmlDomElement* gxml_dom_parent_node_get_last_element_child (GXmlDomParentNode* self);
gint gxml_dom_parent_node_get_child_element_count (GXmlDomParentNode* self);
gchar* gxml_dom_element_get_prefix (GXmlDomElement* self);
gchar* gxml_dom_element_get_local_name (GXmlDomElement* self);
gchar* gxml_dom_element_get_tag_name (GXmlDomElement* self);
gchar* gxml_dom_element_get_id (GXmlDomElement* self);
gchar* gxml_dom_element_get_class_name (GXmlDomElement* self);
GXmlDomTokenList* gxml_dom_element_get_class_list (GXmlDomElement* self);
static void _vala_gxml_gom_element_get_property (GObject * object,
                                          guint property_id,
                                          GValue * value,
                                          GParamSpec * pspec);
void gxml_dom_element_set_id (GXmlDomElement* self,
                              const gchar* value);
void gxml_dom_element_set_class_name (GXmlDomElement* self,
                                      const gchar* value);
static void _vala_gxml_gom_element_set_property (GObject * object,
                                          guint property_id,
                                          const GValue * value,
                                          GParamSpec * pspec);
static void _vala_array_destroy (gpointer array,
                          gint array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gint array_length,
                       GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);

static inline gpointer
gxml_gom_element_get_instance_private (GXmlGomElement* self)
{
	return G_STRUCT_MEMBER_P (self, GXmlGomElement_private_offset);
}

/**
   * Parses an XML file, deserializing it over {@link GomElement}.
   */
static void
gxml_gom_element_real_read_from_file (GXmlDomElement* base,
                                      GFile* f,
                                      GCancellable* cancellable,
                                      GError** error)
{
	GXmlGomElement * self;
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_;
	GError* _inner_error0_ = NULL;
	self = (GXmlGomElement*) base;
	g_return_if_fail (f != NULL);
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
	parser = _tmp0_;
	gxml_parser_set_cancellable ((GXmlParser*) parser, cancellable);
	gxml_parser_read_file ((GXmlParser*) parser, f, &_inner_error0_);
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (parser);
		return;
	}
	_g_object_unref0 (parser);
}

static void
gxml_gom_element_real_read_from_file_async_data_free (gpointer _data)
{
	GxmlGomElementReadFromFileAsyncData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->f);
	_g_object_unref0 (_data_->cancellable);
	_g_object_unref0 (_data_->self);
	g_slice_free (GxmlGomElementReadFromFileAsyncData, _data_);
}

static void
gxml_gom_element_real_read_from_file_async_async_ready_wrapper (GObject *source_object,
                                                                GAsyncResult *res,
                                                                void *user_data)
{
	GxmlGomElementReadFromFileAsyncData* _task_data_;
	_task_data_ = g_task_get_task_data (G_TASK (res));
	if (_task_data_->_callback_ != NULL) {
		_task_data_->_callback_ (source_object, res, user_data);
	}
	_task_data_->_task_complete_ = TRUE;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
gxml_gom_element_real_read_from_file_async (GXmlDomElement* base,
                                            GFile* f,
                                            GCancellable* cancellable,
                                            GAsyncReadyCallback _callback_,
                                            gpointer _user_data_)
{
	GXmlGomElement * self;
	GxmlGomElementReadFromFileAsyncData* _data_;
	GXmlGomElement* _tmp0_;
	GFile* _tmp1_;
	GCancellable* _tmp2_;
	self = (GXmlGomElement*) base;
	_data_ = g_slice_new0 (GxmlGomElementReadFromFileAsyncData);
	_data_->_callback_ = _callback_;
	_data_->_async_result = g_task_new (G_OBJECT (self), cancellable, gxml_gom_element_real_read_from_file_async_async_ready_wrapper, _user_data_);
	if (_callback_ == NULL) {
		_data_->_task_complete_ = TRUE;
	}
	g_task_set_task_data (_data_->_async_result, _data_, gxml_gom_element_real_read_from_file_async_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (f);
	_g_object_unref0 (_data_->f);
	_data_->f = _tmp1_;
	_tmp2_ = _g_object_ref0 (cancellable);
	_g_object_unref0 (_data_->cancellable);
	_data_->cancellable = _tmp2_;
	gxml_gom_element_real_read_from_file_async_co (_data_);
}

static void
gxml_gom_element_read_from_file_finish (GXmlDomElement* base,
                                        GAsyncResult* _res_,
                                        GError** error)
{
	GxmlGomElementReadFromFileAsyncData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), error);
	if (NULL == _data_) {
		return;
	}
}

/**
   * Parses asinchronically an XML file, deserializing it over {@link GomElement}.
   */
static void
gxml_gom_element_read_from_file_async_ready (GObject* source_object,
                                             GAsyncResult* _res_,
                                             gpointer _user_data_)
{
	GxmlGomElementReadFromFileAsyncData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	_data_->_task_complete_ = TRUE;
	gxml_gom_element_real_read_from_file_async_co (_data_);
}

static gboolean
gxml_gom_element_real_read_from_file_async_co (GxmlGomElementReadFromFileAsyncData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = gxml_xparser_new ((GXmlDomNode*) _data_->self);
	_data_->parser = _data_->_tmp0_;
	gxml_parser_set_cancellable ((GXmlParser*) _data_->parser, _data_->cancellable);
	_data_->_state_ = 1;
	gxml_parser_read_file_async ((GXmlParser*) _data_->parser, _data_->f, gxml_gom_element_read_from_file_async_ready, _data_);
	return FALSE;
	_state_1:
	gxml_parser_read_file_finish ((GXmlParser*) _data_->parser, _data_->_res_, &_data_->_inner_error0_);
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
		_g_object_unref0 (_data_->parser);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_g_object_unref0 (_data_->parser);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!_data_->_task_complete_) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

/**
   * Parses an XML over a {@link GLib.InputStream}, deserializing it over {@link GomElement}.
   */
static void
gxml_gom_element_real_read_from_stream (GXmlDomElement* base,
                                        GInputStream* istream,
                                        GCancellable* cancellable,
                                        GError** error)
{
	GXmlGomElement * self;
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_;
	GError* _inner_error0_ = NULL;
	self = (GXmlGomElement*) base;
	g_return_if_fail (istream != NULL);
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
	parser = _tmp0_;
	gxml_parser_set_cancellable ((GXmlParser*) parser, cancellable);
	gxml_parser_read_stream ((GXmlParser*) parser, istream, &_inner_error0_);
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (parser);
		return;
	}
	_g_object_unref0 (parser);
}

static void
gxml_gom_element_real_read_from_stream_async_data_free (gpointer _data)
{
	GxmlGomElementReadFromStreamAsyncData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->istream);
	_g_object_unref0 (_data_->cancellable);
	_g_object_unref0 (_data_->self);
	g_slice_free (GxmlGomElementReadFromStreamAsyncData, _data_);
}

static void
gxml_gom_element_real_read_from_stream_async_async_ready_wrapper (GObject *source_object,
                                                                  GAsyncResult *res,
                                                                  void *user_data)
{
	GxmlGomElementReadFromStreamAsyncData* _task_data_;
	_task_data_ = g_task_get_task_data (G_TASK (res));
	if (_task_data_->_callback_ != NULL) {
		_task_data_->_callback_ (source_object, res, user_data);
	}
	_task_data_->_task_complete_ = TRUE;
}

static void
gxml_gom_element_real_read_from_stream_async (GXmlDomElement* base,
                                              GInputStream* istream,
                                              GCancellable* cancellable,
                                              GAsyncReadyCallback _callback_,
                                              gpointer _user_data_)
{
	GXmlGomElement * self;
	GxmlGomElementReadFromStreamAsyncData* _data_;
	GXmlGomElement* _tmp0_;
	GInputStream* _tmp1_;
	GCancellable* _tmp2_;
	self = (GXmlGomElement*) base;
	_data_ = g_slice_new0 (GxmlGomElementReadFromStreamAsyncData);
	_data_->_callback_ = _callback_;
	_data_->_async_result = g_task_new (G_OBJECT (self), cancellable, gxml_gom_element_real_read_from_stream_async_async_ready_wrapper, _user_data_);
	if (_callback_ == NULL) {
		_data_->_task_complete_ = TRUE;
	}
	g_task_set_task_data (_data_->_async_result, _data_, gxml_gom_element_real_read_from_stream_async_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (istream);
	_g_object_unref0 (_data_->istream);
	_data_->istream = _tmp1_;
	_tmp2_ = _g_object_ref0 (cancellable);
	_g_object_unref0 (_data_->cancellable);
	_data_->cancellable = _tmp2_;
	gxml_gom_element_real_read_from_stream_async_co (_data_);
}

static void
gxml_gom_element_read_from_stream_finish (GXmlDomElement* base,
                                          GAsyncResult* _res_,
                                          GError** error)
{
	GxmlGomElementReadFromStreamAsyncData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), error);
	if (NULL == _data_) {
		return;
	}
}

/**
   * Parses asynchronically an XML over a {@link GLib.InputStream}, deserializing it over {@link GomElement}.
   */
static void
gxml_gom_element_read_from_stream_async_ready (GObject* source_object,
                                               GAsyncResult* _res_,
                                               gpointer _user_data_)
{
	GxmlGomElementReadFromStreamAsyncData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	_data_->_task_complete_ = TRUE;
	gxml_gom_element_real_read_from_stream_async_co (_data_);
}

static gboolean
gxml_gom_element_real_read_from_stream_async_co (GxmlGomElementReadFromStreamAsyncData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = gxml_xparser_new ((GXmlDomNode*) _data_->self);
	_data_->parser = _data_->_tmp0_;
	gxml_parser_set_cancellable ((GXmlParser*) _data_->parser, _data_->cancellable);
	_data_->_state_ = 1;
	gxml_parser_read_stream_async ((GXmlParser*) _data_->parser, _data_->istream, gxml_gom_element_read_from_stream_async_ready, _data_);
	return FALSE;
	_state_1:
	gxml_parser_read_stream_finish ((GXmlParser*) _data_->parser, _data_->_res_, &_data_->_inner_error0_);
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
		_g_object_unref0 (_data_->parser);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_g_object_unref0 (_data_->parser);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!_data_->_task_complete_) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

/**
   * Parses an XML string, deserializing it over {@link GomElement}.
   */
static void
gxml_gom_element_real_read_from_string (GXmlDomElement* base,
                                        const gchar* str,
                                        GCancellable* cancellable,
                                        GError** error)
{
	GXmlGomElement * self;
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_;
	GError* _inner_error0_ = NULL;
	self = (GXmlGomElement*) base;
	g_return_if_fail (str != NULL);
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
	parser = _tmp0_;
	gxml_parser_set_cancellable ((GXmlParser*) parser, cancellable);
	gxml_parser_read_string ((GXmlParser*) parser, str, &_inner_error0_);
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (parser);
		return;
	}
	_g_object_unref0 (parser);
}

static void
gxml_gom_element_real_read_from_string_async_data_free (gpointer _data)
{
	GxmlGomElementReadFromStringAsyncData* _data_;
	_data_ = _data;
	_g_free0 (_data_->str);
	_g_object_unref0 (_data_->cancellable);
	_g_object_unref0 (_data_->self);
	g_slice_free (GxmlGomElementReadFromStringAsyncData, _data_);
}

static void
gxml_gom_element_real_read_from_string_async_async_ready_wrapper (GObject *source_object,
                                                                  GAsyncResult *res,
                                                                  void *user_data)
{
	GxmlGomElementReadFromStringAsyncData* _task_data_;
	_task_data_ = g_task_get_task_data (G_TASK (res));
	if (_task_data_->_callback_ != NULL) {
		_task_data_->_callback_ (source_object, res, user_data);
	}
	_task_data_->_task_complete_ = TRUE;
}

static void
gxml_gom_element_real_read_from_string_async (GXmlDomElement* base,
                                              const gchar* str,
                                              GCancellable* cancellable,
                                              GAsyncReadyCallback _callback_,
                                              gpointer _user_data_)
{
	GXmlGomElement * self;
	GxmlGomElementReadFromStringAsyncData* _data_;
	GXmlGomElement* _tmp0_;
	gchar* _tmp1_;
	GCancellable* _tmp2_;
	self = (GXmlGomElement*) base;
	_data_ = g_slice_new0 (GxmlGomElementReadFromStringAsyncData);
	_data_->_callback_ = _callback_;
	_data_->_async_result = g_task_new (G_OBJECT (self), cancellable, gxml_gom_element_real_read_from_string_async_async_ready_wrapper, _user_data_);
	if (_callback_ == NULL) {
		_data_->_task_complete_ = TRUE;
	}
	g_task_set_task_data (_data_->_async_result, _data_, gxml_gom_element_real_read_from_string_async_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = g_strdup (str);
	_g_free0 (_data_->str);
	_data_->str = _tmp1_;
	_tmp2_ = _g_object_ref0 (cancellable);
	_g_object_unref0 (_data_->cancellable);
	_data_->cancellable = _tmp2_;
	gxml_gom_element_real_read_from_string_async_co (_data_);
}

static void
gxml_gom_element_read_from_string_finish (GXmlDomElement* base,
                                          GAsyncResult* _res_,
                                          GError** error)
{
	GxmlGomElementReadFromStringAsyncData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), error);
	if (NULL == _data_) {
		return;
	}
}

/**
   * Parses an XML string, deserializing it over {@link GomElement}.
   */
static void
gxml_gom_element_read_from_string_async_ready (GObject* source_object,
                                               GAsyncResult* _res_,
                                               gpointer _user_data_)
{
	GxmlGomElementReadFromStringAsyncData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	_data_->_task_complete_ = TRUE;
	gxml_gom_element_real_read_from_string_async_co (_data_);
}

static gboolean
gxml_gom_element_real_read_from_string_async_co (GxmlGomElementReadFromStringAsyncData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = gxml_xparser_new ((GXmlDomNode*) _data_->self);
	_data_->parser = _data_->_tmp0_;
	gxml_parser_set_cancellable ((GXmlParser*) _data_->parser, _data_->cancellable);
	_data_->_state_ = 1;
	gxml_parser_read_string_async ((GXmlParser*) _data_->parser, _data_->str, gxml_gom_element_read_from_string_async_ready, _data_);
	return FALSE;
	_state_1:
	gxml_parser_read_string_finish ((GXmlParser*) _data_->parser, _data_->_res_, &_data_->_inner_error0_);
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
		_g_object_unref0 (_data_->parser);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_g_object_unref0 (_data_->parser);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!_data_->_task_complete_) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

/**
   * Serialize {@link GomElement} to a string.
   */
static gchar*
gxml_gom_element_real_write_string (GXmlDomElement* base,
                                    GCancellable* cancellable,
                                    GError** error)
{
	GXmlGomElement * self;
	gchar* result = NULL;
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_;
	gchar* _tmp3_;
	GError* _inner_error0_ = NULL;
	self = (GXmlGomElement*) base;
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
	parser = _tmp0_;
	gxml_parser_set_cancellable ((GXmlParser*) parser, cancellable);
	_tmp2_ = gxml_parser_write_string ((GXmlParser*) parser, &_inner_error0_);
	_tmp1_ = _tmp2_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (parser);
		return NULL;
	}
	_tmp3_ = _tmp1_;
	_tmp1_ = NULL;
	result = _tmp3_;
	_g_free0 (_tmp1_);
	_g_object_unref0 (parser);
	return result;
}

static void
gxml_gom_element_real_write_string_async_data_free (gpointer _data)
{
	GxmlGomElementWriteStringAsyncData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->cancellable);
	_g_free0 (_data_->result);
	_g_object_unref0 (_data_->self);
	g_slice_free (GxmlGomElementWriteStringAsyncData, _data_);
}

static void
gxml_gom_element_real_write_string_async_async_ready_wrapper (GObject *source_object,
                                                              GAsyncResult *res,
                                                              void *user_data)
{
	GxmlGomElementWriteStringAsyncData* _task_data_;
	_task_data_ = g_task_get_task_data (G_TASK (res));
	if (_task_data_->_callback_ != NULL) {
		_task_data_->_callback_ (source_object, res, user_data);
	}
	_task_data_->_task_complete_ = TRUE;
}

static void
gxml_gom_element_real_write_string_async (GXmlDomElement* base,
                                          GCancellable* cancellable,
                                          GAsyncReadyCallback _callback_,
                                          gpointer _user_data_)
{
	GXmlGomElement * self;
	GxmlGomElementWriteStringAsyncData* _data_;
	GXmlGomElement* _tmp0_;
	GCancellable* _tmp1_;
	self = (GXmlGomElement*) base;
	_data_ = g_slice_new0 (GxmlGomElementWriteStringAsyncData);
	_data_->_callback_ = _callback_;
	_data_->_async_result = g_task_new (G_OBJECT (self), cancellable, gxml_gom_element_real_write_string_async_async_ready_wrapper, _user_data_);
	if (_callback_ == NULL) {
		_data_->_task_complete_ = TRUE;
	}
	g_task_set_task_data (_data_->_async_result, _data_, gxml_gom_element_real_write_string_async_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (cancellable);
	_g_object_unref0 (_data_->cancellable);
	_data_->cancellable = _tmp1_;
	gxml_gom_element_real_write_string_async_co (_data_);
}

static gchar*
gxml_gom_element_write_string_finish (GXmlDomElement* base,
                                      GAsyncResult* _res_,
                                      GError** error)
{
	gchar* result;
	GxmlGomElementWriteStringAsyncData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), error);
	if (NULL == _data_) {
		return NULL;
	}
	result = _data_->result;
	_data_->result = NULL;
	return result;
}

/**
   * Serialize asinchronically {@link GomElement} to a string.
   */
static void
gxml_gom_element_write_string_async_ready (GObject* source_object,
                                           GAsyncResult* _res_,
                                           gpointer _user_data_)
{
	GxmlGomElementWriteStringAsyncData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	_data_->_task_complete_ = TRUE;
	gxml_gom_element_real_write_string_async_co (_data_);
}

static gboolean
gxml_gom_element_real_write_string_async_co (GxmlGomElementWriteStringAsyncData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = gxml_xparser_new ((GXmlDomNode*) _data_->self);
	_data_->parser = _data_->_tmp0_;
	gxml_parser_set_cancellable ((GXmlParser*) _data_->parser, _data_->cancellable);
	_data_->_state_ = 1;
	gxml_parser_write_string_async ((GXmlParser*) _data_->parser, gxml_gom_element_write_string_async_ready, _data_);
	return FALSE;
	_state_1:
	_data_->_tmp2_ = gxml_parser_write_string_finish ((GXmlParser*) _data_->parser, _data_->_res_, &_data_->_inner_error0_);
	_data_->_tmp1_ = _data_->_tmp2_;
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
		_g_object_unref0 (_data_->parser);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->_tmp3_ = _data_->_tmp1_;
	_data_->_tmp1_ = NULL;
	_data_->result = _data_->_tmp3_;
	_g_free0 (_data_->_tmp1_);
	_g_object_unref0 (_data_->parser);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!_data_->_task_complete_) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

/**
   * Uses element's {@link GomDocument} to write an XML to a file, serializing it.
   */
static void
gxml_gom_element_real_write_file (GXmlDomElement* base,
                                  GFile* f,
                                  GCancellable* cancellable,
                                  GError** error)
{
	GXmlGomElement * self;
	GXmlDomDocument* _tmp0_;
	GXmlDomDocument* _tmp1_;
	GError* _inner_error0_ = NULL;
	self = (GXmlGomElement*) base;
	g_return_if_fail (f != NULL);
	_tmp0_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) self);
	_tmp1_ = _tmp0_;
	gxml_dom_document_write_file ((GXmlDomDocument*) (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GXML_TYPE_GOM_DOCUMENT) ? ((GXmlGomDocument*) _tmp1_) : NULL), f, NULL, &_inner_error0_);
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		return;
	}
}

static void
gxml_gom_element_real_write_file_async_data_free (gpointer _data)
{
	GxmlGomElementWriteFileAsyncData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->f);
	_g_object_unref0 (_data_->cancellable);
	_g_object_unref0 (_data_->self);
	g_slice_free (GxmlGomElementWriteFileAsyncData, _data_);
}

static void
gxml_gom_element_real_write_file_async_async_ready_wrapper (GObject *source_object,
                                                            GAsyncResult *res,
                                                            void *user_data)
{
	GxmlGomElementWriteFileAsyncData* _task_data_;
	_task_data_ = g_task_get_task_data (G_TASK (res));
	if (_task_data_->_callback_ != NULL) {
		_task_data_->_callback_ (source_object, res, user_data);
	}
	_task_data_->_task_complete_ = TRUE;
}

static void
gxml_gom_element_real_write_file_async (GXmlDomElement* base,
                                        GFile* f,
                                        GCancellable* cancellable,
                                        GAsyncReadyCallback _callback_,
                                        gpointer _user_data_)
{
	GXmlGomElement * self;
	GxmlGomElementWriteFileAsyncData* _data_;
	GXmlGomElement* _tmp0_;
	GFile* _tmp1_;
	GCancellable* _tmp2_;
	self = (GXmlGomElement*) base;
	_data_ = g_slice_new0 (GxmlGomElementWriteFileAsyncData);
	_data_->_callback_ = _callback_;
	_data_->_async_result = g_task_new (G_OBJECT (self), cancellable, gxml_gom_element_real_write_file_async_async_ready_wrapper, _user_data_);
	if (_callback_ == NULL) {
		_data_->_task_complete_ = TRUE;
	}
	g_task_set_task_data (_data_->_async_result, _data_, gxml_gom_element_real_write_file_async_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (f);
	_g_object_unref0 (_data_->f);
	_data_->f = _tmp1_;
	_tmp2_ = _g_object_ref0 (cancellable);
	_g_object_unref0 (_data_->cancellable);
	_data_->cancellable = _tmp2_;
	gxml_gom_element_real_write_file_async_co (_data_);
}

static void
gxml_gom_element_write_file_finish (GXmlDomElement* base,
                                    GAsyncResult* _res_,
                                    GError** error)
{
	GxmlGomElementWriteFileAsyncData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), error);
	if (NULL == _data_) {
		return;
	}
}

/**
   * Uses element's {@link GomDocument} to write asynchronically an XML to a file, serializing it.
   */
static void
gxml_gom_element_write_file_async_ready (GObject* source_object,
                                         GAsyncResult* _res_,
                                         gpointer _user_data_)
{
	GxmlGomElementWriteFileAsyncData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	_data_->_task_complete_ = TRUE;
	gxml_gom_element_real_write_file_async_co (_data_);
}

static gboolean
gxml_gom_element_real_write_file_async_co (GxmlGomElementWriteFileAsyncData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _data_->self);
	_data_->_tmp1_ = _data_->_tmp0_;
	_data_->_state_ = 1;
	gxml_dom_document_write_file_async ((GXmlDomDocument*) (G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp1_, GXML_TYPE_GOM_DOCUMENT) ? ((GXmlGomDocument*) _data_->_tmp1_) : NULL), _data_->f, NULL, gxml_gom_element_write_file_async_ready, _data_);
	return FALSE;
	_state_1:
	gxml_dom_document_write_file_finish ((GXmlDomDocument*) (G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp1_, GXML_TYPE_GOM_DOCUMENT) ? ((GXmlGomDocument*) _data_->_tmp1_) : NULL), _data_->_res_, &_data_->_inner_error0_);
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!_data_->_task_complete_) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

/**
   * Uses element's {@link GomDocument} to write an XML to a stream, serializing it.
   */
static void
gxml_gom_element_real_write_stream (GXmlDomElement* base,
                                    GOutputStream* stream,
                                    GError** error)
{
	GXmlGomElement * self;
	GXmlDomDocument* _tmp0_;
	GXmlDomDocument* _tmp1_;
	GError* _inner_error0_ = NULL;
	self = (GXmlGomElement*) base;
	g_return_if_fail (stream != NULL);
	_tmp0_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) self);
	_tmp1_ = _tmp0_;
	gxml_dom_document_write_stream ((GXmlDomDocument*) (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GXML_TYPE_GOM_DOCUMENT) ? ((GXmlGomDocument*) _tmp1_) : NULL), stream, NULL, &_inner_error0_);
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		return;
	}
}

static void
gxml_gom_element_real_write_stream_async_data_free (gpointer _data)
{
	GxmlGomElementWriteStreamAsyncData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->stream);
	_g_object_unref0 (_data_->cancellable);
	_g_object_unref0 (_data_->self);
	g_slice_free (GxmlGomElementWriteStreamAsyncData, _data_);
}

static void
gxml_gom_element_real_write_stream_async_async_ready_wrapper (GObject *source_object,
                                                              GAsyncResult *res,
                                                              void *user_data)
{
	GxmlGomElementWriteStreamAsyncData* _task_data_;
	_task_data_ = g_task_get_task_data (G_TASK (res));
	if (_task_data_->_callback_ != NULL) {
		_task_data_->_callback_ (source_object, res, user_data);
	}
	_task_data_->_task_complete_ = TRUE;
}

static void
gxml_gom_element_real_write_stream_async (GXmlDomElement* base,
                                          GOutputStream* stream,
                                          GCancellable* cancellable,
                                          GAsyncReadyCallback _callback_,
                                          gpointer _user_data_)
{
	GXmlGomElement * self;
	GxmlGomElementWriteStreamAsyncData* _data_;
	GXmlGomElement* _tmp0_;
	GOutputStream* _tmp1_;
	GCancellable* _tmp2_;
	self = (GXmlGomElement*) base;
	_data_ = g_slice_new0 (GxmlGomElementWriteStreamAsyncData);
	_data_->_callback_ = _callback_;
	_data_->_async_result = g_task_new (G_OBJECT (self), cancellable, gxml_gom_element_real_write_stream_async_async_ready_wrapper, _user_data_);
	if (_callback_ == NULL) {
		_data_->_task_complete_ = TRUE;
	}
	g_task_set_task_data (_data_->_async_result, _data_, gxml_gom_element_real_write_stream_async_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (stream);
	_g_object_unref0 (_data_->stream);
	_data_->stream = _tmp1_;
	_tmp2_ = _g_object_ref0 (cancellable);
	_g_object_unref0 (_data_->cancellable);
	_data_->cancellable = _tmp2_;
	gxml_gom_element_real_write_stream_async_co (_data_);
}

static void
gxml_gom_element_write_stream_finish (GXmlDomElement* base,
                                      GAsyncResult* _res_,
                                      GError** error)
{
	GxmlGomElementWriteStreamAsyncData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), error);
	if (NULL == _data_) {
		return;
	}
}

/**
   * Uses element's {@link GomDocument} to write an XML to a stream, serializing it.
   */
static void
gxml_gom_element_write_stream_async_ready (GObject* source_object,
                                           GAsyncResult* _res_,
                                           gpointer _user_data_)
{
	GxmlGomElementWriteStreamAsyncData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	_data_->_task_complete_ = TRUE;
	gxml_gom_element_real_write_stream_async_co (_data_);
}

static gboolean
gxml_gom_element_real_write_stream_async_co (GxmlGomElementWriteStreamAsyncData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _data_->self);
	_data_->_tmp1_ = _data_->_tmp0_;
	_data_->_state_ = 1;
	gxml_dom_document_write_stream_async ((GXmlDomDocument*) (G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp1_, GXML_TYPE_GOM_DOCUMENT) ? ((GXmlGomDocument*) _data_->_tmp1_) : NULL), _data_->stream, NULL, gxml_gom_element_write_stream_async_ready, _data_);
	return FALSE;
	_state_1:
	gxml_dom_document_write_stream_finish ((GXmlDomDocument*) (G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp1_, GXML_TYPE_GOM_DOCUMENT) ? ((GXmlGomDocument*) _data_->_tmp1_) : NULL), _data_->_res_, &_data_->_inner_error0_);
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!_data_->_task_complete_) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

/**
   * Creates an {@link GLib.InputStream} to write a string representation
   * in XML of {@link GomElement} using node's {@link GomDocument}
   */
static GInputStream*
gxml_gom_element_real_create_stream (GXmlDomElement* base,
                                     GError** error)
{
	GXmlGomElement * self;
	GInputStream* result = NULL;
	GInputStream* _tmp0_ = NULL;
	GXmlDomDocument* _tmp1_;
	GXmlDomDocument* _tmp2_;
	GInputStream* _tmp3_;
	GInputStream* _tmp4_;
	GError* _inner_error0_ = NULL;
	self = (GXmlGomElement*) base;
	_tmp1_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) self);
	_tmp2_ = _tmp1_;
	_tmp3_ = gxml_dom_document_create_stream ((GXmlDomDocument*) (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, GXML_TYPE_GOM_DOCUMENT) ? ((GXmlGomDocument*) _tmp2_) : NULL), &_inner_error0_);
	_tmp0_ = _tmp3_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	_tmp4_ = _tmp0_;
	_tmp0_ = NULL;
	result = _tmp4_;
	_g_object_unref0 (_tmp0_);
	return result;
}

static void
gxml_gom_element_real_create_stream_async_data_free (gpointer _data)
{
	GxmlGomElementCreateStreamAsyncData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->cancellable);
	_g_object_unref0 (_data_->result);
	_g_object_unref0 (_data_->self);
	g_slice_free (GxmlGomElementCreateStreamAsyncData, _data_);
}

static void
gxml_gom_element_real_create_stream_async_async_ready_wrapper (GObject *source_object,
                                                               GAsyncResult *res,
                                                               void *user_data)
{
	GxmlGomElementCreateStreamAsyncData* _task_data_;
	_task_data_ = g_task_get_task_data (G_TASK (res));
	if (_task_data_->_callback_ != NULL) {
		_task_data_->_callback_ (source_object, res, user_data);
	}
	_task_data_->_task_complete_ = TRUE;
}

static void
gxml_gom_element_real_create_stream_async (GXmlDomElement* base,
                                           GCancellable* cancellable,
                                           GAsyncReadyCallback _callback_,
                                           gpointer _user_data_)
{
	GXmlGomElement * self;
	GxmlGomElementCreateStreamAsyncData* _data_;
	GXmlGomElement* _tmp0_;
	GCancellable* _tmp1_;
	self = (GXmlGomElement*) base;
	_data_ = g_slice_new0 (GxmlGomElementCreateStreamAsyncData);
	_data_->_callback_ = _callback_;
	_data_->_async_result = g_task_new (G_OBJECT (self), cancellable, gxml_gom_element_real_create_stream_async_async_ready_wrapper, _user_data_);
	if (_callback_ == NULL) {
		_data_->_task_complete_ = TRUE;
	}
	g_task_set_task_data (_data_->_async_result, _data_, gxml_gom_element_real_create_stream_async_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (cancellable);
	_g_object_unref0 (_data_->cancellable);
	_data_->cancellable = _tmp1_;
	gxml_gom_element_real_create_stream_async_co (_data_);
}

static GInputStream*
gxml_gom_element_create_stream_finish (GXmlDomElement* base,
                                       GAsyncResult* _res_,
                                       GError** error)
{
	GInputStream* result;
	GxmlGomElementCreateStreamAsyncData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), error);
	if (NULL == _data_) {
		return NULL;
	}
	result = _data_->result;
	_data_->result = NULL;
	return result;
}

/**
   * Creates an {@link GLib.InputStream} to write a string representation
   * in XML of {@link GomElement} using node's {@link GomDocument}
   */
static void
gxml_gom_element_create_stream_async_ready (GObject* source_object,
                                            GAsyncResult* _res_,
                                            gpointer _user_data_)
{
	GxmlGomElementCreateStreamAsyncData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	_data_->_task_complete_ = TRUE;
	gxml_gom_element_real_create_stream_async_co (_data_);
}

static gboolean
gxml_gom_element_real_create_stream_async_co (GxmlGomElementCreateStreamAsyncData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp1_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _data_->self);
	_data_->_tmp2_ = _data_->_tmp1_;
	_data_->_state_ = 1;
	gxml_dom_document_create_stream_async ((GXmlDomDocument*) (G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp2_, GXML_TYPE_GOM_DOCUMENT) ? ((GXmlGomDocument*) _data_->_tmp2_) : NULL), NULL, gxml_gom_element_create_stream_async_ready, _data_);
	return FALSE;
	_state_1:
	_data_->_tmp3_ = gxml_dom_document_create_stream_finish ((GXmlDomDocument*) (G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp2_, GXML_TYPE_GOM_DOCUMENT) ? ((GXmlGomDocument*) _data_->_tmp2_) : NULL), _data_->_res_, &_data_->_inner_error0_);
	_data_->_tmp0_ = _data_->_tmp3_;
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->_tmp4_ = _data_->_tmp0_;
	_data_->_tmp0_ = NULL;
	_data_->result = _data_->_tmp4_;
	_g_object_unref0 (_data_->_tmp0_);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!_data_->_task_complete_) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static gboolean
string_contains (const gchar* self,
                 const gchar* needle)
{
	gboolean result = FALSE;
	gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, FALSE);
	g_return_val_if_fail (needle != NULL, FALSE);
	_tmp0_ = strstr ((gchar*) self, (gchar*) needle);
	result = _tmp0_ != NULL;
	return result;
}

gchar*
gxml_gom_element_lookup_prefix (GXmlGomElement* self,
                                const gchar* nspace)
{
	gchar* result = NULL;
	const gchar* _tmp0_;
	GXmlDomNode* _tmp32_;
	GXmlDomNode* _tmp33_;
	GXmlDomNode* _tmp34_;
	gboolean _tmp35_;
	GXmlDomNode* _tmp36_;
	GXmlDomNode* _tmp37_;
	GXmlDomNode* _tmp38_;
	gchar* _tmp39_;
	gchar* _tmp40_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->_namespace_uri;
	if (g_strcmp0 (_tmp0_, nspace) == 0) {
		const gchar* _tmp1_;
		gchar* _tmp2_;
		_tmp1_ = ((GXmlGomNode*) self)->_prefix;
		_tmp2_ = g_strdup (_tmp1_);
		result = _tmp2_;
		return result;
	}
	{
		GeeIterator* _k_it = NULL;
		GXmlGomElementAttributes* _tmp3_;
		GeeSet* _tmp4_;
		GeeSet* _tmp5_;
		GeeSet* _tmp6_;
		GeeIterator* _tmp7_;
		GeeIterator* _tmp8_;
		_tmp3_ = self->_attributes;
		_tmp4_ = gee_abstract_map_get_keys ((GeeAbstractMap*) _tmp3_);
		_tmp5_ = _tmp4_;
		_tmp6_ = _tmp5_;
		_tmp7_ = gee_iterable_iterator ((GeeIterable*) _tmp6_);
		_tmp8_ = _tmp7_;
		_g_object_unref0 (_tmp6_);
		_k_it = _tmp8_;
		while (TRUE) {
			GeeIterator* _tmp9_;
			gchar* k = NULL;
			GeeIterator* _tmp10_;
			gpointer _tmp11_;
			const gchar* _tmp12_;
			gchar* ns_uri = NULL;
			GXmlDomAttr* prop = NULL;
			GXmlGomElementAttributes* _tmp13_;
			const gchar* _tmp14_;
			gpointer _tmp15_;
			GXmlDomNode* _tmp16_;
			GXmlDomAttr* _tmp17_;
			GXmlDomAttr* _tmp18_;
			const gchar* _tmp22_;
			const gchar* _tmp23_;
			_tmp9_ = _k_it;
			if (!gee_iterator_next (_tmp9_)) {
				break;
			}
			_tmp10_ = _k_it;
			_tmp11_ = gee_iterator_get (_tmp10_);
			k = (gchar*) _tmp11_;
			_tmp12_ = k;
			if (!string_contains (_tmp12_, "xmlns")) {
				_g_free0 (k);
				continue;
			}
			ns_uri = NULL;
			_tmp13_ = self->_attributes;
			_tmp14_ = k;
			_tmp15_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp13_, _tmp14_);
			_tmp16_ = (GXmlDomNode*) _tmp15_;
			_tmp17_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp16_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp16_) : NULL;
			if (_tmp17_ == NULL) {
				_g_object_unref0 (_tmp16_);
			}
			prop = _tmp17_;
			_tmp18_ = prop;
			if (_tmp18_ != NULL) {
				GXmlDomAttr* _tmp19_;
				gchar* _tmp20_;
				gchar* _tmp21_;
				_tmp19_ = prop;
				_tmp20_ = gxml_dom_attr_get_value (_tmp19_);
				_tmp21_ = _tmp20_;
				_g_free0 (ns_uri);
				ns_uri = _tmp21_;
			}
			_tmp22_ = ns_uri;
			if (_tmp22_ == NULL) {
				g_warning ("GomElement.vala:169: %s", _ ("Invalid namespace URI stored in element's attribute"));
				result = NULL;
				_g_object_unref0 (prop);
				_g_free0 (ns_uri);
				_g_free0 (k);
				_g_object_unref0 (_k_it);
				return result;
			}
			_tmp23_ = ns_uri;
			if (g_strcmp0 (_tmp23_, nspace) == 0) {
				const gchar* _tmp24_;
				_tmp24_ = k;
				if (string_contains (_tmp24_, ":")) {
					gchar** sa = NULL;
					const gchar* _tmp25_;
					gchar** _tmp26_;
					gchar** _tmp27_;
					gint sa_length1;
					gint _sa_size_;
					gchar** _tmp28_;
					gint _tmp28__length1;
					gchar** _tmp29_;
					gint _tmp29__length1;
					const gchar* _tmp30_;
					gchar* _tmp31_;
					_tmp25_ = k;
					_tmp27_ = _tmp26_ = g_strsplit (_tmp25_, ":", 0);
					sa = _tmp27_;
					sa_length1 = _vala_array_length (_tmp26_);
					_sa_size_ = sa_length1;
					_tmp28_ = sa;
					_tmp28__length1 = sa_length1;
					if (_tmp28__length1 > 2) {
						g_warning ("GomElement.vala:176: %s", _ ("Invalid attribute name in element's attributes list"));
						result = NULL;
						sa = (_vala_array_free (sa, sa_length1, (GDestroyNotify) g_free), NULL);
						_g_object_unref0 (prop);
						_g_free0 (ns_uri);
						_g_free0 (k);
						_g_object_unref0 (_k_it);
						return result;
					}
					_tmp29_ = sa;
					_tmp29__length1 = sa_length1;
					_tmp30_ = _tmp29_[1];
					_tmp31_ = g_strdup (_tmp30_);
					result = _tmp31_;
					sa = (_vala_array_free (sa, sa_length1, (GDestroyNotify) g_free), NULL);
					_g_object_unref0 (prop);
					_g_free0 (ns_uri);
					_g_free0 (k);
					_g_object_unref0 (_k_it);
					return result;
				}
			}
			_g_object_unref0 (prop);
			_g_free0 (ns_uri);
			_g_free0 (k);
		}
		_g_object_unref0 (_k_it);
	}
	_tmp32_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
	_tmp33_ = _tmp32_;
	_tmp34_ = _tmp33_;
	_tmp35_ = _tmp34_ == NULL;
	_g_object_unref0 (_tmp34_);
	if (_tmp35_) {
		result = NULL;
		return result;
	}
	_tmp36_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
	_tmp37_ = _tmp36_;
	_tmp38_ = _tmp37_;
	_tmp39_ = gxml_dom_node_lookup_prefix (_tmp38_, nspace);
	_tmp40_ = _tmp39_;
	_g_object_unref0 (_tmp38_);
	result = _tmp40_;
	return result;
}

gchar*
gxml_gom_element_lookup_namespace_uri (GXmlGomElement* self,
                                       const gchar* prefix)
{
	gchar* result = NULL;
	GXmlDomNode* _tmp30_;
	GXmlDomNode* _tmp31_;
	GXmlDomNode* _tmp32_;
	gboolean _tmp33_;
	GXmlDomNode* _tmp34_;
	GXmlDomNode* _tmp35_;
	GXmlDomNode* _tmp36_;
	gchar* _tmp37_;
	gchar* _tmp38_;
	g_return_val_if_fail (self != NULL, NULL);
	{
		GeeIterator* _k_it = NULL;
		GXmlDomNamedNodeMap* _tmp0_;
		GXmlDomNamedNodeMap* _tmp1_;
		GXmlDomNamedNodeMap* _tmp2_;
		GeeSet* _tmp3_;
		GeeSet* _tmp4_;
		GeeSet* _tmp5_;
		GeeIterator* _tmp6_;
		GeeIterator* _tmp7_;
		_tmp0_ = gxml_dom_element_get_attributes ((GXmlDomElement*) self);
		_tmp1_ = _tmp0_;
		_tmp2_ = _tmp1_;
		_tmp3_ = gee_map_get_keys ((GeeMap*) _tmp2_);
		_tmp4_ = _tmp3_;
		_tmp5_ = _tmp4_;
		_tmp6_ = gee_iterable_iterator ((GeeIterable*) _tmp5_);
		_tmp7_ = _tmp6_;
		_g_object_unref0 (_tmp5_);
		_g_object_unref0 (_tmp2_);
		_k_it = _tmp7_;
		while (TRUE) {
			GeeIterator* _tmp8_;
			gchar* k = NULL;
			GeeIterator* _tmp9_;
			gpointer _tmp10_;
			const gchar* _tmp11_;
			GXmlDomAttr* p = NULL;
			GXmlGomElementAttributes* _tmp12_;
			const gchar* _tmp13_;
			gpointer _tmp14_;
			GXmlDomNode* _tmp15_;
			GXmlDomAttr* _tmp16_;
			gchar* nsp = NULL;
			GXmlDomAttr* _tmp17_;
			gboolean _tmp21_ = FALSE;
			const gchar* _tmp23_;
			_tmp8_ = _k_it;
			if (!gee_iterator_next (_tmp8_)) {
				break;
			}
			_tmp9_ = _k_it;
			_tmp10_ = gee_iterator_get (_tmp9_);
			k = (gchar*) _tmp10_;
			_tmp11_ = k;
			if (!string_contains (_tmp11_, "xmlns")) {
				_g_free0 (k);
				continue;
			}
			_tmp12_ = self->_attributes;
			_tmp13_ = k;
			_tmp14_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp12_, _tmp13_);
			_tmp15_ = (GXmlDomNode*) _tmp14_;
			_tmp16_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp15_) : NULL;
			if (_tmp16_ == NULL) {
				_g_object_unref0 (_tmp15_);
			}
			p = _tmp16_;
			nsp = NULL;
			_tmp17_ = p;
			if (_tmp17_ != NULL) {
				GXmlDomAttr* _tmp18_;
				gchar* _tmp19_;
				gchar* _tmp20_;
				_tmp18_ = p;
				_tmp19_ = gxml_dom_attr_get_value (_tmp18_);
				_tmp20_ = _tmp19_;
				_g_free0 (nsp);
				nsp = _tmp20_;
			}
			if (prefix == NULL) {
				const gchar* _tmp22_;
				_tmp22_ = k;
				_tmp21_ = g_strcmp0 (_tmp22_, "xmlns") == 0;
			} else {
				_tmp21_ = FALSE;
			}
			if (_tmp21_) {
				result = nsp;
				_g_object_unref0 (p);
				_g_free0 (k);
				_g_object_unref0 (_k_it);
				return result;
			}
			_tmp23_ = k;
			if (string_contains (_tmp23_, ":")) {
				gchar** sa = NULL;
				const gchar* _tmp24_;
				gchar** _tmp25_;
				gchar** _tmp26_;
				gint sa_length1;
				gint _sa_size_;
				gchar** _tmp27_;
				gint _tmp27__length1;
				gchar** _tmp28_;
				gint _tmp28__length1;
				const gchar* _tmp29_;
				_tmp24_ = k;
				_tmp26_ = _tmp25_ = g_strsplit (_tmp24_, ":", 0);
				sa = _tmp26_;
				sa_length1 = _vala_array_length (_tmp25_);
				_sa_size_ = sa_length1;
				_tmp27_ = sa;
				_tmp27__length1 = sa_length1;
				if (_tmp27__length1 != 2) {
					g_warning ("GomElement.vala:198: %s", _ ("Invalid attribute name in element's attributes list"));
					result = NULL;
					sa = (_vala_array_free (sa, sa_length1, (GDestroyNotify) g_free), NULL);
					_g_free0 (nsp);
					_g_object_unref0 (p);
					_g_free0 (k);
					_g_object_unref0 (_k_it);
					return result;
				}
				_tmp28_ = sa;
				_tmp28__length1 = sa_length1;
				_tmp29_ = _tmp28_[1];
				if (g_strcmp0 (prefix, _tmp29_) == 0) {
					result = nsp;
					sa = (_vala_array_free (sa, sa_length1, (GDestroyNotify) g_free), NULL);
					_g_object_unref0 (p);
					_g_free0 (k);
					_g_object_unref0 (_k_it);
					return result;
				}
				sa = (_vala_array_free (sa, sa_length1, (GDestroyNotify) g_free), NULL);
			}
			_g_free0 (nsp);
			_g_object_unref0 (p);
			_g_free0 (k);
		}
		_g_object_unref0 (_k_it);
	}
	_tmp30_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
	_tmp31_ = _tmp30_;
	_tmp32_ = _tmp31_;
	_tmp33_ = _tmp32_ == NULL;
	_g_object_unref0 (_tmp32_);
	if (_tmp33_) {
		result = NULL;
		return result;
	}
	_tmp34_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
	_tmp35_ = _tmp34_;
	_tmp36_ = _tmp35_;
	_tmp37_ = gxml_dom_node_lookup_namespace_uri (_tmp36_, prefix);
	_tmp38_ = _tmp37_;
	_g_object_unref0 (_tmp36_);
	result = _tmp38_;
	return result;
}

static void
gxml_gom_element_real_remove (GXmlDomChildNode* base)
{
	GXmlGomElement * self;
	GXmlDomNode* _tmp0_;
	GXmlDomNode* _tmp1_;
	GXmlDomNode* _tmp2_;
	gboolean _tmp3_;
	self = (GXmlGomElement*) base;
	_tmp0_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_ != NULL;
	_g_object_unref0 (_tmp2_);
	if (_tmp3_) {
		gint i = 0;
		GXmlDomNode* _tmp4_;
		GXmlDomNode* _tmp5_;
		GXmlDomNode* _tmp6_;
		GXmlDomNodeList* _tmp7_;
		GXmlDomNodeList* _tmp8_;
		GXmlDomNodeList* _tmp9_;
		gint _tmp10_;
		gboolean _tmp11_ = FALSE;
		GXmlDomNode* _tmp20_;
		GXmlDomNode* _tmp21_;
		GXmlDomNode* _tmp22_;
		GXmlDomNodeList* _tmp23_;
		GXmlDomNodeList* _tmp24_;
		GXmlDomNodeList* _tmp25_;
		gpointer _tmp26_;
		GXmlDomNode* _tmp27_;
		_tmp4_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
		_tmp5_ = _tmp4_;
		_tmp6_ = _tmp5_;
		_tmp7_ = gxml_dom_node_get_child_nodes (_tmp6_);
		_tmp8_ = _tmp7_;
		_tmp9_ = _tmp8_;
		_tmp10_ = gee_list_index_of ((GeeList*) _tmp9_, (GXmlDomNode*) self);
		_g_object_unref0 (_tmp9_);
		_g_object_unref0 (_tmp6_);
		i = _tmp10_;
		if (i < 0) {
			_tmp11_ = TRUE;
		} else {
			GXmlDomNode* _tmp12_;
			GXmlDomNode* _tmp13_;
			GXmlDomNode* _tmp14_;
			GXmlDomNodeList* _tmp15_;
			GXmlDomNodeList* _tmp16_;
			GXmlDomNodeList* _tmp17_;
			gint _tmp18_;
			gint _tmp19_;
			_tmp12_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
			_tmp13_ = _tmp12_;
			_tmp14_ = _tmp13_;
			_tmp15_ = gxml_dom_node_get_child_nodes (_tmp14_);
			_tmp16_ = _tmp15_;
			_tmp17_ = _tmp16_;
			_tmp18_ = gxml_dom_node_list_get_length (_tmp17_);
			_tmp19_ = _tmp18_;
			_tmp11_ = i > _tmp19_;
			_g_object_unref0 (_tmp17_);
			_g_object_unref0 (_tmp14_);
		}
		if (_tmp11_) {
			g_warning ("GomElement.vala:213: %s", _ ("Can't locate child node to remove"));
		}
		_tmp20_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
		_tmp21_ = _tmp20_;
		_tmp22_ = _tmp21_;
		_tmp23_ = gxml_dom_node_get_child_nodes (_tmp22_);
		_tmp24_ = _tmp23_;
		_tmp25_ = _tmp24_;
		_tmp26_ = gee_list_remove_at ((GeeList*) _tmp25_, i);
		_tmp27_ = (GXmlDomNode*) _tmp26_;
		_g_object_unref0 (_tmp27_);
		_g_object_unref0 (_tmp25_);
		_g_object_unref0 (_tmp22_);
	}
}

static GXmlDomNodeList*
gxml_gom_element_real_query_selector_all (GXmlDomParentNode* base,
                                          const gchar* selectors,
                                          GError** error)
{
	GXmlGomElement * self;
	GXmlDomNodeList* result = NULL;
	GXmlCssSelectorParser* cs = NULL;
	GXmlCssSelectorParser* _tmp0_;
	GXmlCssSelectorParser* _tmp1_;
	GXmlDomNodeList* _tmp2_ = NULL;
	GXmlCssSelectorParser* _tmp3_;
	GXmlDomNodeList* _tmp4_;
	GXmlDomNodeList* _tmp5_;
	GError* _inner_error0_ = NULL;
	self = (GXmlGomElement*) base;
	g_return_val_if_fail (selectors != NULL, NULL);
	_tmp0_ = gxml_css_selector_parser_new ();
	cs = _tmp0_;
	_tmp1_ = cs;
	gxml_css_selector_parser_parse (_tmp1_, selectors, &_inner_error0_);
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (cs);
		return NULL;
	}
	_tmp3_ = cs;
	_tmp4_ = gxml_css_selector_parser_query_selector_all (_tmp3_, (GXmlDomElement*) self, &_inner_error0_);
	_tmp2_ = _tmp4_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (cs);
		return NULL;
	}
	_tmp5_ = _tmp2_;
	_tmp2_ = NULL;
	result = _tmp5_;
	_g_object_unref0 (_tmp2_);
	_g_object_unref0 (cs);
	return result;
}

/**
   * Convenient function to initialize, at construction time, a {@link GomElement}
   * using given local name. If {@link GomElement.initialize_with_namespace}
   * has been called in any base class, this method just change elment node's name
   * and keeps previous namespace and prefix.
   *
   * No {@link DomDocument} is set by default, if this is a top level element in a
   * document, you can call {@link DomNode.owner_document} to set one if not set
   * already.
   *
   * Any instance properties of type {@link GomElement} or {@link Collection}
   * should be initialized using {@link GomObject.set_instance_property}
   */
void
gxml_gom_element_initialize (GXmlGomElement* self,
                             const gchar* local_name)
{
	gchar* _tmp0_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (local_name != NULL);
	_tmp0_ = g_strdup (local_name);
	_g_free0 (((GXmlGomNode*) self)->_local_name);
	((GXmlGomNode*) self)->_local_name = _tmp0_;
}

/**
   * Convenient function to initialize, at construction time, a {@link GomElement}
   * using given local name and document.
   */
void
gxml_gom_element_initialize_document (GXmlGomElement* self,
                                      GXmlDomDocument* doc,
                                      const gchar* local_name)
{
	GXmlDomDocument* _tmp0_;
	gchar* _tmp1_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (doc != NULL);
	g_return_if_fail (local_name != NULL);
	_tmp0_ = _g_object_ref0 (doc);
	_g_object_unref0 (((GXmlGomNode*) self)->_document);
	((GXmlGomNode*) self)->_document = _tmp0_;
	_tmp1_ = g_strdup (local_name);
	_g_free0 (((GXmlGomNode*) self)->_local_name);
	((GXmlGomNode*) self)->_local_name = _tmp1_;
}

/**
   * Convenient function to initialize, at construction time, a {@link GomElement}
   * using given local name and namespace.
   */
void
gxml_gom_element_initialize_with_namespace (GXmlGomElement* self,
                                            const gchar* namespace_uri,
                                            const gchar* prefix,
                                            const gchar* local_name)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (local_name != NULL);
	_tmp0_ = g_strdup (local_name);
	_g_free0 (((GXmlGomNode*) self)->_local_name);
	((GXmlGomNode*) self)->_local_name = _tmp0_;
	_tmp1_ = g_strdup (namespace_uri);
	_g_free0 (self->_namespace_uri);
	self->_namespace_uri = _tmp1_;
	_tmp2_ = g_strdup (prefix);
	_g_free0 (((GXmlGomNode*) self)->_prefix);
	((GXmlGomNode*) self)->_prefix = _tmp2_;
}

/**
   * Convenient function to initialize, at construction time, a {@link GomElement}
   * using given local name, document and namespace.
   */
void
gxml_gom_element_initialize_document_with_namespace (GXmlGomElement* self,
                                                     GXmlDomDocument* doc,
                                                     const gchar* namespace_uri,
                                                     const gchar* prefix,
                                                     const gchar* local_name)
{
	GXmlDomDocument* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (doc != NULL);
	g_return_if_fail (local_name != NULL);
	_tmp0_ = _g_object_ref0 (doc);
	_g_object_unref0 (((GXmlGomNode*) self)->_document);
	((GXmlGomNode*) self)->_document = _tmp0_;
	_tmp1_ = g_strdup (local_name);
	_g_free0 (((GXmlGomNode*) self)->_local_name);
	((GXmlGomNode*) self)->_local_name = _tmp1_;
	_tmp2_ = g_strdup (namespace_uri);
	_g_free0 (self->_namespace_uri);
	self->_namespace_uri = _tmp2_;
	_tmp3_ = g_strdup (prefix);
	_g_free0 (((GXmlGomNode*) self)->_prefix);
	((GXmlGomNode*) self)->_prefix = _tmp3_;
}

static gchar*
gxml_gom_element_real_get_attribute (GXmlDomElement* base,
                                     const gchar* name)
{
	GXmlGomElement * self;
	gchar* result = NULL;
	gchar* str = NULL;
	GXmlDomAttr* prop = NULL;
	GXmlGomElementAttributes* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gpointer _tmp3_;
	GXmlDomNode* _tmp4_;
	GXmlDomAttr* _tmp5_;
	GXmlDomAttr* _tmp6_;
	GXmlDomAttr* _tmp7_;
	self = (GXmlGomElement*) base;
	g_return_val_if_fail (name != NULL, NULL);
	str = NULL;
	_tmp0_ = self->_attributes;
	_tmp1_ = g_utf8_strdown (name, (gssize) -1);
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp0_, _tmp2_);
	_tmp4_ = (GXmlDomNode*) _tmp3_;
	_tmp5_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp4_) : NULL;
	if (_tmp5_ == NULL) {
		_g_object_unref0 (_tmp4_);
	}
	_tmp6_ = _tmp5_;
	_g_free0 (_tmp2_);
	prop = _tmp6_;
	_tmp7_ = prop;
	if (_tmp7_ != NULL) {
		GXmlDomAttr* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		_tmp8_ = prop;
		_tmp9_ = gxml_dom_attr_get_value (_tmp8_);
		_tmp10_ = _tmp9_;
		_g_free0 (str);
		str = _tmp10_;
	}
	result = str;
	_g_object_unref0 (prop);
	return result;
}

static gchar*
gxml_gom_element_real_get_attribute_ns (GXmlDomElement* base,
                                        const gchar* namespace_uri,
                                        const gchar* local_name)
{
	GXmlGomElement * self;
	gchar* result = NULL;
	gchar* nsp = NULL;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gchar* name = NULL;
	gchar* _tmp4_;
	const gchar* _tmp5_;
	gchar* val = NULL;
	GXmlDomAttr* prop = NULL;
	GXmlGomElementAttributes* _tmp10_;
	const gchar* _tmp11_;
	gpointer _tmp12_;
	GXmlDomNode* _tmp13_;
	GXmlDomAttr* _tmp14_;
	GXmlDomAttr* _tmp15_;
	self = (GXmlGomElement*) base;
	g_return_val_if_fail (local_name != NULL, NULL);
	nsp = NULL;
	if (g_strcmp0 (namespace_uri, "http://www.w3.org/2000/xmlns/") == 0) {
		_tmp1_ = TRUE;
	} else {
		_tmp1_ = g_strcmp0 (namespace_uri, "http://www.w3.org/2000/xmlns") == 0;
	}
	if (_tmp1_) {
		_tmp0_ = g_strcmp0 (local_name, "xmlns") != 0;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		gchar* _tmp2_;
		_tmp2_ = g_strdup ("xmlns");
		_g_free0 (nsp);
		nsp = _tmp2_;
	} else {
		gchar* _tmp3_;
		_tmp3_ = gxml_gom_element_lookup_prefix (self, namespace_uri);
		_g_free0 (nsp);
		nsp = _tmp3_;
	}
	_tmp4_ = g_strdup (local_name);
	name = _tmp4_;
	_tmp5_ = nsp;
	if (_tmp5_ != NULL) {
		const gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		_tmp6_ = nsp;
		_tmp7_ = g_strconcat (_tmp6_, ":", NULL);
		_tmp8_ = _tmp7_;
		_tmp9_ = g_strconcat (_tmp8_, local_name, NULL);
		_g_free0 (name);
		name = _tmp9_;
		_g_free0 (_tmp8_);
	}
	val = NULL;
	_tmp10_ = self->_attributes;
	_tmp11_ = name;
	_tmp12_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp10_, _tmp11_);
	_tmp13_ = (GXmlDomNode*) _tmp12_;
	_tmp14_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp13_) : NULL;
	if (_tmp14_ == NULL) {
		_g_object_unref0 (_tmp13_);
	}
	prop = _tmp14_;
	_tmp15_ = prop;
	if (_tmp15_ != NULL) {
		GXmlDomAttr* _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_;
		_tmp16_ = prop;
		_tmp17_ = gxml_dom_attr_get_value (_tmp16_);
		_tmp18_ = _tmp17_;
		_g_free0 (val);
		val = _tmp18_;
	}
	result = val;
	_g_object_unref0 (prop);
	_g_free0 (name);
	_g_free0 (nsp);
	return result;
}

static void
gxml_gom_element_real_set_attribute (GXmlDomElement* base,
                                     const gchar* name,
                                     const gchar* value,
                                     GError** error)
{
	GXmlGomElement * self;
	GXmlGomAttr* a = NULL;
	GXmlGomAttr* _tmp0_;
	GXmlDomNamedNodeMap* _tmp1_;
	GXmlDomNamedNodeMap* _tmp2_;
	GXmlDomNamedNodeMap* _tmp3_;
	GXmlDomNode* _tmp4_;
	GXmlDomNode* _tmp5_;
	GError* _inner_error0_ = NULL;
	self = (GXmlGomElement*) base;
	g_return_if_fail (name != NULL);
	g_return_if_fail (value != NULL);
	_tmp0_ = gxml_gom_attr_new ((GXmlDomElement*) self, name, value);
	a = _tmp0_;
	_tmp1_ = gxml_dom_element_get_attributes ((GXmlDomElement*) self);
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_;
	_tmp4_ = gxml_dom_named_node_map_set_named_item (_tmp3_, (GXmlDomNode*) a, &_inner_error0_);
	_tmp5_ = _tmp4_;
	_g_object_unref0 (_tmp5_);
	_g_object_unref0 (_tmp3_);
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (a);
		return;
	}
	_g_object_unref0 (a);
}

static void
gxml_gom_element_real_set_attribute_ns (GXmlDomElement* base,
                                        const gchar* namespace_uri,
                                        const gchar* name,
                                        const gchar* value,
                                        GError** error)
{
	GXmlGomElement * self;
	gchar* p = NULL;
	gchar* _tmp0_;
	gchar* n = NULL;
	gchar* _tmp1_;
	gboolean _tmp16_ = FALSE;
	gboolean _tmp19_ = FALSE;
	gboolean _tmp20_ = FALSE;
	const gchar* _tmp21_;
	gboolean _tmp23_ = FALSE;
	gboolean _tmp24_ = FALSE;
	const gchar* _tmp25_;
	gboolean _tmp27_ = FALSE;
	gboolean _tmp28_ = FALSE;
	const gchar* _tmp29_;
	gboolean _tmp33_ = FALSE;
	gboolean _tmp34_ = FALSE;
	const gchar* _tmp35_;
	GXmlGomAttr* a = NULL;
	const gchar* _tmp39_;
	const gchar* _tmp40_;
	GXmlGomAttr* _tmp41_;
	GError* _inner_error0_ = NULL;
	self = (GXmlGomElement*) base;
	g_return_if_fail (name != NULL);
	g_return_if_fail (value != NULL);
	_tmp0_ = g_strdup ("");
	p = _tmp0_;
	_tmp1_ = g_strdup (name);
	n = _tmp1_;
	if (string_contains (name, ":")) {
		gchar** s = NULL;
		gchar** _tmp2_;
		gchar** _tmp3_;
		gint s_length1;
		gint _s_size_;
		gchar** _tmp4_;
		gint _tmp4__length1;
		gchar** _tmp6_;
		gint _tmp6__length1;
		const gchar* _tmp7_;
		gchar* _tmp8_;
		gchar** _tmp9_;
		gint _tmp9__length1;
		const gchar* _tmp10_;
		gchar* _tmp11_;
		const gchar* _tmp12_;
		_tmp3_ = _tmp2_ = g_strsplit (name, ":", 0);
		s = _tmp3_;
		s_length1 = _vala_array_length (_tmp2_);
		_s_size_ = s_length1;
		_tmp4_ = s;
		_tmp4__length1 = s_length1;
		if (_tmp4__length1 != 2) {
			GError* _tmp5_;
			_tmp5_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _ ("Invalid attribute name. Just one prefix is allowed"));
			_inner_error0_ = _tmp5_;
			g_propagate_error (error, _inner_error0_);
			s = (_vala_array_free (s, s_length1, (GDestroyNotify) g_free), NULL);
			_g_free0 (n);
			_g_free0 (p);
			return;
		}
		_tmp6_ = s;
		_tmp6__length1 = s_length1;
		_tmp7_ = _tmp6_[0];
		_tmp8_ = g_strdup (_tmp7_);
		_g_free0 (p);
		p = _tmp8_;
		_tmp9_ = s;
		_tmp9__length1 = s_length1;
		_tmp10_ = _tmp9_[1];
		_tmp11_ = g_strdup (_tmp10_);
		_g_free0 (n);
		n = _tmp11_;
		_tmp12_ = n;
		if (string_contains (_tmp12_, ":")) {
			const gchar* _tmp13_;
			GError* _tmp14_;
			_tmp13_ = n;
			_tmp14_ = g_error_new (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _ ("Invalid attribute name. Invalid use of colon: %s"), _tmp13_);
			_inner_error0_ = _tmp14_;
			g_propagate_error (error, _inner_error0_);
			s = (_vala_array_free (s, s_length1, (GDestroyNotify) g_free), NULL);
			_g_free0 (n);
			_g_free0 (p);
			return;
		}
		s = (_vala_array_free (s, s_length1, (GDestroyNotify) g_free), NULL);
	} else {
		gchar* _tmp15_;
		_tmp15_ = g_strdup (name);
		_g_free0 (n);
		n = _tmp15_;
	}
	if (namespace_uri == NULL) {
		const gchar* _tmp17_;
		_tmp17_ = p;
		_tmp16_ = g_strcmp0 (_tmp17_, "") == 0;
	} else {
		_tmp16_ = FALSE;
	}
	if (_tmp16_) {
		GError* _tmp18_;
		_tmp18_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _ ("Invalid namespace. If prefix is null, namespace URI should not be null"));
		_inner_error0_ = _tmp18_;
		g_propagate_error (error, _inner_error0_);
		_g_free0 (n);
		_g_free0 (p);
		return;
	}
	_tmp21_ = p;
	if (g_strcmp0 (_tmp21_, "xml") == 0) {
		_tmp20_ = g_strcmp0 (namespace_uri, "http://www.w3.org/2000/xmlns/") != 0;
	} else {
		_tmp20_ = FALSE;
	}
	if (_tmp20_) {
		_tmp19_ = g_strcmp0 (namespace_uri, "http://www.w3.org/2000/xmlns") != 0;
	} else {
		_tmp19_ = FALSE;
	}
	if (_tmp19_) {
		GError* _tmp22_;
		_tmp22_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _ ("Invalid namespace. If prefix is xml, namespace URI should be http://ww" \
"w.w3.org/2000/xmlns"));
		_inner_error0_ = _tmp22_;
		g_propagate_error (error, _inner_error0_);
		_g_free0 (n);
		_g_free0 (p);
		return;
	}
	_tmp25_ = p;
	if (g_strcmp0 (_tmp25_, "xmlns") == 0) {
		_tmp24_ = g_strcmp0 (namespace_uri, "http://www.w3.org/2000/xmlns/") != 0;
	} else {
		_tmp24_ = FALSE;
	}
	if (_tmp24_) {
		_tmp23_ = g_strcmp0 (namespace_uri, "http://www.w3.org/2000/xmlns") != 0;
	} else {
		_tmp23_ = FALSE;
	}
	if (_tmp23_) {
		GError* _tmp26_;
		_tmp26_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _ ("Invalid namespace. If attribute's prefix is xmlns, namespace URI shoul" \
"d be http://www.w3.org/2000/xmlns"));
		_inner_error0_ = _tmp26_;
		g_propagate_error (error, _inner_error0_);
		_g_free0 (n);
		_g_free0 (p);
		return;
	}
	_tmp29_ = p;
	if (g_strcmp0 (_tmp29_, "") == 0) {
		const gchar* _tmp30_;
		_tmp30_ = n;
		_tmp28_ = g_strcmp0 (_tmp30_, "xmlns") == 0;
	} else {
		_tmp28_ = FALSE;
	}
	if (_tmp28_) {
		gboolean _tmp31_ = FALSE;
		if (g_strcmp0 (namespace_uri, "http://www.w3.org/2000/xmlns/") != 0) {
			_tmp31_ = g_strcmp0 (namespace_uri, "http://www.w3.org/2000/xmlns") != 0;
		} else {
			_tmp31_ = FALSE;
		}
		_tmp27_ = _tmp31_;
	} else {
		_tmp27_ = FALSE;
	}
	if (_tmp27_) {
		GError* _tmp32_;
		_tmp32_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _ ("Invalid namespace. If attribute's name is xmlns, namespace URI should " \
"be http://www.w3.org/2000/xmlns"));
		_inner_error0_ = _tmp32_;
		g_propagate_error (error, _inner_error0_);
		_g_free0 (n);
		_g_free0 (p);
		return;
	}
	_tmp35_ = p;
	if (g_strcmp0 (_tmp35_, "") == 0) {
		const gchar* _tmp36_;
		_tmp36_ = n;
		_tmp34_ = g_strcmp0 (_tmp36_, "xmlns") != 0;
	} else {
		_tmp34_ = FALSE;
	}
	if (_tmp34_) {
		const gchar* _tmp37_;
		_tmp37_ = n;
		_tmp33_ = g_strcmp0 (_tmp37_, "xml") != 0;
	} else {
		_tmp33_ = FALSE;
	}
	if (_tmp33_) {
		GError* _tmp38_;
		_tmp38_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _ ("Invalid attribute name. No prefixed attributes should use xmlns name"));
		_inner_error0_ = _tmp38_;
		g_propagate_error (error, _inner_error0_);
		_g_free0 (n);
		_g_free0 (p);
		return;
	}
	_tmp39_ = p;
	_tmp40_ = n;
	_tmp41_ = gxml_gom_attr_new_namespace ((GXmlDomElement*) self, namespace_uri, _tmp39_, _tmp40_, value);
	a = _tmp41_;
	{
		GXmlGomElementAttributes* _tmp42_;
		GXmlGomAttr* _tmp43_;
		GXmlDomNode* _tmp44_;
		GXmlDomNode* _tmp45_;
		_tmp42_ = self->_attributes;
		_tmp43_ = a;
		_tmp44_ = gxml_dom_named_node_map_set_named_item_ns ((GXmlDomNamedNodeMap*) _tmp42_, (GXmlDomNode*) _tmp43_, &_inner_error0_);
		_tmp45_ = _tmp44_;
		_g_object_unref0 (_tmp45_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch19_g_error;
		}
	}
	goto __finally19;
	__catch19_g_error:
	{
		GError* e = NULL;
		GError* _tmp46_;
		const gchar* _tmp47_;
		gchar* _tmp48_;
		gchar* _tmp49_;
		GError* _tmp50_;
		GError* _tmp51_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp46_ = e;
		_tmp47_ = _tmp46_->message;
		_tmp48_ = g_strconcat (_ ("Setting namespaced property error: "), _tmp47_, NULL);
		_tmp49_ = _tmp48_;
		_tmp50_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _tmp49_);
		_tmp51_ = _tmp50_;
		_g_free0 (_tmp49_);
		_inner_error0_ = _tmp51_;
		_g_error_free0 (e);
		goto __finally19;
	}
	__finally19:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (a);
		_g_free0 (n);
		_g_free0 (p);
		return;
	}
	_g_object_unref0 (a);
	_g_free0 (n);
	_g_free0 (p);
}

static void
gxml_gom_element_real_remove_attribute (GXmlDomElement* base,
                                        const gchar* name)
{
	GXmlGomElement * self;
	GError* _inner_error0_ = NULL;
	self = (GXmlGomElement*) base;
	g_return_if_fail (name != NULL);
	{
		GXmlDomNamedNodeMap* _tmp0_;
		GXmlDomNamedNodeMap* _tmp1_;
		GXmlDomNamedNodeMap* _tmp2_;
		GXmlDomNode* _tmp3_;
		GXmlDomNode* _tmp4_;
		_tmp0_ = gxml_dom_element_get_attributes ((GXmlDomElement*) self);
		_tmp1_ = _tmp0_;
		_tmp2_ = _tmp1_;
		_tmp3_ = gxml_dom_named_node_map_remove_named_item (_tmp2_, name, &_inner_error0_);
		_tmp4_ = _tmp3_;
		_g_object_unref0 (_tmp4_);
		_g_object_unref0 (_tmp2_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch20_g_error;
		}
	}
	goto __finally20;
	__catch20_g_error:
	{
		GError* e = NULL;
		GError* _tmp5_;
		const gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp5_ = e;
		_tmp6_ = _tmp5_->message;
		_tmp7_ = g_strconcat (_ ("Removing attribute Error: "), _tmp6_, NULL);
		_tmp8_ = _tmp7_;
		g_warning ("GomElement.vala:664: %s", _tmp8_);
		_g_free0 (_tmp8_);
		_g_error_free0 (e);
	}
	__finally20:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return;
	}
}

static void
gxml_gom_element_real_remove_attribute_ns (GXmlDomElement* base,
                                           const gchar* namespace_uri,
                                           const gchar* local_name)
{
	GXmlGomElement * self;
	GError* _inner_error0_ = NULL;
	self = (GXmlGomElement*) base;
	g_return_if_fail (local_name != NULL);
	{
		GXmlDomNamedNodeMap* _tmp0_;
		GXmlDomNamedNodeMap* _tmp1_;
		GXmlDomNamedNodeMap* _tmp2_;
		GXmlDomNode* _tmp3_;
		GXmlDomNode* _tmp4_;
		_tmp0_ = gxml_dom_element_get_attributes ((GXmlDomElement*) self);
		_tmp1_ = _tmp0_;
		_tmp2_ = _tmp1_;
		_tmp3_ = gxml_dom_named_node_map_remove_named_item_ns (_tmp2_, namespace_uri, local_name, &_inner_error0_);
		_tmp4_ = _tmp3_;
		_g_object_unref0 (_tmp4_);
		_g_object_unref0 (_tmp2_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch21_g_error;
		}
	}
	goto __finally21;
	__catch21_g_error:
	{
		GError* e = NULL;
		GError* _tmp5_;
		const gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp5_ = e;
		_tmp6_ = _tmp5_->message;
		_tmp7_ = g_strconcat (_ ("Removing namespaced attribute Error: "), _tmp6_, NULL);
		_tmp8_ = _tmp7_;
		g_warning ("GomElement.vala:669: %s", _tmp8_);
		_g_free0 (_tmp8_);
		_g_error_free0 (e);
	}
	__finally21:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return;
	}
}

static gboolean
gxml_gom_element_real_has_attribute (GXmlDomElement* base,
                                     const gchar* name)
{
	GXmlGomElement * self;
	gboolean result = FALSE;
	GXmlGomElementAttributes* _tmp0_;
	self = (GXmlGomElement*) base;
	g_return_val_if_fail (name != NULL, FALSE);
	_tmp0_ = self->_attributes;
	result = gee_abstract_map_has_key ((GeeAbstractMap*) _tmp0_, name);
	return result;
}

static gboolean
gxml_gom_element_real_has_attribute_ns (GXmlDomElement* base,
                                        const gchar* namespace_uri,
                                        const gchar* local_name)
{
	GXmlGomElement * self;
	gboolean result = FALSE;
	gchar* nsp = NULL;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gchar* name = NULL;
	gchar* _tmp4_;
	const gchar* _tmp5_;
	GXmlDomNamedNodeMap* _tmp10_;
	GXmlDomNamedNodeMap* _tmp11_;
	GXmlDomNamedNodeMap* _tmp12_;
	const gchar* _tmp13_;
	gboolean _tmp14_;
	self = (GXmlGomElement*) base;
	g_return_val_if_fail (local_name != NULL, FALSE);
	nsp = NULL;
	if (g_strcmp0 (namespace_uri, "http://www.w3.org/2000/xmlns/") == 0) {
		_tmp1_ = TRUE;
	} else {
		_tmp1_ = g_strcmp0 (namespace_uri, "http://www.w3.org/2000/xmlns") == 0;
	}
	if (_tmp1_) {
		_tmp0_ = g_strcmp0 (local_name, "xmlns") != 0;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		gchar* _tmp2_;
		_tmp2_ = g_strdup ("xmlns");
		_g_free0 (nsp);
		nsp = _tmp2_;
	} else {
		gchar* _tmp3_;
		_tmp3_ = gxml_gom_element_lookup_prefix (self, namespace_uri);
		_g_free0 (nsp);
		nsp = _tmp3_;
	}
	_tmp4_ = g_strdup (local_name);
	name = _tmp4_;
	_tmp5_ = nsp;
	if (_tmp5_ != NULL) {
		const gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		_tmp6_ = nsp;
		_tmp7_ = g_strconcat (_tmp6_, ":", NULL);
		_tmp8_ = _tmp7_;
		_tmp9_ = g_strconcat (_tmp8_, local_name, NULL);
		_g_free0 (name);
		name = _tmp9_;
		_g_free0 (_tmp8_);
	}
	_tmp10_ = gxml_dom_element_get_attributes ((GXmlDomElement*) self);
	_tmp11_ = _tmp10_;
	_tmp12_ = _tmp11_;
	_tmp13_ = name;
	_tmp14_ = gee_map_has_key ((GeeMap*) _tmp12_, _tmp13_);
	_g_object_unref0 (_tmp12_);
	result = _tmp14_;
	_g_free0 (name);
	_g_free0 (nsp);
	return result;
}

static GXmlDomHTMLCollection*
gxml_gom_element_real_get_elements_by_tag_name (GXmlDomElement* base,
                                                const gchar* local_name)
{
	GXmlGomElement * self;
	GXmlDomHTMLCollection* result = NULL;
	GXmlGDomHTMLCollection* l = NULL;
	GXmlGDomHTMLCollection* _tmp0_;
	self = (GXmlGomElement*) base;
	g_return_val_if_fail (local_name != NULL, NULL);
	_tmp0_ = gxml_gdom_html_collection_new ();
	l = _tmp0_;
	{
		GXmlDomNodeList* _n_list = NULL;
		GXmlDomNodeList* _tmp1_;
		GXmlDomNodeList* _tmp2_;
		gint _n_size = 0;
		GXmlDomNodeList* _tmp3_;
		gint _tmp4_;
		gint _tmp5_;
		gint _n_index = 0;
		_tmp1_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
		_tmp2_ = _tmp1_;
		_n_list = _tmp2_;
		_tmp3_ = _n_list;
		_tmp4_ = gee_collection_get_size ((GeeCollection*) _tmp3_);
		_tmp5_ = _tmp4_;
		_n_size = _tmp5_;
		_n_index = -1;
		while (TRUE) {
			GXmlDomNode* n = NULL;
			GXmlDomNodeList* _tmp6_;
			gpointer _tmp7_;
			GXmlDomNode* _tmp8_;
			GXmlDomNode* _tmp9_;
			gchar* _tmp10_;
			gchar* _tmp11_;
			gchar* _tmp12_;
			gboolean _tmp13_;
			GXmlGDomHTMLCollection* _tmp16_;
			GXmlDomNode* _tmp17_;
			GXmlDomHTMLCollection* _tmp18_;
			GXmlDomHTMLCollection* _tmp19_;
			_n_index = _n_index + 1;
			if (!(_n_index < _n_size)) {
				break;
			}
			_tmp6_ = _n_list;
			_tmp7_ = gee_list_get ((GeeList*) _tmp6_, _n_index);
			n = (GXmlDomNode*) _tmp7_;
			_tmp8_ = n;
			if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, GXML_TYPE_DOM_ELEMENT)) {
				_g_object_unref0 (n);
				continue;
			}
			_tmp9_ = n;
			_tmp10_ = gxml_dom_node_get_node_name (_tmp9_);
			_tmp11_ = _tmp10_;
			_tmp12_ = _tmp11_;
			_tmp13_ = g_strcmp0 (_tmp12_, local_name) == 0;
			_g_free0 (_tmp12_);
			if (_tmp13_) {
				GXmlGDomHTMLCollection* _tmp14_;
				GXmlDomNode* _tmp15_;
				_tmp14_ = l;
				_tmp15_ = n;
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp14_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp15_) : NULL);
			}
			_tmp16_ = l;
			_tmp17_ = n;
			_tmp18_ = gxml_dom_element_get_elements_by_tag_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp17_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp17_) : NULL, local_name);
			_tmp19_ = _tmp18_;
			gee_array_list_add_all ((GeeArrayList*) _tmp16_, (GeeCollection*) _tmp19_);
			_g_object_unref0 (_tmp19_);
			_g_object_unref0 (n);
		}
		_g_object_unref0 (_n_list);
	}
	result = (GXmlDomHTMLCollection*) l;
	return result;
}

static GXmlDomHTMLCollection*
gxml_gom_element_real_get_elements_by_tag_name_ns (GXmlDomElement* base,
                                                   const gchar* namespace,
                                                   const gchar* local_name)
{
	GXmlGomElement * self;
	GXmlDomHTMLCollection* result = NULL;
	GXmlGDomHTMLCollection* l = NULL;
	GXmlGDomHTMLCollection* _tmp0_;
	self = (GXmlGomElement*) base;
	g_return_val_if_fail (local_name != NULL, NULL);
	_tmp0_ = gxml_gdom_html_collection_new ();
	l = _tmp0_;
	{
		GXmlDomNodeList* _n_list = NULL;
		GXmlDomNodeList* _tmp1_;
		GXmlDomNodeList* _tmp2_;
		gint _n_size = 0;
		GXmlDomNodeList* _tmp3_;
		gint _tmp4_;
		gint _tmp5_;
		gint _n_index = 0;
		_tmp1_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
		_tmp2_ = _tmp1_;
		_n_list = _tmp2_;
		_tmp3_ = _n_list;
		_tmp4_ = gee_collection_get_size ((GeeCollection*) _tmp3_);
		_tmp5_ = _tmp4_;
		_n_size = _tmp5_;
		_n_index = -1;
		while (TRUE) {
			GXmlDomNode* n = NULL;
			GXmlDomNodeList* _tmp6_;
			gpointer _tmp7_;
			GXmlDomNode* _tmp8_;
			gboolean _tmp9_ = FALSE;
			GXmlDomNode* _tmp10_;
			gchar* _tmp11_;
			gchar* _tmp12_;
			gchar* _tmp13_;
			gboolean _tmp14_;
			GXmlGDomHTMLCollection* _tmp21_;
			GXmlDomNode* _tmp22_;
			GXmlDomHTMLCollection* _tmp23_;
			GXmlDomHTMLCollection* _tmp24_;
			_n_index = _n_index + 1;
			if (!(_n_index < _n_size)) {
				break;
			}
			_tmp6_ = _n_list;
			_tmp7_ = gee_list_get ((GeeList*) _tmp6_, _n_index);
			n = (GXmlDomNode*) _tmp7_;
			_tmp8_ = n;
			if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, GXML_TYPE_DOM_ELEMENT)) {
				_g_object_unref0 (n);
				continue;
			}
			_tmp10_ = n;
			_tmp11_ = gxml_dom_node_get_node_name (_tmp10_);
			_tmp12_ = _tmp11_;
			_tmp13_ = _tmp12_;
			_tmp14_ = g_strcmp0 (_tmp13_, local_name) == 0;
			_g_free0 (_tmp13_);
			if (_tmp14_) {
				GXmlDomNode* _tmp15_;
				gchar* _tmp16_;
				gchar* _tmp17_;
				gchar* _tmp18_;
				_tmp15_ = n;
				_tmp16_ = gxml_dom_element_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp15_) : NULL);
				_tmp17_ = _tmp16_;
				_tmp18_ = _tmp17_;
				_tmp9_ = g_strcmp0 (_tmp18_, namespace) == 0;
				_g_free0 (_tmp18_);
			} else {
				_tmp9_ = FALSE;
			}
			if (_tmp9_) {
				GXmlGDomHTMLCollection* _tmp19_;
				GXmlDomNode* _tmp20_;
				_tmp19_ = l;
				_tmp20_ = n;
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp19_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp20_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp20_) : NULL);
			}
			_tmp21_ = l;
			_tmp22_ = n;
			_tmp23_ = gxml_dom_element_get_elements_by_tag_name_ns (G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp22_) : NULL, namespace, local_name);
			_tmp24_ = _tmp23_;
			gee_array_list_add_all ((GeeArrayList*) _tmp21_, (GeeCollection*) _tmp24_);
			_g_object_unref0 (_tmp24_);
			_g_object_unref0 (n);
		}
		_g_object_unref0 (_n_list);
	}
	result = (GXmlDomHTMLCollection*) l;
	return result;
}

static void
_vala_array_add8 (gchar** * array,
                  int* length,
                  int* size,
                  gchar* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
_vala_array_add9 (gchar** * array,
                  int* length,
                  int* size,
                  gchar* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static GXmlDomHTMLCollection*
gxml_gom_element_real_get_elements_by_class_name (GXmlDomElement* base,
                                                  const gchar* class_names)
{
	GXmlGomElement * self;
	GXmlDomHTMLCollection* result = NULL;
	GXmlGDomHTMLCollection* l = NULL;
	GXmlGDomHTMLCollection* _tmp0_;
	gchar** cs = NULL;
	gchar** _tmp1_;
	gint cs_length1;
	gint _cs_size_;
	self = (GXmlGomElement*) base;
	g_return_val_if_fail (class_names != NULL, NULL);
	_tmp0_ = gxml_gdom_html_collection_new ();
	l = _tmp0_;
	if (g_strcmp0 (class_names, "") == 0) {
		result = (GXmlDomHTMLCollection*) l;
		return result;
	}
	_tmp1_ = g_new0 (gchar*, 0 + 1);
	cs = _tmp1_;
	cs_length1 = 0;
	_cs_size_ = cs_length1;
	if (string_contains (class_names, " ")) {
		gchar** _tmp2_;
		gchar** _tmp3_;
		_tmp3_ = _tmp2_ = g_strsplit (class_names, " ", 0);
		cs = (_vala_array_free (cs, cs_length1, (GDestroyNotify) g_free), NULL);
		cs = _tmp3_;
		cs_length1 = _vala_array_length (_tmp2_);
		_cs_size_ = cs_length1;
	} else {
		gchar** _tmp4_;
		gint _tmp4__length1;
		gchar* _tmp5_;
		_tmp4_ = cs;
		_tmp4__length1 = cs_length1;
		_tmp5_ = g_strdup (class_names);
		_vala_array_add8 (&cs, &cs_length1, &_cs_size_, _tmp5_);
	}
	{
		GXmlDomNodeList* _n_list = NULL;
		GXmlDomNodeList* _tmp6_;
		GXmlDomNodeList* _tmp7_;
		gint _n_size = 0;
		GXmlDomNodeList* _tmp8_;
		gint _tmp9_;
		gint _tmp10_;
		gint _n_index = 0;
		_tmp6_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
		_tmp7_ = _tmp6_;
		_n_list = _tmp7_;
		_tmp8_ = _n_list;
		_tmp9_ = gee_collection_get_size ((GeeCollection*) _tmp8_);
		_tmp10_ = _tmp9_;
		_n_size = _tmp10_;
		_n_index = -1;
		while (TRUE) {
			GXmlDomNode* n = NULL;
			GXmlDomNodeList* _tmp11_;
			gpointer _tmp12_;
			GXmlDomNode* _tmp13_;
			gchar* cls = NULL;
			GXmlDomNode* _tmp14_;
			gchar* _tmp15_;
			const gchar* _tmp16_;
			GXmlGDomHTMLCollection* _tmp40_;
			GXmlDomNode* _tmp41_;
			GXmlDomHTMLCollection* _tmp42_;
			GXmlDomHTMLCollection* _tmp43_;
			_n_index = _n_index + 1;
			if (!(_n_index < _n_size)) {
				break;
			}
			_tmp11_ = _n_list;
			_tmp12_ = gee_list_get ((GeeList*) _tmp11_, _n_index);
			n = (GXmlDomNode*) _tmp12_;
			_tmp13_ = n;
			if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, GXML_TYPE_DOM_ELEMENT)) {
				_g_object_unref0 (n);
				continue;
			}
			_tmp14_ = n;
			_tmp15_ = gxml_dom_element_get_attribute (G_TYPE_CHECK_INSTANCE_TYPE (_tmp14_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp14_) : NULL, "class");
			cls = _tmp15_;
			_tmp16_ = cls;
			if (_tmp16_ != NULL) {
				gchar** ncls = NULL;
				gchar** _tmp17_;
				gint ncls_length1;
				gint _ncls_size_;
				const gchar* _tmp18_;
				gint found = 0;
				gchar** _tmp25_;
				gint _tmp25__length1;
				gchar** _tmp32_;
				gint _tmp32__length1;
				_tmp17_ = g_new0 (gchar*, 0 + 1);
				ncls = _tmp17_;
				ncls_length1 = 0;
				_ncls_size_ = ncls_length1;
				_tmp18_ = cls;
				if (string_contains (_tmp18_, " ")) {
					const gchar* _tmp19_;
					gchar** _tmp20_;
					gchar** _tmp21_;
					_tmp19_ = cls;
					_tmp21_ = _tmp20_ = g_strsplit (_tmp19_, " ", 0);
					ncls = (_vala_array_free (ncls, ncls_length1, (GDestroyNotify) g_free), NULL);
					ncls = _tmp21_;
					ncls_length1 = _vala_array_length (_tmp20_);
					_ncls_size_ = ncls_length1;
				} else {
					gchar** _tmp22_;
					gint _tmp22__length1;
					const gchar* _tmp23_;
					gchar* _tmp24_;
					_tmp22_ = ncls;
					_tmp22__length1 = ncls_length1;
					_tmp23_ = cls;
					_tmp24_ = g_strdup (_tmp23_);
					_vala_array_add9 (&ncls, &ncls_length1, &_ncls_size_, _tmp24_);
				}
				found = 0;
				_tmp25_ = cs;
				_tmp25__length1 = cs_length1;
				{
					gchar** cl_collection = NULL;
					gint cl_collection_length1 = 0;
					gint _cl_collection_size_ = 0;
					gint cl_it = 0;
					cl_collection = _tmp25_;
					cl_collection_length1 = _tmp25__length1;
					for (cl_it = 0; cl_it < _tmp25__length1; cl_it = cl_it + 1) {
						gchar* _tmp26_;
						gchar* cl = NULL;
						_tmp26_ = g_strdup (cl_collection[cl_it]);
						cl = _tmp26_;
						{
							gchar** _tmp27_;
							gint _tmp27__length1;
							_tmp27_ = ncls;
							_tmp27__length1 = ncls_length1;
							{
								gchar** ncl_collection = NULL;
								gint ncl_collection_length1 = 0;
								gint _ncl_collection_size_ = 0;
								gint ncl_it = 0;
								ncl_collection = _tmp27_;
								ncl_collection_length1 = _tmp27__length1;
								for (ncl_it = 0; ncl_it < _tmp27__length1; ncl_it = ncl_it + 1) {
									gchar* _tmp28_;
									gchar* ncl = NULL;
									_tmp28_ = g_strdup (ncl_collection[ncl_it]);
									ncl = _tmp28_;
									{
										const gchar* _tmp29_;
										const gchar* _tmp30_;
										_tmp29_ = cl;
										_tmp30_ = ncl;
										if (g_strcmp0 (_tmp29_, _tmp30_) == 0) {
											gint _tmp31_;
											_tmp31_ = found;
											found = _tmp31_ + 1;
										}
										_g_free0 (ncl);
									}
								}
							}
							_g_free0 (cl);
						}
					}
				}
				_tmp32_ = cs;
				_tmp32__length1 = cs_length1;
				if (found == _tmp32__length1) {
					GXmlGDomHTMLCollection* _tmp33_;
					gint _tmp34_;
					gint _tmp35_;
					_tmp33_ = l;
					_tmp34_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp33_);
					_tmp35_ = _tmp34_;
					if (_tmp35_ == 0) {
						GXmlGDomHTMLCollection* _tmp36_;
						GXmlDomNode* _tmp37_;
						_tmp36_ = l;
						_tmp37_ = n;
						gee_abstract_collection_add ((GeeAbstractCollection*) _tmp36_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp37_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp37_) : NULL);
					} else {
						GXmlGDomHTMLCollection* _tmp38_;
						GXmlDomNode* _tmp39_;
						_tmp38_ = l;
						_tmp39_ = n;
						gee_abstract_list_insert ((GeeAbstractList*) _tmp38_, 0, G_TYPE_CHECK_INSTANCE_TYPE (_tmp39_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp39_) : NULL);
					}
				}
				ncls = (_vala_array_free (ncls, ncls_length1, (GDestroyNotify) g_free), NULL);
			}
			_tmp40_ = l;
			_tmp41_ = n;
			_tmp42_ = gxml_dom_element_get_elements_by_class_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp41_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp41_) : NULL, class_names);
			_tmp43_ = _tmp42_;
			gee_array_list_add_all ((GeeArrayList*) _tmp40_, (GeeCollection*) _tmp43_);
			_g_object_unref0 (_tmp43_);
			_g_free0 (cls);
			_g_object_unref0 (n);
		}
		_g_object_unref0 (_n_list);
	}
	result = (GXmlDomHTMLCollection*) l;
	cs = (_vala_array_free (cs, cs_length1, (GDestroyNotify) g_free), NULL);
	return result;
}

/**
   * Parse all children, adding them to current node, stored in {@link unparsed}.
   * Once it finish, sets {@link unparsed} to null.
   */
void
gxml_gom_element_read_unparsed (GXmlGomElement* self,
                                GError** error)
{
	const gchar* _tmp0_;
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp1_;
	GXmlXParser* _tmp2_;
	const gchar* _tmp3_;
	GError* _inner_error0_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_unparsed;
	if (_tmp0_ == NULL) {
		return;
	}
	_tmp1_ = gxml_xparser_new ((GXmlDomNode*) self);
	parser = _tmp1_;
	_tmp2_ = parser;
	_tmp3_ = self->priv->_unparsed;
	gxml_parser_read_child_nodes_string ((GXmlParser*) _tmp2_, _tmp3_, &_inner_error0_);
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		_g_object_unref0 (parser);
		return;
	}
	gxml_gom_element_set_unparsed (self, NULL);
	_g_object_unref0 (parser);
}

GXmlGomElement*
gxml_gom_element_construct (GType object_type)
{
	GXmlGomElement * self = NULL;
	self = (GXmlGomElement*) gxml_gom_node_construct (object_type);
	return self;
}

GXmlGomElement*
gxml_gom_element_new (void)
{
	return gxml_gom_element_construct (GXML_TYPE_GOM_ELEMENT);
}

static GXmlDomElement*
gxml_gom_element_real_get_previous_element_sibling (GXmlDomNonDocumentTypeChildNode* base)
{
	GXmlDomElement* result;
	GXmlGomElement* self;
	GXmlDomNode* _tmp0_;
	GXmlDomNode* _tmp1_;
	GXmlDomNode* _tmp2_;
	gboolean _tmp3_;
	self = (GXmlGomElement*) base;
	_tmp0_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_ != NULL;
	_g_object_unref0 (_tmp2_);
	if (_tmp3_) {
		gint i = 0;
		GXmlDomNode* _tmp4_;
		GXmlDomNode* _tmp5_;
		GXmlDomNode* _tmp6_;
		GXmlDomNodeList* _tmp7_;
		GXmlDomNodeList* _tmp8_;
		GXmlDomNodeList* _tmp9_;
		gint _tmp10_;
		_tmp4_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
		_tmp5_ = _tmp4_;
		_tmp6_ = _tmp5_;
		_tmp7_ = gxml_dom_node_get_child_nodes (_tmp6_);
		_tmp8_ = _tmp7_;
		_tmp9_ = _tmp8_;
		_tmp10_ = gee_list_index_of ((GeeList*) _tmp9_, (GXmlDomNode*) self);
		_g_object_unref0 (_tmp9_);
		_g_object_unref0 (_tmp6_);
		i = _tmp10_;
		if (i == 0) {
			result = NULL;
			return result;
		}
		{
			gint j = 0;
			j = i;
			{
				gboolean _tmp11_ = FALSE;
				_tmp11_ = TRUE;
				while (TRUE) {
					GXmlDomNode* n = NULL;
					GXmlDomNode* _tmp13_;
					GXmlDomNode* _tmp14_;
					GXmlDomNode* _tmp15_;
					GXmlDomNodeList* _tmp16_;
					GXmlDomNodeList* _tmp17_;
					GXmlDomNodeList* _tmp18_;
					GXmlDomNode* _tmp19_;
					GXmlDomNode* _tmp20_;
					GXmlDomNode* _tmp21_;
					if (!_tmp11_) {
						gint _tmp12_;
						_tmp12_ = j;
						j = _tmp12_ - 1;
					}
					_tmp11_ = FALSE;
					if (!(j >= 1)) {
						break;
					}
					_tmp13_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
					_tmp14_ = _tmp13_;
					_tmp15_ = _tmp14_;
					_tmp16_ = gxml_dom_node_get_child_nodes (_tmp15_);
					_tmp17_ = _tmp16_;
					_tmp18_ = _tmp17_;
					_tmp19_ = gxml_dom_node_list_item (_tmp18_, j - 1);
					_tmp20_ = _tmp19_;
					_g_object_unref0 (_tmp18_);
					_g_object_unref0 (_tmp15_);
					n = _tmp20_;
					_tmp21_ = n;
					if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp21_, GXML_TYPE_DOM_ELEMENT)) {
						GXmlDomNode* _tmp22_;
						GXmlDomElement* _tmp23_;
						_tmp22_ = n;
						_tmp23_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp22_) : NULL);
						result = _tmp23_;
						_g_object_unref0 (n);
						return result;
					}
					_g_object_unref0 (n);
				}
			}
		}
	}
	result = NULL;
	return result;
}

static GXmlDomElement*
gxml_gom_element_real_get_next_element_sibling (GXmlDomNonDocumentTypeChildNode* base)
{
	GXmlDomElement* result;
	GXmlGomElement* self;
	GXmlDomNode* _tmp0_;
	GXmlDomNode* _tmp1_;
	GXmlDomNode* _tmp2_;
	gboolean _tmp3_;
	self = (GXmlGomElement*) base;
	_tmp0_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_ != NULL;
	_g_object_unref0 (_tmp2_);
	if (_tmp3_) {
		gint i = 0;
		GXmlDomNode* _tmp4_;
		GXmlDomNode* _tmp5_;
		GXmlDomNode* _tmp6_;
		GXmlDomNodeList* _tmp7_;
		GXmlDomNodeList* _tmp8_;
		GXmlDomNodeList* _tmp9_;
		gint _tmp10_;
		GXmlDomNode* _tmp11_;
		GXmlDomNode* _tmp12_;
		GXmlDomNode* _tmp13_;
		GXmlDomNodeList* _tmp14_;
		GXmlDomNodeList* _tmp15_;
		GXmlDomNodeList* _tmp16_;
		gint _tmp17_;
		gint _tmp18_;
		gboolean _tmp19_;
		_tmp4_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
		_tmp5_ = _tmp4_;
		_tmp6_ = _tmp5_;
		_tmp7_ = gxml_dom_node_get_child_nodes (_tmp6_);
		_tmp8_ = _tmp7_;
		_tmp9_ = _tmp8_;
		_tmp10_ = gee_list_index_of ((GeeList*) _tmp9_, (GXmlDomNode*) self);
		_g_object_unref0 (_tmp9_);
		_g_object_unref0 (_tmp6_);
		i = _tmp10_;
		_tmp11_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
		_tmp12_ = _tmp11_;
		_tmp13_ = _tmp12_;
		_tmp14_ = gxml_dom_node_get_child_nodes (_tmp13_);
		_tmp15_ = _tmp14_;
		_tmp16_ = _tmp15_;
		_tmp17_ = gxml_dom_node_list_get_length (_tmp16_);
		_tmp18_ = _tmp17_;
		_tmp19_ = i == (_tmp18_ - 1);
		_g_object_unref0 (_tmp16_);
		_g_object_unref0 (_tmp13_);
		if (_tmp19_) {
			result = NULL;
			return result;
		}
		{
			gint j = 0;
			j = i;
			{
				gboolean _tmp20_ = FALSE;
				_tmp20_ = TRUE;
				while (TRUE) {
					GXmlDomNode* _tmp22_;
					GXmlDomNode* _tmp23_;
					GXmlDomNode* _tmp24_;
					GXmlDomNodeList* _tmp25_;
					GXmlDomNodeList* _tmp26_;
					GXmlDomNodeList* _tmp27_;
					gint _tmp28_;
					gint _tmp29_;
					gboolean _tmp30_;
					GXmlDomNode* n = NULL;
					GXmlDomNode* _tmp31_;
					GXmlDomNode* _tmp32_;
					GXmlDomNode* _tmp33_;
					GXmlDomNodeList* _tmp34_;
					GXmlDomNodeList* _tmp35_;
					GXmlDomNodeList* _tmp36_;
					GXmlDomNode* _tmp37_;
					GXmlDomNode* _tmp38_;
					GXmlDomNode* _tmp39_;
					if (!_tmp20_) {
						gint _tmp21_;
						_tmp21_ = j;
						j = _tmp21_ - 1;
					}
					_tmp20_ = FALSE;
					_tmp22_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
					_tmp23_ = _tmp22_;
					_tmp24_ = _tmp23_;
					_tmp25_ = gxml_dom_node_get_child_nodes (_tmp24_);
					_tmp26_ = _tmp25_;
					_tmp27_ = _tmp26_;
					_tmp28_ = gxml_dom_node_list_get_length (_tmp27_);
					_tmp29_ = _tmp28_;
					_tmp30_ = !(j < (_tmp29_ - 1));
					_g_object_unref0 (_tmp27_);
					_g_object_unref0 (_tmp24_);
					if (_tmp30_) {
						break;
					}
					_tmp31_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
					_tmp32_ = _tmp31_;
					_tmp33_ = _tmp32_;
					_tmp34_ = gxml_dom_node_get_child_nodes (_tmp33_);
					_tmp35_ = _tmp34_;
					_tmp36_ = _tmp35_;
					_tmp37_ = gxml_dom_node_list_item (_tmp36_, j + 1);
					_tmp38_ = _tmp37_;
					_g_object_unref0 (_tmp36_);
					_g_object_unref0 (_tmp33_);
					n = _tmp38_;
					_tmp39_ = n;
					if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp39_, GXML_TYPE_DOM_ELEMENT)) {
						GXmlDomNode* _tmp40_;
						GXmlDomElement* _tmp41_;
						_tmp40_ = n;
						_tmp41_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp40_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement));
						result = _tmp41_;
						_g_object_unref0 (n);
						return result;
					}
					_g_object_unref0 (n);
				}
			}
		}
	}
	result = NULL;
	return result;
}

static GXmlDomHTMLCollection*
gxml_gom_element_real_get_children (GXmlDomParentNode* base)
{
	GXmlDomHTMLCollection* result;
	GXmlGomElement* self;
	GXmlGDomHTMLCollection* l = NULL;
	GXmlGDomHTMLCollection* _tmp0_;
	self = (GXmlGomElement*) base;
	_tmp0_ = gxml_gdom_html_collection_new ();
	l = _tmp0_;
	{
		GXmlDomNodeList* _n_list = NULL;
		GXmlDomNodeList* _tmp1_;
		GXmlDomNodeList* _tmp2_;
		gint _n_size = 0;
		GXmlDomNodeList* _tmp3_;
		gint _tmp4_;
		gint _tmp5_;
		gint _n_index = 0;
		_tmp1_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
		_tmp2_ = _tmp1_;
		_n_list = _tmp2_;
		_tmp3_ = _n_list;
		_tmp4_ = gee_collection_get_size ((GeeCollection*) _tmp3_);
		_tmp5_ = _tmp4_;
		_n_size = _tmp5_;
		_n_index = -1;
		while (TRUE) {
			GXmlDomNode* n = NULL;
			GXmlDomNodeList* _tmp6_;
			gpointer _tmp7_;
			GXmlDomNode* _tmp8_;
			_n_index = _n_index + 1;
			if (!(_n_index < _n_size)) {
				break;
			}
			_tmp6_ = _n_list;
			_tmp7_ = gee_list_get ((GeeList*) _tmp6_, _n_index);
			n = (GXmlDomNode*) _tmp7_;
			_tmp8_ = n;
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, GXML_TYPE_DOM_ELEMENT)) {
				GXmlGDomHTMLCollection* _tmp9_;
				GXmlDomNode* _tmp10_;
				_tmp9_ = l;
				_tmp10_ = n;
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp9_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp10_) : NULL);
			}
			_g_object_unref0 (n);
		}
		_g_object_unref0 (_n_list);
	}
	result = (GXmlDomHTMLCollection*) l;
	return result;
}

static GXmlDomElement*
gxml_gom_element_real_get_first_element_child (GXmlDomParentNode* base)
{
	GXmlDomElement* result;
	GXmlGomElement* self;
	GXmlDomHTMLCollection* _tmp0_;
	GXmlDomHTMLCollection* _tmp1_;
	GXmlDomHTMLCollection* _tmp2_;
	gpointer _tmp3_;
	GXmlDomElement* _tmp4_;
	self = (GXmlGomElement*) base;
	_tmp0_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_list_first ((GeeList*) _tmp2_);
	_tmp4_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlDomElement*) _tmp3_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement);
	_g_object_unref0 (_tmp2_);
	result = _tmp4_;
	return result;
}

static GXmlDomElement*
gxml_gom_element_real_get_last_element_child (GXmlDomParentNode* base)
{
	GXmlDomElement* result;
	GXmlGomElement* self;
	GXmlDomHTMLCollection* _tmp0_;
	GXmlDomHTMLCollection* _tmp1_;
	GXmlDomHTMLCollection* _tmp2_;
	gpointer _tmp3_;
	GXmlDomElement* _tmp4_;
	self = (GXmlGomElement*) base;
	_tmp0_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_list_last ((GeeList*) _tmp2_);
	_tmp4_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlDomElement*) _tmp3_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement);
	_g_object_unref0 (_tmp2_);
	result = _tmp4_;
	return result;
}

static gint
gxml_gom_element_real_get_child_element_count (GXmlDomParentNode* base)
{
	gint result;
	GXmlGomElement* self;
	GXmlDomHTMLCollection* _tmp0_;
	GXmlDomHTMLCollection* _tmp1_;
	GXmlDomHTMLCollection* _tmp2_;
	gint _tmp3_;
	gint _tmp4_;
	gint _tmp5_;
	self = (GXmlGomElement*) base;
	_tmp0_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_collection_get_size ((GeeCollection*) _tmp2_);
	_tmp4_ = _tmp3_;
	_tmp5_ = _tmp4_;
	_g_object_unref0 (_tmp2_);
	result = _tmp5_;
	return result;
}

static gchar*
gxml_gom_element_real_get_namespace_uri (GXmlDomElement* base)
{
	gchar* result;
	GXmlGomElement* self;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	self = (GXmlGomElement*) base;
	_tmp0_ = self->_namespace_uri;
	_tmp1_ = g_strdup (_tmp0_);
	result = _tmp1_;
	return result;
}

static gchar*
gxml_gom_element_real_get_prefix (GXmlDomElement* base)
{
	gchar* result;
	GXmlGomElement* self;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	self = (GXmlGomElement*) base;
	_tmp0_ = ((GXmlGomNode*) self)->_prefix;
	_tmp1_ = g_strdup (_tmp0_);
	result = _tmp1_;
	return result;
}

static gchar*
gxml_gom_element_real_get_local_name (GXmlDomElement* base)
{
	gchar* result;
	GXmlGomElement* self;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	self = (GXmlGomElement*) base;
	_tmp0_ = ((GXmlGomNode*) self)->_local_name;
	_tmp1_ = g_strdup (_tmp0_);
	result = _tmp1_;
	return result;
}

static gchar*
gxml_gom_element_real_get_tag_name (GXmlDomElement* base)
{
	gchar* result;
	GXmlGomElement* self;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	self = (GXmlGomElement*) base;
	_tmp0_ = ((GXmlGomNode*) self)->_local_name;
	_tmp1_ = g_strdup (_tmp0_);
	result = _tmp1_;
	return result;
}

static gchar*
gxml_gom_element_real_get_id (GXmlDomElement* base)
{
	gchar* result;
	GXmlGomElement* self;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	self = (GXmlGomElement*) base;
	_tmp0_ = self->priv->_id;
	_tmp1_ = g_strdup (_tmp0_);
	result = _tmp1_;
	return result;
}

static void
gxml_gom_element_real_set_id (GXmlDomElement* base,
                              const gchar* value)
{
	GXmlGomElement* self;
	self = (GXmlGomElement*) base;
	if (g_strcmp0 (value, gxml_gom_element_real_get_id (base)) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_id);
		self->priv->_id = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gxml_gom_element_properties[GXML_GOM_ELEMENT_ID_PROPERTY]);
	}
}

static gchar*
gxml_gom_element_real_get_class_name (GXmlDomElement* base)
{
	gchar* result;
	GXmlGomElement* self;
	gchar* _tmp0_;
	self = (GXmlGomElement*) base;
	_tmp0_ = gxml_dom_element_get_attribute ((GXmlDomElement*) (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_GOM_ELEMENT) ? ((GXmlGomElement*) self) : NULL), "class");
	result = _tmp0_;
	return result;
}

static void
gxml_gom_element_real_set_class_name (GXmlDomElement* base,
                                      const gchar* value)
{
	GXmlGomElement* self;
	self = (GXmlGomElement*) base;
	gxml_gom_object_set_attribute (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_GOM_OBJECT) ? ((GXmlGomObject*) self) : NULL, "class", value);
	g_object_notify_by_pspec ((GObject *) self, gxml_gom_element_properties[GXML_GOM_ELEMENT_CLASS_NAME_PROPERTY]);
}

static GXmlDomTokenList*
gxml_gom_element_real_get_class_list (GXmlDomElement* base)
{
	GXmlDomTokenList* result;
	GXmlGomElement* self;
	GXmlGDomTokenList* _tmp0_;
	self = (GXmlGomElement*) base;
	_tmp0_ = gxml_gdom_token_list_new ((GXmlDomElement*) self, "class");
	result = (GXmlDomTokenList*) _tmp0_;
	return result;
}

static GXmlDomNamedNodeMap*
gxml_gom_element_real_get_attributes (GXmlDomElement* base)
{
	GXmlDomNamedNodeMap* result;
	GXmlGomElement* self;
	GXmlGomElementAttributes* _tmp0_;
	GXmlDomNamedNodeMap* _tmp1_;
	self = (GXmlGomElement*) base;
	_tmp0_ = self->_attributes;
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMap));
	result = _tmp1_;
	return result;
}

gboolean
gxml_gom_element_get_parse_children (GXmlGomElement* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_parse_children;
	return result;
}

void
gxml_gom_element_set_parse_children (GXmlGomElement* self,
                                     gboolean value)
{
	g_return_if_fail (self != NULL);
	if (gxml_gom_element_get_parse_children (self) != value) {
		self->priv->_parse_children = value;
		g_object_notify_by_pspec ((GObject *) self, gxml_gom_element_properties[GXML_GOM_ELEMENT_PARSE_CHILDREN_PROPERTY]);
	}
}

const gchar*
gxml_gom_element_get_unparsed (GXmlGomElement* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_unparsed;
	result = _tmp0_;
	return result;
}

void
gxml_gom_element_set_unparsed (GXmlGomElement* self,
                               const gchar* value)
{
	g_return_if_fail (self != NULL);
	if (g_strcmp0 (value, gxml_gom_element_get_unparsed (self)) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_unparsed);
		self->priv->_unparsed = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gxml_gom_element_properties[GXML_GOM_ELEMENT_UNPARSED_PROPERTY]);
	}
}

static gchar*
string_replace (const gchar* self,
                const gchar* old,
                const gchar* replacement)
{
	gchar* result = NULL;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GError* _inner_error0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (old != NULL, NULL);
	g_return_val_if_fail (replacement != NULL, NULL);
	if ((*((gchar*) self)) == '\0') {
		_tmp1_ = TRUE;
	} else {
		_tmp1_ = (*((gchar*) old)) == '\0';
	}
	if (_tmp1_) {
		_tmp0_ = TRUE;
	} else {
		_tmp0_ = g_strcmp0 (old, replacement) == 0;
	}
	if (_tmp0_) {
		gchar* _tmp2_;
		_tmp2_ = g_strdup (self);
		result = _tmp2_;
		return result;
	}
	{
		GRegex* regex = NULL;
		gchar* _tmp3_;
		gchar* _tmp4_;
		GRegex* _tmp5_;
		GRegex* _tmp6_;
		gchar* _tmp7_ = NULL;
		GRegex* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		_tmp3_ = g_regex_escape_string (old, -1);
		_tmp4_ = _tmp3_;
		_tmp5_ = g_regex_new (_tmp4_, 0, 0, &_inner_error0_);
		_tmp6_ = _tmp5_;
		_g_free0 (_tmp4_);
		regex = _tmp6_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			if (_inner_error0_->domain == G_REGEX_ERROR) {
				goto __catch22_g_regex_error;
			}
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
			g_clear_error (&_inner_error0_);
			return NULL;
		}
		_tmp8_ = regex;
		_tmp9_ = g_regex_replace_literal (_tmp8_, self, (gssize) -1, 0, replacement, 0, &_inner_error0_);
		_tmp7_ = _tmp9_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			_g_regex_unref0 (regex);
			if (_inner_error0_->domain == G_REGEX_ERROR) {
				goto __catch22_g_regex_error;
			}
			_g_regex_unref0 (regex);
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
			g_clear_error (&_inner_error0_);
			return NULL;
		}
		_tmp10_ = _tmp7_;
		_tmp7_ = NULL;
		result = _tmp10_;
		_g_free0 (_tmp7_);
		_g_regex_unref0 (regex);
		return result;
	}
	goto __finally22;
	__catch22_g_regex_error:
	{
		GError* e = NULL;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		g_assert_not_reached ();
		_g_error_free0 (e);
	}
	__finally22:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return NULL;
	}
}

static void
_gxml_gom_element___lambda6_ (GXmlGomElement* self,
                              GParamSpec* pspec)
{
	const gchar* _tmp0_;
	g_return_if_fail (pspec != NULL);
	_tmp0_ = g_param_spec_get_nick (pspec);
	if (string_contains (_tmp0_, "::")) {
		gchar* name = NULL;
		const gchar* _tmp1_;
		gchar* _tmp2_;
		GXmlDomNode* p = NULL;
		GXmlGomElementAttributes* _tmp3_;
		const gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gpointer _tmp7_;
		GXmlDomNode* _tmp8_;
		GXmlDomNode* _tmp9_;
		_tmp1_ = g_param_spec_get_nick (pspec);
		_tmp2_ = string_replace (_tmp1_, "::", "");
		name = _tmp2_;
		_tmp3_ = self->_attributes;
		_tmp4_ = name;
		_tmp5_ = g_utf8_strdown (_tmp4_, (gssize) -1);
		_tmp6_ = _tmp5_;
		_tmp7_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp3_, _tmp6_);
		_tmp8_ = (GXmlDomNode*) _tmp7_;
		_g_free0 (_tmp6_);
		p = _tmp8_;
		_tmp9_ = p;
		if (_tmp9_ == NULL) {
			GXmlGomProperty* prop = NULL;
			const gchar* _tmp10_;
			GXmlGomStringRef* _tmp11_;
			GXmlGomElementAttributes* _tmp12_;
			const gchar* _tmp13_;
			_tmp10_ = name;
			_tmp11_ = gxml_gom_string_ref_new ((GXmlGomObject*) self, _tmp10_);
			prop = (GXmlGomProperty*) _tmp11_;
			_tmp12_ = self->_attributes;
			_tmp13_ = name;
			gxml_gom_element_attributes_add_reference (_tmp12_, _tmp13_);
			_g_object_unref0 (prop);
		}
		_g_object_unref0 (p);
		_g_free0 (name);
	}
}

static void
__gxml_gom_element___lambda6__g_object_notify (GObject* _sender,
                                               GParamSpec* pspec,
                                               gpointer self)
{
	_gxml_gom_element___lambda6_ ((GXmlGomElement*) self, pspec);
}

static GObject *
gxml_gom_element_constructor (GType type,
                              guint n_construct_properties,
                              GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GXmlGomElement * self;
	GXmlGomElementAttributes* _tmp0_;
	gchar* _tmp1_;
	parent_class = G_OBJECT_CLASS (gxml_gom_element_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GOM_ELEMENT, GXmlGomElement);
	((GXmlGomNode*) self)->_node_type = GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE;
	_tmp0_ = gxml_gom_element_attributes_new (self);
	_g_object_unref0 (self->_attributes);
	self->_attributes = _tmp0_;
	_tmp1_ = g_strdup ("");
	_g_free0 (((GXmlGomNode*) self)->_local_name);
	((GXmlGomNode*) self)->_local_name = _tmp1_;
	g_signal_connect_object ((GObject*) self, "notify", (GCallback) __gxml_gom_element___lambda6__g_object_notify, self, 0);
	return obj;
}

static inline gpointer
gxml_gom_element_attributes_get_instance_private (GXmlGomElementAttributes* self)
{
	return G_STRUCT_MEMBER_P (self, GXmlGomElementAttributes_private_offset);
}

static GXmlDomNode*
gxml_gom_element_attributes_real_item (GXmlDomNamedNodeMap* base,
                                       gint index)
{
	GXmlGomElementAttributes * self;
	GXmlDomNode* result = NULL;
	gboolean _tmp0_ = FALSE;
	glong i = 0L;
	self = (GXmlGomElementAttributes*) base;
	if (index < 0) {
		_tmp0_ = TRUE;
	} else {
		gint _tmp1_;
		gint _tmp2_;
		_tmp1_ = gee_abstract_map_get_size ((GeeAbstractMap*) self);
		_tmp2_ = _tmp1_;
		_tmp0_ = index >= _tmp2_;
	}
	if (_tmp0_) {
		result = NULL;
		return result;
	}
	i = (glong) -1;
	{
		GeeIterator* _e_it = NULL;
		GeeTreeMap* _tmp3_;
		GeeSortedSet* _tmp4_;
		GeeSortedSet* _tmp5_;
		GeeSortedSet* _tmp6_;
		GeeIterator* _tmp7_;
		GeeIterator* _tmp8_;
		_tmp3_ = self->priv->order;
		_tmp4_ = gee_abstract_sorted_map_get_ascending_entries ((GeeAbstractSortedMap*) _tmp3_);
		_tmp5_ = _tmp4_;
		_tmp6_ = _tmp5_;
		_tmp7_ = gee_iterable_iterator ((GeeIterable*) _tmp6_);
		_tmp8_ = _tmp7_;
		_g_object_unref0 (_tmp6_);
		_e_it = _tmp8_;
		while (TRUE) {
			GeeIterator* _tmp9_;
			GeeMapEntry* e = NULL;
			GeeIterator* _tmp10_;
			gpointer _tmp11_;
			glong _tmp12_;
			_tmp9_ = _e_it;
			if (!gee_iterator_next (_tmp9_)) {
				break;
			}
			_tmp10_ = _e_it;
			_tmp11_ = gee_iterator_get (_tmp10_);
			e = (GeeMapEntry*) _tmp11_;
			_tmp12_ = i;
			i = _tmp12_ + 1;
			if (i == ((glong) index)) {
				GXmlDomNode* ret = NULL;
				GeeMapEntry* _tmp13_;
				gconstpointer _tmp14_;
				const gchar* _tmp15_;
				gpointer _tmp16_;
				GeeMapEntry* _tmp17_;
				gconstpointer _tmp18_;
				const gchar* _tmp19_;
				GXmlDomNode* _tmp20_;
				gchar* _tmp21_;
				gchar* _tmp22_;
				gchar* _tmp23_;
				GXmlDomNode* _tmp24_;
				gchar* _tmp25_;
				gchar* _tmp26_;
				gchar* _tmp27_;
				_tmp13_ = e;
				_tmp14_ = gee_map_entry_get_value (_tmp13_);
				_tmp15_ = _tmp14_;
				_tmp16_ = gee_abstract_map_get ((GeeAbstractMap*) self, (const gchar*) _tmp15_);
				ret = (GXmlDomNode*) _tmp16_;
				_tmp17_ = e;
				_tmp18_ = gee_map_entry_get_value (_tmp17_);
				_tmp19_ = _tmp18_;
				_tmp20_ = ret;
				_tmp21_ = gxml_dom_attr_get_value (G_TYPE_CHECK_INSTANCE_TYPE (_tmp20_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp20_) : NULL);
				_tmp22_ = _tmp21_;
				_tmp23_ = _tmp22_;
				_tmp24_ = ret;
				_tmp25_ = gxml_dom_node_get_node_value (_tmp24_);
				_tmp26_ = _tmp25_;
				_tmp27_ = _tmp26_;
				g_message ("GomElement.vala:390: Found %s at %ld - Val=%s - as node val = %s", (const gchar*) _tmp19_, i, _tmp23_, _tmp27_);
				_g_free0 (_tmp27_);
				_g_free0 (_tmp23_);
				result = ret;
				_g_object_unref0 (e);
				_g_object_unref0 (_e_it);
				return result;
			}
			_g_object_unref0 (e);
		}
		_g_object_unref0 (_e_it);
	}
	result = NULL;
	return result;
}

GXmlGomElementAttributes*
gxml_gom_element_attributes_construct (GType object_type,
                                       GXmlGomElement* element)
{
	GXmlGomElementAttributes * self = NULL;
	GXmlGomElement* _tmp0_;
	g_return_val_if_fail (element != NULL, NULL);
	self = (GXmlGomElementAttributes*) gee_hash_map_construct (object_type, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, GXML_TYPE_DOM_NODE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
	_tmp0_ = _g_object_ref0 (element);
	_g_object_unref0 (self->_element);
	self->_element = _tmp0_;
	return self;
}

GXmlGomElementAttributes*
gxml_gom_element_attributes_new (GXmlGomElement* element)
{
	return gxml_gom_element_attributes_construct (GXML_GOM_ELEMENT_TYPE_ATTRIBUTES, element);
}

static GXmlDomNode*
gxml_gom_element_attributes_real_get_named_item (GXmlDomNamedNodeMap* base,
                                                 const gchar* name)
{
	GXmlGomElementAttributes * self;
	GXmlDomNode* result = NULL;
	gchar* ov = NULL;
	GXmlGomElement* _tmp0_;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* p = NULL;
	gchar* _tmp6_;
	gchar* ns = NULL;
	gchar* n = NULL;
	gchar* _tmp7_;
	GXmlDomAttr* prop = NULL;
	const gchar* _tmp29_;
	gpointer _tmp30_;
	GXmlDomNode* _tmp31_;
	GXmlDomAttr* _tmp32_;
	gchar* val = NULL;
	GXmlDomAttr* _tmp33_;
	const gchar* _tmp37_;
	GXmlDomNode* attr = NULL;
	gboolean _tmp38_ = FALSE;
	const gchar* _tmp39_;
	self = (GXmlGomElementAttributes*) base;
	g_return_val_if_fail (name != NULL, NULL);
	if (g_strcmp0 (name, "") == 0) {
		result = NULL;
		return result;
	}
	_tmp0_ = self->_element;
	_tmp1_ = gxml_gom_object_get_attribute (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_GOM_OBJECT) ? ((GXmlGomObject*) _tmp0_) : NULL, name);
	ov = _tmp1_;
	_tmp2_ = ov;
	if (_tmp2_ != NULL) {
		GXmlGomElement* _tmp3_;
		const gchar* _tmp4_;
		GXmlGomAttr* _tmp5_;
		_tmp3_ = self->_element;
		_tmp4_ = ov;
		_tmp5_ = gxml_gom_attr_new ((GXmlDomElement*) _tmp3_, name, _tmp4_);
		result = (GXmlDomNode*) _tmp5_;
		_g_free0 (ov);
		return result;
	}
	_tmp6_ = g_strdup ("");
	p = _tmp6_;
	ns = NULL;
	_tmp7_ = g_utf8_strdown (name, (gssize) -1);
	n = _tmp7_;
	if (string_contains (name, ":")) {
		gchar** s = NULL;
		gchar** _tmp8_;
		gchar** _tmp9_;
		gint s_length1;
		gint _s_size_;
		gchar** _tmp10_;
		gint _tmp10__length1;
		gchar** _tmp11_;
		gint _tmp11__length1;
		const gchar* _tmp12_;
		gchar* _tmp13_;
		gchar** _tmp14_;
		gint _tmp14__length1;
		const gchar* _tmp15_;
		gchar* _tmp16_;
		const gchar* _tmp17_;
		const gchar* _tmp19_;
		gboolean _tmp23_ = FALSE;
		const gchar* _tmp24_;
		_tmp9_ = _tmp8_ = g_strsplit (name, ":", 0);
		s = _tmp9_;
		s_length1 = _vala_array_length (_tmp8_);
		_s_size_ = s_length1;
		_tmp10_ = s;
		_tmp10__length1 = s_length1;
		if (_tmp10__length1 > 2) {
			result = NULL;
			s = (_vala_array_free (s, s_length1, (GDestroyNotify) g_free), NULL);
			_g_free0 (n);
			_g_free0 (ns);
			_g_free0 (p);
			_g_free0 (ov);
			return result;
		}
		_tmp11_ = s;
		_tmp11__length1 = s_length1;
		_tmp12_ = _tmp11_[0];
		_tmp13_ = g_strdup (_tmp12_);
		_g_free0 (p);
		p = _tmp13_;
		_tmp14_ = s;
		_tmp14__length1 = s_length1;
		_tmp15_ = _tmp14_[1];
		_tmp16_ = g_utf8_strdown (_tmp15_, (gssize) -1);
		_g_free0 (n);
		n = _tmp16_;
		_tmp17_ = p;
		if (g_strcmp0 (_tmp17_, "xml") == 0) {
			gchar* _tmp18_;
			_tmp18_ = g_strdup ("http://www.w3.org/2000/xmlns/");
			_g_free0 (ns);
			ns = _tmp18_;
		}
		_tmp19_ = p;
		if (g_strcmp0 (_tmp19_, "xmlns") == 0) {
			GXmlGomElement* _tmp20_;
			const gchar* _tmp21_;
			gchar* _tmp22_;
			_tmp20_ = self->_element;
			_tmp21_ = n;
			_tmp22_ = gxml_gom_element_lookup_namespace_uri (_tmp20_, _tmp21_);
			_g_free0 (ns);
			ns = _tmp22_;
		}
		_tmp24_ = p;
		if (g_strcmp0 (_tmp24_, "xmlns") != 0) {
			const gchar* _tmp25_;
			_tmp25_ = p;
			_tmp23_ = g_strcmp0 (_tmp25_, "xml") != 0;
		} else {
			_tmp23_ = FALSE;
		}
		if (_tmp23_) {
			GXmlGomElement* _tmp26_;
			const gchar* _tmp27_;
			gchar* _tmp28_;
			_tmp26_ = self->_element;
			_tmp27_ = p;
			_tmp28_ = gxml_gom_element_lookup_namespace_uri (_tmp26_, _tmp27_);
			_g_free0 (ns);
			ns = _tmp28_;
		}
		s = (_vala_array_free (s, s_length1, (GDestroyNotify) g_free), NULL);
	}
	_tmp29_ = n;
	_tmp30_ = gee_abstract_map_get ((GeeAbstractMap*) self, _tmp29_);
	_tmp31_ = (GXmlDomNode*) _tmp30_;
	_tmp32_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp31_) : NULL;
	if (_tmp32_ == NULL) {
		_g_object_unref0 (_tmp31_);
	}
	prop = _tmp32_;
	val = NULL;
	_tmp33_ = prop;
	if (_tmp33_ != NULL) {
		GXmlDomAttr* _tmp34_;
		gchar* _tmp35_;
		gchar* _tmp36_;
		_tmp34_ = prop;
		_tmp35_ = gxml_dom_attr_get_value (_tmp34_);
		_tmp36_ = _tmp35_;
		_g_free0 (val);
		val = _tmp36_;
	}
	_tmp37_ = val;
	if (_tmp37_ == NULL) {
		result = NULL;
		_g_free0 (val);
		_g_object_unref0 (prop);
		_g_free0 (n);
		_g_free0 (ns);
		_g_free0 (p);
		_g_free0 (ov);
		return result;
	}
	attr = NULL;
	_tmp39_ = p;
	if (_tmp39_ == NULL) {
		_tmp38_ = TRUE;
	} else {
		const gchar* _tmp40_;
		_tmp40_ = p;
		_tmp38_ = g_strcmp0 (_tmp40_, "") == 0;
	}
	if (_tmp38_) {
		GXmlGomElement* _tmp41_;
		const gchar* _tmp42_;
		const gchar* _tmp43_;
		GXmlGomAttr* _tmp44_;
		_tmp41_ = self->_element;
		_tmp42_ = n;
		_tmp43_ = val;
		_tmp44_ = gxml_gom_attr_new ((GXmlDomElement*) _tmp41_, _tmp42_, _tmp43_);
		_g_object_unref0 (attr);
		attr = (GXmlDomNode*) _tmp44_;
	} else {
		GXmlGomElement* _tmp45_;
		const gchar* _tmp46_;
		const gchar* _tmp47_;
		const gchar* _tmp48_;
		const gchar* _tmp49_;
		GXmlGomAttr* _tmp50_;
		_tmp45_ = self->_element;
		_tmp46_ = ns;
		_tmp47_ = p;
		_tmp48_ = n;
		_tmp49_ = val;
		_tmp50_ = gxml_gom_attr_new_namespace ((GXmlDomElement*) _tmp45_, _tmp46_, _tmp47_, _tmp48_, _tmp49_);
		_g_object_unref0 (attr);
		attr = (GXmlDomNode*) _tmp50_;
	}
	result = attr;
	_g_free0 (val);
	_g_object_unref0 (prop);
	_g_free0 (n);
	_g_free0 (ns);
	_g_free0 (p);
	_g_free0 (ov);
	return result;
}

/**
     * Takes given {@link DomNode} as a {@link DomAttr} and use its name and
     * value to set a property in {@link DomElement} ignoring node's prefix and
     * namespace
     */
static GXmlDomNode*
gxml_gom_element_attributes_real_set_named_item (GXmlDomNamedNodeMap* base,
                                                 GXmlDomNode* node,
                                                 GError** error)
{
	GXmlGomElementAttributes * self;
	GXmlDomNode* result = NULL;
	gboolean _tmp0_ = FALSE;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gboolean _tmp4_;
	GXmlGomAttr* attr = NULL;
	GParamSpec* pprop = NULL;
	GXmlGomElement* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	GParamSpec* _tmp18_;
	GParamSpec* _tmp19_;
	GParamSpec* _tmp20_;
	GXmlGomAttr* _tmp41_;
	gchar* _tmp42_;
	gchar* _tmp43_;
	gchar* _tmp44_;
	gchar* _tmp45_;
	gchar* _tmp46_;
	GXmlGomAttr* _tmp47_;
	GeeTreeMap* _tmp48_;
	gint _tmp49_;
	gint _tmp50_;
	gchar* _tmp51_;
	gchar* _tmp52_;
	gchar* _tmp53_;
	gchar* _tmp54_;
	gchar* _tmp55_;
	GError* _inner_error0_ = NULL;
	self = (GXmlGomElementAttributes*) base;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp1_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_;
	_tmp4_ = string_contains (_tmp3_, ":");
	_g_free0 (_tmp3_);
	if (_tmp4_) {
		_tmp0_ = TRUE;
	} else {
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		_tmp5_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp6_ = _tmp5_;
		_tmp7_ = _tmp6_;
		_tmp0_ = g_strcmp0 (_tmp7_, "") == 0;
		_g_free0 (_tmp7_);
	}
	if (_tmp0_) {
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		GError* _tmp11_;
		GError* _tmp12_;
		_tmp8_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp9_ = _tmp8_;
		_tmp10_ = _tmp9_;
		_tmp11_ = g_error_new (GXML_DOM_ERROR, GXML_DOM_ERROR_INVALID_CHARACTER_ERROR, _ ("Invalid attribute name: %s"), _tmp10_);
		_tmp12_ = _tmp11_;
		_g_free0 (_tmp10_);
		_inner_error0_ = _tmp12_;
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	if (!G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR)) {
		GError* _tmp13_;
		_tmp13_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR, _ ("Invalid node type. DomAttr was expected"));
		_inner_error0_ = _tmp13_;
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	attr = NULL;
	_tmp14_ = self->_element;
	_tmp15_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
	_tmp16_ = _tmp15_;
	_tmp17_ = _tmp16_;
	_tmp18_ = gxml_gom_object_find_property_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp14_, GXML_TYPE_GOM_OBJECT) ? ((GXmlGomObject*) _tmp14_) : NULL, _tmp17_);
	_tmp19_ = _tmp18_;
	_g_free0 (_tmp17_);
	pprop = _tmp19_;
	_tmp20_ = pprop;
	if (_tmp20_ != NULL) {
		GXmlGomElement* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		GXmlGomElement* _tmp28_;
		gchar* _tmp29_;
		gchar* _tmp30_;
		gchar* _tmp31_;
		GXmlGomAttr* _tmp32_;
		_tmp21_ = self->_element;
		_tmp22_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp23_ = _tmp22_;
		_tmp24_ = _tmp23_;
		_tmp25_ = gxml_dom_node_get_node_value (node);
		_tmp26_ = _tmp25_;
		_tmp27_ = _tmp26_;
		gxml_gom_object_set_attribute (G_TYPE_CHECK_INSTANCE_TYPE (_tmp21_, GXML_TYPE_GOM_OBJECT) ? ((GXmlGomObject*) _tmp21_) : NULL, _tmp24_, _tmp27_);
		_g_free0 (_tmp27_);
		_g_free0 (_tmp24_);
		_tmp28_ = self->_element;
		_tmp29_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp30_ = _tmp29_;
		_tmp31_ = _tmp30_;
		_tmp32_ = gxml_gom_attr_new_reference ((GXmlDomElement*) _tmp28_, _tmp31_);
		_g_object_unref0 (attr);
		attr = _tmp32_;
		_g_free0 (_tmp31_);
	} else {
		GXmlGomElement* _tmp33_;
		gchar* _tmp34_;
		gchar* _tmp35_;
		gchar* _tmp36_;
		gchar* _tmp37_;
		gchar* _tmp38_;
		gchar* _tmp39_;
		GXmlGomAttr* _tmp40_;
		_tmp33_ = self->_element;
		_tmp34_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp35_ = _tmp34_;
		_tmp36_ = _tmp35_;
		_tmp37_ = gxml_dom_node_get_node_value (node);
		_tmp38_ = _tmp37_;
		_tmp39_ = _tmp38_;
		_tmp40_ = gxml_gom_attr_new ((GXmlDomElement*) _tmp33_, _tmp36_, _tmp39_);
		_g_object_unref0 (attr);
		attr = _tmp40_;
		_g_free0 (_tmp39_);
		_g_free0 (_tmp36_);
	}
	_tmp41_ = attr;
	_tmp42_ = gxml_dom_attr_get_local_name ((GXmlDomAttr*) _tmp41_);
	_tmp43_ = _tmp42_;
	_tmp44_ = _tmp43_;
	_tmp45_ = g_utf8_strdown (_tmp44_, (gssize) -1);
	_tmp46_ = _tmp45_;
	_tmp47_ = attr;
	gee_abstract_map_set ((GeeAbstractMap*) self, _tmp46_, (GXmlDomNode*) _tmp47_);
	_g_free0 (_tmp46_);
	_g_free0 (_tmp44_);
	_tmp48_ = self->priv->order;
	_tmp49_ = gee_abstract_map_get_size ((GeeAbstractMap*) self);
	_tmp50_ = _tmp49_;
	_tmp51_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
	_tmp52_ = _tmp51_;
	_tmp53_ = _tmp52_;
	_tmp54_ = g_utf8_strdown (_tmp53_, (gssize) -1);
	_tmp55_ = _tmp54_;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp48_, (gpointer) ((gintptr) ((glong) (_tmp50_ - 1))), _tmp55_);
	_g_free0 (_tmp55_);
	_g_free0 (_tmp53_);
	result = (GXmlDomNode*) attr;
	_g_param_spec_unref0 (pprop);
	return result;
}

static GXmlDomNode*
gxml_gom_element_attributes_real_remove_named_item (GXmlDomNamedNodeMap* base,
                                                    const gchar* name,
                                                    GError** error)
{
	GXmlGomElementAttributes * self;
	GXmlDomNode* result = NULL;
	gchar* val = NULL;
	GXmlDomAttr* prop = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gpointer _tmp2_;
	GXmlDomNode* _tmp3_;
	GXmlDomAttr* _tmp4_;
	GXmlDomAttr* _tmp5_;
	GXmlDomAttr* _tmp6_;
	GXmlDomAttr* _tmp16_;
	GXmlDomNode* _tmp17_;
	self = (GXmlGomElementAttributes*) base;
	g_return_val_if_fail (name != NULL, NULL);
	if (string_contains (name, ":")) {
		result = NULL;
		return result;
	}
	val = NULL;
	_tmp0_ = g_utf8_strdown (name, (gssize) -1);
	_tmp1_ = _tmp0_;
	_tmp2_ = gee_abstract_map_get ((GeeAbstractMap*) self, _tmp1_);
	_tmp3_ = (GXmlDomNode*) _tmp2_;
	_tmp4_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp3_) : NULL;
	if (_tmp4_ == NULL) {
		_g_object_unref0 (_tmp3_);
	}
	_tmp5_ = _tmp4_;
	_g_free0 (_tmp1_);
	prop = _tmp5_;
	_tmp6_ = prop;
	if (_tmp6_ != NULL) {
		GXmlDomAttr* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		GXmlDomAttr* _tmp10_;
		glong i = 0L;
		gchar* _tmp11_;
		gchar* _tmp12_;
		_tmp7_ = prop;
		_tmp8_ = gxml_dom_attr_get_value (_tmp7_);
		_tmp9_ = _tmp8_;
		_g_free0 (val);
		val = _tmp9_;
		_tmp10_ = prop;
		gxml_dom_attr_set_value (_tmp10_, NULL);
		i = gxml_gom_element_attributes_index_of (self, name);
		_tmp11_ = g_utf8_strdown (name, (gssize) -1);
		_tmp12_ = _tmp11_;
		gee_abstract_map_unset ((GeeAbstractMap*) self, _tmp12_, NULL);
		_g_free0 (_tmp12_);
		if (i < ((glong) 0)) {
			gchar* _tmp13_;
			gchar* _tmp14_;
			_tmp13_ = g_strdup_printf (_ ("No index found for attribute %s"), name);
			_tmp14_ = _tmp13_;
			g_warning ("GomElement.vala:469: %s", _tmp14_);
			_g_free0 (_tmp14_);
		} else {
			GeeTreeMap* _tmp15_;
			_tmp15_ = self->priv->order;
			gee_abstract_map_unset ((GeeAbstractMap*) _tmp15_, (gpointer) ((gintptr) i), NULL);
		}
	}
	_tmp16_ = prop;
	_tmp17_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp16_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp16_) : NULL);
	result = _tmp17_;
	_g_object_unref0 (prop);
	_g_free0 (val);
	return result;
}

static GXmlDomNode*
gxml_gom_element_attributes_real_remove_named_item_ns (GXmlDomNamedNodeMap* base,
                                                       const gchar* namespace_uri,
                                                       const gchar* local_name,
                                                       GError** error)
{
	GXmlGomElementAttributes * self;
	GXmlDomNode* result = NULL;
	gchar* nsp = NULL;
	GXmlGomElement* _tmp0_;
	gchar* _tmp1_;
	gboolean _tmp2_ = FALSE;
	const gchar* _tmp3_;
	GXmlDomAttr* v = NULL;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	gpointer _tmp12_;
	GXmlDomNode* _tmp13_;
	GXmlDomAttr* _tmp14_;
	GXmlDomAttr* _tmp15_;
	GXmlDomAttr* _tmp16_;
	gchar* k = NULL;
	const gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	gchar* _tmp21_;
	gchar* _tmp22_;
	gchar* _tmp23_;
	GXmlDomAttr* _tmp24_;
	const gchar* _tmp25_;
	glong i = 0L;
	const gchar* _tmp26_;
	GXmlDomAttr* _tmp31_;
	GXmlDomNode* _tmp32_;
	self = (GXmlGomElementAttributes*) base;
	g_return_val_if_fail (namespace_uri != NULL, NULL);
	g_return_val_if_fail (local_name != NULL, NULL);
	if (string_contains (local_name, ":")) {
		result = NULL;
		return result;
	}
	_tmp0_ = self->_element;
	_tmp1_ = gxml_gom_element_lookup_prefix (_tmp0_, namespace_uri);
	nsp = _tmp1_;
	_tmp3_ = nsp;
	if (_tmp3_ == NULL) {
		_tmp2_ = TRUE;
	} else {
		const gchar* _tmp4_;
		_tmp4_ = nsp;
		_tmp2_ = g_strcmp0 (_tmp4_, "") == 0;
	}
	if (_tmp2_) {
		result = NULL;
		_g_free0 (nsp);
		return result;
	}
	_tmp5_ = nsp;
	_tmp6_ = g_strconcat (_tmp5_, ":", NULL);
	_tmp7_ = _tmp6_;
	_tmp8_ = g_strconcat (_tmp7_, local_name, NULL);
	_tmp9_ = _tmp8_;
	_tmp10_ = g_utf8_strdown (_tmp9_, (gssize) -1);
	_tmp11_ = _tmp10_;
	_tmp12_ = gee_abstract_map_get ((GeeAbstractMap*) self, _tmp11_);
	_tmp13_ = (GXmlDomNode*) _tmp12_;
	_tmp14_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp13_) : NULL;
	if (_tmp14_ == NULL) {
		_g_object_unref0 (_tmp13_);
	}
	_tmp15_ = _tmp14_;
	_g_free0 (_tmp11_);
	_g_free0 (_tmp9_);
	_g_free0 (_tmp7_);
	v = _tmp15_;
	_tmp16_ = v;
	if (_tmp16_ == NULL) {
		result = NULL;
		_g_object_unref0 (v);
		_g_free0 (nsp);
		return result;
	}
	_tmp17_ = nsp;
	_tmp18_ = g_strconcat (_tmp17_, ":", NULL);
	_tmp19_ = _tmp18_;
	_tmp20_ = g_strconcat (_tmp19_, local_name, NULL);
	_tmp21_ = _tmp20_;
	_tmp22_ = g_utf8_strdown (_tmp21_, (gssize) -1);
	_tmp23_ = _tmp22_;
	_g_free0 (_tmp21_);
	_g_free0 (_tmp19_);
	k = _tmp23_;
	_tmp24_ = v;
	gxml_dom_attr_set_value (_tmp24_, NULL);
	_tmp25_ = k;
	gee_abstract_map_unset ((GeeAbstractMap*) self, _tmp25_, NULL);
	_tmp26_ = k;
	i = gxml_gom_element_attributes_index_of (self, _tmp26_);
	if (i < ((glong) 0)) {
		const gchar* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
		_tmp27_ = k;
		_tmp28_ = g_strdup_printf (_ ("No index found for attribute %s"), _tmp27_);
		_tmp29_ = _tmp28_;
		g_warning ("GomElement.vala:488: %s", _tmp29_);
		_g_free0 (_tmp29_);
	} else {
		GeeTreeMap* _tmp30_;
		_tmp30_ = self->priv->order;
		gee_abstract_map_unset ((GeeAbstractMap*) _tmp30_, (gpointer) ((gintptr) i), NULL);
	}
	_tmp31_ = v;
	_tmp32_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp31_) : NULL);
	result = _tmp32_;
	_g_free0 (k);
	_g_object_unref0 (v);
	_g_free0 (nsp);
	return result;
}

static GXmlDomNode*
gxml_gom_element_attributes_real_get_named_item_ns (GXmlDomNamedNodeMap* base,
                                                    const gchar* namespace_uri,
                                                    const gchar* local_name,
                                                    GError** error)
{
	GXmlGomElementAttributes * self;
	GXmlDomNode* result = NULL;
	gchar* nsp = NULL;
	GXmlGomElement* _tmp0_;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	GXmlDomNode* v = NULL;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gpointer _tmp10_;
	GXmlDomNode* _tmp11_;
	self = (GXmlGomElementAttributes*) base;
	g_return_val_if_fail (namespace_uri != NULL, NULL);
	g_return_val_if_fail (local_name != NULL, NULL);
	if (string_contains (local_name, ":")) {
		result = NULL;
		return result;
	}
	_tmp0_ = self->_element;
	_tmp1_ = gxml_gom_element_lookup_prefix (_tmp0_, namespace_uri);
	nsp = _tmp1_;
	_tmp2_ = nsp;
	if (_tmp2_ == NULL) {
		result = NULL;
		_g_free0 (nsp);
		return result;
	}
	_tmp3_ = nsp;
	_tmp4_ = g_strconcat (_tmp3_, ":", NULL);
	_tmp5_ = _tmp4_;
	_tmp6_ = g_strconcat (_tmp5_, local_name, NULL);
	_tmp7_ = _tmp6_;
	_tmp8_ = g_utf8_strdown (_tmp7_, (gssize) -1);
	_tmp9_ = _tmp8_;
	_tmp10_ = gee_abstract_map_get ((GeeAbstractMap*) self, _tmp9_);
	_tmp11_ = (GXmlDomNode*) _tmp10_;
	_g_free0 (_tmp9_);
	_g_free0 (_tmp7_);
	_g_free0 (_tmp5_);
	v = _tmp11_;
	result = v;
	_g_free0 (nsp);
	return result;
}

static GXmlDomNode*
gxml_gom_element_attributes_real_set_named_item_ns (GXmlDomNamedNodeMap* base,
                                                    GXmlDomNode* node,
                                                    GError** error)
{
	GXmlGomElementAttributes * self;
	GXmlDomNode* result = NULL;
	gboolean _tmp0_ = FALSE;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp14_ = FALSE;
	gboolean _tmp15_ = FALSE;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gboolean _tmp19_;
	gboolean _tmp27_ = FALSE;
	gchar* _tmp28_;
	gchar* _tmp29_;
	gchar* _tmp30_;
	gboolean _tmp31_;
	gboolean _tmp57_ = FALSE;
	gchar* _tmp58_;
	gchar* _tmp59_;
	gchar* _tmp60_;
	gboolean _tmp61_;
	gboolean _tmp66_ = FALSE;
	gchar* _tmp67_;
	gchar* _tmp68_;
	gchar* _tmp69_;
	gboolean _tmp70_;
	gboolean _tmp85_ = FALSE;
	gchar* _tmp86_;
	gchar* _tmp87_;
	gchar* _tmp88_;
	gboolean _tmp89_;
	gboolean _tmp146_ = FALSE;
	gchar* _tmp147_;
	gchar* _tmp148_;
	gchar* _tmp149_;
	gboolean _tmp150_;
	gchar* p = NULL;
	gchar* _tmp199_;
	gboolean _tmp200_ = FALSE;
	gchar* _tmp201_;
	gchar* _tmp202_;
	gchar* _tmp203_;
	gboolean _tmp204_;
	gchar* k = NULL;
	const gchar* _tmp212_;
	gchar* _tmp213_;
	gchar* _tmp214_;
	gchar* _tmp215_;
	gchar* _tmp216_;
	gchar* _tmp217_;
	gchar* _tmp218_;
	gchar* _tmp219_;
	GXmlGomAttr* attr = NULL;
	GParamSpec* pprop = NULL;
	GXmlGomElement* _tmp220_;
	gchar* _tmp221_;
	gchar* _tmp222_;
	gchar* _tmp223_;
	GParamSpec* _tmp224_;
	GParamSpec* _tmp225_;
	GParamSpec* _tmp226_;
	const gchar* _tmp253_;
	GXmlGomAttr* _tmp254_;
	GeeTreeMap* _tmp255_;
	gint _tmp256_;
	gint _tmp257_;
	const gchar* _tmp258_;
	GError* _inner_error0_ = NULL;
	self = (GXmlGomElementAttributes*) base;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp1_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_;
	_tmp4_ = g_strcmp0 (_tmp3_, "") == 0;
	_g_free0 (_tmp3_);
	if (_tmp4_) {
		_tmp0_ = TRUE;
	} else {
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		_tmp5_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp6_ = _tmp5_;
		_tmp7_ = _tmp6_;
		_tmp0_ = string_contains (_tmp7_, ":");
		_g_free0 (_tmp7_);
	}
	if (_tmp0_) {
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		GError* _tmp11_;
		GError* _tmp12_;
		_tmp8_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp9_ = _tmp8_;
		_tmp10_ = _tmp9_;
		_tmp11_ = g_error_new (GXML_DOM_ERROR, GXML_DOM_ERROR_INVALID_CHARACTER_ERROR, _ ("Invalid attribute name: %s"), _tmp10_);
		_tmp12_ = _tmp11_;
		_g_free0 (_tmp10_);
		_inner_error0_ = _tmp12_;
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	if (!G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR)) {
		GError* _tmp13_;
		_tmp13_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR, _ ("Invalid node type. DomAttr was expected"));
		_inner_error0_ = _tmp13_;
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	_tmp16_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
	_tmp17_ = _tmp16_;
	_tmp18_ = _tmp17_;
	_tmp19_ = g_strcmp0 (_tmp18_, "xmlns") == 0;
	_g_free0 (_tmp18_);
	if (_tmp19_) {
		gchar* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
		_tmp20_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp21_ = _tmp20_;
		_tmp22_ = _tmp21_;
		_tmp15_ = g_strcmp0 (_tmp22_, "http://www.w3.org/2000/xmlns/") != 0;
		_g_free0 (_tmp22_);
	} else {
		_tmp15_ = FALSE;
	}
	if (_tmp15_) {
		gchar* _tmp23_;
		gchar* _tmp24_;
		gchar* _tmp25_;
		_tmp23_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp24_ = _tmp23_;
		_tmp25_ = _tmp24_;
		_tmp14_ = g_strcmp0 (_tmp25_, "http://www.w3.org/2000/xmlns") != 0;
		_g_free0 (_tmp25_);
	} else {
		_tmp14_ = FALSE;
	}
	if (_tmp14_) {
		GError* _tmp26_;
		_tmp26_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _ ("Namespace attributes prefixed with xmlns should use a namespace uri ht" \
"tp://www.w3.org/2000/xmlns"));
		_inner_error0_ = _tmp26_;
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	_tmp28_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
	_tmp29_ = _tmp28_;
	_tmp30_ = _tmp29_;
	_tmp31_ = g_strcmp0 (_tmp30_, "") == 0;
	_g_free0 (_tmp30_);
	if (_tmp31_) {
		_tmp27_ = TRUE;
	} else {
		gboolean _tmp32_ = FALSE;
		gchar* _tmp33_;
		gchar* _tmp34_;
		gchar* _tmp35_;
		gboolean _tmp36_;
		_tmp33_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp34_ = _tmp33_;
		_tmp35_ = _tmp34_;
		_tmp36_ = _tmp35_ == NULL;
		_g_free0 (_tmp35_);
		if (_tmp36_) {
			gchar* _tmp37_;
			gchar* _tmp38_;
			gchar* _tmp39_;
			_tmp37_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
			_tmp38_ = _tmp37_;
			_tmp39_ = _tmp38_;
			_tmp32_ = g_strcmp0 (_tmp39_, "xmlns") != 0;
			_g_free0 (_tmp39_);
		} else {
			_tmp32_ = FALSE;
		}
		_tmp27_ = _tmp32_;
	}
	if (_tmp27_) {
		gchar* s = NULL;
		gchar* _tmp40_;
		gchar* _tmp41_;
		gchar* _tmp42_;
		gchar* _tmp43_;
		gchar* _tmp44_;
		gboolean _tmp45_;
		const gchar* _tmp55_;
		GError* _tmp56_;
		_tmp40_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp41_ = _tmp40_;
		s = _tmp41_;
		_tmp42_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp43_ = _tmp42_;
		_tmp44_ = _tmp43_;
		_tmp45_ = _tmp44_ != NULL;
		_g_free0 (_tmp44_);
		if (_tmp45_) {
			const gchar* _tmp46_;
			gchar* _tmp47_;
			gchar* _tmp48_;
			gchar* _tmp49_;
			gchar* _tmp50_;
			gchar* _tmp51_;
			gchar* _tmp52_;
			gchar* _tmp53_;
			gchar* _tmp54_;
			_tmp46_ = s;
			_tmp47_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
			_tmp48_ = _tmp47_;
			_tmp49_ = _tmp48_;
			_tmp50_ = g_strconcat ("=<", _tmp49_, NULL);
			_tmp51_ = _tmp50_;
			_tmp52_ = g_strconcat (_tmp51_, ">", NULL);
			_tmp53_ = _tmp52_;
			_tmp54_ = g_strconcat (_tmp46_, _tmp53_, NULL);
			_g_free0 (s);
			s = _tmp54_;
			_g_free0 (_tmp53_);
			_g_free0 (_tmp51_);
			_g_free0 (_tmp49_);
		}
		_tmp55_ = s;
		_tmp56_ = g_error_new (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _ ("Namespaced attributes should provide a non-null, non-empty prefix: %s"), _tmp55_);
		_inner_error0_ = _tmp56_;
		g_propagate_error (error, _inner_error0_);
		_g_free0 (s);
		return NULL;
	}
	_tmp58_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
	_tmp59_ = _tmp58_;
	_tmp60_ = _tmp59_;
	_tmp61_ = g_strcmp0 (_tmp60_, "xmlns") == 0;
	_g_free0 (_tmp60_);
	if (_tmp61_) {
		gchar* _tmp62_;
		gchar* _tmp63_;
		gchar* _tmp64_;
		_tmp62_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp63_ = _tmp62_;
		_tmp64_ = _tmp63_;
		_tmp57_ = g_strcmp0 (_tmp64_, "xmlns") == 0;
		_g_free0 (_tmp64_);
	} else {
		_tmp57_ = FALSE;
	}
	if (_tmp57_) {
		GError* _tmp65_;
		_tmp65_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _ ("Invalid namespace attribute's name."));
		_inner_error0_ = _tmp65_;
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	_tmp67_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
	_tmp68_ = _tmp67_;
	_tmp69_ = _tmp68_;
	_tmp70_ = g_strcmp0 (_tmp69_, "xmlns") == 0;
	_g_free0 (_tmp69_);
	if (_tmp70_) {
		_tmp66_ = TRUE;
	} else {
		gchar* _tmp71_;
		gchar* _tmp72_;
		gchar* _tmp73_;
		_tmp71_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp72_ = _tmp71_;
		_tmp73_ = _tmp72_;
		_tmp66_ = g_strcmp0 (_tmp73_, "xmlns") == 0;
		_g_free0 (_tmp73_);
	}
	if (_tmp66_) {
		gchar* asp = NULL;
		GXmlGomElement* _tmp74_;
		gchar* _tmp75_;
		gchar* _tmp76_;
		gchar* _tmp77_;
		gchar* _tmp78_;
		gchar* _tmp79_;
		gchar* _tmp80_;
		gchar* _tmp81_;
		gchar* _tmp82_;
		const gchar* _tmp83_;
		_tmp74_ = self->_element;
		_tmp75_ = gxml_dom_node_get_node_value (node);
		_tmp76_ = _tmp75_;
		_tmp77_ = _tmp76_;
		_tmp78_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp79_ = _tmp78_;
		_tmp80_ = _tmp79_;
		_tmp81_ = gxml_dom_element_get_attribute_ns ((GXmlDomElement*) _tmp74_, _tmp77_, _tmp80_);
		_tmp82_ = _tmp81_;
		_g_free0 (_tmp80_);
		_g_free0 (_tmp77_);
		asp = _tmp82_;
		_tmp83_ = asp;
		if (_tmp83_ != NULL) {
			GXmlDomNode* _tmp84_;
			_tmp84_ = _g_object_ref0 (node);
			result = _tmp84_;
			_g_free0 (asp);
			return result;
		}
		_g_free0 (asp);
	}
	_tmp86_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
	_tmp87_ = _tmp86_;
	_tmp88_ = _tmp87_;
	_tmp89_ = g_strcmp0 (_tmp88_, "http://www.w3.org/2000/xmlns/") == 0;
	_g_free0 (_tmp88_);
	if (_tmp89_) {
		_tmp85_ = TRUE;
	} else {
		gchar* _tmp90_;
		gchar* _tmp91_;
		gchar* _tmp92_;
		_tmp90_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp91_ = _tmp90_;
		_tmp92_ = _tmp91_;
		_tmp85_ = g_strcmp0 (_tmp92_, "http://www.w3.org/2000/xmlns") == 0;
		_g_free0 (_tmp92_);
	}
	if (_tmp85_) {
		gchar* _tmp93_;
		gchar* _tmp94_;
		gchar* _tmp95_;
		gboolean _tmp96_;
		gchar* _tmp108_;
		gchar* _tmp109_;
		gchar* _tmp110_;
		gboolean _tmp111_;
		_tmp93_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp94_ = _tmp93_;
		_tmp95_ = _tmp94_;
		_tmp96_ = g_strcmp0 (_tmp95_, "xmlns") == 0;
		_g_free0 (_tmp95_);
		if (_tmp96_) {
			gchar* ns_uri = NULL;
			GXmlGomElement* _tmp97_;
			gchar* _tmp98_;
			gboolean _tmp99_ = FALSE;
			const gchar* _tmp100_;
			_tmp97_ = self->_element;
			_tmp98_ = gxml_gom_element_lookup_namespace_uri (_tmp97_, NULL);
			ns_uri = _tmp98_;
			_tmp100_ = ns_uri;
			if (_tmp100_ != NULL) {
				const gchar* _tmp101_;
				gchar* _tmp102_;
				gchar* _tmp103_;
				gchar* _tmp104_;
				_tmp101_ = ns_uri;
				_tmp102_ = gxml_dom_node_get_node_value (node);
				_tmp103_ = _tmp102_;
				_tmp104_ = _tmp103_;
				_tmp99_ = g_strcmp0 (_tmp101_, _tmp104_) != 0;
				_g_free0 (_tmp104_);
			} else {
				_tmp99_ = FALSE;
			}
			if (_tmp99_) {
				const gchar* _tmp105_;
				gchar* _tmp106_;
				gchar* _tmp107_;
				_tmp105_ = ns_uri;
				_tmp106_ = g_strdup_printf (_ ("Duplicated default namespace detected with URI: %s"), _tmp105_);
				_tmp107_ = _tmp106_;
				g_message ("GomElement.vala:535: %s", _tmp107_);
				_g_free0 (_tmp107_);
			}
			_g_free0 (ns_uri);
		}
		_tmp108_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp109_ = _tmp108_;
		_tmp110_ = _tmp109_;
		_tmp111_ = g_strcmp0 (_tmp110_, "xmlns") == 0;
		_g_free0 (_tmp110_);
		if (_tmp111_) {
			gchar* nsprefix = NULL;
			GXmlGomElement* _tmp112_;
			gchar* _tmp113_;
			gchar* _tmp114_;
			gchar* _tmp115_;
			gchar* _tmp116_;
			gchar* _tmp117_;
			gchar* nsuri = NULL;
			GXmlGomElement* _tmp118_;
			gchar* _tmp119_;
			gchar* _tmp120_;
			gchar* _tmp121_;
			gchar* _tmp122_;
			gchar* _tmp123_;
			gboolean _tmp124_ = FALSE;
			gboolean _tmp125_ = FALSE;
			const gchar* _tmp126_;
			_tmp112_ = self->_element;
			_tmp113_ = gxml_dom_node_get_node_value (node);
			_tmp114_ = _tmp113_;
			_tmp115_ = _tmp114_;
			_tmp116_ = gxml_gom_element_lookup_prefix (_tmp112_, _tmp115_);
			_tmp117_ = _tmp116_;
			_g_free0 (_tmp115_);
			nsprefix = _tmp117_;
			_tmp118_ = self->_element;
			_tmp119_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
			_tmp120_ = _tmp119_;
			_tmp121_ = _tmp120_;
			_tmp122_ = gxml_gom_element_lookup_namespace_uri (_tmp118_, _tmp121_);
			_tmp123_ = _tmp122_;
			_g_free0 (_tmp121_);
			nsuri = _tmp123_;
			_tmp126_ = nsprefix;
			if (_tmp126_ != NULL) {
				_tmp125_ = TRUE;
			} else {
				const gchar* _tmp127_;
				_tmp127_ = nsuri;
				_tmp125_ = _tmp127_ != NULL;
			}
			if (_tmp125_) {
				gboolean _tmp128_ = FALSE;
				const gchar* _tmp129_;
				gchar* _tmp130_;
				gchar* _tmp131_;
				gchar* _tmp132_;
				gboolean _tmp133_;
				_tmp129_ = nsprefix;
				_tmp130_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
				_tmp131_ = _tmp130_;
				_tmp132_ = _tmp131_;
				_tmp133_ = g_strcmp0 (_tmp129_, _tmp132_) != 0;
				_g_free0 (_tmp132_);
				if (_tmp133_) {
					_tmp128_ = TRUE;
				} else {
					const gchar* _tmp134_;
					gchar* _tmp135_;
					gchar* _tmp136_;
					gchar* _tmp137_;
					_tmp134_ = nsuri;
					_tmp135_ = gxml_dom_node_get_node_value (node);
					_tmp136_ = _tmp135_;
					_tmp137_ = _tmp136_;
					_tmp128_ = g_strcmp0 (_tmp134_, _tmp137_) != 0;
					_g_free0 (_tmp137_);
				}
				_tmp124_ = _tmp128_;
			} else {
				_tmp124_ = FALSE;
			}
			if (_tmp124_) {
				gchar* _tmp138_;
				gchar* _tmp139_;
				gchar* _tmp140_;
				gchar* _tmp141_;
				gchar* _tmp142_;
				gchar* _tmp143_;
				gchar* _tmp144_;
				gchar* _tmp145_;
				_tmp138_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
				_tmp139_ = _tmp138_;
				_tmp140_ = _tmp139_;
				_tmp141_ = gxml_dom_node_get_node_value (node);
				_tmp142_ = _tmp141_;
				_tmp143_ = _tmp142_;
				_tmp144_ = g_strdup_printf (_ ("Duplicated namespace detected for: %s:%s"), _tmp140_, _tmp143_);
				_tmp145_ = _tmp144_;
				g_message ("GomElement.vala:544: %s", _tmp145_);
				_g_free0 (_tmp145_);
				_g_free0 (_tmp143_);
				_g_free0 (_tmp140_);
			}
			_g_free0 (nsuri);
			_g_free0 (nsprefix);
		}
	}
	_tmp147_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
	_tmp148_ = _tmp147_;
	_tmp149_ = _tmp148_;
	_tmp150_ = g_strcmp0 (_tmp149_, "http://www.w3.org/2000/xmlns/") != 0;
	_g_free0 (_tmp149_);
	if (_tmp150_) {
		gchar* _tmp151_;
		gchar* _tmp152_;
		gchar* _tmp153_;
		_tmp151_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp152_ = _tmp151_;
		_tmp153_ = _tmp152_;
		_tmp146_ = g_strcmp0 (_tmp153_, "http://www.w3.org/2000/xmlns") != 0;
		_g_free0 (_tmp153_);
	} else {
		_tmp146_ = FALSE;
	}
	if (_tmp146_) {
		gchar* nsn = NULL;
		GXmlGomElement* _tmp154_;
		gchar* _tmp155_;
		gchar* _tmp156_;
		gchar* _tmp157_;
		gchar* _tmp158_;
		gchar* _tmp159_;
		gchar* nspn = NULL;
		GXmlGomElement* _tmp160_;
		const gchar* _tmp161_;
		gchar* _tmp162_;
		gboolean _tmp163_ = FALSE;
		const gchar* _tmp164_;
		gchar* _tmp165_;
		gchar* _tmp166_;
		gchar* _tmp167_;
		gboolean _tmp168_;
		GXmlGomElement* _tmp180_;
		gchar* _tmp181_;
		gchar* _tmp182_;
		gchar* _tmp183_;
		gchar* _tmp184_;
		GXmlGomElement* _tmp185_;
		const gchar* _tmp186_;
		gchar* _tmp187_;
		gboolean _tmp188_ = FALSE;
		const gchar* _tmp189_;
		gchar* _tmp190_;
		gchar* _tmp191_;
		gchar* _tmp192_;
		gboolean _tmp193_;
		_tmp154_ = self->_element;
		_tmp155_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp156_ = _tmp155_;
		_tmp157_ = _tmp156_;
		_tmp158_ = gxml_gom_element_lookup_namespace_uri (_tmp154_, _tmp157_);
		_tmp159_ = _tmp158_;
		_g_free0 (_tmp157_);
		nsn = _tmp159_;
		_tmp160_ = self->_element;
		_tmp161_ = nsn;
		_tmp162_ = gxml_gom_element_lookup_prefix (_tmp160_, _tmp161_);
		nspn = _tmp162_;
		_tmp164_ = nspn;
		_tmp165_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp166_ = _tmp165_;
		_tmp167_ = _tmp166_;
		_tmp168_ = g_strcmp0 (_tmp164_, _tmp167_) != 0;
		_g_free0 (_tmp167_);
		if (_tmp168_) {
			const gchar* _tmp169_;
			gchar* _tmp170_;
			gchar* _tmp171_;
			gchar* _tmp172_;
			_tmp169_ = nsn;
			_tmp170_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
			_tmp171_ = _tmp170_;
			_tmp172_ = _tmp171_;
			_tmp163_ = g_strcmp0 (_tmp169_, _tmp172_) != 0;
			_g_free0 (_tmp172_);
		} else {
			_tmp163_ = FALSE;
		}
		if (_tmp163_) {
			gchar* _tmp173_;
			gchar* _tmp174_;
			gchar* _tmp175_;
			gchar* _tmp176_;
			gchar* _tmp177_;
			GError* _tmp178_;
			GError* _tmp179_;
			_tmp173_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
			_tmp174_ = _tmp173_;
			_tmp175_ = _tmp174_;
			_tmp176_ = g_strdup_printf (_ ("Trying to add an attribute with an undefined namespace prefix: %s"), _tmp175_);
			_tmp177_ = _tmp176_;
			_tmp178_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _tmp177_);
			_tmp179_ = _tmp178_;
			_g_free0 (_tmp177_);
			_g_free0 (_tmp175_);
			_inner_error0_ = _tmp179_;
			g_propagate_error (error, _inner_error0_);
			_g_free0 (nspn);
			_g_free0 (nsn);
			return NULL;
		}
		_tmp180_ = self->_element;
		_tmp181_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp182_ = _tmp181_;
		_tmp183_ = _tmp182_;
		_tmp184_ = gxml_gom_element_lookup_prefix (_tmp180_, _tmp183_);
		_g_free0 (nspn);
		nspn = _tmp184_;
		_g_free0 (_tmp183_);
		_tmp185_ = self->_element;
		_tmp186_ = nspn;
		_tmp187_ = gxml_gom_element_lookup_namespace_uri (_tmp185_, _tmp186_);
		_g_free0 (nsn);
		nsn = _tmp187_;
		_tmp189_ = nspn;
		_tmp190_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp191_ = _tmp190_;
		_tmp192_ = _tmp191_;
		_tmp193_ = g_strcmp0 (_tmp189_, _tmp192_) != 0;
		_g_free0 (_tmp192_);
		if (_tmp193_) {
			const gchar* _tmp194_;
			gchar* _tmp195_;
			gchar* _tmp196_;
			gchar* _tmp197_;
			_tmp194_ = nsn;
			_tmp195_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
			_tmp196_ = _tmp195_;
			_tmp197_ = _tmp196_;
			_tmp188_ = g_strcmp0 (_tmp194_, _tmp197_) != 0;
			_g_free0 (_tmp197_);
		} else {
			_tmp188_ = FALSE;
		}
		if (_tmp188_) {
			GError* _tmp198_;
			_tmp198_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _ ("Trying to add an attribute with a non found namespace URI"));
			_inner_error0_ = _tmp198_;
			g_propagate_error (error, _inner_error0_);
			_g_free0 (nspn);
			_g_free0 (nsn);
			return NULL;
		}
		_g_free0 (nspn);
		_g_free0 (nsn);
	}
	_tmp199_ = g_strdup ("");
	p = _tmp199_;
	_tmp201_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
	_tmp202_ = _tmp201_;
	_tmp203_ = _tmp202_;
	_tmp204_ = _tmp203_ != NULL;
	_g_free0 (_tmp203_);
	if (_tmp204_) {
		gchar* _tmp205_;
		gchar* _tmp206_;
		gchar* _tmp207_;
		_tmp205_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp206_ = _tmp205_;
		_tmp207_ = _tmp206_;
		_tmp200_ = g_strcmp0 (_tmp207_, "") != 0;
		_g_free0 (_tmp207_);
	} else {
		_tmp200_ = FALSE;
	}
	if (_tmp200_) {
		gchar* _tmp208_;
		gchar* _tmp209_;
		gchar* _tmp210_;
		gchar* _tmp211_;
		_tmp208_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp209_ = _tmp208_;
		_tmp210_ = _tmp209_;
		_tmp211_ = g_strconcat (_tmp210_, ":", NULL);
		_g_free0 (p);
		p = _tmp211_;
		_g_free0 (_tmp210_);
	}
	_tmp212_ = p;
	_tmp213_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
	_tmp214_ = _tmp213_;
	_tmp215_ = _tmp214_;
	_tmp216_ = g_strconcat (_tmp212_, _tmp215_, NULL);
	_tmp217_ = _tmp216_;
	_tmp218_ = g_utf8_strdown (_tmp217_, (gssize) -1);
	_tmp219_ = _tmp218_;
	_g_free0 (_tmp217_);
	_g_free0 (_tmp215_);
	k = _tmp219_;
	attr = NULL;
	_tmp220_ = self->_element;
	_tmp221_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
	_tmp222_ = _tmp221_;
	_tmp223_ = _tmp222_;
	_tmp224_ = gxml_gom_object_find_property_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp220_, GXML_TYPE_GOM_OBJECT) ? ((GXmlGomObject*) _tmp220_) : NULL, _tmp223_);
	_tmp225_ = _tmp224_;
	_g_free0 (_tmp223_);
	pprop = _tmp225_;
	_tmp226_ = pprop;
	if (_tmp226_ != NULL) {
		GXmlGomElement* _tmp227_;
		gchar* _tmp228_;
		gchar* _tmp229_;
		gchar* _tmp230_;
		gchar* _tmp231_;
		gchar* _tmp232_;
		gchar* _tmp233_;
		GXmlGomElement* _tmp234_;
		gchar* _tmp235_;
		gchar* _tmp236_;
		gchar* _tmp237_;
		GXmlGomAttr* _tmp238_;
		_tmp227_ = self->_element;
		_tmp228_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp229_ = _tmp228_;
		_tmp230_ = _tmp229_;
		_tmp231_ = gxml_dom_node_get_node_value (node);
		_tmp232_ = _tmp231_;
		_tmp233_ = _tmp232_;
		gxml_gom_object_set_attribute (G_TYPE_CHECK_INSTANCE_TYPE (_tmp227_, GXML_TYPE_GOM_OBJECT) ? ((GXmlGomObject*) _tmp227_) : NULL, _tmp230_, _tmp233_);
		_g_free0 (_tmp233_);
		_g_free0 (_tmp230_);
		_tmp234_ = self->_element;
		_tmp235_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp236_ = _tmp235_;
		_tmp237_ = _tmp236_;
		_tmp238_ = gxml_gom_attr_new_reference ((GXmlDomElement*) _tmp234_, _tmp237_);
		_g_object_unref0 (attr);
		attr = _tmp238_;
		_g_free0 (_tmp237_);
	} else {
		GXmlGomElement* _tmp239_;
		gchar* _tmp240_;
		gchar* _tmp241_;
		gchar* _tmp242_;
		gchar* _tmp243_;
		gchar* _tmp244_;
		gchar* _tmp245_;
		gchar* _tmp246_;
		gchar* _tmp247_;
		gchar* _tmp248_;
		gchar* _tmp249_;
		gchar* _tmp250_;
		gchar* _tmp251_;
		GXmlGomAttr* _tmp252_;
		_tmp239_ = self->_element;
		_tmp240_ = gxml_dom_attr_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp241_ = _tmp240_;
		_tmp242_ = _tmp241_;
		_tmp243_ = gxml_dom_attr_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp244_ = _tmp243_;
		_tmp245_ = _tmp244_;
		_tmp246_ = gxml_dom_attr_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (node, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) node) : NULL);
		_tmp247_ = _tmp246_;
		_tmp248_ = _tmp247_;
		_tmp249_ = gxml_dom_node_get_node_value (node);
		_tmp250_ = _tmp249_;
		_tmp251_ = _tmp250_;
		_tmp252_ = gxml_gom_attr_new_namespace ((GXmlDomElement*) _tmp239_, _tmp242_, _tmp245_, _tmp248_, _tmp251_);
		_g_object_unref0 (attr);
		attr = _tmp252_;
		_g_free0 (_tmp251_);
		_g_free0 (_tmp248_);
		_g_free0 (_tmp245_);
		_g_free0 (_tmp242_);
	}
	_tmp253_ = k;
	_tmp254_ = attr;
	gee_abstract_map_set ((GeeAbstractMap*) self, _tmp253_, (GXmlDomNode*) _tmp254_);
	_tmp255_ = self->priv->order;
	_tmp256_ = gee_abstract_map_get_size ((GeeAbstractMap*) self);
	_tmp257_ = _tmp256_;
	_tmp258_ = k;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp255_, (gpointer) ((gintptr) ((glong) (_tmp257_ - 1))), _tmp258_);
	result = (GXmlDomNode*) attr;
	_g_param_spec_unref0 (pprop);
	_g_free0 (k);
	_g_free0 (p);
	return result;
}

static glong
gxml_gom_element_attributes_index_of (GXmlGomElementAttributes* self,
                                      const gchar* name)
{
	glong result = 0L;
	glong i = 0L;
	g_return_val_if_fail (self != NULL, 0L);
	g_return_val_if_fail (name != NULL, 0L);
	i = (glong) -1;
	{
		GeeIterator* _e_it = NULL;
		GeeTreeMap* _tmp0_;
		GeeSortedSet* _tmp1_;
		GeeSortedSet* _tmp2_;
		GeeSortedSet* _tmp3_;
		GeeIterator* _tmp4_;
		GeeIterator* _tmp5_;
		_tmp0_ = self->priv->order;
		_tmp1_ = gee_abstract_sorted_map_get_ascending_entries ((GeeAbstractSortedMap*) _tmp0_);
		_tmp2_ = _tmp1_;
		_tmp3_ = _tmp2_;
		_tmp4_ = gee_iterable_iterator ((GeeIterable*) _tmp3_);
		_tmp5_ = _tmp4_;
		_g_object_unref0 (_tmp3_);
		_e_it = _tmp5_;
		while (TRUE) {
			GeeIterator* _tmp6_;
			GeeMapEntry* e = NULL;
			GeeIterator* _tmp7_;
			gpointer _tmp8_;
			glong _tmp9_;
			GeeMapEntry* _tmp10_;
			gconstpointer _tmp11_;
			const gchar* _tmp12_;
			_tmp6_ = _e_it;
			if (!gee_iterator_next (_tmp6_)) {
				break;
			}
			_tmp7_ = _e_it;
			_tmp8_ = gee_iterator_get (_tmp7_);
			e = (GeeMapEntry*) _tmp8_;
			_tmp9_ = i;
			i = _tmp9_ + 1;
			_tmp10_ = e;
			_tmp11_ = gee_map_entry_get_value (_tmp10_);
			_tmp12_ = _tmp11_;
			if (g_strcmp0 ((const gchar*) _tmp12_, name) == 0) {
				result = i;
				_g_object_unref0 (e);
				_g_object_unref0 (_e_it);
				return result;
			}
			_g_object_unref0 (e);
		}
		_g_object_unref0 (_e_it);
	}
	result = (glong) -1;
	return result;
}

void
gxml_gom_element_attributes_add_reference (GXmlGomElementAttributes* self,
                                           const gchar* name)
{
	GXmlGomAttr* attr = NULL;
	GXmlGomElement* _tmp0_;
	GXmlGomAttr* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	GeeTreeMap* _tmp4_;
	gint _tmp5_;
	gint _tmp6_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (name != NULL);
	_tmp0_ = self->_element;
	_tmp1_ = gxml_gom_attr_new_reference ((GXmlDomElement*) _tmp0_, name);
	attr = _tmp1_;
	_tmp2_ = g_utf8_strdown (name, (gssize) -1);
	_tmp3_ = _tmp2_;
	gee_abstract_map_set ((GeeAbstractMap*) self, _tmp3_, (GXmlDomNode*) attr);
	_g_free0 (_tmp3_);
	_tmp4_ = self->priv->order;
	_tmp5_ = gee_abstract_map_get_size ((GeeAbstractMap*) self);
	_tmp6_ = _tmp5_;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp4_, (gpointer) ((gintptr) ((glong) _tmp6_)), name);
	_g_object_unref0 (attr);
}

static gint
gxml_gom_element_attributes_real_get_length (GXmlDomNamedNodeMap* base)
{
	gint result;
	GXmlGomElementAttributes* self;
	gint _tmp0_;
	gint _tmp1_;
	self = (GXmlGomElementAttributes*) base;
	_tmp0_ = gee_abstract_map_get_size ((GeeAbstractMap*) self);
	_tmp1_ = _tmp0_;
	result = _tmp1_;
	return result;
}

static void
gxml_gom_element_attributes_class_init (GXmlGomElementAttributesClass * klass,
                                        gpointer klass_data)
{
	gxml_gom_element_attributes_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GXmlGomElementAttributes_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gom_element_attributes_get_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_gom_element_attributes_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_ATTRIBUTES_LENGTH_PROPERTY, gxml_gom_element_attributes_properties[GXML_GOM_ELEMENT_ATTRIBUTES_LENGTH_PROPERTY] = g_param_spec_int ("length", "length", "length", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
gxml_gom_element_attributes_gxml_dom_named_node_map_interface_init (GXmlDomNamedNodeMapIface * iface,
                                                                    gpointer iface_data)
{
	gxml_gom_element_attributes_gxml_dom_named_node_map_parent_iface = g_type_interface_peek_parent (iface);
	iface->item = (GXmlDomNode* (*) (GXmlDomNamedNodeMap*, gint)) gxml_gom_element_attributes_real_item;
	iface->get_named_item = (GXmlDomNode* (*) (GXmlDomNamedNodeMap*, const gchar*)) gxml_gom_element_attributes_real_get_named_item;
	iface->set_named_item = (GXmlDomNode* (*) (GXmlDomNamedNodeMap*, GXmlDomNode*, GError**)) gxml_gom_element_attributes_real_set_named_item;
	iface->remove_named_item = (GXmlDomNode* (*) (GXmlDomNamedNodeMap*, const gchar*, GError**)) gxml_gom_element_attributes_real_remove_named_item;
	iface->remove_named_item_ns = (GXmlDomNode* (*) (GXmlDomNamedNodeMap*, const gchar*, const gchar*, GError**)) gxml_gom_element_attributes_real_remove_named_item_ns;
	iface->get_named_item_ns = (GXmlDomNode* (*) (GXmlDomNamedNodeMap*, const gchar*, const gchar*, GError**)) gxml_gom_element_attributes_real_get_named_item_ns;
	iface->set_named_item_ns = (GXmlDomNode* (*) (GXmlDomNamedNodeMap*, GXmlDomNode*, GError**)) gxml_gom_element_attributes_real_set_named_item_ns;
	iface->get_length = gxml_gom_element_attributes_real_get_length;
}

static void
gxml_gom_element_attributes_instance_init (GXmlGomElementAttributes * self,
                                           gpointer klass)
{
	GeeTreeMap* _tmp0_;
	self->priv = gxml_gom_element_attributes_get_instance_private (self);
	_tmp0_ = gee_tree_map_new (G_TYPE_LONG, NULL, NULL, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, NULL, NULL, NULL, NULL, NULL, NULL);
	self->priv->order = _tmp0_;
}

static void
gxml_gom_element_attributes_finalize (GObject * obj)
{
	GXmlGomElementAttributes * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_GOM_ELEMENT_TYPE_ATTRIBUTES, GXmlGomElementAttributes);
	_g_object_unref0 (self->priv->order);
	_g_object_unref0 (self->_element);
	G_OBJECT_CLASS (gxml_gom_element_attributes_parent_class)->finalize (obj);
}

/**
   * Holds attributes in current node, using attribute's name as key
   * and it's value as value. Appends namespace prefix to attribute's name as
   * key if is a namespaced attribute.
   */
GType
gxml_gom_element_attributes_get_type (void)
{
	static volatile gsize gxml_gom_element_attributes_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_element_attributes_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomElementAttributesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gom_element_attributes_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGomElementAttributes), 0, (GInstanceInitFunc) gxml_gom_element_attributes_instance_init, NULL };
		static const GInterfaceInfo gxml_dom_named_node_map_info = { (GInterfaceInitFunc) gxml_gom_element_attributes_gxml_dom_named_node_map_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_gom_element_attributes_type_id;
		gxml_gom_element_attributes_type_id = g_type_register_static (GEE_TYPE_HASH_MAP, "GXmlGomElementAttributes", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_gom_element_attributes_type_id, GXML_TYPE_DOM_NAMED_NODE_MAP, &gxml_dom_named_node_map_info);
		GXmlGomElementAttributes_private_offset = g_type_add_instance_private (gxml_gom_element_attributes_type_id, sizeof (GXmlGomElementAttributesPrivate));
		g_once_init_leave (&gxml_gom_element_attributes_type_id__volatile, gxml_gom_element_attributes_type_id);
	}
	return gxml_gom_element_attributes_type_id__volatile;
}

static void
_vala_gxml_gom_element_attributes_get_property (GObject * object,
                                                guint property_id,
                                                GValue * value,
                                                GParamSpec * pspec)
{
	GXmlGomElementAttributes * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_GOM_ELEMENT_TYPE_ATTRIBUTES, GXmlGomElementAttributes);
	switch (property_id) {
		case GXML_GOM_ELEMENT_ATTRIBUTES_LENGTH_PROPERTY:
		g_value_set_int (value, gxml_dom_named_node_map_get_length ((GXmlDomNamedNodeMap*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
gxml_gom_element_class_init (GXmlGomElementClass * klass,
                             gpointer klass_data)
{
	gxml_gom_element_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GXmlGomElement_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gom_element_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gxml_gom_element_set_property;
	G_OBJECT_CLASS (klass)->constructor = gxml_gom_element_constructor;
	G_OBJECT_CLASS (klass)->finalize = gxml_gom_element_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_PREVIOUS_ELEMENT_SIBLING_PROPERTY, gxml_gom_element_properties[GXML_GOM_ELEMENT_PREVIOUS_ELEMENT_SIBLING_PROPERTY] = g_param_spec_object ("previous-element-sibling", "previous-element-sibling", "previous-element-sibling", GXML_TYPE_DOM_ELEMENT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_NEXT_ELEMENT_SIBLING_PROPERTY, gxml_gom_element_properties[GXML_GOM_ELEMENT_NEXT_ELEMENT_SIBLING_PROPERTY] = g_param_spec_object ("next-element-sibling", "next-element-sibling", "next-element-sibling", GXML_TYPE_DOM_ELEMENT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_CHILDREN_PROPERTY, gxml_gom_element_properties[GXML_GOM_ELEMENT_CHILDREN_PROPERTY] = g_param_spec_object ("children", "children", "children", GXML_TYPE_DOM_HTML_COLLECTION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_FIRST_ELEMENT_CHILD_PROPERTY, gxml_gom_element_properties[GXML_GOM_ELEMENT_FIRST_ELEMENT_CHILD_PROPERTY] = g_param_spec_object ("first-element-child", "first-element-child", "first-element-child", GXML_TYPE_DOM_ELEMENT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_LAST_ELEMENT_CHILD_PROPERTY, gxml_gom_element_properties[GXML_GOM_ELEMENT_LAST_ELEMENT_CHILD_PROPERTY] = g_param_spec_object ("last-element-child", "last-element-child", "last-element-child", GXML_TYPE_DOM_ELEMENT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_CHILD_ELEMENT_COUNT_PROPERTY, gxml_gom_element_properties[GXML_GOM_ELEMENT_CHILD_ELEMENT_COUNT_PROPERTY] = g_param_spec_int ("child-element-count", "child-element-count", "child-element-count", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_NAMESPACE_URI_PROPERTY, gxml_gom_element_properties[GXML_GOM_ELEMENT_NAMESPACE_URI_PROPERTY] = g_param_spec_string ("namespace-uri", "namespace-uri", "namespace-uri", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_PREFIX_PROPERTY, gxml_gom_element_properties[GXML_GOM_ELEMENT_PREFIX_PROPERTY] = g_param_spec_string ("prefix", "prefix", "prefix", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	/**
	   * Derived classes should define it at construction time, using
	   * {@link GomNode._local_name} field. This is the node's name.
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_LOCAL_NAME_PROPERTY, gxml_gom_element_properties[GXML_GOM_ELEMENT_LOCAL_NAME_PROPERTY] = g_param_spec_string ("local-name", "local-name", "local-name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_TAG_NAME_PROPERTY, gxml_gom_element_properties[GXML_GOM_ELEMENT_TAG_NAME_PROPERTY] = g_param_spec_string ("tag-name", "tag-name", "tag-name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	/**
	   * An attribute called 'id'.
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_ID_PROPERTY, gxml_gom_element_properties[GXML_GOM_ELEMENT_ID_PROPERTY] = g_param_spec_string ("id", "::id", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * An attribute called 'class'.
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_CLASS_NAME_PROPERTY, gxml_gom_element_properties[GXML_GOM_ELEMENT_CLASS_NAME_PROPERTY] = g_param_spec_string ("class-name", "class-name", "class-name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * A list of values of all attributes called 'class'.
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_CLASS_LIST_PROPERTY, gxml_gom_element_properties[GXML_GOM_ELEMENT_CLASS_LIST_PROPERTY] = g_param_spec_object ("class-list", "class-list", "class-list", GXML_TYPE_DOM_TOKEN_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_ATTRIBUTES_PROPERTY, gxml_gom_element_properties[GXML_GOM_ELEMENT_ATTRIBUTES_PROPERTY] = g_param_spec_object ("attributes", "attributes", "attributes", GXML_TYPE_DOM_NAMED_NODE_MAP, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	/**
	   * If true all children are parsed. If false, all its children are stored
	   * as plain string in {@link unparsed}. In order to generate an XML tree
	   * use {@link read_unparsed}.
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_PARSE_CHILDREN_PROPERTY, gxml_gom_element_properties[GXML_GOM_ELEMENT_PARSE_CHILDREN_PROPERTY] = g_param_spec_boolean ("parse-children", "parse-children", "parse-children", TRUE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * Temporally stores, all unparsed children as plain string. See {@link parse_children}.
	   *
	   * If it is null, means all children have been already parsed.
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ELEMENT_UNPARSED_PROPERTY, gxml_gom_element_properties[GXML_GOM_ELEMENT_UNPARSED_PROPERTY] = g_param_spec_string ("unparsed", "unparsed", "unparsed", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
gxml_gom_element_gxml_dom_child_node_interface_init (GXmlDomChildNodeIface * iface,
                                                     gpointer iface_data)
{
	gxml_gom_element_gxml_dom_child_node_parent_iface = g_type_interface_peek_parent (iface);
	iface->remove = (void (*) (GXmlDomChildNode*)) gxml_gom_element_real_remove;
}

static void
gxml_gom_element_gxml_dom_non_document_type_child_node_interface_init (GXmlDomNonDocumentTypeChildNodeIface * iface,
                                                                       gpointer iface_data)
{
	gxml_gom_element_gxml_dom_non_document_type_child_node_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_previous_element_sibling = gxml_gom_element_real_get_previous_element_sibling;
	iface->get_next_element_sibling = gxml_gom_element_real_get_next_element_sibling;
}

static void
gxml_gom_element_gxml_dom_parent_node_interface_init (GXmlDomParentNodeIface * iface,
                                                      gpointer iface_data)
{
	gxml_gom_element_gxml_dom_parent_node_parent_iface = g_type_interface_peek_parent (iface);
	iface->query_selector_all = (GXmlDomNodeList* (*) (GXmlDomParentNode*, const gchar*, GError**)) gxml_gom_element_real_query_selector_all;
	iface->get_children = gxml_gom_element_real_get_children;
	iface->get_first_element_child = gxml_gom_element_real_get_first_element_child;
	iface->get_last_element_child = gxml_gom_element_real_get_last_element_child;
	iface->get_child_element_count = gxml_gom_element_real_get_child_element_count;
}

static void
gxml_gom_element_gxml_dom_element_interface_init (GXmlDomElementIface * iface,
                                                  gpointer iface_data)
{
	gxml_gom_element_gxml_dom_element_parent_iface = g_type_interface_peek_parent (iface);
	iface->read_from_file = (void (*) (GXmlDomElement*, GFile*, GCancellable*, GError**)) gxml_gom_element_real_read_from_file;
	iface->read_from_file_async = (void (*) (GXmlDomElement*, GFile*, GCancellable*, GAsyncReadyCallback, gpointer)) gxml_gom_element_real_read_from_file_async;
	iface->read_from_file_finish = (void (*) (GXmlDomElement*, GAsyncResult*, GError**)) gxml_gom_element_read_from_file_finish;
	iface->read_from_stream = (void (*) (GXmlDomElement*, GInputStream*, GCancellable*, GError**)) gxml_gom_element_real_read_from_stream;
	iface->read_from_stream_async = (void (*) (GXmlDomElement*, GInputStream*, GCancellable*, GAsyncReadyCallback, gpointer)) gxml_gom_element_real_read_from_stream_async;
	iface->read_from_stream_finish = (void (*) (GXmlDomElement*, GAsyncResult*, GError**)) gxml_gom_element_read_from_stream_finish;
	iface->read_from_string = (void (*) (GXmlDomElement*, const gchar*, GCancellable*, GError**)) gxml_gom_element_real_read_from_string;
	iface->read_from_string_async = (void (*) (GXmlDomElement*, const gchar*, GCancellable*, GAsyncReadyCallback, gpointer)) gxml_gom_element_real_read_from_string_async;
	iface->read_from_string_finish = (void (*) (GXmlDomElement*, GAsyncResult*, GError**)) gxml_gom_element_read_from_string_finish;
	iface->write_string = (gchar* (*) (GXmlDomElement*, GCancellable*, GError**)) gxml_gom_element_real_write_string;
	iface->write_string_async = (void (*) (GXmlDomElement*, GCancellable*, GAsyncReadyCallback, gpointer)) gxml_gom_element_real_write_string_async;
	iface->write_string_finish = (gchar* (*) (GXmlDomElement*, GAsyncResult*, GError**)) gxml_gom_element_write_string_finish;
	iface->write_file = (void (*) (GXmlDomElement*, GFile*, GCancellable*, GError**)) gxml_gom_element_real_write_file;
	iface->write_file_async = (void (*) (GXmlDomElement*, GFile*, GCancellable*, GAsyncReadyCallback, gpointer)) gxml_gom_element_real_write_file_async;
	iface->write_file_finish = (void (*) (GXmlDomElement*, GAsyncResult*, GError**)) gxml_gom_element_write_file_finish;
	iface->write_stream = (void (*) (GXmlDomElement*, GOutputStream*, GError**)) gxml_gom_element_real_write_stream;
	iface->write_stream_async = (void (*) (GXmlDomElement*, GOutputStream*, GCancellable*, GAsyncReadyCallback, gpointer)) gxml_gom_element_real_write_stream_async;
	iface->write_stream_finish = (void (*) (GXmlDomElement*, GAsyncResult*, GError**)) gxml_gom_element_write_stream_finish;
	iface->create_stream = (GInputStream* (*) (GXmlDomElement*, GError**)) gxml_gom_element_real_create_stream;
	iface->create_stream_async = (void (*) (GXmlDomElement*, GCancellable*, GAsyncReadyCallback, gpointer)) gxml_gom_element_real_create_stream_async;
	iface->create_stream_finish = (GInputStream* (*) (GXmlDomElement*, GAsyncResult*, GError**)) gxml_gom_element_create_stream_finish;
	iface->get_attribute = (gchar* (*) (GXmlDomElement*, const gchar*)) gxml_gom_element_real_get_attribute;
	iface->get_attribute_ns = (gchar* (*) (GXmlDomElement*, const gchar*, const gchar*)) gxml_gom_element_real_get_attribute_ns;
	iface->set_attribute = (void (*) (GXmlDomElement*, const gchar*, const gchar*, GError**)) gxml_gom_element_real_set_attribute;
	iface->set_attribute_ns = (void (*) (GXmlDomElement*, const gchar*, const gchar*, const gchar*, GError**)) gxml_gom_element_real_set_attribute_ns;
	iface->remove_attribute = (void (*) (GXmlDomElement*, const gchar*)) gxml_gom_element_real_remove_attribute;
	iface->remove_attribute_ns = (void (*) (GXmlDomElement*, const gchar*, const gchar*)) gxml_gom_element_real_remove_attribute_ns;
	iface->has_attribute = (gboolean (*) (GXmlDomElement*, const gchar*)) gxml_gom_element_real_has_attribute;
	iface->has_attribute_ns = (gboolean (*) (GXmlDomElement*, const gchar*, const gchar*)) gxml_gom_element_real_has_attribute_ns;
	iface->get_elements_by_tag_name = (GXmlDomHTMLCollection* (*) (GXmlDomElement*, const gchar*)) gxml_gom_element_real_get_elements_by_tag_name;
	iface->get_elements_by_tag_name_ns = (GXmlDomHTMLCollection* (*) (GXmlDomElement*, const gchar*, const gchar*)) gxml_gom_element_real_get_elements_by_tag_name_ns;
	iface->get_elements_by_class_name = (GXmlDomHTMLCollection* (*) (GXmlDomElement*, const gchar*)) gxml_gom_element_real_get_elements_by_class_name;
	iface->get_namespace_uri = gxml_gom_element_real_get_namespace_uri;
	iface->get_prefix = gxml_gom_element_real_get_prefix;
	iface->get_local_name = gxml_gom_element_real_get_local_name;
	iface->get_tag_name = gxml_gom_element_real_get_tag_name;
	iface->get_id = gxml_gom_element_real_get_id;
	iface->set_id = gxml_gom_element_real_set_id;
	iface->get_class_name = gxml_gom_element_real_get_class_name;
	iface->set_class_name = gxml_gom_element_real_set_class_name;
	iface->get_class_list = gxml_gom_element_real_get_class_list;
	iface->get_attributes = gxml_gom_element_real_get_attributes;
}

static void
gxml_gom_element_gxml_gom_object_interface_init (GXmlGomObjectIface * iface,
                                                 gpointer iface_data)
{
	gxml_gom_element_gxml_gom_object_parent_iface = g_type_interface_peek_parent (iface);
}

static void
gxml_gom_element_instance_init (GXmlGomElement * self,
                                gpointer klass)
{
	self->priv = gxml_gom_element_get_instance_private (self);
	self->_namespace_uri = NULL;
	self->priv->_parse_children = TRUE;
}

static void
gxml_gom_element_finalize (GObject * obj)
{
	GXmlGomElement * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GOM_ELEMENT, GXmlGomElement);
	_g_object_unref0 (self->_attributes);
	_g_free0 (self->_namespace_uri);
	_g_free0 (self->priv->_id);
	_g_free0 (self->priv->_unparsed);
	G_OBJECT_CLASS (gxml_gom_element_parent_class)->finalize (obj);
}

/**
 * A DOM4 implementation of {@link DomElement}, for one-step-parsing.
 *
 * This object avoids pre and post XML parsing, by using a one step parsing
 * to translate text XML tree to an GObject based tree.
 *
 * A GXml Object Model (GOM) implementation of {@link GomElement}.It can be used
 * transparently as {@link DomElement} in a XML tree.
 *
 * It also allows delayed parsing, so you can read large documents by parsing
 * just a XML element node and its attributes but not its childs; save its childs
 * as a text, for a post-on-step-parsing.
 */
GType
gxml_gom_element_get_type (void)
{
	static volatile gsize gxml_gom_element_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_element_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomElementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gom_element_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGomElement), 0, (GInstanceInitFunc) gxml_gom_element_instance_init, NULL };
		static const GInterfaceInfo gxml_dom_child_node_info = { (GInterfaceInitFunc) gxml_gom_element_gxml_dom_child_node_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_dom_non_document_type_child_node_info = { (GInterfaceInitFunc) gxml_gom_element_gxml_dom_non_document_type_child_node_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_dom_parent_node_info = { (GInterfaceInitFunc) gxml_gom_element_gxml_dom_parent_node_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_dom_element_info = { (GInterfaceInitFunc) gxml_gom_element_gxml_dom_element_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_gom_object_info = { (GInterfaceInitFunc) gxml_gom_element_gxml_gom_object_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_gom_element_type_id;
		gxml_gom_element_type_id = g_type_register_static (GXML_TYPE_GOM_NODE, "GXmlGomElement", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_gom_element_type_id, GXML_TYPE_DOM_CHILD_NODE, &gxml_dom_child_node_info);
		g_type_add_interface_static (gxml_gom_element_type_id, GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, &gxml_dom_non_document_type_child_node_info);
		g_type_add_interface_static (gxml_gom_element_type_id, GXML_TYPE_DOM_PARENT_NODE, &gxml_dom_parent_node_info);
		g_type_add_interface_static (gxml_gom_element_type_id, GXML_TYPE_DOM_ELEMENT, &gxml_dom_element_info);
		g_type_add_interface_static (gxml_gom_element_type_id, GXML_TYPE_GOM_OBJECT, &gxml_gom_object_info);
		GXmlGomElement_private_offset = g_type_add_instance_private (gxml_gom_element_type_id, sizeof (GXmlGomElementPrivate));
		g_once_init_leave (&gxml_gom_element_type_id__volatile, gxml_gom_element_type_id);
	}
	return gxml_gom_element_type_id__volatile;
}

static void
_vala_gxml_gom_element_get_property (GObject * object,
                                     guint property_id,
                                     GValue * value,
                                     GParamSpec * pspec)
{
	GXmlGomElement * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_ELEMENT, GXmlGomElement);
	switch (property_id) {
		case GXML_GOM_ELEMENT_PREVIOUS_ELEMENT_SIBLING_PROPERTY:
		g_value_take_object (value, gxml_dom_non_document_type_child_node_get_previous_element_sibling ((GXmlDomNonDocumentTypeChildNode*) self));
		break;
		case GXML_GOM_ELEMENT_NEXT_ELEMENT_SIBLING_PROPERTY:
		g_value_take_object (value, gxml_dom_non_document_type_child_node_get_next_element_sibling ((GXmlDomNonDocumentTypeChildNode*) self));
		break;
		case GXML_GOM_ELEMENT_CHILDREN_PROPERTY:
		g_value_take_object (value, gxml_dom_parent_node_get_children ((GXmlDomParentNode*) self));
		break;
		case GXML_GOM_ELEMENT_FIRST_ELEMENT_CHILD_PROPERTY:
		g_value_take_object (value, gxml_dom_parent_node_get_first_element_child ((GXmlDomParentNode*) self));
		break;
		case GXML_GOM_ELEMENT_LAST_ELEMENT_CHILD_PROPERTY:
		g_value_take_object (value, gxml_dom_parent_node_get_last_element_child ((GXmlDomParentNode*) self));
		break;
		case GXML_GOM_ELEMENT_CHILD_ELEMENT_COUNT_PROPERTY:
		g_value_set_int (value, gxml_dom_parent_node_get_child_element_count ((GXmlDomParentNode*) self));
		break;
		case GXML_GOM_ELEMENT_NAMESPACE_URI_PROPERTY:
		g_value_take_string (value, gxml_dom_element_get_namespace_uri ((GXmlDomElement*) self));
		break;
		case GXML_GOM_ELEMENT_PREFIX_PROPERTY:
		g_value_take_string (value, gxml_dom_element_get_prefix ((GXmlDomElement*) self));
		break;
		case GXML_GOM_ELEMENT_LOCAL_NAME_PROPERTY:
		g_value_take_string (value, gxml_dom_element_get_local_name ((GXmlDomElement*) self));
		break;
		case GXML_GOM_ELEMENT_TAG_NAME_PROPERTY:
		g_value_take_string (value, gxml_dom_element_get_tag_name ((GXmlDomElement*) self));
		break;
		case GXML_GOM_ELEMENT_ID_PROPERTY:
		g_value_take_string (value, gxml_dom_element_get_id ((GXmlDomElement*) self));
		break;
		case GXML_GOM_ELEMENT_CLASS_NAME_PROPERTY:
		g_value_take_string (value, gxml_dom_element_get_class_name ((GXmlDomElement*) self));
		break;
		case GXML_GOM_ELEMENT_CLASS_LIST_PROPERTY:
		g_value_take_object (value, gxml_dom_element_get_class_list ((GXmlDomElement*) self));
		break;
		case GXML_GOM_ELEMENT_ATTRIBUTES_PROPERTY:
		g_value_take_object (value, gxml_dom_element_get_attributes ((GXmlDomElement*) self));
		break;
		case GXML_GOM_ELEMENT_PARSE_CHILDREN_PROPERTY:
		g_value_set_boolean (value, gxml_gom_element_get_parse_children (self));
		break;
		case GXML_GOM_ELEMENT_UNPARSED_PROPERTY:
		g_value_set_string (value, gxml_gom_element_get_unparsed (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_gxml_gom_element_set_property (GObject * object,
                                     guint property_id,
                                     const GValue * value,
                                     GParamSpec * pspec)
{
	GXmlGomElement * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_ELEMENT, GXmlGomElement);
	switch (property_id) {
		case GXML_GOM_ELEMENT_ID_PROPERTY:
		gxml_dom_element_set_id ((GXmlDomElement*) self, g_value_get_string (value));
		break;
		case GXML_GOM_ELEMENT_CLASS_NAME_PROPERTY:
		gxml_dom_element_set_class_name ((GXmlDomElement*) self, g_value_get_string (value));
		break;
		case GXML_GOM_ELEMENT_PARSE_CHILDREN_PROPERTY:
		gxml_gom_element_set_parse_children (self, g_value_get_boolean (value));
		break;
		case GXML_GOM_ELEMENT_UNPARSED_PROPERTY:
		gxml_gom_element_set_unparsed (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_array_destroy (gpointer array,
                     gint array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gint array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

static gint
_vala_array_length (gpointer array)
{
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}

