/* DomGDocumentTest.c generated by valac 0.44.3, the Vala compiler
 * generated from DomGDocumentTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* DomGDocumentTest.vala
 *
 * Copyright (C) 2016  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gxml/gxml.h>
#include <gee.h>

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_DOM_GDOCUMENT_TEST (dom_gdocument_test_get_type ())
#define DOM_GDOCUMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DOM_GDOCUMENT_TEST, DomGDocumentTest))
#define DOM_GDOCUMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DOM_GDOCUMENT_TEST, DomGDocumentTestClass))
#define IS_DOM_GDOCUMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DOM_GDOCUMENT_TEST))
#define IS_DOM_GDOCUMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DOM_GDOCUMENT_TEST))
#define DOM_GDOCUMENT_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DOM_GDOCUMENT_TEST, DomGDocumentTestClass))

typedef struct _DomGDocumentTest DomGDocumentTest;
typedef struct _DomGDocumentTestClass DomGDocumentTestClass;
typedef struct _DomGDocumentTestPrivate DomGDocumentTestPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _DomGDocumentTest {
	GXmlTest parent_instance;
	DomGDocumentTestPrivate * priv;
};

struct _DomGDocumentTestClass {
	GXmlTestClass parent_class;
};

static gpointer dom_gdocument_test_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType dom_gdocument_test_get_type (void) G_GNUC_CONST;
#define DOM_GDOCUMENT_TEST_STRDOC "<?xml version=\"1.0\"?>\n" \
"<!-- Comment -->\n" \
"<Sentences>\n" \
"  <Sentence lang=\"en\">I like the colour blue.</Sentence>\n" \
"  <Sentence lang=\"de\">Ich liebe die T&#xFC;r.</Sentence>\n" \
"  <Authors>\n" \
"    <Author>\n" \
"      <Name>Fred</Name>\n" \
"      <Email>fweasley@hogwarts.co.uk</Email>\n" \
"    </Author>\n" \
"    <Author>\n" \
"      <Name>George</Name>\n" \
"      <Email>gweasley@hogwarts.co.uk</Email>\n" \
"    </Author>\n" \
"  </Authors>\n" \
"</Sentences>\n"
#define DOM_GDOCUMENT_TEST_HTMLDOC "\n" \
"<html>\n" \
"<body>\n" \
"<p class=\"black\">Text content</p>\n" \
"<p id=\"p01\">p01 p id</p>\n" \
"<p class=\"black block\">Two classes</p>\n" \
"<p class=\"   time request hole   \">Three classes</p>\n" \
"</body>\n" \
"</html>\n"
#define DOM_GDOCUMENT_TEST_XMLDOC "<?xml version=\"1.0\"?>\n" \
"<root>\n" \
"<project xmlns:gxml=\"http://live.gnome.org/GXml\">\n" \
"<code class=\"parent\"/>\n" \
"<code class=\"node parent\"/>\n" \
"<page class=\"node\"/>\n" \
"<page class=\"parent node hole\"/>\n" \
"</project>\n" \
"<Author name=\"You\" />\n" \
"</root>\n"
void dom_gdocument_test_add_tests (void);
static void __lambda46_ (void);
static void ___lambda46__gtest_func (void);
static void __lambda47_ (void);
static void ___lambda47__gtest_func (void);
static void __lambda48_ (void);
static void ___lambda48__gtest_func (void);
static void __lambda49_ (void);
static void ___lambda49__gtest_func (void);
static void __lambda50_ (void);
static void ___lambda50__gtest_func (void);
static void __lambda51_ (void);
static void ___lambda51__gtest_func (void);
static void __lambda52_ (void);
static void ___lambda52__gtest_func (void);
static void __lambda53_ (void);
static void ___lambda53__gtest_func (void);
static void __lambda54_ (void);
static void ___lambda54__gtest_func (void);
static void __lambda55_ (void);
static void ___lambda55__gtest_func (void);
static void __lambda56_ (void);
static void ___lambda56__gtest_func (void);
static void __lambda57_ (void);
static void ___lambda57__gtest_func (void);
static void __lambda58_ (void);
static void ___lambda58__gtest_func (void);
static void __lambda59_ (void);
static void ___lambda59__gtest_func (void);
DomGDocumentTest* dom_gdocument_test_new (void);
DomGDocumentTest* dom_gdocument_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);

static gpointer
_g_object_ref0 (gpointer self)
{
#line 74 "DomGDocumentTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 141 "DomGDocumentTest.c"
}

static void
__lambda46_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_;
		GXmlDomDocument* doc = NULL;
		GXmlDomDocument* _tmp2_;
		GXmlDomElement* root = NULL;
		GXmlDomElement* _tmp3_;
		GXmlDomElement* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		GXmlDomHTMLCollection* _tmp8_;
		GXmlDomHTMLCollection* _tmp9_;
		GXmlDomHTMLCollection* _tmp10_;
		gint _tmp11_;
		gint _tmp12_;
		GXmlDomHTMLCollection* _tmp13_;
		GXmlDomHTMLCollection* _tmp14_;
		GXmlDomHTMLCollection* _tmp15_;
		gpointer _tmp16_;
		GXmlDomElement* _tmp17_;
		gchar* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		GXmlDomHTMLCollection* _tmp21_;
		GXmlDomHTMLCollection* _tmp22_;
		GXmlDomHTMLCollection* _tmp23_;
		gpointer _tmp24_;
		GXmlDomElement* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		GXmlDomHTMLCollection* _tmp28_;
		GXmlDomHTMLCollection* _tmp29_;
		GXmlDomHTMLCollection* _tmp30_;
		gpointer _tmp31_;
		GXmlDomElement* _tmp32_;
		gchar* _tmp33_;
		gchar* _tmp34_;
		gchar* _tmp35_;
#line 74 "DomGDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string (DOM_GDOCUMENT_TEST_STRDOC, 0, &_inner_error0_);
#line 74 "DomGDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 74 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 193 "DomGDocumentTest.c"
			goto __catch60_g_error;
		}
#line 74 "DomGDocumentTest.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL);
#line 74 "DomGDocumentTest.vala"
		doc = _tmp2_;
#line 75 "DomGDocumentTest.vala"
		_tmp3_ = gxml_dom_document_get_document_element (doc);
#line 75 "DomGDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 75 "DomGDocumentTest.vala"
		root = _tmp4_;
#line 76 "DomGDocumentTest.vala"
		_vala_assert (root != NULL, "root != null");
#line 77 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (root, GXML_TYPE_DOM_ELEMENT), "root is DomElement");
#line 78 "DomGDocumentTest.vala"
		_tmp5_ = gxml_dom_node_get_node_name ((GXmlDomNode*) root);
#line 78 "DomGDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 78 "DomGDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 78 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "Sentences") == 0, "root.node_name == \"Sentences\"");
#line 78 "DomGDocumentTest.vala"
		_g_free0 (_tmp7_);
#line 79 "DomGDocumentTest.vala"
		_vala_assert (gxml_dom_node_has_child_nodes ((GXmlDomNode*) root), "root.has_child_nodes ()");
#line 80 "DomGDocumentTest.vala"
		_tmp8_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) root);
#line 80 "DomGDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 80 "DomGDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 80 "DomGDocumentTest.vala"
		_tmp11_ = gee_collection_get_size ((GeeCollection*) _tmp10_);
#line 80 "DomGDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 80 "DomGDocumentTest.vala"
		_vala_assert (_tmp12_ == 3, "root.children.size == 3");
#line 80 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp10_);
#line 81 "DomGDocumentTest.vala"
		_tmp13_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) root);
#line 81 "DomGDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 81 "DomGDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 81 "DomGDocumentTest.vala"
		_tmp16_ = gee_list_get ((GeeList*) _tmp15_, 0);
#line 81 "DomGDocumentTest.vala"
		_tmp17_ = (GXmlDomElement*) _tmp16_;
#line 81 "DomGDocumentTest.vala"
		_tmp18_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp17_);
#line 81 "DomGDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 81 "DomGDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 81 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp20_, "Sentence") == 0, "root.children[0].node_name == \"Sentence\"");
#line 81 "DomGDocumentTest.vala"
		_g_free0 (_tmp20_);
#line 81 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp17_);
#line 81 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 82 "DomGDocumentTest.vala"
		_tmp21_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) root);
#line 82 "DomGDocumentTest.vala"
		_tmp22_ = _tmp21_;
#line 82 "DomGDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 82 "DomGDocumentTest.vala"
		_tmp24_ = gee_list_get ((GeeList*) _tmp23_, 0);
#line 82 "DomGDocumentTest.vala"
		_tmp25_ = (GXmlDomElement*) _tmp24_;
#line 82 "DomGDocumentTest.vala"
		_tmp26_ = gxml_dom_element_get_attribute (_tmp25_, "lang");
#line 82 "DomGDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 82 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp27_, "en") == 0, "root.children[0].get_attribute (\"lang\") == \"en\"");
#line 82 "DomGDocumentTest.vala"
		_g_free0 (_tmp27_);
#line 82 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp25_);
#line 82 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp23_);
#line 83 "DomGDocumentTest.vala"
		_tmp28_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) root);
#line 83 "DomGDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 83 "DomGDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 83 "DomGDocumentTest.vala"
		_tmp31_ = gee_list_get ((GeeList*) _tmp30_, 0);
#line 83 "DomGDocumentTest.vala"
		_tmp32_ = (GXmlDomElement*) _tmp31_;
#line 83 "DomGDocumentTest.vala"
		_tmp33_ = gxml_dom_node_get_node_value ((GXmlDomNode*) _tmp32_);
#line 83 "DomGDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 83 "DomGDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 83 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp35_, "I like the colour blue.") == 0, "root.children[0].node_value == \"I like the colour blue.\"");
#line 83 "DomGDocumentTest.vala"
		_g_free0 (_tmp35_);
#line 83 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp32_);
#line 83 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp30_);
#line 70 "DomGDocumentTest.vala"
		_g_object_unref0 (root);
#line 70 "DomGDocumentTest.vala"
		_g_object_unref0 (doc);
#line 70 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 312 "DomGDocumentTest.c"
	}
	goto __finally60;
	__catch60_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp36_;
		gchar* _tmp37_;
		gchar* _tmp38_;
#line 70 "DomGDocumentTest.vala"
		e = _inner_error0_;
#line 70 "DomGDocumentTest.vala"
		_inner_error0_ = NULL;
#line 85 "DomGDocumentTest.vala"
		_tmp36_ = e->message;
#line 85 "DomGDocumentTest.vala"
		_tmp37_ = g_strconcat ("Error: ", _tmp36_, NULL);
#line 85 "DomGDocumentTest.vala"
		_tmp38_ = _tmp37_;
#line 85 "DomGDocumentTest.vala"
		g_message ("DomGDocumentTest.vala:85: %s", _tmp38_);
#line 85 "DomGDocumentTest.vala"
		_g_free0 (_tmp38_);
#line 86 "DomGDocumentTest.vala"
		g_assert_not_reached ();
#line 70 "DomGDocumentTest.vala"
		_g_error_free0 (e);
#line 339 "DomGDocumentTest.c"
	}
	__finally60:
#line 70 "DomGDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 70 "DomGDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 70 "DomGDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 70 "DomGDocumentTest.vala"
		return;
#line 350 "DomGDocumentTest.c"
	}
}

static void
___lambda46__gtest_func (void)
{
#line 69 "DomGDocumentTest.vala"
	__lambda46_ ();
#line 359 "DomGDocumentTest.c"
}

static void
__lambda47_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_;
		GXmlDomDocument* doc = NULL;
		GXmlDomDocument* _tmp2_;
		GXmlDomNodeList* _tmp3_;
		GXmlDomNodeList* _tmp4_;
		GXmlDomNodeList* _tmp5_;
		GXmlDomNodeList* _tmp6_;
		GXmlDomNodeList* _tmp7_;
		GXmlDomNodeList* _tmp8_;
		gint _tmp9_;
		gint _tmp10_;
		GXmlDomNodeList* _tmp11_;
		GXmlDomNodeList* _tmp12_;
		GXmlDomNodeList* _tmp13_;
		gpointer _tmp14_;
		GXmlDomNode* _tmp15_;
		GXmlDomNodeList* _tmp16_;
		GXmlDomNodeList* _tmp17_;
		GXmlDomNodeList* _tmp18_;
		gpointer _tmp19_;
		GXmlDomNode* _tmp20_;
		GXmlDomNodeList* _tmp21_;
		GXmlDomNodeList* _tmp22_;
		GXmlDomNodeList* _tmp23_;
		gpointer _tmp24_;
		GXmlDomNode* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
		GXmlDomElement* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomElement* _tmp31_;
		GXmlDomElement* _tmp32_;
		GXmlDomElement* _tmp33_;
		GXmlDomElement* _tmp34_;
		GXmlDomElement* auths = NULL;
		GXmlDomElement* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomElement* _tmp37_;
		GXmlDomHTMLCollection* _tmp38_;
		GXmlDomHTMLCollection* _tmp39_;
		GXmlDomHTMLCollection* _tmp40_;
		gpointer _tmp41_;
		GXmlDomElement* _tmp42_;
		gchar* _tmp43_;
		gchar* _tmp44_;
		gchar* _tmp45_;
		GXmlDomNodeList* _tmp46_;
		GXmlDomNodeList* _tmp47_;
		GXmlDomNodeList* _tmp48_;
		gint _tmp49_;
		gint _tmp50_;
		GXmlDomNodeList* _tmp51_;
		GXmlDomNodeList* _tmp52_;
		GXmlDomNodeList* _tmp53_;
		gpointer _tmp54_;
		GXmlDomNode* _tmp55_;
#line 94 "DomGDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string (DOM_GDOCUMENT_TEST_STRDOC, 0, &_inner_error0_);
#line 94 "DomGDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 94 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 431 "DomGDocumentTest.c"
			goto __catch61_g_error;
		}
#line 94 "DomGDocumentTest.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL);
#line 94 "DomGDocumentTest.vala"
		doc = _tmp2_;
#line 95 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (doc, GXML_TYPE_DOM_DOCUMENT), "doc is DomDocument");
#line 96 "DomGDocumentTest.vala"
		_tmp3_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) doc);
#line 96 "DomGDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 96 "DomGDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 96 "DomGDocumentTest.vala"
		_vala_assert (_tmp5_ != NULL, "doc.child_nodes != null");
#line 96 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp5_);
#line 97 "DomGDocumentTest.vala"
		_tmp6_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) doc);
#line 97 "DomGDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 97 "DomGDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 97 "DomGDocumentTest.vala"
		_tmp9_ = gee_collection_get_size ((GeeCollection*) _tmp8_);
#line 97 "DomGDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 97 "DomGDocumentTest.vala"
		_vala_assert (_tmp10_ == 2, "doc.child_nodes.size == 2");
#line 97 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp8_);
#line 98 "DomGDocumentTest.vala"
		_tmp11_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) doc);
#line 98 "DomGDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 98 "DomGDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 98 "DomGDocumentTest.vala"
		_tmp14_ = gee_list_get ((GeeList*) _tmp13_, 0);
#line 98 "DomGDocumentTest.vala"
		_tmp15_ = (GXmlDomNode*) _tmp14_;
#line 98 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GXML_TYPE_DOM_COMMENT), "doc.child_nodes[0] is DomComment");
#line 98 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 98 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp13_);
#line 99 "DomGDocumentTest.vala"
		_tmp16_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) doc);
#line 99 "DomGDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 99 "DomGDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 99 "DomGDocumentTest.vala"
		_tmp19_ = gee_list_get ((GeeList*) _tmp18_, 1);
#line 99 "DomGDocumentTest.vala"
		_tmp20_ = (GXmlDomNode*) _tmp19_;
#line 99 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp20_, GXML_TYPE_DOM_ELEMENT), "doc.child_nodes[1] is DomElement");
#line 99 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp20_);
#line 99 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp18_);
#line 100 "DomGDocumentTest.vala"
		_tmp21_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) doc);
#line 100 "DomGDocumentTest.vala"
		_tmp22_ = _tmp21_;
#line 100 "DomGDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 100 "DomGDocumentTest.vala"
		_tmp24_ = gee_list_get ((GeeList*) _tmp23_, 1);
#line 100 "DomGDocumentTest.vala"
		_tmp25_ = (GXmlDomNode*) _tmp24_;
#line 100 "DomGDocumentTest.vala"
		_tmp26_ = gxml_dom_node_get_node_name (_tmp25_);
#line 100 "DomGDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 100 "DomGDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 100 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp28_, "Sentences") == 0, "doc.child_nodes[1].node_name == \"Sentences\"");
#line 100 "DomGDocumentTest.vala"
		_g_free0 (_tmp28_);
#line 100 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp25_);
#line 100 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp23_);
#line 101 "DomGDocumentTest.vala"
		_tmp29_ = gxml_dom_document_get_document_element (doc);
#line 101 "DomGDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 101 "DomGDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 101 "DomGDocumentTest.vala"
		_vala_assert (_tmp31_ != NULL, "doc.document_element != null");
#line 101 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp31_);
#line 102 "DomGDocumentTest.vala"
		_tmp32_ = gxml_dom_document_get_document_element (doc);
#line 102 "DomGDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 102 "DomGDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 102 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp34_, GXML_TYPE_DOM_ELEMENT), "doc.document_element is DomElement");
#line 102 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp34_);
#line 103 "DomGDocumentTest.vala"
		_tmp35_ = gxml_dom_document_get_document_element (doc);
#line 103 "DomGDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 103 "DomGDocumentTest.vala"
		_tmp37_ = _tmp36_;
#line 103 "DomGDocumentTest.vala"
		_tmp38_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp37_);
#line 103 "DomGDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 103 "DomGDocumentTest.vala"
		_tmp40_ = _tmp39_;
#line 103 "DomGDocumentTest.vala"
		_tmp41_ = gee_list_get ((GeeList*) _tmp40_, 2);
#line 103 "DomGDocumentTest.vala"
		_tmp42_ = (GXmlDomElement*) _tmp41_;
#line 103 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp40_);
#line 103 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp37_);
#line 103 "DomGDocumentTest.vala"
		auths = _tmp42_;
#line 104 "DomGDocumentTest.vala"
		_tmp43_ = gxml_dom_node_get_node_name ((GXmlDomNode*) auths);
#line 104 "DomGDocumentTest.vala"
		_tmp44_ = _tmp43_;
#line 104 "DomGDocumentTest.vala"
		_tmp45_ = _tmp44_;
#line 104 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp45_, "Authors") == 0, "auths.node_name == \"Authors\"");
#line 104 "DomGDocumentTest.vala"
		_g_free0 (_tmp45_);
#line 105 "DomGDocumentTest.vala"
		_tmp46_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) auths);
#line 105 "DomGDocumentTest.vala"
		_tmp47_ = _tmp46_;
#line 105 "DomGDocumentTest.vala"
		_tmp48_ = _tmp47_;
#line 105 "DomGDocumentTest.vala"
		_tmp49_ = gee_collection_get_size ((GeeCollection*) _tmp48_);
#line 105 "DomGDocumentTest.vala"
		_tmp50_ = _tmp49_;
#line 105 "DomGDocumentTest.vala"
		_vala_assert (_tmp50_ == 5, "auths.child_nodes.size == 5");
#line 105 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp48_);
#line 106 "DomGDocumentTest.vala"
		_tmp51_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) auths);
#line 106 "DomGDocumentTest.vala"
		_tmp52_ = _tmp51_;
#line 106 "DomGDocumentTest.vala"
		_tmp53_ = _tmp52_;
#line 106 "DomGDocumentTest.vala"
		_tmp54_ = gee_list_get ((GeeList*) _tmp53_, 4);
#line 106 "DomGDocumentTest.vala"
		_tmp55_ = (GXmlDomNode*) _tmp54_;
#line 106 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp55_, GXML_TYPE_DOM_TEXT), "auths.child_nodes[4] is DomText");
#line 106 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp55_);
#line 106 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp53_);
#line 90 "DomGDocumentTest.vala"
		_g_object_unref0 (auths);
#line 90 "DomGDocumentTest.vala"
		_g_object_unref0 (doc);
#line 90 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 608 "DomGDocumentTest.c"
	}
	goto __finally61;
	__catch61_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp56_;
		gchar* _tmp57_;
		gchar* _tmp58_;
#line 90 "DomGDocumentTest.vala"
		e = _inner_error0_;
#line 90 "DomGDocumentTest.vala"
		_inner_error0_ = NULL;
#line 108 "DomGDocumentTest.vala"
		_tmp56_ = e->message;
#line 108 "DomGDocumentTest.vala"
		_tmp57_ = g_strconcat ("Error: ", _tmp56_, NULL);
#line 108 "DomGDocumentTest.vala"
		_tmp58_ = _tmp57_;
#line 108 "DomGDocumentTest.vala"
		g_message ("DomGDocumentTest.vala:108: %s", _tmp58_);
#line 108 "DomGDocumentTest.vala"
		_g_free0 (_tmp58_);
#line 109 "DomGDocumentTest.vala"
		g_assert_not_reached ();
#line 90 "DomGDocumentTest.vala"
		_g_error_free0 (e);
#line 635 "DomGDocumentTest.c"
	}
	__finally61:
#line 90 "DomGDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 90 "DomGDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 90 "DomGDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 90 "DomGDocumentTest.vala"
		return;
#line 646 "DomGDocumentTest.c"
	}
}

static void
___lambda47__gtest_func (void)
{
#line 89 "DomGDocumentTest.vala"
	__lambda47_ ();
#line 655 "DomGDocumentTest.c"
}

static void
__lambda48_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_;
		GXmlDomDocument* doc = NULL;
		GXmlDomDocument* _tmp2_;
		GXmlDomDocument* _tmp3_;
		GXmlDomHTMLCollection* le = NULL;
		GXmlDomDocument* _tmp4_;
		GXmlDomHTMLCollection* _tmp5_;
		GXmlDomHTMLCollection* _tmp6_;
		gint _tmp7_;
		gint _tmp8_;
		GXmlDomHTMLCollection* _tmp9_;
		gpointer _tmp10_;
		GXmlDomElement* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		GXmlDomHTMLCollection* _tmp14_;
		gpointer _tmp15_;
		GXmlDomElement* _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_;
		GXmlDomHTMLCollection* lc = NULL;
		GXmlDomDocument* _tmp19_;
		GXmlDomHTMLCollection* _tmp20_;
		GXmlDomHTMLCollection* _tmp21_;
		gint _tmp22_;
		gint _tmp23_;
		GXmlDomHTMLCollection* _tmp24_;
		gpointer _tmp25_;
		GXmlDomElement* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
		GXmlDomHTMLCollection* _tmp30_;
		gpointer _tmp31_;
		GXmlDomElement* _tmp32_;
		gchar* _tmp33_;
		gchar* _tmp34_;
		GXmlDomElement* nid = NULL;
		GXmlDomDocument* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomElement* _tmp37_;
		GXmlDomElement* _tmp38_;
		gchar* _tmp39_;
		gchar* _tmp40_;
		gchar* _tmp41_;
		GXmlDomElement* _tmp42_;
		gchar* _tmp43_;
		gchar* _tmp44_;
#line 117 "DomGDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string (DOM_GDOCUMENT_TEST_HTMLDOC, 0, &_inner_error0_);
#line 117 "DomGDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 117 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 718 "DomGDocumentTest.c"
			goto __catch62_g_error;
		}
#line 117 "DomGDocumentTest.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL);
#line 117 "DomGDocumentTest.vala"
		doc = _tmp2_;
#line 118 "DomGDocumentTest.vala"
		_tmp3_ = doc;
#line 118 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_DOM_DOCUMENT), "doc is DomDocument");
#line 119 "DomGDocumentTest.vala"
		_tmp4_ = doc;
#line 119 "DomGDocumentTest.vala"
		_tmp5_ = gxml_dom_document_get_elements_by_tag_name (_tmp4_, "p");
#line 119 "DomGDocumentTest.vala"
		le = _tmp5_;
#line 120 "DomGDocumentTest.vala"
		_tmp6_ = le;
#line 120 "DomGDocumentTest.vala"
		_tmp7_ = gee_collection_get_size ((GeeCollection*) _tmp6_);
#line 120 "DomGDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 120 "DomGDocumentTest.vala"
		_vala_assert (_tmp8_ == 4, "le.size == 4");
#line 121 "DomGDocumentTest.vala"
		_tmp9_ = le;
#line 121 "DomGDocumentTest.vala"
		_tmp10_ = gee_list_get ((GeeList*) _tmp9_, 0);
#line 121 "DomGDocumentTest.vala"
		_tmp11_ = (GXmlDomElement*) _tmp10_;
#line 121 "DomGDocumentTest.vala"
		_tmp12_ = gxml_dom_element_get_attribute (_tmp11_, "class");
#line 121 "DomGDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 121 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp13_, "black") == 0, "le[0].get_attribute (\"class\") == \"black\"");
#line 121 "DomGDocumentTest.vala"
		_g_free0 (_tmp13_);
#line 121 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp11_);
#line 122 "DomGDocumentTest.vala"
		_tmp14_ = le;
#line 122 "DomGDocumentTest.vala"
		_tmp15_ = gee_list_get ((GeeList*) _tmp14_, 1);
#line 122 "DomGDocumentTest.vala"
		_tmp16_ = (GXmlDomElement*) _tmp15_;
#line 122 "DomGDocumentTest.vala"
		_tmp17_ = gxml_dom_element_get_attribute (_tmp16_, "id");
#line 122 "DomGDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 122 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp18_, "p01") == 0, "le[1].get_attribute (\"id\") == \"p01\"");
#line 122 "DomGDocumentTest.vala"
		_g_free0 (_tmp18_);
#line 122 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp16_);
#line 123 "DomGDocumentTest.vala"
		_tmp19_ = doc;
#line 123 "DomGDocumentTest.vala"
		_tmp20_ = gxml_dom_document_get_elements_by_class_name (_tmp19_, "black");
#line 123 "DomGDocumentTest.vala"
		lc = _tmp20_;
#line 127 "DomGDocumentTest.vala"
		_tmp21_ = lc;
#line 127 "DomGDocumentTest.vala"
		_tmp22_ = gee_collection_get_size ((GeeCollection*) _tmp21_);
#line 127 "DomGDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 127 "DomGDocumentTest.vala"
		_vala_assert (_tmp23_ == 2, "lc.size == 2");
#line 128 "DomGDocumentTest.vala"
		_tmp24_ = lc;
#line 128 "DomGDocumentTest.vala"
		_tmp25_ = gee_list_get ((GeeList*) _tmp24_, 0);
#line 128 "DomGDocumentTest.vala"
		_tmp26_ = (GXmlDomElement*) _tmp25_;
#line 128 "DomGDocumentTest.vala"
		_tmp27_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp26_);
#line 128 "DomGDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 128 "DomGDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 128 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp29_, "p") == 0, "lc[0].node_name == \"p\"");
#line 128 "DomGDocumentTest.vala"
		_g_free0 (_tmp29_);
#line 128 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp26_);
#line 129 "DomGDocumentTest.vala"
		_tmp30_ = lc;
#line 129 "DomGDocumentTest.vala"
		_tmp31_ = gee_list_get ((GeeList*) _tmp30_, 0);
#line 129 "DomGDocumentTest.vala"
		_tmp32_ = (GXmlDomElement*) _tmp31_;
#line 129 "DomGDocumentTest.vala"
		_tmp33_ = gxml_dom_element_get_attribute (_tmp32_, "class");
#line 129 "DomGDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 129 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "black block") == 0, "lc[0].get_attribute (\"class\") == \"black block\"");
#line 129 "DomGDocumentTest.vala"
		_g_free0 (_tmp34_);
#line 129 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp32_);
#line 130 "DomGDocumentTest.vala"
		_tmp35_ = doc;
#line 130 "DomGDocumentTest.vala"
		_tmp36_ = gxml_dom_non_element_parent_node_get_element_by_id ((GXmlDomNonElementParentNode*) _tmp35_, "p01", &_inner_error0_);
#line 130 "DomGDocumentTest.vala"
		nid = _tmp36_;
#line 130 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 130 "DomGDocumentTest.vala"
			_g_object_unref0 (lc);
#line 130 "DomGDocumentTest.vala"
			_g_object_unref0 (le);
#line 130 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 130 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 839 "DomGDocumentTest.c"
			goto __catch62_g_error;
		}
#line 131 "DomGDocumentTest.vala"
		_tmp37_ = nid;
#line 131 "DomGDocumentTest.vala"
		_vala_assert (_tmp37_ != NULL, "nid != null");
#line 132 "DomGDocumentTest.vala"
		_tmp38_ = nid;
#line 132 "DomGDocumentTest.vala"
		_tmp39_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp38_);
#line 132 "DomGDocumentTest.vala"
		_tmp40_ = _tmp39_;
#line 132 "DomGDocumentTest.vala"
		_tmp41_ = _tmp40_;
#line 132 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp41_, "p") == 0, "nid.node_name == \"p\"");
#line 132 "DomGDocumentTest.vala"
		_g_free0 (_tmp41_);
#line 133 "DomGDocumentTest.vala"
		_tmp42_ = nid;
#line 133 "DomGDocumentTest.vala"
		_tmp43_ = gxml_dom_element_get_attribute (_tmp42_, "id");
#line 133 "DomGDocumentTest.vala"
		_tmp44_ = _tmp43_;
#line 133 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp44_, "p01") == 0, "nid.get_attribute (\"id\") == \"p01\"");
#line 133 "DomGDocumentTest.vala"
		_g_free0 (_tmp44_);
#line 113 "DomGDocumentTest.vala"
		_g_object_unref0 (nid);
#line 113 "DomGDocumentTest.vala"
		_g_object_unref0 (lc);
#line 113 "DomGDocumentTest.vala"
		_g_object_unref0 (le);
#line 113 "DomGDocumentTest.vala"
		_g_object_unref0 (doc);
#line 113 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 878 "DomGDocumentTest.c"
	}
	goto __finally62;
	__catch62_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
#line 113 "DomGDocumentTest.vala"
		e = _inner_error0_;
#line 113 "DomGDocumentTest.vala"
		_inner_error0_ = NULL;
#line 135 "DomGDocumentTest.vala"
		_tmp45_ = e->message;
#line 135 "DomGDocumentTest.vala"
		_tmp46_ = g_strconcat ("Error: ", _tmp45_, NULL);
#line 135 "DomGDocumentTest.vala"
		_tmp47_ = _tmp46_;
#line 135 "DomGDocumentTest.vala"
		g_message ("DomGDocumentTest.vala:135: %s", _tmp47_);
#line 135 "DomGDocumentTest.vala"
		_g_free0 (_tmp47_);
#line 136 "DomGDocumentTest.vala"
		g_assert_not_reached ();
#line 113 "DomGDocumentTest.vala"
		_g_error_free0 (e);
#line 905 "DomGDocumentTest.c"
	}
	__finally62:
#line 113 "DomGDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 113 "DomGDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 113 "DomGDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 113 "DomGDocumentTest.vala"
		return;
#line 916 "DomGDocumentTest.c"
	}
}

static void
___lambda48__gtest_func (void)
{
#line 112 "DomGDocumentTest.vala"
	__lambda48_ ();
#line 925 "DomGDocumentTest.c"
}

static gboolean
string_contains (const gchar* self,
                 const gchar* needle)
{
	gboolean result = FALSE;
	gchar* _tmp0_;
#line 1476 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1476 "glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1477 "glib-2.0.vapi"
	_tmp0_ = strstr ((gchar*) self, (gchar*) needle);
#line 1477 "glib-2.0.vapi"
	result = _tmp0_ != NULL;
#line 1477 "glib-2.0.vapi"
	return result;
#line 944 "DomGDocumentTest.c"
}

static void
__lambda49_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_;
		GXmlDomDocument* doc = NULL;
		GXmlDomDocument* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlDomElement* _tmp5_;
		GXmlDomHTMLCollection* _tmp6_;
		GXmlDomHTMLCollection* _tmp7_;
		GXmlDomHTMLCollection* _tmp8_;
		gint _tmp9_;
		gint _tmp10_;
		GXmlDomHTMLCollection* le = NULL;
		GXmlDomElement* _tmp11_;
		GXmlDomElement* _tmp12_;
		GXmlDomElement* _tmp13_;
		GXmlDomHTMLCollection* _tmp14_;
		GXmlDomHTMLCollection* _tmp15_;
		gint _tmp16_;
		gint _tmp17_;
		gpointer _tmp18_;
		GXmlDomElement* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		gpointer _tmp22_;
		GXmlDomElement* _tmp23_;
		gchar* _tmp24_;
		gchar* _tmp25_;
		GXmlDomHTMLCollection* lc = NULL;
		GXmlDomElement* _tmp26_;
		GXmlDomElement* _tmp27_;
		GXmlDomElement* _tmp28_;
		GXmlDomHTMLCollection* _tmp29_;
		GXmlDomHTMLCollection* _tmp30_;
		gint _tmp31_;
		gint _tmp32_;
		gpointer _tmp33_;
		GXmlDomElement* _tmp34_;
		gchar* _tmp35_;
		gchar* _tmp36_;
		gchar* _tmp37_;
		gpointer _tmp38_;
		GXmlDomElement* _tmp39_;
		gchar* _tmp40_;
		gchar* _tmp41_;
		GXmlDomHTMLCollection* lc2 = NULL;
		GXmlDomElement* _tmp42_;
		GXmlDomElement* _tmp43_;
		GXmlDomElement* _tmp44_;
		GXmlDomHTMLCollection* _tmp45_;
		GXmlDomHTMLCollection* _tmp46_;
		gint _tmp47_;
		gint _tmp48_;
		GXmlDomHTMLCollection* lc3 = NULL;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlDomElement* _tmp51_;
		GXmlDomHTMLCollection* _tmp52_;
		GXmlDomHTMLCollection* _tmp53_;
		gint _tmp54_;
		gint _tmp55_;
		GXmlDomHTMLCollection* lc4 = NULL;
		GXmlDomElement* _tmp56_;
		GXmlDomElement* _tmp57_;
		GXmlDomElement* _tmp58_;
		GXmlDomHTMLCollection* _tmp59_;
		GXmlDomHTMLCollection* _tmp60_;
		gint _tmp61_;
		gint _tmp62_;
#line 141 "DomGDocumentTest.vala"
		g_message ("DomGDocumentTest.vala:141: %s", "Doc: " DOM_GDOCUMENT_TEST_HTMLDOC);
#line 142 "DomGDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string (DOM_GDOCUMENT_TEST_HTMLDOC, 0, &_inner_error0_);
#line 142 "DomGDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 142 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1029 "DomGDocumentTest.c"
			goto __catch63_g_error;
		}
#line 142 "DomGDocumentTest.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL);
#line 142 "DomGDocumentTest.vala"
		doc = _tmp2_;
#line 143 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (doc, GXML_TYPE_DOM_DOCUMENT), "doc is DomDocument");
#line 144 "DomGDocumentTest.vala"
		_tmp3_ = gxml_dom_document_get_document_element (doc);
#line 144 "DomGDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 144 "DomGDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 144 "DomGDocumentTest.vala"
		_tmp6_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp5_);
#line 144 "DomGDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 144 "DomGDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 144 "DomGDocumentTest.vala"
		_tmp9_ = gee_collection_get_size ((GeeCollection*) _tmp8_);
#line 144 "DomGDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 144 "DomGDocumentTest.vala"
		_vala_assert (_tmp10_ == 1, "doc.document_element.children.size == 1");
#line 144 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp8_);
#line 144 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp5_);
#line 145 "DomGDocumentTest.vala"
		_tmp11_ = gxml_dom_document_get_document_element (doc);
#line 145 "DomGDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 145 "DomGDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 145 "DomGDocumentTest.vala"
		_tmp14_ = gxml_dom_element_get_elements_by_tag_name (_tmp13_, "p");
#line 145 "DomGDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 145 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp13_);
#line 145 "DomGDocumentTest.vala"
		le = _tmp15_;
#line 146 "DomGDocumentTest.vala"
		_tmp16_ = gee_collection_get_size ((GeeCollection*) le);
#line 146 "DomGDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 146 "DomGDocumentTest.vala"
		_vala_assert (_tmp17_ == 4, "le.size == 4");
#line 147 "DomGDocumentTest.vala"
		_tmp18_ = gee_list_get ((GeeList*) le, 0);
#line 147 "DomGDocumentTest.vala"
		_tmp19_ = (GXmlDomElement*) _tmp18_;
#line 147 "DomGDocumentTest.vala"
		_tmp20_ = gxml_dom_element_get_attribute (_tmp19_, "class");
#line 147 "DomGDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 147 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp21_, "black") == 0, "le[0].get_attribute (\"class\") == \"black\"");
#line 147 "DomGDocumentTest.vala"
		_g_free0 (_tmp21_);
#line 147 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp19_);
#line 148 "DomGDocumentTest.vala"
		_tmp22_ = gee_list_get ((GeeList*) le, 1);
#line 148 "DomGDocumentTest.vala"
		_tmp23_ = (GXmlDomElement*) _tmp22_;
#line 148 "DomGDocumentTest.vala"
		_tmp24_ = gxml_dom_element_get_attribute (_tmp23_, "id");
#line 148 "DomGDocumentTest.vala"
		_tmp25_ = _tmp24_;
#line 148 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp25_, "p01") == 0, "le[1].get_attribute (\"id\") == \"p01\"");
#line 148 "DomGDocumentTest.vala"
		_g_free0 (_tmp25_);
#line 148 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp23_);
#line 149 "DomGDocumentTest.vala"
		_tmp26_ = gxml_dom_document_get_document_element (doc);
#line 149 "DomGDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 149 "DomGDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 149 "DomGDocumentTest.vala"
		_tmp29_ = gxml_dom_element_get_elements_by_class_name (_tmp28_, "black");
#line 149 "DomGDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 149 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp28_);
#line 149 "DomGDocumentTest.vala"
		lc = _tmp30_;
#line 153 "DomGDocumentTest.vala"
		_tmp31_ = gee_collection_get_size ((GeeCollection*) lc);
#line 153 "DomGDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 153 "DomGDocumentTest.vala"
		_vala_assert (_tmp32_ == 2, "lc.size == 2");
#line 154 "DomGDocumentTest.vala"
		_tmp33_ = gee_list_get ((GeeList*) lc, 0);
#line 154 "DomGDocumentTest.vala"
		_tmp34_ = (GXmlDomElement*) _tmp33_;
#line 154 "DomGDocumentTest.vala"
		_tmp35_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp34_);
#line 154 "DomGDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 154 "DomGDocumentTest.vala"
		_tmp37_ = _tmp36_;
#line 154 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp37_, "p") == 0, "lc[0].node_name == \"p\"");
#line 154 "DomGDocumentTest.vala"
		_g_free0 (_tmp37_);
#line 154 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp34_);
#line 155 "DomGDocumentTest.vala"
		_tmp38_ = gee_list_get ((GeeList*) lc, 0);
#line 155 "DomGDocumentTest.vala"
		_tmp39_ = (GXmlDomElement*) _tmp38_;
#line 155 "DomGDocumentTest.vala"
		_tmp40_ = gxml_dom_element_get_attribute (_tmp39_, "class");
#line 155 "DomGDocumentTest.vala"
		_tmp41_ = _tmp40_;
#line 155 "DomGDocumentTest.vala"
		_vala_assert (string_contains (_tmp41_, "black"), "\"black\" in lc[0].get_attribute (\"class\")");
#line 155 "DomGDocumentTest.vala"
		_g_free0 (_tmp41_);
#line 155 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp39_);
#line 156 "DomGDocumentTest.vala"
		_tmp42_ = gxml_dom_document_get_document_element (doc);
#line 156 "DomGDocumentTest.vala"
		_tmp43_ = _tmp42_;
#line 156 "DomGDocumentTest.vala"
		_tmp44_ = _tmp43_;
#line 156 "DomGDocumentTest.vala"
		_tmp45_ = gxml_dom_element_get_elements_by_class_name (_tmp44_, "time");
#line 156 "DomGDocumentTest.vala"
		_tmp46_ = _tmp45_;
#line 156 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp44_);
#line 156 "DomGDocumentTest.vala"
		lc2 = _tmp46_;
#line 157 "DomGDocumentTest.vala"
		_tmp47_ = gee_collection_get_size ((GeeCollection*) lc2);
#line 157 "DomGDocumentTest.vala"
		_tmp48_ = _tmp47_;
#line 157 "DomGDocumentTest.vala"
		_vala_assert (_tmp48_ == 1, "lc2.size == 1");
#line 158 "DomGDocumentTest.vala"
		_tmp49_ = gxml_dom_document_get_document_element (doc);
#line 158 "DomGDocumentTest.vala"
		_tmp50_ = _tmp49_;
#line 158 "DomGDocumentTest.vala"
		_tmp51_ = _tmp50_;
#line 158 "DomGDocumentTest.vala"
		_tmp52_ = gxml_dom_element_get_elements_by_class_name (_tmp51_, "time request");
#line 158 "DomGDocumentTest.vala"
		_tmp53_ = _tmp52_;
#line 158 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp51_);
#line 158 "DomGDocumentTest.vala"
		lc3 = _tmp53_;
#line 159 "DomGDocumentTest.vala"
		_tmp54_ = gee_collection_get_size ((GeeCollection*) lc3);
#line 159 "DomGDocumentTest.vala"
		_tmp55_ = _tmp54_;
#line 159 "DomGDocumentTest.vala"
		_vala_assert (_tmp55_ == 1, "lc3.size == 1");
#line 160 "DomGDocumentTest.vala"
		_tmp56_ = gxml_dom_document_get_document_element (doc);
#line 160 "DomGDocumentTest.vala"
		_tmp57_ = _tmp56_;
#line 160 "DomGDocumentTest.vala"
		_tmp58_ = _tmp57_;
#line 160 "DomGDocumentTest.vala"
		_tmp59_ = gxml_dom_element_get_elements_by_class_name (_tmp58_, "time request hole");
#line 160 "DomGDocumentTest.vala"
		_tmp60_ = _tmp59_;
#line 160 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp58_);
#line 160 "DomGDocumentTest.vala"
		lc4 = _tmp60_;
#line 161 "DomGDocumentTest.vala"
		_tmp61_ = gee_collection_get_size ((GeeCollection*) lc4);
#line 161 "DomGDocumentTest.vala"
		_tmp62_ = _tmp61_;
#line 161 "DomGDocumentTest.vala"
		_vala_assert (_tmp62_ == 1, "lc4.size == 1");
#line 140 "DomGDocumentTest.vala"
		_g_object_unref0 (lc4);
#line 140 "DomGDocumentTest.vala"
		_g_object_unref0 (lc3);
#line 140 "DomGDocumentTest.vala"
		_g_object_unref0 (lc2);
#line 140 "DomGDocumentTest.vala"
		_g_object_unref0 (lc);
#line 140 "DomGDocumentTest.vala"
		_g_object_unref0 (le);
#line 140 "DomGDocumentTest.vala"
		_g_object_unref0 (doc);
#line 140 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 1232 "DomGDocumentTest.c"
	}
	goto __finally63;
	__catch63_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp63_;
		gchar* _tmp64_;
		gchar* _tmp65_;
#line 140 "DomGDocumentTest.vala"
		e = _inner_error0_;
#line 140 "DomGDocumentTest.vala"
		_inner_error0_ = NULL;
#line 163 "DomGDocumentTest.vala"
		_tmp63_ = e->message;
#line 163 "DomGDocumentTest.vala"
		_tmp64_ = g_strconcat ("Error: ", _tmp63_, NULL);
#line 163 "DomGDocumentTest.vala"
		_tmp65_ = _tmp64_;
#line 163 "DomGDocumentTest.vala"
		g_message ("DomGDocumentTest.vala:163: %s", _tmp65_);
#line 163 "DomGDocumentTest.vala"
		_g_free0 (_tmp65_);
#line 164 "DomGDocumentTest.vala"
		g_assert_not_reached ();
#line 140 "DomGDocumentTest.vala"
		_g_error_free0 (e);
#line 1259 "DomGDocumentTest.c"
	}
	__finally63:
#line 140 "DomGDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 140 "DomGDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 140 "DomGDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 140 "DomGDocumentTest.vala"
		return;
#line 1270 "DomGDocumentTest.c"
	}
}

static void
___lambda49__gtest_func (void)
{
#line 139 "DomGDocumentTest.vala"
	__lambda49_ ();
#line 1279 "DomGDocumentTest.c"
}

static void
__lambda50_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_;
		GXmlDomDocument* doc = NULL;
		GXmlDomDocument* _tmp2_;
		GXmlDomDocument* _tmp3_;
		GXmlDomDocument* _tmp4_;
		GXmlDomElement* _tmp5_;
		GXmlDomElement* _tmp6_;
		GXmlDomElement* _tmp7_;
		GXmlDomHTMLCollection* _tmp8_;
		GXmlDomHTMLCollection* _tmp9_;
		GXmlDomHTMLCollection* _tmp10_;
		gint _tmp11_;
		gint _tmp12_;
		GXmlDomDocument* _tmp13_;
		GXmlDomElement* _tmp14_;
		GXmlDomElement* _tmp15_;
		GXmlDomElement* _tmp16_;
		GXmlDomHTMLCollection* _tmp17_;
		GXmlDomHTMLCollection* _tmp18_;
		GXmlDomHTMLCollection* _tmp19_;
		gpointer _tmp20_;
		GXmlDomElement* _tmp21_;
		GXmlDomDocument* _tmp22_;
		GXmlDomElement* _tmp23_;
		GXmlDomElement* _tmp24_;
		GXmlDomElement* _tmp25_;
		GXmlDomHTMLCollection* _tmp26_;
		GXmlDomHTMLCollection* _tmp27_;
		GXmlDomHTMLCollection* _tmp28_;
		gpointer _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomHTMLCollection* _tmp31_;
		GXmlDomHTMLCollection* _tmp32_;
		GXmlDomHTMLCollection* _tmp33_;
		gpointer _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomElement* e = NULL;
		GXmlDomDocument* _tmp36_;
		GXmlDomElement* _tmp37_;
		GXmlDomElement* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomHTMLCollection* _tmp40_;
		GXmlDomHTMLCollection* _tmp41_;
		GXmlDomHTMLCollection* _tmp42_;
		gpointer _tmp43_;
		GXmlDomElement* _tmp44_;
		GXmlDomHTMLCollection* _tmp45_;
		GXmlDomHTMLCollection* _tmp46_;
		GXmlDomHTMLCollection* _tmp47_;
		gpointer _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlDomDocument* _tmp51_;
		GXmlDomDocument* _tmp52_;
		GXmlDomDocument* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomNode* _tmp55_;
		GXmlDomNode* _tmp56_;
		GXmlDomNode* _tmp57_;
		GXmlDomElement* _tmp58_;
		GXmlDomNode* _tmp59_;
		GXmlDomNode* _tmp60_;
		GXmlDomNode* _tmp61_;
		gchar* _tmp62_;
		gchar* _tmp63_;
		gchar* _tmp64_;
		GXmlDomElement* _tmp65_;
		GXmlDomElement* _tmp66_;
		GXmlDomElement* _tmp67_;
		GXmlDomElement* _tmp68_;
		GXmlDomElement* _tmp69_;
		GXmlDomElement* _tmp70_;
		GXmlDomElement* _tmp71_;
		GXmlDomElement* _tmp72_;
		gchar* _tmp73_;
		gchar* _tmp74_;
		gchar* _tmp75_;
		GXmlDomElement* _tmp76_;
		GXmlDomNodeList* _tmp77_;
		GXmlDomNodeList* _tmp78_;
		GXmlDomNodeList* _tmp79_;
		GXmlDomElement* _tmp80_;
		GXmlDomNodeList* _tmp81_;
		GXmlDomNodeList* _tmp82_;
		GXmlDomNodeList* _tmp83_;
		gint _tmp84_;
		gint _tmp85_;
		GXmlDomElement* _tmp86_;
		GXmlDomNodeList* _tmp87_;
		GXmlDomNodeList* _tmp88_;
		GXmlDomNodeList* _tmp89_;
		GXmlDomNode* _tmp90_;
		GXmlDomNode* _tmp91_;
		GXmlDomElement* _tmp92_;
		GXmlDomNodeList* _tmp93_;
		GXmlDomNodeList* _tmp94_;
		GXmlDomNodeList* _tmp95_;
		GXmlDomNode* _tmp96_;
		GXmlDomNode* _tmp97_;
		GXmlDomElement* _tmp98_;
		GXmlDomNode* _tmp99_;
		GXmlDomNode* _tmp100_;
		GXmlDomNode* _tmp101_;
		GXmlDomElement* _tmp102_;
		GXmlDomNode* _tmp103_;
		GXmlDomNode* _tmp104_;
		GXmlDomNode* _tmp105_;
		GXmlDomElement* _tmp106_;
		GXmlDomNode* _tmp107_;
		GXmlDomNode* _tmp108_;
		GXmlDomNode* _tmp109_;
		GXmlDomElement* _tmp110_;
		GXmlDomNode* _tmp111_;
		GXmlDomNode* _tmp112_;
		GXmlDomNode* _tmp113_;
		GXmlDomNode* t = NULL;
		GXmlDomElement* _tmp114_;
		GXmlDomNodeList* _tmp115_;
		GXmlDomNodeList* _tmp116_;
		GXmlDomNodeList* _tmp117_;
		GXmlDomNode* _tmp118_;
		GXmlDomNode* _tmp119_;
		GXmlDomNode* _tmp120_;
		GXmlDomNode* _tmp121_;
		GXmlDomNode* _tmp122_;
		GXmlDomNode* _tmp123_;
		GXmlDomNode* _tmp124_;
		GXmlDomNode* _tmp125_;
		GXmlDomNode* _tmp126_;
		GXmlDomNode* _tmp127_;
		GXmlDomNode* _tmp128_;
		gchar* _tmp129_;
		gchar* _tmp130_;
		gchar* _tmp131_;
		GXmlDomNode* _tmp132_;
		gchar* _tmp133_;
		gchar* _tmp134_;
		gchar* _tmp135_;
		GXmlDomElement* _tmp136_;
		GXmlDomNode* _tmp137_;
		GXmlDomNode* _tmp138_;
		GXmlDomNode* _tmp139_;
		gchar* _tmp140_;
		gchar* _tmp141_;
		gchar* _tmp142_;
		GXmlDomElement* _tmp143_;
		GXmlDomNode* _tmp144_;
		GXmlDomNode* _tmp145_;
		GXmlDomNode* _tmp146_;
		GXmlDomElement* _tmp147_;
		GXmlDomNode* _tmp148_;
		GXmlDomNode* _tmp149_;
		GXmlDomNode* _tmp150_;
		GXmlDomElement* _tmp151_;
		GXmlDomNode* _tmp152_;
		GXmlDomNode* _tmp153_;
		GXmlDomNode* _tmp154_;
		gchar* _tmp155_;
		gchar* _tmp156_;
		gchar* _tmp157_;
		GXmlDomNode* _tmp158_ = NULL;
		GXmlDomElement* _tmp159_;
		GXmlDomNode* _tmp160_;
		GXmlDomElement* cn = NULL;
		GXmlDomElement* _tmp161_;
		GXmlDomElement* _tmp162_;
		gchar* _tmp163_;
		gchar* _tmp164_;
		gchar* _tmp165_;
		GXmlDomElement* _tmp166_;
		gchar* _tmp167_;
		gchar* _tmp168_;
		GXmlDomElement* _tmp169_;
		GXmlDomNodeList* _tmp170_;
		GXmlDomNodeList* _tmp171_;
		GXmlDomNodeList* _tmp172_;
		GXmlDomElement* _tmp173_;
		GXmlDomNodeList* _tmp174_;
		GXmlDomNodeList* _tmp175_;
		GXmlDomNodeList* _tmp176_;
		gint _tmp177_;
		gint _tmp178_;
		GXmlDomNode* _tmp179_ = NULL;
		GXmlDomElement* _tmp180_;
		GXmlDomNode* _tmp181_;
		GXmlDomElement* cn2 = NULL;
		GXmlDomElement* _tmp182_;
		GXmlDomElement* _tmp183_;
		gchar* _tmp184_;
		gchar* _tmp185_;
		gchar* _tmp186_;
		GXmlDomElement* _tmp187_;
		gchar* _tmp188_;
		gchar* _tmp189_;
		GXmlDomElement* _tmp190_;
		GXmlDomNodeList* _tmp191_;
		GXmlDomNodeList* _tmp192_;
		GXmlDomNodeList* _tmp193_;
		GXmlDomElement* _tmp194_;
		GXmlDomNodeList* _tmp195_;
		GXmlDomNodeList* _tmp196_;
		GXmlDomNodeList* _tmp197_;
		gint _tmp198_;
		gint _tmp199_;
		GXmlDomElement* _tmp200_;
		GXmlDomNodeList* _tmp201_;
		GXmlDomNodeList* _tmp202_;
		GXmlDomNodeList* _tmp203_;
		gpointer _tmp204_;
		GXmlDomNode* _tmp205_;
		GXmlDomElement* _tmp206_;
		gchar* _tmp207_;
		gchar* _tmp208_;
		gchar* _tmp209_;
		GXmlDomElement* _tmp210_;
		GXmlDomElement* _tmp211_;
		GXmlDomElement* _tmp212_;
		GXmlDomElement* _tmp213_;
		GXmlDomElement* e0 = NULL;
		GXmlDomDocument* _tmp214_;
		GXmlDomElement* _tmp215_;
		GXmlDomElement* _tmp216_;
		GXmlDomElement* _tmp217_;
		GXmlDomHTMLCollection* _tmp218_;
		GXmlDomHTMLCollection* _tmp219_;
		GXmlDomHTMLCollection* _tmp220_;
		gpointer _tmp221_;
		GXmlDomElement* _tmp222_;
		GXmlDomHTMLCollection* _tmp223_;
		GXmlDomHTMLCollection* _tmp224_;
		GXmlDomHTMLCollection* _tmp225_;
		gpointer _tmp226_;
		GXmlDomElement* _tmp227_;
		GXmlDomElement* _tmp228_;
		gchar* _tmp229_;
		gchar* _tmp230_;
		gchar* _tmp231_;
		GXmlDomDocument* _tmp232_;
		GXmlDomElement* _tmp233_;
		GXmlDomElement* _tmp234_;
		GXmlDomElement* _tmp235_;
		GXmlDomHTMLCollection* _tmp236_;
		GXmlDomHTMLCollection* _tmp237_;
		GXmlDomHTMLCollection* _tmp238_;
		gpointer _tmp239_;
		GXmlDomElement* _tmp240_;
		GXmlDomNodeList* _tmp241_;
		GXmlDomNodeList* _tmp242_;
		GXmlDomNodeList* _tmp243_;
		GXmlDomElement* _tmp244_;
		GXmlDomElement* e1 = NULL;
		GXmlDomDocument* _tmp245_;
		GXmlDomElement* _tmp246_;
		GXmlDomElement* _tmp247_;
		GXmlDomElement* _tmp248_;
		GXmlDomHTMLCollection* _tmp249_;
		GXmlDomHTMLCollection* _tmp250_;
		GXmlDomHTMLCollection* _tmp251_;
		gpointer _tmp252_;
		GXmlDomElement* _tmp253_;
		GXmlDomHTMLCollection* _tmp254_;
		GXmlDomHTMLCollection* _tmp255_;
		GXmlDomHTMLCollection* _tmp256_;
		gpointer _tmp257_;
		GXmlDomElement* _tmp258_;
		GXmlDomElement* _tmp259_;
		gchar* _tmp260_;
		gchar* _tmp261_;
		gchar* _tmp262_;
		GXmlDomDocument* _tmp263_;
		GXmlDomElement* _tmp264_;
		GXmlDomElement* _tmp265_;
		GXmlDomElement* _tmp266_;
		GXmlDomHTMLCollection* _tmp267_;
		GXmlDomHTMLCollection* _tmp268_;
		GXmlDomHTMLCollection* _tmp269_;
		gpointer _tmp270_;
		GXmlDomElement* _tmp271_;
		GXmlDomNodeList* _tmp272_;
		GXmlDomNodeList* _tmp273_;
		GXmlDomNodeList* _tmp274_;
		GXmlDomElement* _tmp275_;
		GXmlDomElement* e2 = NULL;
		GXmlDomDocument* _tmp276_;
		GXmlDomElement* _tmp277_;
		GXmlDomElement* _tmp278_;
		GXmlDomElement* _tmp279_;
		GXmlDomHTMLCollection* _tmp280_;
		GXmlDomHTMLCollection* _tmp281_;
		GXmlDomHTMLCollection* _tmp282_;
		gpointer _tmp283_;
		GXmlDomElement* _tmp284_;
		GXmlDomHTMLCollection* _tmp285_;
		GXmlDomHTMLCollection* _tmp286_;
		GXmlDomHTMLCollection* _tmp287_;
		gpointer _tmp288_;
		GXmlDomElement* _tmp289_;
		GXmlDomElement* _tmp290_;
		gchar* _tmp291_;
		gchar* _tmp292_;
		gchar* _tmp293_;
		GXmlDomDocument* _tmp294_;
		GXmlDomElement* _tmp295_;
		GXmlDomElement* _tmp296_;
		GXmlDomElement* _tmp297_;
		GXmlDomHTMLCollection* _tmp298_;
		GXmlDomHTMLCollection* _tmp299_;
		GXmlDomHTMLCollection* _tmp300_;
		gpointer _tmp301_;
		GXmlDomElement* _tmp302_;
		GXmlDomNodeList* _tmp303_;
		GXmlDomNodeList* _tmp304_;
		GXmlDomNodeList* _tmp305_;
		GXmlDomElement* _tmp306_;
		GXmlDomElement* _tmp307_;
		GXmlDomNode* _tmp308_;
		GXmlDomNode* _tmp309_;
		GXmlDomNode* _tmp310_;
		GXmlDomElement* _tmp311_;
		GXmlDomElement* _tmp312_;
		GXmlDomNode* _tmp313_;
		GXmlDomNode* _tmp314_;
		GXmlDomNode* _tmp315_;
		GXmlDomElement* _tmp316_;
		GXmlDomElement* _tmp317_;
		GXmlDomNode* _tmp318_;
		GXmlDomNode* _tmp319_;
		GXmlDomNode* _tmp320_;
		GXmlDomElement* _tmp321_;
		gboolean _tmp322_ = FALSE;
		GXmlDomElement* _tmp323_;
		GXmlDomNode* _tmp324_;
		GXmlDomNode* _tmp325_;
		GXmlDomNode* _tmp326_;
		GXmlDomElement* _tmp327_;
		gboolean _tmp328_;
		GXmlDomElement* _tmp334_;
		GXmlDomElement* _tmp335_;
		gboolean _tmp336_ = FALSE;
		GXmlDomElement* _tmp337_;
		GXmlDomNode* _tmp338_;
		GXmlDomNode* _tmp339_;
		GXmlDomNode* _tmp340_;
		GXmlDomElement* _tmp341_;
		gboolean _tmp342_;
		GXmlDomElement* _tmp348_;
		GXmlDomElement* _tmp349_;
		GXmlDomElement* _tmp350_;
		GXmlDomNode* _tmp351_;
		GXmlDomNode* _tmp352_;
		GXmlDomNode* _tmp353_;
		GXmlDomElement* _tmp354_;
		GXmlDomElement* _tmp355_;
		GXmlDomElement* _tmp356_;
		GXmlDomNode* _tmp357_;
		GXmlDomNode* _tmp358_;
		GXmlDomNode* _tmp359_;
		GXmlDomElement* _tmp360_;
		GXmlDomElement* _tmp361_;
		GXmlDomNodeList* _tmp362_;
		GXmlDomNodeList* _tmp363_;
		GXmlDomNodeList* _tmp364_;
		gpointer _tmp365_;
		GXmlDomNode* _tmp366_;
		GXmlDomElement* _tmp367_;
		GXmlDomElement* _tmp368_;
		GXmlDomNodeList* _tmp369_;
		GXmlDomNodeList* _tmp370_;
		GXmlDomNodeList* _tmp371_;
		gpointer _tmp372_;
		GXmlDomNode* _tmp373_;
		GXmlDomElement* b = NULL;
		GXmlDomDocument* _tmp374_;
		GXmlDomElement* _tmp375_;
		GXmlDomElement* _tmp376_;
		GXmlDomElement* _tmp377_;
		GXmlDomHTMLCollection* _tmp378_;
		GXmlDomHTMLCollection* _tmp379_;
		GXmlDomHTMLCollection* _tmp380_;
		gpointer _tmp381_;
		GXmlDomElement* _tmp382_;
		GXmlDomElement* _tmp383_;
		gchar* _tmp384_;
		gchar* _tmp385_;
		gchar* _tmp386_;
		GXmlDomElement* ng = NULL;
		GXmlDomDocument* _tmp387_;
		GXmlDomElement* _tmp388_;
		GXmlDomElement* _tmp389_;
		GXmlDomNodeList* _tmp390_;
		GXmlDomNodeList* _tmp391_;
		GXmlDomNodeList* _tmp392_;
		GXmlDomElement* _tmp393_;
		GXmlDomElement* _tmp394_;
		gchar* _tmp395_;
		gchar* _tmp396_;
		GXmlDomElement* _tmp397_;
		gchar* _tmp398_;
		gchar* _tmp399_;
		GXmlDomElement* _tmp400_;
		GXmlDomElement* ng2 = NULL;
		GXmlDomDocument* _tmp401_;
		GXmlDomElement* _tmp402_;
		GXmlDomElement* _tmp403_;
		GXmlDomNodeList* _tmp404_;
		GXmlDomNodeList* _tmp405_;
		GXmlDomNodeList* _tmp406_;
		GXmlDomElement* _tmp407_;
		GXmlDomElement* _tmp408_;
		gchar* _tmp409_;
		gchar* _tmp410_;
		GXmlDomElement* _tmp411_;
		gchar* _tmp412_;
		gchar* _tmp413_;
		GXmlDomElement* _tmp414_;
		GXmlDomElement* _tmp415_ = NULL;
		GXmlDomDocument* _tmp416_;
		GXmlDomElement* _tmp417_;
		GXmlDomElement* pn = NULL;
		GXmlDomElement* _tmp418_;
		GXmlDomElement* _tmp419_;
		GXmlDomElement* p = NULL;
		GXmlDomDocument* _tmp420_;
		GXmlDomElement* _tmp421_;
		GXmlDomElement* _tmp422_;
		GXmlDomElement* _tmp423_;
		GXmlDomHTMLCollection* _tmp424_;
		GXmlDomHTMLCollection* _tmp425_;
		GXmlDomHTMLCollection* _tmp426_;
		gpointer _tmp427_;
		GXmlDomElement* _tmp428_;
		GXmlDomElement* _tmp429_;
		gchar* _tmp430_;
		gchar* _tmp431_;
		gchar* _tmp432_;
		GXmlDomElement* cp0 = NULL;
		GXmlDomElement* _tmp433_;
		GXmlDomHTMLCollection* _tmp434_;
		GXmlDomHTMLCollection* _tmp435_;
		GXmlDomHTMLCollection* _tmp436_;
		gpointer _tmp437_;
		GXmlDomElement* _tmp438_;
		GXmlDomElement* _tmp439_;
		gchar* _tmp440_;
		gchar* _tmp441_;
		gchar* _tmp442_;
		GXmlDomElement* _tmp443_;
		gchar* _tmp444_;
		gchar* _tmp445_;
		GXmlDomElement* _tmp446_;
		GXmlDomElement* _tmp447_;
		GXmlDomElement* _tmp448_;
		GXmlDomNode* _tmp449_;
		GXmlDomNode* _tmp450_;
		GXmlDomNode* _tmp451_;
		GXmlDomElement* _tmp452_;
		GXmlDomElement* _tmp453_;
		GXmlDomElement* _tmp454_;
		GXmlDomElement* _tmp455_;
		GXmlDomNode* _tmp456_;
		GXmlDomNode* _tmp457_;
		GXmlDomElement* ppn = NULL;
		GXmlDomElement* _tmp458_;
		GXmlDomHTMLCollection* _tmp459_;
		GXmlDomHTMLCollection* _tmp460_;
		GXmlDomHTMLCollection* _tmp461_;
		gpointer _tmp462_;
		GXmlDomElement* _tmp463_;
		GXmlDomElement* _tmp464_;
		gchar* _tmp465_;
		gchar* _tmp466_;
		gchar* _tmp467_;
		GXmlDomElement* _tmp468_;
		GXmlDomElement* _tmp469_;
		gchar* _tmp470_;
		gchar* _tmp471_;
		GXmlDomElement* _tmp472_ = NULL;
		GXmlDomDocument* _tmp473_;
		GXmlDomElement* _tmp474_;
		GXmlDomElement* pn2 = NULL;
		GXmlDomElement* _tmp475_;
		GXmlDomElement* _tmp476_;
		GXmlDomElement* _tmp477_;
		GXmlDomElement* _tmp478_;
		GXmlDomNode* _tmp479_;
		GXmlDomNode* _tmp480_;
		GXmlDomElement* _tmp481_;
		GXmlDomHTMLCollection* _tmp482_;
		GXmlDomHTMLCollection* _tmp483_;
		GXmlDomHTMLCollection* _tmp484_;
		gint _tmp485_;
		gint _tmp486_;
		GXmlDomElement* _tmp487_;
		GXmlDomHTMLCollection* _tmp488_;
		GXmlDomHTMLCollection* _tmp489_;
		GXmlDomHTMLCollection* _tmp490_;
		gpointer _tmp491_;
		GXmlDomElement* _tmp492_;
		GXmlDomElement* _tmp493_;
		GXmlDomHTMLCollection* _tmp494_;
		GXmlDomHTMLCollection* _tmp495_;
		GXmlDomHTMLCollection* _tmp496_;
		gpointer _tmp497_;
		GXmlDomElement* _tmp498_;
		gchar* _tmp499_;
		gchar* _tmp500_;
		gchar* _tmp501_;
		GXmlDomElement* _tmp502_;
		GXmlDomHTMLCollection* _tmp503_;
		GXmlDomHTMLCollection* _tmp504_;
		GXmlDomHTMLCollection* _tmp505_;
		gpointer _tmp506_;
		GXmlDomElement* _tmp507_;
		gchar* _tmp508_;
		gchar* _tmp509_;
		GXmlDomElement* _tmp510_ = NULL;
		GXmlDomDocument* _tmp511_;
		GXmlDomElement* _tmp512_;
		GXmlDomElement* pn3 = NULL;
		GXmlDomElement* _tmp513_;
		GXmlDomElement* _tmp514_;
		GXmlDomElement* _tmp515_;
		GXmlDomElement* _tmp516_;
		GXmlDomElement* _tmp517_;
		GXmlDomElement* _tmp518_;
		GXmlDomNode* _tmp519_;
		GXmlDomNode* _tmp520_;
		GXmlDomElement* _tmp521_;
		GXmlDomHTMLCollection* _tmp522_;
		GXmlDomHTMLCollection* _tmp523_;
		GXmlDomHTMLCollection* _tmp524_;
		gint _tmp525_;
		gint _tmp526_;
		GXmlDomElement* _tmp527_;
		GXmlDomHTMLCollection* _tmp528_;
		GXmlDomHTMLCollection* _tmp529_;
		GXmlDomHTMLCollection* _tmp530_;
		gpointer _tmp531_;
		GXmlDomElement* _tmp532_;
		GXmlDomElement* _tmp533_;
		GXmlDomHTMLCollection* _tmp534_;
		GXmlDomHTMLCollection* _tmp535_;
		GXmlDomHTMLCollection* _tmp536_;
		gpointer _tmp537_;
		GXmlDomElement* _tmp538_;
		gchar* _tmp539_;
		gchar* _tmp540_;
		gchar* _tmp541_;
		GXmlDomElement* _tmp542_;
		GXmlDomHTMLCollection* _tmp543_;
		GXmlDomHTMLCollection* _tmp544_;
		GXmlDomHTMLCollection* _tmp545_;
		gpointer _tmp546_;
		GXmlDomElement* _tmp547_;
		gchar* _tmp548_;
		gchar* _tmp549_;
		GXmlDomElement* _tmp550_;
		GXmlDomHTMLCollection* _tmp551_;
		GXmlDomHTMLCollection* _tmp552_;
		GXmlDomHTMLCollection* _tmp553_;
		gpointer _tmp554_;
		GXmlDomElement* _tmp555_;
		gchar* _tmp556_;
		gchar* _tmp557_;
		GXmlDomElement* _tmp558_ = NULL;
		GXmlDomDocument* _tmp559_;
		GXmlDomElement* _tmp560_;
		GXmlDomElement* pn4 = NULL;
		GXmlDomElement* _tmp561_;
		GXmlDomElement* _tmp562_;
		GXmlDomElement* _tmp563_;
		GXmlDomElement* _tmp564_;
		GXmlDomElement* _tmp565_;
		GXmlDomElement* _tmp566_;
		GXmlDomNodeList* _tmp567_;
		GXmlDomNodeList* _tmp568_;
		GXmlDomNodeList* _tmp569_;
		gpointer _tmp570_;
		GXmlDomNode* _tmp571_;
		GXmlDomNode* _tmp572_;
		GXmlDomNode* _tmp573_;
		GXmlDomElement* _tmp574_;
		GXmlDomHTMLCollection* _tmp575_;
		GXmlDomHTMLCollection* _tmp576_;
		GXmlDomHTMLCollection* _tmp577_;
		gint _tmp578_;
		gint _tmp579_;
		GXmlDomElement* _tmp580_;
		GXmlDomHTMLCollection* _tmp581_;
		GXmlDomHTMLCollection* _tmp582_;
		GXmlDomHTMLCollection* _tmp583_;
		gpointer _tmp584_;
		GXmlDomElement* _tmp585_;
		GXmlDomElement* _tmp586_;
		GXmlDomHTMLCollection* _tmp587_;
		GXmlDomHTMLCollection* _tmp588_;
		GXmlDomHTMLCollection* _tmp589_;
		gpointer _tmp590_;
		GXmlDomElement* _tmp591_;
		gchar* _tmp592_;
		gchar* _tmp593_;
		gchar* _tmp594_;
		GXmlDomElement* _tmp595_;
		GXmlDomHTMLCollection* _tmp596_;
		GXmlDomHTMLCollection* _tmp597_;
		GXmlDomHTMLCollection* _tmp598_;
		gpointer _tmp599_;
		GXmlDomElement* _tmp600_;
		gchar* _tmp601_;
		gchar* _tmp602_;
		GXmlDomElement* _tmp603_;
		GXmlDomHTMLCollection* _tmp604_;
		GXmlDomHTMLCollection* _tmp605_;
		GXmlDomHTMLCollection* _tmp606_;
		gpointer _tmp607_;
		GXmlDomElement* _tmp608_;
		gchar* _tmp609_;
		gchar* _tmp610_;
		GXmlDomElement* _tmp611_;
		GXmlDomElement* _tmp612_;
		GXmlDomHTMLCollection* _tmp613_;
		GXmlDomHTMLCollection* _tmp614_;
		GXmlDomHTMLCollection* _tmp615_;
		gpointer _tmp616_;
		GXmlDomElement* _tmp617_;
		GXmlDomNode* _tmp618_;
		GXmlDomNode* _tmp619_;
		GXmlDomElement* _tmp620_;
		GXmlDomHTMLCollection* _tmp621_;
		GXmlDomHTMLCollection* _tmp622_;
		GXmlDomHTMLCollection* _tmp623_;
		gint _tmp624_;
		gint _tmp625_;
		GXmlDomElement* _tmp626_;
		GXmlDomHTMLCollection* _tmp627_;
		GXmlDomHTMLCollection* _tmp628_;
		GXmlDomHTMLCollection* _tmp629_;
		gpointer _tmp630_;
		GXmlDomElement* _tmp631_;
		GXmlDomElement* _tmp632_;
		GXmlDomHTMLCollection* _tmp633_;
		GXmlDomHTMLCollection* _tmp634_;
		GXmlDomHTMLCollection* _tmp635_;
		gpointer _tmp636_;
		GXmlDomElement* _tmp637_;
		gchar* _tmp638_;
		gchar* _tmp639_;
		gchar* _tmp640_;
		GXmlDomElement* _tmp641_;
		GXmlDomElement* _tmp642_;
		GXmlDomHTMLCollection* _tmp643_;
		GXmlDomHTMLCollection* _tmp644_;
		GXmlDomHTMLCollection* _tmp645_;
		gpointer _tmp646_;
		GXmlDomElement* _tmp647_;
		gchar* _tmp648_;
		gchar* _tmp649_;
		GXmlDomElement* _tmp650_;
		GXmlDomElement* _tmp651_;
		gchar* _tmp652_;
		gchar* _tmp653_;
		gchar* _tmp654_;
		GXmlDomElement* _tmp655_;
		gchar* _tmp656_;
		gchar* _tmp657_;
		GXmlDomElement* _tmp658_;
		gchar* _tmp659_;
		gchar* _tmp660_;
		GXmlDomElement* _tmp661_;
		gchar* _tmp662_;
		gchar* _tmp663_;
		gchar* _tmp664_;
		GXmlDomHTMLCollection* l = NULL;
		GXmlDomDocument* _tmp665_;
		GXmlDomElement* _tmp666_;
		GXmlDomElement* _tmp667_;
		GXmlDomElement* _tmp668_;
		GXmlDomHTMLCollection* _tmp669_;
		GXmlDomHTMLCollection* _tmp670_;
		gint _tmp671_;
		gint _tmp672_;
		gpointer _tmp673_;
		GXmlDomElement* _tmp674_;
		gpointer _tmp675_;
		GXmlDomElement* _tmp676_;
		gpointer _tmp677_;
		GXmlDomElement* _tmp678_;
		gpointer _tmp679_;
		GXmlDomElement* _tmp680_;
		gchar* _tmp681_;
		gchar* _tmp682_;
		gchar* _tmp683_;
		gpointer _tmp684_;
		GXmlDomElement* _tmp685_;
		gchar* _tmp686_;
		gchar* _tmp687_;
		gchar* _tmp688_;
		gpointer _tmp689_;
		GXmlDomElement* _tmp690_;
		gchar* _tmp691_;
		gchar* _tmp692_;
		gchar* _tmp693_;
		GXmlDomDocument* _tmp694_;
		GXmlDomElement* _tmp695_;
		GXmlDomElement* _tmp696_;
		GXmlDomElement* _tmp697_;
		GXmlDomHTMLCollection* _tmp698_;
		GXmlDomHTMLCollection* _tmp699_;
		GXmlDomHTMLCollection* _tmp700_;
		gint _tmp701_;
		gint _tmp702_;
		GXmlDomHTMLCollection* lnst = NULL;
		GXmlDomDocument* _tmp703_;
		GXmlDomElement* _tmp704_;
		GXmlDomElement* _tmp705_;
		GXmlDomElement* _tmp706_;
		GXmlDomHTMLCollection* _tmp707_;
		GXmlDomHTMLCollection* _tmp708_;
		gint _tmp709_;
		gint _tmp710_;
		GXmlDomElement* nnst = NULL;
		GXmlDomElement* _tmp711_;
		gchar* _tmp712_;
		gchar* _tmp713_;
		gchar* _tmp714_;
		GXmlDomHTMLCollection* lns = NULL;
		GXmlDomDocument* _tmp715_;
		GXmlDomElement* _tmp716_;
		GXmlDomElement* _tmp717_;
		GXmlDomElement* _tmp718_;
		GXmlDomHTMLCollection* _tmp719_;
		GXmlDomHTMLCollection* _tmp720_;
		gint _tmp721_;
		gint _tmp722_;
		GXmlDomElement* _tmp723_;
		GXmlDomElement* _tmp724_;
		GXmlDomElement* _tmp725_;
		GXmlDomElement* _tmp726_;
		gchar* _tmp727_;
		gchar* _tmp728_;
		gchar* _tmp729_;
		GXmlDomHTMLCollection* lcl = NULL;
		GXmlDomDocument* _tmp730_;
		GXmlDomElement* _tmp731_;
		GXmlDomElement* _tmp732_;
		GXmlDomElement* _tmp733_;
		GXmlDomHTMLCollection* _tmp734_;
		GXmlDomHTMLCollection* _tmp735_;
		gint _tmp736_;
		gint _tmp737_;
		GXmlDomElement* _tmp738_;
		GXmlDomElement* _tmp739_;
		GXmlDomElement* _tmp740_;
		GXmlDomElement* _tmp741_;
		GXmlDomElement* _tmp742_;
		GXmlDomElement* _tmp743_;
		gchar* _tmp744_;
		gchar* _tmp745_;
		gchar* _tmp746_;
		GXmlDomElement* _tmp747_;
		GXmlDomElement* _tmp748_;
		gchar* _tmp749_;
		gchar* _tmp750_;
		gchar* _tmp751_;
#line 172 "DomGDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string (DOM_GDOCUMENT_TEST_HTMLDOC, 0, &_inner_error0_);
#line 172 "DomGDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 172 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2058 "DomGDocumentTest.c"
			goto __catch64_g_error;
		}
#line 172 "DomGDocumentTest.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL);
#line 172 "DomGDocumentTest.vala"
		doc = _tmp2_;
#line 173 "DomGDocumentTest.vala"
		_tmp3_ = doc;
#line 173 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_DOM_DOCUMENT), "doc is DomDocument");
#line 174 "DomGDocumentTest.vala"
		_tmp4_ = doc;
#line 174 "DomGDocumentTest.vala"
		_tmp5_ = gxml_dom_document_get_document_element (_tmp4_);
#line 174 "DomGDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 174 "DomGDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 174 "DomGDocumentTest.vala"
		_tmp8_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp7_);
#line 174 "DomGDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 174 "DomGDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 174 "DomGDocumentTest.vala"
		_tmp11_ = gee_collection_get_size ((GeeCollection*) _tmp10_);
#line 174 "DomGDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 174 "DomGDocumentTest.vala"
		_vala_assert (_tmp12_ == 1, "doc.document_element.children.size == 1");
#line 174 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp10_);
#line 174 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp7_);
#line 175 "DomGDocumentTest.vala"
		_tmp13_ = doc;
#line 175 "DomGDocumentTest.vala"
		_tmp14_ = gxml_dom_document_get_document_element (_tmp13_);
#line 175 "DomGDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 175 "DomGDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 175 "DomGDocumentTest.vala"
		_tmp17_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp16_);
#line 175 "DomGDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 175 "DomGDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 175 "DomGDocumentTest.vala"
		_tmp20_ = gee_list_get ((GeeList*) _tmp19_, 0);
#line 175 "DomGDocumentTest.vala"
		_tmp21_ = (GXmlDomElement*) _tmp20_;
#line 175 "DomGDocumentTest.vala"
		_vala_assert (_tmp21_ != NULL, "doc.document_element.children[0] != null");
#line 175 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp21_);
#line 175 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp19_);
#line 175 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp16_);
#line 176 "DomGDocumentTest.vala"
		_tmp22_ = doc;
#line 176 "DomGDocumentTest.vala"
		_tmp23_ = gxml_dom_document_get_document_element (_tmp22_);
#line 176 "DomGDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 176 "DomGDocumentTest.vala"
		_tmp25_ = _tmp24_;
#line 176 "DomGDocumentTest.vala"
		_tmp26_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp25_);
#line 176 "DomGDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 176 "DomGDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 176 "DomGDocumentTest.vala"
		_tmp29_ = gee_list_get ((GeeList*) _tmp28_, 0);
#line 176 "DomGDocumentTest.vala"
		_tmp30_ = (GXmlDomElement*) _tmp29_;
#line 176 "DomGDocumentTest.vala"
		_tmp31_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp30_);
#line 176 "DomGDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 176 "DomGDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 176 "DomGDocumentTest.vala"
		_tmp34_ = gee_list_get ((GeeList*) _tmp33_, 1);
#line 176 "DomGDocumentTest.vala"
		_tmp35_ = (GXmlDomElement*) _tmp34_;
#line 176 "DomGDocumentTest.vala"
		_vala_assert (_tmp35_ != NULL, "doc.document_element.children[0].children[1] != null");
#line 176 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp35_);
#line 176 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp33_);
#line 176 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp30_);
#line 176 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp28_);
#line 176 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp25_);
#line 177 "DomGDocumentTest.vala"
		_tmp36_ = doc;
#line 177 "DomGDocumentTest.vala"
		_tmp37_ = gxml_dom_document_get_document_element (_tmp36_);
#line 177 "DomGDocumentTest.vala"
		_tmp38_ = _tmp37_;
#line 177 "DomGDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 177 "DomGDocumentTest.vala"
		_tmp40_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp39_);
#line 177 "DomGDocumentTest.vala"
		_tmp41_ = _tmp40_;
#line 177 "DomGDocumentTest.vala"
		_tmp42_ = _tmp41_;
#line 177 "DomGDocumentTest.vala"
		_tmp43_ = gee_list_get ((GeeList*) _tmp42_, 0);
#line 177 "DomGDocumentTest.vala"
		_tmp44_ = (GXmlDomElement*) _tmp43_;
#line 177 "DomGDocumentTest.vala"
		_tmp45_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp44_);
#line 177 "DomGDocumentTest.vala"
		_tmp46_ = _tmp45_;
#line 177 "DomGDocumentTest.vala"
		_tmp47_ = _tmp46_;
#line 177 "DomGDocumentTest.vala"
		_tmp48_ = gee_list_get ((GeeList*) _tmp47_, 1);
#line 177 "DomGDocumentTest.vala"
		_tmp49_ = (GXmlDomElement*) _tmp48_;
#line 177 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp47_);
#line 177 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp44_);
#line 177 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp42_);
#line 177 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp39_);
#line 177 "DomGDocumentTest.vala"
		e = _tmp49_;
#line 178 "DomGDocumentTest.vala"
		_tmp50_ = e;
#line 178 "DomGDocumentTest.vala"
		_tmp51_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _tmp50_);
#line 178 "DomGDocumentTest.vala"
		_tmp52_ = _tmp51_;
#line 178 "DomGDocumentTest.vala"
		_tmp53_ = doc;
#line 178 "DomGDocumentTest.vala"
		_vala_assert (_tmp52_ == G_TYPE_CHECK_INSTANCE_CAST (_tmp53_, GXML_TYPE_DOM_DOCUMENT, GXmlDomDocument), "e.owner_document == (DomDocument) doc");
#line 179 "DomGDocumentTest.vala"
		_tmp54_ = e;
#line 179 "DomGDocumentTest.vala"
		_tmp55_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp54_);
#line 179 "DomGDocumentTest.vala"
		_tmp56_ = _tmp55_;
#line 179 "DomGDocumentTest.vala"
		_tmp57_ = _tmp56_;
#line 179 "DomGDocumentTest.vala"
		_vala_assert (_tmp57_ != NULL, "e.parent_node != null");
#line 179 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp57_);
#line 180 "DomGDocumentTest.vala"
		_tmp58_ = e;
#line 180 "DomGDocumentTest.vala"
		_tmp59_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp58_);
#line 180 "DomGDocumentTest.vala"
		_tmp60_ = _tmp59_;
#line 180 "DomGDocumentTest.vala"
		_tmp61_ = _tmp60_;
#line 180 "DomGDocumentTest.vala"
		_tmp62_ = gxml_dom_node_get_node_name (_tmp61_);
#line 180 "DomGDocumentTest.vala"
		_tmp63_ = _tmp62_;
#line 180 "DomGDocumentTest.vala"
		_tmp64_ = _tmp63_;
#line 180 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp64_, "body") == 0, "e.parent_node.node_name == \"body\"");
#line 180 "DomGDocumentTest.vala"
		_g_free0 (_tmp64_);
#line 180 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp61_);
#line 181 "DomGDocumentTest.vala"
		_tmp65_ = e;
#line 181 "DomGDocumentTest.vala"
		_tmp66_ = gxml_dom_node_get_parent_element ((GXmlDomNode*) _tmp65_);
#line 181 "DomGDocumentTest.vala"
		_tmp67_ = _tmp66_;
#line 181 "DomGDocumentTest.vala"
		_tmp68_ = _tmp67_;
#line 181 "DomGDocumentTest.vala"
		_vala_assert (_tmp68_ != NULL, "e.parent_element != null");
#line 181 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp68_);
#line 182 "DomGDocumentTest.vala"
		_tmp69_ = e;
#line 182 "DomGDocumentTest.vala"
		_tmp70_ = gxml_dom_node_get_parent_element ((GXmlDomNode*) _tmp69_);
#line 182 "DomGDocumentTest.vala"
		_tmp71_ = _tmp70_;
#line 182 "DomGDocumentTest.vala"
		_tmp72_ = _tmp71_;
#line 182 "DomGDocumentTest.vala"
		_tmp73_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp72_);
#line 182 "DomGDocumentTest.vala"
		_tmp74_ = _tmp73_;
#line 182 "DomGDocumentTest.vala"
		_tmp75_ = _tmp74_;
#line 182 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp75_, "body") == 0, "e.parent_element.node_name == \"body\"");
#line 182 "DomGDocumentTest.vala"
		_g_free0 (_tmp75_);
#line 182 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp72_);
#line 183 "DomGDocumentTest.vala"
		_tmp76_ = e;
#line 183 "DomGDocumentTest.vala"
		_tmp77_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp76_);
#line 183 "DomGDocumentTest.vala"
		_tmp78_ = _tmp77_;
#line 183 "DomGDocumentTest.vala"
		_tmp79_ = _tmp78_;
#line 183 "DomGDocumentTest.vala"
		_vala_assert (_tmp79_ != NULL, "e.child_nodes != null");
#line 183 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp79_);
#line 184 "DomGDocumentTest.vala"
		_tmp80_ = e;
#line 184 "DomGDocumentTest.vala"
		_tmp81_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp80_);
#line 184 "DomGDocumentTest.vala"
		_tmp82_ = _tmp81_;
#line 184 "DomGDocumentTest.vala"
		_tmp83_ = _tmp82_;
#line 184 "DomGDocumentTest.vala"
		_tmp84_ = gee_collection_get_size ((GeeCollection*) _tmp83_);
#line 184 "DomGDocumentTest.vala"
		_tmp85_ = _tmp84_;
#line 184 "DomGDocumentTest.vala"
		_vala_assert (_tmp85_ == 1, "e.child_nodes.size == 1");
#line 184 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp83_);
#line 185 "DomGDocumentTest.vala"
		_tmp86_ = e;
#line 185 "DomGDocumentTest.vala"
		_tmp87_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp86_);
#line 185 "DomGDocumentTest.vala"
		_tmp88_ = _tmp87_;
#line 185 "DomGDocumentTest.vala"
		_tmp89_ = _tmp88_;
#line 185 "DomGDocumentTest.vala"
		_tmp90_ = gxml_dom_node_list_item (_tmp89_, 0);
#line 185 "DomGDocumentTest.vala"
		_tmp91_ = _tmp90_;
#line 185 "DomGDocumentTest.vala"
		_vala_assert (_tmp91_ != NULL, "e.child_nodes.item (0) != null");
#line 185 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp91_);
#line 185 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp89_);
#line 186 "DomGDocumentTest.vala"
		_tmp92_ = e;
#line 186 "DomGDocumentTest.vala"
		_tmp93_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp92_);
#line 186 "DomGDocumentTest.vala"
		_tmp94_ = _tmp93_;
#line 186 "DomGDocumentTest.vala"
		_tmp95_ = _tmp94_;
#line 186 "DomGDocumentTest.vala"
		_tmp96_ = gxml_dom_node_list_item (_tmp95_, 0);
#line 186 "DomGDocumentTest.vala"
		_tmp97_ = _tmp96_;
#line 186 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp97_, GXML_TYPE_DOM_TEXT), "e.child_nodes.item (0) is DomText");
#line 186 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp97_);
#line 186 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp95_);
#line 187 "DomGDocumentTest.vala"
		_tmp98_ = e;
#line 187 "DomGDocumentTest.vala"
		_tmp99_ = gxml_dom_node_get_previous_sibling ((GXmlDomNode*) _tmp98_);
#line 187 "DomGDocumentTest.vala"
		_tmp100_ = _tmp99_;
#line 187 "DomGDocumentTest.vala"
		_tmp101_ = _tmp100_;
#line 187 "DomGDocumentTest.vala"
		_vala_assert (_tmp101_ != NULL, "e.previous_sibling != null");
#line 187 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp101_);
#line 188 "DomGDocumentTest.vala"
		_tmp102_ = e;
#line 188 "DomGDocumentTest.vala"
		_tmp103_ = gxml_dom_node_get_previous_sibling ((GXmlDomNode*) _tmp102_);
#line 188 "DomGDocumentTest.vala"
		_tmp104_ = _tmp103_;
#line 188 "DomGDocumentTest.vala"
		_tmp105_ = _tmp104_;
#line 188 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp105_, GXML_TYPE_DOM_TEXT), "e.previous_sibling is DomText");
#line 188 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp105_);
#line 189 "DomGDocumentTest.vala"
		_tmp106_ = e;
#line 189 "DomGDocumentTest.vala"
		_tmp107_ = gxml_dom_node_get_next_sibling ((GXmlDomNode*) _tmp106_);
#line 189 "DomGDocumentTest.vala"
		_tmp108_ = _tmp107_;
#line 189 "DomGDocumentTest.vala"
		_tmp109_ = _tmp108_;
#line 189 "DomGDocumentTest.vala"
		_vala_assert (_tmp109_ != NULL, "e.next_sibling != null");
#line 189 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp109_);
#line 190 "DomGDocumentTest.vala"
		_tmp110_ = e;
#line 190 "DomGDocumentTest.vala"
		_tmp111_ = gxml_dom_node_get_next_sibling ((GXmlDomNode*) _tmp110_);
#line 190 "DomGDocumentTest.vala"
		_tmp112_ = _tmp111_;
#line 190 "DomGDocumentTest.vala"
		_tmp113_ = _tmp112_;
#line 190 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp113_, GXML_TYPE_DOM_TEXT), "e.next_sibling is DomText");
#line 190 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp113_);
#line 191 "DomGDocumentTest.vala"
		_tmp114_ = e;
#line 191 "DomGDocumentTest.vala"
		_tmp115_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp114_);
#line 191 "DomGDocumentTest.vala"
		_tmp116_ = _tmp115_;
#line 191 "DomGDocumentTest.vala"
		_tmp117_ = _tmp116_;
#line 191 "DomGDocumentTest.vala"
		_tmp118_ = gxml_dom_node_list_item (_tmp117_, 0);
#line 191 "DomGDocumentTest.vala"
		_tmp119_ = _tmp118_;
#line 191 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp117_);
#line 191 "DomGDocumentTest.vala"
		t = _tmp119_;
#line 192 "DomGDocumentTest.vala"
		_tmp120_ = t;
#line 192 "DomGDocumentTest.vala"
		_tmp121_ = gxml_dom_node_get_previous_sibling (_tmp120_);
#line 192 "DomGDocumentTest.vala"
		_tmp122_ = _tmp121_;
#line 192 "DomGDocumentTest.vala"
		_tmp123_ = _tmp122_;
#line 192 "DomGDocumentTest.vala"
		_vala_assert (_tmp123_ == NULL, "t.previous_sibling == null");
#line 192 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp123_);
#line 193 "DomGDocumentTest.vala"
		_tmp124_ = t;
#line 193 "DomGDocumentTest.vala"
		_tmp125_ = gxml_dom_node_get_next_sibling (_tmp124_);
#line 193 "DomGDocumentTest.vala"
		_tmp126_ = _tmp125_;
#line 193 "DomGDocumentTest.vala"
		_tmp127_ = _tmp126_;
#line 193 "DomGDocumentTest.vala"
		_vala_assert (_tmp127_ == NULL, "t.next_sibling == null");
#line 193 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp127_);
#line 194 "DomGDocumentTest.vala"
		_tmp128_ = t;
#line 194 "DomGDocumentTest.vala"
		_tmp129_ = gxml_dom_node_get_text_content (_tmp128_);
#line 194 "DomGDocumentTest.vala"
		_tmp130_ = _tmp129_;
#line 194 "DomGDocumentTest.vala"
		_tmp131_ = _tmp130_;
#line 194 "DomGDocumentTest.vala"
		_vala_assert (_tmp131_ != NULL, "t.text_content != null");
#line 194 "DomGDocumentTest.vala"
		_g_free0 (_tmp131_);
#line 195 "DomGDocumentTest.vala"
		_tmp132_ = t;
#line 195 "DomGDocumentTest.vala"
		_tmp133_ = gxml_dom_node_get_text_content (_tmp132_);
#line 195 "DomGDocumentTest.vala"
		_tmp134_ = _tmp133_;
#line 195 "DomGDocumentTest.vala"
		_tmp135_ = _tmp134_;
#line 195 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp135_, "p01 p id") == 0, "t.text_content == \"p01 p id\"");
#line 195 "DomGDocumentTest.vala"
		_g_free0 (_tmp135_);
#line 196 "DomGDocumentTest.vala"
		_tmp136_ = e;
#line 196 "DomGDocumentTest.vala"
		_tmp137_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp136_);
#line 196 "DomGDocumentTest.vala"
		_tmp138_ = _tmp137_;
#line 196 "DomGDocumentTest.vala"
		_tmp139_ = _tmp138_;
#line 196 "DomGDocumentTest.vala"
		_tmp140_ = gxml_dom_node_get_text_content (_tmp139_);
#line 196 "DomGDocumentTest.vala"
		_tmp141_ = _tmp140_;
#line 196 "DomGDocumentTest.vala"
		_tmp142_ = _tmp141_;
#line 196 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp142_, "\n\n\n\n\n") == 0, "e.parent_node.text_content == \"\\n\\n\\n\\n\\n\"");
#line 196 "DomGDocumentTest.vala"
		_g_free0 (_tmp142_);
#line 196 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp139_);
#line 197 "DomGDocumentTest.vala"
		_tmp143_ = e;
#line 197 "DomGDocumentTest.vala"
		_tmp144_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp143_);
#line 197 "DomGDocumentTest.vala"
		_tmp145_ = _tmp144_;
#line 197 "DomGDocumentTest.vala"
		_tmp146_ = _tmp145_;
#line 197 "DomGDocumentTest.vala"
		_vala_assert (gxml_dom_node_has_child_nodes (_tmp146_), "e.parent_node.has_child_nodes ()");
#line 197 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp146_);
#line 198 "DomGDocumentTest.vala"
		_tmp147_ = e;
#line 198 "DomGDocumentTest.vala"
		_tmp148_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp147_);
#line 198 "DomGDocumentTest.vala"
		_tmp149_ = _tmp148_;
#line 198 "DomGDocumentTest.vala"
		_tmp150_ = _tmp149_;
#line 198 "DomGDocumentTest.vala"
		gxml_dom_node_normalize (_tmp150_);
#line 198 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp150_);
#line 199 "DomGDocumentTest.vala"
		_tmp151_ = e;
#line 199 "DomGDocumentTest.vala"
		_tmp152_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp151_);
#line 199 "DomGDocumentTest.vala"
		_tmp153_ = _tmp152_;
#line 199 "DomGDocumentTest.vala"
		_tmp154_ = _tmp153_;
#line 199 "DomGDocumentTest.vala"
		_tmp155_ = gxml_dom_node_get_text_content (_tmp154_);
#line 199 "DomGDocumentTest.vala"
		_tmp156_ = _tmp155_;
#line 199 "DomGDocumentTest.vala"
		_tmp157_ = _tmp156_;
#line 199 "DomGDocumentTest.vala"
		_vala_assert (_tmp157_ == NULL, "e.parent_node.text_content == null");
#line 199 "DomGDocumentTest.vala"
		_g_free0 (_tmp157_);
#line 199 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp154_);
#line 200 "DomGDocumentTest.vala"
		_tmp159_ = e;
#line 200 "DomGDocumentTest.vala"
		_tmp160_ = gxml_dom_node_clone_node ((GXmlDomNode*) _tmp159_, FALSE, &_inner_error0_);
#line 200 "DomGDocumentTest.vala"
		_tmp158_ = _tmp160_;
#line 200 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 200 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 200 "DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 200 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 200 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 2527 "DomGDocumentTest.c"
			goto __catch64_g_error;
		}
#line 200 "DomGDocumentTest.vala"
		_tmp161_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp158_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp158_) : NULL);
#line 200 "DomGDocumentTest.vala"
		cn = _tmp161_;
#line 201 "DomGDocumentTest.vala"
		_tmp162_ = cn;
#line 201 "DomGDocumentTest.vala"
		_tmp163_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp162_);
#line 201 "DomGDocumentTest.vala"
		_tmp164_ = _tmp163_;
#line 201 "DomGDocumentTest.vala"
		_tmp165_ = _tmp164_;
#line 201 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp165_, "p") == 0, "cn.node_name == \"p\"");
#line 201 "DomGDocumentTest.vala"
		_g_free0 (_tmp165_);
#line 202 "DomGDocumentTest.vala"
		_tmp166_ = cn;
#line 202 "DomGDocumentTest.vala"
		_tmp167_ = gxml_dom_element_get_attribute (_tmp166_, "id");
#line 202 "DomGDocumentTest.vala"
		_tmp168_ = _tmp167_;
#line 202 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp168_, "p01") == 0, "cn.get_attribute (\"id\") == \"p01\"");
#line 202 "DomGDocumentTest.vala"
		_g_free0 (_tmp168_);
#line 203 "DomGDocumentTest.vala"
		_tmp169_ = cn;
#line 203 "DomGDocumentTest.vala"
		_tmp170_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp169_);
#line 203 "DomGDocumentTest.vala"
		_tmp171_ = _tmp170_;
#line 203 "DomGDocumentTest.vala"
		_tmp172_ = _tmp171_;
#line 203 "DomGDocumentTest.vala"
		_vala_assert (_tmp172_ != NULL, "cn.child_nodes != null");
#line 203 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp172_);
#line 204 "DomGDocumentTest.vala"
		_tmp173_ = cn;
#line 204 "DomGDocumentTest.vala"
		_tmp174_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp173_);
#line 204 "DomGDocumentTest.vala"
		_tmp175_ = _tmp174_;
#line 204 "DomGDocumentTest.vala"
		_tmp176_ = _tmp175_;
#line 204 "DomGDocumentTest.vala"
		_tmp177_ = gee_collection_get_size ((GeeCollection*) _tmp176_);
#line 204 "DomGDocumentTest.vala"
		_tmp178_ = _tmp177_;
#line 204 "DomGDocumentTest.vala"
		_vala_assert (_tmp178_ == 0, "cn.child_nodes.size == 0");
#line 204 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp176_);
#line 205 "DomGDocumentTest.vala"
		_tmp180_ = e;
#line 205 "DomGDocumentTest.vala"
		_tmp181_ = gxml_dom_node_clone_node ((GXmlDomNode*) _tmp180_, TRUE, &_inner_error0_);
#line 205 "DomGDocumentTest.vala"
		_tmp179_ = _tmp181_;
#line 205 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 205 "DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 205 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp158_);
#line 205 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 205 "DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 205 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 205 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 2604 "DomGDocumentTest.c"
			goto __catch64_g_error;
		}
#line 205 "DomGDocumentTest.vala"
		_tmp182_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp179_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp179_) : NULL);
#line 205 "DomGDocumentTest.vala"
		cn2 = _tmp182_;
#line 206 "DomGDocumentTest.vala"
		_tmp183_ = cn2;
#line 206 "DomGDocumentTest.vala"
		_tmp184_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp183_);
#line 206 "DomGDocumentTest.vala"
		_tmp185_ = _tmp184_;
#line 206 "DomGDocumentTest.vala"
		_tmp186_ = _tmp185_;
#line 206 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp186_, "p") == 0, "cn2.node_name == \"p\"");
#line 206 "DomGDocumentTest.vala"
		_g_free0 (_tmp186_);
#line 207 "DomGDocumentTest.vala"
		_tmp187_ = cn2;
#line 207 "DomGDocumentTest.vala"
		_tmp188_ = gxml_dom_element_get_attribute (_tmp187_, "id");
#line 207 "DomGDocumentTest.vala"
		_tmp189_ = _tmp188_;
#line 207 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp189_, "p01") == 0, "cn2.get_attribute (\"id\") == \"p01\"");
#line 207 "DomGDocumentTest.vala"
		_g_free0 (_tmp189_);
#line 208 "DomGDocumentTest.vala"
		_tmp190_ = cn2;
#line 208 "DomGDocumentTest.vala"
		_tmp191_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp190_);
#line 208 "DomGDocumentTest.vala"
		_tmp192_ = _tmp191_;
#line 208 "DomGDocumentTest.vala"
		_tmp193_ = _tmp192_;
#line 208 "DomGDocumentTest.vala"
		_vala_assert (_tmp193_ != NULL, "cn2.child_nodes != null");
#line 208 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp193_);
#line 209 "DomGDocumentTest.vala"
		_tmp194_ = cn2;
#line 209 "DomGDocumentTest.vala"
		_tmp195_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp194_);
#line 209 "DomGDocumentTest.vala"
		_tmp196_ = _tmp195_;
#line 209 "DomGDocumentTest.vala"
		_tmp197_ = _tmp196_;
#line 209 "DomGDocumentTest.vala"
		_tmp198_ = gee_collection_get_size ((GeeCollection*) _tmp197_);
#line 209 "DomGDocumentTest.vala"
		_tmp199_ = _tmp198_;
#line 209 "DomGDocumentTest.vala"
		_vala_assert (_tmp199_ == 1, "cn2.child_nodes.size == 1");
#line 209 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp197_);
#line 210 "DomGDocumentTest.vala"
		_tmp200_ = cn2;
#line 210 "DomGDocumentTest.vala"
		_tmp201_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp200_);
#line 210 "DomGDocumentTest.vala"
		_tmp202_ = _tmp201_;
#line 210 "DomGDocumentTest.vala"
		_tmp203_ = _tmp202_;
#line 210 "DomGDocumentTest.vala"
		_tmp204_ = gee_list_get ((GeeList*) _tmp203_, 0);
#line 210 "DomGDocumentTest.vala"
		_tmp205_ = (GXmlDomNode*) _tmp204_;
#line 210 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp205_, GXML_TYPE_DOM_TEXT), "cn2.child_nodes[0] is DomText");
#line 210 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp205_);
#line 210 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp203_);
#line 211 "DomGDocumentTest.vala"
		_tmp206_ = cn2;
#line 211 "DomGDocumentTest.vala"
		_tmp207_ = gxml_dom_node_get_text_content ((GXmlDomNode*) _tmp206_);
#line 211 "DomGDocumentTest.vala"
		_tmp208_ = _tmp207_;
#line 211 "DomGDocumentTest.vala"
		_tmp209_ = _tmp208_;
#line 211 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp209_, "p01 p id") == 0, "cn2.text_content == \"p01 p id\"");
#line 211 "DomGDocumentTest.vala"
		_g_free0 (_tmp209_);
#line 212 "DomGDocumentTest.vala"
		_tmp210_ = e;
#line 212 "DomGDocumentTest.vala"
		_tmp211_ = cn;
#line 212 "DomGDocumentTest.vala"
		_vala_assert (!gxml_dom_node_is_equal_node ((GXmlDomNode*) _tmp210_, (GXmlDomNode*) _tmp211_), "!e.is_equal_node (cn)");
#line 213 "DomGDocumentTest.vala"
		_tmp212_ = e;
#line 213 "DomGDocumentTest.vala"
		_tmp213_ = cn2;
#line 213 "DomGDocumentTest.vala"
		_vala_assert (gxml_dom_node_is_equal_node ((GXmlDomNode*) _tmp212_, (GXmlDomNode*) _tmp213_), "e.is_equal_node (cn2)");
#line 214 "DomGDocumentTest.vala"
		_tmp214_ = doc;
#line 214 "DomGDocumentTest.vala"
		_tmp215_ = gxml_dom_document_get_document_element (_tmp214_);
#line 214 "DomGDocumentTest.vala"
		_tmp216_ = _tmp215_;
#line 214 "DomGDocumentTest.vala"
		_tmp217_ = _tmp216_;
#line 214 "DomGDocumentTest.vala"
		_tmp218_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp217_);
#line 214 "DomGDocumentTest.vala"
		_tmp219_ = _tmp218_;
#line 214 "DomGDocumentTest.vala"
		_tmp220_ = _tmp219_;
#line 214 "DomGDocumentTest.vala"
		_tmp221_ = gee_list_get ((GeeList*) _tmp220_, 0);
#line 214 "DomGDocumentTest.vala"
		_tmp222_ = (GXmlDomElement*) _tmp221_;
#line 214 "DomGDocumentTest.vala"
		_tmp223_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp222_);
#line 214 "DomGDocumentTest.vala"
		_tmp224_ = _tmp223_;
#line 214 "DomGDocumentTest.vala"
		_tmp225_ = _tmp224_;
#line 214 "DomGDocumentTest.vala"
		_tmp226_ = gee_list_get ((GeeList*) _tmp225_, 0);
#line 214 "DomGDocumentTest.vala"
		_tmp227_ = (GXmlDomElement*) _tmp226_;
#line 214 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp225_);
#line 214 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp222_);
#line 214 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp220_);
#line 214 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp217_);
#line 214 "DomGDocumentTest.vala"
		e0 = _tmp227_;
#line 215 "DomGDocumentTest.vala"
		_tmp228_ = e0;
#line 215 "DomGDocumentTest.vala"
		_tmp229_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp228_);
#line 215 "DomGDocumentTest.vala"
		_tmp230_ = _tmp229_;
#line 215 "DomGDocumentTest.vala"
		_tmp231_ = _tmp230_;
#line 215 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp231_, "p") == 0, "e0.node_name == \"p\"");
#line 215 "DomGDocumentTest.vala"
		_g_free0 (_tmp231_);
#line 216 "DomGDocumentTest.vala"
		_tmp232_ = doc;
#line 216 "DomGDocumentTest.vala"
		_tmp233_ = gxml_dom_document_get_document_element (_tmp232_);
#line 216 "DomGDocumentTest.vala"
		_tmp234_ = _tmp233_;
#line 216 "DomGDocumentTest.vala"
		_tmp235_ = _tmp234_;
#line 216 "DomGDocumentTest.vala"
		_tmp236_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp235_);
#line 216 "DomGDocumentTest.vala"
		_tmp237_ = _tmp236_;
#line 216 "DomGDocumentTest.vala"
		_tmp238_ = _tmp237_;
#line 216 "DomGDocumentTest.vala"
		_tmp239_ = gee_list_get ((GeeList*) _tmp238_, 0);
#line 216 "DomGDocumentTest.vala"
		_tmp240_ = (GXmlDomElement*) _tmp239_;
#line 216 "DomGDocumentTest.vala"
		_tmp241_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp240_);
#line 216 "DomGDocumentTest.vala"
		_tmp242_ = _tmp241_;
#line 216 "DomGDocumentTest.vala"
		_tmp243_ = _tmp242_;
#line 216 "DomGDocumentTest.vala"
		_tmp244_ = e0;
#line 216 "DomGDocumentTest.vala"
		_vala_assert (gee_list_index_of ((GeeList*) _tmp243_, (GXmlDomNode*) _tmp244_) == 0, "doc.document_element.children[0].child_nodes.index_of (e0) == 0");
#line 216 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp243_);
#line 216 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp240_);
#line 216 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp238_);
#line 216 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp235_);
#line 217 "DomGDocumentTest.vala"
		_tmp245_ = doc;
#line 217 "DomGDocumentTest.vala"
		_tmp246_ = gxml_dom_document_get_document_element (_tmp245_);
#line 217 "DomGDocumentTest.vala"
		_tmp247_ = _tmp246_;
#line 217 "DomGDocumentTest.vala"
		_tmp248_ = _tmp247_;
#line 217 "DomGDocumentTest.vala"
		_tmp249_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp248_);
#line 217 "DomGDocumentTest.vala"
		_tmp250_ = _tmp249_;
#line 217 "DomGDocumentTest.vala"
		_tmp251_ = _tmp250_;
#line 217 "DomGDocumentTest.vala"
		_tmp252_ = gee_list_get ((GeeList*) _tmp251_, 0);
#line 217 "DomGDocumentTest.vala"
		_tmp253_ = (GXmlDomElement*) _tmp252_;
#line 217 "DomGDocumentTest.vala"
		_tmp254_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp253_);
#line 217 "DomGDocumentTest.vala"
		_tmp255_ = _tmp254_;
#line 217 "DomGDocumentTest.vala"
		_tmp256_ = _tmp255_;
#line 217 "DomGDocumentTest.vala"
		_tmp257_ = gee_list_get ((GeeList*) _tmp256_, 1);
#line 217 "DomGDocumentTest.vala"
		_tmp258_ = (GXmlDomElement*) _tmp257_;
#line 217 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp256_);
#line 217 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp253_);
#line 217 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp251_);
#line 217 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp248_);
#line 217 "DomGDocumentTest.vala"
		e1 = _tmp258_;
#line 218 "DomGDocumentTest.vala"
		_tmp259_ = e1;
#line 218 "DomGDocumentTest.vala"
		_tmp260_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp259_);
#line 218 "DomGDocumentTest.vala"
		_tmp261_ = _tmp260_;
#line 218 "DomGDocumentTest.vala"
		_tmp262_ = _tmp261_;
#line 218 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp262_, "p") == 0, "e1.node_name == \"p\"");
#line 218 "DomGDocumentTest.vala"
		_g_free0 (_tmp262_);
#line 219 "DomGDocumentTest.vala"
		_tmp263_ = doc;
#line 219 "DomGDocumentTest.vala"
		_tmp264_ = gxml_dom_document_get_document_element (_tmp263_);
#line 219 "DomGDocumentTest.vala"
		_tmp265_ = _tmp264_;
#line 219 "DomGDocumentTest.vala"
		_tmp266_ = _tmp265_;
#line 219 "DomGDocumentTest.vala"
		_tmp267_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp266_);
#line 219 "DomGDocumentTest.vala"
		_tmp268_ = _tmp267_;
#line 219 "DomGDocumentTest.vala"
		_tmp269_ = _tmp268_;
#line 219 "DomGDocumentTest.vala"
		_tmp270_ = gee_list_get ((GeeList*) _tmp269_, 0);
#line 219 "DomGDocumentTest.vala"
		_tmp271_ = (GXmlDomElement*) _tmp270_;
#line 219 "DomGDocumentTest.vala"
		_tmp272_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp271_);
#line 219 "DomGDocumentTest.vala"
		_tmp273_ = _tmp272_;
#line 219 "DomGDocumentTest.vala"
		_tmp274_ = _tmp273_;
#line 219 "DomGDocumentTest.vala"
		_tmp275_ = e1;
#line 219 "DomGDocumentTest.vala"
		_vala_assert (gee_list_index_of ((GeeList*) _tmp274_, (GXmlDomNode*) _tmp275_) == 1, "doc.document_element.children[0].child_nodes.index_of (e1) == 1");
#line 219 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp274_);
#line 219 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp271_);
#line 219 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp269_);
#line 219 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp266_);
#line 220 "DomGDocumentTest.vala"
		_tmp276_ = doc;
#line 220 "DomGDocumentTest.vala"
		_tmp277_ = gxml_dom_document_get_document_element (_tmp276_);
#line 220 "DomGDocumentTest.vala"
		_tmp278_ = _tmp277_;
#line 220 "DomGDocumentTest.vala"
		_tmp279_ = _tmp278_;
#line 220 "DomGDocumentTest.vala"
		_tmp280_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp279_);
#line 220 "DomGDocumentTest.vala"
		_tmp281_ = _tmp280_;
#line 220 "DomGDocumentTest.vala"
		_tmp282_ = _tmp281_;
#line 220 "DomGDocumentTest.vala"
		_tmp283_ = gee_list_get ((GeeList*) _tmp282_, 0);
#line 220 "DomGDocumentTest.vala"
		_tmp284_ = (GXmlDomElement*) _tmp283_;
#line 220 "DomGDocumentTest.vala"
		_tmp285_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp284_);
#line 220 "DomGDocumentTest.vala"
		_tmp286_ = _tmp285_;
#line 220 "DomGDocumentTest.vala"
		_tmp287_ = _tmp286_;
#line 220 "DomGDocumentTest.vala"
		_tmp288_ = gee_list_get ((GeeList*) _tmp287_, 2);
#line 220 "DomGDocumentTest.vala"
		_tmp289_ = (GXmlDomElement*) _tmp288_;
#line 220 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp287_);
#line 220 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp284_);
#line 220 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp282_);
#line 220 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp279_);
#line 220 "DomGDocumentTest.vala"
		e2 = _tmp289_;
#line 221 "DomGDocumentTest.vala"
		_tmp290_ = e2;
#line 221 "DomGDocumentTest.vala"
		_tmp291_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp290_);
#line 221 "DomGDocumentTest.vala"
		_tmp292_ = _tmp291_;
#line 221 "DomGDocumentTest.vala"
		_tmp293_ = _tmp292_;
#line 221 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp293_, "p") == 0, "e2.node_name == \"p\"");
#line 221 "DomGDocumentTest.vala"
		_g_free0 (_tmp293_);
#line 222 "DomGDocumentTest.vala"
		_tmp294_ = doc;
#line 222 "DomGDocumentTest.vala"
		_tmp295_ = gxml_dom_document_get_document_element (_tmp294_);
#line 222 "DomGDocumentTest.vala"
		_tmp296_ = _tmp295_;
#line 222 "DomGDocumentTest.vala"
		_tmp297_ = _tmp296_;
#line 222 "DomGDocumentTest.vala"
		_tmp298_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp297_);
#line 222 "DomGDocumentTest.vala"
		_tmp299_ = _tmp298_;
#line 222 "DomGDocumentTest.vala"
		_tmp300_ = _tmp299_;
#line 222 "DomGDocumentTest.vala"
		_tmp301_ = gee_list_get ((GeeList*) _tmp300_, 0);
#line 222 "DomGDocumentTest.vala"
		_tmp302_ = (GXmlDomElement*) _tmp301_;
#line 222 "DomGDocumentTest.vala"
		_tmp303_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp302_);
#line 222 "DomGDocumentTest.vala"
		_tmp304_ = _tmp303_;
#line 222 "DomGDocumentTest.vala"
		_tmp305_ = _tmp304_;
#line 222 "DomGDocumentTest.vala"
		_tmp306_ = e2;
#line 222 "DomGDocumentTest.vala"
		_vala_assert (gee_list_index_of ((GeeList*) _tmp305_, (GXmlDomNode*) _tmp306_) == 2, "doc.document_element.children[0].child_nodes.index_of (e2) == 2");
#line 222 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp305_);
#line 222 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp302_);
#line 222 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp300_);
#line 222 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp297_);
#line 223 "DomGDocumentTest.vala"
		_tmp307_ = e;
#line 223 "DomGDocumentTest.vala"
		_tmp308_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp307_);
#line 223 "DomGDocumentTest.vala"
		_tmp309_ = _tmp308_;
#line 223 "DomGDocumentTest.vala"
		_tmp310_ = _tmp309_;
#line 223 "DomGDocumentTest.vala"
		_tmp311_ = e0;
#line 223 "DomGDocumentTest.vala"
		_vala_assert (gxml_dom_node_contains (_tmp310_, (GXmlDomNode*) _tmp311_), "e.parent_node.contains (e0)");
#line 223 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp310_);
#line 224 "DomGDocumentTest.vala"
		_tmp312_ = e;
#line 224 "DomGDocumentTest.vala"
		_tmp313_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp312_);
#line 224 "DomGDocumentTest.vala"
		_tmp314_ = _tmp313_;
#line 224 "DomGDocumentTest.vala"
		_tmp315_ = _tmp314_;
#line 224 "DomGDocumentTest.vala"
		_tmp316_ = e1;
#line 224 "DomGDocumentTest.vala"
		_vala_assert (gxml_dom_node_contains (_tmp315_, (GXmlDomNode*) _tmp316_), "e.parent_node.contains (e1)");
#line 224 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp315_);
#line 225 "DomGDocumentTest.vala"
		_tmp317_ = e;
#line 225 "DomGDocumentTest.vala"
		_tmp318_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp317_);
#line 225 "DomGDocumentTest.vala"
		_tmp319_ = _tmp318_;
#line 225 "DomGDocumentTest.vala"
		_tmp320_ = _tmp319_;
#line 225 "DomGDocumentTest.vala"
		_tmp321_ = e2;
#line 225 "DomGDocumentTest.vala"
		_vala_assert (gxml_dom_node_contains (_tmp320_, (GXmlDomNode*) _tmp321_), "e.parent_node.contains (e2)");
#line 225 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp320_);
#line 226 "DomGDocumentTest.vala"
		_tmp323_ = e1;
#line 226 "DomGDocumentTest.vala"
		_tmp324_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp323_);
#line 226 "DomGDocumentTest.vala"
		_tmp325_ = _tmp324_;
#line 226 "DomGDocumentTest.vala"
		_tmp326_ = _tmp325_;
#line 226 "DomGDocumentTest.vala"
		_tmp327_ = e0;
#line 226 "DomGDocumentTest.vala"
		_tmp328_ = gxml_dom_node_contains (_tmp326_, (GXmlDomNode*) _tmp327_);
#line 226 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp326_);
#line 226 "DomGDocumentTest.vala"
		if (_tmp328_) {
#line 3019 "DomGDocumentTest.c"
			GXmlDomElement* _tmp329_;
			GXmlDomNode* _tmp330_;
			GXmlDomNode* _tmp331_;
			GXmlDomNode* _tmp332_;
			GXmlDomElement* _tmp333_;
#line 226 "DomGDocumentTest.vala"
			_tmp329_ = e0;
#line 226 "DomGDocumentTest.vala"
			_tmp330_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp329_);
#line 226 "DomGDocumentTest.vala"
			_tmp331_ = _tmp330_;
#line 226 "DomGDocumentTest.vala"
			_tmp332_ = _tmp331_;
#line 226 "DomGDocumentTest.vala"
			_tmp333_ = e1;
#line 226 "DomGDocumentTest.vala"
			_tmp322_ = gxml_dom_node_contains (_tmp332_, (GXmlDomNode*) _tmp333_);
#line 226 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp332_);
#line 3039 "DomGDocumentTest.c"
		} else {
#line 226 "DomGDocumentTest.vala"
			_tmp322_ = FALSE;
#line 3043 "DomGDocumentTest.c"
		}
#line 226 "DomGDocumentTest.vala"
		_vala_assert (_tmp322_, "e1.parent_node.contains (e0) && e0.parent_node.contains (e1)");
#line 227 "DomGDocumentTest.vala"
		_tmp334_ = e1;
#line 227 "DomGDocumentTest.vala"
		_tmp335_ = e0;
#line 227 "DomGDocumentTest.vala"
		_vala_assert (gxml_dom_node_compare_document_position ((GXmlDomNode*) _tmp334_, (GXmlDomNode*) _tmp335_) == GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING, "e1.compare_document_position (e0) == DomNode.DocumentPosition.PRECEDING");
#line 228 "DomGDocumentTest.vala"
		_tmp337_ = e1;
#line 228 "DomGDocumentTest.vala"
		_tmp338_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp337_);
#line 228 "DomGDocumentTest.vala"
		_tmp339_ = _tmp338_;
#line 228 "DomGDocumentTest.vala"
		_tmp340_ = _tmp339_;
#line 228 "DomGDocumentTest.vala"
		_tmp341_ = e2;
#line 228 "DomGDocumentTest.vala"
		_tmp342_ = gxml_dom_node_contains (_tmp340_, (GXmlDomNode*) _tmp341_);
#line 228 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp340_);
#line 228 "DomGDocumentTest.vala"
		if (_tmp342_) {
#line 3069 "DomGDocumentTest.c"
			GXmlDomElement* _tmp343_;
			GXmlDomNode* _tmp344_;
			GXmlDomNode* _tmp345_;
			GXmlDomNode* _tmp346_;
			GXmlDomElement* _tmp347_;
#line 228 "DomGDocumentTest.vala"
			_tmp343_ = e2;
#line 228 "DomGDocumentTest.vala"
			_tmp344_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp343_);
#line 228 "DomGDocumentTest.vala"
			_tmp345_ = _tmp344_;
#line 228 "DomGDocumentTest.vala"
			_tmp346_ = _tmp345_;
#line 228 "DomGDocumentTest.vala"
			_tmp347_ = e1;
#line 228 "DomGDocumentTest.vala"
			_tmp336_ = gxml_dom_node_contains (_tmp346_, (GXmlDomNode*) _tmp347_);
#line 228 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp346_);
#line 3089 "DomGDocumentTest.c"
		} else {
#line 228 "DomGDocumentTest.vala"
			_tmp336_ = FALSE;
#line 3093 "DomGDocumentTest.c"
		}
#line 228 "DomGDocumentTest.vala"
		_vala_assert (_tmp336_, "e1.parent_node.contains (e2) && e2.parent_node.contains (e1)");
#line 229 "DomGDocumentTest.vala"
		_tmp348_ = e1;
#line 229 "DomGDocumentTest.vala"
		_tmp349_ = e2;
#line 229 "DomGDocumentTest.vala"
		_vala_assert (gxml_dom_node_compare_document_position ((GXmlDomNode*) _tmp348_, (GXmlDomNode*) _tmp349_) == GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING, "e1.compare_document_position (e2) == DomNode.DocumentPosition.FOLLOWING");
#line 230 "DomGDocumentTest.vala"
		_tmp350_ = e1;
#line 230 "DomGDocumentTest.vala"
		_tmp351_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp350_);
#line 230 "DomGDocumentTest.vala"
		_tmp352_ = _tmp351_;
#line 230 "DomGDocumentTest.vala"
		_tmp353_ = _tmp352_;
#line 230 "DomGDocumentTest.vala"
		_tmp354_ = e1;
#line 230 "DomGDocumentTest.vala"
		_vala_assert (gxml_dom_node_contains (_tmp353_, (GXmlDomNode*) _tmp354_), "e1.parent_node.contains (e1)");
#line 230 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp353_);
#line 231 "DomGDocumentTest.vala"
		_tmp355_ = e1;
#line 231 "DomGDocumentTest.vala"
		_tmp356_ = e1;
#line 231 "DomGDocumentTest.vala"
		_tmp357_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp356_);
#line 231 "DomGDocumentTest.vala"
		_tmp358_ = _tmp357_;
#line 231 "DomGDocumentTest.vala"
		_tmp359_ = _tmp358_;
#line 231 "DomGDocumentTest.vala"
		_vala_assert (gxml_dom_node_compare_document_position ((GXmlDomNode*) _tmp355_, _tmp359_) == (GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINS & GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING), "e1.compare_document_position (e1.parent_node) == (DomNode.DocumentPosition.CONTAINS & DomNode.DocumentPosition.FOLLOWING)");
#line 231 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp359_);
#line 232 "DomGDocumentTest.vala"
		_tmp360_ = e1;
#line 232 "DomGDocumentTest.vala"
		_tmp361_ = e1;
#line 232 "DomGDocumentTest.vala"
		_tmp362_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp361_);
#line 232 "DomGDocumentTest.vala"
		_tmp363_ = _tmp362_;
#line 232 "DomGDocumentTest.vala"
		_tmp364_ = _tmp363_;
#line 232 "DomGDocumentTest.vala"
		_tmp365_ = gee_list_get ((GeeList*) _tmp364_, 0);
#line 232 "DomGDocumentTest.vala"
		_tmp366_ = (GXmlDomNode*) _tmp365_;
#line 232 "DomGDocumentTest.vala"
		_vala_assert (gxml_dom_node_contains ((GXmlDomNode*) _tmp360_, _tmp366_), "e1.contains (e1.child_nodes[0])");
#line 232 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp366_);
#line 232 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp364_);
#line 233 "DomGDocumentTest.vala"
		_tmp367_ = e1;
#line 233 "DomGDocumentTest.vala"
		_tmp368_ = e1;
#line 233 "DomGDocumentTest.vala"
		_tmp369_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp368_);
#line 233 "DomGDocumentTest.vala"
		_tmp370_ = _tmp369_;
#line 233 "DomGDocumentTest.vala"
		_tmp371_ = _tmp370_;
#line 233 "DomGDocumentTest.vala"
		_tmp372_ = gee_list_get ((GeeList*) _tmp371_, 0);
#line 233 "DomGDocumentTest.vala"
		_tmp373_ = (GXmlDomNode*) _tmp372_;
#line 233 "DomGDocumentTest.vala"
		_vala_assert (gxml_dom_node_compare_document_position ((GXmlDomNode*) _tmp367_, _tmp373_) == (GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINED_BY & GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING), "e1.compare_document_position (e1.child_nodes[0]) == (DomNode.DocumentPosition.CONTAINED_BY & DomNode.DocumentPosition.PRECEDING)");
#line 233 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp373_);
#line 233 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp371_);
#line 234 "DomGDocumentTest.vala"
		_tmp374_ = doc;
#line 234 "DomGDocumentTest.vala"
		_tmp375_ = gxml_dom_document_get_document_element (_tmp374_);
#line 234 "DomGDocumentTest.vala"
		_tmp376_ = _tmp375_;
#line 234 "DomGDocumentTest.vala"
		_tmp377_ = _tmp376_;
#line 234 "DomGDocumentTest.vala"
		_tmp378_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp377_);
#line 234 "DomGDocumentTest.vala"
		_tmp379_ = _tmp378_;
#line 234 "DomGDocumentTest.vala"
		_tmp380_ = _tmp379_;
#line 234 "DomGDocumentTest.vala"
		_tmp381_ = gee_list_get ((GeeList*) _tmp380_, 0);
#line 234 "DomGDocumentTest.vala"
		_tmp382_ = (GXmlDomElement*) _tmp381_;
#line 234 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp380_);
#line 234 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp377_);
#line 234 "DomGDocumentTest.vala"
		b = _tmp382_;
#line 235 "DomGDocumentTest.vala"
		_tmp383_ = b;
#line 235 "DomGDocumentTest.vala"
		_tmp384_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp383_);
#line 235 "DomGDocumentTest.vala"
		_tmp385_ = _tmp384_;
#line 235 "DomGDocumentTest.vala"
		_tmp386_ = _tmp385_;
#line 235 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp386_, "body") == 0, "b.node_name == \"body\"");
#line 235 "DomGDocumentTest.vala"
		_g_free0 (_tmp386_);
#line 236 "DomGDocumentTest.vala"
		_tmp387_ = doc;
#line 236 "DomGDocumentTest.vala"
		_tmp388_ = gxml_dom_document_create_element_ns (_tmp387_, "http://git.gnome.org/browse/gxml", "gxml:MyNode", &_inner_error0_);
#line 236 "DomGDocumentTest.vala"
		ng = _tmp388_;
#line 236 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 236 "DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 236 "DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 236 "DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 236 "DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 236 "DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 236 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp179_);
#line 236 "DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 236 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp158_);
#line 236 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 236 "DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 236 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 236 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 3239 "DomGDocumentTest.c"
			goto __catch64_g_error;
		}
#line 237 "DomGDocumentTest.vala"
		_tmp389_ = b;
#line 237 "DomGDocumentTest.vala"
		_tmp390_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp389_);
#line 237 "DomGDocumentTest.vala"
		_tmp391_ = _tmp390_;
#line 237 "DomGDocumentTest.vala"
		_tmp392_ = _tmp391_;
#line 237 "DomGDocumentTest.vala"
		_tmp393_ = ng;
#line 237 "DomGDocumentTest.vala"
		gee_collection_add ((GeeCollection*) _tmp392_, (GXmlDomNode*) _tmp393_);
#line 237 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp392_);
#line 238 "DomGDocumentTest.vala"
		_tmp394_ = ng;
#line 238 "DomGDocumentTest.vala"
		_tmp395_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) _tmp394_, "http://git.gnome.org/browse/gxml");
#line 238 "DomGDocumentTest.vala"
		_tmp396_ = _tmp395_;
#line 238 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp396_, "gxml") == 0, "ng.lookup_prefix (\"http://git.gnome.org/browse/gxml\") == \"gxml\"");
#line 238 "DomGDocumentTest.vala"
		_g_free0 (_tmp396_);
#line 239 "DomGDocumentTest.vala"
		_tmp397_ = ng;
#line 239 "DomGDocumentTest.vala"
		_tmp398_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp397_, "gxml");
#line 239 "DomGDocumentTest.vala"
		_tmp399_ = _tmp398_;
#line 239 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp399_, "http://git.gnome.org/browse/gxml") == 0, "ng.lookup_namespace_uri (\"gxml\") == \"http://git.gnome.org/browse/gxml\"");
#line 239 "DomGDocumentTest.vala"
		_g_free0 (_tmp399_);
#line 240 "DomGDocumentTest.vala"
		_tmp400_ = ng;
#line 240 "DomGDocumentTest.vala"
		_vala_assert (!gxml_dom_node_is_default_namespace ((GXmlDomNode*) _tmp400_, "gxml:http://git.gnome.org/browse/gxml"), "!ng.is_default_namespace (\"gxml:http://git.gnome.org/browse/gxml\")");
#line 241 "DomGDocumentTest.vala"
		_tmp401_ = doc;
#line 241 "DomGDocumentTest.vala"
		_tmp402_ = gxml_dom_document_create_element_ns (_tmp401_, "http://live.gnome.org/GXml", "OtherNode", &_inner_error0_);
#line 241 "DomGDocumentTest.vala"
		ng2 = _tmp402_;
#line 241 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 241 "DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 241 "DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 241 "DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 241 "DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 241 "DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 241 "DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 241 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp179_);
#line 241 "DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 241 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp158_);
#line 241 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 241 "DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 241 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 241 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 3314 "DomGDocumentTest.c"
			goto __catch64_g_error;
		}
#line 242 "DomGDocumentTest.vala"
		_tmp403_ = b;
#line 242 "DomGDocumentTest.vala"
		_tmp404_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp403_);
#line 242 "DomGDocumentTest.vala"
		_tmp405_ = _tmp404_;
#line 242 "DomGDocumentTest.vala"
		_tmp406_ = _tmp405_;
#line 242 "DomGDocumentTest.vala"
		_tmp407_ = ng2;
#line 242 "DomGDocumentTest.vala"
		gee_collection_add ((GeeCollection*) _tmp406_, (GXmlDomNode*) _tmp407_);
#line 242 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp406_);
#line 243 "DomGDocumentTest.vala"
		_tmp408_ = ng2;
#line 243 "DomGDocumentTest.vala"
		_tmp409_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) _tmp408_, "http://live.gnome.org/GXml");
#line 243 "DomGDocumentTest.vala"
		_tmp410_ = _tmp409_;
#line 243 "DomGDocumentTest.vala"
		_vala_assert (_tmp410_ == NULL, "ng2.lookup_prefix (\"http://live.gnome.org/GXml\") == null");
#line 243 "DomGDocumentTest.vala"
		_g_free0 (_tmp410_);
#line 244 "DomGDocumentTest.vala"
		_tmp411_ = ng2;
#line 244 "DomGDocumentTest.vala"
		_tmp412_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp411_, NULL);
#line 244 "DomGDocumentTest.vala"
		_tmp413_ = _tmp412_;
#line 244 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp413_, "http://live.gnome.org/GXml") == 0, "ng2.lookup_namespace_uri (null) == \"http://live.gnome.org/GXml\"");
#line 244 "DomGDocumentTest.vala"
		_g_free0 (_tmp413_);
#line 245 "DomGDocumentTest.vala"
		_tmp414_ = ng2;
#line 245 "DomGDocumentTest.vala"
		_vala_assert (gxml_dom_node_is_default_namespace ((GXmlDomNode*) _tmp414_, "http://live.gnome.org/GXml"), "ng2.is_default_namespace (\"http://live.gnome.org/GXml\")");
#line 246 "DomGDocumentTest.vala"
		_tmp416_ = doc;
#line 246 "DomGDocumentTest.vala"
		_tmp417_ = gxml_dom_document_create_element (_tmp416_, "p", &_inner_error0_);
#line 246 "DomGDocumentTest.vala"
		_tmp415_ = _tmp417_;
#line 246 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 246 "DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 246 "DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 246 "DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 246 "DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 246 "DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 246 "DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 246 "DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 246 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp179_);
#line 246 "DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 246 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp158_);
#line 246 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 246 "DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 246 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 246 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 3391 "DomGDocumentTest.c"
			goto __catch64_g_error;
		}
#line 246 "DomGDocumentTest.vala"
		_tmp418_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp415_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp415_) : NULL);
#line 246 "DomGDocumentTest.vala"
		pn = _tmp418_;
#line 247 "DomGDocumentTest.vala"
		_tmp419_ = pn;
#line 247 "DomGDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp419_, "id", "insertedp01", &_inner_error0_);
#line 247 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 247 "DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 247 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp415_);
#line 247 "DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 247 "DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 247 "DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 247 "DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 247 "DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 247 "DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 247 "DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 247 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp179_);
#line 247 "DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 247 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp158_);
#line 247 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 247 "DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 247 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 247 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 3436 "DomGDocumentTest.c"
			goto __catch64_g_error;
		}
#line 248 "DomGDocumentTest.vala"
		_tmp420_ = doc;
#line 248 "DomGDocumentTest.vala"
		_tmp421_ = gxml_dom_document_get_document_element (_tmp420_);
#line 248 "DomGDocumentTest.vala"
		_tmp422_ = _tmp421_;
#line 248 "DomGDocumentTest.vala"
		_tmp423_ = _tmp422_;
#line 248 "DomGDocumentTest.vala"
		_tmp424_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp423_);
#line 248 "DomGDocumentTest.vala"
		_tmp425_ = _tmp424_;
#line 248 "DomGDocumentTest.vala"
		_tmp426_ = _tmp425_;
#line 248 "DomGDocumentTest.vala"
		_tmp427_ = gee_list_get ((GeeList*) _tmp426_, 0);
#line 248 "DomGDocumentTest.vala"
		_tmp428_ = (GXmlDomElement*) _tmp427_;
#line 248 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp426_);
#line 248 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp423_);
#line 248 "DomGDocumentTest.vala"
		p = _tmp428_;
#line 249 "DomGDocumentTest.vala"
		_tmp429_ = p;
#line 249 "DomGDocumentTest.vala"
		_tmp430_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp429_);
#line 249 "DomGDocumentTest.vala"
		_tmp431_ = _tmp430_;
#line 249 "DomGDocumentTest.vala"
		_tmp432_ = _tmp431_;
#line 249 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp432_, "body") == 0, "p.node_name == \"body\"");
#line 249 "DomGDocumentTest.vala"
		_g_free0 (_tmp432_);
#line 250 "DomGDocumentTest.vala"
		_tmp433_ = p;
#line 250 "DomGDocumentTest.vala"
		_tmp434_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp433_);
#line 250 "DomGDocumentTest.vala"
		_tmp435_ = _tmp434_;
#line 250 "DomGDocumentTest.vala"
		_tmp436_ = _tmp435_;
#line 250 "DomGDocumentTest.vala"
		_tmp437_ = gee_list_get ((GeeList*) _tmp436_, 0);
#line 250 "DomGDocumentTest.vala"
		_tmp438_ = (GXmlDomElement*) _tmp437_;
#line 250 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp436_);
#line 250 "DomGDocumentTest.vala"
		cp0 = _tmp438_;
#line 251 "DomGDocumentTest.vala"
		_tmp439_ = cp0;
#line 251 "DomGDocumentTest.vala"
		_tmp440_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp439_);
#line 251 "DomGDocumentTest.vala"
		_tmp441_ = _tmp440_;
#line 251 "DomGDocumentTest.vala"
		_tmp442_ = _tmp441_;
#line 251 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp442_, "p") == 0, "cp0.node_name == \"p\"");
#line 251 "DomGDocumentTest.vala"
		_g_free0 (_tmp442_);
#line 252 "DomGDocumentTest.vala"
		_tmp443_ = cp0;
#line 252 "DomGDocumentTest.vala"
		_tmp444_ = gxml_dom_element_get_attribute (_tmp443_, "class");
#line 252 "DomGDocumentTest.vala"
		_tmp445_ = _tmp444_;
#line 252 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp445_, "black") == 0, "cp0.get_attribute (\"class\") == \"black\"");
#line 252 "DomGDocumentTest.vala"
		_g_free0 (_tmp445_);
#line 253 "DomGDocumentTest.vala"
		_tmp446_ = p;
#line 253 "DomGDocumentTest.vala"
		_tmp447_ = cp0;
#line 253 "DomGDocumentTest.vala"
		_vala_assert (gxml_dom_node_contains ((GXmlDomNode*) _tmp446_, (GXmlDomNode*) _tmp447_), "p.contains (cp0)");
#line 254 "DomGDocumentTest.vala"
		_tmp448_ = cp0;
#line 254 "DomGDocumentTest.vala"
		_tmp449_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp448_);
#line 254 "DomGDocumentTest.vala"
		_tmp450_ = _tmp449_;
#line 254 "DomGDocumentTest.vala"
		_tmp451_ = _tmp450_;
#line 254 "DomGDocumentTest.vala"
		_tmp452_ = cp0;
#line 254 "DomGDocumentTest.vala"
		_vala_assert (gxml_dom_node_contains (_tmp451_, (GXmlDomNode*) _tmp452_), "cp0.parent_node.contains (cp0)");
#line 254 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp451_);
#line 255 "DomGDocumentTest.vala"
		_tmp453_ = p;
#line 255 "DomGDocumentTest.vala"
		_tmp454_ = pn;
#line 255 "DomGDocumentTest.vala"
		_tmp455_ = cp0;
#line 255 "DomGDocumentTest.vala"
		_tmp456_ = gxml_dom_node_insert_before ((GXmlDomNode*) _tmp453_, (GXmlDomNode*) _tmp454_, (GXmlDomNode*) _tmp455_, &_inner_error0_);
#line 255 "DomGDocumentTest.vala"
		_tmp457_ = _tmp456_;
#line 255 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp457_);
#line 255 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 255 "DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 255 "DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 255 "DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 255 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp415_);
#line 255 "DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 255 "DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 255 "DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 255 "DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 255 "DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 255 "DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 255 "DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 255 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp179_);
#line 255 "DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 255 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp158_);
#line 255 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 255 "DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 255 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 255 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 3583 "DomGDocumentTest.c"
			goto __catch64_g_error;
		}
#line 256 "DomGDocumentTest.vala"
		_tmp458_ = p;
#line 256 "DomGDocumentTest.vala"
		_tmp459_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp458_);
#line 256 "DomGDocumentTest.vala"
		_tmp460_ = _tmp459_;
#line 256 "DomGDocumentTest.vala"
		_tmp461_ = _tmp460_;
#line 256 "DomGDocumentTest.vala"
		_tmp462_ = gee_list_get ((GeeList*) _tmp461_, 0);
#line 256 "DomGDocumentTest.vala"
		_tmp463_ = (GXmlDomElement*) _tmp462_;
#line 256 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp461_);
#line 256 "DomGDocumentTest.vala"
		ppn = _tmp463_;
#line 257 "DomGDocumentTest.vala"
		_tmp464_ = ppn;
#line 257 "DomGDocumentTest.vala"
		_tmp465_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp464_);
#line 257 "DomGDocumentTest.vala"
		_tmp466_ = _tmp465_;
#line 257 "DomGDocumentTest.vala"
		_tmp467_ = _tmp466_;
#line 257 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp467_, "p") == 0, "ppn.node_name == \"p\"");
#line 257 "DomGDocumentTest.vala"
		_g_free0 (_tmp467_);
#line 258 "DomGDocumentTest.vala"
		_tmp468_ = ppn;
#line 258 "DomGDocumentTest.vala"
		_vala_assert (gxml_dom_element_has_attribute (_tmp468_, "id"), "ppn.has_attribute (\"id\")");
#line 259 "DomGDocumentTest.vala"
		_tmp469_ = ppn;
#line 259 "DomGDocumentTest.vala"
		_tmp470_ = gxml_dom_element_get_attribute (_tmp469_, "id");
#line 259 "DomGDocumentTest.vala"
		_tmp471_ = _tmp470_;
#line 259 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp471_, "insertedp01") == 0, "ppn.get_attribute (\"id\") == \"insertedp01\"");
#line 259 "DomGDocumentTest.vala"
		_g_free0 (_tmp471_);
#line 260 "DomGDocumentTest.vala"
		_tmp473_ = doc;
#line 260 "DomGDocumentTest.vala"
		_tmp474_ = gxml_dom_document_create_element (_tmp473_, "p", &_inner_error0_);
#line 260 "DomGDocumentTest.vala"
		_tmp472_ = _tmp474_;
#line 260 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 260 "DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 260 "DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 260 "DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 260 "DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 260 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp415_);
#line 260 "DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 260 "DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 260 "DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 260 "DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 260 "DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 260 "DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 260 "DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 260 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp179_);
#line 260 "DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 260 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp158_);
#line 260 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 260 "DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 260 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 260 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 3674 "DomGDocumentTest.c"
			goto __catch64_g_error;
		}
#line 260 "DomGDocumentTest.vala"
		_tmp475_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp472_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp472_) : NULL);
#line 260 "DomGDocumentTest.vala"
		pn2 = _tmp475_;
#line 261 "DomGDocumentTest.vala"
		_tmp476_ = pn2;
#line 261 "DomGDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp476_, "id", "newp", &_inner_error0_);
#line 261 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 261 "DomGDocumentTest.vala"
			_g_object_unref0 (pn2);
#line 261 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp472_);
#line 261 "DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 261 "DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 261 "DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 261 "DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 261 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp415_);
#line 261 "DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 261 "DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 261 "DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 261 "DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 261 "DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 261 "DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 261 "DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 261 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp179_);
#line 261 "DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 261 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp158_);
#line 261 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 261 "DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 261 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 261 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 3729 "DomGDocumentTest.c"
			goto __catch64_g_error;
		}
#line 262 "DomGDocumentTest.vala"
		_tmp477_ = p;
#line 262 "DomGDocumentTest.vala"
		_tmp478_ = pn2;
#line 262 "DomGDocumentTest.vala"
		_tmp479_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp477_, (GXmlDomNode*) _tmp478_, &_inner_error0_);
#line 262 "DomGDocumentTest.vala"
		_tmp480_ = _tmp479_;
#line 262 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp480_);
#line 262 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 262 "DomGDocumentTest.vala"
			_g_object_unref0 (pn2);
#line 262 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp472_);
#line 262 "DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 262 "DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 262 "DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 262 "DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 262 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp415_);
#line 262 "DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 262 "DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 262 "DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 262 "DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 262 "DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 262 "DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 262 "DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 262 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp179_);
#line 262 "DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 262 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp158_);
#line 262 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 262 "DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 262 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 262 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 3786 "DomGDocumentTest.c"
			goto __catch64_g_error;
		}
#line 263 "DomGDocumentTest.vala"
		_tmp481_ = p;
#line 263 "DomGDocumentTest.vala"
		_tmp482_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp481_);
#line 263 "DomGDocumentTest.vala"
		_tmp483_ = _tmp482_;
#line 263 "DomGDocumentTest.vala"
		_tmp484_ = _tmp483_;
#line 263 "DomGDocumentTest.vala"
		_tmp485_ = gxml_dom_html_collection_get_length (_tmp484_);
#line 263 "DomGDocumentTest.vala"
		_tmp486_ = _tmp485_;
#line 263 "DomGDocumentTest.vala"
		_vala_assert (_tmp486_ == 8, "p.children.length == 8");
#line 263 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp484_);
#line 264 "DomGDocumentTest.vala"
		_tmp487_ = p;
#line 264 "DomGDocumentTest.vala"
		_tmp488_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp487_);
#line 264 "DomGDocumentTest.vala"
		_tmp489_ = _tmp488_;
#line 264 "DomGDocumentTest.vala"
		_tmp490_ = _tmp489_;
#line 264 "DomGDocumentTest.vala"
		_tmp491_ = gee_list_get ((GeeList*) _tmp490_, 7);
#line 264 "DomGDocumentTest.vala"
		_tmp492_ = (GXmlDomElement*) _tmp491_;
#line 264 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp492_, GXML_TYPE_DOM_ELEMENT), "p.children[7] is DomElement");
#line 264 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp492_);
#line 264 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp490_);
#line 265 "DomGDocumentTest.vala"
		_tmp493_ = p;
#line 265 "DomGDocumentTest.vala"
		_tmp494_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp493_);
#line 265 "DomGDocumentTest.vala"
		_tmp495_ = _tmp494_;
#line 265 "DomGDocumentTest.vala"
		_tmp496_ = _tmp495_;
#line 265 "DomGDocumentTest.vala"
		_tmp497_ = gee_list_get ((GeeList*) _tmp496_, 7);
#line 265 "DomGDocumentTest.vala"
		_tmp498_ = (GXmlDomElement*) _tmp497_;
#line 265 "DomGDocumentTest.vala"
		_tmp499_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp498_);
#line 265 "DomGDocumentTest.vala"
		_tmp500_ = _tmp499_;
#line 265 "DomGDocumentTest.vala"
		_tmp501_ = _tmp500_;
#line 265 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp501_, "p") == 0, "p.children[7].node_name == \"p\"");
#line 265 "DomGDocumentTest.vala"
		_g_free0 (_tmp501_);
#line 265 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp498_);
#line 265 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp496_);
#line 266 "DomGDocumentTest.vala"
		_tmp502_ = p;
#line 266 "DomGDocumentTest.vala"
		_tmp503_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp502_);
#line 266 "DomGDocumentTest.vala"
		_tmp504_ = _tmp503_;
#line 266 "DomGDocumentTest.vala"
		_tmp505_ = _tmp504_;
#line 266 "DomGDocumentTest.vala"
		_tmp506_ = gee_list_get ((GeeList*) _tmp505_, 7);
#line 266 "DomGDocumentTest.vala"
		_tmp507_ = (GXmlDomElement*) _tmp506_;
#line 266 "DomGDocumentTest.vala"
		_tmp508_ = gxml_dom_element_get_attribute (_tmp507_, "id");
#line 266 "DomGDocumentTest.vala"
		_tmp509_ = _tmp508_;
#line 266 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp509_, "newp") == 0, "p.children[7].get_attribute (\"id\") == \"newp\"");
#line 266 "DomGDocumentTest.vala"
		_g_free0 (_tmp509_);
#line 266 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp507_);
#line 266 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp505_);
#line 267 "DomGDocumentTest.vala"
		_tmp511_ = doc;
#line 267 "DomGDocumentTest.vala"
		_tmp512_ = gxml_dom_document_create_element (_tmp511_, "p", &_inner_error0_);
#line 267 "DomGDocumentTest.vala"
		_tmp510_ = _tmp512_;
#line 267 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 267 "DomGDocumentTest.vala"
			_g_object_unref0 (pn2);
#line 267 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp472_);
#line 267 "DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 267 "DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 267 "DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 267 "DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 267 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp415_);
#line 267 "DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 267 "DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 267 "DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 267 "DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 267 "DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 267 "DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 267 "DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 267 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp179_);
#line 267 "DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 267 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp158_);
#line 267 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 267 "DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 267 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 267 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 3923 "DomGDocumentTest.c"
			goto __catch64_g_error;
		}
#line 267 "DomGDocumentTest.vala"
		_tmp513_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp510_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp510_) : NULL);
#line 267 "DomGDocumentTest.vala"
		pn3 = _tmp513_;
#line 268 "DomGDocumentTest.vala"
		_tmp514_ = pn3;
#line 268 "DomGDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp514_, "id", "newp1", &_inner_error0_);
#line 268 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 268 "DomGDocumentTest.vala"
			_g_object_unref0 (pn3);
#line 268 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp510_);
#line 268 "DomGDocumentTest.vala"
			_g_object_unref0 (pn2);
#line 268 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp472_);
#line 268 "DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 268 "DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 268 "DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 268 "DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 268 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp415_);
#line 268 "DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 268 "DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 268 "DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 268 "DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 268 "DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 268 "DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 268 "DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 268 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp179_);
#line 268 "DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 268 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp158_);
#line 268 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 268 "DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 268 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 268 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 3982 "DomGDocumentTest.c"
			goto __catch64_g_error;
		}
#line 269 "DomGDocumentTest.vala"
		_tmp515_ = pn3;
#line 269 "DomGDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp515_, "class", "black", &_inner_error0_);
#line 269 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 269 "DomGDocumentTest.vala"
			_g_object_unref0 (pn3);
#line 269 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp510_);
#line 269 "DomGDocumentTest.vala"
			_g_object_unref0 (pn2);
#line 269 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp472_);
#line 269 "DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 269 "DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 269 "DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 269 "DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 269 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp415_);
#line 269 "DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 269 "DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 269 "DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 269 "DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 269 "DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 269 "DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 269 "DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 269 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp179_);
#line 269 "DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 269 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp158_);
#line 269 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 269 "DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 269 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 269 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 4037 "DomGDocumentTest.c"
			goto __catch64_g_error;
		}
#line 270 "DomGDocumentTest.vala"
		_tmp516_ = p;
#line 270 "DomGDocumentTest.vala"
		_tmp517_ = pn3;
#line 270 "DomGDocumentTest.vala"
		_tmp518_ = pn2;
#line 270 "DomGDocumentTest.vala"
		_tmp519_ = gxml_dom_node_replace_child ((GXmlDomNode*) _tmp516_, (GXmlDomNode*) _tmp517_, (GXmlDomNode*) _tmp518_, &_inner_error0_);
#line 270 "DomGDocumentTest.vala"
		_tmp520_ = _tmp519_;
#line 270 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp520_);
#line 270 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 270 "DomGDocumentTest.vala"
			_g_object_unref0 (pn3);
#line 270 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp510_);
#line 270 "DomGDocumentTest.vala"
			_g_object_unref0 (pn2);
#line 270 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp472_);
#line 270 "DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 270 "DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 270 "DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 270 "DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 270 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp415_);
#line 270 "DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 270 "DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 270 "DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 270 "DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 270 "DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 270 "DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 270 "DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 270 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp179_);
#line 270 "DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 270 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp158_);
#line 270 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 270 "DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 270 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 270 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 4100 "DomGDocumentTest.c"
			goto __catch64_g_error;
		}
#line 271 "DomGDocumentTest.vala"
		_tmp521_ = p;
#line 271 "DomGDocumentTest.vala"
		_tmp522_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp521_);
#line 271 "DomGDocumentTest.vala"
		_tmp523_ = _tmp522_;
#line 271 "DomGDocumentTest.vala"
		_tmp524_ = _tmp523_;
#line 271 "DomGDocumentTest.vala"
		_tmp525_ = gxml_dom_html_collection_get_length (_tmp524_);
#line 271 "DomGDocumentTest.vala"
		_tmp526_ = _tmp525_;
#line 271 "DomGDocumentTest.vala"
		_vala_assert (_tmp526_ == 8, "p.children.length == 8");
#line 271 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp524_);
#line 272 "DomGDocumentTest.vala"
		_tmp527_ = p;
#line 272 "DomGDocumentTest.vala"
		_tmp528_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp527_);
#line 272 "DomGDocumentTest.vala"
		_tmp529_ = _tmp528_;
#line 272 "DomGDocumentTest.vala"
		_tmp530_ = _tmp529_;
#line 272 "DomGDocumentTest.vala"
		_tmp531_ = gee_list_get ((GeeList*) _tmp530_, 7);
#line 272 "DomGDocumentTest.vala"
		_tmp532_ = (GXmlDomElement*) _tmp531_;
#line 272 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp532_, GXML_TYPE_DOM_ELEMENT), "p.children[7] is DomElement");
#line 272 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp532_);
#line 272 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp530_);
#line 273 "DomGDocumentTest.vala"
		_tmp533_ = p;
#line 273 "DomGDocumentTest.vala"
		_tmp534_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp533_);
#line 273 "DomGDocumentTest.vala"
		_tmp535_ = _tmp534_;
#line 273 "DomGDocumentTest.vala"
		_tmp536_ = _tmp535_;
#line 273 "DomGDocumentTest.vala"
		_tmp537_ = gee_list_get ((GeeList*) _tmp536_, 7);
#line 273 "DomGDocumentTest.vala"
		_tmp538_ = (GXmlDomElement*) _tmp537_;
#line 273 "DomGDocumentTest.vala"
		_tmp539_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp538_);
#line 273 "DomGDocumentTest.vala"
		_tmp540_ = _tmp539_;
#line 273 "DomGDocumentTest.vala"
		_tmp541_ = _tmp540_;
#line 273 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp541_, "p") == 0, "p.children[7].node_name == \"p\"");
#line 273 "DomGDocumentTest.vala"
		_g_free0 (_tmp541_);
#line 273 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp538_);
#line 273 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp536_);
#line 274 "DomGDocumentTest.vala"
		_tmp542_ = p;
#line 274 "DomGDocumentTest.vala"
		_tmp543_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp542_);
#line 274 "DomGDocumentTest.vala"
		_tmp544_ = _tmp543_;
#line 274 "DomGDocumentTest.vala"
		_tmp545_ = _tmp544_;
#line 274 "DomGDocumentTest.vala"
		_tmp546_ = gee_list_get ((GeeList*) _tmp545_, 7);
#line 274 "DomGDocumentTest.vala"
		_tmp547_ = (GXmlDomElement*) _tmp546_;
#line 274 "DomGDocumentTest.vala"
		_tmp548_ = gxml_dom_element_get_attribute (_tmp547_, "id");
#line 274 "DomGDocumentTest.vala"
		_tmp549_ = _tmp548_;
#line 274 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp549_, "newp1") == 0, "p.children[7].get_attribute (\"id\") == \"newp1\"");
#line 274 "DomGDocumentTest.vala"
		_g_free0 (_tmp549_);
#line 274 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp547_);
#line 274 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp545_);
#line 275 "DomGDocumentTest.vala"
		_tmp550_ = p;
#line 275 "DomGDocumentTest.vala"
		_tmp551_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp550_);
#line 275 "DomGDocumentTest.vala"
		_tmp552_ = _tmp551_;
#line 275 "DomGDocumentTest.vala"
		_tmp553_ = _tmp552_;
#line 275 "DomGDocumentTest.vala"
		_tmp554_ = gee_list_get ((GeeList*) _tmp553_, 7);
#line 275 "DomGDocumentTest.vala"
		_tmp555_ = (GXmlDomElement*) _tmp554_;
#line 275 "DomGDocumentTest.vala"
		_tmp556_ = gxml_dom_element_get_attribute (_tmp555_, "class");
#line 275 "DomGDocumentTest.vala"
		_tmp557_ = _tmp556_;
#line 275 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp557_, "black") == 0, "p.children[7].get_attribute (\"class\") == \"black\"");
#line 275 "DomGDocumentTest.vala"
		_g_free0 (_tmp557_);
#line 275 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp555_);
#line 275 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp553_);
#line 276 "DomGDocumentTest.vala"
		_tmp559_ = doc;
#line 276 "DomGDocumentTest.vala"
		_tmp560_ = gxml_dom_document_create_element (_tmp559_, "p", &_inner_error0_);
#line 276 "DomGDocumentTest.vala"
		_tmp558_ = _tmp560_;
#line 276 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 276 "DomGDocumentTest.vala"
			_g_object_unref0 (pn3);
#line 276 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp510_);
#line 276 "DomGDocumentTest.vala"
			_g_object_unref0 (pn2);
#line 276 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp472_);
#line 276 "DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 276 "DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 276 "DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 276 "DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 276 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp415_);
#line 276 "DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 276 "DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 276 "DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 276 "DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 276 "DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 276 "DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 276 "DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 276 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp179_);
#line 276 "DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 276 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp158_);
#line 276 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 276 "DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 276 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 276 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 4265 "DomGDocumentTest.c"
			goto __catch64_g_error;
		}
#line 276 "DomGDocumentTest.vala"
		_tmp561_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp558_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp558_) : NULL);
#line 276 "DomGDocumentTest.vala"
		pn4 = _tmp561_;
#line 277 "DomGDocumentTest.vala"
		_tmp562_ = pn4;
#line 277 "DomGDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp562_, "id", "newp2", &_inner_error0_);
#line 277 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (pn4);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp558_);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (pn3);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp510_);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (pn2);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp472_);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp415_);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp179_);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp158_);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 277 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 4328 "DomGDocumentTest.c"
			goto __catch64_g_error;
		}
#line 278 "DomGDocumentTest.vala"
		_tmp563_ = pn4;
#line 278 "DomGDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp563_, "class", "black", &_inner_error0_);
#line 278 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (pn4);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp558_);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (pn3);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp510_);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (pn2);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp472_);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp415_);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp179_);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp158_);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 278 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 4387 "DomGDocumentTest.c"
			goto __catch64_g_error;
		}
#line 279 "DomGDocumentTest.vala"
		_tmp564_ = p;
#line 279 "DomGDocumentTest.vala"
		_tmp565_ = pn4;
#line 279 "DomGDocumentTest.vala"
		_tmp566_ = p;
#line 279 "DomGDocumentTest.vala"
		_tmp567_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp566_);
#line 279 "DomGDocumentTest.vala"
		_tmp568_ = _tmp567_;
#line 279 "DomGDocumentTest.vala"
		_tmp569_ = _tmp568_;
#line 279 "DomGDocumentTest.vala"
		_tmp570_ = gee_list_get ((GeeList*) _tmp569_, 0);
#line 279 "DomGDocumentTest.vala"
		_tmp571_ = (GXmlDomNode*) _tmp570_;
#line 279 "DomGDocumentTest.vala"
		_tmp572_ = gxml_dom_node_replace_child ((GXmlDomNode*) _tmp564_, (GXmlDomNode*) _tmp565_, _tmp571_, &_inner_error0_);
#line 279 "DomGDocumentTest.vala"
		_tmp573_ = _tmp572_;
#line 279 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp573_);
#line 279 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp571_);
#line 279 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp569_);
#line 279 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (pn4);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp558_);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (pn3);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp510_);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (pn2);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp472_);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp415_);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp179_);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp158_);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 279 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 4468 "DomGDocumentTest.c"
			goto __catch64_g_error;
		}
#line 280 "DomGDocumentTest.vala"
		_tmp574_ = p;
#line 280 "DomGDocumentTest.vala"
		_tmp575_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp574_);
#line 280 "DomGDocumentTest.vala"
		_tmp576_ = _tmp575_;
#line 280 "DomGDocumentTest.vala"
		_tmp577_ = _tmp576_;
#line 280 "DomGDocumentTest.vala"
		_tmp578_ = gxml_dom_html_collection_get_length (_tmp577_);
#line 280 "DomGDocumentTest.vala"
		_tmp579_ = _tmp578_;
#line 280 "DomGDocumentTest.vala"
		_vala_assert (_tmp579_ == 8, "p.children.length == 8");
#line 280 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp577_);
#line 281 "DomGDocumentTest.vala"
		_tmp580_ = p;
#line 281 "DomGDocumentTest.vala"
		_tmp581_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp580_);
#line 281 "DomGDocumentTest.vala"
		_tmp582_ = _tmp581_;
#line 281 "DomGDocumentTest.vala"
		_tmp583_ = _tmp582_;
#line 281 "DomGDocumentTest.vala"
		_tmp584_ = gee_list_get ((GeeList*) _tmp583_, 0);
#line 281 "DomGDocumentTest.vala"
		_tmp585_ = (GXmlDomElement*) _tmp584_;
#line 281 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp585_, GXML_TYPE_DOM_ELEMENT), "p.children[0] is DomElement");
#line 281 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp585_);
#line 281 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp583_);
#line 282 "DomGDocumentTest.vala"
		_tmp586_ = p;
#line 282 "DomGDocumentTest.vala"
		_tmp587_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp586_);
#line 282 "DomGDocumentTest.vala"
		_tmp588_ = _tmp587_;
#line 282 "DomGDocumentTest.vala"
		_tmp589_ = _tmp588_;
#line 282 "DomGDocumentTest.vala"
		_tmp590_ = gee_list_get ((GeeList*) _tmp589_, 0);
#line 282 "DomGDocumentTest.vala"
		_tmp591_ = (GXmlDomElement*) _tmp590_;
#line 282 "DomGDocumentTest.vala"
		_tmp592_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp591_);
#line 282 "DomGDocumentTest.vala"
		_tmp593_ = _tmp592_;
#line 282 "DomGDocumentTest.vala"
		_tmp594_ = _tmp593_;
#line 282 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp594_, "p") == 0, "p.children[0].node_name == \"p\"");
#line 282 "DomGDocumentTest.vala"
		_g_free0 (_tmp594_);
#line 282 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp591_);
#line 282 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp589_);
#line 283 "DomGDocumentTest.vala"
		_tmp595_ = p;
#line 283 "DomGDocumentTest.vala"
		_tmp596_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp595_);
#line 283 "DomGDocumentTest.vala"
		_tmp597_ = _tmp596_;
#line 283 "DomGDocumentTest.vala"
		_tmp598_ = _tmp597_;
#line 283 "DomGDocumentTest.vala"
		_tmp599_ = gee_list_get ((GeeList*) _tmp598_, 0);
#line 283 "DomGDocumentTest.vala"
		_tmp600_ = (GXmlDomElement*) _tmp599_;
#line 283 "DomGDocumentTest.vala"
		_tmp601_ = gxml_dom_element_get_attribute (_tmp600_, "id");
#line 283 "DomGDocumentTest.vala"
		_tmp602_ = _tmp601_;
#line 283 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp602_, "newp2") == 0, "p.children[0].get_attribute (\"id\") == \"newp2\"");
#line 283 "DomGDocumentTest.vala"
		_g_free0 (_tmp602_);
#line 283 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp600_);
#line 283 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp598_);
#line 284 "DomGDocumentTest.vala"
		_tmp603_ = p;
#line 284 "DomGDocumentTest.vala"
		_tmp604_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp603_);
#line 284 "DomGDocumentTest.vala"
		_tmp605_ = _tmp604_;
#line 284 "DomGDocumentTest.vala"
		_tmp606_ = _tmp605_;
#line 284 "DomGDocumentTest.vala"
		_tmp607_ = gee_list_get ((GeeList*) _tmp606_, 0);
#line 284 "DomGDocumentTest.vala"
		_tmp608_ = (GXmlDomElement*) _tmp607_;
#line 284 "DomGDocumentTest.vala"
		_tmp609_ = gxml_dom_element_get_attribute (_tmp608_, "class");
#line 284 "DomGDocumentTest.vala"
		_tmp610_ = _tmp609_;
#line 284 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp610_, "black") == 0, "p.children[0].get_attribute (\"class\") == \"black\"");
#line 284 "DomGDocumentTest.vala"
		_g_free0 (_tmp610_);
#line 284 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp608_);
#line 284 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp606_);
#line 285 "DomGDocumentTest.vala"
		_tmp611_ = p;
#line 285 "DomGDocumentTest.vala"
		_tmp612_ = p;
#line 285 "DomGDocumentTest.vala"
		_tmp613_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp612_);
#line 285 "DomGDocumentTest.vala"
		_tmp614_ = _tmp613_;
#line 285 "DomGDocumentTest.vala"
		_tmp615_ = _tmp614_;
#line 285 "DomGDocumentTest.vala"
		_tmp616_ = gee_list_get ((GeeList*) _tmp615_, 0);
#line 285 "DomGDocumentTest.vala"
		_tmp617_ = (GXmlDomElement*) _tmp616_;
#line 285 "DomGDocumentTest.vala"
		_tmp618_ = gxml_dom_node_remove_child ((GXmlDomNode*) _tmp611_, (GXmlDomNode*) _tmp617_, &_inner_error0_);
#line 285 "DomGDocumentTest.vala"
		_tmp619_ = _tmp618_;
#line 285 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp619_);
#line 285 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp617_);
#line 285 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp615_);
#line 285 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (pn4);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp558_);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (pn3);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp510_);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (pn2);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp472_);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp415_);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp179_);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp158_);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 285 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 4655 "DomGDocumentTest.c"
			goto __catch64_g_error;
		}
#line 286 "DomGDocumentTest.vala"
		_tmp620_ = p;
#line 286 "DomGDocumentTest.vala"
		_tmp621_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp620_);
#line 286 "DomGDocumentTest.vala"
		_tmp622_ = _tmp621_;
#line 286 "DomGDocumentTest.vala"
		_tmp623_ = _tmp622_;
#line 286 "DomGDocumentTest.vala"
		_tmp624_ = gxml_dom_html_collection_get_length (_tmp623_);
#line 286 "DomGDocumentTest.vala"
		_tmp625_ = _tmp624_;
#line 286 "DomGDocumentTest.vala"
		_vala_assert (_tmp625_ == 7, "p.children.length == 7");
#line 286 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp623_);
#line 287 "DomGDocumentTest.vala"
		_tmp626_ = p;
#line 287 "DomGDocumentTest.vala"
		_tmp627_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp626_);
#line 287 "DomGDocumentTest.vala"
		_tmp628_ = _tmp627_;
#line 287 "DomGDocumentTest.vala"
		_tmp629_ = _tmp628_;
#line 287 "DomGDocumentTest.vala"
		_tmp630_ = gee_list_get ((GeeList*) _tmp629_, 0);
#line 287 "DomGDocumentTest.vala"
		_tmp631_ = (GXmlDomElement*) _tmp630_;
#line 287 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp631_, GXML_TYPE_DOM_ELEMENT), "p.children[0] is DomElement");
#line 287 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp631_);
#line 287 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp629_);
#line 288 "DomGDocumentTest.vala"
		_tmp632_ = p;
#line 288 "DomGDocumentTest.vala"
		_tmp633_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp632_);
#line 288 "DomGDocumentTest.vala"
		_tmp634_ = _tmp633_;
#line 288 "DomGDocumentTest.vala"
		_tmp635_ = _tmp634_;
#line 288 "DomGDocumentTest.vala"
		_tmp636_ = gee_list_get ((GeeList*) _tmp635_, 0);
#line 288 "DomGDocumentTest.vala"
		_tmp637_ = (GXmlDomElement*) _tmp636_;
#line 288 "DomGDocumentTest.vala"
		_tmp638_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp637_);
#line 288 "DomGDocumentTest.vala"
		_tmp639_ = _tmp638_;
#line 288 "DomGDocumentTest.vala"
		_tmp640_ = _tmp639_;
#line 288 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp640_, "p") == 0, "p.children[0].node_name == \"p\"");
#line 288 "DomGDocumentTest.vala"
		_g_free0 (_tmp640_);
#line 288 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp637_);
#line 288 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp635_);
#line 289 "DomGDocumentTest.vala"
		_tmp641_ = p;
#line 289 "DomGDocumentTest.vala"
		_vala_assert (!gxml_dom_element_has_attribute (_tmp641_, "id"), "!p.has_attribute (\"id\")");
#line 290 "DomGDocumentTest.vala"
		_tmp642_ = p;
#line 290 "DomGDocumentTest.vala"
		_tmp643_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp642_);
#line 290 "DomGDocumentTest.vala"
		_tmp644_ = _tmp643_;
#line 290 "DomGDocumentTest.vala"
		_tmp645_ = _tmp644_;
#line 290 "DomGDocumentTest.vala"
		_tmp646_ = gee_list_get ((GeeList*) _tmp645_, 0);
#line 290 "DomGDocumentTest.vala"
		_tmp647_ = (GXmlDomElement*) _tmp646_;
#line 290 "DomGDocumentTest.vala"
		_tmp648_ = gxml_dom_element_get_attribute (_tmp647_, "class");
#line 290 "DomGDocumentTest.vala"
		_tmp649_ = _tmp648_;
#line 290 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp649_, "black") == 0, "p.children[0].get_attribute (\"class\") == \"black\"");
#line 290 "DomGDocumentTest.vala"
		_g_free0 (_tmp649_);
#line 290 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp647_);
#line 290 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp645_);
#line 292 "DomGDocumentTest.vala"
		_tmp650_ = ng2;
#line 292 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp650_, GXML_TYPE_DOM_ELEMENT), "ng2 is DomElement");
#line 293 "DomGDocumentTest.vala"
		_tmp651_ = ng2;
#line 293 "DomGDocumentTest.vala"
		_tmp652_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp651_);
#line 293 "DomGDocumentTest.vala"
		_tmp653_ = _tmp652_;
#line 293 "DomGDocumentTest.vala"
		_tmp654_ = _tmp653_;
#line 293 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp654_, "OtherNode") == 0, "ng2.node_name == \"OtherNode\"");
#line 293 "DomGDocumentTest.vala"
		_g_free0 (_tmp654_);
#line 294 "DomGDocumentTest.vala"
		_tmp655_ = ng2;
#line 294 "DomGDocumentTest.vala"
		_tmp656_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp655_, NULL);
#line 294 "DomGDocumentTest.vala"
		_tmp657_ = _tmp656_;
#line 294 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp657_, "http://live.gnome.org/GXml") == 0, "ng2.lookup_namespace_uri (null) == \"http://live.gnome.org/GXml\"");
#line 294 "DomGDocumentTest.vala"
		_g_free0 (_tmp657_);
#line 295 "DomGDocumentTest.vala"
		_tmp658_ = ng2;
#line 295 "DomGDocumentTest.vala"
		_tmp659_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) _tmp658_, "http://live.gnome.org/GXml");
#line 295 "DomGDocumentTest.vala"
		_tmp660_ = _tmp659_;
#line 295 "DomGDocumentTest.vala"
		_vala_assert (_tmp660_ == NULL, "ng2.lookup_prefix (\"http://live.gnome.org/GXml\") == null");
#line 295 "DomGDocumentTest.vala"
		_g_free0 (_tmp660_);
#line 296 "DomGDocumentTest.vala"
		_tmp661_ = ng2;
#line 296 "DomGDocumentTest.vala"
		_tmp662_ = gxml_dom_element_get_tag_name (_tmp661_);
#line 296 "DomGDocumentTest.vala"
		_tmp663_ = _tmp662_;
#line 296 "DomGDocumentTest.vala"
		_tmp664_ = _tmp663_;
#line 296 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp664_, "OtherNode") == 0, "ng2.tag_name == \"OtherNode\"");
#line 296 "DomGDocumentTest.vala"
		_g_free0 (_tmp664_);
#line 301 "DomGDocumentTest.vala"
		_tmp665_ = doc;
#line 301 "DomGDocumentTest.vala"
		_tmp666_ = gxml_dom_document_get_document_element (_tmp665_);
#line 301 "DomGDocumentTest.vala"
		_tmp667_ = _tmp666_;
#line 301 "DomGDocumentTest.vala"
		_tmp668_ = _tmp667_;
#line 301 "DomGDocumentTest.vala"
		_tmp669_ = gxml_dom_element_get_elements_by_tag_name (_tmp668_, "p");
#line 301 "DomGDocumentTest.vala"
		_tmp670_ = _tmp669_;
#line 301 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp668_);
#line 301 "DomGDocumentTest.vala"
		l = _tmp670_;
#line 302 "DomGDocumentTest.vala"
		_vala_assert (l != NULL, "l != null");
#line 303 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (l, GXML_TYPE_DOM_HTML_COLLECTION), "l is DomHTMLCollection");
#line 304 "DomGDocumentTest.vala"
		_tmp671_ = gxml_dom_html_collection_get_length (l);
#line 304 "DomGDocumentTest.vala"
		_tmp672_ = _tmp671_;
#line 304 "DomGDocumentTest.vala"
		_vala_assert (_tmp672_ == 5, "l.length == 5");
#line 305 "DomGDocumentTest.vala"
		_tmp673_ = gee_list_get ((GeeList*) l, 0);
#line 305 "DomGDocumentTest.vala"
		_tmp674_ = (GXmlDomElement*) _tmp673_;
#line 305 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp674_, GXML_TYPE_DOM_ELEMENT), "l[0] is DomElement");
#line 305 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp674_);
#line 306 "DomGDocumentTest.vala"
		_tmp675_ = gee_list_get ((GeeList*) l, 1);
#line 306 "DomGDocumentTest.vala"
		_tmp676_ = (GXmlDomElement*) _tmp675_;
#line 306 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp676_, GXML_TYPE_DOM_ELEMENT), "l[1] is DomElement");
#line 306 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp676_);
#line 307 "DomGDocumentTest.vala"
		_tmp677_ = gee_list_get ((GeeList*) l, 1);
#line 307 "DomGDocumentTest.vala"
		_tmp678_ = (GXmlDomElement*) _tmp677_;
#line 307 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp678_, GXML_TYPE_DOM_ELEMENT), "l[1] is DomElement");
#line 307 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp678_);
#line 308 "DomGDocumentTest.vala"
		_tmp679_ = gee_list_get ((GeeList*) l, 0);
#line 308 "DomGDocumentTest.vala"
		_tmp680_ = (GXmlDomElement*) _tmp679_;
#line 308 "DomGDocumentTest.vala"
		_tmp681_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp680_);
#line 308 "DomGDocumentTest.vala"
		_tmp682_ = _tmp681_;
#line 308 "DomGDocumentTest.vala"
		_tmp683_ = _tmp682_;
#line 308 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp683_, "p") == 0, "l[0].node_name == \"p\"");
#line 308 "DomGDocumentTest.vala"
		_g_free0 (_tmp683_);
#line 308 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp680_);
#line 309 "DomGDocumentTest.vala"
		_tmp684_ = gee_list_get ((GeeList*) l, 1);
#line 309 "DomGDocumentTest.vala"
		_tmp685_ = (GXmlDomElement*) _tmp684_;
#line 309 "DomGDocumentTest.vala"
		_tmp686_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp685_);
#line 309 "DomGDocumentTest.vala"
		_tmp687_ = _tmp686_;
#line 309 "DomGDocumentTest.vala"
		_tmp688_ = _tmp687_;
#line 309 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp688_, "p") == 0, "l[1].node_name == \"p\"");
#line 309 "DomGDocumentTest.vala"
		_g_free0 (_tmp688_);
#line 309 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp685_);
#line 310 "DomGDocumentTest.vala"
		_tmp689_ = gee_list_get ((GeeList*) l, 2);
#line 310 "DomGDocumentTest.vala"
		_tmp690_ = (GXmlDomElement*) _tmp689_;
#line 310 "DomGDocumentTest.vala"
		_tmp691_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp690_);
#line 310 "DomGDocumentTest.vala"
		_tmp692_ = _tmp691_;
#line 310 "DomGDocumentTest.vala"
		_tmp693_ = _tmp692_;
#line 310 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp693_, "p") == 0, "l[2].node_name == \"p\"");
#line 310 "DomGDocumentTest.vala"
		_g_free0 (_tmp693_);
#line 310 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp690_);
#line 311 "DomGDocumentTest.vala"
		_tmp694_ = doc;
#line 311 "DomGDocumentTest.vala"
		_tmp695_ = gxml_dom_document_get_document_element (_tmp694_);
#line 311 "DomGDocumentTest.vala"
		_tmp696_ = _tmp695_;
#line 311 "DomGDocumentTest.vala"
		_tmp697_ = _tmp696_;
#line 311 "DomGDocumentTest.vala"
		_tmp698_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp697_);
#line 311 "DomGDocumentTest.vala"
		_tmp699_ = _tmp698_;
#line 311 "DomGDocumentTest.vala"
		_tmp700_ = _tmp699_;
#line 311 "DomGDocumentTest.vala"
		_tmp701_ = gxml_dom_html_collection_get_length (_tmp700_);
#line 311 "DomGDocumentTest.vala"
		_tmp702_ = _tmp701_;
#line 311 "DomGDocumentTest.vala"
		_vala_assert (_tmp702_ == 1, "doc.document_element.children.length == 1");
#line 311 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp700_);
#line 311 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp697_);
#line 312 "DomGDocumentTest.vala"
		_tmp703_ = doc;
#line 312 "DomGDocumentTest.vala"
		_tmp704_ = gxml_dom_document_get_document_element (_tmp703_);
#line 312 "DomGDocumentTest.vala"
		_tmp705_ = _tmp704_;
#line 312 "DomGDocumentTest.vala"
		_tmp706_ = _tmp705_;
#line 312 "DomGDocumentTest.vala"
		_tmp707_ = gxml_dom_element_get_elements_by_tag_name (_tmp706_, "OtherNode");
#line 312 "DomGDocumentTest.vala"
		_tmp708_ = _tmp707_;
#line 312 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp706_);
#line 312 "DomGDocumentTest.vala"
		lnst = _tmp708_;
#line 313 "DomGDocumentTest.vala"
		_tmp709_ = gxml_dom_html_collection_get_length (lnst);
#line 313 "DomGDocumentTest.vala"
		_tmp710_ = _tmp709_;
#line 313 "DomGDocumentTest.vala"
		_vala_assert (_tmp710_ == 1, "lnst.length == 1");
#line 314 "DomGDocumentTest.vala"
		_tmp711_ = gxml_dom_html_collection_item (lnst, 0);
#line 314 "DomGDocumentTest.vala"
		nnst = _tmp711_;
#line 315 "DomGDocumentTest.vala"
		_tmp712_ = gxml_dom_element_get_namespace_uri (nnst);
#line 315 "DomGDocumentTest.vala"
		_tmp713_ = _tmp712_;
#line 315 "DomGDocumentTest.vala"
		_tmp714_ = _tmp713_;
#line 315 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp714_, "http://live.gnome.org/GXml") == 0, "nnst.namespace_uri == \"http://live.gnome.org/GXml\"");
#line 315 "DomGDocumentTest.vala"
		_g_free0 (_tmp714_);
#line 316 "DomGDocumentTest.vala"
		_tmp715_ = doc;
#line 316 "DomGDocumentTest.vala"
		_tmp716_ = gxml_dom_document_get_document_element (_tmp715_);
#line 316 "DomGDocumentTest.vala"
		_tmp717_ = _tmp716_;
#line 316 "DomGDocumentTest.vala"
		_tmp718_ = _tmp717_;
#line 316 "DomGDocumentTest.vala"
		_tmp719_ = gxml_dom_element_get_elements_by_tag_name_ns (_tmp718_, "http://live.gnome.org/GXml", "OtherNode");
#line 316 "DomGDocumentTest.vala"
		_tmp720_ = _tmp719_;
#line 316 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp718_);
#line 316 "DomGDocumentTest.vala"
		lns = _tmp720_;
#line 317 "DomGDocumentTest.vala"
		_vala_assert (lns != NULL, "lns != null");
#line 318 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (lns, GXML_TYPE_DOM_HTML_COLLECTION), "lns is DomHTMLCollection");
#line 322 "DomGDocumentTest.vala"
		_tmp721_ = gxml_dom_html_collection_get_length (lns);
#line 322 "DomGDocumentTest.vala"
		_tmp722_ = _tmp721_;
#line 322 "DomGDocumentTest.vala"
		_vala_assert (_tmp722_ == 1, "lns.length == 1");
#line 323 "DomGDocumentTest.vala"
		_tmp723_ = gxml_dom_html_collection_item (lns, 0);
#line 323 "DomGDocumentTest.vala"
		_tmp724_ = _tmp723_;
#line 323 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp724_, GXML_TYPE_DOM_ELEMENT), "lns.item (0) is DomElement");
#line 323 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp724_);
#line 324 "DomGDocumentTest.vala"
		_tmp725_ = gxml_dom_html_collection_item (lns, 0);
#line 324 "DomGDocumentTest.vala"
		_tmp726_ = _tmp725_;
#line 324 "DomGDocumentTest.vala"
		_tmp727_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp726_);
#line 324 "DomGDocumentTest.vala"
		_tmp728_ = _tmp727_;
#line 324 "DomGDocumentTest.vala"
		_tmp729_ = _tmp728_;
#line 324 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp729_, "OtherNode") == 0, "lns.item (0).node_name == \"OtherNode\"");
#line 324 "DomGDocumentTest.vala"
		_g_free0 (_tmp729_);
#line 324 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp726_);
#line 325 "DomGDocumentTest.vala"
		_tmp730_ = doc;
#line 325 "DomGDocumentTest.vala"
		_tmp731_ = gxml_dom_document_get_document_element (_tmp730_);
#line 325 "DomGDocumentTest.vala"
		_tmp732_ = _tmp731_;
#line 325 "DomGDocumentTest.vala"
		_tmp733_ = _tmp732_;
#line 325 "DomGDocumentTest.vala"
		_tmp734_ = gxml_dom_element_get_elements_by_class_name (_tmp733_, "black");
#line 325 "DomGDocumentTest.vala"
		_tmp735_ = _tmp734_;
#line 325 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp733_);
#line 325 "DomGDocumentTest.vala"
		lcl = _tmp735_;
#line 326 "DomGDocumentTest.vala"
		_vala_assert (lcl != NULL, "lcl != null");
#line 327 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (lcl, GXML_TYPE_DOM_HTML_COLLECTION), "lcl is DomHTMLCollection");
#line 328 "DomGDocumentTest.vala"
		_tmp736_ = gxml_dom_html_collection_get_length (lcl);
#line 328 "DomGDocumentTest.vala"
		_tmp737_ = _tmp736_;
#line 328 "DomGDocumentTest.vala"
		_vala_assert (_tmp737_ == 3, "lcl.length == 3");
#line 329 "DomGDocumentTest.vala"
		_tmp738_ = gxml_dom_html_collection_item (lcl, 0);
#line 329 "DomGDocumentTest.vala"
		_tmp739_ = _tmp738_;
#line 329 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp739_, GXML_TYPE_DOM_ELEMENT), "lcl.item (0) is DomElement");
#line 329 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp739_);
#line 330 "DomGDocumentTest.vala"
		_tmp740_ = gxml_dom_html_collection_item (lcl, 1);
#line 330 "DomGDocumentTest.vala"
		_tmp741_ = _tmp740_;
#line 330 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp741_, GXML_TYPE_DOM_ELEMENT), "lcl.item (1) is DomElement");
#line 330 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp741_);
#line 331 "DomGDocumentTest.vala"
		_tmp742_ = gxml_dom_html_collection_item (lcl, 0);
#line 331 "DomGDocumentTest.vala"
		_tmp743_ = _tmp742_;
#line 331 "DomGDocumentTest.vala"
		_tmp744_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp743_);
#line 331 "DomGDocumentTest.vala"
		_tmp745_ = _tmp744_;
#line 331 "DomGDocumentTest.vala"
		_tmp746_ = _tmp745_;
#line 331 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp746_, "p") == 0, "lcl.item (0).node_name == \"p\"");
#line 331 "DomGDocumentTest.vala"
		_g_free0 (_tmp746_);
#line 331 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp743_);
#line 332 "DomGDocumentTest.vala"
		_tmp747_ = gxml_dom_html_collection_item (lcl, 1);
#line 332 "DomGDocumentTest.vala"
		_tmp748_ = _tmp747_;
#line 332 "DomGDocumentTest.vala"
		_tmp749_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp748_);
#line 332 "DomGDocumentTest.vala"
		_tmp750_ = _tmp749_;
#line 332 "DomGDocumentTest.vala"
		_tmp751_ = _tmp750_;
#line 332 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp751_, "p") == 0, "lcl.item (1).node_name == \"p\"");
#line 332 "DomGDocumentTest.vala"
		_g_free0 (_tmp751_);
#line 332 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp748_);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (lcl);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (lns);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (nnst);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (lnst);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (l);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (pn4);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp558_);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (pn3);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp510_);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (pn2);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp472_);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (ppn);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (cp0);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (p);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (pn);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp415_);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (ng2);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (ng);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (b);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (e2);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (e1);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (e0);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (cn2);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp179_);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (cn);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp158_);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (t);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (e);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (doc);
#line 168 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 5136 "DomGDocumentTest.c"
	}
	goto __finally64;
	__catch64_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp752_;
		gchar* _tmp753_;
		gchar* _tmp754_;
#line 168 "DomGDocumentTest.vala"
		e = _inner_error0_;
#line 168 "DomGDocumentTest.vala"
		_inner_error0_ = NULL;
#line 334 "DomGDocumentTest.vala"
		_tmp752_ = e->message;
#line 334 "DomGDocumentTest.vala"
		_tmp753_ = g_strconcat ("Error: ", _tmp752_, NULL);
#line 334 "DomGDocumentTest.vala"
		_tmp754_ = _tmp753_;
#line 334 "DomGDocumentTest.vala"
		g_message ("DomGDocumentTest.vala:334: %s", _tmp754_);
#line 334 "DomGDocumentTest.vala"
		_g_free0 (_tmp754_);
#line 335 "DomGDocumentTest.vala"
		g_assert_not_reached ();
#line 168 "DomGDocumentTest.vala"
		_g_error_free0 (e);
#line 5163 "DomGDocumentTest.c"
	}
	__finally64:
#line 168 "DomGDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 168 "DomGDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 168 "DomGDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 168 "DomGDocumentTest.vala"
		return;
#line 5174 "DomGDocumentTest.c"
	}
}

static void
___lambda50__gtest_func (void)
{
#line 167 "DomGDocumentTest.vala"
	__lambda50_ ();
#line 5183 "DomGDocumentTest.c"
}

static void
__lambda51_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_;
		GXmlDomDocument* doc = NULL;
		GXmlDomDocument* _tmp2_;
		GXmlDomDocument* _tmp3_;
		GXmlDomDocument* _tmp4_;
		GXmlDomElement* _tmp5_;
		GXmlDomElement* _tmp6_;
		GXmlDomElement* _tmp7_;
		GXmlDomHTMLCollection* _tmp8_;
		GXmlDomHTMLCollection* _tmp9_;
		GXmlDomHTMLCollection* _tmp10_;
		gint _tmp11_;
		gint _tmp12_;
		GXmlDomElement* n1 = NULL;
		GXmlDomDocument* _tmp13_;
		GXmlDomElement* _tmp14_;
		GXmlDomDocument* _tmp15_;
		GXmlDomElement* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlDomElement* _tmp18_;
		GXmlDomElement* _tmp19_;
		GXmlDomNode* _tmp20_;
		GXmlDomNode* _tmp21_;
		GXmlDomElement* n = NULL;
		GXmlDomDocument* _tmp22_;
		GXmlDomElement* _tmp23_;
		GXmlDomElement* _tmp24_;
		GXmlDomElement* _tmp25_;
		GXmlDomHTMLCollection* _tmp26_;
		GXmlDomHTMLCollection* _tmp27_;
		GXmlDomHTMLCollection* _tmp28_;
		gpointer _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomElement* _tmp31_;
		GXmlDomElement* _tmp32_;
		GXmlDomElement* _tmp33_;
		gchar* _tmp34_;
		gchar* _tmp35_;
		gchar* _tmp36_;
		GXmlDomElement* _tmp37_;
		GXmlDomElement* _tmp38_;
		GXmlDomElement* _tmp39_;
		GeeList* _tmp40_;
		GeeList* _tmp41_;
		GeeList* _tmp42_;
		gint _tmp43_;
		gint _tmp44_;
		GXmlDomElement* _tmp45_;
		GeeList* _tmp46_;
		GeeList* _tmp47_;
		GeeList* _tmp48_;
		gpointer _tmp49_;
		GXmlNamespace* _tmp50_;
		gchar* _tmp51_;
		gchar* _tmp52_;
		gchar* _tmp53_;
		GXmlDomElement* _tmp54_;
		GeeList* _tmp55_;
		GeeList* _tmp56_;
		GeeList* _tmp57_;
		gpointer _tmp58_;
		GXmlNamespace* _tmp59_;
		gchar* _tmp60_;
		gchar* _tmp61_;
		gchar* _tmp62_;
		GXmlDomElement* _tmp63_;
		gchar* _tmp64_;
		gchar* _tmp65_;
		gchar* _tmp66_;
		GXmlDomElement* _tmp67_;
		gchar* _tmp68_;
		gchar* _tmp69_;
		gchar* _tmp70_;
		GXmlDomElement* _tmp71_;
		gchar* _tmp72_;
		gchar* _tmp73_;
		gchar* _tmp74_;
		GXmlDomElement* _tmp75_;
		gchar* _tmp76_;
		gchar* _tmp77_;
		gchar* _tmp78_;
		GXmlDomElement* _tmp79_;
		gchar* _tmp80_;
		gchar* _tmp81_;
		gchar* _tmp82_;
		GXmlDomElement* _tmp83_;
		GXmlDomTokenList* _tmp84_;
		GXmlDomTokenList* _tmp85_;
		GXmlDomTokenList* _tmp86_;
		GXmlDomElement* _tmp87_;
		GXmlDomTokenList* _tmp88_;
		GXmlDomTokenList* _tmp89_;
		GXmlDomTokenList* _tmp90_;
		gint _tmp91_;
		gint _tmp92_;
		GXmlDomElement* _tmp93_;
		GXmlDomTokenList* _tmp94_;
		GXmlDomTokenList* _tmp95_;
		GXmlDomTokenList* _tmp96_;
		gchar* _tmp97_;
		gchar* _tmp98_;
		GXmlDomElement* _tmp99_;
		GXmlDomTokenList* _tmp100_;
		GXmlDomTokenList* _tmp101_;
		GXmlDomTokenList* _tmp102_;
		gchar* _tmp103_;
		gchar* _tmp104_;
		GXmlDomElement* _tmp105_;
		GXmlDomNamedNodeMap* _tmp106_;
		GXmlDomNamedNodeMap* _tmp107_;
		GXmlDomNamedNodeMap* _tmp108_;
		GXmlDomElement* _tmp109_;
		GXmlDomNamedNodeMap* _tmp110_;
		GXmlDomNamedNodeMap* _tmp111_;
		GXmlDomNamedNodeMap* _tmp112_;
		gint _tmp113_;
		gint _tmp114_;
		GXmlDomElement* _tmp115_;
		GXmlDomNamedNodeMap* _tmp116_;
		GXmlDomNamedNodeMap* _tmp117_;
		GXmlDomNamedNodeMap* _tmp118_;
		GXmlDomNode* _tmp119_;
		GXmlDomNode* _tmp120_;
		GXmlDomElement* _tmp121_;
		GXmlDomNamedNodeMap* _tmp122_;
		GXmlDomNamedNodeMap* _tmp123_;
		GXmlDomNamedNodeMap* _tmp124_;
		GXmlDomNode* _tmp125_;
		GXmlDomNode* _tmp126_;
		gchar* _tmp127_;
		gchar* _tmp128_;
		gchar* _tmp129_;
		GXmlDomElement* _tmp130_;
		GXmlDomNamedNodeMap* _tmp131_;
		GXmlDomNamedNodeMap* _tmp132_;
		GXmlDomNamedNodeMap* _tmp133_;
		GXmlDomNode* _tmp134_;
		GXmlDomNode* _tmp135_;
		gchar* _tmp136_;
		gchar* _tmp137_;
		gchar* _tmp138_;
		GXmlDomElement* _tmp139_;
		gchar* _tmp140_;
		gchar* _tmp141_;
		gchar* _tmp142_;
		GXmlDomElement* _tmp143_;
		gchar* _tmp144_;
		gchar* _tmp145_;
		GXmlDomElement* _tmp146_;
		gchar* _tmp147_;
		gchar* _tmp148_;
		GXmlDomElement* _tmp149_;
		gchar* _tmp150_;
		gchar* _tmp151_;
		gchar* _tmp152_;
		GXmlDomElement* _tmp153_;
		GXmlDomElement* _tmp154_;
		gchar* _tmp155_;
		gchar* _tmp156_;
		GXmlDomElement* _tmp157_;
		GXmlDomElement* n2 = NULL;
		GXmlDomDocument* _tmp158_;
		GXmlDomElement* _tmp159_;
		GXmlDomDocument* _tmp160_;
		GXmlDomElement* _tmp161_;
		GXmlDomElement* _tmp162_;
		GXmlDomElement* _tmp163_;
		GXmlDomElement* _tmp164_;
		GXmlDomNode* _tmp165_;
		GXmlDomNode* _tmp166_;
		GXmlDomDocument* _tmp167_;
		GXmlDomElement* _tmp168_;
		GXmlDomElement* _tmp169_;
		GXmlDomElement* _tmp170_;
		GXmlDomHTMLCollection* _tmp171_;
		GXmlDomHTMLCollection* _tmp172_;
		GXmlDomHTMLCollection* _tmp173_;
		gint _tmp174_;
		gint _tmp175_;
		GXmlDomElement* _tmp176_;
		GXmlDomNamedNodeMap* _tmp177_;
		GXmlDomNamedNodeMap* _tmp178_;
		GXmlDomNamedNodeMap* _tmp179_;
		gint _tmp180_;
		gint _tmp181_;
		GXmlDomElement* _tmp182_;
		GXmlDomElement* _tmp183_;
		GXmlDomNamedNodeMap* _tmp184_;
		GXmlDomNamedNodeMap* _tmp185_;
		GXmlDomNamedNodeMap* _tmp186_;
		gint _tmp187_;
		gint _tmp188_;
		GXmlDomElement* _tmp189_;
		GXmlDomElement* _tmp190_;
		GXmlDomElement* _tmp191_;
		gchar* _tmp192_;
		gchar* _tmp193_;
		GXmlDomElement* _tmp194_;
		gchar* _tmp195_;
		gchar* _tmp196_;
#line 343 "DomGDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string (DOM_GDOCUMENT_TEST_HTMLDOC, 0, &_inner_error0_);
#line 343 "DomGDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 343 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 5398 "DomGDocumentTest.c"
			goto __catch65_g_error;
		}
#line 343 "DomGDocumentTest.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL);
#line 343 "DomGDocumentTest.vala"
		doc = _tmp2_;
#line 344 "DomGDocumentTest.vala"
		_tmp3_ = doc;
#line 344 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_DOM_DOCUMENT), "doc is DomDocument");
#line 345 "DomGDocumentTest.vala"
		_tmp4_ = doc;
#line 345 "DomGDocumentTest.vala"
		_tmp5_ = gxml_dom_document_get_document_element (_tmp4_);
#line 345 "DomGDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 345 "DomGDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 345 "DomGDocumentTest.vala"
		_tmp8_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp7_);
#line 345 "DomGDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 345 "DomGDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 345 "DomGDocumentTest.vala"
		_tmp11_ = gee_collection_get_size ((GeeCollection*) _tmp10_);
#line 345 "DomGDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 345 "DomGDocumentTest.vala"
		_vala_assert (_tmp12_ == 1, "doc.document_element.children.size == 1");
#line 345 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp10_);
#line 345 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp7_);
#line 346 "DomGDocumentTest.vala"
		_tmp13_ = doc;
#line 346 "DomGDocumentTest.vala"
		_tmp14_ = gxml_dom_document_create_element_ns (_tmp13_, "http://live.gnome.org/GXml", "gxml:code", &_inner_error0_);
#line 346 "DomGDocumentTest.vala"
		n1 = _tmp14_;
#line 346 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 346 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 346 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 5445 "DomGDocumentTest.c"
			goto __catch65_g_error;
		}
#line 347 "DomGDocumentTest.vala"
		_tmp15_ = doc;
#line 347 "DomGDocumentTest.vala"
		_tmp16_ = gxml_dom_document_get_document_element (_tmp15_);
#line 347 "DomGDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 347 "DomGDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 347 "DomGDocumentTest.vala"
		_tmp19_ = n1;
#line 347 "DomGDocumentTest.vala"
		_tmp20_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp18_, (GXmlDomNode*) _tmp19_, &_inner_error0_);
#line 347 "DomGDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 347 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp21_);
#line 347 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp18_);
#line 347 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 347 "DomGDocumentTest.vala"
			_g_object_unref0 (n1);
#line 347 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 347 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 5474 "DomGDocumentTest.c"
			goto __catch65_g_error;
		}
#line 348 "DomGDocumentTest.vala"
		_tmp22_ = doc;
#line 348 "DomGDocumentTest.vala"
		_tmp23_ = gxml_dom_document_get_document_element (_tmp22_);
#line 348 "DomGDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 348 "DomGDocumentTest.vala"
		_tmp25_ = _tmp24_;
#line 348 "DomGDocumentTest.vala"
		_tmp26_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp25_);
#line 348 "DomGDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 348 "DomGDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 348 "DomGDocumentTest.vala"
		_tmp29_ = gee_list_get ((GeeList*) _tmp28_, 1);
#line 348 "DomGDocumentTest.vala"
		_tmp30_ = (GXmlDomElement*) _tmp29_;
#line 348 "DomGDocumentTest.vala"
		_tmp31_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp30_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp30_) : NULL;
#line 348 "DomGDocumentTest.vala"
		if (_tmp31_ == NULL) {
#line 348 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp30_);
#line 5501 "DomGDocumentTest.c"
		}
#line 348 "DomGDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 348 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp28_);
#line 348 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp25_);
#line 348 "DomGDocumentTest.vala"
		n = _tmp32_;
#line 349 "DomGDocumentTest.vala"
		_tmp33_ = n;
#line 349 "DomGDocumentTest.vala"
		_tmp34_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp33_);
#line 349 "DomGDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 349 "DomGDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 349 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp36_, "code") == 0, "n.node_name == \"code\"");
#line 349 "DomGDocumentTest.vala"
		_g_free0 (_tmp36_);
#line 350 "DomGDocumentTest.vala"
		_tmp37_ = n;
#line 350 "DomGDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp37_, "id", "0y1", &_inner_error0_);
#line 350 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 350 "DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 350 "DomGDocumentTest.vala"
			_g_object_unref0 (n1);
#line 350 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 350 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 5537 "DomGDocumentTest.c"
			goto __catch65_g_error;
		}
#line 351 "DomGDocumentTest.vala"
		_tmp38_ = n;
#line 351 "DomGDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp38_, "class", "login black", &_inner_error0_);
#line 351 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 351 "DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 351 "DomGDocumentTest.vala"
			_g_object_unref0 (n1);
#line 351 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 351 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 5554 "DomGDocumentTest.c"
			goto __catch65_g_error;
		}
#line 352 "DomGDocumentTest.vala"
		_tmp39_ = n;
#line 352 "DomGDocumentTest.vala"
		_tmp40_ = gxml_node_get_namespaces (G_TYPE_CHECK_INSTANCE_TYPE (_tmp39_, GXML_TYPE_NODE) ? ((GXmlNode*) _tmp39_) : NULL);
#line 352 "DomGDocumentTest.vala"
		_tmp41_ = _tmp40_;
#line 352 "DomGDocumentTest.vala"
		_tmp42_ = _tmp41_;
#line 352 "DomGDocumentTest.vala"
		_tmp43_ = gee_collection_get_size ((GeeCollection*) _tmp42_);
#line 352 "DomGDocumentTest.vala"
		_tmp44_ = _tmp43_;
#line 352 "DomGDocumentTest.vala"
		_vala_assert (_tmp44_ == 1, "(n as GXml.Node).namespaces.size == 1");
#line 352 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp42_);
#line 353 "DomGDocumentTest.vala"
		_tmp45_ = n;
#line 353 "DomGDocumentTest.vala"
		_tmp46_ = gxml_node_get_namespaces (G_TYPE_CHECK_INSTANCE_TYPE (_tmp45_, GXML_TYPE_NODE) ? ((GXmlNode*) _tmp45_) : NULL);
#line 353 "DomGDocumentTest.vala"
		_tmp47_ = _tmp46_;
#line 353 "DomGDocumentTest.vala"
		_tmp48_ = _tmp47_;
#line 353 "DomGDocumentTest.vala"
		_tmp49_ = gee_list_get (_tmp48_, 0);
#line 353 "DomGDocumentTest.vala"
		_tmp50_ = (GXmlNamespace*) _tmp49_;
#line 353 "DomGDocumentTest.vala"
		_tmp51_ = gxml_namespace_get_uri (_tmp50_);
#line 353 "DomGDocumentTest.vala"
		_tmp52_ = _tmp51_;
#line 353 "DomGDocumentTest.vala"
		_tmp53_ = _tmp52_;
#line 353 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp53_, "http://live.gnome.org/GXml") == 0, "(n as GXml.Node).namespaces[0].uri == \"http://live.gnome.org/GXml\"");
#line 353 "DomGDocumentTest.vala"
		_g_free0 (_tmp53_);
#line 353 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp50_);
#line 353 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp48_);
#line 354 "DomGDocumentTest.vala"
		_tmp54_ = n;
#line 354 "DomGDocumentTest.vala"
		_tmp55_ = gxml_node_get_namespaces (G_TYPE_CHECK_INSTANCE_TYPE (_tmp54_, GXML_TYPE_NODE) ? ((GXmlNode*) _tmp54_) : NULL);
#line 354 "DomGDocumentTest.vala"
		_tmp56_ = _tmp55_;
#line 354 "DomGDocumentTest.vala"
		_tmp57_ = _tmp56_;
#line 354 "DomGDocumentTest.vala"
		_tmp58_ = gee_list_get (_tmp57_, 0);
#line 354 "DomGDocumentTest.vala"
		_tmp59_ = (GXmlNamespace*) _tmp58_;
#line 354 "DomGDocumentTest.vala"
		_tmp60_ = gxml_namespace_get_prefix (_tmp59_);
#line 354 "DomGDocumentTest.vala"
		_tmp61_ = _tmp60_;
#line 354 "DomGDocumentTest.vala"
		_tmp62_ = _tmp61_;
#line 354 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp62_, "gxml") == 0, "(n as GXml.Node).namespaces[0].prefix == \"gxml\"");
#line 354 "DomGDocumentTest.vala"
		_g_free0 (_tmp62_);
#line 354 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp59_);
#line 354 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp57_);
#line 355 "DomGDocumentTest.vala"
		_tmp63_ = n;
#line 355 "DomGDocumentTest.vala"
		_tmp64_ = gxml_dom_element_get_namespace_uri (_tmp63_);
#line 355 "DomGDocumentTest.vala"
		_tmp65_ = _tmp64_;
#line 355 "DomGDocumentTest.vala"
		_tmp66_ = _tmp65_;
#line 355 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp66_, "http://live.gnome.org/GXml") == 0, "n.namespace_uri == \"http://live.gnome.org/GXml\"");
#line 355 "DomGDocumentTest.vala"
		_g_free0 (_tmp66_);
#line 356 "DomGDocumentTest.vala"
		_tmp67_ = n;
#line 356 "DomGDocumentTest.vala"
		_tmp68_ = gxml_dom_element_get_prefix (_tmp67_);
#line 356 "DomGDocumentTest.vala"
		_tmp69_ = _tmp68_;
#line 356 "DomGDocumentTest.vala"
		_tmp70_ = _tmp69_;
#line 356 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp70_, "gxml") == 0, "n.prefix == \"gxml\"");
#line 356 "DomGDocumentTest.vala"
		_g_free0 (_tmp70_);
#line 357 "DomGDocumentTest.vala"
		_tmp71_ = n;
#line 357 "DomGDocumentTest.vala"
		_tmp72_ = gxml_dom_element_get_local_name (_tmp71_);
#line 357 "DomGDocumentTest.vala"
		_tmp73_ = _tmp72_;
#line 357 "DomGDocumentTest.vala"
		_tmp74_ = _tmp73_;
#line 357 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp74_, "code") == 0, "n.local_name == \"code\"");
#line 357 "DomGDocumentTest.vala"
		_g_free0 (_tmp74_);
#line 358 "DomGDocumentTest.vala"
		_tmp75_ = n;
#line 358 "DomGDocumentTest.vala"
		_tmp76_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp75_);
#line 358 "DomGDocumentTest.vala"
		_tmp77_ = _tmp76_;
#line 358 "DomGDocumentTest.vala"
		_tmp78_ = _tmp77_;
#line 358 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp78_, "code") == 0, "n.node_name == \"code\"");
#line 358 "DomGDocumentTest.vala"
		_g_free0 (_tmp78_);
#line 359 "DomGDocumentTest.vala"
		_tmp79_ = n;
#line 359 "DomGDocumentTest.vala"
		_tmp80_ = gxml_dom_element_get_id (_tmp79_);
#line 359 "DomGDocumentTest.vala"
		_tmp81_ = _tmp80_;
#line 359 "DomGDocumentTest.vala"
		_tmp82_ = _tmp81_;
#line 359 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp82_, "0y1") == 0, "n.id == \"0y1\"");
#line 359 "DomGDocumentTest.vala"
		_g_free0 (_tmp82_);
#line 360 "DomGDocumentTest.vala"
		_tmp83_ = n;
#line 360 "DomGDocumentTest.vala"
		_tmp84_ = gxml_dom_element_get_class_list (_tmp83_);
#line 360 "DomGDocumentTest.vala"
		_tmp85_ = _tmp84_;
#line 360 "DomGDocumentTest.vala"
		_tmp86_ = _tmp85_;
#line 360 "DomGDocumentTest.vala"
		_vala_assert (_tmp86_ != NULL, "n.class_list != null");
#line 360 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp86_);
#line 361 "DomGDocumentTest.vala"
		_tmp87_ = n;
#line 361 "DomGDocumentTest.vala"
		_tmp88_ = gxml_dom_element_get_class_list (_tmp87_);
#line 361 "DomGDocumentTest.vala"
		_tmp89_ = _tmp88_;
#line 361 "DomGDocumentTest.vala"
		_tmp90_ = _tmp89_;
#line 361 "DomGDocumentTest.vala"
		_tmp91_ = gxml_dom_token_list_get_length (_tmp90_);
#line 361 "DomGDocumentTest.vala"
		_tmp92_ = _tmp91_;
#line 361 "DomGDocumentTest.vala"
		_vala_assert (_tmp92_ == 2, "n.class_list.length == 2");
#line 361 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp90_);
#line 362 "DomGDocumentTest.vala"
		_tmp93_ = n;
#line 362 "DomGDocumentTest.vala"
		_tmp94_ = gxml_dom_element_get_class_list (_tmp93_);
#line 362 "DomGDocumentTest.vala"
		_tmp95_ = _tmp94_;
#line 362 "DomGDocumentTest.vala"
		_tmp96_ = _tmp95_;
#line 362 "DomGDocumentTest.vala"
		_tmp97_ = gxml_dom_token_list_item (_tmp96_, 0);
#line 362 "DomGDocumentTest.vala"
		_tmp98_ = _tmp97_;
#line 362 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp98_, "login") == 0, "n.class_list.item (0) == \"login\"");
#line 362 "DomGDocumentTest.vala"
		_g_free0 (_tmp98_);
#line 362 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp96_);
#line 363 "DomGDocumentTest.vala"
		_tmp99_ = n;
#line 363 "DomGDocumentTest.vala"
		_tmp100_ = gxml_dom_element_get_class_list (_tmp99_);
#line 363 "DomGDocumentTest.vala"
		_tmp101_ = _tmp100_;
#line 363 "DomGDocumentTest.vala"
		_tmp102_ = _tmp101_;
#line 363 "DomGDocumentTest.vala"
		_tmp103_ = gxml_dom_token_list_item (_tmp102_, 1);
#line 363 "DomGDocumentTest.vala"
		_tmp104_ = _tmp103_;
#line 363 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp104_, "black") == 0, "n.class_list.item (1) == \"black\"");
#line 363 "DomGDocumentTest.vala"
		_g_free0 (_tmp104_);
#line 363 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp102_);
#line 364 "DomGDocumentTest.vala"
		_tmp105_ = n;
#line 364 "DomGDocumentTest.vala"
		_tmp106_ = gxml_dom_element_get_attributes (_tmp105_);
#line 364 "DomGDocumentTest.vala"
		_tmp107_ = _tmp106_;
#line 364 "DomGDocumentTest.vala"
		_tmp108_ = _tmp107_;
#line 364 "DomGDocumentTest.vala"
		_vala_assert (_tmp108_ != NULL, "n.attributes != null");
#line 364 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp108_);
#line 365 "DomGDocumentTest.vala"
		_tmp109_ = n;
#line 365 "DomGDocumentTest.vala"
		_tmp110_ = gxml_dom_element_get_attributes (_tmp109_);
#line 365 "DomGDocumentTest.vala"
		_tmp111_ = _tmp110_;
#line 365 "DomGDocumentTest.vala"
		_tmp112_ = _tmp111_;
#line 365 "DomGDocumentTest.vala"
		_tmp113_ = gxml_dom_named_node_map_get_length (_tmp112_);
#line 365 "DomGDocumentTest.vala"
		_tmp114_ = _tmp113_;
#line 365 "DomGDocumentTest.vala"
		_vala_assert (_tmp114_ == 2, "n.attributes.length == 2");
#line 365 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp112_);
#line 366 "DomGDocumentTest.vala"
		_tmp115_ = n;
#line 366 "DomGDocumentTest.vala"
		_tmp116_ = gxml_dom_element_get_attributes (_tmp115_);
#line 366 "DomGDocumentTest.vala"
		_tmp117_ = _tmp116_;
#line 366 "DomGDocumentTest.vala"
		_tmp118_ = _tmp117_;
#line 366 "DomGDocumentTest.vala"
		_tmp119_ = gxml_dom_named_node_map_get_named_item (_tmp118_, "id");
#line 366 "DomGDocumentTest.vala"
		_tmp120_ = _tmp119_;
#line 366 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp120_, GXML_TYPE_DOM_NODE), "n.attributes.get_named_item (\"id\") is DomNode");
#line 366 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp120_);
#line 366 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp118_);
#line 367 "DomGDocumentTest.vala"
		_tmp121_ = n;
#line 367 "DomGDocumentTest.vala"
		_tmp122_ = gxml_dom_element_get_attributes (_tmp121_);
#line 367 "DomGDocumentTest.vala"
		_tmp123_ = _tmp122_;
#line 367 "DomGDocumentTest.vala"
		_tmp124_ = _tmp123_;
#line 367 "DomGDocumentTest.vala"
		_tmp125_ = gxml_dom_named_node_map_get_named_item (_tmp124_, "id");
#line 367 "DomGDocumentTest.vala"
		_tmp126_ = _tmp125_;
#line 367 "DomGDocumentTest.vala"
		_tmp127_ = gxml_dom_node_get_node_name (_tmp126_);
#line 367 "DomGDocumentTest.vala"
		_tmp128_ = _tmp127_;
#line 367 "DomGDocumentTest.vala"
		_tmp129_ = _tmp128_;
#line 367 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp129_, "id") == 0, "n.attributes.get_named_item (\"id\").node_name == \"id\"");
#line 367 "DomGDocumentTest.vala"
		_g_free0 (_tmp129_);
#line 367 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp126_);
#line 367 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp124_);
#line 368 "DomGDocumentTest.vala"
		_tmp130_ = n;
#line 368 "DomGDocumentTest.vala"
		_tmp131_ = gxml_dom_element_get_attributes (_tmp130_);
#line 368 "DomGDocumentTest.vala"
		_tmp132_ = _tmp131_;
#line 368 "DomGDocumentTest.vala"
		_tmp133_ = _tmp132_;
#line 368 "DomGDocumentTest.vala"
		_tmp134_ = gxml_dom_named_node_map_get_named_item (_tmp133_, "id");
#line 368 "DomGDocumentTest.vala"
		_tmp135_ = _tmp134_;
#line 368 "DomGDocumentTest.vala"
		_tmp136_ = gxml_dom_node_get_node_value (_tmp135_);
#line 368 "DomGDocumentTest.vala"
		_tmp137_ = _tmp136_;
#line 368 "DomGDocumentTest.vala"
		_tmp138_ = _tmp137_;
#line 368 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp138_, "0y1") == 0, "n.attributes.get_named_item (\"id\").node_value == \"0y1\"");
#line 368 "DomGDocumentTest.vala"
		_g_free0 (_tmp138_);
#line 368 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp135_);
#line 368 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp133_);
#line 369 "DomGDocumentTest.vala"
		_tmp139_ = n;
#line 369 "DomGDocumentTest.vala"
		_tmp140_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp139_);
#line 369 "DomGDocumentTest.vala"
		_tmp141_ = _tmp140_;
#line 369 "DomGDocumentTest.vala"
		_tmp142_ = _tmp141_;
#line 369 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp142_, "code") == 0, "n.node_name == \"code\"");
#line 369 "DomGDocumentTest.vala"
		_g_free0 (_tmp142_);
#line 370 "DomGDocumentTest.vala"
		_tmp143_ = n;
#line 370 "DomGDocumentTest.vala"
		_tmp144_ = gxml_dom_node_lookup_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp143_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp143_) : NULL, "gxml");
#line 370 "DomGDocumentTest.vala"
		_tmp145_ = _tmp144_;
#line 370 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp145_, "http://live.gnome.org/GXml") == 0, "(n as DomNode).lookup_namespace_uri (\"gxml\") == \"http://live.gnome.org/GXml\"");
#line 370 "DomGDocumentTest.vala"
		_g_free0 (_tmp145_);
#line 371 "DomGDocumentTest.vala"
		_tmp146_ = n;
#line 371 "DomGDocumentTest.vala"
		_tmp147_ = gxml_dom_node_lookup_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp146_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp146_) : NULL, "http://live.gnome.org/GXml");
#line 371 "DomGDocumentTest.vala"
		_tmp148_ = _tmp147_;
#line 371 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp148_, "gxml") == 0, "(n as DomNode).lookup_prefix (\"http://live.gnome.org/GXml\") == \"gxml\"");
#line 371 "DomGDocumentTest.vala"
		_g_free0 (_tmp148_);
#line 372 "DomGDocumentTest.vala"
		_tmp149_ = n;
#line 372 "DomGDocumentTest.vala"
		_tmp150_ = gxml_dom_element_get_tag_name (_tmp149_);
#line 372 "DomGDocumentTest.vala"
		_tmp151_ = _tmp150_;
#line 372 "DomGDocumentTest.vala"
		_tmp152_ = _tmp151_;
#line 372 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp152_, "gxml:code") == 0, "n.tag_name == \"gxml:code\"");
#line 372 "DomGDocumentTest.vala"
		_g_free0 (_tmp152_);
#line 373 "DomGDocumentTest.vala"
		_tmp153_ = n;
#line 373 "DomGDocumentTest.vala"
		gxml_dom_element_remove_attribute (_tmp153_, "id");
#line 374 "DomGDocumentTest.vala"
		_tmp154_ = n;
#line 374 "DomGDocumentTest.vala"
		_tmp155_ = gxml_dom_element_get_attribute (_tmp154_, "id");
#line 374 "DomGDocumentTest.vala"
		_tmp156_ = _tmp155_;
#line 374 "DomGDocumentTest.vala"
		_vala_assert (_tmp156_ == NULL, "n.get_attribute (\"id\") == null");
#line 374 "DomGDocumentTest.vala"
		_g_free0 (_tmp156_);
#line 375 "DomGDocumentTest.vala"
		_tmp157_ = n;
#line 375 "DomGDocumentTest.vala"
		_vala_assert (!gxml_dom_element_has_attribute (_tmp157_, "id"), "!n.has_attribute (\"id\")");
#line 376 "DomGDocumentTest.vala"
		_tmp158_ = doc;
#line 376 "DomGDocumentTest.vala"
		_tmp159_ = gxml_dom_document_create_element (_tmp158_, "p", &_inner_error0_);
#line 376 "DomGDocumentTest.vala"
		n2 = _tmp159_;
#line 376 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 376 "DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 376 "DomGDocumentTest.vala"
			_g_object_unref0 (n1);
#line 376 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 376 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 5925 "DomGDocumentTest.c"
			goto __catch65_g_error;
		}
#line 377 "DomGDocumentTest.vala"
		_tmp160_ = doc;
#line 377 "DomGDocumentTest.vala"
		_tmp161_ = gxml_dom_document_get_document_element (_tmp160_);
#line 377 "DomGDocumentTest.vala"
		_tmp162_ = _tmp161_;
#line 377 "DomGDocumentTest.vala"
		_tmp163_ = _tmp162_;
#line 377 "DomGDocumentTest.vala"
		_tmp164_ = n2;
#line 377 "DomGDocumentTest.vala"
		_tmp165_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp163_, (GXmlDomNode*) _tmp164_, &_inner_error0_);
#line 377 "DomGDocumentTest.vala"
		_tmp166_ = _tmp165_;
#line 377 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp166_);
#line 377 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp163_);
#line 377 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 377 "DomGDocumentTest.vala"
			_g_object_unref0 (n2);
#line 377 "DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 377 "DomGDocumentTest.vala"
			_g_object_unref0 (n1);
#line 377 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 377 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 5958 "DomGDocumentTest.c"
			goto __catch65_g_error;
		}
#line 378 "DomGDocumentTest.vala"
		_tmp167_ = doc;
#line 378 "DomGDocumentTest.vala"
		_tmp168_ = gxml_dom_document_get_document_element (_tmp167_);
#line 378 "DomGDocumentTest.vala"
		_tmp169_ = _tmp168_;
#line 378 "DomGDocumentTest.vala"
		_tmp170_ = _tmp169_;
#line 378 "DomGDocumentTest.vala"
		_tmp171_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp170_);
#line 378 "DomGDocumentTest.vala"
		_tmp172_ = _tmp171_;
#line 378 "DomGDocumentTest.vala"
		_tmp173_ = _tmp172_;
#line 378 "DomGDocumentTest.vala"
		_tmp174_ = gxml_dom_html_collection_get_length (_tmp173_);
#line 378 "DomGDocumentTest.vala"
		_tmp175_ = _tmp174_;
#line 378 "DomGDocumentTest.vala"
		_vala_assert (_tmp175_ == 3, "doc.document_element.children.length == 3");
#line 378 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp173_);
#line 378 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp170_);
#line 382 "DomGDocumentTest.vala"
		_tmp176_ = n2;
#line 382 "DomGDocumentTest.vala"
		_tmp177_ = gxml_dom_element_get_attributes (_tmp176_);
#line 382 "DomGDocumentTest.vala"
		_tmp178_ = _tmp177_;
#line 382 "DomGDocumentTest.vala"
		_tmp179_ = _tmp178_;
#line 382 "DomGDocumentTest.vala"
		_tmp180_ = gxml_dom_named_node_map_get_length (_tmp179_);
#line 382 "DomGDocumentTest.vala"
		_tmp181_ = _tmp180_;
#line 382 "DomGDocumentTest.vala"
		_vala_assert (_tmp181_ == 0, "n2.attributes.length == 0");
#line 382 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp179_);
#line 386 "DomGDocumentTest.vala"
		_tmp182_ = n2;
#line 386 "DomGDocumentTest.vala"
		gxml_dom_element_set_attribute_ns (_tmp182_, "http://devel.org/", "dev:nice", "good", &_inner_error0_);
#line 386 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 386 "DomGDocumentTest.vala"
			_g_object_unref0 (n2);
#line 386 "DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 386 "DomGDocumentTest.vala"
			_g_object_unref0 (n1);
#line 386 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 386 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 6017 "DomGDocumentTest.c"
			goto __catch65_g_error;
		}
#line 387 "DomGDocumentTest.vala"
		_tmp183_ = n2;
#line 387 "DomGDocumentTest.vala"
		_tmp184_ = gxml_dom_element_get_attributes (_tmp183_);
#line 387 "DomGDocumentTest.vala"
		_tmp185_ = _tmp184_;
#line 387 "DomGDocumentTest.vala"
		_tmp186_ = _tmp185_;
#line 387 "DomGDocumentTest.vala"
		_tmp187_ = gxml_dom_named_node_map_get_length (_tmp186_);
#line 387 "DomGDocumentTest.vala"
		_tmp188_ = _tmp187_;
#line 387 "DomGDocumentTest.vala"
		_vala_assert (_tmp188_ == 1, "n2.attributes.length == 1");
#line 387 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp186_);
#line 388 "DomGDocumentTest.vala"
		_tmp189_ = n2;
#line 388 "DomGDocumentTest.vala"
		_vala_assert (gxml_dom_element_has_attribute_ns (_tmp189_, "http://devel.org/", "nice"), "n2.has_attribute_ns (\"http://devel.org/\",\"nice\")");
#line 389 "DomGDocumentTest.vala"
		_tmp190_ = n2;
#line 389 "DomGDocumentTest.vala"
		_vala_assert (!gxml_dom_element_has_attribute_ns (_tmp190_, "http://devel.org/", "dev:nice"), "!n2.has_attribute_ns (\"http://devel.org/\",\"dev:nice\")");
#line 393 "DomGDocumentTest.vala"
		_tmp191_ = n2;
#line 393 "DomGDocumentTest.vala"
		_tmp192_ = gxml_dom_element_get_attribute_ns (_tmp191_, "http://devel.org/", "nice");
#line 393 "DomGDocumentTest.vala"
		_tmp193_ = _tmp192_;
#line 393 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp193_, "good") == 0, "n2.get_attribute_ns (\"http://devel.org/\",\"nice\") == \"good\"");
#line 393 "DomGDocumentTest.vala"
		_g_free0 (_tmp193_);
#line 394 "DomGDocumentTest.vala"
		_tmp194_ = n2;
#line 394 "DomGDocumentTest.vala"
		_tmp195_ = gxml_dom_element_get_attribute_ns (_tmp194_, "http://devel.org/", "dev:nice");
#line 394 "DomGDocumentTest.vala"
		_tmp196_ = _tmp195_;
#line 394 "DomGDocumentTest.vala"
		_vala_assert (_tmp196_ == NULL, "n2.get_attribute_ns (\"http://devel.org/\",\"dev:nice\") == null");
#line 394 "DomGDocumentTest.vala"
		_g_free0 (_tmp196_);
#line 339 "DomGDocumentTest.vala"
		_g_object_unref0 (n2);
#line 339 "DomGDocumentTest.vala"
		_g_object_unref0 (n);
#line 339 "DomGDocumentTest.vala"
		_g_object_unref0 (n1);
#line 339 "DomGDocumentTest.vala"
		_g_object_unref0 (doc);
#line 339 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 6074 "DomGDocumentTest.c"
	}
	goto __finally65;
	__catch65_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp197_;
		gchar* _tmp198_;
		gchar* _tmp199_;
#line 339 "DomGDocumentTest.vala"
		e = _inner_error0_;
#line 339 "DomGDocumentTest.vala"
		_inner_error0_ = NULL;
#line 396 "DomGDocumentTest.vala"
		_tmp197_ = e->message;
#line 396 "DomGDocumentTest.vala"
		_tmp198_ = g_strconcat ("Error: ", _tmp197_, NULL);
#line 396 "DomGDocumentTest.vala"
		_tmp199_ = _tmp198_;
#line 396 "DomGDocumentTest.vala"
		g_message ("DomGDocumentTest.vala:396: %s", _tmp199_);
#line 396 "DomGDocumentTest.vala"
		_g_free0 (_tmp199_);
#line 397 "DomGDocumentTest.vala"
		g_assert_not_reached ();
#line 339 "DomGDocumentTest.vala"
		_g_error_free0 (e);
#line 6101 "DomGDocumentTest.c"
	}
	__finally65:
#line 339 "DomGDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 339 "DomGDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 339 "DomGDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 339 "DomGDocumentTest.vala"
		return;
#line 6112 "DomGDocumentTest.c"
	}
}

static void
___lambda51__gtest_func (void)
{
#line 338 "DomGDocumentTest.vala"
	__lambda51_ ();
#line 6121 "DomGDocumentTest.c"
}

static void
__lambda52_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_;
		GXmlDomDocument* doc = NULL;
		GXmlDomDocument* _tmp2_;
		GXmlDomDocument* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		GXmlDomDocument* _tmp6_;
		const gchar* _tmp7_;
		const gchar* _tmp8_;
		GXmlDomDocument* _tmp9_;
		const gchar* _tmp10_;
		const gchar* _tmp11_;
		GXmlDomDocument* _tmp12_;
		const gchar* _tmp13_;
		const gchar* _tmp14_;
		GXmlDomDocument* _tmp15_;
		const gchar* _tmp16_;
		const gchar* _tmp17_;
		GXmlDomDocument* _tmp18_;
		const gchar* _tmp19_;
		const gchar* _tmp20_;
		GXmlDomDocument* _tmp21_;
		GXmlDomDocumentType* _tmp22_;
		GXmlDomDocumentType* _tmp23_;
		GXmlDomDocumentType* _tmp24_;
		GXmlDomDocument* _tmp25_;
		GXmlDomElement* _tmp26_;
		GXmlDomElement* _tmp27_;
		GXmlDomElement* _tmp28_;
		GXmlDomDocument* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomElement* _tmp31_;
		GXmlDomElement* _tmp32_;
		GXmlDomDocument* _tmp33_;
		GXmlDomElement* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomElement* _tmp36_;
		gchar* _tmp37_;
		gchar* _tmp38_;
		gchar* _tmp39_;
		GXmlDomHTMLCollection* le = NULL;
		GXmlDomDocument* _tmp40_;
		GXmlDomHTMLCollection* _tmp41_;
		GXmlDomHTMLCollection* _tmp42_;
		gint _tmp43_;
		gint _tmp44_;
		GXmlDomHTMLCollection* _tmp45_;
		GXmlDomElement* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomHTMLCollection* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		gchar* _tmp51_;
		gchar* _tmp52_;
		gchar* _tmp53_;
		GXmlDomElement* n = NULL;
		GXmlDomDocument* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomNode* _tmp56_ = NULL;
		GXmlDomDocument* _tmp57_;
		GXmlDomElement* _tmp58_;
		GXmlDomElement* _tmp59_;
		GXmlDomElement* _tmp60_;
		GXmlDomElement* _tmp61_;
		GXmlDomNode* _tmp62_;
		GXmlDomNode* _tmp63_;
		GXmlDomElement* n2 = NULL;
		GXmlDomElement* _tmp64_;
		GXmlDomElement* _tmp65_;
		GXmlDomHTMLCollection* lens = NULL;
		GXmlDomDocument* _tmp66_;
		GXmlDomHTMLCollection* _tmp67_;
		GXmlDomHTMLCollection* _tmp68_;
		gint _tmp69_;
		gint _tmp70_;
		GXmlDomHTMLCollection* _tmp71_;
		GXmlDomElement* _tmp72_;
		GXmlDomElement* _tmp73_;
		GXmlDomHTMLCollection* _tmp74_;
		GXmlDomElement* _tmp75_;
		GXmlDomElement* _tmp76_;
		gchar* _tmp77_;
		gchar* _tmp78_;
		gchar* _tmp79_;
		GXmlDomHTMLCollection* lec = NULL;
		GXmlDomDocument* _tmp80_;
		GXmlDomHTMLCollection* _tmp81_;
		GXmlDomHTMLCollection* _tmp82_;
		gint _tmp83_;
		gint _tmp84_;
		GXmlDomHTMLCollection* _tmp85_;
		GXmlDomElement* _tmp86_;
		GXmlDomElement* _tmp87_;
		GXmlDomHTMLCollection* _tmp88_;
		GXmlDomElement* _tmp89_;
		GXmlDomElement* _tmp90_;
		gchar* _tmp91_;
		gchar* _tmp92_;
		gchar* _tmp93_;
		GXmlDomHTMLCollection* _tmp94_;
		GXmlDomElement* _tmp95_;
		GXmlDomElement* _tmp96_;
		GXmlDomHTMLCollection* _tmp97_;
		GXmlDomElement* _tmp98_;
		GXmlDomElement* _tmp99_;
		gchar* _tmp100_;
		gchar* _tmp101_;
		gchar* _tmp102_;
		GXmlDomElement* _tmp103_;
		GXmlDomHTMLCollection* lec2 = NULL;
		GXmlDomDocument* _tmp104_;
		GXmlDomHTMLCollection* _tmp105_;
		GXmlDomHTMLCollection* _tmp106_;
		gint _tmp107_;
		gint _tmp108_;
		GXmlDomHTMLCollection* _tmp109_;
		GXmlDomElement* _tmp110_;
		GXmlDomElement* _tmp111_;
		GXmlDomHTMLCollection* lec3 = NULL;
		GXmlDomDocument* _tmp112_;
		GXmlDomHTMLCollection* _tmp113_;
		GXmlDomHTMLCollection* _tmp114_;
		gint _tmp115_;
		gint _tmp116_;
		GXmlDomHTMLCollection* lec4 = NULL;
		GXmlDomDocument* _tmp117_;
		GXmlDomHTMLCollection* _tmp118_;
		GXmlDomHTMLCollection* _tmp119_;
		gint _tmp120_;
		gint _tmp121_;
		GXmlDomHTMLCollection* lec5 = NULL;
		GXmlDomDocument* _tmp122_;
		GXmlDomHTMLCollection* _tmp123_;
		GXmlDomHTMLCollection* _tmp124_;
		gint _tmp125_;
		gint _tmp126_;
		GXmlDomHTMLCollection* _tmp127_;
		GXmlDomElement* _tmp128_;
		GXmlDomElement* _tmp129_;
		GXmlDomHTMLCollection* _tmp130_;
		GXmlDomElement* _tmp131_;
		GXmlDomElement* _tmp132_;
		gchar* _tmp133_;
		gchar* _tmp134_;
		gchar* _tmp135_;
		GXmlDomHTMLCollection* _tmp136_;
		GXmlDomElement* _tmp137_;
		GXmlDomElement* _tmp138_;
		GXmlDomHTMLCollection* _tmp139_;
		GXmlDomElement* _tmp140_;
		GXmlDomElement* _tmp141_;
		gchar* _tmp142_;
		gchar* _tmp143_;
		gchar* _tmp144_;
		GXmlDomHTMLCollection* _tmp145_;
		GXmlDomElement* _tmp146_;
		GXmlDomElement* _tmp147_;
		GXmlDomHTMLCollection* _tmp148_;
		GXmlDomElement* _tmp149_;
		GXmlDomElement* _tmp150_;
		gchar* _tmp151_;
		gchar* _tmp152_;
		gchar* _tmp153_;
		GXmlDomText* t = NULL;
		GXmlDomDocument* _tmp154_;
		GXmlDomText* _tmp155_;
		GXmlDomElement* _tmp156_;
		GXmlDomText* _tmp157_;
		GXmlDomNode* _tmp158_;
		GXmlDomNode* _tmp159_;
		GXmlDomElement* _tmp160_;
		GXmlDomNodeList* _tmp161_;
		GXmlDomNodeList* _tmp162_;
		GXmlDomNodeList* _tmp163_;
		gpointer _tmp164_;
		GXmlDomNode* _tmp165_;
		GXmlDomElement* _tmp166_;
		GXmlDomNodeList* _tmp167_;
		GXmlDomNodeList* _tmp168_;
		GXmlDomNodeList* _tmp169_;
		gpointer _tmp170_;
		GXmlDomNode* _tmp171_;
		gchar* _tmp172_;
		gchar* _tmp173_;
		gchar* _tmp174_;
		GXmlDomComment* comment = NULL;
		GXmlDomDocument* _tmp175_;
		GXmlDomComment* _tmp176_;
		GXmlDomDocument* _tmp177_;
		GXmlDomElement* _tmp178_;
		GXmlDomElement* _tmp179_;
		GXmlDomElement* _tmp180_;
		GXmlDomComment* _tmp181_;
		GXmlDomNode* _tmp182_;
		GXmlDomNode* _tmp183_;
		GXmlDomDocument* _tmp184_;
		GXmlDomElement* _tmp185_;
		GXmlDomElement* _tmp186_;
		GXmlDomElement* _tmp187_;
		GXmlDomNode* _tmp188_;
		GXmlDomNode* _tmp189_;
		GXmlDomNode* _tmp190_;
		GXmlDomDocument* _tmp191_;
		GXmlDomElement* _tmp192_;
		GXmlDomElement* _tmp193_;
		GXmlDomElement* _tmp194_;
		GXmlDomNode* _tmp195_;
		GXmlDomNode* _tmp196_;
		GXmlDomNode* _tmp197_;
		gchar* _tmp198_;
		gchar* _tmp199_;
		gchar* _tmp200_;
		GXmlDomProcessingInstruction* pi = NULL;
		GXmlDomDocument* _tmp201_;
		GXmlDomProcessingInstruction* _tmp202_;
		GXmlDomDocument* _tmp203_;
		GXmlDomElement* _tmp204_;
		GXmlDomElement* _tmp205_;
		GXmlDomElement* _tmp206_;
		GXmlDomProcessingInstruction* _tmp207_;
		GXmlDomNode* _tmp208_;
		GXmlDomNode* _tmp209_;
		GXmlDomDocument* _tmp210_;
		GXmlDomElement* _tmp211_;
		GXmlDomElement* _tmp212_;
		GXmlDomElement* _tmp213_;
		GXmlDomNode* _tmp214_;
		GXmlDomNode* _tmp215_;
		GXmlDomNode* _tmp216_;
#line 405 "DomGDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string (DOM_GDOCUMENT_TEST_XMLDOC, 0, &_inner_error0_);
#line 405 "DomGDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 405 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 6365 "DomGDocumentTest.c"
			goto __catch66_g_error;
		}
#line 405 "DomGDocumentTest.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL);
#line 405 "DomGDocumentTest.vala"
		doc = _tmp2_;
#line 406 "DomGDocumentTest.vala"
		_tmp3_ = doc;
#line 406 "DomGDocumentTest.vala"
		_tmp4_ = gxml_dom_document_get_url (_tmp3_);
#line 406 "DomGDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 406 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp5_, "about:blank") == 0, "doc.url == \"about:blank\"");
#line 407 "DomGDocumentTest.vala"
		_tmp6_ = doc;
#line 407 "DomGDocumentTest.vala"
		_tmp7_ = gxml_dom_document_get_document_uri (_tmp6_);
#line 407 "DomGDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 407 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp8_, "about:blank") == 0, "doc.document_uri == \"about:blank\"");
#line 408 "DomGDocumentTest.vala"
		_tmp9_ = doc;
#line 408 "DomGDocumentTest.vala"
		_tmp10_ = gxml_dom_document_get_origin (_tmp9_);
#line 408 "DomGDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 408 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp11_, "") == 0, "doc.origin == \"\"");
#line 409 "DomGDocumentTest.vala"
		_tmp12_ = doc;
#line 409 "DomGDocumentTest.vala"
		_tmp13_ = gxml_dom_document_get_compat_mode (_tmp12_);
#line 409 "DomGDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 409 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp14_, "") == 0, "doc.compat_mode == \"\"");
#line 410 "DomGDocumentTest.vala"
		_tmp15_ = doc;
#line 410 "DomGDocumentTest.vala"
		_tmp16_ = gxml_dom_document_get_character_set (_tmp15_);
#line 410 "DomGDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 410 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp17_, "utf-8") == 0, "doc.character_set == \"utf-8\"");
#line 411 "DomGDocumentTest.vala"
		_tmp18_ = doc;
#line 411 "DomGDocumentTest.vala"
		_tmp19_ = gxml_dom_document_get_content_type (_tmp18_);
#line 411 "DomGDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 411 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp20_, "application/xml") == 0, "doc.content_type == \"application/xml\"");
#line 412 "DomGDocumentTest.vala"
		_tmp21_ = doc;
#line 412 "DomGDocumentTest.vala"
		_tmp22_ = gxml_dom_document_get_doctype (_tmp21_);
#line 412 "DomGDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 412 "DomGDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 412 "DomGDocumentTest.vala"
		_vala_assert (_tmp24_ == NULL, "doc.doctype == null");
#line 412 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp24_);
#line 413 "DomGDocumentTest.vala"
		_tmp25_ = doc;
#line 413 "DomGDocumentTest.vala"
		_tmp26_ = gxml_dom_document_get_document_element (_tmp25_);
#line 413 "DomGDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 413 "DomGDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 413 "DomGDocumentTest.vala"
		_vala_assert (_tmp28_ != NULL, "doc.document_element != null");
#line 413 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp28_);
#line 414 "DomGDocumentTest.vala"
		_tmp29_ = doc;
#line 414 "DomGDocumentTest.vala"
		_tmp30_ = gxml_dom_document_get_document_element (_tmp29_);
#line 414 "DomGDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 414 "DomGDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 414 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp32_, GXML_TYPE_DOM_ELEMENT), "doc.document_element is DomElement");
#line 414 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp32_);
#line 415 "DomGDocumentTest.vala"
		_tmp33_ = doc;
#line 415 "DomGDocumentTest.vala"
		_tmp34_ = gxml_dom_document_get_document_element (_tmp33_);
#line 415 "DomGDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 415 "DomGDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 415 "DomGDocumentTest.vala"
		_tmp37_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp36_);
#line 415 "DomGDocumentTest.vala"
		_tmp38_ = _tmp37_;
#line 415 "DomGDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 415 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp39_, "root") == 0, "doc.document_element.node_name == \"root\"");
#line 415 "DomGDocumentTest.vala"
		_g_free0 (_tmp39_);
#line 415 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp36_);
#line 416 "DomGDocumentTest.vala"
		_tmp40_ = doc;
#line 416 "DomGDocumentTest.vala"
		_tmp41_ = gxml_dom_document_get_elements_by_tag_name (_tmp40_, "code");
#line 416 "DomGDocumentTest.vala"
		le = _tmp41_;
#line 417 "DomGDocumentTest.vala"
		_tmp42_ = le;
#line 417 "DomGDocumentTest.vala"
		_tmp43_ = gxml_dom_html_collection_get_length (_tmp42_);
#line 417 "DomGDocumentTest.vala"
		_tmp44_ = _tmp43_;
#line 417 "DomGDocumentTest.vala"
		_vala_assert (_tmp44_ == 2, "le.length == 2");
#line 418 "DomGDocumentTest.vala"
		_tmp45_ = le;
#line 418 "DomGDocumentTest.vala"
		_tmp46_ = gxml_dom_html_collection_item (_tmp45_, 0);
#line 418 "DomGDocumentTest.vala"
		_tmp47_ = _tmp46_;
#line 418 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp47_, GXML_TYPE_DOM_ELEMENT), "le.item (0) is DomElement");
#line 418 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp47_);
#line 419 "DomGDocumentTest.vala"
		_tmp48_ = le;
#line 419 "DomGDocumentTest.vala"
		_tmp49_ = gxml_dom_html_collection_item (_tmp48_, 0);
#line 419 "DomGDocumentTest.vala"
		_tmp50_ = _tmp49_;
#line 419 "DomGDocumentTest.vala"
		_tmp51_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp50_);
#line 419 "DomGDocumentTest.vala"
		_tmp52_ = _tmp51_;
#line 419 "DomGDocumentTest.vala"
		_tmp53_ = _tmp52_;
#line 419 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp53_, "code") == 0, "le.item (0).node_name == \"code\"");
#line 419 "DomGDocumentTest.vala"
		_g_free0 (_tmp53_);
#line 419 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp50_);
#line 420 "DomGDocumentTest.vala"
		_tmp54_ = doc;
#line 420 "DomGDocumentTest.vala"
		_tmp55_ = gxml_dom_document_create_element_ns (_tmp54_, "http://git.gnome.org/browse/gxml", "git:MyNode", &_inner_error0_);
#line 420 "DomGDocumentTest.vala"
		n = _tmp55_;
#line 420 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 420 "DomGDocumentTest.vala"
			_g_object_unref0 (le);
#line 420 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 420 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 6532 "DomGDocumentTest.c"
			goto __catch66_g_error;
		}
#line 421 "DomGDocumentTest.vala"
		_tmp57_ = doc;
#line 421 "DomGDocumentTest.vala"
		_tmp58_ = gxml_dom_document_get_document_element (_tmp57_);
#line 421 "DomGDocumentTest.vala"
		_tmp59_ = _tmp58_;
#line 421 "DomGDocumentTest.vala"
		_tmp60_ = _tmp59_;
#line 421 "DomGDocumentTest.vala"
		_tmp61_ = n;
#line 421 "DomGDocumentTest.vala"
		_tmp62_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp60_, (GXmlDomNode*) _tmp61_, &_inner_error0_);
#line 421 "DomGDocumentTest.vala"
		_tmp63_ = _tmp62_;
#line 421 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp60_);
#line 421 "DomGDocumentTest.vala"
		_tmp56_ = _tmp63_;
#line 421 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 421 "DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 421 "DomGDocumentTest.vala"
			_g_object_unref0 (le);
#line 421 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 421 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 6563 "DomGDocumentTest.c"
			goto __catch66_g_error;
		}
#line 421 "DomGDocumentTest.vala"
		_tmp64_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp56_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp56_) : NULL);
#line 421 "DomGDocumentTest.vala"
		n2 = _tmp64_;
#line 422 "DomGDocumentTest.vala"
		_tmp65_ = n2;
#line 422 "DomGDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp65_, "class", "node", &_inner_error0_);
#line 422 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 422 "DomGDocumentTest.vala"
			_g_object_unref0 (n2);
#line 422 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp56_);
#line 422 "DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 422 "DomGDocumentTest.vala"
			_g_object_unref0 (le);
#line 422 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 422 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 6588 "DomGDocumentTest.c"
			goto __catch66_g_error;
		}
#line 423 "DomGDocumentTest.vala"
		_tmp66_ = doc;
#line 423 "DomGDocumentTest.vala"
		_tmp67_ = gxml_dom_document_get_elements_by_tag_name_ns (_tmp66_, "http://git.gnome.org/browse/gxml", "MyNode");
#line 423 "DomGDocumentTest.vala"
		lens = _tmp67_;
#line 424 "DomGDocumentTest.vala"
		_tmp68_ = lens;
#line 424 "DomGDocumentTest.vala"
		_tmp69_ = gxml_dom_html_collection_get_length (_tmp68_);
#line 424 "DomGDocumentTest.vala"
		_tmp70_ = _tmp69_;
#line 424 "DomGDocumentTest.vala"
		_vala_assert (_tmp70_ == 1, "lens.length == 1");
#line 425 "DomGDocumentTest.vala"
		_tmp71_ = lens;
#line 425 "DomGDocumentTest.vala"
		_tmp72_ = gxml_dom_html_collection_item (_tmp71_, 0);
#line 425 "DomGDocumentTest.vala"
		_tmp73_ = _tmp72_;
#line 425 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp73_, GXML_TYPE_DOM_ELEMENT), "lens.item (0) is DomElement");
#line 425 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp73_);
#line 426 "DomGDocumentTest.vala"
		_tmp74_ = lens;
#line 426 "DomGDocumentTest.vala"
		_tmp75_ = gxml_dom_html_collection_item (_tmp74_, 0);
#line 426 "DomGDocumentTest.vala"
		_tmp76_ = _tmp75_;
#line 426 "DomGDocumentTest.vala"
		_tmp77_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp76_);
#line 426 "DomGDocumentTest.vala"
		_tmp78_ = _tmp77_;
#line 426 "DomGDocumentTest.vala"
		_tmp79_ = _tmp78_;
#line 426 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp79_, "MyNode") == 0, "lens.item (0).node_name == \"MyNode\"");
#line 426 "DomGDocumentTest.vala"
		_g_free0 (_tmp79_);
#line 426 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp76_);
#line 430 "DomGDocumentTest.vala"
		_tmp80_ = doc;
#line 430 "DomGDocumentTest.vala"
		_tmp81_ = gxml_dom_document_get_elements_by_class_name (_tmp80_, "node");
#line 430 "DomGDocumentTest.vala"
		lec = _tmp81_;
#line 431 "DomGDocumentTest.vala"
		_tmp82_ = lec;
#line 431 "DomGDocumentTest.vala"
		_tmp83_ = gxml_dom_html_collection_get_length (_tmp82_);
#line 431 "DomGDocumentTest.vala"
		_tmp84_ = _tmp83_;
#line 431 "DomGDocumentTest.vala"
		_vala_assert (_tmp84_ == 4, "lec.length == 4");
#line 432 "DomGDocumentTest.vala"
		_tmp85_ = lec;
#line 432 "DomGDocumentTest.vala"
		_tmp86_ = gxml_dom_html_collection_item (_tmp85_, 0);
#line 432 "DomGDocumentTest.vala"
		_tmp87_ = _tmp86_;
#line 432 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp87_, GXML_TYPE_DOM_ELEMENT), "lec.item (0) is DomElement");
#line 432 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp87_);
#line 433 "DomGDocumentTest.vala"
		_tmp88_ = lec;
#line 433 "DomGDocumentTest.vala"
		_tmp89_ = gxml_dom_html_collection_item (_tmp88_, 0);
#line 433 "DomGDocumentTest.vala"
		_tmp90_ = _tmp89_;
#line 433 "DomGDocumentTest.vala"
		_tmp91_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp90_);
#line 433 "DomGDocumentTest.vala"
		_tmp92_ = _tmp91_;
#line 433 "DomGDocumentTest.vala"
		_tmp93_ = _tmp92_;
#line 433 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp93_, "MyNode") == 0, "lec.item (0).node_name == \"MyNode\"");
#line 433 "DomGDocumentTest.vala"
		_g_free0 (_tmp93_);
#line 433 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp90_);
#line 434 "DomGDocumentTest.vala"
		_tmp94_ = lec;
#line 434 "DomGDocumentTest.vala"
		_tmp95_ = gxml_dom_html_collection_item (_tmp94_, 1);
#line 434 "DomGDocumentTest.vala"
		_tmp96_ = _tmp95_;
#line 434 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp96_, GXML_TYPE_DOM_ELEMENT), "lec.item (1) is DomElement");
#line 434 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp96_);
#line 435 "DomGDocumentTest.vala"
		_tmp97_ = lec;
#line 435 "DomGDocumentTest.vala"
		_tmp98_ = gxml_dom_html_collection_item (_tmp97_, 1);
#line 435 "DomGDocumentTest.vala"
		_tmp99_ = _tmp98_;
#line 435 "DomGDocumentTest.vala"
		_tmp100_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp99_);
#line 435 "DomGDocumentTest.vala"
		_tmp101_ = _tmp100_;
#line 435 "DomGDocumentTest.vala"
		_tmp102_ = _tmp101_;
#line 435 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp102_, "page") == 0, "lec.item (1).node_name == \"page\"");
#line 435 "DomGDocumentTest.vala"
		_g_free0 (_tmp102_);
#line 435 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp99_);
#line 436 "DomGDocumentTest.vala"
		_tmp103_ = n;
#line 436 "DomGDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp103_, "class", "node parent", &_inner_error0_);
#line 436 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 436 "DomGDocumentTest.vala"
			_g_object_unref0 (lec);
#line 436 "DomGDocumentTest.vala"
			_g_object_unref0 (lens);
#line 436 "DomGDocumentTest.vala"
			_g_object_unref0 (n2);
#line 436 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp56_);
#line 436 "DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 436 "DomGDocumentTest.vala"
			_g_object_unref0 (le);
#line 436 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 436 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 6725 "DomGDocumentTest.c"
			goto __catch66_g_error;
		}
#line 437 "DomGDocumentTest.vala"
		_tmp104_ = doc;
#line 437 "DomGDocumentTest.vala"
		_tmp105_ = gxml_dom_document_get_elements_by_class_name (_tmp104_, "parent");
#line 437 "DomGDocumentTest.vala"
		lec2 = _tmp105_;
#line 438 "DomGDocumentTest.vala"
		_tmp106_ = lec2;
#line 438 "DomGDocumentTest.vala"
		_tmp107_ = gxml_dom_html_collection_get_length (_tmp106_);
#line 438 "DomGDocumentTest.vala"
		_tmp108_ = _tmp107_;
#line 438 "DomGDocumentTest.vala"
		_vala_assert (_tmp108_ == 4, "lec2.length == 4");
#line 439 "DomGDocumentTest.vala"
		_tmp109_ = lec2;
#line 439 "DomGDocumentTest.vala"
		_tmp110_ = gxml_dom_html_collection_item (_tmp109_, 0);
#line 439 "DomGDocumentTest.vala"
		_tmp111_ = _tmp110_;
#line 439 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp111_, GXML_TYPE_DOM_ELEMENT), "lec2.item (0) is DomElement");
#line 439 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp111_);
#line 440 "DomGDocumentTest.vala"
		_tmp112_ = doc;
#line 440 "DomGDocumentTest.vala"
		_tmp113_ = gxml_dom_document_get_elements_by_class_name (_tmp112_, "parent code");
#line 440 "DomGDocumentTest.vala"
		lec3 = _tmp113_;
#line 441 "DomGDocumentTest.vala"
		_tmp114_ = lec3;
#line 441 "DomGDocumentTest.vala"
		_tmp115_ = gxml_dom_html_collection_get_length (_tmp114_);
#line 441 "DomGDocumentTest.vala"
		_tmp116_ = _tmp115_;
#line 441 "DomGDocumentTest.vala"
		_vala_assert (_tmp116_ == 0, "lec3.length == 0");
#line 442 "DomGDocumentTest.vala"
		_tmp117_ = doc;
#line 442 "DomGDocumentTest.vala"
		_tmp118_ = gxml_dom_document_get_elements_by_class_name (_tmp117_, "code parent");
#line 442 "DomGDocumentTest.vala"
		lec4 = _tmp118_;
#line 443 "DomGDocumentTest.vala"
		_tmp119_ = lec4;
#line 443 "DomGDocumentTest.vala"
		_tmp120_ = gxml_dom_html_collection_get_length (_tmp119_);
#line 443 "DomGDocumentTest.vala"
		_tmp121_ = _tmp120_;
#line 443 "DomGDocumentTest.vala"
		_vala_assert (_tmp121_ == 0, "lec4.length == 0");
#line 444 "DomGDocumentTest.vala"
		_tmp122_ = doc;
#line 444 "DomGDocumentTest.vala"
		_tmp123_ = gxml_dom_document_get_elements_by_class_name (_tmp122_, "node parent");
#line 444 "DomGDocumentTest.vala"
		lec5 = _tmp123_;
#line 449 "DomGDocumentTest.vala"
		_tmp124_ = lec5;
#line 449 "DomGDocumentTest.vala"
		_tmp125_ = gxml_dom_html_collection_get_length (_tmp124_);
#line 449 "DomGDocumentTest.vala"
		_tmp126_ = _tmp125_;
#line 449 "DomGDocumentTest.vala"
		_vala_assert (_tmp126_ == 3, "lec5.length == 3");
#line 450 "DomGDocumentTest.vala"
		_tmp127_ = lec5;
#line 450 "DomGDocumentTest.vala"
		_tmp128_ = gxml_dom_html_collection_item (_tmp127_, 0);
#line 450 "DomGDocumentTest.vala"
		_tmp129_ = _tmp128_;
#line 450 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp129_, GXML_TYPE_DOM_ELEMENT), "lec5.item (0) is DomElement");
#line 450 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp129_);
#line 451 "DomGDocumentTest.vala"
		_tmp130_ = lec5;
#line 451 "DomGDocumentTest.vala"
		_tmp131_ = gxml_dom_html_collection_item (_tmp130_, 0);
#line 451 "DomGDocumentTest.vala"
		_tmp132_ = _tmp131_;
#line 451 "DomGDocumentTest.vala"
		_tmp133_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp132_);
#line 451 "DomGDocumentTest.vala"
		_tmp134_ = _tmp133_;
#line 451 "DomGDocumentTest.vala"
		_tmp135_ = _tmp134_;
#line 451 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp135_, "MyNode") == 0, "lec5.item (0).node_name == \"MyNode\"");
#line 451 "DomGDocumentTest.vala"
		_g_free0 (_tmp135_);
#line 451 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp132_);
#line 452 "DomGDocumentTest.vala"
		_tmp136_ = lec5;
#line 452 "DomGDocumentTest.vala"
		_tmp137_ = gxml_dom_html_collection_item (_tmp136_, 1);
#line 452 "DomGDocumentTest.vala"
		_tmp138_ = _tmp137_;
#line 452 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp138_, GXML_TYPE_DOM_ELEMENT), "lec5.item (1) is DomElement");
#line 452 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp138_);
#line 453 "DomGDocumentTest.vala"
		_tmp139_ = lec5;
#line 453 "DomGDocumentTest.vala"
		_tmp140_ = gxml_dom_html_collection_item (_tmp139_, 1);
#line 453 "DomGDocumentTest.vala"
		_tmp141_ = _tmp140_;
#line 453 "DomGDocumentTest.vala"
		_tmp142_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp141_);
#line 453 "DomGDocumentTest.vala"
		_tmp143_ = _tmp142_;
#line 453 "DomGDocumentTest.vala"
		_tmp144_ = _tmp143_;
#line 453 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp144_, "page") == 0, "lec5.item (1).node_name == \"page\"");
#line 453 "DomGDocumentTest.vala"
		_g_free0 (_tmp144_);
#line 453 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp141_);
#line 454 "DomGDocumentTest.vala"
		_tmp145_ = lec5;
#line 454 "DomGDocumentTest.vala"
		_tmp146_ = gxml_dom_html_collection_item (_tmp145_, 2);
#line 454 "DomGDocumentTest.vala"
		_tmp147_ = _tmp146_;
#line 454 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp147_, GXML_TYPE_DOM_ELEMENT), "lec5.item (2) is DomElement");
#line 454 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp147_);
#line 455 "DomGDocumentTest.vala"
		_tmp148_ = lec5;
#line 455 "DomGDocumentTest.vala"
		_tmp149_ = gxml_dom_html_collection_item (_tmp148_, 2);
#line 455 "DomGDocumentTest.vala"
		_tmp150_ = _tmp149_;
#line 455 "DomGDocumentTest.vala"
		_tmp151_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp150_);
#line 455 "DomGDocumentTest.vala"
		_tmp152_ = _tmp151_;
#line 455 "DomGDocumentTest.vala"
		_tmp153_ = _tmp152_;
#line 455 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp153_, "code") == 0, "lec5.item (2).node_name == \"code\"");
#line 455 "DomGDocumentTest.vala"
		_g_free0 (_tmp153_);
#line 455 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp150_);
#line 456 "DomGDocumentTest.vala"
		_tmp154_ = doc;
#line 456 "DomGDocumentTest.vala"
		_tmp155_ = gxml_dom_document_create_text_node (_tmp154_, "TEXT", &_inner_error0_);
#line 456 "DomGDocumentTest.vala"
		t = _tmp155_;
#line 456 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 456 "DomGDocumentTest.vala"
			_g_object_unref0 (lec5);
#line 456 "DomGDocumentTest.vala"
			_g_object_unref0 (lec4);
#line 456 "DomGDocumentTest.vala"
			_g_object_unref0 (lec3);
#line 456 "DomGDocumentTest.vala"
			_g_object_unref0 (lec2);
#line 456 "DomGDocumentTest.vala"
			_g_object_unref0 (lec);
#line 456 "DomGDocumentTest.vala"
			_g_object_unref0 (lens);
#line 456 "DomGDocumentTest.vala"
			_g_object_unref0 (n2);
#line 456 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp56_);
#line 456 "DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 456 "DomGDocumentTest.vala"
			_g_object_unref0 (le);
#line 456 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 456 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 6910 "DomGDocumentTest.c"
			goto __catch66_g_error;
		}
#line 457 "DomGDocumentTest.vala"
		_tmp156_ = n;
#line 457 "DomGDocumentTest.vala"
		_tmp157_ = t;
#line 457 "DomGDocumentTest.vala"
		_tmp158_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp156_, (GXmlDomNode*) _tmp157_, &_inner_error0_);
#line 457 "DomGDocumentTest.vala"
		_tmp159_ = _tmp158_;
#line 457 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp159_);
#line 457 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 457 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 457 "DomGDocumentTest.vala"
			_g_object_unref0 (lec5);
#line 457 "DomGDocumentTest.vala"
			_g_object_unref0 (lec4);
#line 457 "DomGDocumentTest.vala"
			_g_object_unref0 (lec3);
#line 457 "DomGDocumentTest.vala"
			_g_object_unref0 (lec2);
#line 457 "DomGDocumentTest.vala"
			_g_object_unref0 (lec);
#line 457 "DomGDocumentTest.vala"
			_g_object_unref0 (lens);
#line 457 "DomGDocumentTest.vala"
			_g_object_unref0 (n2);
#line 457 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp56_);
#line 457 "DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 457 "DomGDocumentTest.vala"
			_g_object_unref0 (le);
#line 457 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 457 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 6951 "DomGDocumentTest.c"
			goto __catch66_g_error;
		}
#line 458 "DomGDocumentTest.vala"
		_tmp160_ = n;
#line 458 "DomGDocumentTest.vala"
		_tmp161_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp160_);
#line 458 "DomGDocumentTest.vala"
		_tmp162_ = _tmp161_;
#line 458 "DomGDocumentTest.vala"
		_tmp163_ = _tmp162_;
#line 458 "DomGDocumentTest.vala"
		_tmp164_ = gee_list_get ((GeeList*) _tmp163_, 0);
#line 458 "DomGDocumentTest.vala"
		_tmp165_ = (GXmlDomNode*) _tmp164_;
#line 458 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp165_, GXML_TYPE_DOM_TEXT), "n.child_nodes[0] is DomText");
#line 458 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp165_);
#line 458 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp163_);
#line 459 "DomGDocumentTest.vala"
		_tmp166_ = n;
#line 459 "DomGDocumentTest.vala"
		_tmp167_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp166_);
#line 459 "DomGDocumentTest.vala"
		_tmp168_ = _tmp167_;
#line 459 "DomGDocumentTest.vala"
		_tmp169_ = _tmp168_;
#line 459 "DomGDocumentTest.vala"
		_tmp170_ = gee_list_get ((GeeList*) _tmp169_, 0);
#line 459 "DomGDocumentTest.vala"
		_tmp171_ = (GXmlDomNode*) _tmp170_;
#line 459 "DomGDocumentTest.vala"
		_tmp172_ = gxml_dom_node_get_node_value (_tmp171_);
#line 459 "DomGDocumentTest.vala"
		_tmp173_ = _tmp172_;
#line 459 "DomGDocumentTest.vala"
		_tmp174_ = _tmp173_;
#line 459 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp174_, "TEXT") == 0, "n.child_nodes[0].node_value == \"TEXT\"");
#line 459 "DomGDocumentTest.vala"
		_g_free0 (_tmp174_);
#line 459 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp171_);
#line 459 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp169_);
#line 460 "DomGDocumentTest.vala"
		_tmp175_ = doc;
#line 460 "DomGDocumentTest.vala"
		_tmp176_ = gxml_dom_document_create_comment (_tmp175_, "COMMENT", &_inner_error0_);
#line 460 "DomGDocumentTest.vala"
		comment = _tmp176_;
#line 460 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 460 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 460 "DomGDocumentTest.vala"
			_g_object_unref0 (lec5);
#line 460 "DomGDocumentTest.vala"
			_g_object_unref0 (lec4);
#line 460 "DomGDocumentTest.vala"
			_g_object_unref0 (lec3);
#line 460 "DomGDocumentTest.vala"
			_g_object_unref0 (lec2);
#line 460 "DomGDocumentTest.vala"
			_g_object_unref0 (lec);
#line 460 "DomGDocumentTest.vala"
			_g_object_unref0 (lens);
#line 460 "DomGDocumentTest.vala"
			_g_object_unref0 (n2);
#line 460 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp56_);
#line 460 "DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 460 "DomGDocumentTest.vala"
			_g_object_unref0 (le);
#line 460 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 460 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 7032 "DomGDocumentTest.c"
			goto __catch66_g_error;
		}
#line 461 "DomGDocumentTest.vala"
		_tmp177_ = doc;
#line 461 "DomGDocumentTest.vala"
		_tmp178_ = gxml_dom_document_get_document_element (_tmp177_);
#line 461 "DomGDocumentTest.vala"
		_tmp179_ = _tmp178_;
#line 461 "DomGDocumentTest.vala"
		_tmp180_ = _tmp179_;
#line 461 "DomGDocumentTest.vala"
		_tmp181_ = comment;
#line 461 "DomGDocumentTest.vala"
		_tmp182_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp180_, (GXmlDomNode*) _tmp181_, &_inner_error0_);
#line 461 "DomGDocumentTest.vala"
		_tmp183_ = _tmp182_;
#line 461 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp183_);
#line 461 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp180_);
#line 461 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 461 "DomGDocumentTest.vala"
			_g_object_unref0 (comment);
#line 461 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 461 "DomGDocumentTest.vala"
			_g_object_unref0 (lec5);
#line 461 "DomGDocumentTest.vala"
			_g_object_unref0 (lec4);
#line 461 "DomGDocumentTest.vala"
			_g_object_unref0 (lec3);
#line 461 "DomGDocumentTest.vala"
			_g_object_unref0 (lec2);
#line 461 "DomGDocumentTest.vala"
			_g_object_unref0 (lec);
#line 461 "DomGDocumentTest.vala"
			_g_object_unref0 (lens);
#line 461 "DomGDocumentTest.vala"
			_g_object_unref0 (n2);
#line 461 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp56_);
#line 461 "DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 461 "DomGDocumentTest.vala"
			_g_object_unref0 (le);
#line 461 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 461 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 7083 "DomGDocumentTest.c"
			goto __catch66_g_error;
		}
#line 462 "DomGDocumentTest.vala"
		_tmp184_ = doc;
#line 462 "DomGDocumentTest.vala"
		_tmp185_ = gxml_dom_document_get_document_element (_tmp184_);
#line 462 "DomGDocumentTest.vala"
		_tmp186_ = _tmp185_;
#line 462 "DomGDocumentTest.vala"
		_tmp187_ = _tmp186_;
#line 462 "DomGDocumentTest.vala"
		_tmp188_ = gxml_dom_node_get_last_child ((GXmlDomNode*) _tmp187_);
#line 462 "DomGDocumentTest.vala"
		_tmp189_ = _tmp188_;
#line 462 "DomGDocumentTest.vala"
		_tmp190_ = _tmp189_;
#line 462 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp190_, GXML_TYPE_DOM_COMMENT), "doc.document_element.last_child is DomComment");
#line 462 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp190_);
#line 462 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp187_);
#line 463 "DomGDocumentTest.vala"
		_tmp191_ = doc;
#line 463 "DomGDocumentTest.vala"
		_tmp192_ = gxml_dom_document_get_document_element (_tmp191_);
#line 463 "DomGDocumentTest.vala"
		_tmp193_ = _tmp192_;
#line 463 "DomGDocumentTest.vala"
		_tmp194_ = _tmp193_;
#line 463 "DomGDocumentTest.vala"
		_tmp195_ = gxml_dom_node_get_last_child ((GXmlDomNode*) _tmp194_);
#line 463 "DomGDocumentTest.vala"
		_tmp196_ = _tmp195_;
#line 463 "DomGDocumentTest.vala"
		_tmp197_ = _tmp196_;
#line 463 "DomGDocumentTest.vala"
		_tmp198_ = gxml_dom_node_get_node_value (_tmp197_);
#line 463 "DomGDocumentTest.vala"
		_tmp199_ = _tmp198_;
#line 463 "DomGDocumentTest.vala"
		_tmp200_ = _tmp199_;
#line 463 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp200_, "COMMENT") == 0, "doc.document_element.last_child.node_value == \"COMMENT\"");
#line 463 "DomGDocumentTest.vala"
		_g_free0 (_tmp200_);
#line 463 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp197_);
#line 463 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp194_);
#line 464 "DomGDocumentTest.vala"
		_tmp201_ = doc;
#line 464 "DomGDocumentTest.vala"
		_tmp202_ = gxml_dom_document_create_processing_instruction (_tmp201_, "git", "commit", &_inner_error0_);
#line 464 "DomGDocumentTest.vala"
		pi = _tmp202_;
#line 464 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 464 "DomGDocumentTest.vala"
			_g_object_unref0 (comment);
#line 464 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 464 "DomGDocumentTest.vala"
			_g_object_unref0 (lec5);
#line 464 "DomGDocumentTest.vala"
			_g_object_unref0 (lec4);
#line 464 "DomGDocumentTest.vala"
			_g_object_unref0 (lec3);
#line 464 "DomGDocumentTest.vala"
			_g_object_unref0 (lec2);
#line 464 "DomGDocumentTest.vala"
			_g_object_unref0 (lec);
#line 464 "DomGDocumentTest.vala"
			_g_object_unref0 (lens);
#line 464 "DomGDocumentTest.vala"
			_g_object_unref0 (n2);
#line 464 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp56_);
#line 464 "DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 464 "DomGDocumentTest.vala"
			_g_object_unref0 (le);
#line 464 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 464 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 7170 "DomGDocumentTest.c"
			goto __catch66_g_error;
		}
#line 465 "DomGDocumentTest.vala"
		_tmp203_ = doc;
#line 465 "DomGDocumentTest.vala"
		_tmp204_ = gxml_dom_document_get_document_element (_tmp203_);
#line 465 "DomGDocumentTest.vala"
		_tmp205_ = _tmp204_;
#line 465 "DomGDocumentTest.vala"
		_tmp206_ = _tmp205_;
#line 465 "DomGDocumentTest.vala"
		_tmp207_ = pi;
#line 465 "DomGDocumentTest.vala"
		_tmp208_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp206_, (GXmlDomNode*) _tmp207_, &_inner_error0_);
#line 465 "DomGDocumentTest.vala"
		_tmp209_ = _tmp208_;
#line 465 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp209_);
#line 465 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp206_);
#line 465 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 465 "DomGDocumentTest.vala"
			_g_object_unref0 (pi);
#line 465 "DomGDocumentTest.vala"
			_g_object_unref0 (comment);
#line 465 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 465 "DomGDocumentTest.vala"
			_g_object_unref0 (lec5);
#line 465 "DomGDocumentTest.vala"
			_g_object_unref0 (lec4);
#line 465 "DomGDocumentTest.vala"
			_g_object_unref0 (lec3);
#line 465 "DomGDocumentTest.vala"
			_g_object_unref0 (lec2);
#line 465 "DomGDocumentTest.vala"
			_g_object_unref0 (lec);
#line 465 "DomGDocumentTest.vala"
			_g_object_unref0 (lens);
#line 465 "DomGDocumentTest.vala"
			_g_object_unref0 (n2);
#line 465 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp56_);
#line 465 "DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 465 "DomGDocumentTest.vala"
			_g_object_unref0 (le);
#line 465 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 465 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 7223 "DomGDocumentTest.c"
			goto __catch66_g_error;
		}
#line 469 "DomGDocumentTest.vala"
		_tmp210_ = doc;
#line 469 "DomGDocumentTest.vala"
		_tmp211_ = gxml_dom_document_get_document_element (_tmp210_);
#line 469 "DomGDocumentTest.vala"
		_tmp212_ = _tmp211_;
#line 469 "DomGDocumentTest.vala"
		_tmp213_ = _tmp212_;
#line 469 "DomGDocumentTest.vala"
		_tmp214_ = gxml_dom_node_get_last_child ((GXmlDomNode*) _tmp213_);
#line 469 "DomGDocumentTest.vala"
		_tmp215_ = _tmp214_;
#line 469 "DomGDocumentTest.vala"
		_tmp216_ = _tmp215_;
#line 469 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp216_, GXML_TYPE_DOM_PROCESSING_INSTRUCTION), "doc.document_element.last_child is DomProcessingInstruction");
#line 469 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp216_);
#line 469 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp213_);
#line 401 "DomGDocumentTest.vala"
		_g_object_unref0 (pi);
#line 401 "DomGDocumentTest.vala"
		_g_object_unref0 (comment);
#line 401 "DomGDocumentTest.vala"
		_g_object_unref0 (t);
#line 401 "DomGDocumentTest.vala"
		_g_object_unref0 (lec5);
#line 401 "DomGDocumentTest.vala"
		_g_object_unref0 (lec4);
#line 401 "DomGDocumentTest.vala"
		_g_object_unref0 (lec3);
#line 401 "DomGDocumentTest.vala"
		_g_object_unref0 (lec2);
#line 401 "DomGDocumentTest.vala"
		_g_object_unref0 (lec);
#line 401 "DomGDocumentTest.vala"
		_g_object_unref0 (lens);
#line 401 "DomGDocumentTest.vala"
		_g_object_unref0 (n2);
#line 401 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp56_);
#line 401 "DomGDocumentTest.vala"
		_g_object_unref0 (n);
#line 401 "DomGDocumentTest.vala"
		_g_object_unref0 (le);
#line 401 "DomGDocumentTest.vala"
		_g_object_unref0 (doc);
#line 401 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 7276 "DomGDocumentTest.c"
	}
	goto __finally66;
	__catch66_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp217_;
		gchar* _tmp218_;
		gchar* _tmp219_;
#line 401 "DomGDocumentTest.vala"
		e = _inner_error0_;
#line 401 "DomGDocumentTest.vala"
		_inner_error0_ = NULL;
#line 471 "DomGDocumentTest.vala"
		_tmp217_ = e->message;
#line 471 "DomGDocumentTest.vala"
		_tmp218_ = g_strconcat ("Error: ", _tmp217_, NULL);
#line 471 "DomGDocumentTest.vala"
		_tmp219_ = _tmp218_;
#line 471 "DomGDocumentTest.vala"
		g_message ("DomGDocumentTest.vala:471: %s", _tmp219_);
#line 471 "DomGDocumentTest.vala"
		_g_free0 (_tmp219_);
#line 472 "DomGDocumentTest.vala"
		g_assert_not_reached ();
#line 401 "DomGDocumentTest.vala"
		_g_error_free0 (e);
#line 7303 "DomGDocumentTest.c"
	}
	__finally66:
#line 401 "DomGDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 401 "DomGDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 401 "DomGDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 401 "DomGDocumentTest.vala"
		return;
#line 7314 "DomGDocumentTest.c"
	}
}

static void
___lambda52__gtest_func (void)
{
#line 400 "DomGDocumentTest.vala"
	__lambda52_ ();
#line 7323 "DomGDocumentTest.c"
}

static void
__lambda53_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_;
		GXmlDomDocument* doc = NULL;
		GXmlDomDocument* _tmp2_;
		GXmlGDocument* _tmp3_ = NULL;
		GXmlGDocument* _tmp4_;
		GXmlDomDocument* doc2 = NULL;
		GXmlDomDocument* _tmp5_;
		GXmlDomDocument* _tmp6_;
		GXmlDomDocument* _tmp7_;
		GXmlDomElement* _tmp8_;
		GXmlDomElement* _tmp9_;
		GXmlDomElement* _tmp10_;
		GXmlDomNode* _tmp11_;
		GXmlDomNode* _tmp12_;
		GXmlDomDocument* _tmp13_;
		GXmlDomElement* _tmp14_;
		GXmlDomElement* _tmp15_;
		GXmlDomElement* _tmp16_;
		GXmlDomNode* _tmp17_;
		GXmlDomNode* _tmp18_;
		GXmlDomNode* _tmp19_;
		GXmlDomDocument* _tmp20_;
		GXmlDomElement* _tmp21_;
		GXmlDomElement* _tmp22_;
		GXmlDomElement* _tmp23_;
		GXmlDomNode* _tmp24_;
		GXmlDomNode* _tmp25_;
		GXmlDomNode* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
		GXmlDomDocument* _tmp30_;
		GXmlDomElement* _tmp31_;
		GXmlDomElement* _tmp32_;
		GXmlDomElement* _tmp33_;
		GXmlDomNode* _tmp34_;
		GXmlDomNode* _tmp35_;
		GXmlDomNode* _tmp36_;
		GXmlDomNodeList* _tmp37_;
		GXmlDomNodeList* _tmp38_;
		GXmlDomNodeList* _tmp39_;
		gint _tmp40_;
		gint _tmp41_;
#line 480 "DomGDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string (DOM_GDOCUMENT_TEST_XMLDOC, 0, &_inner_error0_);
#line 480 "DomGDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 480 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 7381 "DomGDocumentTest.c"
			goto __catch67_g_error;
		}
#line 480 "DomGDocumentTest.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL);
#line 480 "DomGDocumentTest.vala"
		doc = _tmp2_;
#line 481 "DomGDocumentTest.vala"
		_tmp4_ = gxml_gdocument_new_from_string (DOM_GDOCUMENT_TEST_STRDOC, 0, &_inner_error0_);
#line 481 "DomGDocumentTest.vala"
		_tmp3_ = _tmp4_;
#line 481 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 481 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 481 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 7398 "DomGDocumentTest.c"
			goto __catch67_g_error;
		}
#line 481 "DomGDocumentTest.vala"
		_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp3_) : NULL);
#line 481 "DomGDocumentTest.vala"
		doc2 = _tmp5_;
#line 482 "DomGDocumentTest.vala"
		_tmp6_ = doc;
#line 482 "DomGDocumentTest.vala"
		_tmp7_ = doc2;
#line 482 "DomGDocumentTest.vala"
		_tmp8_ = gxml_dom_document_get_document_element (_tmp7_);
#line 482 "DomGDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 482 "DomGDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 482 "DomGDocumentTest.vala"
		_tmp11_ = gxml_dom_document_import_node (_tmp6_, (GXmlDomNode*) _tmp10_, FALSE, &_inner_error0_);
#line 482 "DomGDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 482 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp12_);
#line 482 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp10_);
#line 482 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 482 "DomGDocumentTest.vala"
			_g_object_unref0 (doc2);
#line 482 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp3_);
#line 482 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 482 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 7433 "DomGDocumentTest.c"
			goto __catch67_g_error;
		}
#line 486 "DomGDocumentTest.vala"
		_tmp13_ = doc;
#line 486 "DomGDocumentTest.vala"
		_tmp14_ = gxml_dom_document_get_document_element (_tmp13_);
#line 486 "DomGDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 486 "DomGDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 486 "DomGDocumentTest.vala"
		_tmp17_ = gxml_dom_node_get_last_child ((GXmlDomNode*) _tmp16_);
#line 486 "DomGDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 486 "DomGDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 486 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, GXML_TYPE_DOM_ELEMENT), "doc.document_element.last_child is DomElement");
#line 486 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp19_);
#line 486 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp16_);
#line 487 "DomGDocumentTest.vala"
		_tmp20_ = doc;
#line 487 "DomGDocumentTest.vala"
		_tmp21_ = gxml_dom_document_get_document_element (_tmp20_);
#line 487 "DomGDocumentTest.vala"
		_tmp22_ = _tmp21_;
#line 487 "DomGDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 487 "DomGDocumentTest.vala"
		_tmp24_ = gxml_dom_node_get_last_child ((GXmlDomNode*) _tmp23_);
#line 487 "DomGDocumentTest.vala"
		_tmp25_ = _tmp24_;
#line 487 "DomGDocumentTest.vala"
		_tmp26_ = _tmp25_;
#line 487 "DomGDocumentTest.vala"
		_tmp27_ = gxml_dom_node_get_node_name (_tmp26_);
#line 487 "DomGDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 487 "DomGDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 487 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp29_, "Sentences") == 0, "doc.document_element.last_child.node_name == \"Sentences\"");
#line 487 "DomGDocumentTest.vala"
		_g_free0 (_tmp29_);
#line 487 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp26_);
#line 487 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp23_);
#line 488 "DomGDocumentTest.vala"
		_tmp30_ = doc;
#line 488 "DomGDocumentTest.vala"
		_tmp31_ = gxml_dom_document_get_document_element (_tmp30_);
#line 488 "DomGDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 488 "DomGDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 488 "DomGDocumentTest.vala"
		_tmp34_ = gxml_dom_node_get_last_child ((GXmlDomNode*) _tmp33_);
#line 488 "DomGDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 488 "DomGDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 488 "DomGDocumentTest.vala"
		_tmp37_ = gxml_dom_node_get_child_nodes (_tmp36_);
#line 488 "DomGDocumentTest.vala"
		_tmp38_ = _tmp37_;
#line 488 "DomGDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 488 "DomGDocumentTest.vala"
		_tmp40_ = gxml_dom_node_list_get_length (_tmp39_);
#line 488 "DomGDocumentTest.vala"
		_tmp41_ = _tmp40_;
#line 488 "DomGDocumentTest.vala"
		_vala_assert (_tmp41_ == 0, "doc.document_element.last_child.child_nodes.length == 0");
#line 488 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp39_);
#line 488 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp36_);
#line 488 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp33_);
#line 476 "DomGDocumentTest.vala"
		_g_object_unref0 (doc2);
#line 476 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp3_);
#line 476 "DomGDocumentTest.vala"
		_g_object_unref0 (doc);
#line 476 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 7524 "DomGDocumentTest.c"
	}
	goto __finally67;
	__catch67_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp42_;
		gchar* _tmp43_;
		gchar* _tmp44_;
#line 476 "DomGDocumentTest.vala"
		e = _inner_error0_;
#line 476 "DomGDocumentTest.vala"
		_inner_error0_ = NULL;
#line 491 "DomGDocumentTest.vala"
		_tmp42_ = e->message;
#line 491 "DomGDocumentTest.vala"
		_tmp43_ = g_strconcat ("Error: ", _tmp42_, NULL);
#line 491 "DomGDocumentTest.vala"
		_tmp44_ = _tmp43_;
#line 491 "DomGDocumentTest.vala"
		g_message ("DomGDocumentTest.vala:491: %s", _tmp44_);
#line 491 "DomGDocumentTest.vala"
		_g_free0 (_tmp44_);
#line 492 "DomGDocumentTest.vala"
		g_assert_not_reached ();
#line 476 "DomGDocumentTest.vala"
		_g_error_free0 (e);
#line 7551 "DomGDocumentTest.c"
	}
	__finally67:
#line 476 "DomGDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 476 "DomGDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 476 "DomGDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 476 "DomGDocumentTest.vala"
		return;
#line 7562 "DomGDocumentTest.c"
	}
}

static void
___lambda53__gtest_func (void)
{
#line 475 "DomGDocumentTest.vala"
	__lambda53_ ();
#line 7571 "DomGDocumentTest.c"
}

static void
__lambda54_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_;
		GXmlDomDocument* doc = NULL;
		GXmlDomDocument* _tmp2_;
		GXmlGDocument* _tmp3_ = NULL;
		GXmlGDocument* _tmp4_;
		GXmlDomDocument* doc2 = NULL;
		GXmlDomDocument* _tmp5_;
		GXmlDomDocument* _tmp6_;
		GXmlDomDocument* _tmp7_;
		GXmlDomElement* _tmp8_;
		GXmlDomElement* _tmp9_;
		GXmlDomElement* _tmp10_;
		GXmlDomHTMLCollection* _tmp11_;
		GXmlDomHTMLCollection* _tmp12_;
		GXmlDomHTMLCollection* _tmp13_;
		gpointer _tmp14_;
		GXmlDomElement* _tmp15_;
		GXmlDomNode* _tmp16_;
		GXmlDomNode* _tmp17_;
		GXmlDomDocument* _tmp18_;
		GXmlDomElement* _tmp19_;
		GXmlDomElement* _tmp20_;
		GXmlDomElement* _tmp21_;
		GXmlDomHTMLCollection* _tmp22_;
		GXmlDomHTMLCollection* _tmp23_;
		GXmlDomHTMLCollection* _tmp24_;
		gpointer _tmp25_;
		GXmlDomElement* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
		GXmlDomDocument* _tmp30_;
		GXmlDomElement* _tmp31_;
		GXmlDomElement* _tmp32_;
		GXmlDomElement* _tmp33_;
		GXmlDomNode* _tmp34_;
		GXmlDomNode* _tmp35_;
		GXmlDomNode* _tmp36_;
		GXmlDomDocument* _tmp37_;
		GXmlDomElement* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomNode* _tmp41_;
		GXmlDomNode* _tmp42_;
		GXmlDomNode* _tmp43_;
		gchar* _tmp44_;
		gchar* _tmp45_;
		gchar* _tmp46_;
#line 500 "DomGDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string (DOM_GDOCUMENT_TEST_XMLDOC, 0, &_inner_error0_);
#line 500 "DomGDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 500 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 7634 "DomGDocumentTest.c"
			goto __catch68_g_error;
		}
#line 500 "DomGDocumentTest.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL);
#line 500 "DomGDocumentTest.vala"
		doc = _tmp2_;
#line 501 "DomGDocumentTest.vala"
		_tmp4_ = gxml_gdocument_new_from_string (DOM_GDOCUMENT_TEST_STRDOC, 0, &_inner_error0_);
#line 501 "DomGDocumentTest.vala"
		_tmp3_ = _tmp4_;
#line 501 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 501 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 501 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 7651 "DomGDocumentTest.c"
			goto __catch68_g_error;
		}
#line 501 "DomGDocumentTest.vala"
		_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp3_) : NULL);
#line 501 "DomGDocumentTest.vala"
		doc2 = _tmp5_;
#line 502 "DomGDocumentTest.vala"
		_tmp6_ = doc2;
#line 502 "DomGDocumentTest.vala"
		_tmp7_ = doc;
#line 502 "DomGDocumentTest.vala"
		_tmp8_ = gxml_dom_document_get_document_element (_tmp7_);
#line 502 "DomGDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 502 "DomGDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 502 "DomGDocumentTest.vala"
		_tmp11_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp10_);
#line 502 "DomGDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 502 "DomGDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 502 "DomGDocumentTest.vala"
		_tmp14_ = gee_list_last ((GeeList*) _tmp13_);
#line 502 "DomGDocumentTest.vala"
		_tmp15_ = (GXmlDomElement*) _tmp14_;
#line 502 "DomGDocumentTest.vala"
		_tmp16_ = gxml_dom_document_adopt_node (_tmp6_, (GXmlDomNode*) _tmp15_, &_inner_error0_);
#line 502 "DomGDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 502 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp17_);
#line 502 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 502 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp13_);
#line 502 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp10_);
#line 502 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 502 "DomGDocumentTest.vala"
			_g_object_unref0 (doc2);
#line 502 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp3_);
#line 502 "DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 502 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 7700 "DomGDocumentTest.c"
			goto __catch68_g_error;
		}
#line 507 "DomGDocumentTest.vala"
		_tmp18_ = doc;
#line 507 "DomGDocumentTest.vala"
		_tmp19_ = gxml_dom_document_get_document_element (_tmp18_);
#line 507 "DomGDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 507 "DomGDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 507 "DomGDocumentTest.vala"
		_tmp22_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp21_);
#line 507 "DomGDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 507 "DomGDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 507 "DomGDocumentTest.vala"
		_tmp25_ = gee_list_last ((GeeList*) _tmp24_);
#line 507 "DomGDocumentTest.vala"
		_tmp26_ = (GXmlDomElement*) _tmp25_;
#line 507 "DomGDocumentTest.vala"
		_tmp27_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp26_);
#line 507 "DomGDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 507 "DomGDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 507 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp29_, "project") == 0, "doc.document_element.children.last ().node_name == \"project\"");
#line 507 "DomGDocumentTest.vala"
		_g_free0 (_tmp29_);
#line 507 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp26_);
#line 507 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp24_);
#line 507 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp21_);
#line 508 "DomGDocumentTest.vala"
		_tmp30_ = doc2;
#line 508 "DomGDocumentTest.vala"
		_tmp31_ = gxml_dom_document_get_document_element (_tmp30_);
#line 508 "DomGDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 508 "DomGDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 508 "DomGDocumentTest.vala"
		_tmp34_ = gxml_dom_node_get_last_child ((GXmlDomNode*) _tmp33_);
#line 508 "DomGDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 508 "DomGDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 508 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp36_, GXML_TYPE_DOM_ELEMENT), "doc2.document_element.last_child is DomElement");
#line 508 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp36_);
#line 508 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp33_);
#line 509 "DomGDocumentTest.vala"
		_tmp37_ = doc2;
#line 509 "DomGDocumentTest.vala"
		_tmp38_ = gxml_dom_document_get_document_element (_tmp37_);
#line 509 "DomGDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 509 "DomGDocumentTest.vala"
		_tmp40_ = _tmp39_;
#line 509 "DomGDocumentTest.vala"
		_tmp41_ = gxml_dom_node_get_last_child ((GXmlDomNode*) _tmp40_);
#line 509 "DomGDocumentTest.vala"
		_tmp42_ = _tmp41_;
#line 509 "DomGDocumentTest.vala"
		_tmp43_ = _tmp42_;
#line 509 "DomGDocumentTest.vala"
		_tmp44_ = gxml_dom_node_get_node_name (_tmp43_);
#line 509 "DomGDocumentTest.vala"
		_tmp45_ = _tmp44_;
#line 509 "DomGDocumentTest.vala"
		_tmp46_ = _tmp45_;
#line 509 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp46_, "Author") == 0, "doc2.document_element.last_child.node_name == \"Author\"");
#line 509 "DomGDocumentTest.vala"
		_g_free0 (_tmp46_);
#line 509 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp43_);
#line 509 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp40_);
#line 496 "DomGDocumentTest.vala"
		_g_object_unref0 (doc2);
#line 496 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp3_);
#line 496 "DomGDocumentTest.vala"
		_g_object_unref0 (doc);
#line 496 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 7793 "DomGDocumentTest.c"
	}
	goto __finally68;
	__catch68_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp47_;
		gchar* _tmp48_;
		gchar* _tmp49_;
#line 496 "DomGDocumentTest.vala"
		e = _inner_error0_;
#line 496 "DomGDocumentTest.vala"
		_inner_error0_ = NULL;
#line 512 "DomGDocumentTest.vala"
		_tmp47_ = e->message;
#line 512 "DomGDocumentTest.vala"
		_tmp48_ = g_strconcat ("Error: ", _tmp47_, NULL);
#line 512 "DomGDocumentTest.vala"
		_tmp49_ = _tmp48_;
#line 512 "DomGDocumentTest.vala"
		g_message ("DomGDocumentTest.vala:512: %s", _tmp49_);
#line 512 "DomGDocumentTest.vala"
		_g_free0 (_tmp49_);
#line 513 "DomGDocumentTest.vala"
		g_assert_not_reached ();
#line 496 "DomGDocumentTest.vala"
		_g_error_free0 (e);
#line 7820 "DomGDocumentTest.c"
	}
	__finally68:
#line 496 "DomGDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 496 "DomGDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 496 "DomGDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 496 "DomGDocumentTest.vala"
		return;
#line 7831 "DomGDocumentTest.c"
	}
}

static void
___lambda54__gtest_func (void)
{
#line 495 "DomGDocumentTest.vala"
	__lambda54_ ();
#line 7840 "DomGDocumentTest.c"
}

static void
__lambda55_ (void)
{
}

static void
___lambda55__gtest_func (void)
{
#line 516 "DomGDocumentTest.vala"
	__lambda55_ ();
#line 7853 "DomGDocumentTest.c"
}

static void
__lambda56_ (void)
{
}

static void
___lambda56__gtest_func (void)
{
#line 519 "DomGDocumentTest.vala"
	__lambda56_ ();
#line 7866 "DomGDocumentTest.c"
}

static void
__lambda57_ (void)
{
}

static void
___lambda57__gtest_func (void)
{
#line 522 "DomGDocumentTest.vala"
	__lambda57_ ();
#line 7879 "DomGDocumentTest.c"
}

static void
__lambda58_ (void)
{
}

static void
___lambda58__gtest_func (void)
{
#line 525 "DomGDocumentTest.vala"
	__lambda58_ ();
#line 7892 "DomGDocumentTest.c"
}

static void
__lambda59_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlDomDocument* d = NULL;
		GXmlGDocument* _tmp0_;
		GXmlDomDocument* _tmp1_;
		GXmlDomText* _tmp2_ = NULL;
		GXmlDomDocument* _tmp3_;
		GXmlDomText* _tmp4_;
		GXmlDomCharacterData* t = NULL;
		GXmlDomCharacterData* _tmp5_;
		GXmlDomCharacterData* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		GXmlDomCharacterData* _tmp10_;
		gint _tmp11_;
		gint _tmp12_;
		gint _tmp13_;
		gint _tmp14_;
		gchar* _tmp15_ = NULL;
		GXmlDomCharacterData* _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_ = NULL;
		GXmlDomCharacterData* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_ = NULL;
		GXmlDomCharacterData* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_ = NULL;
		GXmlDomCharacterData* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_ = NULL;
		GXmlDomCharacterData* _tmp28_;
		gchar* _tmp29_;
		gchar* _tmp30_ = NULL;
		GXmlDomCharacterData* _tmp31_;
		gchar* _tmp32_;
		GXmlDomCharacterData* _tmp36_;
		GXmlDomCharacterData* _tmp37_;
		gchar* _tmp38_;
		gchar* _tmp39_;
		gchar* _tmp40_;
		GXmlDomCharacterData* _tmp41_;
		GXmlDomCharacterData* _tmp42_;
		gchar* _tmp43_;
		gchar* _tmp44_;
		gchar* _tmp45_;
		GXmlDomCharacterData* _tmp46_;
		GXmlDomCharacterData* _tmp47_;
		gchar* _tmp48_;
		gchar* _tmp49_;
		gchar* _tmp50_;
		GXmlDomCharacterData* _tmp51_;
		GXmlDomCharacterData* _tmp52_;
		gchar* _tmp53_;
		gchar* _tmp54_;
		gchar* _tmp55_;
		GXmlDomCharacterData* _tmp56_;
		GXmlDomCharacterData* _tmp57_;
		gchar* _tmp58_;
		gchar* _tmp59_;
		gchar* _tmp60_;
		GXmlDomCharacterData* _tmp61_;
		GXmlDomCharacterData* _tmp62_;
		gchar* _tmp63_;
		gchar* _tmp64_;
		gchar* _tmp65_;
		GXmlDomElement* n = NULL;
		GXmlDomDocument* _tmp66_;
		GXmlDomElement* _tmp67_;
		GXmlDomDocument* _tmp68_;
		GXmlDomElement* _tmp69_;
		GXmlDomNode* _tmp70_;
		GXmlDomNode* _tmp71_;
		GXmlDomElement* _tmp72_;
		GXmlDomCharacterData* _tmp73_;
		GXmlDomNode* _tmp74_;
		GXmlDomNode* _tmp75_;
		GXmlDomCharacterData* _tmp76_;
		GXmlDomNode* _tmp77_;
		GXmlDomNode* _tmp78_;
		GXmlDomNode* _tmp79_;
		GXmlDomNodeList* _tmp80_;
		GXmlDomNodeList* _tmp81_;
		GXmlDomNodeList* _tmp82_;
		gint _tmp83_;
		gint _tmp84_;
		GXmlDomCharacterData* _tmp85_;
		GXmlDomNode* _tmp86_;
		GXmlDomNode* _tmp87_;
		GXmlDomNode* _tmp88_;
		GXmlDomNodeList* _tmp89_;
		GXmlDomNodeList* _tmp90_;
		GXmlDomNodeList* _tmp91_;
		gint _tmp92_;
		gint _tmp93_;
		GXmlDomElement* ntst = NULL;
		GXmlDomDocument* _tmp94_;
		GXmlDomElement* _tmp95_;
		GXmlDomElement* _tmp96_;
		GXmlDomElement* _tmp97_;
		GXmlDomNode* _tmp98_;
		GXmlDomNode* _tmp99_;
		GXmlDomText* ct1 = NULL;
		GXmlDomDocument* _tmp100_;
		GXmlDomText* _tmp101_;
		GXmlDomElement* _tmp102_;
		GXmlDomText* _tmp103_;
		GXmlDomNode* _tmp104_;
		GXmlDomNode* _tmp105_;
		GXmlDomElement* _tmp106_;
		GXmlDomNodeList* _tmp107_;
		GXmlDomNodeList* _tmp108_;
		GXmlDomNodeList* _tmp109_;
		gint _tmp110_;
		gint _tmp111_;
		GXmlDomText* ct2 = NULL;
		GXmlDomDocument* _tmp112_;
		GXmlDomText* _tmp113_;
		GXmlDomElement* _tmp114_;
		GXmlDomText* _tmp115_;
		GXmlDomNode* _tmp116_;
		GXmlDomNode* _tmp117_;
		GXmlDomElement* _tmp118_;
		GXmlDomNodeList* _tmp119_;
		GXmlDomNodeList* _tmp120_;
		GXmlDomNodeList* _tmp121_;
		GXmlDomNode* _tmp122_;
		GXmlDomNode* _tmp123_;
		GXmlDomElement* _tmp124_;
		GXmlDomNodeList* _tmp125_;
		GXmlDomNodeList* _tmp126_;
		GXmlDomNodeList* _tmp127_;
		GXmlDomNode* _tmp128_;
		GXmlDomText* _tmp129_;
		GXmlDomText* _tmp130_;
		gchar* _tmp131_;
		gchar* _tmp132_;
		gchar* _tmp133_;
		GXmlDomElement* _tmp134_;
		GXmlDomNodeList* _tmp135_;
		GXmlDomNodeList* _tmp136_;
		GXmlDomNodeList* _tmp137_;
		GXmlDomNode* _tmp138_;
		GXmlDomText* _tmp139_;
		GXmlDomText* _tmp140_;
		gchar* _tmp141_;
		gchar* _tmp142_;
		gchar* _tmp143_;
#line 530 "DomGDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new ();
#line 530 "DomGDocumentTest.vala"
		_tmp1_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL;
#line 530 "DomGDocumentTest.vala"
		if (_tmp1_ == NULL) {
#line 530 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 8055 "DomGDocumentTest.c"
		}
#line 530 "DomGDocumentTest.vala"
		d = _tmp1_;
#line 531 "DomGDocumentTest.vala"
		_tmp3_ = d;
#line 531 "DomGDocumentTest.vala"
		_tmp4_ = gxml_dom_document_create_text_node (_tmp3_, "TEXT", &_inner_error0_);
#line 531 "DomGDocumentTest.vala"
		_tmp2_ = _tmp4_;
#line 531 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 531 "DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8069 "DomGDocumentTest.c"
			goto __catch69_g_error;
		}
#line 531 "DomGDocumentTest.vala"
		_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, GXML_TYPE_DOM_CHARACTER_DATA) ? ((GXmlDomCharacterData*) _tmp2_) : NULL);
#line 531 "DomGDocumentTest.vala"
		t = _tmp5_;
#line 532 "DomGDocumentTest.vala"
		_tmp6_ = t;
#line 532 "DomGDocumentTest.vala"
		_tmp7_ = gxml_dom_character_data_get_data (_tmp6_);
#line 532 "DomGDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 532 "DomGDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 532 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp9_, "TEXT") == 0, "t.data == \"TEXT\"");
#line 532 "DomGDocumentTest.vala"
		_g_free0 (_tmp9_);
#line 533 "DomGDocumentTest.vala"
		_tmp10_ = t;
#line 533 "DomGDocumentTest.vala"
		_tmp11_ = gxml_dom_character_data_get_length (_tmp10_);
#line 533 "DomGDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 533 "DomGDocumentTest.vala"
		_tmp13_ = strlen ("TEXT");
#line 533 "DomGDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 533 "DomGDocumentTest.vala"
		_vala_assert (_tmp12_ == _tmp14_, "t.length == \"TEXT\".length");
#line 534 "DomGDocumentTest.vala"
		_tmp16_ = t;
#line 534 "DomGDocumentTest.vala"
		_tmp17_ = gxml_dom_character_data_substring_data (_tmp16_, 0, 2, &_inner_error0_);
#line 534 "DomGDocumentTest.vala"
		_tmp15_ = _tmp17_;
#line 534 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 534 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 534 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 534 "DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8114 "DomGDocumentTest.c"
			goto __catch69_g_error;
		}
#line 534 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp15_, "TE") == 0, "t.substring_data (0,2) == \"TE\"");
#line 535 "DomGDocumentTest.vala"
		_tmp19_ = t;
#line 535 "DomGDocumentTest.vala"
		_tmp20_ = gxml_dom_character_data_substring_data (_tmp19_, 0, 3, &_inner_error0_);
#line 535 "DomGDocumentTest.vala"
		_tmp18_ = _tmp20_;
#line 535 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 535 "DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 535 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 535 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 535 "DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8135 "DomGDocumentTest.c"
			goto __catch69_g_error;
		}
#line 535 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp18_, "TEX") == 0, "t.substring_data (0,3) == \"TEX\"");
#line 536 "DomGDocumentTest.vala"
		_tmp22_ = t;
#line 536 "DomGDocumentTest.vala"
		_tmp23_ = gxml_dom_character_data_substring_data (_tmp22_, 1, 3, &_inner_error0_);
#line 536 "DomGDocumentTest.vala"
		_tmp21_ = _tmp23_;
#line 536 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 536 "DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 536 "DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 536 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 536 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 536 "DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8158 "DomGDocumentTest.c"
			goto __catch69_g_error;
		}
#line 536 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp21_, "EXT") == 0, "t.substring_data (1,3) == \"EXT\"");
#line 537 "DomGDocumentTest.vala"
		_tmp25_ = t;
#line 537 "DomGDocumentTest.vala"
		_tmp26_ = gxml_dom_character_data_substring_data (_tmp25_, 1, 4, &_inner_error0_);
#line 537 "DomGDocumentTest.vala"
		_tmp24_ = _tmp26_;
#line 537 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 537 "DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 537 "DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 537 "DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 537 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 537 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 537 "DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8183 "DomGDocumentTest.c"
			goto __catch69_g_error;
		}
#line 537 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp24_, "EXT") == 0, "t.substring_data (1,4) == \"EXT\"");
#line 538 "DomGDocumentTest.vala"
		_tmp28_ = t;
#line 538 "DomGDocumentTest.vala"
		_tmp29_ = gxml_dom_character_data_substring_data (_tmp28_, 1, 5, &_inner_error0_);
#line 538 "DomGDocumentTest.vala"
		_tmp27_ = _tmp29_;
#line 538 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 538 "DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 538 "DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 538 "DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 538 "DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 538 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 538 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 538 "DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8210 "DomGDocumentTest.c"
			goto __catch69_g_error;
		}
#line 538 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp27_, "EXT") == 0, "t.substring_data (1,5) == \"EXT\"");
#line 539 "DomGDocumentTest.vala"
		_tmp31_ = t;
#line 539 "DomGDocumentTest.vala"
		_tmp32_ = gxml_dom_character_data_substring_data (_tmp31_, 2, 0, &_inner_error0_);
#line 539 "DomGDocumentTest.vala"
		_tmp30_ = _tmp32_;
#line 539 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 539 "DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 539 "DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 539 "DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 539 "DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 539 "DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 539 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 539 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 539 "DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8239 "DomGDocumentTest.c"
			goto __catch69_g_error;
		}
#line 539 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp30_, "") == 0, "t.substring_data (2,0) == \"\"");
#line 8244 "DomGDocumentTest.c"
		{
			GXmlDomCharacterData* _tmp33_;
			gchar* _tmp34_;
			gchar* _tmp35_;
#line 541 "DomGDocumentTest.vala"
			_tmp33_ = t;
#line 541 "DomGDocumentTest.vala"
			_tmp34_ = gxml_dom_character_data_substring_data (_tmp33_, 5, 1, &_inner_error0_);
#line 541 "DomGDocumentTest.vala"
			_tmp35_ = _tmp34_;
#line 541 "DomGDocumentTest.vala"
			_g_free0 (_tmp35_);
#line 541 "DomGDocumentTest.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 8259 "DomGDocumentTest.c"
				goto __catch70_g_error;
			}
#line 542 "DomGDocumentTest.vala"
			g_assert_not_reached ();
#line 8264 "DomGDocumentTest.c"
		}
		goto __finally70;
		__catch70_g_error:
		{
#line 540 "DomGDocumentTest.vala"
			g_clear_error (&_inner_error0_);
#line 540 "DomGDocumentTest.vala"
			_inner_error0_ = NULL;
#line 8273 "DomGDocumentTest.c"
		}
		__finally70:
#line 540 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 540 "DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 540 "DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 540 "DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 540 "DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 540 "DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 540 "DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 540 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 540 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 540 "DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8296 "DomGDocumentTest.c"
			goto __catch69_g_error;
		}
#line 545 "DomGDocumentTest.vala"
		_tmp36_ = t;
#line 545 "DomGDocumentTest.vala"
		gxml_dom_character_data_append_data (_tmp36_, " HI");
#line 546 "DomGDocumentTest.vala"
		_tmp37_ = t;
#line 546 "DomGDocumentTest.vala"
		_tmp38_ = gxml_dom_character_data_get_data (_tmp37_);
#line 546 "DomGDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 546 "DomGDocumentTest.vala"
		_tmp40_ = _tmp39_;
#line 546 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp40_, "TEXT HI") == 0, "t.data == \"TEXT HI\"");
#line 546 "DomGDocumentTest.vala"
		_g_free0 (_tmp40_);
#line 547 "DomGDocumentTest.vala"
		_tmp41_ = t;
#line 547 "DomGDocumentTest.vala"
		gxml_dom_character_data_replace_data (_tmp41_, 0, 4, "", &_inner_error0_);
#line 547 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 547 "DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 547 "DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 547 "DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 547 "DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 547 "DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 547 "DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 547 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 547 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 547 "DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8339 "DomGDocumentTest.c"
			goto __catch69_g_error;
		}
#line 548 "DomGDocumentTest.vala"
		_tmp42_ = t;
#line 548 "DomGDocumentTest.vala"
		_tmp43_ = gxml_dom_character_data_get_data (_tmp42_);
#line 548 "DomGDocumentTest.vala"
		_tmp44_ = _tmp43_;
#line 548 "DomGDocumentTest.vala"
		_tmp45_ = _tmp44_;
#line 548 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp45_, " HI") == 0, "t.data == \" HI\"");
#line 548 "DomGDocumentTest.vala"
		_g_free0 (_tmp45_);
#line 549 "DomGDocumentTest.vala"
		_tmp46_ = t;
#line 549 "DomGDocumentTest.vala"
		gxml_dom_character_data_insert_data (_tmp46_, 0, "TEXT", &_inner_error0_);
#line 549 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 549 "DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 549 "DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 549 "DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 549 "DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 549 "DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 549 "DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 549 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 549 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 549 "DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8378 "DomGDocumentTest.c"
			goto __catch69_g_error;
		}
#line 550 "DomGDocumentTest.vala"
		_tmp47_ = t;
#line 550 "DomGDocumentTest.vala"
		_tmp48_ = gxml_dom_character_data_get_data (_tmp47_);
#line 550 "DomGDocumentTest.vala"
		_tmp49_ = _tmp48_;
#line 550 "DomGDocumentTest.vala"
		_tmp50_ = _tmp49_;
#line 550 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp50_, "TEXT HI") == 0, "t.data == \"TEXT HI\"");
#line 550 "DomGDocumentTest.vala"
		_g_free0 (_tmp50_);
#line 551 "DomGDocumentTest.vala"
		_tmp51_ = t;
#line 551 "DomGDocumentTest.vala"
		gxml_dom_character_data_delete_data (_tmp51_, 0, 4, &_inner_error0_);
#line 551 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 551 "DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 551 "DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 551 "DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 551 "DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 551 "DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 551 "DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 551 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 551 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 551 "DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8417 "DomGDocumentTest.c"
			goto __catch69_g_error;
		}
#line 552 "DomGDocumentTest.vala"
		_tmp52_ = t;
#line 552 "DomGDocumentTest.vala"
		_tmp53_ = gxml_dom_character_data_get_data (_tmp52_);
#line 552 "DomGDocumentTest.vala"
		_tmp54_ = _tmp53_;
#line 552 "DomGDocumentTest.vala"
		_tmp55_ = _tmp54_;
#line 552 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp55_, " HI") == 0, "t.data == \" HI\"");
#line 552 "DomGDocumentTest.vala"
		_g_free0 (_tmp55_);
#line 553 "DomGDocumentTest.vala"
		_tmp56_ = t;
#line 553 "DomGDocumentTest.vala"
		gxml_dom_character_data_insert_data (_tmp56_, 0, "TEXT", &_inner_error0_);
#line 553 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 553 "DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 553 "DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 553 "DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 553 "DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 553 "DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 553 "DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 553 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 553 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 553 "DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8456 "DomGDocumentTest.c"
			goto __catch69_g_error;
		}
#line 554 "DomGDocumentTest.vala"
		_tmp57_ = t;
#line 554 "DomGDocumentTest.vala"
		_tmp58_ = gxml_dom_character_data_get_data (_tmp57_);
#line 554 "DomGDocumentTest.vala"
		_tmp59_ = _tmp58_;
#line 554 "DomGDocumentTest.vala"
		_tmp60_ = _tmp59_;
#line 554 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp60_, "TEXT HI") == 0, "t.data == \"TEXT HI\"");
#line 554 "DomGDocumentTest.vala"
		_g_free0 (_tmp60_);
#line 555 "DomGDocumentTest.vala"
		_tmp61_ = t;
#line 555 "DomGDocumentTest.vala"
		gxml_dom_character_data_replace_data (_tmp61_, 0, 4, "text", &_inner_error0_);
#line 555 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 555 "DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 555 "DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 555 "DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 555 "DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 555 "DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 555 "DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 555 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 555 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 555 "DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8495 "DomGDocumentTest.c"
			goto __catch69_g_error;
		}
#line 556 "DomGDocumentTest.vala"
		_tmp62_ = t;
#line 556 "DomGDocumentTest.vala"
		_tmp63_ = gxml_dom_character_data_get_data (_tmp62_);
#line 556 "DomGDocumentTest.vala"
		_tmp64_ = _tmp63_;
#line 556 "DomGDocumentTest.vala"
		_tmp65_ = _tmp64_;
#line 556 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp65_, "text HI") == 0, "t.data == \"text HI\"");
#line 556 "DomGDocumentTest.vala"
		_g_free0 (_tmp65_);
#line 557 "DomGDocumentTest.vala"
		_tmp66_ = d;
#line 557 "DomGDocumentTest.vala"
		_tmp67_ = gxml_dom_document_create_element (_tmp66_, "node", &_inner_error0_);
#line 557 "DomGDocumentTest.vala"
		n = _tmp67_;
#line 557 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 557 "DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 557 "DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 557 "DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 557 "DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 557 "DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 557 "DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 557 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 557 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 557 "DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8536 "DomGDocumentTest.c"
			goto __catch69_g_error;
		}
#line 558 "DomGDocumentTest.vala"
		_tmp68_ = d;
#line 558 "DomGDocumentTest.vala"
		_tmp69_ = n;
#line 558 "DomGDocumentTest.vala"
		_tmp70_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp68_, (GXmlDomNode*) _tmp69_, &_inner_error0_);
#line 558 "DomGDocumentTest.vala"
		_tmp71_ = _tmp70_;
#line 558 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp71_);
#line 558 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 558 "DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 558 "DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 558 "DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 558 "DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 558 "DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 558 "DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 558 "DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 558 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 558 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 558 "DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8571 "DomGDocumentTest.c"
			goto __catch69_g_error;
		}
#line 559 "DomGDocumentTest.vala"
		_tmp72_ = n;
#line 559 "DomGDocumentTest.vala"
		_tmp73_ = t;
#line 559 "DomGDocumentTest.vala"
		_tmp74_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp72_, (GXmlDomNode*) _tmp73_, &_inner_error0_);
#line 559 "DomGDocumentTest.vala"
		_tmp75_ = _tmp74_;
#line 559 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp75_);
#line 559 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 559 "DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 559 "DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 559 "DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 559 "DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 559 "DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 559 "DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 559 "DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 559 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 559 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 559 "DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8606 "DomGDocumentTest.c"
			goto __catch69_g_error;
		}
#line 560 "DomGDocumentTest.vala"
		_tmp76_ = t;
#line 560 "DomGDocumentTest.vala"
		_tmp77_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp76_);
#line 560 "DomGDocumentTest.vala"
		_tmp78_ = _tmp77_;
#line 560 "DomGDocumentTest.vala"
		_tmp79_ = _tmp78_;
#line 560 "DomGDocumentTest.vala"
		_tmp80_ = gxml_dom_node_get_child_nodes (_tmp79_);
#line 560 "DomGDocumentTest.vala"
		_tmp81_ = _tmp80_;
#line 560 "DomGDocumentTest.vala"
		_tmp82_ = _tmp81_;
#line 560 "DomGDocumentTest.vala"
		_tmp83_ = gxml_dom_node_list_get_length (_tmp82_);
#line 560 "DomGDocumentTest.vala"
		_tmp84_ = _tmp83_;
#line 560 "DomGDocumentTest.vala"
		_vala_assert (_tmp84_ == 1, "t.parent_node.child_nodes.length == 1");
#line 560 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp82_);
#line 560 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp79_);
#line 561 "DomGDocumentTest.vala"
		_tmp85_ = t;
#line 561 "DomGDocumentTest.vala"
		_tmp86_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp85_);
#line 561 "DomGDocumentTest.vala"
		_tmp87_ = _tmp86_;
#line 561 "DomGDocumentTest.vala"
		_tmp88_ = _tmp87_;
#line 561 "DomGDocumentTest.vala"
		_tmp89_ = gxml_dom_node_get_child_nodes (_tmp88_);
#line 561 "DomGDocumentTest.vala"
		_tmp90_ = _tmp89_;
#line 561 "DomGDocumentTest.vala"
		_tmp91_ = _tmp90_;
#line 561 "DomGDocumentTest.vala"
		_tmp92_ = gxml_dom_node_list_get_length (_tmp91_);
#line 561 "DomGDocumentTest.vala"
		_tmp93_ = _tmp92_;
#line 561 "DomGDocumentTest.vala"
		_vala_assert (_tmp93_ == 1, "t.parent_node.child_nodes.length == 1");
#line 561 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp91_);
#line 561 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp88_);
#line 562 "DomGDocumentTest.vala"
		_tmp94_ = d;
#line 562 "DomGDocumentTest.vala"
		_tmp95_ = gxml_dom_document_create_element (_tmp94_, "child", &_inner_error0_);
#line 562 "DomGDocumentTest.vala"
		ntst = _tmp95_;
#line 562 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 562 "DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 562 "DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 562 "DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 562 "DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 562 "DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 562 "DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 562 "DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 562 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 562 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 562 "DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8685 "DomGDocumentTest.c"
			goto __catch69_g_error;
		}
#line 563 "DomGDocumentTest.vala"
		_tmp96_ = n;
#line 563 "DomGDocumentTest.vala"
		_tmp97_ = ntst;
#line 563 "DomGDocumentTest.vala"
		_tmp98_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp96_, (GXmlDomNode*) _tmp97_, &_inner_error0_);
#line 563 "DomGDocumentTest.vala"
		_tmp99_ = _tmp98_;
#line 563 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp99_);
#line 563 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 563 "DomGDocumentTest.vala"
			_g_object_unref0 (ntst);
#line 563 "DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 563 "DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 563 "DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 563 "DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 563 "DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 563 "DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 563 "DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 563 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 563 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 563 "DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8722 "DomGDocumentTest.c"
			goto __catch69_g_error;
		}
#line 564 "DomGDocumentTest.vala"
		_tmp100_ = d;
#line 564 "DomGDocumentTest.vala"
		_tmp101_ = gxml_dom_document_create_text_node (_tmp100_, "TEXT1", &_inner_error0_);
#line 564 "DomGDocumentTest.vala"
		ct1 = _tmp101_;
#line 564 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 564 "DomGDocumentTest.vala"
			_g_object_unref0 (ntst);
#line 564 "DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 564 "DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 564 "DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 564 "DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 564 "DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 564 "DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 564 "DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 564 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 564 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 564 "DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8755 "DomGDocumentTest.c"
			goto __catch69_g_error;
		}
#line 565 "DomGDocumentTest.vala"
		_tmp102_ = ntst;
#line 565 "DomGDocumentTest.vala"
		_tmp103_ = ct1;
#line 565 "DomGDocumentTest.vala"
		_tmp104_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp102_, (GXmlDomNode*) _tmp103_, &_inner_error0_);
#line 565 "DomGDocumentTest.vala"
		_tmp105_ = _tmp104_;
#line 565 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp105_);
#line 565 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 565 "DomGDocumentTest.vala"
			_g_object_unref0 (ct1);
#line 565 "DomGDocumentTest.vala"
			_g_object_unref0 (ntst);
#line 565 "DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 565 "DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 565 "DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 565 "DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 565 "DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 565 "DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 565 "DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 565 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 565 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 565 "DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8794 "DomGDocumentTest.c"
			goto __catch69_g_error;
		}
#line 566 "DomGDocumentTest.vala"
		_tmp106_ = ntst;
#line 566 "DomGDocumentTest.vala"
		_tmp107_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp106_);
#line 566 "DomGDocumentTest.vala"
		_tmp108_ = _tmp107_;
#line 566 "DomGDocumentTest.vala"
		_tmp109_ = _tmp108_;
#line 566 "DomGDocumentTest.vala"
		_tmp110_ = gxml_dom_node_list_get_length (_tmp109_);
#line 566 "DomGDocumentTest.vala"
		_tmp111_ = _tmp110_;
#line 566 "DomGDocumentTest.vala"
		_vala_assert (_tmp111_ == 1, "ntst.child_nodes.length == 1");
#line 566 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp109_);
#line 567 "DomGDocumentTest.vala"
		_tmp112_ = d;
#line 567 "DomGDocumentTest.vala"
		_tmp113_ = gxml_dom_document_create_text_node (_tmp112_, "TEXT2", &_inner_error0_);
#line 567 "DomGDocumentTest.vala"
		ct2 = _tmp113_;
#line 567 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 567 "DomGDocumentTest.vala"
			_g_object_unref0 (ct1);
#line 567 "DomGDocumentTest.vala"
			_g_object_unref0 (ntst);
#line 567 "DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 567 "DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 567 "DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 567 "DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 567 "DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 567 "DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 567 "DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 567 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 567 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 567 "DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8845 "DomGDocumentTest.c"
			goto __catch69_g_error;
		}
#line 568 "DomGDocumentTest.vala"
		_tmp114_ = ntst;
#line 568 "DomGDocumentTest.vala"
		_tmp115_ = ct2;
#line 568 "DomGDocumentTest.vala"
		_tmp116_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp114_, (GXmlDomNode*) _tmp115_, &_inner_error0_);
#line 568 "DomGDocumentTest.vala"
		_tmp117_ = _tmp116_;
#line 568 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp117_);
#line 568 "DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 568 "DomGDocumentTest.vala"
			_g_object_unref0 (ct2);
#line 568 "DomGDocumentTest.vala"
			_g_object_unref0 (ct1);
#line 568 "DomGDocumentTest.vala"
			_g_object_unref0 (ntst);
#line 568 "DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 568 "DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 568 "DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 568 "DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 568 "DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 568 "DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 568 "DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 568 "DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 568 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 568 "DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8886 "DomGDocumentTest.c"
			goto __catch69_g_error;
		}
#line 576 "DomGDocumentTest.vala"
		_tmp118_ = ntst;
#line 576 "DomGDocumentTest.vala"
		_tmp119_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp118_);
#line 576 "DomGDocumentTest.vala"
		_tmp120_ = _tmp119_;
#line 576 "DomGDocumentTest.vala"
		_tmp121_ = _tmp120_;
#line 576 "DomGDocumentTest.vala"
		_tmp122_ = gxml_dom_node_list_item (_tmp121_, 0);
#line 576 "DomGDocumentTest.vala"
		_tmp123_ = _tmp122_;
#line 576 "DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp123_, GXML_TYPE_DOM_TEXT), "ntst.child_nodes.item (0) is DomText");
#line 576 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp123_);
#line 576 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp121_);
#line 577 "DomGDocumentTest.vala"
		_tmp124_ = ntst;
#line 577 "DomGDocumentTest.vala"
		_tmp125_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp124_);
#line 577 "DomGDocumentTest.vala"
		_tmp126_ = _tmp125_;
#line 577 "DomGDocumentTest.vala"
		_tmp127_ = _tmp126_;
#line 577 "DomGDocumentTest.vala"
		_tmp128_ = gxml_dom_node_list_item (_tmp127_, 0);
#line 577 "DomGDocumentTest.vala"
		_tmp129_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp128_, GXML_TYPE_DOM_TEXT) ? ((GXmlDomText*) _tmp128_) : NULL;
#line 577 "DomGDocumentTest.vala"
		if (_tmp129_ == NULL) {
#line 577 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp128_);
#line 8923 "DomGDocumentTest.c"
		}
#line 577 "DomGDocumentTest.vala"
		_tmp130_ = _tmp129_;
#line 577 "DomGDocumentTest.vala"
		_tmp131_ = gxml_dom_character_data_get_data ((GXmlDomCharacterData*) _tmp130_);
#line 577 "DomGDocumentTest.vala"
		_tmp132_ = _tmp131_;
#line 577 "DomGDocumentTest.vala"
		_tmp133_ = _tmp132_;
#line 577 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp133_, "TEXT1TEXT2") == 0, "(ntst.child_nodes.item (0) as DomText).data == \"TEXT1TEXT2\"");
#line 577 "DomGDocumentTest.vala"
		_g_free0 (_tmp133_);
#line 577 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp130_);
#line 577 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp127_);
#line 579 "DomGDocumentTest.vala"
		_tmp134_ = ntst;
#line 579 "DomGDocumentTest.vala"
		_tmp135_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp134_);
#line 579 "DomGDocumentTest.vala"
		_tmp136_ = _tmp135_;
#line 579 "DomGDocumentTest.vala"
		_tmp137_ = _tmp136_;
#line 579 "DomGDocumentTest.vala"
		_tmp138_ = gxml_dom_node_list_item (_tmp137_, 0);
#line 579 "DomGDocumentTest.vala"
		_tmp139_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp138_, GXML_TYPE_DOM_TEXT) ? ((GXmlDomText*) _tmp138_) : NULL;
#line 579 "DomGDocumentTest.vala"
		if (_tmp139_ == NULL) {
#line 579 "DomGDocumentTest.vala"
			_g_object_unref0 (_tmp138_);
#line 8957 "DomGDocumentTest.c"
		}
#line 579 "DomGDocumentTest.vala"
		_tmp140_ = _tmp139_;
#line 579 "DomGDocumentTest.vala"
		_tmp141_ = gxml_dom_text_get_whole_text (_tmp140_);
#line 579 "DomGDocumentTest.vala"
		_tmp142_ = _tmp141_;
#line 579 "DomGDocumentTest.vala"
		_tmp143_ = _tmp142_;
#line 579 "DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp143_, "TEXT1TEXT2") == 0, "(ntst.child_nodes.item(0) as DomText).whole_text == \"TEXT1TEXT2\"");
#line 579 "DomGDocumentTest.vala"
		_g_free0 (_tmp143_);
#line 579 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp140_);
#line 579 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp137_);
#line 529 "DomGDocumentTest.vala"
		_g_object_unref0 (ct2);
#line 529 "DomGDocumentTest.vala"
		_g_object_unref0 (ct1);
#line 529 "DomGDocumentTest.vala"
		_g_object_unref0 (ntst);
#line 529 "DomGDocumentTest.vala"
		_g_object_unref0 (n);
#line 529 "DomGDocumentTest.vala"
		_g_free0 (_tmp30_);
#line 529 "DomGDocumentTest.vala"
		_g_free0 (_tmp27_);
#line 529 "DomGDocumentTest.vala"
		_g_free0 (_tmp24_);
#line 529 "DomGDocumentTest.vala"
		_g_free0 (_tmp21_);
#line 529 "DomGDocumentTest.vala"
		_g_free0 (_tmp18_);
#line 529 "DomGDocumentTest.vala"
		_g_free0 (_tmp15_);
#line 529 "DomGDocumentTest.vala"
		_g_object_unref0 (t);
#line 529 "DomGDocumentTest.vala"
		_g_object_unref0 (_tmp2_);
#line 529 "DomGDocumentTest.vala"
		_g_object_unref0 (d);
#line 9001 "DomGDocumentTest.c"
	}
	goto __finally69;
	__catch69_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp144_;
		gchar* _tmp145_;
		gchar* _tmp146_;
#line 529 "DomGDocumentTest.vala"
		e = _inner_error0_;
#line 529 "DomGDocumentTest.vala"
		_inner_error0_ = NULL;
#line 581 "DomGDocumentTest.vala"
		_tmp144_ = e->message;
#line 581 "DomGDocumentTest.vala"
		_tmp145_ = g_strconcat ("Error: ", _tmp144_, NULL);
#line 581 "DomGDocumentTest.vala"
		_tmp146_ = _tmp145_;
#line 581 "DomGDocumentTest.vala"
		g_message ("DomGDocumentTest.vala:581: %s", _tmp146_);
#line 581 "DomGDocumentTest.vala"
		_g_free0 (_tmp146_);
#line 582 "DomGDocumentTest.vala"
		g_assert_not_reached ();
#line 529 "DomGDocumentTest.vala"
		_g_error_free0 (e);
#line 9028 "DomGDocumentTest.c"
	}
	__finally69:
#line 529 "DomGDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 529 "DomGDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 529 "DomGDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 529 "DomGDocumentTest.vala"
		return;
#line 9039 "DomGDocumentTest.c"
	}
}

static void
___lambda59__gtest_func (void)
{
#line 528 "DomGDocumentTest.vala"
	__lambda59_ ();
#line 9048 "DomGDocumentTest.c"
}

void
dom_gdocument_test_add_tests (void)
{
#line 69 "DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/document/children", ___lambda46__gtest_func);
#line 89 "DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/document/child_nodes", ___lambda47__gtest_func);
#line 112 "DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/document/element_collections", ___lambda48__gtest_func);
#line 139 "DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/element/element_collections", ___lambda49__gtest_func);
#line 167 "DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/node", ___lambda50__gtest_func);
#line 338 "DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/element/api", ___lambda51__gtest_func);
#line 400 "DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/document/api", ___lambda52__gtest_func);
#line 475 "DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/document/import", ___lambda53__gtest_func);
#line 495 "DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/document/adopt", ___lambda54__gtest_func);
#line 516 "DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/document/event", ___lambda55__gtest_func);
#line 519 "DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/document/range", ___lambda56__gtest_func);
#line 522 "DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/document/iterator", ___lambda57__gtest_func);
#line 525 "DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/document/walker", ___lambda58__gtest_func);
#line 528 "DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/character", ___lambda59__gtest_func);
#line 9082 "DomGDocumentTest.c"
}

DomGDocumentTest*
dom_gdocument_test_construct (GType object_type)
{
	DomGDocumentTest* self = NULL;
#line 25 "DomGDocumentTest.vala"
	self = (DomGDocumentTest*) gxml_test_construct (object_type);
#line 25 "DomGDocumentTest.vala"
	return self;
#line 9093 "DomGDocumentTest.c"
}

DomGDocumentTest*
dom_gdocument_test_new (void)
{
#line 25 "DomGDocumentTest.vala"
	return dom_gdocument_test_construct (TYPE_DOM_GDOCUMENT_TEST);
#line 9101 "DomGDocumentTest.c"
}

static void
dom_gdocument_test_class_init (DomGDocumentTestClass * klass,
                               gpointer klass_data)
{
#line 25 "DomGDocumentTest.vala"
	dom_gdocument_test_parent_class = g_type_class_peek_parent (klass);
#line 9110 "DomGDocumentTest.c"
}

static void
dom_gdocument_test_instance_init (DomGDocumentTest * self,
                                  gpointer klass)
{
}

GType
dom_gdocument_test_get_type (void)
{
	static volatile gsize dom_gdocument_test_type_id__volatile = 0;
	if (g_once_init_enter (&dom_gdocument_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DomGDocumentTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) dom_gdocument_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DomGDocumentTest), 0, (GInstanceInitFunc) dom_gdocument_test_instance_init, NULL };
		GType dom_gdocument_test_type_id;
		dom_gdocument_test_type_id = g_type_register_static (TYPE_GXML_TEST, "DomGDocumentTest", &g_define_type_info, 0);
		g_once_init_leave (&dom_gdocument_test_type_id__volatile, dom_gdocument_test_type_id);
	}
	return dom_gdocument_test_type_id__volatile;
}

