/* SerializableGeeHashMapTest.c generated by valac 0.44.3, the Vala compiler
 * generated from SerializableGeeHashMapTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */

#include <glib-object.h>
#include <glib.h>
#include <gxml/gxml.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_SERIALIZABLE_GEE_HASH_MAP_TEST (serializable_gee_hash_map_test_get_type ())
#define SERIALIZABLE_GEE_HASH_MAP_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_GEE_HASH_MAP_TEST, SerializableGeeHashMapTest))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_GEE_HASH_MAP_TEST, SerializableGeeHashMapTestClass))
#define IS_SERIALIZABLE_GEE_HASH_MAP_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_GEE_HASH_MAP_TEST))
#define IS_SERIALIZABLE_GEE_HASH_MAP_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_GEE_HASH_MAP_TEST))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_GEE_HASH_MAP_TEST, SerializableGeeHashMapTestClass))

typedef struct _SerializableGeeHashMapTest SerializableGeeHashMapTest;
typedef struct _SerializableGeeHashMapTestClass SerializableGeeHashMapTestClass;
typedef struct _SerializableGeeHashMapTestPrivate SerializableGeeHashMapTestPrivate;

#define SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE (serializable_gee_hash_map_test_space_get_type ())
#define SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE, SerializableGeeHashMapTestSpace))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE, SerializableGeeHashMapTestSpaceClass))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_IS_SPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_IS_SPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE, SerializableGeeHashMapTestSpaceClass))

typedef struct _SerializableGeeHashMapTestSpace SerializableGeeHashMapTestSpace;
typedef struct _SerializableGeeHashMapTestSpaceClass SerializableGeeHashMapTestSpaceClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE_CONTAINER (serializable_gee_hash_map_test_space_container_get_type ())
#define SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_CONTAINER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE_CONTAINER, SerializableGeeHashMapTestSpaceContainer))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_CONTAINER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE_CONTAINER, SerializableGeeHashMapTestSpaceContainerClass))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_IS_SPACE_CONTAINER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE_CONTAINER))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_IS_SPACE_CONTAINER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE_CONTAINER))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_CONTAINER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE_CONTAINER, SerializableGeeHashMapTestSpaceContainerClass))

typedef struct _SerializableGeeHashMapTestSpaceContainer SerializableGeeHashMapTestSpaceContainer;
typedef struct _SerializableGeeHashMapTestSpaceContainerClass SerializableGeeHashMapTestSpaceContainerClass;

#define SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_TYPE_COLLECTION (serializable_gee_hash_map_test_space_collection_get_type ())
#define SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_TYPE_COLLECTION, SerializableGeeHashMapTestSpaceCollection))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_TYPE_COLLECTION, SerializableGeeHashMapTestSpaceCollectionClass))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_TYPE_COLLECTION))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_TYPE_COLLECTION))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_TYPE_COLLECTION, SerializableGeeHashMapTestSpaceCollectionClass))

typedef struct _SerializableGeeHashMapTestSpaceCollection SerializableGeeHashMapTestSpaceCollection;
typedef struct _SerializableGeeHashMapTestSpaceCollectionClass SerializableGeeHashMapTestSpaceCollectionClass;

#define TYPE_BOOK_STORE (book_store_get_type ())
#define BOOK_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BOOK_STORE, BookStore))
#define BOOK_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BOOK_STORE, BookStoreClass))
#define IS_BOOK_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BOOK_STORE))
#define IS_BOOK_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BOOK_STORE))
#define BOOK_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BOOK_STORE, BookStoreClass))

typedef struct _BookStore BookStore;
typedef struct _BookStoreClass BookStoreClass;

#define BOOK_TYPE_ARRAY (book_array_get_type ())
#define BOOK_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOOK_TYPE_ARRAY, BookArray))
#define BOOK_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOOK_TYPE_ARRAY, BookArrayClass))
#define BOOK_IS_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOOK_TYPE_ARRAY))
#define BOOK_IS_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOOK_TYPE_ARRAY))
#define BOOK_ARRAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOOK_TYPE_ARRAY, BookArrayClass))

typedef struct _BookArray BookArray;
typedef struct _BookArrayClass BookArrayClass;

#define TYPE_BOOK (book_get_type ())
#define BOOK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BOOK, Book))
#define BOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BOOK, BookClass))
#define IS_BOOK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BOOK))
#define IS_BOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BOOK))
#define BOOK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BOOK, BookClass))

typedef struct _Book Book;
typedef struct _BookClass BookClass;

#define TYPE_NAME (name_get_type ())
#define NAME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_NAME, Name))
#define NAME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_NAME, NameClass))
#define IS_NAME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_NAME))
#define IS_NAME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_NAME))
#define NAME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_NAME, NameClass))

typedef struct _Name Name;
typedef struct _NameClass NameClass;

#define TYPE_AUTHORS (authors_get_type ())
#define AUTHORS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_AUTHORS, Authors))
#define AUTHORS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_AUTHORS, AuthorsClass))
#define IS_AUTHORS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_AUTHORS))
#define IS_AUTHORS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_AUTHORS))
#define AUTHORS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_AUTHORS, AuthorsClass))

typedef struct _Authors Authors;
typedef struct _AuthorsClass AuthorsClass;

#define AUTHOR_TYPE_ARRAY (author_array_get_type ())
#define AUTHOR_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), AUTHOR_TYPE_ARRAY, AuthorArray))
#define AUTHOR_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), AUTHOR_TYPE_ARRAY, AuthorArrayClass))
#define AUTHOR_IS_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), AUTHOR_TYPE_ARRAY))
#define AUTHOR_IS_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), AUTHOR_TYPE_ARRAY))
#define AUTHOR_ARRAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), AUTHOR_TYPE_ARRAY, AuthorArrayClass))

typedef struct _AuthorArray AuthorArray;
typedef struct _AuthorArrayClass AuthorArrayClass;

#define CATEGORY_TYPE_MAP (category_map_get_type ())
#define CATEGORY_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CATEGORY_TYPE_MAP, CategoryMap))
#define CATEGORY_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CATEGORY_TYPE_MAP, CategoryMapClass))
#define CATEGORY_IS_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CATEGORY_TYPE_MAP))
#define CATEGORY_IS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CATEGORY_TYPE_MAP))
#define CATEGORY_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CATEGORY_TYPE_MAP, CategoryMapClass))

typedef struct _CategoryMap CategoryMap;
typedef struct _CategoryMapClass CategoryMapClass;

#define TYPE_CATEGORY (category_get_type ())
#define CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CATEGORY, Category))
#define CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CATEGORY, CategoryClass))
#define IS_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CATEGORY))
#define IS_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CATEGORY))
#define CATEGORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CATEGORY, CategoryClass))

typedef struct _Category Category;
typedef struct _CategoryClass CategoryClass;

#define SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BIG_BAG (serializable_gee_hash_map_test_big_bag_get_type ())
#define SERIALIZABLE_GEE_HASH_MAP_TEST_BIG_BAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BIG_BAG, SerializableGeeHashMapTestBigBag))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_BIG_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BIG_BAG, SerializableGeeHashMapTestBigBagClass))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_IS_BIG_BAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BIG_BAG))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_IS_BIG_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BIG_BAG))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_BIG_BAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BIG_BAG, SerializableGeeHashMapTestBigBagClass))

typedef struct _SerializableGeeHashMapTestBigBag SerializableGeeHashMapTestBigBag;
typedef struct _SerializableGeeHashMapTestBigBagClass SerializableGeeHashMapTestBigBagClass;

#define SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_TYPE_HASH_MAP (serializable_gee_hash_map_test_small_bag_hash_map_get_type ())
#define SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_HASH_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_TYPE_HASH_MAP, SerializableGeeHashMapTestSmallBagHashMap))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_HASH_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_TYPE_HASH_MAP, SerializableGeeHashMapTestSmallBagHashMapClass))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_IS_HASH_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_TYPE_HASH_MAP))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_IS_HASH_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_TYPE_HASH_MAP))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_HASH_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_TYPE_HASH_MAP, SerializableGeeHashMapTestSmallBagHashMapClass))

typedef struct _SerializableGeeHashMapTestSmallBagHashMap SerializableGeeHashMapTestSmallBagHashMap;
typedef struct _SerializableGeeHashMapTestSmallBagHashMapClass SerializableGeeHashMapTestSmallBagHashMapClass;

#define SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SMALL_BAG (serializable_gee_hash_map_test_small_bag_get_type ())
#define SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeHashMapTestSmallBag))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeHashMapTestSmallBagClass))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_IS_SMALL_BAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SMALL_BAG))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_IS_SMALL_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SMALL_BAG))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeHashMapTestSmallBagClass))

typedef struct _SerializableGeeHashMapTestSmallBag SerializableGeeHashMapTestSmallBag;
typedef struct _SerializableGeeHashMapTestSmallBagClass SerializableGeeHashMapTestSmallBagClass;

#define SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_TYPE_HASH_MAP (serializable_gee_hash_map_test_ball_hash_map_get_type ())
#define SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_HASH_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_TYPE_HASH_MAP, SerializableGeeHashMapTestBallHashMap))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_HASH_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_TYPE_HASH_MAP, SerializableGeeHashMapTestBallHashMapClass))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_IS_HASH_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_TYPE_HASH_MAP))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_IS_HASH_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_TYPE_HASH_MAP))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_HASH_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_TYPE_HASH_MAP, SerializableGeeHashMapTestBallHashMapClass))

typedef struct _SerializableGeeHashMapTestBallHashMap SerializableGeeHashMapTestBallHashMap;
typedef struct _SerializableGeeHashMapTestBallHashMapClass SerializableGeeHashMapTestBallHashMapClass;

#define SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BALL (serializable_gee_hash_map_test_ball_get_type ())
#define SERIALIZABLE_GEE_HASH_MAP_TEST_BALL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BALL, SerializableGeeHashMapTestBall))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BALL, SerializableGeeHashMapTestBallClass))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_IS_BALL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BALL))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_IS_BALL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BALL))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BALL, SerializableGeeHashMapTestBallClass))

typedef struct _SerializableGeeHashMapTestBall SerializableGeeHashMapTestBall;
typedef struct _SerializableGeeHashMapTestBallClass SerializableGeeHashMapTestBallClass;

#define SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BALL_FILL (serializable_gee_hash_map_test_ball_fill_get_type ())
#define SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_FILL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BALL_FILL, SerializableGeeHashMapTestBallFill))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_FILL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BALL_FILL, SerializableGeeHashMapTestBallFillClass))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_IS_BALL_FILL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BALL_FILL))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_IS_BALL_FILL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BALL_FILL))
#define SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_FILL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BALL_FILL, SerializableGeeHashMapTestBallFillClass))

typedef struct _SerializableGeeHashMapTestBallFill SerializableGeeHashMapTestBallFill;
typedef struct _SerializableGeeHashMapTestBallFillClass SerializableGeeHashMapTestBallFillClass;
typedef struct _SerializableGeeHashMapTestSpacePrivate SerializableGeeHashMapTestSpacePrivate;
enum  {
	SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_0_PROPERTY,
	SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_NAME_PROPERTY,
	SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_hash_map_test_space_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_NUM_PROPERTIES];
typedef struct _SerializableGeeHashMapTestSpaceCollectionPrivate SerializableGeeHashMapTestSpaceCollectionPrivate;
enum  {
	SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_COLLECTION_0_PROPERTY,
	SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_COLLECTION_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_hash_map_test_space_collection_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_COLLECTION_NUM_PROPERTIES];
typedef struct _SerializableGeeHashMapTestSpaceContainerPrivate SerializableGeeHashMapTestSpaceContainerPrivate;
enum  {
	SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_CONTAINER_0_PROPERTY,
	SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_CONTAINER_OWNER_PROPERTY,
	SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_CONTAINER_STORAGE_PROPERTY,
	SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_CONTAINER_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_hash_map_test_space_container_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_CONTAINER_NUM_PROPERTIES];
typedef struct _SerializableGeeHashMapTestBallFillPrivate SerializableGeeHashMapTestBallFillPrivate;
enum  {
	SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_FILL_0_PROPERTY,
	SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_FILL_NAME_PROPERTY,
	SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_FILL_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_hash_map_test_ball_fill_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_FILL_NUM_PROPERTIES];
typedef struct _SerializableGeeHashMapTestBallPrivate SerializableGeeHashMapTestBallPrivate;
enum  {
	SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_0_PROPERTY,
	SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_NAME_PROPERTY,
	SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_BALLFILL_PROPERTY,
	SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_hash_map_test_ball_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_NUM_PROPERTIES];
typedef struct _SerializableGeeHashMapTestBallHashMapPrivate SerializableGeeHashMapTestBallHashMapPrivate;
enum  {
	SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_HASH_MAP_0_PROPERTY,
	SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_HASH_MAP_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_hash_map_test_ball_hash_map_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_HASH_MAP_NUM_PROPERTIES];
typedef struct _SerializableGeeHashMapTestSmallBagPrivate SerializableGeeHashMapTestSmallBagPrivate;
enum  {
	SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_0_PROPERTY,
	SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_NAME_PROPERTY,
	SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_BALLS_PROPERTY,
	SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_hash_map_test_small_bag_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_NUM_PROPERTIES];
typedef struct _SerializableGeeHashMapTestSmallBagHashMapPrivate SerializableGeeHashMapTestSmallBagHashMapPrivate;
enum  {
	SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_HASH_MAP_0_PROPERTY,
	SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_HASH_MAP_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_hash_map_test_small_bag_hash_map_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_HASH_MAP_NUM_PROPERTIES];
typedef struct _SerializableGeeHashMapTestBigBagPrivate SerializableGeeHashMapTestBigBagPrivate;
enum  {
	SERIALIZABLE_GEE_HASH_MAP_TEST_BIG_BAG_0_PROPERTY,
	SERIALIZABLE_GEE_HASH_MAP_TEST_BIG_BAG_NAME_PROPERTY,
	SERIALIZABLE_GEE_HASH_MAP_TEST_BIG_BAG_BAGS_PROPERTY,
	SERIALIZABLE_GEE_HASH_MAP_TEST_BIG_BAG_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_hash_map_test_big_bag_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_BIG_BAG_NUM_PROPERTIES];
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _SerializableGeeHashMapTest {
	GXmlTest parent_instance;
	SerializableGeeHashMapTestPrivate * priv;
};

struct _SerializableGeeHashMapTestClass {
	GXmlTestClass parent_class;
};

struct _SerializableGeeHashMapTestSpace {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeHashMapTestSpacePrivate * priv;
};

struct _SerializableGeeHashMapTestSpaceClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeHashMapTestSpacePrivate {
	gchar* _name;
};

struct _SerializableGeeHashMapTestSpaceCollection {
	GXmlSerializableHashMap parent_instance;
	SerializableGeeHashMapTestSpaceCollectionPrivate * priv;
};

struct _SerializableGeeHashMapTestSpaceCollectionClass {
	GXmlSerializableHashMapClass parent_class;
};

struct _SerializableGeeHashMapTestSpaceContainer {
	GXmlSerializableContainer parent_instance;
	SerializableGeeHashMapTestSpaceContainerPrivate * priv;
};

struct _SerializableGeeHashMapTestSpaceContainerClass {
	GXmlSerializableContainerClass parent_class;
};

struct _SerializableGeeHashMapTestSpaceContainerPrivate {
	gchar* _owner;
	SerializableGeeHashMapTestSpaceCollection* _storage;
};

struct _SerializableGeeHashMapTestBallFill {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeHashMapTestBallFillPrivate * priv;
};

struct _SerializableGeeHashMapTestBallFillClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeHashMapTestBallFillPrivate {
	gchar* _name;
};

struct _SerializableGeeHashMapTestBall {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeHashMapTestBallPrivate * priv;
};

struct _SerializableGeeHashMapTestBallClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeHashMapTestBallPrivate {
	gchar* _name;
	SerializableGeeHashMapTestBallFill* _ballfill;
};

struct _SerializableGeeHashMapTestBallHashMap {
	GXmlSerializableHashMap parent_instance;
	SerializableGeeHashMapTestBallHashMapPrivate * priv;
};

struct _SerializableGeeHashMapTestBallHashMapClass {
	GXmlSerializableHashMapClass parent_class;
};

struct _SerializableGeeHashMapTestSmallBag {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeHashMapTestSmallBagPrivate * priv;
};

struct _SerializableGeeHashMapTestSmallBagClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeHashMapTestSmallBagPrivate {
	gchar* _name;
	SerializableGeeHashMapTestBallHashMap* _balls;
};

struct _SerializableGeeHashMapTestSmallBagHashMap {
	GXmlSerializableHashMap parent_instance;
	SerializableGeeHashMapTestSmallBagHashMapPrivate * priv;
};

struct _SerializableGeeHashMapTestSmallBagHashMapClass {
	GXmlSerializableHashMapClass parent_class;
};

struct _SerializableGeeHashMapTestBigBag {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeHashMapTestBigBagPrivate * priv;
};

struct _SerializableGeeHashMapTestBigBagClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeHashMapTestBigBagPrivate {
	gchar* _name;
	SerializableGeeHashMapTestSmallBagHashMap* _bags;
};

static gpointer serializable_gee_hash_map_test_parent_class = NULL;
static gint SerializableGeeHashMapTestSpace_private_offset;
static gpointer serializable_gee_hash_map_test_space_parent_class = NULL;
static gpointer serializable_gee_hash_map_test_space_collection_parent_class = NULL;
static GXmlSerializableMapKeyIface * serializable_gee_hash_map_test_space_gxml_serializable_map_key_parent_iface = NULL;
static gint SerializableGeeHashMapTestSpaceContainer_private_offset;
static gpointer serializable_gee_hash_map_test_space_container_parent_class = NULL;
static gint SerializableGeeHashMapTestBallFill_private_offset;
static gpointer serializable_gee_hash_map_test_ball_fill_parent_class = NULL;
static gint SerializableGeeHashMapTestBall_private_offset;
static gpointer serializable_gee_hash_map_test_ball_parent_class = NULL;
static gpointer serializable_gee_hash_map_test_ball_hash_map_parent_class = NULL;
static GXmlSerializableMapKeyIface * serializable_gee_hash_map_test_ball_gxml_serializable_map_key_parent_iface = NULL;
static gint SerializableGeeHashMapTestSmallBag_private_offset;
static gpointer serializable_gee_hash_map_test_small_bag_parent_class = NULL;
static gpointer serializable_gee_hash_map_test_small_bag_hash_map_parent_class = NULL;
static GXmlSerializableMapKeyIface * serializable_gee_hash_map_test_small_bag_gxml_serializable_map_key_parent_iface = NULL;
static gint SerializableGeeHashMapTestBigBag_private_offset;
static gpointer serializable_gee_hash_map_test_big_bag_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType serializable_gee_hash_map_test_get_type (void) G_GNUC_CONST;
void serializable_gee_hash_map_test_add_tests (void);
static void __lambda311_ (void);
static GType serializable_gee_hash_map_test_space_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeHashMapTestSpace* serializable_gee_hash_map_test_space_new_named (const gchar* name);
static SerializableGeeHashMapTestSpace* serializable_gee_hash_map_test_space_construct_named (GType object_type,
                                                                                       const gchar* name);
static const gchar* serializable_gee_hash_map_test_space_get_name (SerializableGeeHashMapTestSpace* self);
static void ___lambda311__gtest_func (void);
static void __lambda312_ (void);
static void serializable_gee_hash_map_test_space_set_value (SerializableGeeHashMapTestSpace* self,
                                                     const gchar* str);
static void ___lambda312__gtest_func (void);
static void __lambda313_ (void);
static void ___lambda313__gtest_func (void);
static void __lambda314_ (void);
static GType serializable_gee_hash_map_test_space_container_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeHashMapTestSpaceContainer* serializable_gee_hash_map_test_space_container_new (void);
static SerializableGeeHashMapTestSpaceContainer* serializable_gee_hash_map_test_space_container_construct (GType object_type);
static const gchar* serializable_gee_hash_map_test_space_container_get_owner (SerializableGeeHashMapTestSpaceContainer* self);
GType serializable_gee_hash_map_test_space_collection_get_type (void) G_GNUC_CONST;
static SerializableGeeHashMapTestSpaceCollection* serializable_gee_hash_map_test_space_container_get_storage (SerializableGeeHashMapTestSpaceContainer* self);
static void ___lambda314__gtest_func (void);
static void __lambda315_ (void);
static SerializableGeeHashMapTestSpaceCollection* serializable_gee_hash_map_test_space_collection_new (void);
static SerializableGeeHashMapTestSpaceCollection* serializable_gee_hash_map_test_space_collection_construct (GType object_type);
static void serializable_gee_hash_map_test_space_container_set_storage (SerializableGeeHashMapTestSpaceContainer* self,
                                                                 SerializableGeeHashMapTestSpaceCollection* value);
static void ___lambda315__gtest_func (void);
static void __lambda316_ (void);
static gchar* serializable_gee_hash_map_test_space_get_value (SerializableGeeHashMapTestSpace* self);
static void ___lambda316__gtest_func (void);
static void __lambda317_ (void);
GType book_store_get_type (void) G_GNUC_CONST;
BookStore* book_store_new (void);
BookStore* book_store_construct (GType object_type);
const gchar* book_store_get_name (BookStore* self);
GType book_array_get_type (void) G_GNUC_CONST;
BookArray* book_store_get_books (BookStore* self);
GType book_get_type (void) G_GNUC_CONST;
GType name_get_type (void) G_GNUC_CONST;
Name* book_get_name (Book* self);
gchar* name_get_name (Name* self);
const gchar* book_get_year (Book* self);
GType authors_get_type (void) G_GNUC_CONST;
Authors* book_get_authors (Book* self);
GType author_array_get_type (void) G_GNUC_CONST;
AuthorArray* authors_get_array (Authors* self);
GType category_map_get_type (void) G_GNUC_CONST;
CategoryMap* book_get_categories (Book* self);
GType category_get_type (void) G_GNUC_CONST;
const gchar* category_get_name (Category* self);
static void ___lambda317__gtest_func (void);
static void __lambda318_ (void);
static GType serializable_gee_hash_map_test_big_bag_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeHashMapTestBigBag* serializable_gee_hash_map_test_big_bag_new (void);
static SerializableGeeHashMapTestBigBag* serializable_gee_hash_map_test_big_bag_construct (GType object_type);
GType serializable_gee_hash_map_test_small_bag_hash_map_get_type (void) G_GNUC_CONST;
static SerializableGeeHashMapTestSmallBagHashMap* serializable_gee_hash_map_test_big_bag_get_bags (SerializableGeeHashMapTestBigBag* self);
static GType serializable_gee_hash_map_test_small_bag_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeHashMapTestSmallBag* serializable_gee_hash_map_test_small_bag_new (void);
static SerializableGeeHashMapTestSmallBag* serializable_gee_hash_map_test_small_bag_construct (GType object_type);
static void serializable_gee_hash_map_test_small_bag_set_name (SerializableGeeHashMapTestSmallBag* self,
                                                        const gchar* value);
GType serializable_gee_hash_map_test_ball_hash_map_get_type (void) G_GNUC_CONST;
static SerializableGeeHashMapTestBallHashMap* serializable_gee_hash_map_test_small_bag_get_balls (SerializableGeeHashMapTestSmallBag* self);
static GType serializable_gee_hash_map_test_ball_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeHashMapTestBall* serializable_gee_hash_map_test_ball_new (void);
static SerializableGeeHashMapTestBall* serializable_gee_hash_map_test_ball_construct (GType object_type);
static void serializable_gee_hash_map_test_ball_set_name (SerializableGeeHashMapTestBall* self,
                                                   const gchar* value);
static SerializableGeeHashMapTestBallFill* serializable_gee_hash_map_test_ball_fill_new (void);
static SerializableGeeHashMapTestBallFill* serializable_gee_hash_map_test_ball_fill_construct (GType object_type);
static GType serializable_gee_hash_map_test_ball_fill_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static void serializable_gee_hash_map_test_ball_set_ballfill (SerializableGeeHashMapTestBall* self,
                                                       SerializableGeeHashMapTestBallFill* value);
static SerializableGeeHashMapTestBallFill* serializable_gee_hash_map_test_ball_get_ballfill (SerializableGeeHashMapTestBall* self);
static void serializable_gee_hash_map_test_ball_fill_set_text (SerializableGeeHashMapTestBallFill* self,
                                                        const gchar* txt);
static const gchar* serializable_gee_hash_map_test_ball_get_name (SerializableGeeHashMapTestBall* self);
static const gchar* serializable_gee_hash_map_test_small_bag_get_name (SerializableGeeHashMapTestSmallBag* self);
static void ___lambda318__gtest_func (void);
SerializableGeeHashMapTest* serializable_gee_hash_map_test_new (void);
SerializableGeeHashMapTest* serializable_gee_hash_map_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static gchar* serializable_gee_hash_map_test_space_real_get_map_key (GXmlSerializableMapKey* base);
static void serializable_gee_hash_map_test_space_set_name (SerializableGeeHashMapTestSpace* self,
                                                    const gchar* value);
static gboolean serializable_gee_hash_map_test_space_real_serialize_use_xml_node_value (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_hash_map_test_space_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_hash_map_test_space_real_to_string (GXmlSerializableObjectModel* base);
static SerializableGeeHashMapTestSpace* serializable_gee_hash_map_test_space_new (void);
static SerializableGeeHashMapTestSpace* serializable_gee_hash_map_test_space_construct (GType object_type);
static void serializable_gee_hash_map_test_space_finalize (GObject * obj);
static void _vala_serializable_gee_hash_map_test_space_get_property (GObject * object,
                                                              guint property_id,
                                                              GValue * value,
                                                              GParamSpec * pspec);
static void _vala_serializable_gee_hash_map_test_space_set_property (GObject * object,
                                                              guint property_id,
                                                              const GValue * value,
                                                              GParamSpec * pspec);
static gchar* serializable_gee_hash_map_test_space_container_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_hash_map_test_space_container_real_to_string (GXmlSerializableObjectModel* base);
static void serializable_gee_hash_map_test_space_container_real_init_containers (GXmlSerializableContainer* base);
static void serializable_gee_hash_map_test_space_container_set_owner (SerializableGeeHashMapTestSpaceContainer* self,
                                                               const gchar* value);
static void serializable_gee_hash_map_test_space_container_finalize (GObject * obj);
static void _vala_serializable_gee_hash_map_test_space_container_get_property (GObject * object,
                                                                        guint property_id,
                                                                        GValue * value,
                                                                        GParamSpec * pspec);
static void _vala_serializable_gee_hash_map_test_space_container_set_property (GObject * object,
                                                                        guint property_id,
                                                                        const GValue * value,
                                                                        GParamSpec * pspec);
static gchar* serializable_gee_hash_map_test_ball_fill_real_to_string (GXmlSerializableObjectModel* base);
static const gchar* serializable_gee_hash_map_test_ball_fill_get_name (SerializableGeeHashMapTestBallFill* self);
static gchar* serializable_gee_hash_map_test_ball_fill_real_node_name (GXmlSerializableObjectModel* base);
static gboolean serializable_gee_hash_map_test_ball_fill_real_serialize_use_xml_node_value (GXmlSerializableObjectModel* base);
static void serializable_gee_hash_map_test_ball_fill_set_name (SerializableGeeHashMapTestBallFill* self,
                                                        const gchar* value);
static void serializable_gee_hash_map_test_ball_fill_finalize (GObject * obj);
static void _vala_serializable_gee_hash_map_test_ball_fill_get_property (GObject * object,
                                                                  guint property_id,
                                                                  GValue * value,
                                                                  GParamSpec * pspec);
static void _vala_serializable_gee_hash_map_test_ball_fill_set_property (GObject * object,
                                                                  guint property_id,
                                                                  const GValue * value,
                                                                  GParamSpec * pspec);
static gchar* serializable_gee_hash_map_test_ball_real_to_string (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_hash_map_test_ball_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_hash_map_test_ball_real_get_map_key (GXmlSerializableMapKey* base);
static gboolean serializable_gee_hash_map_test_ball_hash_map_real_deserialize_proceed (GXmlSerializableHashMap* base);
static SerializableGeeHashMapTestBallHashMap* serializable_gee_hash_map_test_ball_hash_map_new (void);
static SerializableGeeHashMapTestBallHashMap* serializable_gee_hash_map_test_ball_hash_map_construct (GType object_type);
static void serializable_gee_hash_map_test_ball_finalize (GObject * obj);
static void _vala_serializable_gee_hash_map_test_ball_get_property (GObject * object,
                                                             guint property_id,
                                                             GValue * value,
                                                             GParamSpec * pspec);
static void _vala_serializable_gee_hash_map_test_ball_set_property (GObject * object,
                                                             guint property_id,
                                                             const GValue * value,
                                                             GParamSpec * pspec);
static gchar* serializable_gee_hash_map_test_small_bag_real_to_string (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_hash_map_test_small_bag_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_hash_map_test_small_bag_real_get_map_key (GXmlSerializableMapKey* base);
static void serializable_gee_hash_map_test_small_bag_set_balls (SerializableGeeHashMapTestSmallBag* self,
                                                         SerializableGeeHashMapTestBallHashMap* value);
static gboolean serializable_gee_hash_map_test_small_bag_hash_map_real_deserialize_proceed (GXmlSerializableHashMap* base);
static SerializableGeeHashMapTestSmallBagHashMap* serializable_gee_hash_map_test_small_bag_hash_map_new (void);
static SerializableGeeHashMapTestSmallBagHashMap* serializable_gee_hash_map_test_small_bag_hash_map_construct (GType object_type);
static void serializable_gee_hash_map_test_small_bag_finalize (GObject * obj);
static void _vala_serializable_gee_hash_map_test_small_bag_get_property (GObject * object,
                                                                  guint property_id,
                                                                  GValue * value,
                                                                  GParamSpec * pspec);
static void _vala_serializable_gee_hash_map_test_small_bag_set_property (GObject * object,
                                                                  guint property_id,
                                                                  const GValue * value,
                                                                  GParamSpec * pspec);
static gchar* serializable_gee_hash_map_test_big_bag_real_to_string (GXmlSerializableObjectModel* base);
static const gchar* serializable_gee_hash_map_test_big_bag_get_name (SerializableGeeHashMapTestBigBag* self);
static gchar* serializable_gee_hash_map_test_big_bag_real_node_name (GXmlSerializableObjectModel* base);
static void serializable_gee_hash_map_test_big_bag_set_name (SerializableGeeHashMapTestBigBag* self,
                                                      const gchar* value);
static void serializable_gee_hash_map_test_big_bag_set_bags (SerializableGeeHashMapTestBigBag* self,
                                                      SerializableGeeHashMapTestSmallBagHashMap* value);
static void serializable_gee_hash_map_test_big_bag_finalize (GObject * obj);
static void _vala_serializable_gee_hash_map_test_big_bag_get_property (GObject * object,
                                                                guint property_id,
                                                                GValue * value,
                                                                GParamSpec * pspec);
static void _vala_serializable_gee_hash_map_test_big_bag_set_property (GObject * object,
                                                                guint property_id,
                                                                const GValue * value,
                                                                GParamSpec * pspec);

static void
__lambda311_ (void)
{
	GXmlSerializableHashMap* c = NULL;
	GXmlSerializableHashMap* _tmp0_;
	SerializableGeeHashMapTestSpace* o1 = NULL;
	SerializableGeeHashMapTestSpace* _tmp1_;
	SerializableGeeHashMapTestSpace* o2 = NULL;
	SerializableGeeHashMapTestSpace* _tmp2_;
	GXmlSerializableHashMap* _tmp3_;
	SerializableGeeHashMapTestSpace* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	SerializableGeeHashMapTestSpace* _tmp7_;
	GXmlSerializableHashMap* _tmp8_;
	SerializableGeeHashMapTestSpace* _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	SerializableGeeHashMapTestSpace* _tmp12_;
	gboolean found1 = FALSE;
	gboolean found2 = FALSE;
#line 107 "SerializableGeeHashMapTest.vala"
	_tmp0_ = gxml_serializable_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 107 "SerializableGeeHashMapTest.vala"
	c = _tmp0_;
#line 108 "SerializableGeeHashMapTest.vala"
	_tmp1_ = serializable_gee_hash_map_test_space_new_named ("Big");
#line 108 "SerializableGeeHashMapTest.vala"
	o1 = _tmp1_;
#line 109 "SerializableGeeHashMapTest.vala"
	_tmp2_ = serializable_gee_hash_map_test_space_new_named ("Small");
#line 109 "SerializableGeeHashMapTest.vala"
	o2 = _tmp2_;
#line 110 "SerializableGeeHashMapTest.vala"
	_tmp3_ = c;
#line 110 "SerializableGeeHashMapTest.vala"
	_tmp4_ = o1;
#line 110 "SerializableGeeHashMapTest.vala"
	_tmp5_ = serializable_gee_hash_map_test_space_get_name (_tmp4_);
#line 110 "SerializableGeeHashMapTest.vala"
	_tmp6_ = _tmp5_;
#line 110 "SerializableGeeHashMapTest.vala"
	_tmp7_ = o1;
#line 110 "SerializableGeeHashMapTest.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp3_, _tmp6_, _tmp7_);
#line 111 "SerializableGeeHashMapTest.vala"
	_tmp8_ = c;
#line 111 "SerializableGeeHashMapTest.vala"
	_tmp9_ = o2;
#line 111 "SerializableGeeHashMapTest.vala"
	_tmp10_ = serializable_gee_hash_map_test_space_get_name (_tmp9_);
#line 111 "SerializableGeeHashMapTest.vala"
	_tmp11_ = _tmp10_;
#line 111 "SerializableGeeHashMapTest.vala"
	_tmp12_ = o2;
#line 111 "SerializableGeeHashMapTest.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp8_, _tmp11_, _tmp12_);
#line 112 "SerializableGeeHashMapTest.vala"
	found1 = FALSE;
#line 113 "SerializableGeeHashMapTest.vala"
	found2 = FALSE;
#line 681 "SerializableGeeHashMapTest.c"
	{
		GeeIterator* _o_it = NULL;
		GXmlSerializableHashMap* _tmp13_;
		GeeCollection* _tmp14_;
		GeeCollection* _tmp15_;
		GeeCollection* _tmp16_;
		GeeIterator* _tmp17_;
		GeeIterator* _tmp18_;
#line 114 "SerializableGeeHashMapTest.vala"
		_tmp13_ = c;
#line 114 "SerializableGeeHashMapTest.vala"
		_tmp14_ = gee_abstract_map_get_values ((GeeAbstractMap*) _tmp13_);
#line 114 "SerializableGeeHashMapTest.vala"
		_tmp15_ = _tmp14_;
#line 114 "SerializableGeeHashMapTest.vala"
		_tmp16_ = _tmp15_;
#line 114 "SerializableGeeHashMapTest.vala"
		_tmp17_ = gee_iterable_iterator ((GeeIterable*) _tmp16_);
#line 114 "SerializableGeeHashMapTest.vala"
		_tmp18_ = _tmp17_;
#line 114 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp16_);
#line 114 "SerializableGeeHashMapTest.vala"
		_o_it = _tmp18_;
#line 114 "SerializableGeeHashMapTest.vala"
		while (TRUE) {
#line 708 "SerializableGeeHashMapTest.c"
			GeeIterator* _tmp19_;
			SerializableGeeHashMapTestSpace* o = NULL;
			GeeIterator* _tmp20_;
			gpointer _tmp21_;
			SerializableGeeHashMapTestSpace* _tmp22_;
			const gchar* _tmp23_;
			const gchar* _tmp24_;
			SerializableGeeHashMapTestSpace* _tmp25_;
			const gchar* _tmp26_;
			const gchar* _tmp27_;
#line 114 "SerializableGeeHashMapTest.vala"
			_tmp19_ = _o_it;
#line 114 "SerializableGeeHashMapTest.vala"
			if (!gee_iterator_next (_tmp19_)) {
#line 114 "SerializableGeeHashMapTest.vala"
				break;
#line 725 "SerializableGeeHashMapTest.c"
			}
#line 114 "SerializableGeeHashMapTest.vala"
			_tmp20_ = _o_it;
#line 114 "SerializableGeeHashMapTest.vala"
			_tmp21_ = gee_iterator_get (_tmp20_);
#line 114 "SerializableGeeHashMapTest.vala"
			o = (SerializableGeeHashMapTestSpace*) _tmp21_;
#line 115 "SerializableGeeHashMapTest.vala"
			_tmp22_ = o;
#line 115 "SerializableGeeHashMapTest.vala"
			_tmp23_ = serializable_gee_hash_map_test_space_get_name (_tmp22_);
#line 115 "SerializableGeeHashMapTest.vala"
			_tmp24_ = _tmp23_;
#line 115 "SerializableGeeHashMapTest.vala"
			if (g_strcmp0 (_tmp24_, "Big") == 0) {
#line 115 "SerializableGeeHashMapTest.vala"
				found1 = TRUE;
#line 743 "SerializableGeeHashMapTest.c"
			}
#line 116 "SerializableGeeHashMapTest.vala"
			_tmp25_ = o;
#line 116 "SerializableGeeHashMapTest.vala"
			_tmp26_ = serializable_gee_hash_map_test_space_get_name (_tmp25_);
#line 116 "SerializableGeeHashMapTest.vala"
			_tmp27_ = _tmp26_;
#line 116 "SerializableGeeHashMapTest.vala"
			if (g_strcmp0 (_tmp27_, "Small") == 0) {
#line 116 "SerializableGeeHashMapTest.vala"
				found2 = TRUE;
#line 755 "SerializableGeeHashMapTest.c"
			}
#line 114 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (o);
#line 759 "SerializableGeeHashMapTest.c"
		}
#line 114 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_o_it);
#line 763 "SerializableGeeHashMapTest.c"
	}
#line 118 "SerializableGeeHashMapTest.vala"
	if (!found1) {
#line 119 "SerializableGeeHashMapTest.vala"
		g_message ("SerializableGeeHashMapTest.vala:119: %s", "Big is not found\n");
#line 120 "SerializableGeeHashMapTest.vala"
		g_assert_not_reached ();
#line 771 "SerializableGeeHashMapTest.c"
	}
#line 122 "SerializableGeeHashMapTest.vala"
	if (!found2) {
#line 123 "SerializableGeeHashMapTest.vala"
		g_message ("SerializableGeeHashMapTest.vala:123: %s", "Small is not found\n");
#line 124 "SerializableGeeHashMapTest.vala"
		g_assert_not_reached ();
#line 779 "SerializableGeeHashMapTest.c"
	}
#line 126 "SerializableGeeHashMapTest.vala"
	found2 = FALSE;
#line 126 "SerializableGeeHashMapTest.vala"
	found1 = found2;
#line 785 "SerializableGeeHashMapTest.c"
	{
		GeeIterator* _k_it = NULL;
		GXmlSerializableHashMap* _tmp28_;
		GeeSet* _tmp29_;
		GeeSet* _tmp30_;
		GeeSet* _tmp31_;
		GeeIterator* _tmp32_;
		GeeIterator* _tmp33_;
#line 127 "SerializableGeeHashMapTest.vala"
		_tmp28_ = c;
#line 127 "SerializableGeeHashMapTest.vala"
		_tmp29_ = gee_abstract_map_get_keys ((GeeAbstractMap*) _tmp28_);
#line 127 "SerializableGeeHashMapTest.vala"
		_tmp30_ = _tmp29_;
#line 127 "SerializableGeeHashMapTest.vala"
		_tmp31_ = _tmp30_;
#line 127 "SerializableGeeHashMapTest.vala"
		_tmp32_ = gee_iterable_iterator ((GeeIterable*) _tmp31_);
#line 127 "SerializableGeeHashMapTest.vala"
		_tmp33_ = _tmp32_;
#line 127 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp31_);
#line 127 "SerializableGeeHashMapTest.vala"
		_k_it = _tmp33_;
#line 127 "SerializableGeeHashMapTest.vala"
		while (TRUE) {
#line 812 "SerializableGeeHashMapTest.c"
			GeeIterator* _tmp34_;
			gchar* k = NULL;
			GeeIterator* _tmp35_;
			gpointer _tmp36_;
			GXmlSerializableHashMap* _tmp37_;
			const gchar* _tmp38_;
			gpointer _tmp39_;
			SerializableGeeHashMapTestSpace* _tmp40_;
			const gchar* _tmp41_;
			const gchar* _tmp42_;
			gboolean _tmp43_;
			GXmlSerializableHashMap* _tmp44_;
			const gchar* _tmp45_;
			gpointer _tmp46_;
			SerializableGeeHashMapTestSpace* _tmp47_;
			const gchar* _tmp48_;
			const gchar* _tmp49_;
			gboolean _tmp50_;
#line 127 "SerializableGeeHashMapTest.vala"
			_tmp34_ = _k_it;
#line 127 "SerializableGeeHashMapTest.vala"
			if (!gee_iterator_next (_tmp34_)) {
#line 127 "SerializableGeeHashMapTest.vala"
				break;
#line 837 "SerializableGeeHashMapTest.c"
			}
#line 127 "SerializableGeeHashMapTest.vala"
			_tmp35_ = _k_it;
#line 127 "SerializableGeeHashMapTest.vala"
			_tmp36_ = gee_iterator_get (_tmp35_);
#line 127 "SerializableGeeHashMapTest.vala"
			k = (gchar*) _tmp36_;
#line 128 "SerializableGeeHashMapTest.vala"
			_tmp37_ = c;
#line 128 "SerializableGeeHashMapTest.vala"
			_tmp38_ = k;
#line 128 "SerializableGeeHashMapTest.vala"
			_tmp39_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp37_, _tmp38_);
#line 128 "SerializableGeeHashMapTest.vala"
			_tmp40_ = (SerializableGeeHashMapTestSpace*) _tmp39_;
#line 128 "SerializableGeeHashMapTest.vala"
			_tmp41_ = serializable_gee_hash_map_test_space_get_name (_tmp40_);
#line 128 "SerializableGeeHashMapTest.vala"
			_tmp42_ = _tmp41_;
#line 128 "SerializableGeeHashMapTest.vala"
			_tmp43_ = g_strcmp0 (_tmp42_, "Big") == 0;
#line 128 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (_tmp40_);
#line 128 "SerializableGeeHashMapTest.vala"
			if (_tmp43_) {
#line 128 "SerializableGeeHashMapTest.vala"
				found1 = TRUE;
#line 865 "SerializableGeeHashMapTest.c"
			}
#line 129 "SerializableGeeHashMapTest.vala"
			_tmp44_ = c;
#line 129 "SerializableGeeHashMapTest.vala"
			_tmp45_ = k;
#line 129 "SerializableGeeHashMapTest.vala"
			_tmp46_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp44_, _tmp45_);
#line 129 "SerializableGeeHashMapTest.vala"
			_tmp47_ = (SerializableGeeHashMapTestSpace*) _tmp46_;
#line 129 "SerializableGeeHashMapTest.vala"
			_tmp48_ = serializable_gee_hash_map_test_space_get_name (_tmp47_);
#line 129 "SerializableGeeHashMapTest.vala"
			_tmp49_ = _tmp48_;
#line 129 "SerializableGeeHashMapTest.vala"
			_tmp50_ = g_strcmp0 (_tmp49_, "Small") == 0;
#line 129 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (_tmp47_);
#line 129 "SerializableGeeHashMapTest.vala"
			if (_tmp50_) {
#line 129 "SerializableGeeHashMapTest.vala"
				found2 = TRUE;
#line 887 "SerializableGeeHashMapTest.c"
			}
#line 127 "SerializableGeeHashMapTest.vala"
			_g_free0 (k);
#line 891 "SerializableGeeHashMapTest.c"
		}
#line 127 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_k_it);
#line 895 "SerializableGeeHashMapTest.c"
	}
#line 131 "SerializableGeeHashMapTest.vala"
	if (!found1) {
#line 132 "SerializableGeeHashMapTest.vala"
		g_message ("SerializableGeeHashMapTest.vala:132: %s", "Big key value is not found\n");
#line 133 "SerializableGeeHashMapTest.vala"
		g_assert_not_reached ();
#line 903 "SerializableGeeHashMapTest.c"
	}
#line 135 "SerializableGeeHashMapTest.vala"
	if (!found2) {
#line 136 "SerializableGeeHashMapTest.vala"
		g_message ("SerializableGeeHashMapTest.vala:136: %s", "Small key value is not found\n");
#line 137 "SerializableGeeHashMapTest.vala"
		g_assert_not_reached ();
#line 911 "SerializableGeeHashMapTest.c"
	}
#line 106 "SerializableGeeHashMapTest.vala"
	_g_object_unref0 (o2);
#line 106 "SerializableGeeHashMapTest.vala"
	_g_object_unref0 (o1);
#line 106 "SerializableGeeHashMapTest.vala"
	_g_object_unref0 (c);
#line 919 "SerializableGeeHashMapTest.c"
}

static void
___lambda311__gtest_func (void)
{
#line 105 "SerializableGeeHashMapTest.vala"
	__lambda311_ ();
#line 927 "SerializableGeeHashMapTest.c"
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result = NULL;
#line 1516 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1517 "glib-2.0.vapi"
	result = self;
#line 1517 "glib-2.0.vapi"
	return result;
#line 940 "SerializableGeeHashMapTest.c"
}

static void
__lambda312_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlSerializableHashMap* c = NULL;
		GXmlSerializableHashMap* _tmp0_;
		SerializableGeeHashMapTestSpace* o1 = NULL;
		SerializableGeeHashMapTestSpace* _tmp1_;
		SerializableGeeHashMapTestSpace* _tmp2_;
		SerializableGeeHashMapTestSpace* o2 = NULL;
		SerializableGeeHashMapTestSpace* _tmp3_;
		SerializableGeeHashMapTestSpace* _tmp4_;
		GXmlSerializableHashMap* _tmp5_;
		SerializableGeeHashMapTestSpace* _tmp6_;
		const gchar* _tmp7_;
		const gchar* _tmp8_;
		SerializableGeeHashMapTestSpace* _tmp9_;
		GXmlSerializableHashMap* _tmp10_;
		SerializableGeeHashMapTestSpace* _tmp11_;
		const gchar* _tmp12_;
		const gchar* _tmp13_;
		SerializableGeeHashMapTestSpace* _tmp14_;
		GXmlTDocument* doc = NULL;
		GXmlTDocument* _tmp15_;
		GXmlNode* root = NULL;
		GXmlTDocument* _tmp16_;
		GXmlNode* _tmp17_;
		GXmlTDocument* _tmp18_;
		GeeBidirList* _tmp19_;
		GeeBidirList* _tmp20_;
		GeeBidirList* _tmp21_;
		GXmlNode* _tmp22_;
		GXmlSerializableHashMap* _tmp23_;
		GXmlNode* _tmp24_;
		GXmlNode* _tmp25_;
		GXmlNode* _tmp26_;
		GXmlNode* _tmp27_;
		GeeBidirList* _tmp28_;
		GeeBidirList* _tmp29_;
		GeeBidirList* _tmp30_;
		gint _tmp31_;
		gint _tmp32_;
		gboolean found1 = FALSE;
		gboolean found2 = FALSE;
#line 143 "SerializableGeeHashMapTest.vala"
		_tmp0_ = gxml_serializable_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 143 "SerializableGeeHashMapTest.vala"
		c = _tmp0_;
#line 144 "SerializableGeeHashMapTest.vala"
		_tmp1_ = serializable_gee_hash_map_test_space_new_named ("Big");
#line 144 "SerializableGeeHashMapTest.vala"
		o1 = _tmp1_;
#line 145 "SerializableGeeHashMapTest.vala"
		_tmp2_ = o1;
#line 145 "SerializableGeeHashMapTest.vala"
		serializable_gee_hash_map_test_space_set_value (_tmp2_, "FAKE TEXT");
#line 146 "SerializableGeeHashMapTest.vala"
		_tmp3_ = serializable_gee_hash_map_test_space_new_named ("Small");
#line 146 "SerializableGeeHashMapTest.vala"
		o2 = _tmp3_;
#line 147 "SerializableGeeHashMapTest.vala"
		_tmp4_ = o2;
#line 147 "SerializableGeeHashMapTest.vala"
		serializable_gee_hash_map_test_space_set_value (_tmp4_, "FAKE TEXT");
#line 148 "SerializableGeeHashMapTest.vala"
		_tmp5_ = c;
#line 148 "SerializableGeeHashMapTest.vala"
		_tmp6_ = o1;
#line 148 "SerializableGeeHashMapTest.vala"
		_tmp7_ = serializable_gee_hash_map_test_space_get_name (_tmp6_);
#line 148 "SerializableGeeHashMapTest.vala"
		_tmp8_ = _tmp7_;
#line 148 "SerializableGeeHashMapTest.vala"
		_tmp9_ = o1;
#line 148 "SerializableGeeHashMapTest.vala"
		gee_abstract_map_set ((GeeAbstractMap*) _tmp5_, _tmp8_, _tmp9_);
#line 149 "SerializableGeeHashMapTest.vala"
		_tmp10_ = c;
#line 149 "SerializableGeeHashMapTest.vala"
		_tmp11_ = o2;
#line 149 "SerializableGeeHashMapTest.vala"
		_tmp12_ = serializable_gee_hash_map_test_space_get_name (_tmp11_);
#line 149 "SerializableGeeHashMapTest.vala"
		_tmp13_ = _tmp12_;
#line 149 "SerializableGeeHashMapTest.vala"
		_tmp14_ = o2;
#line 149 "SerializableGeeHashMapTest.vala"
		gee_abstract_map_set ((GeeAbstractMap*) _tmp10_, _tmp13_, _tmp14_);
#line 150 "SerializableGeeHashMapTest.vala"
		_tmp15_ = gxml_tdocument_new ();
#line 150 "SerializableGeeHashMapTest.vala"
		doc = _tmp15_;
#line 151 "SerializableGeeHashMapTest.vala"
		_tmp16_ = doc;
#line 151 "SerializableGeeHashMapTest.vala"
		_tmp17_ = gxml_document_create_element ((GXmlDocument*) _tmp16_, "root", &_inner_error0_);
#line 151 "SerializableGeeHashMapTest.vala"
		root = _tmp17_;
#line 151 "SerializableGeeHashMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 151 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (doc);
#line 151 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (o2);
#line 151 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (o1);
#line 151 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (c);
#line 1052 "SerializableGeeHashMapTest.c"
			goto __catch362_g_error;
		}
#line 152 "SerializableGeeHashMapTest.vala"
		_tmp18_ = doc;
#line 152 "SerializableGeeHashMapTest.vala"
		_tmp19_ = gxml_tnode_get_children_nodes ((GXmlTNode*) _tmp18_);
#line 152 "SerializableGeeHashMapTest.vala"
		_tmp20_ = _tmp19_;
#line 152 "SerializableGeeHashMapTest.vala"
		_tmp21_ = _tmp20_;
#line 152 "SerializableGeeHashMapTest.vala"
		_tmp22_ = root;
#line 152 "SerializableGeeHashMapTest.vala"
		gee_collection_add ((GeeCollection*) _tmp21_, _tmp22_);
#line 152 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp21_);
#line 153 "SerializableGeeHashMapTest.vala"
		_tmp23_ = c;
#line 153 "SerializableGeeHashMapTest.vala"
		_tmp24_ = root;
#line 153 "SerializableGeeHashMapTest.vala"
		_tmp25_ = gxml_serializable_hash_map_serialize (_tmp23_, _tmp24_, &_inner_error0_);
#line 153 "SerializableGeeHashMapTest.vala"
		_tmp26_ = _tmp25_;
#line 153 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp26_);
#line 153 "SerializableGeeHashMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 153 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (root);
#line 153 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (doc);
#line 153 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (o2);
#line 153 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (o1);
#line 153 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (c);
#line 1091 "SerializableGeeHashMapTest.c"
			goto __catch362_g_error;
		}
#line 154 "SerializableGeeHashMapTest.vala"
		_tmp27_ = root;
#line 154 "SerializableGeeHashMapTest.vala"
		_tmp28_ = gxml_node_get_children_nodes (_tmp27_);
#line 154 "SerializableGeeHashMapTest.vala"
		_tmp29_ = _tmp28_;
#line 154 "SerializableGeeHashMapTest.vala"
		_tmp30_ = _tmp29_;
#line 154 "SerializableGeeHashMapTest.vala"
		_tmp31_ = gee_collection_get_size ((GeeCollection*) _tmp30_);
#line 154 "SerializableGeeHashMapTest.vala"
		_tmp32_ = _tmp31_;
#line 154 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp32_ > 0, "root.children_nodes.size > 0");
#line 154 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp30_);
#line 155 "SerializableGeeHashMapTest.vala"
		found1 = FALSE;
#line 156 "SerializableGeeHashMapTest.vala"
		found2 = FALSE;
#line 1114 "SerializableGeeHashMapTest.c"
		{
			GeeBidirList* _n_list = NULL;
			GXmlNode* _tmp33_;
			GeeBidirList* _tmp34_;
			GeeBidirList* _tmp35_;
			gint _n_size = 0;
			GeeBidirList* _tmp36_;
			gint _tmp37_;
			gint _tmp38_;
			gint _n_index = 0;
#line 157 "SerializableGeeHashMapTest.vala"
			_tmp33_ = root;
#line 157 "SerializableGeeHashMapTest.vala"
			_tmp34_ = gxml_node_get_children_nodes (_tmp33_);
#line 157 "SerializableGeeHashMapTest.vala"
			_tmp35_ = _tmp34_;
#line 157 "SerializableGeeHashMapTest.vala"
			_n_list = _tmp35_;
#line 157 "SerializableGeeHashMapTest.vala"
			_tmp36_ = _n_list;
#line 157 "SerializableGeeHashMapTest.vala"
			_tmp37_ = gee_collection_get_size ((GeeCollection*) _tmp36_);
#line 157 "SerializableGeeHashMapTest.vala"
			_tmp38_ = _tmp37_;
#line 157 "SerializableGeeHashMapTest.vala"
			_n_size = _tmp38_;
#line 157 "SerializableGeeHashMapTest.vala"
			_n_index = -1;
#line 157 "SerializableGeeHashMapTest.vala"
			while (TRUE) {
#line 1145 "SerializableGeeHashMapTest.c"
				GXmlNode* n = NULL;
				GeeBidirList* _tmp39_;
				gpointer _tmp40_;
				gboolean _tmp41_ = FALSE;
				GXmlNode* _tmp42_;
#line 157 "SerializableGeeHashMapTest.vala"
				_n_index = _n_index + 1;
#line 157 "SerializableGeeHashMapTest.vala"
				if (!(_n_index < _n_size)) {
#line 157 "SerializableGeeHashMapTest.vala"
					break;
#line 1157 "SerializableGeeHashMapTest.c"
				}
#line 157 "SerializableGeeHashMapTest.vala"
				_tmp39_ = _n_list;
#line 157 "SerializableGeeHashMapTest.vala"
				_tmp40_ = gee_list_get ((GeeList*) _tmp39_, _n_index);
#line 157 "SerializableGeeHashMapTest.vala"
				n = (GXmlNode*) _tmp40_;
#line 158 "SerializableGeeHashMapTest.vala"
				_tmp42_ = n;
#line 158 "SerializableGeeHashMapTest.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp42_, GXML_TYPE_ELEMENT)) {
#line 1169 "SerializableGeeHashMapTest.c"
					GXmlNode* _tmp43_;
					gchar* _tmp44_;
					gchar* _tmp45_;
					gchar* _tmp46_;
#line 158 "SerializableGeeHashMapTest.vala"
					_tmp43_ = n;
#line 158 "SerializableGeeHashMapTest.vala"
					_tmp44_ = gxml_node_get_name (_tmp43_);
#line 158 "SerializableGeeHashMapTest.vala"
					_tmp45_ = _tmp44_;
#line 158 "SerializableGeeHashMapTest.vala"
					_tmp46_ = _tmp45_;
#line 158 "SerializableGeeHashMapTest.vala"
					_tmp41_ = g_strcmp0 (_tmp46_, "space") == 0;
#line 158 "SerializableGeeHashMapTest.vala"
					_g_free0 (_tmp46_);
#line 1186 "SerializableGeeHashMapTest.c"
				} else {
#line 158 "SerializableGeeHashMapTest.vala"
					_tmp41_ = FALSE;
#line 1190 "SerializableGeeHashMapTest.c"
				}
#line 158 "SerializableGeeHashMapTest.vala"
				if (_tmp41_) {
#line 1194 "SerializableGeeHashMapTest.c"
					GXmlNode* name = NULL;
					GXmlNode* _tmp47_;
					GeeMap* _tmp48_;
					GeeMap* _tmp49_;
					GeeMap* _tmp50_;
					gpointer _tmp51_;
					GXmlNode* _tmp52_;
					GXmlNode* _tmp53_;
					GXmlNode* _tmp64_;
					GeeBidirList* _tmp65_;
					GeeBidirList* _tmp66_;
					GeeBidirList* _tmp67_;
					gint _tmp68_;
					gint _tmp69_;
					gboolean _tmp70_;
#line 159 "SerializableGeeHashMapTest.vala"
					_tmp47_ = n;
#line 159 "SerializableGeeHashMapTest.vala"
					_tmp48_ = gxml_node_get_attrs (_tmp47_);
#line 159 "SerializableGeeHashMapTest.vala"
					_tmp49_ = _tmp48_;
#line 159 "SerializableGeeHashMapTest.vala"
					_tmp50_ = _tmp49_;
#line 159 "SerializableGeeHashMapTest.vala"
					_tmp51_ = gee_map_get (_tmp50_, "name");
#line 159 "SerializableGeeHashMapTest.vala"
					_tmp52_ = (GXmlNode*) _tmp51_;
#line 159 "SerializableGeeHashMapTest.vala"
					_g_object_unref0 (_tmp50_);
#line 159 "SerializableGeeHashMapTest.vala"
					name = _tmp52_;
#line 160 "SerializableGeeHashMapTest.vala"
					_tmp53_ = name;
#line 160 "SerializableGeeHashMapTest.vala"
					if (_tmp53_ != NULL) {
#line 1230 "SerializableGeeHashMapTest.c"
						GXmlNode* _tmp54_;
						gchar* _tmp55_;
						gchar* _tmp56_;
						gchar* _tmp57_;
						gboolean _tmp58_;
						GXmlNode* _tmp59_;
						gchar* _tmp60_;
						gchar* _tmp61_;
						gchar* _tmp62_;
						gboolean _tmp63_;
#line 161 "SerializableGeeHashMapTest.vala"
						_tmp54_ = name;
#line 161 "SerializableGeeHashMapTest.vala"
						_tmp55_ = gxml_node_get_value (_tmp54_);
#line 161 "SerializableGeeHashMapTest.vala"
						_tmp56_ = _tmp55_;
#line 161 "SerializableGeeHashMapTest.vala"
						_tmp57_ = _tmp56_;
#line 161 "SerializableGeeHashMapTest.vala"
						_tmp58_ = g_strcmp0 (_tmp57_, "Big") == 0;
#line 161 "SerializableGeeHashMapTest.vala"
						_g_free0 (_tmp57_);
#line 161 "SerializableGeeHashMapTest.vala"
						if (_tmp58_) {
#line 161 "SerializableGeeHashMapTest.vala"
							found1 = TRUE;
#line 1257 "SerializableGeeHashMapTest.c"
						}
#line 162 "SerializableGeeHashMapTest.vala"
						_tmp59_ = name;
#line 162 "SerializableGeeHashMapTest.vala"
						_tmp60_ = gxml_node_get_value (_tmp59_);
#line 162 "SerializableGeeHashMapTest.vala"
						_tmp61_ = _tmp60_;
#line 162 "SerializableGeeHashMapTest.vala"
						_tmp62_ = _tmp61_;
#line 162 "SerializableGeeHashMapTest.vala"
						_tmp63_ = g_strcmp0 (_tmp62_, "Small") == 0;
#line 162 "SerializableGeeHashMapTest.vala"
						_g_free0 (_tmp62_);
#line 162 "SerializableGeeHashMapTest.vala"
						if (_tmp63_) {
#line 162 "SerializableGeeHashMapTest.vala"
							found2 = TRUE;
#line 1275 "SerializableGeeHashMapTest.c"
						}
					}
#line 164 "SerializableGeeHashMapTest.vala"
					_tmp64_ = n;
#line 164 "SerializableGeeHashMapTest.vala"
					_tmp65_ = gxml_node_get_children_nodes (_tmp64_);
#line 164 "SerializableGeeHashMapTest.vala"
					_tmp66_ = _tmp65_;
#line 164 "SerializableGeeHashMapTest.vala"
					_tmp67_ = _tmp66_;
#line 164 "SerializableGeeHashMapTest.vala"
					_tmp68_ = gee_collection_get_size ((GeeCollection*) _tmp67_);
#line 164 "SerializableGeeHashMapTest.vala"
					_tmp69_ = _tmp68_;
#line 164 "SerializableGeeHashMapTest.vala"
					_tmp70_ = _tmp69_ > 0;
#line 164 "SerializableGeeHashMapTest.vala"
					_g_object_unref0 (_tmp67_);
#line 164 "SerializableGeeHashMapTest.vala"
					if (_tmp70_) {
#line 1296 "SerializableGeeHashMapTest.c"
						{
							GeeBidirList* _nd_list = NULL;
							GXmlNode* _tmp71_;
							GeeBidirList* _tmp72_;
							GeeBidirList* _tmp73_;
							gint _nd_size = 0;
							GeeBidirList* _tmp74_;
							gint _tmp75_;
							gint _tmp76_;
							gint _nd_index = 0;
#line 165 "SerializableGeeHashMapTest.vala"
							_tmp71_ = n;
#line 165 "SerializableGeeHashMapTest.vala"
							_tmp72_ = gxml_node_get_children_nodes (_tmp71_);
#line 165 "SerializableGeeHashMapTest.vala"
							_tmp73_ = _tmp72_;
#line 165 "SerializableGeeHashMapTest.vala"
							_nd_list = _tmp73_;
#line 165 "SerializableGeeHashMapTest.vala"
							_tmp74_ = _nd_list;
#line 165 "SerializableGeeHashMapTest.vala"
							_tmp75_ = gee_collection_get_size ((GeeCollection*) _tmp74_);
#line 165 "SerializableGeeHashMapTest.vala"
							_tmp76_ = _tmp75_;
#line 165 "SerializableGeeHashMapTest.vala"
							_nd_size = _tmp76_;
#line 165 "SerializableGeeHashMapTest.vala"
							_nd_index = -1;
#line 165 "SerializableGeeHashMapTest.vala"
							while (TRUE) {
#line 1327 "SerializableGeeHashMapTest.c"
								GXmlNode* nd = NULL;
								GeeBidirList* _tmp77_;
								gpointer _tmp78_;
								GXmlNode* _tmp79_;
#line 165 "SerializableGeeHashMapTest.vala"
								_nd_index = _nd_index + 1;
#line 165 "SerializableGeeHashMapTest.vala"
								if (!(_nd_index < _nd_size)) {
#line 165 "SerializableGeeHashMapTest.vala"
									break;
#line 1338 "SerializableGeeHashMapTest.c"
								}
#line 165 "SerializableGeeHashMapTest.vala"
								_tmp77_ = _nd_list;
#line 165 "SerializableGeeHashMapTest.vala"
								_tmp78_ = gee_list_get ((GeeList*) _tmp77_, _nd_index);
#line 165 "SerializableGeeHashMapTest.vala"
								nd = (GXmlNode*) _tmp78_;
#line 166 "SerializableGeeHashMapTest.vala"
								_tmp79_ = nd;
#line 166 "SerializableGeeHashMapTest.vala"
								if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp79_, GXML_TYPE_TEXT)) {
#line 1350 "SerializableGeeHashMapTest.c"
									GXmlNode* _tmp80_;
									gchar* _tmp81_;
									gchar* _tmp82_;
									gchar* _tmp83_;
									gboolean _tmp84_;
#line 167 "SerializableGeeHashMapTest.vala"
									_tmp80_ = nd;
#line 167 "SerializableGeeHashMapTest.vala"
									_tmp81_ = gxml_node_get_value (_tmp80_);
#line 167 "SerializableGeeHashMapTest.vala"
									_tmp82_ = _tmp81_;
#line 167 "SerializableGeeHashMapTest.vala"
									_tmp83_ = _tmp82_;
#line 167 "SerializableGeeHashMapTest.vala"
									_tmp84_ = g_strcmp0 (_tmp83_, "FAKE TEXT") != 0;
#line 167 "SerializableGeeHashMapTest.vala"
									_g_free0 (_tmp83_);
#line 167 "SerializableGeeHashMapTest.vala"
									if (_tmp84_) {
#line 1370 "SerializableGeeHashMapTest.c"
										GXmlNode* _tmp85_;
										gchar* _tmp86_;
										gchar* _tmp87_;
										gchar* _tmp88_;
										const gchar* _tmp89_;
										GXmlTDocument* _tmp90_;
										gchar* _tmp91_;
										gchar* _tmp92_;
										gchar* _tmp93_;
										gchar* _tmp94_;
#line 168 "SerializableGeeHashMapTest.vala"
										_tmp85_ = nd;
#line 168 "SerializableGeeHashMapTest.vala"
										_tmp86_ = gxml_node_get_value (_tmp85_);
#line 168 "SerializableGeeHashMapTest.vala"
										_tmp87_ = _tmp86_;
#line 168 "SerializableGeeHashMapTest.vala"
										_tmp88_ = _tmp87_;
#line 168 "SerializableGeeHashMapTest.vala"
										_tmp89_ = string_to_string (_tmp88_);
#line 168 "SerializableGeeHashMapTest.vala"
										_tmp90_ = doc;
#line 168 "SerializableGeeHashMapTest.vala"
										_tmp91_ = gxml_tnode_to_string ((GXmlTNode*) _tmp90_);
#line 168 "SerializableGeeHashMapTest.vala"
										_tmp92_ = _tmp91_;
#line 168 "SerializableGeeHashMapTest.vala"
										_tmp93_ = g_strconcat ("ERROR: node content don't much. Expected 'FAKE TEXT', got: ", _tmp89_, "\n", _tmp92_, "\n", NULL);
#line 168 "SerializableGeeHashMapTest.vala"
										_tmp94_ = _tmp93_;
#line 168 "SerializableGeeHashMapTest.vala"
										g_message ("SerializableGeeHashMapTest.vala:168: %s", _tmp94_);
#line 168 "SerializableGeeHashMapTest.vala"
										_g_free0 (_tmp94_);
#line 168 "SerializableGeeHashMapTest.vala"
										_g_free0 (_tmp92_);
#line 168 "SerializableGeeHashMapTest.vala"
										_g_free0 (_tmp88_);
#line 169 "SerializableGeeHashMapTest.vala"
										g_assert_not_reached ();
#line 1411 "SerializableGeeHashMapTest.c"
									}
								}
#line 165 "SerializableGeeHashMapTest.vala"
								_g_object_unref0 (nd);
#line 1416 "SerializableGeeHashMapTest.c"
							}
#line 165 "SerializableGeeHashMapTest.vala"
							_g_object_unref0 (_nd_list);
#line 1420 "SerializableGeeHashMapTest.c"
						}
					}
#line 158 "SerializableGeeHashMapTest.vala"
					_g_object_unref0 (name);
#line 1425 "SerializableGeeHashMapTest.c"
				}
#line 157 "SerializableGeeHashMapTest.vala"
				_g_object_unref0 (n);
#line 1429 "SerializableGeeHashMapTest.c"
			}
#line 157 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (_n_list);
#line 1433 "SerializableGeeHashMapTest.c"
		}
#line 176 "SerializableGeeHashMapTest.vala"
		if (!found1) {
#line 1437 "SerializableGeeHashMapTest.c"
			GXmlTDocument* _tmp95_;
			gchar* _tmp96_;
			gchar* _tmp97_;
			gchar* _tmp98_;
			gchar* _tmp99_;
#line 177 "SerializableGeeHashMapTest.vala"
			_tmp95_ = doc;
#line 177 "SerializableGeeHashMapTest.vala"
			_tmp96_ = gxml_tnode_to_string ((GXmlTNode*) _tmp95_);
#line 177 "SerializableGeeHashMapTest.vala"
			_tmp97_ = _tmp96_;
#line 177 "SerializableGeeHashMapTest.vala"
			_tmp98_ = g_strconcat ("ERROR: Big space node is not found\n", _tmp97_, "\n", NULL);
#line 177 "SerializableGeeHashMapTest.vala"
			_tmp99_ = _tmp98_;
#line 177 "SerializableGeeHashMapTest.vala"
			g_message ("SerializableGeeHashMapTest.vala:177: %s", _tmp99_);
#line 177 "SerializableGeeHashMapTest.vala"
			_g_free0 (_tmp99_);
#line 177 "SerializableGeeHashMapTest.vala"
			_g_free0 (_tmp97_);
#line 178 "SerializableGeeHashMapTest.vala"
			g_assert_not_reached ();
#line 1461 "SerializableGeeHashMapTest.c"
		}
#line 180 "SerializableGeeHashMapTest.vala"
		if (!found2) {
#line 1465 "SerializableGeeHashMapTest.c"
			GXmlTDocument* _tmp100_;
			gchar* _tmp101_;
			gchar* _tmp102_;
			gchar* _tmp103_;
			gchar* _tmp104_;
#line 181 "SerializableGeeHashMapTest.vala"
			_tmp100_ = doc;
#line 181 "SerializableGeeHashMapTest.vala"
			_tmp101_ = gxml_tnode_to_string ((GXmlTNode*) _tmp100_);
#line 181 "SerializableGeeHashMapTest.vala"
			_tmp102_ = _tmp101_;
#line 181 "SerializableGeeHashMapTest.vala"
			_tmp103_ = g_strconcat ("ERROR: Small space node is not found\n", _tmp102_, "\n", NULL);
#line 181 "SerializableGeeHashMapTest.vala"
			_tmp104_ = _tmp103_;
#line 181 "SerializableGeeHashMapTest.vala"
			g_message ("SerializableGeeHashMapTest.vala:181: %s", _tmp104_);
#line 181 "SerializableGeeHashMapTest.vala"
			_g_free0 (_tmp104_);
#line 181 "SerializableGeeHashMapTest.vala"
			_g_free0 (_tmp102_);
#line 182 "SerializableGeeHashMapTest.vala"
			g_assert_not_reached ();
#line 1489 "SerializableGeeHashMapTest.c"
		}
#line 142 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (root);
#line 142 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (doc);
#line 142 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (o2);
#line 142 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (o1);
#line 142 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (c);
#line 1501 "SerializableGeeHashMapTest.c"
	}
	goto __finally362;
	__catch362_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp105_;
		const gchar* _tmp106_;
		gchar* _tmp107_;
		gchar* _tmp108_;
#line 142 "SerializableGeeHashMapTest.vala"
		e = _inner_error0_;
#line 142 "SerializableGeeHashMapTest.vala"
		_inner_error0_ = NULL;
#line 186 "SerializableGeeHashMapTest.vala"
		_tmp105_ = e->message;
#line 186 "SerializableGeeHashMapTest.vala"
		_tmp106_ = string_to_string (_tmp105_);
#line 186 "SerializableGeeHashMapTest.vala"
		_tmp107_ = g_strconcat ("ERROR: ", _tmp106_, NULL);
#line 186 "SerializableGeeHashMapTest.vala"
		_tmp108_ = _tmp107_;
#line 186 "SerializableGeeHashMapTest.vala"
		g_message ("SerializableGeeHashMapTest.vala:186: %s", _tmp108_);
#line 186 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp108_);
#line 187 "SerializableGeeHashMapTest.vala"
		g_assert_not_reached ();
#line 142 "SerializableGeeHashMapTest.vala"
		_g_error_free0 (e);
#line 1531 "SerializableGeeHashMapTest.c"
	}
	__finally362:
#line 142 "SerializableGeeHashMapTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 142 "SerializableGeeHashMapTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 142 "SerializableGeeHashMapTest.vala"
		g_clear_error (&_inner_error0_);
#line 142 "SerializableGeeHashMapTest.vala"
		return;
#line 1542 "SerializableGeeHashMapTest.c"
	}
}

static void
___lambda312__gtest_func (void)
{
#line 140 "SerializableGeeHashMapTest.vala"
	__lambda312_ ();
#line 1551 "SerializableGeeHashMapTest.c"
}

static void
__lambda313_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlSerializableHashMap* c = NULL;
		GXmlSerializableHashMap* _tmp1_;
		GXmlSerializableHashMap* _tmp2_;
		GXmlGDocument* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		GXmlSerializableHashMap* _tmp7_;
		gint _tmp8_;
		gint _tmp9_;
		gboolean found1 = FALSE;
		gboolean found2 = FALSE;
#line 193 "SerializableGeeHashMapTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"  <root><space name=\"Big\"/><space name=\"Small\"/></root>", 0, &_inner_error0_);
#line 193 "SerializableGeeHashMapTest.vala"
		doc = _tmp0_;
#line 193 "SerializableGeeHashMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1579 "SerializableGeeHashMapTest.c"
			goto __catch363_g_error;
		}
#line 195 "SerializableGeeHashMapTest.vala"
		_tmp1_ = gxml_serializable_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 195 "SerializableGeeHashMapTest.vala"
		c = _tmp1_;
#line 196 "SerializableGeeHashMapTest.vala"
		_tmp2_ = c;
#line 196 "SerializableGeeHashMapTest.vala"
		_tmp3_ = doc;
#line 196 "SerializableGeeHashMapTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) _tmp3_);
#line 196 "SerializableGeeHashMapTest.vala"
		_tmp5_ = _tmp4_;
#line 196 "SerializableGeeHashMapTest.vala"
		_tmp6_ = _tmp5_;
#line 196 "SerializableGeeHashMapTest.vala"
		gxml_serializable_hash_map_deserialize (_tmp2_, _tmp6_, &_inner_error0_);
#line 196 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp6_);
#line 196 "SerializableGeeHashMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 196 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (c);
#line 196 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (doc);
#line 1606 "SerializableGeeHashMapTest.c"
			goto __catch363_g_error;
		}
#line 197 "SerializableGeeHashMapTest.vala"
		_tmp7_ = c;
#line 197 "SerializableGeeHashMapTest.vala"
		_tmp8_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp7_);
#line 197 "SerializableGeeHashMapTest.vala"
		_tmp9_ = _tmp8_;
#line 197 "SerializableGeeHashMapTest.vala"
		if (_tmp9_ != 2) {
#line 1617 "SerializableGeeHashMapTest.c"
			GXmlSerializableHashMap* _tmp10_;
			gint _tmp11_;
			gint _tmp12_;
			gchar* _tmp13_;
			gchar* _tmp14_;
			gchar* _tmp15_;
			gchar* _tmp16_;
#line 198 "SerializableGeeHashMapTest.vala"
			_tmp10_ = c;
#line 198 "SerializableGeeHashMapTest.vala"
			_tmp11_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp10_);
#line 198 "SerializableGeeHashMapTest.vala"
			_tmp12_ = _tmp11_;
#line 198 "SerializableGeeHashMapTest.vala"
			_tmp13_ = g_strdup_printf ("%i", _tmp12_);
#line 198 "SerializableGeeHashMapTest.vala"
			_tmp14_ = _tmp13_;
#line 198 "SerializableGeeHashMapTest.vala"
			_tmp15_ = g_strconcat ("ERROR: incorrect size must be 2 got: ", _tmp14_, "\n", NULL);
#line 198 "SerializableGeeHashMapTest.vala"
			_tmp16_ = _tmp15_;
#line 198 "SerializableGeeHashMapTest.vala"
			g_message ("SerializableGeeHashMapTest.vala:198: %s", _tmp16_);
#line 198 "SerializableGeeHashMapTest.vala"
			_g_free0 (_tmp16_);
#line 198 "SerializableGeeHashMapTest.vala"
			_g_free0 (_tmp14_);
#line 199 "SerializableGeeHashMapTest.vala"
			g_assert_not_reached ();
#line 1647 "SerializableGeeHashMapTest.c"
		}
#line 201 "SerializableGeeHashMapTest.vala"
		found1 = FALSE;
#line 202 "SerializableGeeHashMapTest.vala"
		found2 = FALSE;
#line 1653 "SerializableGeeHashMapTest.c"
		{
			GeeIterator* _k_it = NULL;
			GXmlSerializableHashMap* _tmp17_;
			GeeSet* _tmp18_;
			GeeSet* _tmp19_;
			GeeSet* _tmp20_;
			GeeIterator* _tmp21_;
			GeeIterator* _tmp22_;
#line 203 "SerializableGeeHashMapTest.vala"
			_tmp17_ = c;
#line 203 "SerializableGeeHashMapTest.vala"
			_tmp18_ = gee_abstract_map_get_keys ((GeeAbstractMap*) _tmp17_);
#line 203 "SerializableGeeHashMapTest.vala"
			_tmp19_ = _tmp18_;
#line 203 "SerializableGeeHashMapTest.vala"
			_tmp20_ = _tmp19_;
#line 203 "SerializableGeeHashMapTest.vala"
			_tmp21_ = gee_iterable_iterator ((GeeIterable*) _tmp20_);
#line 203 "SerializableGeeHashMapTest.vala"
			_tmp22_ = _tmp21_;
#line 203 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (_tmp20_);
#line 203 "SerializableGeeHashMapTest.vala"
			_k_it = _tmp22_;
#line 203 "SerializableGeeHashMapTest.vala"
			while (TRUE) {
#line 1680 "SerializableGeeHashMapTest.c"
				GeeIterator* _tmp23_;
				gchar* k = NULL;
				GeeIterator* _tmp24_;
				gpointer _tmp25_;
				GXmlSerializableHashMap* _tmp26_;
				const gchar* _tmp27_;
				gpointer _tmp28_;
				SerializableGeeHashMapTestSpace* _tmp29_;
				const gchar* _tmp30_;
				const gchar* _tmp31_;
				gboolean _tmp32_;
				GXmlSerializableHashMap* _tmp33_;
				const gchar* _tmp34_;
				gpointer _tmp35_;
				SerializableGeeHashMapTestSpace* _tmp36_;
				const gchar* _tmp37_;
				const gchar* _tmp38_;
				gboolean _tmp39_;
#line 203 "SerializableGeeHashMapTest.vala"
				_tmp23_ = _k_it;
#line 203 "SerializableGeeHashMapTest.vala"
				if (!gee_iterator_next (_tmp23_)) {
#line 203 "SerializableGeeHashMapTest.vala"
					break;
#line 1705 "SerializableGeeHashMapTest.c"
				}
#line 203 "SerializableGeeHashMapTest.vala"
				_tmp24_ = _k_it;
#line 203 "SerializableGeeHashMapTest.vala"
				_tmp25_ = gee_iterator_get (_tmp24_);
#line 203 "SerializableGeeHashMapTest.vala"
				k = (gchar*) _tmp25_;
#line 204 "SerializableGeeHashMapTest.vala"
				_tmp26_ = c;
#line 204 "SerializableGeeHashMapTest.vala"
				_tmp27_ = k;
#line 204 "SerializableGeeHashMapTest.vala"
				_tmp28_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp26_, _tmp27_);
#line 204 "SerializableGeeHashMapTest.vala"
				_tmp29_ = (SerializableGeeHashMapTestSpace*) _tmp28_;
#line 204 "SerializableGeeHashMapTest.vala"
				_tmp30_ = serializable_gee_hash_map_test_space_get_name (_tmp29_);
#line 204 "SerializableGeeHashMapTest.vala"
				_tmp31_ = _tmp30_;
#line 204 "SerializableGeeHashMapTest.vala"
				_tmp32_ = g_strcmp0 (_tmp31_, "Big") == 0;
#line 204 "SerializableGeeHashMapTest.vala"
				_g_object_unref0 (_tmp29_);
#line 204 "SerializableGeeHashMapTest.vala"
				if (_tmp32_) {
#line 204 "SerializableGeeHashMapTest.vala"
					found1 = TRUE;
#line 1733 "SerializableGeeHashMapTest.c"
				}
#line 205 "SerializableGeeHashMapTest.vala"
				_tmp33_ = c;
#line 205 "SerializableGeeHashMapTest.vala"
				_tmp34_ = k;
#line 205 "SerializableGeeHashMapTest.vala"
				_tmp35_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp33_, _tmp34_);
#line 205 "SerializableGeeHashMapTest.vala"
				_tmp36_ = (SerializableGeeHashMapTestSpace*) _tmp35_;
#line 205 "SerializableGeeHashMapTest.vala"
				_tmp37_ = serializable_gee_hash_map_test_space_get_name (_tmp36_);
#line 205 "SerializableGeeHashMapTest.vala"
				_tmp38_ = _tmp37_;
#line 205 "SerializableGeeHashMapTest.vala"
				_tmp39_ = g_strcmp0 (_tmp38_, "Small") == 0;
#line 205 "SerializableGeeHashMapTest.vala"
				_g_object_unref0 (_tmp36_);
#line 205 "SerializableGeeHashMapTest.vala"
				if (_tmp39_) {
#line 205 "SerializableGeeHashMapTest.vala"
					found2 = TRUE;
#line 1755 "SerializableGeeHashMapTest.c"
				}
#line 203 "SerializableGeeHashMapTest.vala"
				_g_free0 (k);
#line 1759 "SerializableGeeHashMapTest.c"
			}
#line 203 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (_k_it);
#line 1763 "SerializableGeeHashMapTest.c"
		}
#line 207 "SerializableGeeHashMapTest.vala"
		if (!found1) {
#line 208 "SerializableGeeHashMapTest.vala"
			g_message ("SerializableGeeHashMapTest.vala:208: %s", "ERROR: Big key value is not found\n");
#line 209 "SerializableGeeHashMapTest.vala"
			g_assert_not_reached ();
#line 1771 "SerializableGeeHashMapTest.c"
		}
#line 211 "SerializableGeeHashMapTest.vala"
		if (!found2) {
#line 212 "SerializableGeeHashMapTest.vala"
			g_message ("SerializableGeeHashMapTest.vala:212: %s", "ERROR: Small key value is not found\n");
#line 213 "SerializableGeeHashMapTest.vala"
			g_assert_not_reached ();
#line 1779 "SerializableGeeHashMapTest.c"
		}
#line 192 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (c);
#line 192 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (doc);
#line 1785 "SerializableGeeHashMapTest.c"
	}
	goto __finally363;
	__catch363_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp40_;
		const gchar* _tmp41_;
		gchar* _tmp42_;
		gchar* _tmp43_;
#line 192 "SerializableGeeHashMapTest.vala"
		e = _inner_error0_;
#line 192 "SerializableGeeHashMapTest.vala"
		_inner_error0_ = NULL;
#line 217 "SerializableGeeHashMapTest.vala"
		_tmp40_ = e->message;
#line 217 "SerializableGeeHashMapTest.vala"
		_tmp41_ = string_to_string (_tmp40_);
#line 217 "SerializableGeeHashMapTest.vala"
		_tmp42_ = g_strconcat ("ERROR: ", _tmp41_, NULL);
#line 217 "SerializableGeeHashMapTest.vala"
		_tmp43_ = _tmp42_;
#line 217 "SerializableGeeHashMapTest.vala"
		g_message ("SerializableGeeHashMapTest.vala:217: %s", _tmp43_);
#line 217 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp43_);
#line 218 "SerializableGeeHashMapTest.vala"
		g_assert_not_reached ();
#line 192 "SerializableGeeHashMapTest.vala"
		_g_error_free0 (e);
#line 1815 "SerializableGeeHashMapTest.c"
	}
	__finally363:
#line 192 "SerializableGeeHashMapTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 192 "SerializableGeeHashMapTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 192 "SerializableGeeHashMapTest.vala"
		g_clear_error (&_inner_error0_);
#line 192 "SerializableGeeHashMapTest.vala"
		return;
#line 1826 "SerializableGeeHashMapTest.c"
	}
}

static void
___lambda313__gtest_func (void)
{
#line 190 "SerializableGeeHashMapTest.vala"
	__lambda313_ ();
#line 1835 "SerializableGeeHashMapTest.c"
}

static void
__lambda314_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		SerializableGeeHashMapTestSpaceContainer* c = NULL;
		SerializableGeeHashMapTestSpaceContainer* _tmp1_;
		SerializableGeeHashMapTestSpaceContainer* _tmp2_;
		GXmlGDocument* _tmp3_;
		SerializableGeeHashMapTestSpaceContainer* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		SerializableGeeHashMapTestSpaceContainer* _tmp16_;
		SerializableGeeHashMapTestSpaceCollection* _tmp17_;
		SerializableGeeHashMapTestSpaceCollection* _tmp18_;
		gint _tmp19_;
		gint _tmp20_;
		gboolean found1 = FALSE;
		gboolean found2 = FALSE;
#line 224 "SerializableGeeHashMapTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"  <spacecontainer owner=\"Earth\"><space name=\"Big\"/><space name=\"S" \
"mall\"/></spacecontainer>", 0, &_inner_error0_);
#line 224 "SerializableGeeHashMapTest.vala"
		doc = _tmp0_;
#line 224 "SerializableGeeHashMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1865 "SerializableGeeHashMapTest.c"
			goto __catch364_g_error;
		}
#line 226 "SerializableGeeHashMapTest.vala"
		_tmp1_ = serializable_gee_hash_map_test_space_container_new ();
#line 226 "SerializableGeeHashMapTest.vala"
		c = _tmp1_;
#line 227 "SerializableGeeHashMapTest.vala"
		_tmp2_ = c;
#line 227 "SerializableGeeHashMapTest.vala"
		_tmp3_ = doc;
#line 227 "SerializableGeeHashMapTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 227 "SerializableGeeHashMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 227 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (c);
#line 227 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (doc);
#line 1884 "SerializableGeeHashMapTest.c"
			goto __catch364_g_error;
		}
#line 228 "SerializableGeeHashMapTest.vala"
		_tmp4_ = c;
#line 228 "SerializableGeeHashMapTest.vala"
		_tmp5_ = serializable_gee_hash_map_test_space_container_get_owner (_tmp4_);
#line 228 "SerializableGeeHashMapTest.vala"
		_tmp6_ = _tmp5_;
#line 228 "SerializableGeeHashMapTest.vala"
		if (g_strcmp0 (_tmp6_, "Earth") != 0) {
#line 1895 "SerializableGeeHashMapTest.c"
			SerializableGeeHashMapTestSpaceContainer* _tmp7_;
			const gchar* _tmp8_;
			const gchar* _tmp9_;
			const gchar* _tmp10_;
			GXmlGDocument* _tmp11_;
			gchar* _tmp12_;
			gchar* _tmp13_;
			gchar* _tmp14_;
			gchar* _tmp15_;
#line 229 "SerializableGeeHashMapTest.vala"
			_tmp7_ = c;
#line 229 "SerializableGeeHashMapTest.vala"
			_tmp8_ = serializable_gee_hash_map_test_space_container_get_owner (_tmp7_);
#line 229 "SerializableGeeHashMapTest.vala"
			_tmp9_ = _tmp8_;
#line 229 "SerializableGeeHashMapTest.vala"
			_tmp10_ = string_to_string (_tmp9_);
#line 229 "SerializableGeeHashMapTest.vala"
			_tmp11_ = doc;
#line 229 "SerializableGeeHashMapTest.vala"
			_tmp12_ = gxml_gnode_to_string ((GXmlGNode*) _tmp11_);
#line 229 "SerializableGeeHashMapTest.vala"
			_tmp13_ = _tmp12_;
#line 229 "SerializableGeeHashMapTest.vala"
			_tmp14_ = g_strconcat ("ERROR: owner must be 'Earth' got: ", _tmp10_, "\n", _tmp13_, "\n", NULL);
#line 229 "SerializableGeeHashMapTest.vala"
			_tmp15_ = _tmp14_;
#line 229 "SerializableGeeHashMapTest.vala"
			g_message ("SerializableGeeHashMapTest.vala:229: %s", _tmp15_);
#line 229 "SerializableGeeHashMapTest.vala"
			_g_free0 (_tmp15_);
#line 229 "SerializableGeeHashMapTest.vala"
			_g_free0 (_tmp13_);
#line 230 "SerializableGeeHashMapTest.vala"
			g_assert_not_reached ();
#line 1931 "SerializableGeeHashMapTest.c"
		}
#line 232 "SerializableGeeHashMapTest.vala"
		_tmp16_ = c;
#line 232 "SerializableGeeHashMapTest.vala"
		_tmp17_ = serializable_gee_hash_map_test_space_container_get_storage (_tmp16_);
#line 232 "SerializableGeeHashMapTest.vala"
		_tmp18_ = _tmp17_;
#line 232 "SerializableGeeHashMapTest.vala"
		_tmp19_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp18_);
#line 232 "SerializableGeeHashMapTest.vala"
		_tmp20_ = _tmp19_;
#line 232 "SerializableGeeHashMapTest.vala"
		if (_tmp20_ != 2) {
#line 1945 "SerializableGeeHashMapTest.c"
			SerializableGeeHashMapTestSpaceContainer* _tmp21_;
			SerializableGeeHashMapTestSpaceCollection* _tmp22_;
			SerializableGeeHashMapTestSpaceCollection* _tmp23_;
			gint _tmp24_;
			gint _tmp25_;
			gchar* _tmp26_;
			gchar* _tmp27_;
			GXmlGDocument* _tmp28_;
			gchar* _tmp29_;
			gchar* _tmp30_;
			gchar* _tmp31_;
			gchar* _tmp32_;
#line 233 "SerializableGeeHashMapTest.vala"
			_tmp21_ = c;
#line 233 "SerializableGeeHashMapTest.vala"
			_tmp22_ = serializable_gee_hash_map_test_space_container_get_storage (_tmp21_);
#line 233 "SerializableGeeHashMapTest.vala"
			_tmp23_ = _tmp22_;
#line 233 "SerializableGeeHashMapTest.vala"
			_tmp24_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp23_);
#line 233 "SerializableGeeHashMapTest.vala"
			_tmp25_ = _tmp24_;
#line 233 "SerializableGeeHashMapTest.vala"
			_tmp26_ = g_strdup_printf ("%i", _tmp25_);
#line 233 "SerializableGeeHashMapTest.vala"
			_tmp27_ = _tmp26_;
#line 233 "SerializableGeeHashMapTest.vala"
			_tmp28_ = doc;
#line 233 "SerializableGeeHashMapTest.vala"
			_tmp29_ = gxml_gnode_to_string ((GXmlGNode*) _tmp28_);
#line 233 "SerializableGeeHashMapTest.vala"
			_tmp30_ = _tmp29_;
#line 233 "SerializableGeeHashMapTest.vala"
			_tmp31_ = g_strconcat ("ERROR: Size must be 2 got: ", _tmp27_, "\n", _tmp30_, "\n", NULL);
#line 233 "SerializableGeeHashMapTest.vala"
			_tmp32_ = _tmp31_;
#line 233 "SerializableGeeHashMapTest.vala"
			g_message ("SerializableGeeHashMapTest.vala:233: %s", _tmp32_);
#line 233 "SerializableGeeHashMapTest.vala"
			_g_free0 (_tmp32_);
#line 233 "SerializableGeeHashMapTest.vala"
			_g_free0 (_tmp30_);
#line 233 "SerializableGeeHashMapTest.vala"
			_g_free0 (_tmp27_);
#line 234 "SerializableGeeHashMapTest.vala"
			g_assert_not_reached ();
#line 1992 "SerializableGeeHashMapTest.c"
		}
#line 236 "SerializableGeeHashMapTest.vala"
		found1 = FALSE;
#line 237 "SerializableGeeHashMapTest.vala"
		found2 = FALSE;
#line 1998 "SerializableGeeHashMapTest.c"
		{
			GeeIterator* _k_it = NULL;
			SerializableGeeHashMapTestSpaceContainer* _tmp33_;
			SerializableGeeHashMapTestSpaceCollection* _tmp34_;
			SerializableGeeHashMapTestSpaceCollection* _tmp35_;
			GeeSet* _tmp36_;
			GeeSet* _tmp37_;
			GeeSet* _tmp38_;
			GeeIterator* _tmp39_;
			GeeIterator* _tmp40_;
#line 238 "SerializableGeeHashMapTest.vala"
			_tmp33_ = c;
#line 238 "SerializableGeeHashMapTest.vala"
			_tmp34_ = serializable_gee_hash_map_test_space_container_get_storage (_tmp33_);
#line 238 "SerializableGeeHashMapTest.vala"
			_tmp35_ = _tmp34_;
#line 238 "SerializableGeeHashMapTest.vala"
			_tmp36_ = gee_abstract_map_get_keys ((GeeAbstractMap*) _tmp35_);
#line 238 "SerializableGeeHashMapTest.vala"
			_tmp37_ = _tmp36_;
#line 238 "SerializableGeeHashMapTest.vala"
			_tmp38_ = _tmp37_;
#line 238 "SerializableGeeHashMapTest.vala"
			_tmp39_ = gee_iterable_iterator ((GeeIterable*) _tmp38_);
#line 238 "SerializableGeeHashMapTest.vala"
			_tmp40_ = _tmp39_;
#line 238 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (_tmp38_);
#line 238 "SerializableGeeHashMapTest.vala"
			_k_it = _tmp40_;
#line 238 "SerializableGeeHashMapTest.vala"
			while (TRUE) {
#line 2031 "SerializableGeeHashMapTest.c"
				GeeIterator* _tmp41_;
				gchar* k = NULL;
				GeeIterator* _tmp42_;
				gpointer _tmp43_;
				SerializableGeeHashMapTestSpaceContainer* _tmp44_;
				SerializableGeeHashMapTestSpaceCollection* _tmp45_;
				SerializableGeeHashMapTestSpaceCollection* _tmp46_;
				const gchar* _tmp47_;
				gpointer _tmp48_;
				SerializableGeeHashMapTestSpace* _tmp49_;
				const gchar* _tmp50_;
				const gchar* _tmp51_;
				gboolean _tmp52_;
				SerializableGeeHashMapTestSpaceContainer* _tmp53_;
				SerializableGeeHashMapTestSpaceCollection* _tmp54_;
				SerializableGeeHashMapTestSpaceCollection* _tmp55_;
				const gchar* _tmp56_;
				gpointer _tmp57_;
				SerializableGeeHashMapTestSpace* _tmp58_;
				const gchar* _tmp59_;
				const gchar* _tmp60_;
				gboolean _tmp61_;
#line 238 "SerializableGeeHashMapTest.vala"
				_tmp41_ = _k_it;
#line 238 "SerializableGeeHashMapTest.vala"
				if (!gee_iterator_next (_tmp41_)) {
#line 238 "SerializableGeeHashMapTest.vala"
					break;
#line 2060 "SerializableGeeHashMapTest.c"
				}
#line 238 "SerializableGeeHashMapTest.vala"
				_tmp42_ = _k_it;
#line 238 "SerializableGeeHashMapTest.vala"
				_tmp43_ = gee_iterator_get (_tmp42_);
#line 238 "SerializableGeeHashMapTest.vala"
				k = (gchar*) _tmp43_;
#line 239 "SerializableGeeHashMapTest.vala"
				_tmp44_ = c;
#line 239 "SerializableGeeHashMapTest.vala"
				_tmp45_ = serializable_gee_hash_map_test_space_container_get_storage (_tmp44_);
#line 239 "SerializableGeeHashMapTest.vala"
				_tmp46_ = _tmp45_;
#line 239 "SerializableGeeHashMapTest.vala"
				_tmp47_ = k;
#line 239 "SerializableGeeHashMapTest.vala"
				_tmp48_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp46_, _tmp47_);
#line 239 "SerializableGeeHashMapTest.vala"
				_tmp49_ = (SerializableGeeHashMapTestSpace*) _tmp48_;
#line 239 "SerializableGeeHashMapTest.vala"
				_tmp50_ = serializable_gee_hash_map_test_space_get_name (_tmp49_);
#line 239 "SerializableGeeHashMapTest.vala"
				_tmp51_ = _tmp50_;
#line 239 "SerializableGeeHashMapTest.vala"
				_tmp52_ = g_strcmp0 (_tmp51_, "Big") == 0;
#line 239 "SerializableGeeHashMapTest.vala"
				_g_object_unref0 (_tmp49_);
#line 239 "SerializableGeeHashMapTest.vala"
				if (_tmp52_) {
#line 239 "SerializableGeeHashMapTest.vala"
					found1 = TRUE;
#line 2092 "SerializableGeeHashMapTest.c"
				}
#line 240 "SerializableGeeHashMapTest.vala"
				_tmp53_ = c;
#line 240 "SerializableGeeHashMapTest.vala"
				_tmp54_ = serializable_gee_hash_map_test_space_container_get_storage (_tmp53_);
#line 240 "SerializableGeeHashMapTest.vala"
				_tmp55_ = _tmp54_;
#line 240 "SerializableGeeHashMapTest.vala"
				_tmp56_ = k;
#line 240 "SerializableGeeHashMapTest.vala"
				_tmp57_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp55_, _tmp56_);
#line 240 "SerializableGeeHashMapTest.vala"
				_tmp58_ = (SerializableGeeHashMapTestSpace*) _tmp57_;
#line 240 "SerializableGeeHashMapTest.vala"
				_tmp59_ = serializable_gee_hash_map_test_space_get_name (_tmp58_);
#line 240 "SerializableGeeHashMapTest.vala"
				_tmp60_ = _tmp59_;
#line 240 "SerializableGeeHashMapTest.vala"
				_tmp61_ = g_strcmp0 (_tmp60_, "Small") == 0;
#line 240 "SerializableGeeHashMapTest.vala"
				_g_object_unref0 (_tmp58_);
#line 240 "SerializableGeeHashMapTest.vala"
				if (_tmp61_) {
#line 240 "SerializableGeeHashMapTest.vala"
					found2 = TRUE;
#line 2118 "SerializableGeeHashMapTest.c"
				}
#line 238 "SerializableGeeHashMapTest.vala"
				_g_free0 (k);
#line 2122 "SerializableGeeHashMapTest.c"
			}
#line 238 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (_k_it);
#line 2126 "SerializableGeeHashMapTest.c"
		}
#line 242 "SerializableGeeHashMapTest.vala"
		if (!found1) {
#line 243 "SerializableGeeHashMapTest.vala"
			g_message ("SerializableGeeHashMapTest.vala:243: %s", "ERROR: Big key value is not found\n");
#line 244 "SerializableGeeHashMapTest.vala"
			g_assert_not_reached ();
#line 2134 "SerializableGeeHashMapTest.c"
		}
#line 246 "SerializableGeeHashMapTest.vala"
		if (!found2) {
#line 247 "SerializableGeeHashMapTest.vala"
			g_message ("SerializableGeeHashMapTest.vala:247: %s", "ERROR: Small key value is not found\n");
#line 248 "SerializableGeeHashMapTest.vala"
			g_assert_not_reached ();
#line 2142 "SerializableGeeHashMapTest.c"
		}
#line 223 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (c);
#line 223 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (doc);
#line 2148 "SerializableGeeHashMapTest.c"
	}
	goto __finally364;
	__catch364_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp62_;
		const gchar* _tmp63_;
		gchar* _tmp64_;
		gchar* _tmp65_;
#line 223 "SerializableGeeHashMapTest.vala"
		e = _inner_error0_;
#line 223 "SerializableGeeHashMapTest.vala"
		_inner_error0_ = NULL;
#line 252 "SerializableGeeHashMapTest.vala"
		_tmp62_ = e->message;
#line 252 "SerializableGeeHashMapTest.vala"
		_tmp63_ = string_to_string (_tmp62_);
#line 252 "SerializableGeeHashMapTest.vala"
		_tmp64_ = g_strconcat ("ERROR: ", _tmp63_, NULL);
#line 252 "SerializableGeeHashMapTest.vala"
		_tmp65_ = _tmp64_;
#line 252 "SerializableGeeHashMapTest.vala"
		g_message ("SerializableGeeHashMapTest.vala:252: %s", _tmp65_);
#line 252 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp65_);
#line 253 "SerializableGeeHashMapTest.vala"
		g_assert_not_reached ();
#line 223 "SerializableGeeHashMapTest.vala"
		_g_error_free0 (e);
#line 2178 "SerializableGeeHashMapTest.c"
	}
	__finally364:
#line 223 "SerializableGeeHashMapTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 223 "SerializableGeeHashMapTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 223 "SerializableGeeHashMapTest.vala"
		g_clear_error (&_inner_error0_);
#line 223 "SerializableGeeHashMapTest.vala"
		return;
#line 2189 "SerializableGeeHashMapTest.c"
	}
}

static void
___lambda314__gtest_func (void)
{
#line 221 "SerializableGeeHashMapTest.vala"
	__lambda314_ ();
#line 2198 "SerializableGeeHashMapTest.c"
}

static void
__lambda315_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		SerializableGeeHashMapTestSpaceContainer* c = NULL;
		SerializableGeeHashMapTestSpaceContainer* _tmp0_;
		SerializableGeeHashMapTestSpace* o1 = NULL;
		SerializableGeeHashMapTestSpace* _tmp1_;
		SerializableGeeHashMapTestSpace* o2 = NULL;
		SerializableGeeHashMapTestSpace* _tmp2_;
		SerializableGeeHashMapTestSpaceCollection* _tmp3_;
		SerializableGeeHashMapTestSpaceCollection* _tmp4_;
		SerializableGeeHashMapTestSpaceCollection* _tmp5_;
		SerializableGeeHashMapTestSpaceCollection* _tmp6_;
		const gchar* _tmp7_;
		const gchar* _tmp8_;
		SerializableGeeHashMapTestSpaceCollection* _tmp9_;
		SerializableGeeHashMapTestSpaceCollection* _tmp10_;
		const gchar* _tmp11_;
		const gchar* _tmp12_;
		GXmlTDocument* doc = NULL;
		GXmlTDocument* _tmp13_;
		GXmlNode* _tmp14_;
		GXmlNode* _tmp15_;
		GXmlNode* _tmp16_;
		GXmlNode* _tmp17_;
		GXmlNode* _tmp18_;
		GXmlNode* _tmp19_;
		GXmlNode* _tmp20_;
		GXmlNode* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
		GXmlNode* root = NULL;
		GXmlNode* _tmp25_;
		GXmlNode* _tmp26_;
		GXmlNode* _tmp27_;
		GeeBidirList* _tmp28_;
		GeeBidirList* _tmp29_;
		GeeBidirList* _tmp30_;
		gint _tmp31_;
		gint _tmp32_;
		gboolean found1 = FALSE;
		gboolean found2 = FALSE;
#line 259 "SerializableGeeHashMapTest.vala"
		_tmp0_ = serializable_gee_hash_map_test_space_container_new ();
#line 259 "SerializableGeeHashMapTest.vala"
		c = _tmp0_;
#line 260 "SerializableGeeHashMapTest.vala"
		_tmp1_ = serializable_gee_hash_map_test_space_new_named ("Big");
#line 260 "SerializableGeeHashMapTest.vala"
		o1 = _tmp1_;
#line 261 "SerializableGeeHashMapTest.vala"
		_tmp2_ = serializable_gee_hash_map_test_space_new_named ("Small");
#line 261 "SerializableGeeHashMapTest.vala"
		o2 = _tmp2_;
#line 262 "SerializableGeeHashMapTest.vala"
		_tmp3_ = serializable_gee_hash_map_test_space_collection_new ();
#line 262 "SerializableGeeHashMapTest.vala"
		_tmp4_ = _tmp3_;
#line 262 "SerializableGeeHashMapTest.vala"
		serializable_gee_hash_map_test_space_container_set_storage (c, _tmp4_);
#line 262 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp4_);
#line 263 "SerializableGeeHashMapTest.vala"
		_tmp5_ = serializable_gee_hash_map_test_space_container_get_storage (c);
#line 263 "SerializableGeeHashMapTest.vala"
		_tmp6_ = _tmp5_;
#line 263 "SerializableGeeHashMapTest.vala"
		_tmp7_ = serializable_gee_hash_map_test_space_get_name (o1);
#line 263 "SerializableGeeHashMapTest.vala"
		_tmp8_ = _tmp7_;
#line 263 "SerializableGeeHashMapTest.vala"
		gee_abstract_map_set ((GeeAbstractMap*) _tmp6_, _tmp8_, o1);
#line 264 "SerializableGeeHashMapTest.vala"
		_tmp9_ = serializable_gee_hash_map_test_space_container_get_storage (c);
#line 264 "SerializableGeeHashMapTest.vala"
		_tmp10_ = _tmp9_;
#line 264 "SerializableGeeHashMapTest.vala"
		_tmp11_ = serializable_gee_hash_map_test_space_get_name (o2);
#line 264 "SerializableGeeHashMapTest.vala"
		_tmp12_ = _tmp11_;
#line 264 "SerializableGeeHashMapTest.vala"
		gee_abstract_map_set ((GeeAbstractMap*) _tmp10_, _tmp12_, o2);
#line 265 "SerializableGeeHashMapTest.vala"
		_tmp13_ = gxml_tdocument_new ();
#line 265 "SerializableGeeHashMapTest.vala"
		doc = _tmp13_;
#line 266 "SerializableGeeHashMapTest.vala"
		_tmp14_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) c, (GXmlNode*) doc, &_inner_error0_);
#line 266 "SerializableGeeHashMapTest.vala"
		_tmp15_ = _tmp14_;
#line 266 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp15_);
#line 266 "SerializableGeeHashMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 266 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (doc);
#line 266 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (o2);
#line 266 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (o1);
#line 266 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (c);
#line 2306 "SerializableGeeHashMapTest.c"
			goto __catch365_g_error;
		}
#line 267 "SerializableGeeHashMapTest.vala"
		_tmp16_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 267 "SerializableGeeHashMapTest.vala"
		_tmp17_ = _tmp16_;
#line 267 "SerializableGeeHashMapTest.vala"
		_tmp18_ = _tmp17_;
#line 267 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp18_ != NULL, "doc.root != null");
#line 267 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp18_);
#line 268 "SerializableGeeHashMapTest.vala"
		_tmp19_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 268 "SerializableGeeHashMapTest.vala"
		_tmp20_ = _tmp19_;
#line 268 "SerializableGeeHashMapTest.vala"
		_tmp21_ = _tmp20_;
#line 268 "SerializableGeeHashMapTest.vala"
		_tmp22_ = gxml_node_get_name (_tmp21_);
#line 268 "SerializableGeeHashMapTest.vala"
		_tmp23_ = _tmp22_;
#line 268 "SerializableGeeHashMapTest.vala"
		_tmp24_ = _tmp23_;
#line 268 "SerializableGeeHashMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp24_, "spacecontainer") == 0, "doc.root.name == \"spacecontainer\"");
#line 268 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp24_);
#line 268 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp21_);
#line 269 "SerializableGeeHashMapTest.vala"
		_tmp25_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 269 "SerializableGeeHashMapTest.vala"
		_tmp26_ = _tmp25_;
#line 269 "SerializableGeeHashMapTest.vala"
		root = _tmp26_;
#line 270 "SerializableGeeHashMapTest.vala"
		_tmp27_ = root;
#line 270 "SerializableGeeHashMapTest.vala"
		_tmp28_ = gxml_node_get_children_nodes (_tmp27_);
#line 270 "SerializableGeeHashMapTest.vala"
		_tmp29_ = _tmp28_;
#line 270 "SerializableGeeHashMapTest.vala"
		_tmp30_ = _tmp29_;
#line 270 "SerializableGeeHashMapTest.vala"
		_tmp31_ = gee_collection_get_size ((GeeCollection*) _tmp30_);
#line 270 "SerializableGeeHashMapTest.vala"
		_tmp32_ = _tmp31_;
#line 270 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp32_ > 0, "root.children_nodes.size > 0");
#line 270 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp30_);
#line 271 "SerializableGeeHashMapTest.vala"
		found1 = FALSE;
#line 272 "SerializableGeeHashMapTest.vala"
		found2 = FALSE;
#line 2363 "SerializableGeeHashMapTest.c"
		{
			GeeBidirList* _n_list = NULL;
			GXmlNode* _tmp33_;
			GeeBidirList* _tmp34_;
			GeeBidirList* _tmp35_;
			gint _n_size = 0;
			GeeBidirList* _tmp36_;
			gint _tmp37_;
			gint _tmp38_;
			gint _n_index = 0;
#line 273 "SerializableGeeHashMapTest.vala"
			_tmp33_ = root;
#line 273 "SerializableGeeHashMapTest.vala"
			_tmp34_ = gxml_node_get_children_nodes (_tmp33_);
#line 273 "SerializableGeeHashMapTest.vala"
			_tmp35_ = _tmp34_;
#line 273 "SerializableGeeHashMapTest.vala"
			_n_list = _tmp35_;
#line 273 "SerializableGeeHashMapTest.vala"
			_tmp36_ = _n_list;
#line 273 "SerializableGeeHashMapTest.vala"
			_tmp37_ = gee_collection_get_size ((GeeCollection*) _tmp36_);
#line 273 "SerializableGeeHashMapTest.vala"
			_tmp38_ = _tmp37_;
#line 273 "SerializableGeeHashMapTest.vala"
			_n_size = _tmp38_;
#line 273 "SerializableGeeHashMapTest.vala"
			_n_index = -1;
#line 273 "SerializableGeeHashMapTest.vala"
			while (TRUE) {
#line 2394 "SerializableGeeHashMapTest.c"
				GXmlNode* n = NULL;
				GeeBidirList* _tmp39_;
				gpointer _tmp40_;
				gboolean _tmp41_ = FALSE;
				GXmlNode* _tmp42_;
#line 273 "SerializableGeeHashMapTest.vala"
				_n_index = _n_index + 1;
#line 273 "SerializableGeeHashMapTest.vala"
				if (!(_n_index < _n_size)) {
#line 273 "SerializableGeeHashMapTest.vala"
					break;
#line 2406 "SerializableGeeHashMapTest.c"
				}
#line 273 "SerializableGeeHashMapTest.vala"
				_tmp39_ = _n_list;
#line 273 "SerializableGeeHashMapTest.vala"
				_tmp40_ = gee_list_get ((GeeList*) _tmp39_, _n_index);
#line 273 "SerializableGeeHashMapTest.vala"
				n = (GXmlNode*) _tmp40_;
#line 274 "SerializableGeeHashMapTest.vala"
				_tmp42_ = n;
#line 274 "SerializableGeeHashMapTest.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp42_, GXML_TYPE_ELEMENT)) {
#line 2418 "SerializableGeeHashMapTest.c"
					GXmlNode* _tmp43_;
					gchar* _tmp44_;
					gchar* _tmp45_;
					gchar* _tmp46_;
#line 274 "SerializableGeeHashMapTest.vala"
					_tmp43_ = n;
#line 274 "SerializableGeeHashMapTest.vala"
					_tmp44_ = gxml_node_get_name (_tmp43_);
#line 274 "SerializableGeeHashMapTest.vala"
					_tmp45_ = _tmp44_;
#line 274 "SerializableGeeHashMapTest.vala"
					_tmp46_ = _tmp45_;
#line 274 "SerializableGeeHashMapTest.vala"
					_tmp41_ = g_strcmp0 (_tmp46_, "space") == 0;
#line 274 "SerializableGeeHashMapTest.vala"
					_g_free0 (_tmp46_);
#line 2435 "SerializableGeeHashMapTest.c"
				} else {
#line 274 "SerializableGeeHashMapTest.vala"
					_tmp41_ = FALSE;
#line 2439 "SerializableGeeHashMapTest.c"
				}
#line 274 "SerializableGeeHashMapTest.vala"
				if (_tmp41_) {
#line 2443 "SerializableGeeHashMapTest.c"
					GXmlNode* name = NULL;
					GXmlNode* _tmp47_;
					GeeMap* _tmp48_;
					GeeMap* _tmp49_;
					GeeMap* _tmp50_;
					gpointer _tmp51_;
					GXmlNode* _tmp52_;
					GXmlNode* _tmp53_;
#line 275 "SerializableGeeHashMapTest.vala"
					_tmp47_ = n;
#line 275 "SerializableGeeHashMapTest.vala"
					_tmp48_ = gxml_node_get_attrs (_tmp47_);
#line 275 "SerializableGeeHashMapTest.vala"
					_tmp49_ = _tmp48_;
#line 275 "SerializableGeeHashMapTest.vala"
					_tmp50_ = _tmp49_;
#line 275 "SerializableGeeHashMapTest.vala"
					_tmp51_ = gee_map_get (_tmp50_, "name");
#line 275 "SerializableGeeHashMapTest.vala"
					_tmp52_ = (GXmlNode*) _tmp51_;
#line 275 "SerializableGeeHashMapTest.vala"
					_g_object_unref0 (_tmp50_);
#line 275 "SerializableGeeHashMapTest.vala"
					name = _tmp52_;
#line 276 "SerializableGeeHashMapTest.vala"
					_tmp53_ = name;
#line 276 "SerializableGeeHashMapTest.vala"
					if (_tmp53_ != NULL) {
#line 2472 "SerializableGeeHashMapTest.c"
						GXmlNode* _tmp54_;
						gchar* _tmp55_;
						gchar* _tmp56_;
						gchar* _tmp57_;
						gboolean _tmp58_;
						GXmlNode* _tmp59_;
						gchar* _tmp60_;
						gchar* _tmp61_;
						gchar* _tmp62_;
						gboolean _tmp63_;
#line 277 "SerializableGeeHashMapTest.vala"
						_tmp54_ = name;
#line 277 "SerializableGeeHashMapTest.vala"
						_tmp55_ = gxml_node_get_value (_tmp54_);
#line 277 "SerializableGeeHashMapTest.vala"
						_tmp56_ = _tmp55_;
#line 277 "SerializableGeeHashMapTest.vala"
						_tmp57_ = _tmp56_;
#line 277 "SerializableGeeHashMapTest.vala"
						_tmp58_ = g_strcmp0 (_tmp57_, "Big") == 0;
#line 277 "SerializableGeeHashMapTest.vala"
						_g_free0 (_tmp57_);
#line 277 "SerializableGeeHashMapTest.vala"
						if (_tmp58_) {
#line 277 "SerializableGeeHashMapTest.vala"
							found1 = TRUE;
#line 2499 "SerializableGeeHashMapTest.c"
						}
#line 278 "SerializableGeeHashMapTest.vala"
						_tmp59_ = name;
#line 278 "SerializableGeeHashMapTest.vala"
						_tmp60_ = gxml_node_get_value (_tmp59_);
#line 278 "SerializableGeeHashMapTest.vala"
						_tmp61_ = _tmp60_;
#line 278 "SerializableGeeHashMapTest.vala"
						_tmp62_ = _tmp61_;
#line 278 "SerializableGeeHashMapTest.vala"
						_tmp63_ = g_strcmp0 (_tmp62_, "Small") == 0;
#line 278 "SerializableGeeHashMapTest.vala"
						_g_free0 (_tmp62_);
#line 278 "SerializableGeeHashMapTest.vala"
						if (_tmp63_) {
#line 278 "SerializableGeeHashMapTest.vala"
							found2 = TRUE;
#line 2517 "SerializableGeeHashMapTest.c"
						}
					}
#line 274 "SerializableGeeHashMapTest.vala"
					_g_object_unref0 (name);
#line 2522 "SerializableGeeHashMapTest.c"
				}
#line 273 "SerializableGeeHashMapTest.vala"
				_g_object_unref0 (n);
#line 2526 "SerializableGeeHashMapTest.c"
			}
#line 273 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (_n_list);
#line 2530 "SerializableGeeHashMapTest.c"
		}
#line 282 "SerializableGeeHashMapTest.vala"
		_vala_assert (found1, "found1");
#line 283 "SerializableGeeHashMapTest.vala"
		_vala_assert (found2, "found2");
#line 258 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (root);
#line 258 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (doc);
#line 258 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (o2);
#line 258 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (o1);
#line 258 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (c);
#line 2546 "SerializableGeeHashMapTest.c"
	}
	goto __finally365;
	__catch365_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp64_;
		const gchar* _tmp65_;
		gchar* _tmp66_;
		gchar* _tmp67_;
#line 258 "SerializableGeeHashMapTest.vala"
		e = _inner_error0_;
#line 258 "SerializableGeeHashMapTest.vala"
		_inner_error0_ = NULL;
#line 286 "SerializableGeeHashMapTest.vala"
		_tmp64_ = e->message;
#line 286 "SerializableGeeHashMapTest.vala"
		_tmp65_ = string_to_string (_tmp64_);
#line 286 "SerializableGeeHashMapTest.vala"
		_tmp66_ = g_strconcat ("ERROR: ", _tmp65_, NULL);
#line 286 "SerializableGeeHashMapTest.vala"
		_tmp67_ = _tmp66_;
#line 286 "SerializableGeeHashMapTest.vala"
		g_message ("SerializableGeeHashMapTest.vala:286: %s", _tmp67_);
#line 286 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp67_);
#line 287 "SerializableGeeHashMapTest.vala"
		g_assert_not_reached ();
#line 258 "SerializableGeeHashMapTest.vala"
		_g_error_free0 (e);
#line 2576 "SerializableGeeHashMapTest.c"
	}
	__finally365:
#line 258 "SerializableGeeHashMapTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 258 "SerializableGeeHashMapTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 258 "SerializableGeeHashMapTest.vala"
		g_clear_error (&_inner_error0_);
#line 258 "SerializableGeeHashMapTest.vala"
		return;
#line 2587 "SerializableGeeHashMapTest.c"
	}
}

static void
___lambda315__gtest_func (void)
{
#line 256 "SerializableGeeHashMapTest.vala"
	__lambda315_ ();
#line 2596 "SerializableGeeHashMapTest.c"
}

static void
__lambda316_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* idoc = NULL;
		GXmlGDocument* _tmp0_;
		SerializableGeeHashMapTestSpaceContainer* isc = NULL;
		SerializableGeeHashMapTestSpaceContainer* _tmp1_;
		SerializableGeeHashMapTestSpaceContainer* _tmp2_;
		GXmlGDocument* _tmp3_;
		GXmlTDocument* doc = NULL;
		GXmlTDocument* _tmp4_;
		SerializableGeeHashMapTestSpaceContainer* _tmp5_;
		GXmlTDocument* _tmp6_;
		GXmlNode* _tmp7_;
		GXmlNode* _tmp8_;
		SerializableGeeHashMapTestSpaceContainer* sc = NULL;
		SerializableGeeHashMapTestSpaceContainer* _tmp9_;
		SerializableGeeHashMapTestSpaceContainer* _tmp10_;
		GXmlTDocument* _tmp11_;
		SerializableGeeHashMapTestSpaceContainer* _tmp12_;
		SerializableGeeHashMapTestSpaceCollection* _tmp13_;
		SerializableGeeHashMapTestSpaceCollection* _tmp14_;
		SerializableGeeHashMapTestSpaceContainer* _tmp15_;
		SerializableGeeHashMapTestSpaceCollection* _tmp16_;
		SerializableGeeHashMapTestSpaceCollection* _tmp17_;
		gint _tmp18_;
		gint _tmp19_;
		gint i = 0;
		SerializableGeeHashMapTestSpace* s1 = NULL;
		SerializableGeeHashMapTestSpaceContainer* _tmp33_;
		SerializableGeeHashMapTestSpaceCollection* _tmp34_;
		SerializableGeeHashMapTestSpaceCollection* _tmp35_;
		gpointer _tmp36_;
		gchar* _tmp37_;
		gchar* _tmp38_;
		SerializableGeeHashMapTestSpace* s2 = NULL;
		SerializableGeeHashMapTestSpaceContainer* _tmp39_;
		SerializableGeeHashMapTestSpaceCollection* _tmp40_;
		SerializableGeeHashMapTestSpaceCollection* _tmp41_;
		gpointer _tmp42_;
		gchar* _tmp43_;
		gchar* _tmp44_;
		SerializableGeeHashMapTestSpace* s3 = NULL;
		SerializableGeeHashMapTestSpaceContainer* _tmp45_;
		SerializableGeeHashMapTestSpaceCollection* _tmp46_;
		SerializableGeeHashMapTestSpaceCollection* _tmp47_;
		gpointer _tmp48_;
		gchar* _tmp49_;
		gchar* _tmp50_;
		SerializableGeeHashMapTestSpace* s4 = NULL;
		SerializableGeeHashMapTestSpaceContainer* _tmp51_;
		SerializableGeeHashMapTestSpaceCollection* _tmp52_;
		SerializableGeeHashMapTestSpaceCollection* _tmp53_;
		gpointer _tmp54_;
		gchar* _tmp55_;
		gchar* _tmp56_;
		SerializableGeeHashMapTestSpace* s5 = NULL;
		SerializableGeeHashMapTestSpaceContainer* _tmp57_;
		SerializableGeeHashMapTestSpaceCollection* _tmp58_;
		SerializableGeeHashMapTestSpaceCollection* _tmp59_;
		gpointer _tmp60_;
		gchar* _tmp61_;
		gchar* _tmp62_;
#line 293 "SerializableGeeHashMapTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"    <spacecontainer owner=\"Earth\">\n" \
"      <space name=\"Big\"/>\n" \
"      <space name=\"Big\">FAKE1</space>\n" \
"      <space name=\"Small\"/>\n" \
"      <space name=\"Yum1\">FAKE2</space>\n" \
"      <space name=\"Yum2\">FAKE3</space>\n" \
"      <space name=\"Yum3\">FAKE4</space>\n" \
"      <space name=\"Yum3\">FAKE5</space>\n" \
"    </spacecontainer>", 0, &_inner_error0_);
#line 293 "SerializableGeeHashMapTest.vala"
		idoc = _tmp0_;
#line 293 "SerializableGeeHashMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2670 "SerializableGeeHashMapTest.c"
			goto __catch366_g_error;
		}
#line 303 "SerializableGeeHashMapTest.vala"
		_tmp1_ = serializable_gee_hash_map_test_space_container_new ();
#line 303 "SerializableGeeHashMapTest.vala"
		isc = _tmp1_;
#line 304 "SerializableGeeHashMapTest.vala"
		_tmp2_ = isc;
#line 304 "SerializableGeeHashMapTest.vala"
		_tmp3_ = idoc;
#line 304 "SerializableGeeHashMapTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 304 "SerializableGeeHashMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 304 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (isc);
#line 304 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (idoc);
#line 2689 "SerializableGeeHashMapTest.c"
			goto __catch366_g_error;
		}
#line 305 "SerializableGeeHashMapTest.vala"
		_tmp4_ = gxml_tdocument_new ();
#line 305 "SerializableGeeHashMapTest.vala"
		doc = _tmp4_;
#line 306 "SerializableGeeHashMapTest.vala"
		_tmp5_ = isc;
#line 306 "SerializableGeeHashMapTest.vala"
		_tmp6_ = doc;
#line 306 "SerializableGeeHashMapTest.vala"
		_tmp7_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp5_, (GXmlNode*) _tmp6_, &_inner_error0_);
#line 306 "SerializableGeeHashMapTest.vala"
		_tmp8_ = _tmp7_;
#line 306 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp8_);
#line 306 "SerializableGeeHashMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 306 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (doc);
#line 306 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (isc);
#line 306 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (idoc);
#line 2714 "SerializableGeeHashMapTest.c"
			goto __catch366_g_error;
		}
#line 307 "SerializableGeeHashMapTest.vala"
		_tmp9_ = serializable_gee_hash_map_test_space_container_new ();
#line 307 "SerializableGeeHashMapTest.vala"
		sc = _tmp9_;
#line 308 "SerializableGeeHashMapTest.vala"
		_tmp10_ = sc;
#line 308 "SerializableGeeHashMapTest.vala"
		_tmp11_ = doc;
#line 308 "SerializableGeeHashMapTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp10_, (GXmlNode*) _tmp11_, &_inner_error0_);
#line 308 "SerializableGeeHashMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 308 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (sc);
#line 308 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (doc);
#line 308 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (isc);
#line 308 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (idoc);
#line 2737 "SerializableGeeHashMapTest.c"
			goto __catch366_g_error;
		}
#line 309 "SerializableGeeHashMapTest.vala"
		_tmp12_ = sc;
#line 309 "SerializableGeeHashMapTest.vala"
		_tmp13_ = serializable_gee_hash_map_test_space_container_get_storage (_tmp12_);
#line 309 "SerializableGeeHashMapTest.vala"
		_tmp14_ = _tmp13_;
#line 309 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp14_ != NULL, "sc.storage != null");
#line 310 "SerializableGeeHashMapTest.vala"
		_tmp15_ = sc;
#line 310 "SerializableGeeHashMapTest.vala"
		_tmp16_ = serializable_gee_hash_map_test_space_container_get_storage (_tmp15_);
#line 310 "SerializableGeeHashMapTest.vala"
		_tmp17_ = _tmp16_;
#line 310 "SerializableGeeHashMapTest.vala"
		_tmp18_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp17_);
#line 310 "SerializableGeeHashMapTest.vala"
		_tmp19_ = _tmp18_;
#line 310 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp19_ == 5, "sc.storage.size == 5");
#line 311 "SerializableGeeHashMapTest.vala"
		i = 0;
#line 2762 "SerializableGeeHashMapTest.c"
		{
			GeeIterator* _s_it = NULL;
			SerializableGeeHashMapTestSpaceContainer* _tmp20_;
			SerializableGeeHashMapTestSpaceCollection* _tmp21_;
			SerializableGeeHashMapTestSpaceCollection* _tmp22_;
			GeeCollection* _tmp23_;
			GeeCollection* _tmp24_;
			GeeCollection* _tmp25_;
			GeeIterator* _tmp26_;
			GeeIterator* _tmp27_;
#line 312 "SerializableGeeHashMapTest.vala"
			_tmp20_ = sc;
#line 312 "SerializableGeeHashMapTest.vala"
			_tmp21_ = serializable_gee_hash_map_test_space_container_get_storage (_tmp20_);
#line 312 "SerializableGeeHashMapTest.vala"
			_tmp22_ = _tmp21_;
#line 312 "SerializableGeeHashMapTest.vala"
			_tmp23_ = gee_abstract_map_get_values ((GeeAbstractMap*) _tmp22_);
#line 312 "SerializableGeeHashMapTest.vala"
			_tmp24_ = _tmp23_;
#line 312 "SerializableGeeHashMapTest.vala"
			_tmp25_ = _tmp24_;
#line 312 "SerializableGeeHashMapTest.vala"
			_tmp26_ = gee_iterable_iterator ((GeeIterable*) _tmp25_);
#line 312 "SerializableGeeHashMapTest.vala"
			_tmp27_ = _tmp26_;
#line 312 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (_tmp25_);
#line 312 "SerializableGeeHashMapTest.vala"
			_s_it = _tmp27_;
#line 312 "SerializableGeeHashMapTest.vala"
			while (TRUE) {
#line 2795 "SerializableGeeHashMapTest.c"
				GeeIterator* _tmp28_;
				SerializableGeeHashMapTestSpace* s = NULL;
				GeeIterator* _tmp29_;
				gpointer _tmp30_;
				SerializableGeeHashMapTestSpace* _tmp31_;
				gint _tmp32_;
#line 312 "SerializableGeeHashMapTest.vala"
				_tmp28_ = _s_it;
#line 312 "SerializableGeeHashMapTest.vala"
				if (!gee_iterator_next (_tmp28_)) {
#line 312 "SerializableGeeHashMapTest.vala"
					break;
#line 2808 "SerializableGeeHashMapTest.c"
				}
#line 312 "SerializableGeeHashMapTest.vala"
				_tmp29_ = _s_it;
#line 312 "SerializableGeeHashMapTest.vala"
				_tmp30_ = gee_iterator_get (_tmp29_);
#line 312 "SerializableGeeHashMapTest.vala"
				s = (SerializableGeeHashMapTestSpace*) _tmp30_;
#line 313 "SerializableGeeHashMapTest.vala"
				_tmp31_ = s;
#line 313 "SerializableGeeHashMapTest.vala"
				_vala_assert (_tmp31_ != NULL, "s != null");
#line 314 "SerializableGeeHashMapTest.vala"
				_tmp32_ = i;
#line 314 "SerializableGeeHashMapTest.vala"
				i = _tmp32_ + 1;
#line 312 "SerializableGeeHashMapTest.vala"
				_g_object_unref0 (s);
#line 2826 "SerializableGeeHashMapTest.c"
			}
#line 312 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (_s_it);
#line 2830 "SerializableGeeHashMapTest.c"
		}
#line 316 "SerializableGeeHashMapTest.vala"
		_vala_assert (i == 5, "i == 5");
#line 317 "SerializableGeeHashMapTest.vala"
		_tmp33_ = sc;
#line 317 "SerializableGeeHashMapTest.vala"
		_tmp34_ = serializable_gee_hash_map_test_space_container_get_storage (_tmp33_);
#line 317 "SerializableGeeHashMapTest.vala"
		_tmp35_ = _tmp34_;
#line 317 "SerializableGeeHashMapTest.vala"
		_tmp36_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp35_, "Big");
#line 317 "SerializableGeeHashMapTest.vala"
		s1 = (SerializableGeeHashMapTestSpace*) _tmp36_;
#line 318 "SerializableGeeHashMapTest.vala"
		_vala_assert (s1 != NULL, "s1 != null");
#line 319 "SerializableGeeHashMapTest.vala"
		_tmp37_ = serializable_gee_hash_map_test_space_get_value (s1);
#line 319 "SerializableGeeHashMapTest.vala"
		_tmp38_ = _tmp37_;
#line 319 "SerializableGeeHashMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp38_, "FAKE1") == 0, "s1.get_value () == \"FAKE1\"");
#line 319 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp38_);
#line 320 "SerializableGeeHashMapTest.vala"
		_tmp39_ = sc;
#line 320 "SerializableGeeHashMapTest.vala"
		_tmp40_ = serializable_gee_hash_map_test_space_container_get_storage (_tmp39_);
#line 320 "SerializableGeeHashMapTest.vala"
		_tmp41_ = _tmp40_;
#line 320 "SerializableGeeHashMapTest.vala"
		_tmp42_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp41_, "Small");
#line 320 "SerializableGeeHashMapTest.vala"
		s2 = (SerializableGeeHashMapTestSpace*) _tmp42_;
#line 321 "SerializableGeeHashMapTest.vala"
		_vala_assert (s2 != NULL, "s2 != null");
#line 322 "SerializableGeeHashMapTest.vala"
		_tmp43_ = serializable_gee_hash_map_test_space_get_value (s2);
#line 322 "SerializableGeeHashMapTest.vala"
		_tmp44_ = _tmp43_;
#line 322 "SerializableGeeHashMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp44_, "") == 0, "s2.get_value () == \"\"");
#line 322 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp44_);
#line 323 "SerializableGeeHashMapTest.vala"
		_tmp45_ = sc;
#line 323 "SerializableGeeHashMapTest.vala"
		_tmp46_ = serializable_gee_hash_map_test_space_container_get_storage (_tmp45_);
#line 323 "SerializableGeeHashMapTest.vala"
		_tmp47_ = _tmp46_;
#line 323 "SerializableGeeHashMapTest.vala"
		_tmp48_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp47_, "Yum1");
#line 323 "SerializableGeeHashMapTest.vala"
		s3 = (SerializableGeeHashMapTestSpace*) _tmp48_;
#line 324 "SerializableGeeHashMapTest.vala"
		_vala_assert (s3 != NULL, "s3 != null");
#line 325 "SerializableGeeHashMapTest.vala"
		_tmp49_ = serializable_gee_hash_map_test_space_get_value (s3);
#line 325 "SerializableGeeHashMapTest.vala"
		_tmp50_ = _tmp49_;
#line 325 "SerializableGeeHashMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp50_, "FAKE2") == 0, "s3.get_value () == \"FAKE2\"");
#line 325 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp50_);
#line 326 "SerializableGeeHashMapTest.vala"
		_tmp51_ = sc;
#line 326 "SerializableGeeHashMapTest.vala"
		_tmp52_ = serializable_gee_hash_map_test_space_container_get_storage (_tmp51_);
#line 326 "SerializableGeeHashMapTest.vala"
		_tmp53_ = _tmp52_;
#line 326 "SerializableGeeHashMapTest.vala"
		_tmp54_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp53_, "Yum2");
#line 326 "SerializableGeeHashMapTest.vala"
		s4 = (SerializableGeeHashMapTestSpace*) _tmp54_;
#line 327 "SerializableGeeHashMapTest.vala"
		_vala_assert (s4 != NULL, "s4 != null");
#line 328 "SerializableGeeHashMapTest.vala"
		_tmp55_ = serializable_gee_hash_map_test_space_get_value (s4);
#line 328 "SerializableGeeHashMapTest.vala"
		_tmp56_ = _tmp55_;
#line 328 "SerializableGeeHashMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp56_, "FAKE3") == 0, "s4.get_value () == \"FAKE3\"");
#line 328 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp56_);
#line 329 "SerializableGeeHashMapTest.vala"
		_tmp57_ = sc;
#line 329 "SerializableGeeHashMapTest.vala"
		_tmp58_ = serializable_gee_hash_map_test_space_container_get_storage (_tmp57_);
#line 329 "SerializableGeeHashMapTest.vala"
		_tmp59_ = _tmp58_;
#line 329 "SerializableGeeHashMapTest.vala"
		_tmp60_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp59_, "Yum3");
#line 329 "SerializableGeeHashMapTest.vala"
		s5 = (SerializableGeeHashMapTestSpace*) _tmp60_;
#line 330 "SerializableGeeHashMapTest.vala"
		_vala_assert (s5 != NULL, "s5 != null");
#line 331 "SerializableGeeHashMapTest.vala"
		_tmp61_ = serializable_gee_hash_map_test_space_get_value (s5);
#line 331 "SerializableGeeHashMapTest.vala"
		_tmp62_ = _tmp61_;
#line 331 "SerializableGeeHashMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp62_, "FAKE5") == 0, "s5.get_value () == \"FAKE5\"");
#line 331 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp62_);
#line 292 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (s5);
#line 292 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (s4);
#line 292 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (s3);
#line 292 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (s2);
#line 292 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (s1);
#line 292 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (sc);
#line 292 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (doc);
#line 292 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (isc);
#line 292 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (idoc);
#line 2952 "SerializableGeeHashMapTest.c"
	}
	goto __finally366;
	__catch366_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp63_;
		const gchar* _tmp64_;
		gchar* _tmp65_;
		gchar* _tmp66_;
#line 292 "SerializableGeeHashMapTest.vala"
		e = _inner_error0_;
#line 292 "SerializableGeeHashMapTest.vala"
		_inner_error0_ = NULL;
#line 333 "SerializableGeeHashMapTest.vala"
		_tmp63_ = e->message;
#line 333 "SerializableGeeHashMapTest.vala"
		_tmp64_ = string_to_string (_tmp63_);
#line 333 "SerializableGeeHashMapTest.vala"
		_tmp65_ = g_strconcat ("ERROR: ", _tmp64_, NULL);
#line 333 "SerializableGeeHashMapTest.vala"
		_tmp66_ = _tmp65_;
#line 333 "SerializableGeeHashMapTest.vala"
		g_message ("SerializableGeeHashMapTest.vala:333: %s", _tmp66_);
#line 333 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp66_);
#line 334 "SerializableGeeHashMapTest.vala"
		g_assert_not_reached ();
#line 292 "SerializableGeeHashMapTest.vala"
		_g_error_free0 (e);
#line 2982 "SerializableGeeHashMapTest.c"
	}
	__finally366:
#line 292 "SerializableGeeHashMapTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 292 "SerializableGeeHashMapTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 292 "SerializableGeeHashMapTest.vala"
		g_clear_error (&_inner_error0_);
#line 292 "SerializableGeeHashMapTest.vala"
		return;
#line 2993 "SerializableGeeHashMapTest.c"
	}
}

static void
___lambda316__gtest_func (void)
{
#line 290 "SerializableGeeHashMapTest.vala"
	__lambda316_ ();
#line 3002 "SerializableGeeHashMapTest.c"
}

static void
__lambda317_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* d = NULL;
		GXmlGDocument* _tmp0_;
		BookStore* bs = NULL;
		BookStore* _tmp1_;
		BookStore* _tmp2_;
		GXmlGDocument* _tmp3_;
		BookStore* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		BookStore* _tmp7_;
		BookArray* _tmp8_;
		BookArray* _tmp9_;
		gint _tmp10_;
		gint _tmp11_;
		Book* b = NULL;
		BookStore* _tmp12_;
		BookArray* _tmp13_;
		BookArray* _tmp14_;
		gpointer _tmp15_;
		Name* _tmp16_;
		Name* _tmp17_;
		Name* _tmp18_;
		Name* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		const gchar* _tmp22_;
		const gchar* _tmp23_;
		Authors* _tmp24_;
		Authors* _tmp25_;
		Authors* _tmp26_;
		Authors* _tmp27_;
		AuthorArray* _tmp28_;
		AuthorArray* _tmp29_;
		Authors* _tmp30_;
		Authors* _tmp31_;
		AuthorArray* _tmp32_;
		AuthorArray* _tmp33_;
		gint _tmp34_;
		gint _tmp35_;
		CategoryMap* _tmp36_;
		CategoryMap* _tmp37_;
		CategoryMap* _tmp38_;
		CategoryMap* _tmp39_;
		gint _tmp40_;
		gint _tmp41_;
		Category* c = NULL;
		CategoryMap* _tmp42_;
		CategoryMap* _tmp43_;
		gpointer _tmp44_;
		const gchar* _tmp45_;
		const gchar* _tmp46_;
#line 340 "SerializableGeeHashMapTest.vala"
		_tmp0_ = gxml_gdocument_new_from_path (TEST_DIR "/test-collection.xml", 0, &_inner_error0_);
#line 340 "SerializableGeeHashMapTest.vala"
		d = _tmp0_;
#line 340 "SerializableGeeHashMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 3067 "SerializableGeeHashMapTest.c"
			goto __catch367_g_error;
		}
#line 341 "SerializableGeeHashMapTest.vala"
		_tmp1_ = book_store_new ();
#line 341 "SerializableGeeHashMapTest.vala"
		bs = _tmp1_;
#line 342 "SerializableGeeHashMapTest.vala"
		_tmp2_ = bs;
#line 342 "SerializableGeeHashMapTest.vala"
		_tmp3_ = d;
#line 342 "SerializableGeeHashMapTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 342 "SerializableGeeHashMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 342 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (bs);
#line 342 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (d);
#line 3086 "SerializableGeeHashMapTest.c"
			goto __catch367_g_error;
		}
#line 343 "SerializableGeeHashMapTest.vala"
		_tmp4_ = bs;
#line 343 "SerializableGeeHashMapTest.vala"
		_tmp5_ = book_store_get_name (_tmp4_);
#line 343 "SerializableGeeHashMapTest.vala"
		_tmp6_ = _tmp5_;
#line 343 "SerializableGeeHashMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp6_, "The Great Book") == 0, "bs.name == \"The Great Book\"");
#line 344 "SerializableGeeHashMapTest.vala"
		_tmp7_ = bs;
#line 344 "SerializableGeeHashMapTest.vala"
		_tmp8_ = book_store_get_books (_tmp7_);
#line 344 "SerializableGeeHashMapTest.vala"
		_tmp9_ = _tmp8_;
#line 344 "SerializableGeeHashMapTest.vala"
		_tmp10_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp9_);
#line 344 "SerializableGeeHashMapTest.vala"
		_tmp11_ = _tmp10_;
#line 344 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp11_ == 3, "bs.books.size == 3");
#line 345 "SerializableGeeHashMapTest.vala"
		_tmp12_ = bs;
#line 345 "SerializableGeeHashMapTest.vala"
		_tmp13_ = book_store_get_books (_tmp12_);
#line 345 "SerializableGeeHashMapTest.vala"
		_tmp14_ = _tmp13_;
#line 345 "SerializableGeeHashMapTest.vala"
		_tmp15_ = gee_list_first ((GeeList*) _tmp14_);
#line 345 "SerializableGeeHashMapTest.vala"
		b = (Book*) _tmp15_;
#line 346 "SerializableGeeHashMapTest.vala"
		_vala_assert (b != NULL, "b != null");
#line 347 "SerializableGeeHashMapTest.vala"
		_tmp16_ = book_get_name (b);
#line 347 "SerializableGeeHashMapTest.vala"
		_tmp17_ = _tmp16_;
#line 347 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp17_ != NULL, "b.name != null");
#line 348 "SerializableGeeHashMapTest.vala"
		_tmp18_ = book_get_name (b);
#line 348 "SerializableGeeHashMapTest.vala"
		_tmp19_ = _tmp18_;
#line 348 "SerializableGeeHashMapTest.vala"
		_tmp20_ = name_get_name (_tmp19_);
#line 348 "SerializableGeeHashMapTest.vala"
		_tmp21_ = _tmp20_;
#line 348 "SerializableGeeHashMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp21_, "Book1") == 0, "b.name.get_name () == \"Book1\"");
#line 348 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp21_);
#line 349 "SerializableGeeHashMapTest.vala"
		_tmp22_ = book_get_year (b);
#line 349 "SerializableGeeHashMapTest.vala"
		_tmp23_ = _tmp22_;
#line 349 "SerializableGeeHashMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp23_, "2015") == 0, "b.year == \"2015\"");
#line 350 "SerializableGeeHashMapTest.vala"
		_tmp24_ = book_get_authors (b);
#line 350 "SerializableGeeHashMapTest.vala"
		_tmp25_ = _tmp24_;
#line 350 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp25_ != NULL, "b.authors != null");
#line 351 "SerializableGeeHashMapTest.vala"
		_tmp26_ = book_get_authors (b);
#line 351 "SerializableGeeHashMapTest.vala"
		_tmp27_ = _tmp26_;
#line 351 "SerializableGeeHashMapTest.vala"
		_tmp28_ = authors_get_array (_tmp27_);
#line 351 "SerializableGeeHashMapTest.vala"
		_tmp29_ = _tmp28_;
#line 351 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp29_ != NULL, "b.authors.array != null");
#line 352 "SerializableGeeHashMapTest.vala"
		_tmp30_ = book_get_authors (b);
#line 352 "SerializableGeeHashMapTest.vala"
		_tmp31_ = _tmp30_;
#line 352 "SerializableGeeHashMapTest.vala"
		_tmp32_ = authors_get_array (_tmp31_);
#line 352 "SerializableGeeHashMapTest.vala"
		_tmp33_ = _tmp32_;
#line 352 "SerializableGeeHashMapTest.vala"
		_tmp34_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp33_);
#line 352 "SerializableGeeHashMapTest.vala"
		_tmp35_ = _tmp34_;
#line 352 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp35_ == 2, "b.authors.array.size == 2");
#line 353 "SerializableGeeHashMapTest.vala"
		_tmp36_ = book_get_categories (b);
#line 353 "SerializableGeeHashMapTest.vala"
		_tmp37_ = _tmp36_;
#line 353 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp37_ != NULL, "b.categories != null");
#line 354 "SerializableGeeHashMapTest.vala"
		_tmp38_ = book_get_categories (b);
#line 354 "SerializableGeeHashMapTest.vala"
		_tmp39_ = _tmp38_;
#line 354 "SerializableGeeHashMapTest.vala"
		_tmp40_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp39_);
#line 354 "SerializableGeeHashMapTest.vala"
		_tmp41_ = _tmp40_;
#line 354 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp41_ == 2, "b.categories.size == 2");
#line 355 "SerializableGeeHashMapTest.vala"
		_tmp42_ = book_get_categories (b);
#line 355 "SerializableGeeHashMapTest.vala"
		_tmp43_ = _tmp42_;
#line 355 "SerializableGeeHashMapTest.vala"
		_tmp44_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp43_, "Fiction");
#line 355 "SerializableGeeHashMapTest.vala"
		c = (Category*) _tmp44_;
#line 356 "SerializableGeeHashMapTest.vala"
		_vala_assert (c != NULL, "c != null");
#line 357 "SerializableGeeHashMapTest.vala"
		_tmp45_ = category_get_name (c);
#line 357 "SerializableGeeHashMapTest.vala"
		_tmp46_ = _tmp45_;
#line 357 "SerializableGeeHashMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp46_, "Fiction") == 0, "c.name == \"Fiction\"");
#line 339 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (c);
#line 339 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (b);
#line 339 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (bs);
#line 339 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (d);
#line 3215 "SerializableGeeHashMapTest.c"
	}
	goto __finally367;
	__catch367_g_error:
	{
		GError* e = NULL;
#line 339 "SerializableGeeHashMapTest.vala"
		e = _inner_error0_;
#line 339 "SerializableGeeHashMapTest.vala"
		_inner_error0_ = NULL;
#line 362 "SerializableGeeHashMapTest.vala"
		g_assert_not_reached ();
#line 339 "SerializableGeeHashMapTest.vala"
		_g_error_free0 (e);
#line 3229 "SerializableGeeHashMapTest.c"
	}
	__finally367:
#line 339 "SerializableGeeHashMapTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 339 "SerializableGeeHashMapTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 339 "SerializableGeeHashMapTest.vala"
		g_clear_error (&_inner_error0_);
#line 339 "SerializableGeeHashMapTest.vala"
		return;
#line 3240 "SerializableGeeHashMapTest.c"
	}
}

static void
___lambda317__gtest_func (void)
{
#line 337 "SerializableGeeHashMapTest.vala"
	__lambda317_ ();
#line 3249 "SerializableGeeHashMapTest.c"
}

static void
__lambda318_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		SerializableGeeHashMapTestBigBag* bag = NULL;
		SerializableGeeHashMapTestBigBag* _tmp0_;
		SerializableGeeHashMapTestBigBag* _tmp1_;
		SerializableGeeHashMapTestSmallBagHashMap* _tmp2_;
		SerializableGeeHashMapTestSmallBagHashMap* _tmp3_;
		SerializableGeeHashMapTestBigBag* _tmp48_;
		SerializableGeeHashMapTestSmallBagHashMap* _tmp49_;
		SerializableGeeHashMapTestSmallBagHashMap* _tmp50_;
		gint _tmp51_;
		gint _tmp52_;
		GXmlGDocument* d = NULL;
		GXmlGDocument* _tmp53_;
		SerializableGeeHashMapTestBigBag* _tmp54_;
		GXmlGDocument* _tmp55_;
		GXmlNode* _tmp56_;
		GXmlNode* _tmp57_;
		GXmlGDocument* _tmp58_;
		GXmlNode* _tmp59_;
		GXmlNode* _tmp60_;
		GXmlNode* _tmp61_;
		GXmlGDocument* _tmp62_;
		GXmlNode* _tmp63_;
		GXmlNode* _tmp64_;
		GXmlNode* _tmp65_;
		gchar* _tmp66_;
		gchar* _tmp67_;
		gchar* _tmp68_;
		GXmlGDocument* _tmp69_;
		GXmlNode* _tmp70_;
		GXmlNode* _tmp71_;
		GXmlNode* _tmp72_;
		GeeBidirList* _tmp73_;
		GeeBidirList* _tmp74_;
		GeeBidirList* _tmp75_;
		gint _tmp76_;
		gint _tmp77_;
		GXmlGDocument* _tmp78_;
		GXmlNode* _tmp79_;
		GXmlNode* _tmp80_;
		GXmlNode* _tmp81_;
		GeeBidirList* _tmp82_;
		GeeBidirList* _tmp83_;
		GeeBidirList* _tmp84_;
		gpointer _tmp85_;
		GXmlNode* _tmp86_;
		gchar* _tmp87_;
		gchar* _tmp88_;
		gchar* _tmp89_;
		GXmlGDocument* _tmp90_;
		GXmlNode* _tmp91_;
		GXmlNode* _tmp92_;
		GXmlNode* _tmp93_;
		GeeBidirList* _tmp94_;
		GeeBidirList* _tmp95_;
		GeeBidirList* _tmp96_;
		gpointer _tmp97_;
		GXmlNode* _tmp98_;
		GeeBidirList* _tmp99_;
		GeeBidirList* _tmp100_;
		GeeBidirList* _tmp101_;
		gint _tmp102_;
		gint _tmp103_;
		GXmlGDocument* _tmp104_;
		GXmlNode* _tmp105_;
		GXmlNode* _tmp106_;
		GXmlNode* _tmp107_;
		GeeBidirList* _tmp108_;
		GeeBidirList* _tmp109_;
		GeeBidirList* _tmp110_;
		gpointer _tmp111_;
		GXmlNode* _tmp112_;
		GeeBidirList* _tmp113_;
		GeeBidirList* _tmp114_;
		GeeBidirList* _tmp115_;
		gpointer _tmp116_;
		GXmlNode* _tmp117_;
		gchar* _tmp118_;
		gchar* _tmp119_;
		gchar* _tmp120_;
		GXmlGDocument* _tmp121_;
		GXmlNode* _tmp122_;
		GXmlNode* _tmp123_;
		GXmlNode* _tmp124_;
		GeeBidirList* _tmp125_;
		GeeBidirList* _tmp126_;
		GeeBidirList* _tmp127_;
		gpointer _tmp128_;
		GXmlNode* _tmp129_;
		GeeBidirList* _tmp130_;
		GeeBidirList* _tmp131_;
		GeeBidirList* _tmp132_;
		gpointer _tmp133_;
		GXmlNode* _tmp134_;
		GeeBidirList* _tmp135_;
		GeeBidirList* _tmp136_;
		GeeBidirList* _tmp137_;
		gint _tmp138_;
		gint _tmp139_;
		GXmlGDocument* _tmp140_;
		GXmlNode* _tmp141_;
		GXmlNode* _tmp142_;
		GXmlNode* _tmp143_;
		GeeBidirList* _tmp144_;
		GeeBidirList* _tmp145_;
		GeeBidirList* _tmp146_;
		gpointer _tmp147_;
		GXmlNode* _tmp148_;
		GeeBidirList* _tmp149_;
		GeeBidirList* _tmp150_;
		GeeBidirList* _tmp151_;
		gpointer _tmp152_;
		GXmlNode* _tmp153_;
		GeeBidirList* _tmp154_;
		GeeBidirList* _tmp155_;
		GeeBidirList* _tmp156_;
		gpointer _tmp157_;
		GXmlNode* _tmp158_;
		gchar* _tmp159_;
		gchar* _tmp160_;
		gchar* _tmp161_;
		GXmlGDocument* _tmp162_;
		GXmlNode* _tmp163_;
		GXmlNode* _tmp164_;
		GXmlNode* _tmp165_;
		GeeBidirList* _tmp166_;
		GeeBidirList* _tmp167_;
		GeeBidirList* _tmp168_;
		gpointer _tmp169_;
		GXmlNode* _tmp170_;
		GeeBidirList* _tmp171_;
		GeeBidirList* _tmp172_;
		GeeBidirList* _tmp173_;
		gpointer _tmp174_;
		GXmlNode* _tmp175_;
		GeeBidirList* _tmp176_;
		GeeBidirList* _tmp177_;
		GeeBidirList* _tmp178_;
		gpointer _tmp179_;
		GXmlNode* _tmp180_;
		GeeBidirList* _tmp181_;
		GeeBidirList* _tmp182_;
		GeeBidirList* _tmp183_;
		gint _tmp184_;
		gint _tmp185_;
		GXmlGDocument* _tmp186_;
		GXmlNode* _tmp187_;
		GXmlNode* _tmp188_;
		GXmlNode* _tmp189_;
		GeeBidirList* _tmp190_;
		GeeBidirList* _tmp191_;
		GeeBidirList* _tmp192_;
		gpointer _tmp193_;
		GXmlNode* _tmp194_;
		GeeBidirList* _tmp195_;
		GeeBidirList* _tmp196_;
		GeeBidirList* _tmp197_;
		gpointer _tmp198_;
		GXmlNode* _tmp199_;
		GeeBidirList* _tmp200_;
		GeeBidirList* _tmp201_;
		GeeBidirList* _tmp202_;
		gpointer _tmp203_;
		GXmlNode* _tmp204_;
		GeeBidirList* _tmp205_;
		GeeBidirList* _tmp206_;
		GeeBidirList* _tmp207_;
		gpointer _tmp208_;
		GXmlNode* _tmp209_;
		GXmlGDocument* _tmp210_;
		GXmlNode* _tmp211_;
		GXmlNode* _tmp212_;
		GXmlNode* _tmp213_;
		GeeBidirList* _tmp214_;
		GeeBidirList* _tmp215_;
		GeeBidirList* _tmp216_;
		gpointer _tmp217_;
		GXmlNode* _tmp218_;
		GeeBidirList* _tmp219_;
		GeeBidirList* _tmp220_;
		GeeBidirList* _tmp221_;
		gpointer _tmp222_;
		GXmlNode* _tmp223_;
		GeeBidirList* _tmp224_;
		GeeBidirList* _tmp225_;
		GeeBidirList* _tmp226_;
		gpointer _tmp227_;
		GXmlNode* _tmp228_;
		GeeBidirList* _tmp229_;
		GeeBidirList* _tmp230_;
		GeeBidirList* _tmp231_;
		gpointer _tmp232_;
		GXmlNode* _tmp233_;
		gchar* _tmp234_;
		gchar* _tmp235_;
		gchar* _tmp236_;
		SerializableGeeHashMapTestBigBag* bagt = NULL;
		SerializableGeeHashMapTestBigBag* _tmp237_;
		SerializableGeeHashMapTestBigBag* _tmp238_;
		GXmlGDocument* _tmp239_;
		gboolean _tmp240_ = FALSE;
		SerializableGeeHashMapTestBigBag* _tmp241_;
		SerializableGeeHashMapTestSmallBagHashMap* _tmp242_;
		SerializableGeeHashMapTestSmallBagHashMap* _tmp243_;
		SerializableGeeHashMapTestBigBag* _tmp244_;
		SerializableGeeHashMapTestSmallBagHashMap* _tmp245_;
		SerializableGeeHashMapTestSmallBagHashMap* _tmp246_;
		gint _tmp247_;
		gint _tmp248_;
		gboolean _tmp249_ = FALSE;
		SerializableGeeHashMapTestBigBag* _tmp250_;
		SerializableGeeHashMapTestSmallBagHashMap* _tmp251_;
		SerializableGeeHashMapTestSmallBagHashMap* _tmp252_;
		gpointer _tmp253_;
		SerializableGeeHashMapTestSmallBag* _tmp254_;
		SerializableGeeHashMapTestBallHashMap* _tmp255_;
		SerializableGeeHashMapTestBallHashMap* _tmp256_;
		gboolean _tmp257_;
		SerializableGeeHashMapTestBigBag* _tmp258_;
		SerializableGeeHashMapTestSmallBagHashMap* _tmp259_;
		SerializableGeeHashMapTestSmallBagHashMap* _tmp260_;
		gpointer _tmp261_;
		SerializableGeeHashMapTestSmallBag* _tmp262_;
		SerializableGeeHashMapTestBallHashMap* _tmp263_;
		SerializableGeeHashMapTestBallHashMap* _tmp264_;
		gint _tmp265_;
		gint _tmp266_;
		SerializableGeeHashMapTestBigBag* _tmp267_;
		SerializableGeeHashMapTestSmallBagHashMap* _tmp268_;
		SerializableGeeHashMapTestSmallBagHashMap* _tmp269_;
		gpointer _tmp270_;
		SerializableGeeHashMapTestSmallBag* _tmp271_;
		SerializableGeeHashMapTestBallHashMap* _tmp272_;
		SerializableGeeHashMapTestBallHashMap* _tmp273_;
		gpointer _tmp274_;
		SerializableGeeHashMapTestBall* _tmp275_;
		const gchar* _tmp276_;
		const gchar* _tmp277_;
		SerializableGeeHashMapTestBigBag* _tmp278_;
		SerializableGeeHashMapTestSmallBagHashMap* _tmp279_;
		SerializableGeeHashMapTestSmallBagHashMap* _tmp280_;
		gpointer _tmp281_;
		SerializableGeeHashMapTestSmallBag* _tmp282_;
		SerializableGeeHashMapTestBallHashMap* _tmp283_;
		SerializableGeeHashMapTestBallHashMap* _tmp284_;
		gpointer _tmp285_;
		SerializableGeeHashMapTestBall* _tmp286_;
		SerializableGeeHashMapTestBallFill* _tmp287_;
		SerializableGeeHashMapTestBallFill* _tmp288_;
		SerializableGeeHashMapTestBigBag* _tmp289_;
		SerializableGeeHashMapTestSmallBagHashMap* _tmp290_;
		SerializableGeeHashMapTestSmallBagHashMap* _tmp291_;
		gpointer _tmp292_;
		SerializableGeeHashMapTestSmallBag* _tmp293_;
		SerializableGeeHashMapTestBallHashMap* _tmp294_;
		SerializableGeeHashMapTestBallHashMap* _tmp295_;
		gpointer _tmp296_;
		SerializableGeeHashMapTestBall* _tmp297_;
		SerializableGeeHashMapTestBallFill* _tmp298_;
		SerializableGeeHashMapTestBallFill* _tmp299_;
		gchar* _tmp300_;
		gchar* _tmp301_;
		gchar* _tmp302_;
		SerializableGeeHashMapTestBigBag* _tmp303_;
		SerializableGeeHashMapTestSmallBagHashMap* _tmp304_;
		SerializableGeeHashMapTestSmallBagHashMap* _tmp305_;
		gpointer _tmp306_;
		SerializableGeeHashMapTestSmallBag* _tmp307_;
		SerializableGeeHashMapTestBallHashMap* _tmp308_;
		SerializableGeeHashMapTestBallHashMap* _tmp309_;
		gpointer _tmp310_;
		SerializableGeeHashMapTestBall* _tmp311_;
		SerializableGeeHashMapTestBallFill* _tmp312_;
		SerializableGeeHashMapTestBallFill* _tmp313_;
		gchar* _tmp314_;
		gchar* _tmp315_;
		gchar* _tmp316_;
		SerializableGeeHashMapTestBigBag* bag2 = NULL;
		SerializableGeeHashMapTestBigBag* _tmp317_;
		SerializableGeeHashMapTestBigBag* _tmp318_;
		GXmlGDocument* _tmp319_;
		SerializableGeeHashMapTestBigBag* _tmp320_;
		SerializableGeeHashMapTestSmallBagHashMap* _tmp321_;
		SerializableGeeHashMapTestSmallBagHashMap* _tmp322_;
		gint _tmp323_;
		gint _tmp324_;
		GXmlGDocument* d2 = NULL;
		GXmlGDocument* _tmp325_;
		SerializableGeeHashMapTestBigBag* _tmp326_;
		GXmlGDocument* _tmp327_;
		GXmlNode* _tmp328_;
		GXmlNode* _tmp329_;
		GXmlGDocument* _tmp330_;
		GXmlNode* _tmp331_;
		GXmlNode* _tmp332_;
		GXmlNode* _tmp333_;
		GXmlGDocument* _tmp334_;
		GXmlNode* _tmp335_;
		GXmlNode* _tmp336_;
		GXmlNode* _tmp337_;
		gchar* _tmp338_;
		gchar* _tmp339_;
		gchar* _tmp340_;
		GXmlGDocument* _tmp341_;
		GXmlNode* _tmp342_;
		GXmlNode* _tmp343_;
		GXmlNode* _tmp344_;
		GeeBidirList* _tmp345_;
		GeeBidirList* _tmp346_;
		GeeBidirList* _tmp347_;
		gint _tmp348_;
		gint _tmp349_;
		GXmlGDocument* _tmp350_;
		GXmlNode* _tmp351_;
		GXmlNode* _tmp352_;
		GXmlNode* _tmp353_;
		GeeBidirList* _tmp354_;
		GeeBidirList* _tmp355_;
		GeeBidirList* _tmp356_;
		gpointer _tmp357_;
		GXmlNode* _tmp358_;
		gchar* _tmp359_;
		gchar* _tmp360_;
		gchar* _tmp361_;
		GXmlGDocument* _tmp362_;
		GXmlNode* _tmp363_;
		GXmlNode* _tmp364_;
		GXmlNode* _tmp365_;
		GeeBidirList* _tmp366_;
		GeeBidirList* _tmp367_;
		GeeBidirList* _tmp368_;
		gpointer _tmp369_;
		GXmlNode* _tmp370_;
		GeeBidirList* _tmp371_;
		GeeBidirList* _tmp372_;
		GeeBidirList* _tmp373_;
		gint _tmp374_;
		gint _tmp375_;
		GXmlGDocument* _tmp376_;
		GXmlNode* _tmp377_;
		GXmlNode* _tmp378_;
		GXmlNode* _tmp379_;
		GeeBidirList* _tmp380_;
		GeeBidirList* _tmp381_;
		GeeBidirList* _tmp382_;
		gpointer _tmp383_;
		GXmlNode* _tmp384_;
		GeeBidirList* _tmp385_;
		GeeBidirList* _tmp386_;
		GeeBidirList* _tmp387_;
		gpointer _tmp388_;
		GXmlNode* _tmp389_;
		gchar* _tmp390_;
		gchar* _tmp391_;
		gchar* _tmp392_;
		GXmlGDocument* _tmp393_;
		GXmlNode* _tmp394_;
		GXmlNode* _tmp395_;
		GXmlNode* _tmp396_;
		GeeBidirList* _tmp397_;
		GeeBidirList* _tmp398_;
		GeeBidirList* _tmp399_;
		gpointer _tmp400_;
		GXmlNode* _tmp401_;
		GeeBidirList* _tmp402_;
		GeeBidirList* _tmp403_;
		GeeBidirList* _tmp404_;
		gpointer _tmp405_;
		GXmlNode* _tmp406_;
		GeeBidirList* _tmp407_;
		GeeBidirList* _tmp408_;
		GeeBidirList* _tmp409_;
		gint _tmp410_;
		gint _tmp411_;
		GXmlGDocument* _tmp412_;
		GXmlNode* _tmp413_;
		GXmlNode* _tmp414_;
		GXmlNode* _tmp415_;
		GeeBidirList* _tmp416_;
		GeeBidirList* _tmp417_;
		GeeBidirList* _tmp418_;
		gpointer _tmp419_;
		GXmlNode* _tmp420_;
		GeeBidirList* _tmp421_;
		GeeBidirList* _tmp422_;
		GeeBidirList* _tmp423_;
		gpointer _tmp424_;
		GXmlNode* _tmp425_;
		GeeBidirList* _tmp426_;
		GeeBidirList* _tmp427_;
		GeeBidirList* _tmp428_;
		gpointer _tmp429_;
		GXmlNode* _tmp430_;
		gchar* _tmp431_;
		gchar* _tmp432_;
		gchar* _tmp433_;
		GXmlGDocument* _tmp434_;
		GXmlNode* _tmp435_;
		GXmlNode* _tmp436_;
		GXmlNode* _tmp437_;
		GeeBidirList* _tmp438_;
		GeeBidirList* _tmp439_;
		GeeBidirList* _tmp440_;
		gpointer _tmp441_;
		GXmlNode* _tmp442_;
		GeeBidirList* _tmp443_;
		GeeBidirList* _tmp444_;
		GeeBidirList* _tmp445_;
		gpointer _tmp446_;
		GXmlNode* _tmp447_;
		GeeBidirList* _tmp448_;
		GeeBidirList* _tmp449_;
		GeeBidirList* _tmp450_;
		gpointer _tmp451_;
		GXmlNode* _tmp452_;
		GeeBidirList* _tmp453_;
		GeeBidirList* _tmp454_;
		GeeBidirList* _tmp455_;
		gint _tmp456_;
		gint _tmp457_;
		GXmlGDocument* _tmp458_;
		GXmlNode* _tmp459_;
		GXmlNode* _tmp460_;
		GXmlNode* _tmp461_;
		GeeBidirList* _tmp462_;
		GeeBidirList* _tmp463_;
		GeeBidirList* _tmp464_;
		gpointer _tmp465_;
		GXmlNode* _tmp466_;
		GeeBidirList* _tmp467_;
		GeeBidirList* _tmp468_;
		GeeBidirList* _tmp469_;
		gpointer _tmp470_;
		GXmlNode* _tmp471_;
		GeeBidirList* _tmp472_;
		GeeBidirList* _tmp473_;
		GeeBidirList* _tmp474_;
		gpointer _tmp475_;
		GXmlNode* _tmp476_;
		GeeBidirList* _tmp477_;
		GeeBidirList* _tmp478_;
		GeeBidirList* _tmp479_;
		gpointer _tmp480_;
		GXmlNode* _tmp481_;
		GXmlGDocument* _tmp482_;
		GXmlNode* _tmp483_;
		GXmlNode* _tmp484_;
		GXmlNode* _tmp485_;
		GeeBidirList* _tmp486_;
		GeeBidirList* _tmp487_;
		GeeBidirList* _tmp488_;
		gpointer _tmp489_;
		GXmlNode* _tmp490_;
		GeeBidirList* _tmp491_;
		GeeBidirList* _tmp492_;
		GeeBidirList* _tmp493_;
		gpointer _tmp494_;
		GXmlNode* _tmp495_;
		GeeBidirList* _tmp496_;
		GeeBidirList* _tmp497_;
		GeeBidirList* _tmp498_;
		gpointer _tmp499_;
		GXmlNode* _tmp500_;
		GeeBidirList* _tmp501_;
		GeeBidirList* _tmp502_;
		GeeBidirList* _tmp503_;
		gpointer _tmp504_;
		GXmlNode* _tmp505_;
		gchar* _tmp506_;
		gchar* _tmp507_;
		gchar* _tmp508_;
#line 369 "SerializableGeeHashMapTest.vala"
		_tmp0_ = serializable_gee_hash_map_test_big_bag_new ();
#line 369 "SerializableGeeHashMapTest.vala"
		bag = _tmp0_;
#line 370 "SerializableGeeHashMapTest.vala"
		_tmp1_ = bag;
#line 370 "SerializableGeeHashMapTest.vala"
		_tmp2_ = serializable_gee_hash_map_test_big_bag_get_bags (_tmp1_);
#line 370 "SerializableGeeHashMapTest.vala"
		_tmp3_ = _tmp2_;
#line 370 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp3_ != NULL, "bag.bags != null");
#line 3739 "SerializableGeeHashMapTest.c"
		{
			gint i = 0;
#line 371 "SerializableGeeHashMapTest.vala"
			i = 0;
#line 3744 "SerializableGeeHashMapTest.c"
			{
				gboolean _tmp4_ = FALSE;
#line 371 "SerializableGeeHashMapTest.vala"
				_tmp4_ = TRUE;
#line 371 "SerializableGeeHashMapTest.vala"
				while (TRUE) {
#line 3751 "SerializableGeeHashMapTest.c"
					SerializableGeeHashMapTestSmallBag* sbag = NULL;
					SerializableGeeHashMapTestSmallBag* _tmp6_;
					SerializableGeeHashMapTestSmallBag* _tmp7_;
					gchar* _tmp8_;
					gchar* _tmp9_;
					gchar* _tmp10_;
					gchar* _tmp11_;
					SerializableGeeHashMapTestSmallBag* _tmp12_;
					SerializableGeeHashMapTestBallHashMap* _tmp13_;
					SerializableGeeHashMapTestBallHashMap* _tmp14_;
					SerializableGeeHashMapTestSmallBag* _tmp36_;
					SerializableGeeHashMapTestBallHashMap* _tmp37_;
					SerializableGeeHashMapTestBallHashMap* _tmp38_;
					gint _tmp39_;
					gint _tmp40_;
					SerializableGeeHashMapTestBigBag* _tmp41_;
					SerializableGeeHashMapTestSmallBagHashMap* _tmp42_;
					SerializableGeeHashMapTestSmallBagHashMap* _tmp43_;
					SerializableGeeHashMapTestSmallBag* _tmp44_;
					const gchar* _tmp45_;
					const gchar* _tmp46_;
					SerializableGeeHashMapTestSmallBag* _tmp47_;
#line 371 "SerializableGeeHashMapTest.vala"
					if (!_tmp4_) {
#line 3776 "SerializableGeeHashMapTest.c"
						gint _tmp5_;
#line 371 "SerializableGeeHashMapTest.vala"
						_tmp5_ = i;
#line 371 "SerializableGeeHashMapTest.vala"
						i = _tmp5_ + 1;
#line 3782 "SerializableGeeHashMapTest.c"
					}
#line 371 "SerializableGeeHashMapTest.vala"
					_tmp4_ = FALSE;
#line 371 "SerializableGeeHashMapTest.vala"
					if (!(i < 2)) {
#line 371 "SerializableGeeHashMapTest.vala"
						break;
#line 3790 "SerializableGeeHashMapTest.c"
					}
#line 372 "SerializableGeeHashMapTest.vala"
					_tmp6_ = serializable_gee_hash_map_test_small_bag_new ();
#line 372 "SerializableGeeHashMapTest.vala"
					sbag = _tmp6_;
#line 373 "SerializableGeeHashMapTest.vala"
					_tmp7_ = sbag;
#line 373 "SerializableGeeHashMapTest.vala"
					_tmp8_ = g_strdup_printf ("%i", i);
#line 373 "SerializableGeeHashMapTest.vala"
					_tmp9_ = _tmp8_;
#line 373 "SerializableGeeHashMapTest.vala"
					_tmp10_ = g_strconcat ("SmallBag", _tmp9_, NULL);
#line 373 "SerializableGeeHashMapTest.vala"
					_tmp11_ = _tmp10_;
#line 373 "SerializableGeeHashMapTest.vala"
					serializable_gee_hash_map_test_small_bag_set_name (_tmp7_, _tmp11_);
#line 373 "SerializableGeeHashMapTest.vala"
					_g_free0 (_tmp11_);
#line 373 "SerializableGeeHashMapTest.vala"
					_g_free0 (_tmp9_);
#line 374 "SerializableGeeHashMapTest.vala"
					_tmp12_ = sbag;
#line 374 "SerializableGeeHashMapTest.vala"
					_tmp13_ = serializable_gee_hash_map_test_small_bag_get_balls (_tmp12_);
#line 374 "SerializableGeeHashMapTest.vala"
					_tmp14_ = _tmp13_;
#line 374 "SerializableGeeHashMapTest.vala"
					_vala_assert (_tmp14_ != NULL, "sbag.balls != null");
#line 3820 "SerializableGeeHashMapTest.c"
					{
						gint j = 0;
#line 375 "SerializableGeeHashMapTest.vala"
						j = 0;
#line 3825 "SerializableGeeHashMapTest.c"
						{
							gboolean _tmp15_ = FALSE;
#line 375 "SerializableGeeHashMapTest.vala"
							_tmp15_ = TRUE;
#line 375 "SerializableGeeHashMapTest.vala"
							while (TRUE) {
#line 3832 "SerializableGeeHashMapTest.c"
								SerializableGeeHashMapTestBall* b = NULL;
								SerializableGeeHashMapTestBall* _tmp17_;
								SerializableGeeHashMapTestBall* _tmp18_;
								gchar* _tmp19_;
								gchar* _tmp20_;
								gchar* _tmp21_;
								gchar* _tmp22_;
								SerializableGeeHashMapTestBall* _tmp23_;
								SerializableGeeHashMapTestBallFill* _tmp24_;
								SerializableGeeHashMapTestBallFill* _tmp25_;
								SerializableGeeHashMapTestBall* _tmp26_;
								SerializableGeeHashMapTestBallFill* _tmp27_;
								SerializableGeeHashMapTestBallFill* _tmp28_;
								SerializableGeeHashMapTestSmallBag* _tmp29_;
								SerializableGeeHashMapTestBallHashMap* _tmp30_;
								SerializableGeeHashMapTestBallHashMap* _tmp31_;
								SerializableGeeHashMapTestBall* _tmp32_;
								const gchar* _tmp33_;
								const gchar* _tmp34_;
								SerializableGeeHashMapTestBall* _tmp35_;
#line 375 "SerializableGeeHashMapTest.vala"
								if (!_tmp15_) {
#line 3855 "SerializableGeeHashMapTest.c"
									gint _tmp16_;
#line 375 "SerializableGeeHashMapTest.vala"
									_tmp16_ = j;
#line 375 "SerializableGeeHashMapTest.vala"
									j = _tmp16_ + 1;
#line 3861 "SerializableGeeHashMapTest.c"
								}
#line 375 "SerializableGeeHashMapTest.vala"
								_tmp15_ = FALSE;
#line 375 "SerializableGeeHashMapTest.vala"
								if (!(j < 2)) {
#line 375 "SerializableGeeHashMapTest.vala"
									break;
#line 3869 "SerializableGeeHashMapTest.c"
								}
#line 376 "SerializableGeeHashMapTest.vala"
								_tmp17_ = serializable_gee_hash_map_test_ball_new ();
#line 376 "SerializableGeeHashMapTest.vala"
								b = _tmp17_;
#line 377 "SerializableGeeHashMapTest.vala"
								_tmp18_ = b;
#line 377 "SerializableGeeHashMapTest.vala"
								_tmp19_ = g_strdup_printf ("%i", j);
#line 377 "SerializableGeeHashMapTest.vala"
								_tmp20_ = _tmp19_;
#line 377 "SerializableGeeHashMapTest.vala"
								_tmp21_ = g_strconcat ("Ball", _tmp20_, NULL);
#line 377 "SerializableGeeHashMapTest.vala"
								_tmp22_ = _tmp21_;
#line 377 "SerializableGeeHashMapTest.vala"
								serializable_gee_hash_map_test_ball_set_name (_tmp18_, _tmp22_);
#line 377 "SerializableGeeHashMapTest.vala"
								_g_free0 (_tmp22_);
#line 377 "SerializableGeeHashMapTest.vala"
								_g_free0 (_tmp20_);
#line 378 "SerializableGeeHashMapTest.vala"
								_tmp23_ = b;
#line 378 "SerializableGeeHashMapTest.vala"
								_tmp24_ = serializable_gee_hash_map_test_ball_fill_new ();
#line 378 "SerializableGeeHashMapTest.vala"
								_tmp25_ = _tmp24_;
#line 378 "SerializableGeeHashMapTest.vala"
								serializable_gee_hash_map_test_ball_set_ballfill (_tmp23_, _tmp25_);
#line 378 "SerializableGeeHashMapTest.vala"
								_g_object_unref0 (_tmp25_);
#line 379 "SerializableGeeHashMapTest.vala"
								_tmp26_ = b;
#line 379 "SerializableGeeHashMapTest.vala"
								_tmp27_ = serializable_gee_hash_map_test_ball_get_ballfill (_tmp26_);
#line 379 "SerializableGeeHashMapTest.vala"
								_tmp28_ = _tmp27_;
#line 379 "SerializableGeeHashMapTest.vala"
								serializable_gee_hash_map_test_ball_fill_set_text (_tmp28_, "golden dust");
#line 380 "SerializableGeeHashMapTest.vala"
								_tmp29_ = sbag;
#line 380 "SerializableGeeHashMapTest.vala"
								_tmp30_ = serializable_gee_hash_map_test_small_bag_get_balls (_tmp29_);
#line 380 "SerializableGeeHashMapTest.vala"
								_tmp31_ = _tmp30_;
#line 380 "SerializableGeeHashMapTest.vala"
								_tmp32_ = b;
#line 380 "SerializableGeeHashMapTest.vala"
								_tmp33_ = serializable_gee_hash_map_test_ball_get_name (_tmp32_);
#line 380 "SerializableGeeHashMapTest.vala"
								_tmp34_ = _tmp33_;
#line 380 "SerializableGeeHashMapTest.vala"
								_tmp35_ = b;
#line 380 "SerializableGeeHashMapTest.vala"
								gee_abstract_map_set ((GeeAbstractMap*) _tmp31_, _tmp34_, _tmp35_);
#line 375 "SerializableGeeHashMapTest.vala"
								_g_object_unref0 (b);
#line 3927 "SerializableGeeHashMapTest.c"
							}
						}
					}
#line 382 "SerializableGeeHashMapTest.vala"
					_tmp36_ = sbag;
#line 382 "SerializableGeeHashMapTest.vala"
					_tmp37_ = serializable_gee_hash_map_test_small_bag_get_balls (_tmp36_);
#line 382 "SerializableGeeHashMapTest.vala"
					_tmp38_ = _tmp37_;
#line 382 "SerializableGeeHashMapTest.vala"
					_tmp39_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp38_);
#line 382 "SerializableGeeHashMapTest.vala"
					_tmp40_ = _tmp39_;
#line 382 "SerializableGeeHashMapTest.vala"
					_vala_assert (_tmp40_ == 2, "sbag.balls.size == 2");
#line 383 "SerializableGeeHashMapTest.vala"
					_tmp41_ = bag;
#line 383 "SerializableGeeHashMapTest.vala"
					_tmp42_ = serializable_gee_hash_map_test_big_bag_get_bags (_tmp41_);
#line 383 "SerializableGeeHashMapTest.vala"
					_tmp43_ = _tmp42_;
#line 383 "SerializableGeeHashMapTest.vala"
					_tmp44_ = sbag;
#line 383 "SerializableGeeHashMapTest.vala"
					_tmp45_ = serializable_gee_hash_map_test_small_bag_get_name (_tmp44_);
#line 383 "SerializableGeeHashMapTest.vala"
					_tmp46_ = _tmp45_;
#line 383 "SerializableGeeHashMapTest.vala"
					_tmp47_ = sbag;
#line 383 "SerializableGeeHashMapTest.vala"
					gee_abstract_map_set ((GeeAbstractMap*) _tmp43_, _tmp46_, _tmp47_);
#line 371 "SerializableGeeHashMapTest.vala"
					_g_object_unref0 (sbag);
#line 3961 "SerializableGeeHashMapTest.c"
				}
			}
		}
#line 385 "SerializableGeeHashMapTest.vala"
		_tmp48_ = bag;
#line 385 "SerializableGeeHashMapTest.vala"
		_tmp49_ = serializable_gee_hash_map_test_big_bag_get_bags (_tmp48_);
#line 385 "SerializableGeeHashMapTest.vala"
		_tmp50_ = _tmp49_;
#line 385 "SerializableGeeHashMapTest.vala"
		_tmp51_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp50_);
#line 385 "SerializableGeeHashMapTest.vala"
		_tmp52_ = _tmp51_;
#line 385 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp52_ == 2, "bag.bags.size == 2");
#line 387 "SerializableGeeHashMapTest.vala"
		_tmp53_ = gxml_gdocument_new ();
#line 387 "SerializableGeeHashMapTest.vala"
		d = _tmp53_;
#line 388 "SerializableGeeHashMapTest.vala"
		_tmp54_ = bag;
#line 388 "SerializableGeeHashMapTest.vala"
		_tmp55_ = d;
#line 388 "SerializableGeeHashMapTest.vala"
		_tmp56_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp54_, (GXmlNode*) _tmp55_, &_inner_error0_);
#line 388 "SerializableGeeHashMapTest.vala"
		_tmp57_ = _tmp56_;
#line 388 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp57_);
#line 388 "SerializableGeeHashMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 388 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (d);
#line 388 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (bag);
#line 3997 "SerializableGeeHashMapTest.c"
			goto __catch368_g_error;
		}
#line 389 "SerializableGeeHashMapTest.vala"
		_tmp58_ = d;
#line 389 "SerializableGeeHashMapTest.vala"
		_tmp59_ = gxml_document_get_root ((GXmlDocument*) _tmp58_);
#line 389 "SerializableGeeHashMapTest.vala"
		_tmp60_ = _tmp59_;
#line 389 "SerializableGeeHashMapTest.vala"
		_tmp61_ = _tmp60_;
#line 389 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp61_ != NULL, "d.root != null");
#line 389 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp61_);
#line 390 "SerializableGeeHashMapTest.vala"
		_tmp62_ = d;
#line 390 "SerializableGeeHashMapTest.vala"
		_tmp63_ = gxml_document_get_root ((GXmlDocument*) _tmp62_);
#line 390 "SerializableGeeHashMapTest.vala"
		_tmp64_ = _tmp63_;
#line 390 "SerializableGeeHashMapTest.vala"
		_tmp65_ = _tmp64_;
#line 390 "SerializableGeeHashMapTest.vala"
		_tmp66_ = gxml_node_get_name (_tmp65_);
#line 390 "SerializableGeeHashMapTest.vala"
		_tmp67_ = _tmp66_;
#line 390 "SerializableGeeHashMapTest.vala"
		_tmp68_ = _tmp67_;
#line 390 "SerializableGeeHashMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp68_, "BigBag") == 0, "d.root.name == \"BigBag\"");
#line 390 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp68_);
#line 390 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp65_);
#line 391 "SerializableGeeHashMapTest.vala"
		_tmp69_ = d;
#line 391 "SerializableGeeHashMapTest.vala"
		_tmp70_ = gxml_document_get_root ((GXmlDocument*) _tmp69_);
#line 391 "SerializableGeeHashMapTest.vala"
		_tmp71_ = _tmp70_;
#line 391 "SerializableGeeHashMapTest.vala"
		_tmp72_ = _tmp71_;
#line 391 "SerializableGeeHashMapTest.vala"
		_tmp73_ = gxml_node_get_children_nodes (_tmp72_);
#line 391 "SerializableGeeHashMapTest.vala"
		_tmp74_ = _tmp73_;
#line 391 "SerializableGeeHashMapTest.vala"
		_tmp75_ = _tmp74_;
#line 391 "SerializableGeeHashMapTest.vala"
		_tmp76_ = gee_collection_get_size ((GeeCollection*) _tmp75_);
#line 391 "SerializableGeeHashMapTest.vala"
		_tmp77_ = _tmp76_;
#line 391 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp77_ == 2, "d.root.children_nodes.size == 2");
#line 391 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp75_);
#line 391 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp72_);
#line 392 "SerializableGeeHashMapTest.vala"
		_tmp78_ = d;
#line 392 "SerializableGeeHashMapTest.vala"
		_tmp79_ = gxml_document_get_root ((GXmlDocument*) _tmp78_);
#line 392 "SerializableGeeHashMapTest.vala"
		_tmp80_ = _tmp79_;
#line 392 "SerializableGeeHashMapTest.vala"
		_tmp81_ = _tmp80_;
#line 392 "SerializableGeeHashMapTest.vala"
		_tmp82_ = gxml_node_get_children_nodes (_tmp81_);
#line 392 "SerializableGeeHashMapTest.vala"
		_tmp83_ = _tmp82_;
#line 392 "SerializableGeeHashMapTest.vala"
		_tmp84_ = _tmp83_;
#line 392 "SerializableGeeHashMapTest.vala"
		_tmp85_ = gee_list_get ((GeeList*) _tmp84_, 0);
#line 392 "SerializableGeeHashMapTest.vala"
		_tmp86_ = (GXmlNode*) _tmp85_;
#line 392 "SerializableGeeHashMapTest.vala"
		_tmp87_ = gxml_node_get_name (_tmp86_);
#line 392 "SerializableGeeHashMapTest.vala"
		_tmp88_ = _tmp87_;
#line 392 "SerializableGeeHashMapTest.vala"
		_tmp89_ = _tmp88_;
#line 392 "SerializableGeeHashMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp89_, "SmallBag") == 0, "d.root.children_nodes[0].name == \"SmallBag\"");
#line 392 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp89_);
#line 392 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp86_);
#line 392 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp84_);
#line 392 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp81_);
#line 393 "SerializableGeeHashMapTest.vala"
		_tmp90_ = d;
#line 393 "SerializableGeeHashMapTest.vala"
		_tmp91_ = gxml_document_get_root ((GXmlDocument*) _tmp90_);
#line 393 "SerializableGeeHashMapTest.vala"
		_tmp92_ = _tmp91_;
#line 393 "SerializableGeeHashMapTest.vala"
		_tmp93_ = _tmp92_;
#line 393 "SerializableGeeHashMapTest.vala"
		_tmp94_ = gxml_node_get_children_nodes (_tmp93_);
#line 393 "SerializableGeeHashMapTest.vala"
		_tmp95_ = _tmp94_;
#line 393 "SerializableGeeHashMapTest.vala"
		_tmp96_ = _tmp95_;
#line 393 "SerializableGeeHashMapTest.vala"
		_tmp97_ = gee_list_get ((GeeList*) _tmp96_, 0);
#line 393 "SerializableGeeHashMapTest.vala"
		_tmp98_ = (GXmlNode*) _tmp97_;
#line 393 "SerializableGeeHashMapTest.vala"
		_tmp99_ = gxml_node_get_children_nodes (_tmp98_);
#line 393 "SerializableGeeHashMapTest.vala"
		_tmp100_ = _tmp99_;
#line 393 "SerializableGeeHashMapTest.vala"
		_tmp101_ = _tmp100_;
#line 393 "SerializableGeeHashMapTest.vala"
		_tmp102_ = gee_collection_get_size ((GeeCollection*) _tmp101_);
#line 393 "SerializableGeeHashMapTest.vala"
		_tmp103_ = _tmp102_;
#line 393 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp103_ == 2, "d.root.children_nodes[0].children_nodes.size == 2");
#line 393 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp101_);
#line 393 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp98_);
#line 393 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp96_);
#line 393 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp93_);
#line 394 "SerializableGeeHashMapTest.vala"
		_tmp104_ = d;
#line 394 "SerializableGeeHashMapTest.vala"
		_tmp105_ = gxml_document_get_root ((GXmlDocument*) _tmp104_);
#line 394 "SerializableGeeHashMapTest.vala"
		_tmp106_ = _tmp105_;
#line 394 "SerializableGeeHashMapTest.vala"
		_tmp107_ = _tmp106_;
#line 394 "SerializableGeeHashMapTest.vala"
		_tmp108_ = gxml_node_get_children_nodes (_tmp107_);
#line 394 "SerializableGeeHashMapTest.vala"
		_tmp109_ = _tmp108_;
#line 394 "SerializableGeeHashMapTest.vala"
		_tmp110_ = _tmp109_;
#line 394 "SerializableGeeHashMapTest.vala"
		_tmp111_ = gee_list_get ((GeeList*) _tmp110_, 0);
#line 394 "SerializableGeeHashMapTest.vala"
		_tmp112_ = (GXmlNode*) _tmp111_;
#line 394 "SerializableGeeHashMapTest.vala"
		_tmp113_ = gxml_node_get_children_nodes (_tmp112_);
#line 394 "SerializableGeeHashMapTest.vala"
		_tmp114_ = _tmp113_;
#line 394 "SerializableGeeHashMapTest.vala"
		_tmp115_ = _tmp114_;
#line 394 "SerializableGeeHashMapTest.vala"
		_tmp116_ = gee_list_get ((GeeList*) _tmp115_, 0);
#line 394 "SerializableGeeHashMapTest.vala"
		_tmp117_ = (GXmlNode*) _tmp116_;
#line 394 "SerializableGeeHashMapTest.vala"
		_tmp118_ = gxml_node_get_name (_tmp117_);
#line 394 "SerializableGeeHashMapTest.vala"
		_tmp119_ = _tmp118_;
#line 394 "SerializableGeeHashMapTest.vala"
		_tmp120_ = _tmp119_;
#line 394 "SerializableGeeHashMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp120_, "Ball") == 0, "d.root.children_nodes[0].children_nodes[0].name == \"Ball\"");
#line 394 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp120_);
#line 394 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp117_);
#line 394 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp115_);
#line 394 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp112_);
#line 394 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp110_);
#line 394 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp107_);
#line 395 "SerializableGeeHashMapTest.vala"
		_tmp121_ = d;
#line 395 "SerializableGeeHashMapTest.vala"
		_tmp122_ = gxml_document_get_root ((GXmlDocument*) _tmp121_);
#line 395 "SerializableGeeHashMapTest.vala"
		_tmp123_ = _tmp122_;
#line 395 "SerializableGeeHashMapTest.vala"
		_tmp124_ = _tmp123_;
#line 395 "SerializableGeeHashMapTest.vala"
		_tmp125_ = gxml_node_get_children_nodes (_tmp124_);
#line 395 "SerializableGeeHashMapTest.vala"
		_tmp126_ = _tmp125_;
#line 395 "SerializableGeeHashMapTest.vala"
		_tmp127_ = _tmp126_;
#line 395 "SerializableGeeHashMapTest.vala"
		_tmp128_ = gee_list_get ((GeeList*) _tmp127_, 0);
#line 395 "SerializableGeeHashMapTest.vala"
		_tmp129_ = (GXmlNode*) _tmp128_;
#line 395 "SerializableGeeHashMapTest.vala"
		_tmp130_ = gxml_node_get_children_nodes (_tmp129_);
#line 395 "SerializableGeeHashMapTest.vala"
		_tmp131_ = _tmp130_;
#line 395 "SerializableGeeHashMapTest.vala"
		_tmp132_ = _tmp131_;
#line 395 "SerializableGeeHashMapTest.vala"
		_tmp133_ = gee_list_get ((GeeList*) _tmp132_, 0);
#line 395 "SerializableGeeHashMapTest.vala"
		_tmp134_ = (GXmlNode*) _tmp133_;
#line 395 "SerializableGeeHashMapTest.vala"
		_tmp135_ = gxml_node_get_children_nodes (_tmp134_);
#line 395 "SerializableGeeHashMapTest.vala"
		_tmp136_ = _tmp135_;
#line 395 "SerializableGeeHashMapTest.vala"
		_tmp137_ = _tmp136_;
#line 395 "SerializableGeeHashMapTest.vala"
		_tmp138_ = gee_collection_get_size ((GeeCollection*) _tmp137_);
#line 395 "SerializableGeeHashMapTest.vala"
		_tmp139_ = _tmp138_;
#line 395 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp139_ == 1, "d.root.children_nodes[0].children_nodes[0].children_nodes.size == 1");
#line 395 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp137_);
#line 395 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp134_);
#line 395 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp132_);
#line 395 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp129_);
#line 395 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp127_);
#line 395 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp124_);
#line 396 "SerializableGeeHashMapTest.vala"
		_tmp140_ = d;
#line 396 "SerializableGeeHashMapTest.vala"
		_tmp141_ = gxml_document_get_root ((GXmlDocument*) _tmp140_);
#line 396 "SerializableGeeHashMapTest.vala"
		_tmp142_ = _tmp141_;
#line 396 "SerializableGeeHashMapTest.vala"
		_tmp143_ = _tmp142_;
#line 396 "SerializableGeeHashMapTest.vala"
		_tmp144_ = gxml_node_get_children_nodes (_tmp143_);
#line 396 "SerializableGeeHashMapTest.vala"
		_tmp145_ = _tmp144_;
#line 396 "SerializableGeeHashMapTest.vala"
		_tmp146_ = _tmp145_;
#line 396 "SerializableGeeHashMapTest.vala"
		_tmp147_ = gee_list_get ((GeeList*) _tmp146_, 0);
#line 396 "SerializableGeeHashMapTest.vala"
		_tmp148_ = (GXmlNode*) _tmp147_;
#line 396 "SerializableGeeHashMapTest.vala"
		_tmp149_ = gxml_node_get_children_nodes (_tmp148_);
#line 396 "SerializableGeeHashMapTest.vala"
		_tmp150_ = _tmp149_;
#line 396 "SerializableGeeHashMapTest.vala"
		_tmp151_ = _tmp150_;
#line 396 "SerializableGeeHashMapTest.vala"
		_tmp152_ = gee_list_get ((GeeList*) _tmp151_, 0);
#line 396 "SerializableGeeHashMapTest.vala"
		_tmp153_ = (GXmlNode*) _tmp152_;
#line 396 "SerializableGeeHashMapTest.vala"
		_tmp154_ = gxml_node_get_children_nodes (_tmp153_);
#line 396 "SerializableGeeHashMapTest.vala"
		_tmp155_ = _tmp154_;
#line 396 "SerializableGeeHashMapTest.vala"
		_tmp156_ = _tmp155_;
#line 396 "SerializableGeeHashMapTest.vala"
		_tmp157_ = gee_list_get ((GeeList*) _tmp156_, 0);
#line 396 "SerializableGeeHashMapTest.vala"
		_tmp158_ = (GXmlNode*) _tmp157_;
#line 396 "SerializableGeeHashMapTest.vala"
		_tmp159_ = gxml_node_get_name (_tmp158_);
#line 396 "SerializableGeeHashMapTest.vala"
		_tmp160_ = _tmp159_;
#line 396 "SerializableGeeHashMapTest.vala"
		_tmp161_ = _tmp160_;
#line 396 "SerializableGeeHashMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp161_, "BallFill") == 0, "d.root.children_nodes[0].children_nodes[0].children_nodes[0].name == \"BallFill\"");
#line 396 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp161_);
#line 396 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp158_);
#line 396 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp156_);
#line 396 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp153_);
#line 396 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp151_);
#line 396 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp148_);
#line 396 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp146_);
#line 396 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp143_);
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp162_ = d;
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp163_ = gxml_document_get_root ((GXmlDocument*) _tmp162_);
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp164_ = _tmp163_;
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp165_ = _tmp164_;
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp166_ = gxml_node_get_children_nodes (_tmp165_);
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp167_ = _tmp166_;
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp168_ = _tmp167_;
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp169_ = gee_list_get ((GeeList*) _tmp168_, 0);
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp170_ = (GXmlNode*) _tmp169_;
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp171_ = gxml_node_get_children_nodes (_tmp170_);
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp172_ = _tmp171_;
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp173_ = _tmp172_;
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp174_ = gee_list_get ((GeeList*) _tmp173_, 0);
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp175_ = (GXmlNode*) _tmp174_;
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp176_ = gxml_node_get_children_nodes (_tmp175_);
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp177_ = _tmp176_;
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp178_ = _tmp177_;
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp179_ = gee_list_get ((GeeList*) _tmp178_, 0);
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp180_ = (GXmlNode*) _tmp179_;
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp181_ = gxml_node_get_children_nodes (_tmp180_);
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp182_ = _tmp181_;
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp183_ = _tmp182_;
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp184_ = gee_collection_get_size ((GeeCollection*) _tmp183_);
#line 397 "SerializableGeeHashMapTest.vala"
		_tmp185_ = _tmp184_;
#line 397 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp185_ == 1, "d.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes.size == 1");
#line 397 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp183_);
#line 397 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp180_);
#line 397 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp178_);
#line 397 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp175_);
#line 397 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp173_);
#line 397 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp170_);
#line 397 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp168_);
#line 397 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp165_);
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp186_ = d;
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp187_ = gxml_document_get_root ((GXmlDocument*) _tmp186_);
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp188_ = _tmp187_;
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp189_ = _tmp188_;
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp190_ = gxml_node_get_children_nodes (_tmp189_);
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp191_ = _tmp190_;
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp192_ = _tmp191_;
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp193_ = gee_list_get ((GeeList*) _tmp192_, 0);
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp194_ = (GXmlNode*) _tmp193_;
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp195_ = gxml_node_get_children_nodes (_tmp194_);
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp196_ = _tmp195_;
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp197_ = _tmp196_;
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp198_ = gee_list_get ((GeeList*) _tmp197_, 0);
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp199_ = (GXmlNode*) _tmp198_;
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp200_ = gxml_node_get_children_nodes (_tmp199_);
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp201_ = _tmp200_;
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp202_ = _tmp201_;
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp203_ = gee_list_get ((GeeList*) _tmp202_, 0);
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp204_ = (GXmlNode*) _tmp203_;
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp205_ = gxml_node_get_children_nodes (_tmp204_);
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp206_ = _tmp205_;
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp207_ = _tmp206_;
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp208_ = gee_list_get ((GeeList*) _tmp207_, 0);
#line 398 "SerializableGeeHashMapTest.vala"
		_tmp209_ = (GXmlNode*) _tmp208_;
#line 398 "SerializableGeeHashMapTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp209_, GXML_TYPE_TEXT), "d.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes[0] is Text");
#line 398 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp209_);
#line 398 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp207_);
#line 398 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp204_);
#line 398 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp202_);
#line 398 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp199_);
#line 398 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp197_);
#line 398 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp194_);
#line 398 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp192_);
#line 398 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp189_);
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp210_ = d;
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp211_ = gxml_document_get_root ((GXmlDocument*) _tmp210_);
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp212_ = _tmp211_;
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp213_ = _tmp212_;
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp214_ = gxml_node_get_children_nodes (_tmp213_);
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp215_ = _tmp214_;
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp216_ = _tmp215_;
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp217_ = gee_list_get ((GeeList*) _tmp216_, 0);
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp218_ = (GXmlNode*) _tmp217_;
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp219_ = gxml_node_get_children_nodes (_tmp218_);
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp220_ = _tmp219_;
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp221_ = _tmp220_;
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp222_ = gee_list_get ((GeeList*) _tmp221_, 0);
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp223_ = (GXmlNode*) _tmp222_;
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp224_ = gxml_node_get_children_nodes (_tmp223_);
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp225_ = _tmp224_;
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp226_ = _tmp225_;
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp227_ = gee_list_get ((GeeList*) _tmp226_, 0);
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp228_ = (GXmlNode*) _tmp227_;
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp229_ = gxml_node_get_children_nodes (_tmp228_);
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp230_ = _tmp229_;
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp231_ = _tmp230_;
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp232_ = gee_list_get ((GeeList*) _tmp231_, 0);
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp233_ = (GXmlNode*) _tmp232_;
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp234_ = gxml_node_get_value (_tmp233_);
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp235_ = _tmp234_;
#line 399 "SerializableGeeHashMapTest.vala"
		_tmp236_ = _tmp235_;
#line 399 "SerializableGeeHashMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp236_, "golden dust") == 0, "d.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes[0].value == \"golden dust\"");
#line 399 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp236_);
#line 399 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp233_);
#line 399 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp231_);
#line 399 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp228_);
#line 399 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp226_);
#line 399 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp223_);
#line 399 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp221_);
#line 399 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp218_);
#line 399 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp216_);
#line 399 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp213_);
#line 402 "SerializableGeeHashMapTest.vala"
		_tmp237_ = serializable_gee_hash_map_test_big_bag_new ();
#line 402 "SerializableGeeHashMapTest.vala"
		bagt = _tmp237_;
#line 403 "SerializableGeeHashMapTest.vala"
		_tmp238_ = bagt;
#line 403 "SerializableGeeHashMapTest.vala"
		_tmp239_ = d;
#line 403 "SerializableGeeHashMapTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp238_, (GXmlNode*) _tmp239_, &_inner_error0_);
#line 403 "SerializableGeeHashMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 403 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (bagt);
#line 403 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (d);
#line 403 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (bag);
#line 4518 "SerializableGeeHashMapTest.c"
			goto __catch368_g_error;
		}
#line 404 "SerializableGeeHashMapTest.vala"
		_tmp241_ = bagt;
#line 404 "SerializableGeeHashMapTest.vala"
		_tmp242_ = serializable_gee_hash_map_test_big_bag_get_bags (_tmp241_);
#line 404 "SerializableGeeHashMapTest.vala"
		_tmp243_ = _tmp242_;
#line 404 "SerializableGeeHashMapTest.vala"
		_tmp240_ = gxml_serializable_hash_map_deserialize_children ((GXmlSerializableHashMap*) _tmp243_, &_inner_error0_);
#line 404 "SerializableGeeHashMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 404 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (bagt);
#line 404 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (d);
#line 404 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (bag);
#line 4537 "SerializableGeeHashMapTest.c"
			goto __catch368_g_error;
		}
#line 404 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp240_, "bagt.bags.deserialize_children ()");
#line 405 "SerializableGeeHashMapTest.vala"
		_tmp244_ = bagt;
#line 405 "SerializableGeeHashMapTest.vala"
		_tmp245_ = serializable_gee_hash_map_test_big_bag_get_bags (_tmp244_);
#line 405 "SerializableGeeHashMapTest.vala"
		_tmp246_ = _tmp245_;
#line 405 "SerializableGeeHashMapTest.vala"
		_tmp247_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp246_);
#line 405 "SerializableGeeHashMapTest.vala"
		_tmp248_ = _tmp247_;
#line 405 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp248_ == 2, "bagt.bags.size == 2");
#line 406 "SerializableGeeHashMapTest.vala"
		_tmp250_ = bagt;
#line 406 "SerializableGeeHashMapTest.vala"
		_tmp251_ = serializable_gee_hash_map_test_big_bag_get_bags (_tmp250_);
#line 406 "SerializableGeeHashMapTest.vala"
		_tmp252_ = _tmp251_;
#line 406 "SerializableGeeHashMapTest.vala"
		_tmp253_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp252_, "SmallBag1");
#line 406 "SerializableGeeHashMapTest.vala"
		_tmp254_ = (SerializableGeeHashMapTestSmallBag*) _tmp253_;
#line 406 "SerializableGeeHashMapTest.vala"
		_tmp255_ = serializable_gee_hash_map_test_small_bag_get_balls (_tmp254_);
#line 406 "SerializableGeeHashMapTest.vala"
		_tmp256_ = _tmp255_;
#line 406 "SerializableGeeHashMapTest.vala"
		_tmp257_ = gxml_serializable_hash_map_deserialize_children ((GXmlSerializableHashMap*) _tmp256_, &_inner_error0_);
#line 406 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp254_);
#line 406 "SerializableGeeHashMapTest.vala"
		_tmp249_ = _tmp257_;
#line 406 "SerializableGeeHashMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 406 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (bagt);
#line 406 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (d);
#line 406 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (bag);
#line 4582 "SerializableGeeHashMapTest.c"
			goto __catch368_g_error;
		}
#line 406 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp249_, "bagt.bags.get(\"SmallBag1\").balls.deserialize_children ()");
#line 407 "SerializableGeeHashMapTest.vala"
		_tmp258_ = bagt;
#line 407 "SerializableGeeHashMapTest.vala"
		_tmp259_ = serializable_gee_hash_map_test_big_bag_get_bags (_tmp258_);
#line 407 "SerializableGeeHashMapTest.vala"
		_tmp260_ = _tmp259_;
#line 407 "SerializableGeeHashMapTest.vala"
		_tmp261_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp260_, "SmallBag1");
#line 407 "SerializableGeeHashMapTest.vala"
		_tmp262_ = (SerializableGeeHashMapTestSmallBag*) _tmp261_;
#line 407 "SerializableGeeHashMapTest.vala"
		_tmp263_ = serializable_gee_hash_map_test_small_bag_get_balls (_tmp262_);
#line 407 "SerializableGeeHashMapTest.vala"
		_tmp264_ = _tmp263_;
#line 407 "SerializableGeeHashMapTest.vala"
		_tmp265_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp264_);
#line 407 "SerializableGeeHashMapTest.vala"
		_tmp266_ = _tmp265_;
#line 407 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp266_ == 2, "bagt.bags.get(\"SmallBag1\").balls.size == 2");
#line 407 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp262_);
#line 408 "SerializableGeeHashMapTest.vala"
		_tmp267_ = bagt;
#line 408 "SerializableGeeHashMapTest.vala"
		_tmp268_ = serializable_gee_hash_map_test_big_bag_get_bags (_tmp267_);
#line 408 "SerializableGeeHashMapTest.vala"
		_tmp269_ = _tmp268_;
#line 408 "SerializableGeeHashMapTest.vala"
		_tmp270_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp269_, "SmallBag1");
#line 408 "SerializableGeeHashMapTest.vala"
		_tmp271_ = (SerializableGeeHashMapTestSmallBag*) _tmp270_;
#line 408 "SerializableGeeHashMapTest.vala"
		_tmp272_ = serializable_gee_hash_map_test_small_bag_get_balls (_tmp271_);
#line 408 "SerializableGeeHashMapTest.vala"
		_tmp273_ = _tmp272_;
#line 408 "SerializableGeeHashMapTest.vala"
		_tmp274_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp273_, "Ball1");
#line 408 "SerializableGeeHashMapTest.vala"
		_tmp275_ = (SerializableGeeHashMapTestBall*) _tmp274_;
#line 408 "SerializableGeeHashMapTest.vala"
		_tmp276_ = serializable_gee_hash_map_test_ball_get_name (_tmp275_);
#line 408 "SerializableGeeHashMapTest.vala"
		_tmp277_ = _tmp276_;
#line 408 "SerializableGeeHashMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp277_, "Ball1") == 0, "bagt.bags.get(\"SmallBag1\").balls.get(\"Ball1\").name == \"Ball1\"");
#line 408 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp275_);
#line 408 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp271_);
#line 409 "SerializableGeeHashMapTest.vala"
		_tmp278_ = bagt;
#line 409 "SerializableGeeHashMapTest.vala"
		_tmp279_ = serializable_gee_hash_map_test_big_bag_get_bags (_tmp278_);
#line 409 "SerializableGeeHashMapTest.vala"
		_tmp280_ = _tmp279_;
#line 409 "SerializableGeeHashMapTest.vala"
		_tmp281_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp280_, "SmallBag1");
#line 409 "SerializableGeeHashMapTest.vala"
		_tmp282_ = (SerializableGeeHashMapTestSmallBag*) _tmp281_;
#line 409 "SerializableGeeHashMapTest.vala"
		_tmp283_ = serializable_gee_hash_map_test_small_bag_get_balls (_tmp282_);
#line 409 "SerializableGeeHashMapTest.vala"
		_tmp284_ = _tmp283_;
#line 409 "SerializableGeeHashMapTest.vala"
		_tmp285_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp284_, "Ball1");
#line 409 "SerializableGeeHashMapTest.vala"
		_tmp286_ = (SerializableGeeHashMapTestBall*) _tmp285_;
#line 409 "SerializableGeeHashMapTest.vala"
		_tmp287_ = serializable_gee_hash_map_test_ball_get_ballfill (_tmp286_);
#line 409 "SerializableGeeHashMapTest.vala"
		_tmp288_ = _tmp287_;
#line 409 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp288_ != NULL, "bagt.bags.get(\"SmallBag1\").balls.get(\"Ball1\").ballfill !=null");
#line 409 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp286_);
#line 409 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp282_);
#line 410 "SerializableGeeHashMapTest.vala"
		_tmp289_ = bagt;
#line 410 "SerializableGeeHashMapTest.vala"
		_tmp290_ = serializable_gee_hash_map_test_big_bag_get_bags (_tmp289_);
#line 410 "SerializableGeeHashMapTest.vala"
		_tmp291_ = _tmp290_;
#line 410 "SerializableGeeHashMapTest.vala"
		_tmp292_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp291_, "SmallBag1");
#line 410 "SerializableGeeHashMapTest.vala"
		_tmp293_ = (SerializableGeeHashMapTestSmallBag*) _tmp292_;
#line 410 "SerializableGeeHashMapTest.vala"
		_tmp294_ = serializable_gee_hash_map_test_small_bag_get_balls (_tmp293_);
#line 410 "SerializableGeeHashMapTest.vala"
		_tmp295_ = _tmp294_;
#line 410 "SerializableGeeHashMapTest.vala"
		_tmp296_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp295_, "Ball1");
#line 410 "SerializableGeeHashMapTest.vala"
		_tmp297_ = (SerializableGeeHashMapTestBall*) _tmp296_;
#line 410 "SerializableGeeHashMapTest.vala"
		_tmp298_ = serializable_gee_hash_map_test_ball_get_ballfill (_tmp297_);
#line 410 "SerializableGeeHashMapTest.vala"
		_tmp299_ = _tmp298_;
#line 410 "SerializableGeeHashMapTest.vala"
		_tmp300_ = gxml_serializable_get_serialized_xml_node_value ((GXmlSerializable*) _tmp299_);
#line 410 "SerializableGeeHashMapTest.vala"
		_tmp301_ = _tmp300_;
#line 410 "SerializableGeeHashMapTest.vala"
		_tmp302_ = _tmp301_;
#line 410 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp302_ != NULL, "bagt.bags.get(\"SmallBag1\").balls.get(\"Ball1\").ballfill.serialized_xml_node_value !=null");
#line 410 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp302_);
#line 410 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp297_);
#line 410 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp293_);
#line 411 "SerializableGeeHashMapTest.vala"
		_tmp303_ = bagt;
#line 411 "SerializableGeeHashMapTest.vala"
		_tmp304_ = serializable_gee_hash_map_test_big_bag_get_bags (_tmp303_);
#line 411 "SerializableGeeHashMapTest.vala"
		_tmp305_ = _tmp304_;
#line 411 "SerializableGeeHashMapTest.vala"
		_tmp306_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp305_, "SmallBag1");
#line 411 "SerializableGeeHashMapTest.vala"
		_tmp307_ = (SerializableGeeHashMapTestSmallBag*) _tmp306_;
#line 411 "SerializableGeeHashMapTest.vala"
		_tmp308_ = serializable_gee_hash_map_test_small_bag_get_balls (_tmp307_);
#line 411 "SerializableGeeHashMapTest.vala"
		_tmp309_ = _tmp308_;
#line 411 "SerializableGeeHashMapTest.vala"
		_tmp310_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp309_, "Ball1");
#line 411 "SerializableGeeHashMapTest.vala"
		_tmp311_ = (SerializableGeeHashMapTestBall*) _tmp310_;
#line 411 "SerializableGeeHashMapTest.vala"
		_tmp312_ = serializable_gee_hash_map_test_ball_get_ballfill (_tmp311_);
#line 411 "SerializableGeeHashMapTest.vala"
		_tmp313_ = _tmp312_;
#line 411 "SerializableGeeHashMapTest.vala"
		_tmp314_ = gxml_serializable_get_serialized_xml_node_value ((GXmlSerializable*) _tmp313_);
#line 411 "SerializableGeeHashMapTest.vala"
		_tmp315_ = _tmp314_;
#line 411 "SerializableGeeHashMapTest.vala"
		_tmp316_ = _tmp315_;
#line 411 "SerializableGeeHashMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp316_, "golden dust") == 0, "bagt.bags.get(\"SmallBag1\").balls.get(\"Ball1\").ballfill.serialized_xml_node_value ==\"golden dust\"");
#line 411 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp316_);
#line 411 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp311_);
#line 411 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp307_);
#line 412 "SerializableGeeHashMapTest.vala"
		_tmp317_ = serializable_gee_hash_map_test_big_bag_new ();
#line 412 "SerializableGeeHashMapTest.vala"
		bag2 = _tmp317_;
#line 413 "SerializableGeeHashMapTest.vala"
		_tmp318_ = bag2;
#line 413 "SerializableGeeHashMapTest.vala"
		_tmp319_ = d;
#line 413 "SerializableGeeHashMapTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp318_, (GXmlNode*) _tmp319_, &_inner_error0_);
#line 413 "SerializableGeeHashMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 413 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (bag2);
#line 413 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (bagt);
#line 413 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (d);
#line 413 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (bag);
#line 4757 "SerializableGeeHashMapTest.c"
			goto __catch368_g_error;
		}
#line 414 "SerializableGeeHashMapTest.vala"
		_tmp320_ = bag2;
#line 414 "SerializableGeeHashMapTest.vala"
		_tmp321_ = serializable_gee_hash_map_test_big_bag_get_bags (_tmp320_);
#line 414 "SerializableGeeHashMapTest.vala"
		_tmp322_ = _tmp321_;
#line 414 "SerializableGeeHashMapTest.vala"
		_tmp323_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp322_);
#line 414 "SerializableGeeHashMapTest.vala"
		_tmp324_ = _tmp323_;
#line 414 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp324_ == 0, "bag2.bags.size == 0");
#line 416 "SerializableGeeHashMapTest.vala"
		_tmp325_ = gxml_gdocument_new ();
#line 416 "SerializableGeeHashMapTest.vala"
		d2 = _tmp325_;
#line 417 "SerializableGeeHashMapTest.vala"
		_tmp326_ = bag2;
#line 417 "SerializableGeeHashMapTest.vala"
		_tmp327_ = d2;
#line 417 "SerializableGeeHashMapTest.vala"
		_tmp328_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp326_, (GXmlNode*) _tmp327_, &_inner_error0_);
#line 417 "SerializableGeeHashMapTest.vala"
		_tmp329_ = _tmp328_;
#line 417 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp329_);
#line 417 "SerializableGeeHashMapTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 417 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (d2);
#line 417 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (bag2);
#line 417 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (bagt);
#line 417 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (d);
#line 417 "SerializableGeeHashMapTest.vala"
			_g_object_unref0 (bag);
#line 4798 "SerializableGeeHashMapTest.c"
			goto __catch368_g_error;
		}
#line 419 "SerializableGeeHashMapTest.vala"
		_tmp330_ = d2;
#line 419 "SerializableGeeHashMapTest.vala"
		_tmp331_ = gxml_document_get_root ((GXmlDocument*) _tmp330_);
#line 419 "SerializableGeeHashMapTest.vala"
		_tmp332_ = _tmp331_;
#line 419 "SerializableGeeHashMapTest.vala"
		_tmp333_ = _tmp332_;
#line 419 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp333_ != NULL, "d2.root != null");
#line 419 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp333_);
#line 420 "SerializableGeeHashMapTest.vala"
		_tmp334_ = d2;
#line 420 "SerializableGeeHashMapTest.vala"
		_tmp335_ = gxml_document_get_root ((GXmlDocument*) _tmp334_);
#line 420 "SerializableGeeHashMapTest.vala"
		_tmp336_ = _tmp335_;
#line 420 "SerializableGeeHashMapTest.vala"
		_tmp337_ = _tmp336_;
#line 420 "SerializableGeeHashMapTest.vala"
		_tmp338_ = gxml_node_get_name (_tmp337_);
#line 420 "SerializableGeeHashMapTest.vala"
		_tmp339_ = _tmp338_;
#line 420 "SerializableGeeHashMapTest.vala"
		_tmp340_ = _tmp339_;
#line 420 "SerializableGeeHashMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp340_, "BigBag") == 0, "d2.root.name == \"BigBag\"");
#line 420 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp340_);
#line 420 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp337_);
#line 421 "SerializableGeeHashMapTest.vala"
		_tmp341_ = d2;
#line 421 "SerializableGeeHashMapTest.vala"
		_tmp342_ = gxml_document_get_root ((GXmlDocument*) _tmp341_);
#line 421 "SerializableGeeHashMapTest.vala"
		_tmp343_ = _tmp342_;
#line 421 "SerializableGeeHashMapTest.vala"
		_tmp344_ = _tmp343_;
#line 421 "SerializableGeeHashMapTest.vala"
		_tmp345_ = gxml_node_get_children_nodes (_tmp344_);
#line 421 "SerializableGeeHashMapTest.vala"
		_tmp346_ = _tmp345_;
#line 421 "SerializableGeeHashMapTest.vala"
		_tmp347_ = _tmp346_;
#line 421 "SerializableGeeHashMapTest.vala"
		_tmp348_ = gee_collection_get_size ((GeeCollection*) _tmp347_);
#line 421 "SerializableGeeHashMapTest.vala"
		_tmp349_ = _tmp348_;
#line 421 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp349_ == 2, "d2.root.children_nodes.size == 2");
#line 421 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp347_);
#line 421 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp344_);
#line 422 "SerializableGeeHashMapTest.vala"
		_tmp350_ = d2;
#line 422 "SerializableGeeHashMapTest.vala"
		_tmp351_ = gxml_document_get_root ((GXmlDocument*) _tmp350_);
#line 422 "SerializableGeeHashMapTest.vala"
		_tmp352_ = _tmp351_;
#line 422 "SerializableGeeHashMapTest.vala"
		_tmp353_ = _tmp352_;
#line 422 "SerializableGeeHashMapTest.vala"
		_tmp354_ = gxml_node_get_children_nodes (_tmp353_);
#line 422 "SerializableGeeHashMapTest.vala"
		_tmp355_ = _tmp354_;
#line 422 "SerializableGeeHashMapTest.vala"
		_tmp356_ = _tmp355_;
#line 422 "SerializableGeeHashMapTest.vala"
		_tmp357_ = gee_list_get ((GeeList*) _tmp356_, 0);
#line 422 "SerializableGeeHashMapTest.vala"
		_tmp358_ = (GXmlNode*) _tmp357_;
#line 422 "SerializableGeeHashMapTest.vala"
		_tmp359_ = gxml_node_get_name (_tmp358_);
#line 422 "SerializableGeeHashMapTest.vala"
		_tmp360_ = _tmp359_;
#line 422 "SerializableGeeHashMapTest.vala"
		_tmp361_ = _tmp360_;
#line 422 "SerializableGeeHashMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp361_, "SmallBag") == 0, "d2.root.children_nodes[0].name == \"SmallBag\"");
#line 422 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp361_);
#line 422 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp358_);
#line 422 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp356_);
#line 422 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp353_);
#line 423 "SerializableGeeHashMapTest.vala"
		_tmp362_ = d2;
#line 423 "SerializableGeeHashMapTest.vala"
		_tmp363_ = gxml_document_get_root ((GXmlDocument*) _tmp362_);
#line 423 "SerializableGeeHashMapTest.vala"
		_tmp364_ = _tmp363_;
#line 423 "SerializableGeeHashMapTest.vala"
		_tmp365_ = _tmp364_;
#line 423 "SerializableGeeHashMapTest.vala"
		_tmp366_ = gxml_node_get_children_nodes (_tmp365_);
#line 423 "SerializableGeeHashMapTest.vala"
		_tmp367_ = _tmp366_;
#line 423 "SerializableGeeHashMapTest.vala"
		_tmp368_ = _tmp367_;
#line 423 "SerializableGeeHashMapTest.vala"
		_tmp369_ = gee_list_get ((GeeList*) _tmp368_, 0);
#line 423 "SerializableGeeHashMapTest.vala"
		_tmp370_ = (GXmlNode*) _tmp369_;
#line 423 "SerializableGeeHashMapTest.vala"
		_tmp371_ = gxml_node_get_children_nodes (_tmp370_);
#line 423 "SerializableGeeHashMapTest.vala"
		_tmp372_ = _tmp371_;
#line 423 "SerializableGeeHashMapTest.vala"
		_tmp373_ = _tmp372_;
#line 423 "SerializableGeeHashMapTest.vala"
		_tmp374_ = gee_collection_get_size ((GeeCollection*) _tmp373_);
#line 423 "SerializableGeeHashMapTest.vala"
		_tmp375_ = _tmp374_;
#line 423 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp375_ == 2, "d2.root.children_nodes[0].children_nodes.size == 2");
#line 423 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp373_);
#line 423 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp370_);
#line 423 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp368_);
#line 423 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp365_);
#line 424 "SerializableGeeHashMapTest.vala"
		_tmp376_ = d2;
#line 424 "SerializableGeeHashMapTest.vala"
		_tmp377_ = gxml_document_get_root ((GXmlDocument*) _tmp376_);
#line 424 "SerializableGeeHashMapTest.vala"
		_tmp378_ = _tmp377_;
#line 424 "SerializableGeeHashMapTest.vala"
		_tmp379_ = _tmp378_;
#line 424 "SerializableGeeHashMapTest.vala"
		_tmp380_ = gxml_node_get_children_nodes (_tmp379_);
#line 424 "SerializableGeeHashMapTest.vala"
		_tmp381_ = _tmp380_;
#line 424 "SerializableGeeHashMapTest.vala"
		_tmp382_ = _tmp381_;
#line 424 "SerializableGeeHashMapTest.vala"
		_tmp383_ = gee_list_get ((GeeList*) _tmp382_, 0);
#line 424 "SerializableGeeHashMapTest.vala"
		_tmp384_ = (GXmlNode*) _tmp383_;
#line 424 "SerializableGeeHashMapTest.vala"
		_tmp385_ = gxml_node_get_children_nodes (_tmp384_);
#line 424 "SerializableGeeHashMapTest.vala"
		_tmp386_ = _tmp385_;
#line 424 "SerializableGeeHashMapTest.vala"
		_tmp387_ = _tmp386_;
#line 424 "SerializableGeeHashMapTest.vala"
		_tmp388_ = gee_list_get ((GeeList*) _tmp387_, 0);
#line 424 "SerializableGeeHashMapTest.vala"
		_tmp389_ = (GXmlNode*) _tmp388_;
#line 424 "SerializableGeeHashMapTest.vala"
		_tmp390_ = gxml_node_get_name (_tmp389_);
#line 424 "SerializableGeeHashMapTest.vala"
		_tmp391_ = _tmp390_;
#line 424 "SerializableGeeHashMapTest.vala"
		_tmp392_ = _tmp391_;
#line 424 "SerializableGeeHashMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp392_, "Ball") == 0, "d2.root.children_nodes[0].children_nodes[0].name == \"Ball\"");
#line 424 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp392_);
#line 424 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp389_);
#line 424 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp387_);
#line 424 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp384_);
#line 424 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp382_);
#line 424 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp379_);
#line 425 "SerializableGeeHashMapTest.vala"
		_tmp393_ = d2;
#line 425 "SerializableGeeHashMapTest.vala"
		_tmp394_ = gxml_document_get_root ((GXmlDocument*) _tmp393_);
#line 425 "SerializableGeeHashMapTest.vala"
		_tmp395_ = _tmp394_;
#line 425 "SerializableGeeHashMapTest.vala"
		_tmp396_ = _tmp395_;
#line 425 "SerializableGeeHashMapTest.vala"
		_tmp397_ = gxml_node_get_children_nodes (_tmp396_);
#line 425 "SerializableGeeHashMapTest.vala"
		_tmp398_ = _tmp397_;
#line 425 "SerializableGeeHashMapTest.vala"
		_tmp399_ = _tmp398_;
#line 425 "SerializableGeeHashMapTest.vala"
		_tmp400_ = gee_list_get ((GeeList*) _tmp399_, 0);
#line 425 "SerializableGeeHashMapTest.vala"
		_tmp401_ = (GXmlNode*) _tmp400_;
#line 425 "SerializableGeeHashMapTest.vala"
		_tmp402_ = gxml_node_get_children_nodes (_tmp401_);
#line 425 "SerializableGeeHashMapTest.vala"
		_tmp403_ = _tmp402_;
#line 425 "SerializableGeeHashMapTest.vala"
		_tmp404_ = _tmp403_;
#line 425 "SerializableGeeHashMapTest.vala"
		_tmp405_ = gee_list_get ((GeeList*) _tmp404_, 0);
#line 425 "SerializableGeeHashMapTest.vala"
		_tmp406_ = (GXmlNode*) _tmp405_;
#line 425 "SerializableGeeHashMapTest.vala"
		_tmp407_ = gxml_node_get_children_nodes (_tmp406_);
#line 425 "SerializableGeeHashMapTest.vala"
		_tmp408_ = _tmp407_;
#line 425 "SerializableGeeHashMapTest.vala"
		_tmp409_ = _tmp408_;
#line 425 "SerializableGeeHashMapTest.vala"
		_tmp410_ = gee_collection_get_size ((GeeCollection*) _tmp409_);
#line 425 "SerializableGeeHashMapTest.vala"
		_tmp411_ = _tmp410_;
#line 425 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp411_ == 1, "d2.root.children_nodes[0].children_nodes[0].children_nodes.size == 1");
#line 425 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp409_);
#line 425 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp406_);
#line 425 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp404_);
#line 425 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp401_);
#line 425 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp399_);
#line 425 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp396_);
#line 426 "SerializableGeeHashMapTest.vala"
		_tmp412_ = d2;
#line 426 "SerializableGeeHashMapTest.vala"
		_tmp413_ = gxml_document_get_root ((GXmlDocument*) _tmp412_);
#line 426 "SerializableGeeHashMapTest.vala"
		_tmp414_ = _tmp413_;
#line 426 "SerializableGeeHashMapTest.vala"
		_tmp415_ = _tmp414_;
#line 426 "SerializableGeeHashMapTest.vala"
		_tmp416_ = gxml_node_get_children_nodes (_tmp415_);
#line 426 "SerializableGeeHashMapTest.vala"
		_tmp417_ = _tmp416_;
#line 426 "SerializableGeeHashMapTest.vala"
		_tmp418_ = _tmp417_;
#line 426 "SerializableGeeHashMapTest.vala"
		_tmp419_ = gee_list_get ((GeeList*) _tmp418_, 0);
#line 426 "SerializableGeeHashMapTest.vala"
		_tmp420_ = (GXmlNode*) _tmp419_;
#line 426 "SerializableGeeHashMapTest.vala"
		_tmp421_ = gxml_node_get_children_nodes (_tmp420_);
#line 426 "SerializableGeeHashMapTest.vala"
		_tmp422_ = _tmp421_;
#line 426 "SerializableGeeHashMapTest.vala"
		_tmp423_ = _tmp422_;
#line 426 "SerializableGeeHashMapTest.vala"
		_tmp424_ = gee_list_get ((GeeList*) _tmp423_, 0);
#line 426 "SerializableGeeHashMapTest.vala"
		_tmp425_ = (GXmlNode*) _tmp424_;
#line 426 "SerializableGeeHashMapTest.vala"
		_tmp426_ = gxml_node_get_children_nodes (_tmp425_);
#line 426 "SerializableGeeHashMapTest.vala"
		_tmp427_ = _tmp426_;
#line 426 "SerializableGeeHashMapTest.vala"
		_tmp428_ = _tmp427_;
#line 426 "SerializableGeeHashMapTest.vala"
		_tmp429_ = gee_list_get ((GeeList*) _tmp428_, 0);
#line 426 "SerializableGeeHashMapTest.vala"
		_tmp430_ = (GXmlNode*) _tmp429_;
#line 426 "SerializableGeeHashMapTest.vala"
		_tmp431_ = gxml_node_get_name (_tmp430_);
#line 426 "SerializableGeeHashMapTest.vala"
		_tmp432_ = _tmp431_;
#line 426 "SerializableGeeHashMapTest.vala"
		_tmp433_ = _tmp432_;
#line 426 "SerializableGeeHashMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp433_, "BallFill") == 0, "d2.root.children_nodes[0].children_nodes[0].children_nodes[0].name == \"BallFill\"");
#line 426 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp433_);
#line 426 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp430_);
#line 426 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp428_);
#line 426 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp425_);
#line 426 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp423_);
#line 426 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp420_);
#line 426 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp418_);
#line 426 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp415_);
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp434_ = d2;
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp435_ = gxml_document_get_root ((GXmlDocument*) _tmp434_);
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp436_ = _tmp435_;
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp437_ = _tmp436_;
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp438_ = gxml_node_get_children_nodes (_tmp437_);
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp439_ = _tmp438_;
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp440_ = _tmp439_;
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp441_ = gee_list_get ((GeeList*) _tmp440_, 0);
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp442_ = (GXmlNode*) _tmp441_;
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp443_ = gxml_node_get_children_nodes (_tmp442_);
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp444_ = _tmp443_;
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp445_ = _tmp444_;
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp446_ = gee_list_get ((GeeList*) _tmp445_, 0);
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp447_ = (GXmlNode*) _tmp446_;
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp448_ = gxml_node_get_children_nodes (_tmp447_);
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp449_ = _tmp448_;
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp450_ = _tmp449_;
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp451_ = gee_list_get ((GeeList*) _tmp450_, 0);
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp452_ = (GXmlNode*) _tmp451_;
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp453_ = gxml_node_get_children_nodes (_tmp452_);
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp454_ = _tmp453_;
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp455_ = _tmp454_;
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp456_ = gee_collection_get_size ((GeeCollection*) _tmp455_);
#line 427 "SerializableGeeHashMapTest.vala"
		_tmp457_ = _tmp456_;
#line 427 "SerializableGeeHashMapTest.vala"
		_vala_assert (_tmp457_ == 1, "d2.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes.size == 1");
#line 427 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp455_);
#line 427 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp452_);
#line 427 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp450_);
#line 427 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp447_);
#line 427 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp445_);
#line 427 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp442_);
#line 427 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp440_);
#line 427 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp437_);
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp458_ = d2;
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp459_ = gxml_document_get_root ((GXmlDocument*) _tmp458_);
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp460_ = _tmp459_;
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp461_ = _tmp460_;
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp462_ = gxml_node_get_children_nodes (_tmp461_);
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp463_ = _tmp462_;
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp464_ = _tmp463_;
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp465_ = gee_list_get ((GeeList*) _tmp464_, 0);
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp466_ = (GXmlNode*) _tmp465_;
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp467_ = gxml_node_get_children_nodes (_tmp466_);
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp468_ = _tmp467_;
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp469_ = _tmp468_;
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp470_ = gee_list_get ((GeeList*) _tmp469_, 0);
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp471_ = (GXmlNode*) _tmp470_;
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp472_ = gxml_node_get_children_nodes (_tmp471_);
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp473_ = _tmp472_;
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp474_ = _tmp473_;
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp475_ = gee_list_get ((GeeList*) _tmp474_, 0);
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp476_ = (GXmlNode*) _tmp475_;
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp477_ = gxml_node_get_children_nodes (_tmp476_);
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp478_ = _tmp477_;
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp479_ = _tmp478_;
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp480_ = gee_list_get ((GeeList*) _tmp479_, 0);
#line 428 "SerializableGeeHashMapTest.vala"
		_tmp481_ = (GXmlNode*) _tmp480_;
#line 428 "SerializableGeeHashMapTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp481_, GXML_TYPE_TEXT), "d2.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes[0] is GXml.Text");
#line 428 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp481_);
#line 428 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp479_);
#line 428 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp476_);
#line 428 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp474_);
#line 428 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp471_);
#line 428 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp469_);
#line 428 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp466_);
#line 428 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp464_);
#line 428 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp461_);
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp482_ = d2;
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp483_ = gxml_document_get_root ((GXmlDocument*) _tmp482_);
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp484_ = _tmp483_;
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp485_ = _tmp484_;
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp486_ = gxml_node_get_children_nodes (_tmp485_);
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp487_ = _tmp486_;
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp488_ = _tmp487_;
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp489_ = gee_list_get ((GeeList*) _tmp488_, 0);
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp490_ = (GXmlNode*) _tmp489_;
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp491_ = gxml_node_get_children_nodes (_tmp490_);
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp492_ = _tmp491_;
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp493_ = _tmp492_;
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp494_ = gee_list_get ((GeeList*) _tmp493_, 0);
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp495_ = (GXmlNode*) _tmp494_;
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp496_ = gxml_node_get_children_nodes (_tmp495_);
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp497_ = _tmp496_;
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp498_ = _tmp497_;
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp499_ = gee_list_get ((GeeList*) _tmp498_, 0);
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp500_ = (GXmlNode*) _tmp499_;
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp501_ = gxml_node_get_children_nodes (_tmp500_);
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp502_ = _tmp501_;
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp503_ = _tmp502_;
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp504_ = gee_list_get ((GeeList*) _tmp503_, 0);
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp505_ = (GXmlNode*) _tmp504_;
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp506_ = gxml_node_get_value (_tmp505_);
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp507_ = _tmp506_;
#line 429 "SerializableGeeHashMapTest.vala"
		_tmp508_ = _tmp507_;
#line 429 "SerializableGeeHashMapTest.vala"
		_vala_assert (g_strcmp0 (_tmp508_, "golden dust") == 0, "d2.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes[0].value == \"golden dust\"");
#line 429 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp508_);
#line 429 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp505_);
#line 429 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp503_);
#line 429 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp500_);
#line 429 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp498_);
#line 429 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp495_);
#line 429 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp493_);
#line 429 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp490_);
#line 429 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp488_);
#line 429 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp485_);
#line 367 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (d2);
#line 367 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (bag2);
#line 367 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (bagt);
#line 367 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (d);
#line 367 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (bag);
#line 5311 "SerializableGeeHashMapTest.c"
	}
	goto __finally368;
	__catch368_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp509_;
		gchar* _tmp510_;
		gchar* _tmp511_;
#line 367 "SerializableGeeHashMapTest.vala"
		e = _inner_error0_;
#line 367 "SerializableGeeHashMapTest.vala"
		_inner_error0_ = NULL;
#line 431 "SerializableGeeHashMapTest.vala"
		_tmp509_ = e->message;
#line 431 "SerializableGeeHashMapTest.vala"
		_tmp510_ = g_strconcat ("ERROR: ", _tmp509_, NULL);
#line 431 "SerializableGeeHashMapTest.vala"
		_tmp511_ = _tmp510_;
#line 431 "SerializableGeeHashMapTest.vala"
		g_message ("SerializableGeeHashMapTest.vala:431: %s", _tmp511_);
#line 431 "SerializableGeeHashMapTest.vala"
		_g_free0 (_tmp511_);
#line 432 "SerializableGeeHashMapTest.vala"
		g_assert_not_reached ();
#line 367 "SerializableGeeHashMapTest.vala"
		_g_error_free0 (e);
#line 5338 "SerializableGeeHashMapTest.c"
	}
	__finally368:
#line 367 "SerializableGeeHashMapTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 367 "SerializableGeeHashMapTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 367 "SerializableGeeHashMapTest.vala"
		g_clear_error (&_inner_error0_);
#line 367 "SerializableGeeHashMapTest.vala"
		return;
#line 5349 "SerializableGeeHashMapTest.c"
	}
}

static void
___lambda318__gtest_func (void)
{
#line 365 "SerializableGeeHashMapTest.vala"
	__lambda318_ ();
#line 5358 "SerializableGeeHashMapTest.c"
}

void
serializable_gee_hash_map_test_add_tests (void)
{
#line 105 "SerializableGeeHashMapTest.vala"
	g_test_add_func ("/gxml/serializable/hashmap/api", ___lambda311__gtest_func);
#line 140 "SerializableGeeHashMapTest.vala"
	g_test_add_func ("/gxml/serializable/hashmap/serialize", ___lambda312__gtest_func);
#line 190 "SerializableGeeHashMapTest.vala"
	g_test_add_func ("/gxml/serializable/hashmap/deserialize", ___lambda313__gtest_func);
#line 221 "SerializableGeeHashMapTest.vala"
	g_test_add_func ("/gxml/serializable/hashmap/container_class/deserialize", ___lambda314__gtest_func);
#line 256 "SerializableGeeHashMapTest.vala"
	g_test_add_func ("/gxml/serializable/hashmap/containder_class/serialize", ___lambda315__gtest_func);
#line 290 "SerializableGeeHashMapTest.vala"
	g_test_add_func ("/gxml/serializable/hashmap/deserialize-serialize", ___lambda316__gtest_func);
#line 337 "SerializableGeeHashMapTest.vala"
	g_test_add_func ("/gxml/serializable/hashmap/deserialize-node-names", ___lambda317__gtest_func);
#line 365 "SerializableGeeHashMapTest.vala"
	g_test_add_func ("/gxml/serializable/hashmap/post-deserialization/serialize/contents", ___lambda318__gtest_func);
#line 5380 "SerializableGeeHashMapTest.c"
}

SerializableGeeHashMapTest*
serializable_gee_hash_map_test_construct (GType object_type)
{
	SerializableGeeHashMapTest* self = NULL;
#line 29 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTest*) gxml_test_construct (object_type);
#line 29 "SerializableGeeHashMapTest.vala"
	return self;
#line 5391 "SerializableGeeHashMapTest.c"
}

SerializableGeeHashMapTest*
serializable_gee_hash_map_test_new (void)
{
#line 29 "SerializableGeeHashMapTest.vala"
	return serializable_gee_hash_map_test_construct (TYPE_SERIALIZABLE_GEE_HASH_MAP_TEST);
#line 5399 "SerializableGeeHashMapTest.c"
}

static inline gpointer
serializable_gee_hash_map_test_space_get_instance_private (SerializableGeeHashMapTestSpace* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeHashMapTestSpace_private_offset);
}

static gchar*
serializable_gee_hash_map_test_space_real_get_map_key (GXmlSerializableMapKey* base)
{
	SerializableGeeHashMapTestSpace * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 33 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestSpace*) base;
#line 33 "SerializableGeeHashMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 33 "SerializableGeeHashMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 33 "SerializableGeeHashMapTest.vala"
	result = _tmp1_;
#line 33 "SerializableGeeHashMapTest.vala"
	return result;
#line 5425 "SerializableGeeHashMapTest.c"
}

static SerializableGeeHashMapTestSpace*
serializable_gee_hash_map_test_space_construct_named (GType object_type,
                                                      const gchar* name)
{
	SerializableGeeHashMapTestSpace * self = NULL;
#line 35 "SerializableGeeHashMapTest.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 35 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestSpace*) gxml_serializable_object_model_construct (object_type);
#line 35 "SerializableGeeHashMapTest.vala"
	serializable_gee_hash_map_test_space_set_name (self, name);
#line 35 "SerializableGeeHashMapTest.vala"
	return self;
#line 5441 "SerializableGeeHashMapTest.c"
}

static SerializableGeeHashMapTestSpace*
serializable_gee_hash_map_test_space_new_named (const gchar* name)
{
#line 35 "SerializableGeeHashMapTest.vala"
	return serializable_gee_hash_map_test_space_construct_named (SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE, name);
#line 5449 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_space_set_value (SerializableGeeHashMapTestSpace* self,
                                                const gchar* str)
{
#line 36 "SerializableGeeHashMapTest.vala"
	g_return_if_fail (self != NULL);
#line 36 "SerializableGeeHashMapTest.vala"
	g_return_if_fail (str != NULL);
#line 36 "SerializableGeeHashMapTest.vala"
	gxml_serializable_set_serialized_xml_node_value ((GXmlSerializable*) self, str);
#line 5462 "SerializableGeeHashMapTest.c"
}

static gchar*
serializable_gee_hash_map_test_space_get_value (SerializableGeeHashMapTestSpace* self)
{
	gchar* result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gboolean _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
#line 37 "SerializableGeeHashMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 38 "SerializableGeeHashMapTest.vala"
	_tmp0_ = gxml_serializable_get_serialized_xml_node_value ((GXmlSerializable*) self);
#line 38 "SerializableGeeHashMapTest.vala"
	_tmp1_ = _tmp0_;
#line 38 "SerializableGeeHashMapTest.vala"
	_tmp2_ = _tmp1_;
#line 38 "SerializableGeeHashMapTest.vala"
	_tmp3_ = _tmp2_ == NULL;
#line 38 "SerializableGeeHashMapTest.vala"
	_g_free0 (_tmp2_);
#line 38 "SerializableGeeHashMapTest.vala"
	if (_tmp3_) {
#line 39 "SerializableGeeHashMapTest.vala"
		gxml_serializable_set_serialized_xml_node_value ((GXmlSerializable*) self, "");
#line 5491 "SerializableGeeHashMapTest.c"
	}
#line 40 "SerializableGeeHashMapTest.vala"
	_tmp4_ = gxml_serializable_get_serialized_xml_node_value ((GXmlSerializable*) self);
#line 40 "SerializableGeeHashMapTest.vala"
	_tmp5_ = _tmp4_;
#line 40 "SerializableGeeHashMapTest.vala"
	result = _tmp5_;
#line 40 "SerializableGeeHashMapTest.vala"
	return result;
#line 5501 "SerializableGeeHashMapTest.c"
}

static gboolean
serializable_gee_hash_map_test_space_real_serialize_use_xml_node_value (GXmlSerializableObjectModel* base)
{
	SerializableGeeHashMapTestSpace * self;
	gboolean result = FALSE;
#line 43 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestSpace*) base;
#line 43 "SerializableGeeHashMapTest.vala"
	result = TRUE;
#line 43 "SerializableGeeHashMapTest.vala"
	return result;
#line 5515 "SerializableGeeHashMapTest.c"
}

static gchar*
serializable_gee_hash_map_test_space_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeHashMapTestSpace * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 44 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestSpace*) base;
#line 44 "SerializableGeeHashMapTest.vala"
	_tmp0_ = g_strdup ("space");
#line 44 "SerializableGeeHashMapTest.vala"
	result = _tmp0_;
#line 44 "SerializableGeeHashMapTest.vala"
	return result;
#line 5532 "SerializableGeeHashMapTest.c"
}

static gchar*
serializable_gee_hash_map_test_space_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeHashMapTestSpace * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 45 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestSpace*) base;
#line 45 "SerializableGeeHashMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 45 "SerializableGeeHashMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 45 "SerializableGeeHashMapTest.vala"
	result = _tmp1_;
#line 45 "SerializableGeeHashMapTest.vala"
	return result;
#line 5552 "SerializableGeeHashMapTest.c"
}

static SerializableGeeHashMapTestSpace*
serializable_gee_hash_map_test_space_construct (GType object_type)
{
	SerializableGeeHashMapTestSpace * self = NULL;
#line 31 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestSpace*) gxml_serializable_object_model_construct (object_type);
#line 31 "SerializableGeeHashMapTest.vala"
	return self;
#line 5563 "SerializableGeeHashMapTest.c"
}

static SerializableGeeHashMapTestSpace*
serializable_gee_hash_map_test_space_new (void)
{
#line 31 "SerializableGeeHashMapTest.vala"
	return serializable_gee_hash_map_test_space_construct (SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE);
#line 5571 "SerializableGeeHashMapTest.c"
}

static const gchar*
serializable_gee_hash_map_test_space_get_name (SerializableGeeHashMapTestSpace* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 34 "SerializableGeeHashMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 34 "SerializableGeeHashMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 34 "SerializableGeeHashMapTest.vala"
	result = _tmp0_;
#line 34 "SerializableGeeHashMapTest.vala"
	return result;
#line 5587 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_space_set_name (SerializableGeeHashMapTestSpace* self,
                                               const gchar* value)
{
#line 34 "SerializableGeeHashMapTest.vala"
	g_return_if_fail (self != NULL);
#line 34 "SerializableGeeHashMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_hash_map_test_space_get_name (self)) != 0) {
#line 5598 "SerializableGeeHashMapTest.c"
		gchar* _tmp0_;
#line 34 "SerializableGeeHashMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 34 "SerializableGeeHashMapTest.vala"
		_g_free0 (self->priv->_name);
#line 34 "SerializableGeeHashMapTest.vala"
		self->priv->_name = _tmp0_;
#line 34 "SerializableGeeHashMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_hash_map_test_space_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_NAME_PROPERTY]);
#line 5608 "SerializableGeeHashMapTest.c"
	}
}

static SerializableGeeHashMapTestSpaceCollection*
serializable_gee_hash_map_test_space_collection_construct (GType object_type)
{
	SerializableGeeHashMapTestSpaceCollection * self = NULL;
#line 46 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestSpaceCollection*) gxml_serializable_hash_map_construct (object_type, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 46 "SerializableGeeHashMapTest.vala"
	return self;
#line 5620 "SerializableGeeHashMapTest.c"
}

static SerializableGeeHashMapTestSpaceCollection*
serializable_gee_hash_map_test_space_collection_new (void)
{
#line 46 "SerializableGeeHashMapTest.vala"
	return serializable_gee_hash_map_test_space_collection_construct (SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_TYPE_COLLECTION);
#line 5628 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_space_collection_class_init (SerializableGeeHashMapTestSpaceCollectionClass * klass,
                                                            gpointer klass_data)
{
#line 46 "SerializableGeeHashMapTest.vala"
	serializable_gee_hash_map_test_space_collection_parent_class = g_type_class_peek_parent (klass);
#line 5637 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_space_collection_instance_init (SerializableGeeHashMapTestSpaceCollection * self,
                                                               gpointer klass)
{
}

GType
serializable_gee_hash_map_test_space_collection_get_type (void)
{
	static volatile gsize serializable_gee_hash_map_test_space_collection_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_hash_map_test_space_collection_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeHashMapTestSpaceCollectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_hash_map_test_space_collection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeHashMapTestSpaceCollection), 0, (GInstanceInitFunc) serializable_gee_hash_map_test_space_collection_instance_init, NULL };
		GType serializable_gee_hash_map_test_space_collection_type_id;
		serializable_gee_hash_map_test_space_collection_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_HASH_MAP, "SerializableGeeHashMapTestSpaceCollection", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_hash_map_test_space_collection_type_id__volatile, serializable_gee_hash_map_test_space_collection_type_id);
	}
	return serializable_gee_hash_map_test_space_collection_type_id__volatile;
}

static void
serializable_gee_hash_map_test_space_class_init (SerializableGeeHashMapTestSpaceClass * klass,
                                                 gpointer klass_data)
{
#line 31 "SerializableGeeHashMapTest.vala"
	serializable_gee_hash_map_test_space_parent_class = g_type_class_peek_parent (klass);
#line 31 "SerializableGeeHashMapTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeHashMapTestSpace_private_offset);
#line 31 "SerializableGeeHashMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->serialize_use_xml_node_value = (gboolean (*) (GXmlSerializableObjectModel*)) serializable_gee_hash_map_test_space_real_serialize_use_xml_node_value;
#line 31 "SerializableGeeHashMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_hash_map_test_space_real_node_name;
#line 31 "SerializableGeeHashMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_hash_map_test_space_real_to_string;
#line 31 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_hash_map_test_space_get_property;
#line 31 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_hash_map_test_space_set_property;
#line 31 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_hash_map_test_space_finalize;
#line 31 "SerializableGeeHashMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_NAME_PROPERTY, serializable_gee_hash_map_test_space_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5681 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_space_gxml_serializable_map_key_interface_init (GXmlSerializableMapKeyIface * iface,
                                                                               gpointer iface_data)
{
#line 31 "SerializableGeeHashMapTest.vala"
	serializable_gee_hash_map_test_space_gxml_serializable_map_key_parent_iface = g_type_interface_peek_parent (iface);
#line 31 "SerializableGeeHashMapTest.vala"
	iface->get_map_key = (gpointer (*) (GXmlSerializableMapKey*)) serializable_gee_hash_map_test_space_real_get_map_key;
#line 5692 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_space_instance_init (SerializableGeeHashMapTestSpace * self,
                                                    gpointer klass)
{
#line 31 "SerializableGeeHashMapTest.vala"
	self->priv = serializable_gee_hash_map_test_space_get_instance_private (self);
#line 5701 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_space_finalize (GObject * obj)
{
	SerializableGeeHashMapTestSpace * self;
#line 31 "SerializableGeeHashMapTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE, SerializableGeeHashMapTestSpace);
#line 34 "SerializableGeeHashMapTest.vala"
	_g_free0 (self->priv->_name);
#line 31 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (serializable_gee_hash_map_test_space_parent_class)->finalize (obj);
#line 5714 "SerializableGeeHashMapTest.c"
}

static GType
serializable_gee_hash_map_test_space_get_type (void)
{
	static volatile gsize serializable_gee_hash_map_test_space_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_hash_map_test_space_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeHashMapTestSpaceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_hash_map_test_space_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeHashMapTestSpace), 0, (GInstanceInitFunc) serializable_gee_hash_map_test_space_instance_init, NULL };
		static const GInterfaceInfo gxml_serializable_map_key_info = { (GInterfaceInitFunc) serializable_gee_hash_map_test_space_gxml_serializable_map_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType serializable_gee_hash_map_test_space_type_id;
		serializable_gee_hash_map_test_space_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeHashMapTestSpace", &g_define_type_info, 0);
		g_type_add_interface_static (serializable_gee_hash_map_test_space_type_id, GXML_TYPE_SERIALIZABLE_MAP_KEY, &gxml_serializable_map_key_info);
		SerializableGeeHashMapTestSpace_private_offset = g_type_add_instance_private (serializable_gee_hash_map_test_space_type_id, sizeof (SerializableGeeHashMapTestSpacePrivate));
		g_once_init_leave (&serializable_gee_hash_map_test_space_type_id__volatile, serializable_gee_hash_map_test_space_type_id);
	}
	return serializable_gee_hash_map_test_space_type_id__volatile;
}

static void
_vala_serializable_gee_hash_map_test_space_get_property (GObject * object,
                                                         guint property_id,
                                                         GValue * value,
                                                         GParamSpec * pspec)
{
	SerializableGeeHashMapTestSpace * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE, SerializableGeeHashMapTestSpace);
#line 31 "SerializableGeeHashMapTest.vala"
	switch (property_id) {
#line 31 "SerializableGeeHashMapTest.vala"
		case SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_NAME_PROPERTY:
#line 31 "SerializableGeeHashMapTest.vala"
		g_value_set_string (value, serializable_gee_hash_map_test_space_get_name (self));
#line 31 "SerializableGeeHashMapTest.vala"
		break;
#line 5749 "SerializableGeeHashMapTest.c"
		default:
#line 31 "SerializableGeeHashMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 31 "SerializableGeeHashMapTest.vala"
		break;
#line 5755 "SerializableGeeHashMapTest.c"
	}
}

static void
_vala_serializable_gee_hash_map_test_space_set_property (GObject * object,
                                                         guint property_id,
                                                         const GValue * value,
                                                         GParamSpec * pspec)
{
	SerializableGeeHashMapTestSpace * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE, SerializableGeeHashMapTestSpace);
#line 31 "SerializableGeeHashMapTest.vala"
	switch (property_id) {
#line 31 "SerializableGeeHashMapTest.vala"
		case SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_NAME_PROPERTY:
#line 31 "SerializableGeeHashMapTest.vala"
		serializable_gee_hash_map_test_space_set_name (self, g_value_get_string (value));
#line 31 "SerializableGeeHashMapTest.vala"
		break;
#line 5775 "SerializableGeeHashMapTest.c"
		default:
#line 31 "SerializableGeeHashMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 31 "SerializableGeeHashMapTest.vala"
		break;
#line 5781 "SerializableGeeHashMapTest.c"
	}
}

static inline gpointer
serializable_gee_hash_map_test_space_container_get_instance_private (SerializableGeeHashMapTestSpaceContainer* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeHashMapTestSpaceContainer_private_offset);
}

static gchar*
serializable_gee_hash_map_test_space_container_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeHashMapTestSpaceContainer * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 53 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestSpaceContainer*) base;
#line 53 "SerializableGeeHashMapTest.vala"
	_tmp0_ = g_strdup ("spacecontainer");
#line 53 "SerializableGeeHashMapTest.vala"
	result = _tmp0_;
#line 53 "SerializableGeeHashMapTest.vala"
	return result;
#line 5805 "SerializableGeeHashMapTest.c"
}

static gchar*
serializable_gee_hash_map_test_space_container_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeHashMapTestSpaceContainer * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 54 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestSpaceContainer*) base;
#line 54 "SerializableGeeHashMapTest.vala"
	_tmp0_ = self->priv->_owner;
#line 54 "SerializableGeeHashMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 54 "SerializableGeeHashMapTest.vala"
	result = _tmp1_;
#line 54 "SerializableGeeHashMapTest.vala"
	return result;
#line 5825 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_space_container_real_init_containers (GXmlSerializableContainer* base)
{
	SerializableGeeHashMapTestSpaceContainer * self;
	SerializableGeeHashMapTestSpaceCollection* _tmp0_;
#line 56 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestSpaceContainer*) base;
#line 57 "SerializableGeeHashMapTest.vala"
	_tmp0_ = self->priv->_storage;
#line 57 "SerializableGeeHashMapTest.vala"
	if (_tmp0_ == NULL) {
#line 5839 "SerializableGeeHashMapTest.c"
		SerializableGeeHashMapTestSpaceCollection* _tmp1_;
		SerializableGeeHashMapTestSpaceCollection* _tmp2_;
#line 58 "SerializableGeeHashMapTest.vala"
		_tmp1_ = serializable_gee_hash_map_test_space_collection_new ();
#line 58 "SerializableGeeHashMapTest.vala"
		_tmp2_ = _tmp1_;
#line 58 "SerializableGeeHashMapTest.vala"
		serializable_gee_hash_map_test_space_container_set_storage (self, _tmp2_);
#line 58 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (_tmp2_);
#line 5850 "SerializableGeeHashMapTest.c"
	}
}

static SerializableGeeHashMapTestSpaceContainer*
serializable_gee_hash_map_test_space_container_construct (GType object_type)
{
	SerializableGeeHashMapTestSpaceContainer * self = NULL;
#line 49 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestSpaceContainer*) gxml_serializable_container_construct (object_type);
#line 49 "SerializableGeeHashMapTest.vala"
	return self;
#line 5862 "SerializableGeeHashMapTest.c"
}

static SerializableGeeHashMapTestSpaceContainer*
serializable_gee_hash_map_test_space_container_new (void)
{
#line 49 "SerializableGeeHashMapTest.vala"
	return serializable_gee_hash_map_test_space_container_construct (SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE_CONTAINER);
#line 5870 "SerializableGeeHashMapTest.c"
}

static const gchar*
serializable_gee_hash_map_test_space_container_get_owner (SerializableGeeHashMapTestSpaceContainer* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 51 "SerializableGeeHashMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 51 "SerializableGeeHashMapTest.vala"
	_tmp0_ = self->priv->_owner;
#line 51 "SerializableGeeHashMapTest.vala"
	result = _tmp0_;
#line 51 "SerializableGeeHashMapTest.vala"
	return result;
#line 5886 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_space_container_set_owner (SerializableGeeHashMapTestSpaceContainer* self,
                                                          const gchar* value)
{
#line 51 "SerializableGeeHashMapTest.vala"
	g_return_if_fail (self != NULL);
#line 51 "SerializableGeeHashMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_hash_map_test_space_container_get_owner (self)) != 0) {
#line 5897 "SerializableGeeHashMapTest.c"
		gchar* _tmp0_;
#line 51 "SerializableGeeHashMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 51 "SerializableGeeHashMapTest.vala"
		_g_free0 (self->priv->_owner);
#line 51 "SerializableGeeHashMapTest.vala"
		self->priv->_owner = _tmp0_;
#line 51 "SerializableGeeHashMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_hash_map_test_space_container_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_CONTAINER_OWNER_PROPERTY]);
#line 5907 "SerializableGeeHashMapTest.c"
	}
}

static SerializableGeeHashMapTestSpaceCollection*
serializable_gee_hash_map_test_space_container_get_storage (SerializableGeeHashMapTestSpaceContainer* self)
{
	SerializableGeeHashMapTestSpaceCollection* result;
	SerializableGeeHashMapTestSpaceCollection* _tmp0_;
#line 52 "SerializableGeeHashMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 52 "SerializableGeeHashMapTest.vala"
	_tmp0_ = self->priv->_storage;
#line 52 "SerializableGeeHashMapTest.vala"
	result = _tmp0_;
#line 52 "SerializableGeeHashMapTest.vala"
	return result;
#line 5924 "SerializableGeeHashMapTest.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 52 "SerializableGeeHashMapTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 5932 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_space_container_set_storage (SerializableGeeHashMapTestSpaceContainer* self,
                                                            SerializableGeeHashMapTestSpaceCollection* value)
{
#line 52 "SerializableGeeHashMapTest.vala"
	g_return_if_fail (self != NULL);
#line 52 "SerializableGeeHashMapTest.vala"
	if (serializable_gee_hash_map_test_space_container_get_storage (self) != value) {
#line 5943 "SerializableGeeHashMapTest.c"
		SerializableGeeHashMapTestSpaceCollection* _tmp0_;
#line 52 "SerializableGeeHashMapTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 52 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (self->priv->_storage);
#line 52 "SerializableGeeHashMapTest.vala"
		self->priv->_storage = _tmp0_;
#line 52 "SerializableGeeHashMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_hash_map_test_space_container_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_CONTAINER_STORAGE_PROPERTY]);
#line 5953 "SerializableGeeHashMapTest.c"
	}
}

static void
serializable_gee_hash_map_test_space_container_class_init (SerializableGeeHashMapTestSpaceContainerClass * klass,
                                                           gpointer klass_data)
{
#line 49 "SerializableGeeHashMapTest.vala"
	serializable_gee_hash_map_test_space_container_parent_class = g_type_class_peek_parent (klass);
#line 49 "SerializableGeeHashMapTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeHashMapTestSpaceContainer_private_offset);
#line 49 "SerializableGeeHashMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_hash_map_test_space_container_real_node_name;
#line 49 "SerializableGeeHashMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_hash_map_test_space_container_real_to_string;
#line 49 "SerializableGeeHashMapTest.vala"
	((GXmlSerializableContainerClass *) klass)->init_containers = (void (*) (GXmlSerializableContainer*)) serializable_gee_hash_map_test_space_container_real_init_containers;
#line 49 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_hash_map_test_space_container_get_property;
#line 49 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_hash_map_test_space_container_set_property;
#line 49 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_hash_map_test_space_container_finalize;
#line 49 "SerializableGeeHashMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_CONTAINER_OWNER_PROPERTY, serializable_gee_hash_map_test_space_container_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_CONTAINER_OWNER_PROPERTY] = g_param_spec_string ("owner", "owner", "owner", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 49 "SerializableGeeHashMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_CONTAINER_STORAGE_PROPERTY, serializable_gee_hash_map_test_space_container_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_CONTAINER_STORAGE_PROPERTY] = g_param_spec_object ("storage", "storage", "storage", SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_TYPE_COLLECTION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5981 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_space_container_instance_init (SerializableGeeHashMapTestSpaceContainer * self,
                                                              gpointer klass)
{
#line 49 "SerializableGeeHashMapTest.vala"
	self->priv = serializable_gee_hash_map_test_space_container_get_instance_private (self);
#line 5990 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_space_container_finalize (GObject * obj)
{
	SerializableGeeHashMapTestSpaceContainer * self;
#line 49 "SerializableGeeHashMapTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE_CONTAINER, SerializableGeeHashMapTestSpaceContainer);
#line 51 "SerializableGeeHashMapTest.vala"
	_g_free0 (self->priv->_owner);
#line 52 "SerializableGeeHashMapTest.vala"
	_g_object_unref0 (self->priv->_storage);
#line 49 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (serializable_gee_hash_map_test_space_container_parent_class)->finalize (obj);
#line 6005 "SerializableGeeHashMapTest.c"
}

static GType
serializable_gee_hash_map_test_space_container_get_type (void)
{
	static volatile gsize serializable_gee_hash_map_test_space_container_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_hash_map_test_space_container_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeHashMapTestSpaceContainerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_hash_map_test_space_container_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeHashMapTestSpaceContainer), 0, (GInstanceInitFunc) serializable_gee_hash_map_test_space_container_instance_init, NULL };
		GType serializable_gee_hash_map_test_space_container_type_id;
		serializable_gee_hash_map_test_space_container_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_CONTAINER, "SerializableGeeHashMapTestSpaceContainer", &g_define_type_info, 0);
		SerializableGeeHashMapTestSpaceContainer_private_offset = g_type_add_instance_private (serializable_gee_hash_map_test_space_container_type_id, sizeof (SerializableGeeHashMapTestSpaceContainerPrivate));
		g_once_init_leave (&serializable_gee_hash_map_test_space_container_type_id__volatile, serializable_gee_hash_map_test_space_container_type_id);
	}
	return serializable_gee_hash_map_test_space_container_type_id__volatile;
}

static void
_vala_serializable_gee_hash_map_test_space_container_get_property (GObject * object,
                                                                   guint property_id,
                                                                   GValue * value,
                                                                   GParamSpec * pspec)
{
	SerializableGeeHashMapTestSpaceContainer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE_CONTAINER, SerializableGeeHashMapTestSpaceContainer);
#line 49 "SerializableGeeHashMapTest.vala"
	switch (property_id) {
#line 49 "SerializableGeeHashMapTest.vala"
		case SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_CONTAINER_OWNER_PROPERTY:
#line 49 "SerializableGeeHashMapTest.vala"
		g_value_set_string (value, serializable_gee_hash_map_test_space_container_get_owner (self));
#line 49 "SerializableGeeHashMapTest.vala"
		break;
#line 49 "SerializableGeeHashMapTest.vala"
		case SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_CONTAINER_STORAGE_PROPERTY:
#line 49 "SerializableGeeHashMapTest.vala"
		g_value_set_object (value, serializable_gee_hash_map_test_space_container_get_storage (self));
#line 49 "SerializableGeeHashMapTest.vala"
		break;
#line 6044 "SerializableGeeHashMapTest.c"
		default:
#line 49 "SerializableGeeHashMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 49 "SerializableGeeHashMapTest.vala"
		break;
#line 6050 "SerializableGeeHashMapTest.c"
	}
}

static void
_vala_serializable_gee_hash_map_test_space_container_set_property (GObject * object,
                                                                   guint property_id,
                                                                   const GValue * value,
                                                                   GParamSpec * pspec)
{
	SerializableGeeHashMapTestSpaceContainer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SPACE_CONTAINER, SerializableGeeHashMapTestSpaceContainer);
#line 49 "SerializableGeeHashMapTest.vala"
	switch (property_id) {
#line 49 "SerializableGeeHashMapTest.vala"
		case SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_CONTAINER_OWNER_PROPERTY:
#line 49 "SerializableGeeHashMapTest.vala"
		serializable_gee_hash_map_test_space_container_set_owner (self, g_value_get_string (value));
#line 49 "SerializableGeeHashMapTest.vala"
		break;
#line 49 "SerializableGeeHashMapTest.vala"
		case SERIALIZABLE_GEE_HASH_MAP_TEST_SPACE_CONTAINER_STORAGE_PROPERTY:
#line 49 "SerializableGeeHashMapTest.vala"
		serializable_gee_hash_map_test_space_container_set_storage (self, g_value_get_object (value));
#line 49 "SerializableGeeHashMapTest.vala"
		break;
#line 6076 "SerializableGeeHashMapTest.c"
		default:
#line 49 "SerializableGeeHashMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 49 "SerializableGeeHashMapTest.vala"
		break;
#line 6082 "SerializableGeeHashMapTest.c"
	}
}

static inline gpointer
serializable_gee_hash_map_test_ball_fill_get_instance_private (SerializableGeeHashMapTestBallFill* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeHashMapTestBallFill_private_offset);
}

static void
serializable_gee_hash_map_test_ball_fill_set_text (SerializableGeeHashMapTestBallFill* self,
                                                   const gchar* txt)
{
#line 65 "SerializableGeeHashMapTest.vala"
	g_return_if_fail (self != NULL);
#line 65 "SerializableGeeHashMapTest.vala"
	g_return_if_fail (txt != NULL);
#line 65 "SerializableGeeHashMapTest.vala"
	gxml_serializable_set_serialized_xml_node_value ((GXmlSerializable*) self, txt);
#line 6102 "SerializableGeeHashMapTest.c"
}

static gchar*
serializable_gee_hash_map_test_ball_fill_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeHashMapTestBallFill * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 66 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestBallFill*) base;
#line 66 "SerializableGeeHashMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 66 "SerializableGeeHashMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 66 "SerializableGeeHashMapTest.vala"
	result = _tmp1_;
#line 66 "SerializableGeeHashMapTest.vala"
	return result;
#line 6122 "SerializableGeeHashMapTest.c"
}

static gchar*
serializable_gee_hash_map_test_ball_fill_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeHashMapTestBallFill * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 67 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestBallFill*) base;
#line 67 "SerializableGeeHashMapTest.vala"
	_tmp0_ = g_strdup ("BallFill");
#line 67 "SerializableGeeHashMapTest.vala"
	result = _tmp0_;
#line 67 "SerializableGeeHashMapTest.vala"
	return result;
#line 6139 "SerializableGeeHashMapTest.c"
}

static gboolean
serializable_gee_hash_map_test_ball_fill_real_serialize_use_xml_node_value (GXmlSerializableObjectModel* base)
{
	SerializableGeeHashMapTestBallFill * self;
	gboolean result = FALSE;
#line 68 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestBallFill*) base;
#line 68 "SerializableGeeHashMapTest.vala"
	result = TRUE;
#line 68 "SerializableGeeHashMapTest.vala"
	return result;
#line 6153 "SerializableGeeHashMapTest.c"
}

static SerializableGeeHashMapTestBallFill*
serializable_gee_hash_map_test_ball_fill_construct (GType object_type)
{
	SerializableGeeHashMapTestBallFill * self = NULL;
#line 62 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestBallFill*) gxml_serializable_object_model_construct (object_type);
#line 62 "SerializableGeeHashMapTest.vala"
	return self;
#line 6164 "SerializableGeeHashMapTest.c"
}

static SerializableGeeHashMapTestBallFill*
serializable_gee_hash_map_test_ball_fill_new (void)
{
#line 62 "SerializableGeeHashMapTest.vala"
	return serializable_gee_hash_map_test_ball_fill_construct (SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BALL_FILL);
#line 6172 "SerializableGeeHashMapTest.c"
}

static const gchar*
serializable_gee_hash_map_test_ball_fill_get_name (SerializableGeeHashMapTestBallFill* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 64 "SerializableGeeHashMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 64 "SerializableGeeHashMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 64 "SerializableGeeHashMapTest.vala"
	result = _tmp0_;
#line 64 "SerializableGeeHashMapTest.vala"
	return result;
#line 6188 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_ball_fill_set_name (SerializableGeeHashMapTestBallFill* self,
                                                   const gchar* value)
{
#line 64 "SerializableGeeHashMapTest.vala"
	g_return_if_fail (self != NULL);
#line 64 "SerializableGeeHashMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_hash_map_test_ball_fill_get_name (self)) != 0) {
#line 6199 "SerializableGeeHashMapTest.c"
		gchar* _tmp0_;
#line 64 "SerializableGeeHashMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 64 "SerializableGeeHashMapTest.vala"
		_g_free0 (self->priv->_name);
#line 64 "SerializableGeeHashMapTest.vala"
		self->priv->_name = _tmp0_;
#line 64 "SerializableGeeHashMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_hash_map_test_ball_fill_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_FILL_NAME_PROPERTY]);
#line 6209 "SerializableGeeHashMapTest.c"
	}
}

static void
serializable_gee_hash_map_test_ball_fill_class_init (SerializableGeeHashMapTestBallFillClass * klass,
                                                     gpointer klass_data)
{
#line 62 "SerializableGeeHashMapTest.vala"
	serializable_gee_hash_map_test_ball_fill_parent_class = g_type_class_peek_parent (klass);
#line 62 "SerializableGeeHashMapTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeHashMapTestBallFill_private_offset);
#line 62 "SerializableGeeHashMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_hash_map_test_ball_fill_real_to_string;
#line 62 "SerializableGeeHashMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_hash_map_test_ball_fill_real_node_name;
#line 62 "SerializableGeeHashMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->serialize_use_xml_node_value = (gboolean (*) (GXmlSerializableObjectModel*)) serializable_gee_hash_map_test_ball_fill_real_serialize_use_xml_node_value;
#line 62 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_hash_map_test_ball_fill_get_property;
#line 62 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_hash_map_test_ball_fill_set_property;
#line 62 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_hash_map_test_ball_fill_finalize;
#line 62 "SerializableGeeHashMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_FILL_NAME_PROPERTY, serializable_gee_hash_map_test_ball_fill_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_FILL_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6235 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_ball_fill_instance_init (SerializableGeeHashMapTestBallFill * self,
                                                        gpointer klass)
{
	gchar* _tmp0_;
#line 62 "SerializableGeeHashMapTest.vala"
	self->priv = serializable_gee_hash_map_test_ball_fill_get_instance_private (self);
#line 64 "SerializableGeeHashMapTest.vala"
	_tmp0_ = g_strdup ("Fill");
#line 64 "SerializableGeeHashMapTest.vala"
	self->priv->_name = _tmp0_;
#line 6249 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_ball_fill_finalize (GObject * obj)
{
	SerializableGeeHashMapTestBallFill * self;
#line 62 "SerializableGeeHashMapTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BALL_FILL, SerializableGeeHashMapTestBallFill);
#line 64 "SerializableGeeHashMapTest.vala"
	_g_free0 (self->priv->_name);
#line 62 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (serializable_gee_hash_map_test_ball_fill_parent_class)->finalize (obj);
#line 6262 "SerializableGeeHashMapTest.c"
}

static GType
serializable_gee_hash_map_test_ball_fill_get_type (void)
{
	static volatile gsize serializable_gee_hash_map_test_ball_fill_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_hash_map_test_ball_fill_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeHashMapTestBallFillClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_hash_map_test_ball_fill_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeHashMapTestBallFill), 0, (GInstanceInitFunc) serializable_gee_hash_map_test_ball_fill_instance_init, NULL };
		GType serializable_gee_hash_map_test_ball_fill_type_id;
		serializable_gee_hash_map_test_ball_fill_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeHashMapTestBallFill", &g_define_type_info, 0);
		SerializableGeeHashMapTestBallFill_private_offset = g_type_add_instance_private (serializable_gee_hash_map_test_ball_fill_type_id, sizeof (SerializableGeeHashMapTestBallFillPrivate));
		g_once_init_leave (&serializable_gee_hash_map_test_ball_fill_type_id__volatile, serializable_gee_hash_map_test_ball_fill_type_id);
	}
	return serializable_gee_hash_map_test_ball_fill_type_id__volatile;
}

static void
_vala_serializable_gee_hash_map_test_ball_fill_get_property (GObject * object,
                                                             guint property_id,
                                                             GValue * value,
                                                             GParamSpec * pspec)
{
	SerializableGeeHashMapTestBallFill * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BALL_FILL, SerializableGeeHashMapTestBallFill);
#line 62 "SerializableGeeHashMapTest.vala"
	switch (property_id) {
#line 62 "SerializableGeeHashMapTest.vala"
		case SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_FILL_NAME_PROPERTY:
#line 62 "SerializableGeeHashMapTest.vala"
		g_value_set_string (value, serializable_gee_hash_map_test_ball_fill_get_name (self));
#line 62 "SerializableGeeHashMapTest.vala"
		break;
#line 6295 "SerializableGeeHashMapTest.c"
		default:
#line 62 "SerializableGeeHashMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 62 "SerializableGeeHashMapTest.vala"
		break;
#line 6301 "SerializableGeeHashMapTest.c"
	}
}

static void
_vala_serializable_gee_hash_map_test_ball_fill_set_property (GObject * object,
                                                             guint property_id,
                                                             const GValue * value,
                                                             GParamSpec * pspec)
{
	SerializableGeeHashMapTestBallFill * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BALL_FILL, SerializableGeeHashMapTestBallFill);
#line 62 "SerializableGeeHashMapTest.vala"
	switch (property_id) {
#line 62 "SerializableGeeHashMapTest.vala"
		case SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_FILL_NAME_PROPERTY:
#line 62 "SerializableGeeHashMapTest.vala"
		serializable_gee_hash_map_test_ball_fill_set_name (self, g_value_get_string (value));
#line 62 "SerializableGeeHashMapTest.vala"
		break;
#line 6321 "SerializableGeeHashMapTest.c"
		default:
#line 62 "SerializableGeeHashMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 62 "SerializableGeeHashMapTest.vala"
		break;
#line 6327 "SerializableGeeHashMapTest.c"
	}
}

static inline gpointer
serializable_gee_hash_map_test_ball_get_instance_private (SerializableGeeHashMapTestBall* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeHashMapTestBall_private_offset);
}

static gchar*
serializable_gee_hash_map_test_ball_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeHashMapTestBall * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 75 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestBall*) base;
#line 75 "SerializableGeeHashMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 75 "SerializableGeeHashMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 75 "SerializableGeeHashMapTest.vala"
	result = _tmp1_;
#line 75 "SerializableGeeHashMapTest.vala"
	return result;
#line 6354 "SerializableGeeHashMapTest.c"
}

static gchar*
serializable_gee_hash_map_test_ball_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeHashMapTestBall * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 76 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestBall*) base;
#line 76 "SerializableGeeHashMapTest.vala"
	_tmp0_ = g_strdup ("Ball");
#line 76 "SerializableGeeHashMapTest.vala"
	result = _tmp0_;
#line 76 "SerializableGeeHashMapTest.vala"
	return result;
#line 6371 "SerializableGeeHashMapTest.c"
}

static gchar*
serializable_gee_hash_map_test_ball_real_get_map_key (GXmlSerializableMapKey* base)
{
	SerializableGeeHashMapTestBall * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 77 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestBall*) base;
#line 77 "SerializableGeeHashMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 77 "SerializableGeeHashMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 77 "SerializableGeeHashMapTest.vala"
	result = _tmp1_;
#line 77 "SerializableGeeHashMapTest.vala"
	return result;
#line 6391 "SerializableGeeHashMapTest.c"
}

static SerializableGeeHashMapTestBall*
serializable_gee_hash_map_test_ball_construct (GType object_type)
{
	SerializableGeeHashMapTestBall * self = NULL;
#line 71 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestBall*) gxml_serializable_object_model_construct (object_type);
#line 71 "SerializableGeeHashMapTest.vala"
	return self;
#line 6402 "SerializableGeeHashMapTest.c"
}

static SerializableGeeHashMapTestBall*
serializable_gee_hash_map_test_ball_new (void)
{
#line 71 "SerializableGeeHashMapTest.vala"
	return serializable_gee_hash_map_test_ball_construct (SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BALL);
#line 6410 "SerializableGeeHashMapTest.c"
}

static const gchar*
serializable_gee_hash_map_test_ball_get_name (SerializableGeeHashMapTestBall* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 73 "SerializableGeeHashMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 73 "SerializableGeeHashMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 73 "SerializableGeeHashMapTest.vala"
	result = _tmp0_;
#line 73 "SerializableGeeHashMapTest.vala"
	return result;
#line 6426 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_ball_set_name (SerializableGeeHashMapTestBall* self,
                                              const gchar* value)
{
#line 73 "SerializableGeeHashMapTest.vala"
	g_return_if_fail (self != NULL);
#line 73 "SerializableGeeHashMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_hash_map_test_ball_get_name (self)) != 0) {
#line 6437 "SerializableGeeHashMapTest.c"
		gchar* _tmp0_;
#line 73 "SerializableGeeHashMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 73 "SerializableGeeHashMapTest.vala"
		_g_free0 (self->priv->_name);
#line 73 "SerializableGeeHashMapTest.vala"
		self->priv->_name = _tmp0_;
#line 73 "SerializableGeeHashMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_hash_map_test_ball_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_NAME_PROPERTY]);
#line 6447 "SerializableGeeHashMapTest.c"
	}
}

static SerializableGeeHashMapTestBallFill*
serializable_gee_hash_map_test_ball_get_ballfill (SerializableGeeHashMapTestBall* self)
{
	SerializableGeeHashMapTestBallFill* result;
	SerializableGeeHashMapTestBallFill* _tmp0_;
#line 74 "SerializableGeeHashMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 74 "SerializableGeeHashMapTest.vala"
	_tmp0_ = self->priv->_ballfill;
#line 74 "SerializableGeeHashMapTest.vala"
	result = _tmp0_;
#line 74 "SerializableGeeHashMapTest.vala"
	return result;
#line 6464 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_ball_set_ballfill (SerializableGeeHashMapTestBall* self,
                                                  SerializableGeeHashMapTestBallFill* value)
{
#line 74 "SerializableGeeHashMapTest.vala"
	g_return_if_fail (self != NULL);
#line 74 "SerializableGeeHashMapTest.vala"
	if (serializable_gee_hash_map_test_ball_get_ballfill (self) != value) {
#line 6475 "SerializableGeeHashMapTest.c"
		SerializableGeeHashMapTestBallFill* _tmp0_;
#line 74 "SerializableGeeHashMapTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 74 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (self->priv->_ballfill);
#line 74 "SerializableGeeHashMapTest.vala"
		self->priv->_ballfill = _tmp0_;
#line 74 "SerializableGeeHashMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_hash_map_test_ball_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_BALLFILL_PROPERTY]);
#line 6485 "SerializableGeeHashMapTest.c"
	}
}

static gboolean
serializable_gee_hash_map_test_ball_hash_map_real_deserialize_proceed (GXmlSerializableHashMap* base)
{
	SerializableGeeHashMapTestBallHashMap * self;
	gboolean result = FALSE;
#line 79 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestBallHashMap*) base;
#line 79 "SerializableGeeHashMapTest.vala"
	result = FALSE;
#line 79 "SerializableGeeHashMapTest.vala"
	return result;
#line 6500 "SerializableGeeHashMapTest.c"
}

static SerializableGeeHashMapTestBallHashMap*
serializable_gee_hash_map_test_ball_hash_map_construct (GType object_type)
{
	SerializableGeeHashMapTestBallHashMap * self = NULL;
#line 78 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestBallHashMap*) gxml_serializable_hash_map_construct (object_type, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BALL, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 78 "SerializableGeeHashMapTest.vala"
	return self;
#line 6511 "SerializableGeeHashMapTest.c"
}

static SerializableGeeHashMapTestBallHashMap*
serializable_gee_hash_map_test_ball_hash_map_new (void)
{
#line 78 "SerializableGeeHashMapTest.vala"
	return serializable_gee_hash_map_test_ball_hash_map_construct (SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_TYPE_HASH_MAP);
#line 6519 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_ball_hash_map_class_init (SerializableGeeHashMapTestBallHashMapClass * klass,
                                                         gpointer klass_data)
{
#line 78 "SerializableGeeHashMapTest.vala"
	serializable_gee_hash_map_test_ball_hash_map_parent_class = g_type_class_peek_parent (klass);
#line 78 "SerializableGeeHashMapTest.vala"
	((GXmlSerializableHashMapClass *) klass)->deserialize_proceed = (gboolean (*) (GXmlSerializableHashMap*)) serializable_gee_hash_map_test_ball_hash_map_real_deserialize_proceed;
#line 6530 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_ball_hash_map_instance_init (SerializableGeeHashMapTestBallHashMap * self,
                                                            gpointer klass)
{
}

GType
serializable_gee_hash_map_test_ball_hash_map_get_type (void)
{
	static volatile gsize serializable_gee_hash_map_test_ball_hash_map_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_hash_map_test_ball_hash_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeHashMapTestBallHashMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_hash_map_test_ball_hash_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeHashMapTestBallHashMap), 0, (GInstanceInitFunc) serializable_gee_hash_map_test_ball_hash_map_instance_init, NULL };
		GType serializable_gee_hash_map_test_ball_hash_map_type_id;
		serializable_gee_hash_map_test_ball_hash_map_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_HASH_MAP, "SerializableGeeHashMapTestBallHashMap", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_hash_map_test_ball_hash_map_type_id__volatile, serializable_gee_hash_map_test_ball_hash_map_type_id);
	}
	return serializable_gee_hash_map_test_ball_hash_map_type_id__volatile;
}

static void
serializable_gee_hash_map_test_ball_class_init (SerializableGeeHashMapTestBallClass * klass,
                                                gpointer klass_data)
{
#line 71 "SerializableGeeHashMapTest.vala"
	serializable_gee_hash_map_test_ball_parent_class = g_type_class_peek_parent (klass);
#line 71 "SerializableGeeHashMapTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeHashMapTestBall_private_offset);
#line 71 "SerializableGeeHashMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_hash_map_test_ball_real_to_string;
#line 71 "SerializableGeeHashMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_hash_map_test_ball_real_node_name;
#line 71 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_hash_map_test_ball_get_property;
#line 71 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_hash_map_test_ball_set_property;
#line 71 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_hash_map_test_ball_finalize;
#line 71 "SerializableGeeHashMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_NAME_PROPERTY, serializable_gee_hash_map_test_ball_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 71 "SerializableGeeHashMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_BALLFILL_PROPERTY, serializable_gee_hash_map_test_ball_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_BALLFILL_PROPERTY] = g_param_spec_object ("ballfill", "ballfill", "ballfill", SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BALL_FILL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6574 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_ball_gxml_serializable_map_key_interface_init (GXmlSerializableMapKeyIface * iface,
                                                                              gpointer iface_data)
{
#line 71 "SerializableGeeHashMapTest.vala"
	serializable_gee_hash_map_test_ball_gxml_serializable_map_key_parent_iface = g_type_interface_peek_parent (iface);
#line 71 "SerializableGeeHashMapTest.vala"
	iface->get_map_key = (gpointer (*) (GXmlSerializableMapKey*)) serializable_gee_hash_map_test_ball_real_get_map_key;
#line 6585 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_ball_instance_init (SerializableGeeHashMapTestBall * self,
                                                   gpointer klass)
{
	gchar* _tmp0_;
#line 71 "SerializableGeeHashMapTest.vala"
	self->priv = serializable_gee_hash_map_test_ball_get_instance_private (self);
#line 73 "SerializableGeeHashMapTest.vala"
	_tmp0_ = g_strdup ("Ball");
#line 73 "SerializableGeeHashMapTest.vala"
	self->priv->_name = _tmp0_;
#line 6599 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_ball_finalize (GObject * obj)
{
	SerializableGeeHashMapTestBall * self;
#line 71 "SerializableGeeHashMapTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BALL, SerializableGeeHashMapTestBall);
#line 73 "SerializableGeeHashMapTest.vala"
	_g_free0 (self->priv->_name);
#line 74 "SerializableGeeHashMapTest.vala"
	_g_object_unref0 (self->priv->_ballfill);
#line 71 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (serializable_gee_hash_map_test_ball_parent_class)->finalize (obj);
#line 6614 "SerializableGeeHashMapTest.c"
}

static GType
serializable_gee_hash_map_test_ball_get_type (void)
{
	static volatile gsize serializable_gee_hash_map_test_ball_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_hash_map_test_ball_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeHashMapTestBallClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_hash_map_test_ball_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeHashMapTestBall), 0, (GInstanceInitFunc) serializable_gee_hash_map_test_ball_instance_init, NULL };
		static const GInterfaceInfo gxml_serializable_map_key_info = { (GInterfaceInitFunc) serializable_gee_hash_map_test_ball_gxml_serializable_map_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType serializable_gee_hash_map_test_ball_type_id;
		serializable_gee_hash_map_test_ball_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeHashMapTestBall", &g_define_type_info, 0);
		g_type_add_interface_static (serializable_gee_hash_map_test_ball_type_id, GXML_TYPE_SERIALIZABLE_MAP_KEY, &gxml_serializable_map_key_info);
		SerializableGeeHashMapTestBall_private_offset = g_type_add_instance_private (serializable_gee_hash_map_test_ball_type_id, sizeof (SerializableGeeHashMapTestBallPrivate));
		g_once_init_leave (&serializable_gee_hash_map_test_ball_type_id__volatile, serializable_gee_hash_map_test_ball_type_id);
	}
	return serializable_gee_hash_map_test_ball_type_id__volatile;
}

static void
_vala_serializable_gee_hash_map_test_ball_get_property (GObject * object,
                                                        guint property_id,
                                                        GValue * value,
                                                        GParamSpec * pspec)
{
	SerializableGeeHashMapTestBall * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BALL, SerializableGeeHashMapTestBall);
#line 71 "SerializableGeeHashMapTest.vala"
	switch (property_id) {
#line 71 "SerializableGeeHashMapTest.vala"
		case SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_NAME_PROPERTY:
#line 71 "SerializableGeeHashMapTest.vala"
		g_value_set_string (value, serializable_gee_hash_map_test_ball_get_name (self));
#line 71 "SerializableGeeHashMapTest.vala"
		break;
#line 71 "SerializableGeeHashMapTest.vala"
		case SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_BALLFILL_PROPERTY:
#line 71 "SerializableGeeHashMapTest.vala"
		g_value_set_object (value, serializable_gee_hash_map_test_ball_get_ballfill (self));
#line 71 "SerializableGeeHashMapTest.vala"
		break;
#line 6655 "SerializableGeeHashMapTest.c"
		default:
#line 71 "SerializableGeeHashMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 71 "SerializableGeeHashMapTest.vala"
		break;
#line 6661 "SerializableGeeHashMapTest.c"
	}
}

static void
_vala_serializable_gee_hash_map_test_ball_set_property (GObject * object,
                                                        guint property_id,
                                                        const GValue * value,
                                                        GParamSpec * pspec)
{
	SerializableGeeHashMapTestBall * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BALL, SerializableGeeHashMapTestBall);
#line 71 "SerializableGeeHashMapTest.vala"
	switch (property_id) {
#line 71 "SerializableGeeHashMapTest.vala"
		case SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_NAME_PROPERTY:
#line 71 "SerializableGeeHashMapTest.vala"
		serializable_gee_hash_map_test_ball_set_name (self, g_value_get_string (value));
#line 71 "SerializableGeeHashMapTest.vala"
		break;
#line 71 "SerializableGeeHashMapTest.vala"
		case SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_BALLFILL_PROPERTY:
#line 71 "SerializableGeeHashMapTest.vala"
		serializable_gee_hash_map_test_ball_set_ballfill (self, g_value_get_object (value));
#line 71 "SerializableGeeHashMapTest.vala"
		break;
#line 6687 "SerializableGeeHashMapTest.c"
		default:
#line 71 "SerializableGeeHashMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 71 "SerializableGeeHashMapTest.vala"
		break;
#line 6693 "SerializableGeeHashMapTest.c"
	}
}

static inline gpointer
serializable_gee_hash_map_test_small_bag_get_instance_private (SerializableGeeHashMapTestSmallBag* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeHashMapTestSmallBag_private_offset);
}

static gchar*
serializable_gee_hash_map_test_small_bag_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeHashMapTestSmallBag * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 87 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestSmallBag*) base;
#line 87 "SerializableGeeHashMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 87 "SerializableGeeHashMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 87 "SerializableGeeHashMapTest.vala"
	result = _tmp1_;
#line 87 "SerializableGeeHashMapTest.vala"
	return result;
#line 6720 "SerializableGeeHashMapTest.c"
}

static gchar*
serializable_gee_hash_map_test_small_bag_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeHashMapTestSmallBag * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 88 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestSmallBag*) base;
#line 88 "SerializableGeeHashMapTest.vala"
	_tmp0_ = g_strdup ("SmallBag");
#line 88 "SerializableGeeHashMapTest.vala"
	result = _tmp0_;
#line 88 "SerializableGeeHashMapTest.vala"
	return result;
#line 6737 "SerializableGeeHashMapTest.c"
}

static gchar*
serializable_gee_hash_map_test_small_bag_real_get_map_key (GXmlSerializableMapKey* base)
{
	SerializableGeeHashMapTestSmallBag * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 89 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestSmallBag*) base;
#line 89 "SerializableGeeHashMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 89 "SerializableGeeHashMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 89 "SerializableGeeHashMapTest.vala"
	result = _tmp1_;
#line 89 "SerializableGeeHashMapTest.vala"
	return result;
#line 6757 "SerializableGeeHashMapTest.c"
}

static SerializableGeeHashMapTestSmallBag*
serializable_gee_hash_map_test_small_bag_construct (GType object_type)
{
	SerializableGeeHashMapTestSmallBag * self = NULL;
#line 83 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestSmallBag*) gxml_serializable_object_model_construct (object_type);
#line 83 "SerializableGeeHashMapTest.vala"
	return self;
#line 6768 "SerializableGeeHashMapTest.c"
}

static SerializableGeeHashMapTestSmallBag*
serializable_gee_hash_map_test_small_bag_new (void)
{
#line 83 "SerializableGeeHashMapTest.vala"
	return serializable_gee_hash_map_test_small_bag_construct (SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SMALL_BAG);
#line 6776 "SerializableGeeHashMapTest.c"
}

static const gchar*
serializable_gee_hash_map_test_small_bag_get_name (SerializableGeeHashMapTestSmallBag* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 85 "SerializableGeeHashMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 85 "SerializableGeeHashMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 85 "SerializableGeeHashMapTest.vala"
	result = _tmp0_;
#line 85 "SerializableGeeHashMapTest.vala"
	return result;
#line 6792 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_small_bag_set_name (SerializableGeeHashMapTestSmallBag* self,
                                                   const gchar* value)
{
#line 85 "SerializableGeeHashMapTest.vala"
	g_return_if_fail (self != NULL);
#line 85 "SerializableGeeHashMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_hash_map_test_small_bag_get_name (self)) != 0) {
#line 6803 "SerializableGeeHashMapTest.c"
		gchar* _tmp0_;
#line 85 "SerializableGeeHashMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 85 "SerializableGeeHashMapTest.vala"
		_g_free0 (self->priv->_name);
#line 85 "SerializableGeeHashMapTest.vala"
		self->priv->_name = _tmp0_;
#line 85 "SerializableGeeHashMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_hash_map_test_small_bag_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_NAME_PROPERTY]);
#line 6813 "SerializableGeeHashMapTest.c"
	}
}

static SerializableGeeHashMapTestBallHashMap*
serializable_gee_hash_map_test_small_bag_get_balls (SerializableGeeHashMapTestSmallBag* self)
{
	SerializableGeeHashMapTestBallHashMap* result;
	SerializableGeeHashMapTestBallHashMap* _tmp0_;
#line 86 "SerializableGeeHashMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 86 "SerializableGeeHashMapTest.vala"
	_tmp0_ = self->priv->_balls;
#line 86 "SerializableGeeHashMapTest.vala"
	result = _tmp0_;
#line 86 "SerializableGeeHashMapTest.vala"
	return result;
#line 6830 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_small_bag_set_balls (SerializableGeeHashMapTestSmallBag* self,
                                                    SerializableGeeHashMapTestBallHashMap* value)
{
#line 86 "SerializableGeeHashMapTest.vala"
	g_return_if_fail (self != NULL);
#line 86 "SerializableGeeHashMapTest.vala"
	if (serializable_gee_hash_map_test_small_bag_get_balls (self) != value) {
#line 6841 "SerializableGeeHashMapTest.c"
		SerializableGeeHashMapTestBallHashMap* _tmp0_;
#line 86 "SerializableGeeHashMapTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 86 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (self->priv->_balls);
#line 86 "SerializableGeeHashMapTest.vala"
		self->priv->_balls = _tmp0_;
#line 86 "SerializableGeeHashMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_hash_map_test_small_bag_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_BALLS_PROPERTY]);
#line 6851 "SerializableGeeHashMapTest.c"
	}
}

static gboolean
serializable_gee_hash_map_test_small_bag_hash_map_real_deserialize_proceed (GXmlSerializableHashMap* base)
{
	SerializableGeeHashMapTestSmallBagHashMap * self;
	gboolean result = FALSE;
#line 91 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestSmallBagHashMap*) base;
#line 91 "SerializableGeeHashMapTest.vala"
	result = FALSE;
#line 91 "SerializableGeeHashMapTest.vala"
	return result;
#line 6866 "SerializableGeeHashMapTest.c"
}

static SerializableGeeHashMapTestSmallBagHashMap*
serializable_gee_hash_map_test_small_bag_hash_map_construct (GType object_type)
{
	SerializableGeeHashMapTestSmallBagHashMap * self = NULL;
#line 90 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestSmallBagHashMap*) gxml_serializable_hash_map_construct (object_type, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SMALL_BAG, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 90 "SerializableGeeHashMapTest.vala"
	return self;
#line 6877 "SerializableGeeHashMapTest.c"
}

static SerializableGeeHashMapTestSmallBagHashMap*
serializable_gee_hash_map_test_small_bag_hash_map_new (void)
{
#line 90 "SerializableGeeHashMapTest.vala"
	return serializable_gee_hash_map_test_small_bag_hash_map_construct (SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_TYPE_HASH_MAP);
#line 6885 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_small_bag_hash_map_class_init (SerializableGeeHashMapTestSmallBagHashMapClass * klass,
                                                              gpointer klass_data)
{
#line 90 "SerializableGeeHashMapTest.vala"
	serializable_gee_hash_map_test_small_bag_hash_map_parent_class = g_type_class_peek_parent (klass);
#line 90 "SerializableGeeHashMapTest.vala"
	((GXmlSerializableHashMapClass *) klass)->deserialize_proceed = (gboolean (*) (GXmlSerializableHashMap*)) serializable_gee_hash_map_test_small_bag_hash_map_real_deserialize_proceed;
#line 6896 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_small_bag_hash_map_instance_init (SerializableGeeHashMapTestSmallBagHashMap * self,
                                                                 gpointer klass)
{
}

GType
serializable_gee_hash_map_test_small_bag_hash_map_get_type (void)
{
	static volatile gsize serializable_gee_hash_map_test_small_bag_hash_map_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_hash_map_test_small_bag_hash_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeHashMapTestSmallBagHashMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_hash_map_test_small_bag_hash_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeHashMapTestSmallBagHashMap), 0, (GInstanceInitFunc) serializable_gee_hash_map_test_small_bag_hash_map_instance_init, NULL };
		GType serializable_gee_hash_map_test_small_bag_hash_map_type_id;
		serializable_gee_hash_map_test_small_bag_hash_map_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_HASH_MAP, "SerializableGeeHashMapTestSmallBagHashMap", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_hash_map_test_small_bag_hash_map_type_id__volatile, serializable_gee_hash_map_test_small_bag_hash_map_type_id);
	}
	return serializable_gee_hash_map_test_small_bag_hash_map_type_id__volatile;
}

static void
serializable_gee_hash_map_test_small_bag_class_init (SerializableGeeHashMapTestSmallBagClass * klass,
                                                     gpointer klass_data)
{
#line 83 "SerializableGeeHashMapTest.vala"
	serializable_gee_hash_map_test_small_bag_parent_class = g_type_class_peek_parent (klass);
#line 83 "SerializableGeeHashMapTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeHashMapTestSmallBag_private_offset);
#line 83 "SerializableGeeHashMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_hash_map_test_small_bag_real_to_string;
#line 83 "SerializableGeeHashMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_hash_map_test_small_bag_real_node_name;
#line 83 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_hash_map_test_small_bag_get_property;
#line 83 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_hash_map_test_small_bag_set_property;
#line 83 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_hash_map_test_small_bag_finalize;
#line 83 "SerializableGeeHashMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_NAME_PROPERTY, serializable_gee_hash_map_test_small_bag_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 83 "SerializableGeeHashMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_BALLS_PROPERTY, serializable_gee_hash_map_test_small_bag_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_BALLS_PROPERTY] = g_param_spec_object ("balls", "balls", "balls", SERIALIZABLE_GEE_HASH_MAP_TEST_BALL_TYPE_HASH_MAP, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6940 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_small_bag_gxml_serializable_map_key_interface_init (GXmlSerializableMapKeyIface * iface,
                                                                                   gpointer iface_data)
{
#line 83 "SerializableGeeHashMapTest.vala"
	serializable_gee_hash_map_test_small_bag_gxml_serializable_map_key_parent_iface = g_type_interface_peek_parent (iface);
#line 83 "SerializableGeeHashMapTest.vala"
	iface->get_map_key = (gpointer (*) (GXmlSerializableMapKey*)) serializable_gee_hash_map_test_small_bag_real_get_map_key;
#line 6951 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_small_bag_instance_init (SerializableGeeHashMapTestSmallBag * self,
                                                        gpointer klass)
{
	gchar* _tmp0_;
	SerializableGeeHashMapTestBallHashMap* _tmp1_;
#line 83 "SerializableGeeHashMapTest.vala"
	self->priv = serializable_gee_hash_map_test_small_bag_get_instance_private (self);
#line 85 "SerializableGeeHashMapTest.vala"
	_tmp0_ = g_strdup ("SmallBag");
#line 85 "SerializableGeeHashMapTest.vala"
	self->priv->_name = _tmp0_;
#line 86 "SerializableGeeHashMapTest.vala"
	_tmp1_ = serializable_gee_hash_map_test_ball_hash_map_new ();
#line 86 "SerializableGeeHashMapTest.vala"
	self->priv->_balls = _tmp1_;
#line 6970 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_small_bag_finalize (GObject * obj)
{
	SerializableGeeHashMapTestSmallBag * self;
#line 83 "SerializableGeeHashMapTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeHashMapTestSmallBag);
#line 85 "SerializableGeeHashMapTest.vala"
	_g_free0 (self->priv->_name);
#line 86 "SerializableGeeHashMapTest.vala"
	_g_object_unref0 (self->priv->_balls);
#line 83 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (serializable_gee_hash_map_test_small_bag_parent_class)->finalize (obj);
#line 6985 "SerializableGeeHashMapTest.c"
}

static GType
serializable_gee_hash_map_test_small_bag_get_type (void)
{
	static volatile gsize serializable_gee_hash_map_test_small_bag_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_hash_map_test_small_bag_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeHashMapTestSmallBagClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_hash_map_test_small_bag_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeHashMapTestSmallBag), 0, (GInstanceInitFunc) serializable_gee_hash_map_test_small_bag_instance_init, NULL };
		static const GInterfaceInfo gxml_serializable_map_key_info = { (GInterfaceInitFunc) serializable_gee_hash_map_test_small_bag_gxml_serializable_map_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType serializable_gee_hash_map_test_small_bag_type_id;
		serializable_gee_hash_map_test_small_bag_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeHashMapTestSmallBag", &g_define_type_info, 0);
		g_type_add_interface_static (serializable_gee_hash_map_test_small_bag_type_id, GXML_TYPE_SERIALIZABLE_MAP_KEY, &gxml_serializable_map_key_info);
		SerializableGeeHashMapTestSmallBag_private_offset = g_type_add_instance_private (serializable_gee_hash_map_test_small_bag_type_id, sizeof (SerializableGeeHashMapTestSmallBagPrivate));
		g_once_init_leave (&serializable_gee_hash_map_test_small_bag_type_id__volatile, serializable_gee_hash_map_test_small_bag_type_id);
	}
	return serializable_gee_hash_map_test_small_bag_type_id__volatile;
}

static void
_vala_serializable_gee_hash_map_test_small_bag_get_property (GObject * object,
                                                             guint property_id,
                                                             GValue * value,
                                                             GParamSpec * pspec)
{
	SerializableGeeHashMapTestSmallBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeHashMapTestSmallBag);
#line 83 "SerializableGeeHashMapTest.vala"
	switch (property_id) {
#line 83 "SerializableGeeHashMapTest.vala"
		case SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_NAME_PROPERTY:
#line 83 "SerializableGeeHashMapTest.vala"
		g_value_set_string (value, serializable_gee_hash_map_test_small_bag_get_name (self));
#line 83 "SerializableGeeHashMapTest.vala"
		break;
#line 83 "SerializableGeeHashMapTest.vala"
		case SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_BALLS_PROPERTY:
#line 83 "SerializableGeeHashMapTest.vala"
		g_value_set_object (value, serializable_gee_hash_map_test_small_bag_get_balls (self));
#line 83 "SerializableGeeHashMapTest.vala"
		break;
#line 7026 "SerializableGeeHashMapTest.c"
		default:
#line 83 "SerializableGeeHashMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 83 "SerializableGeeHashMapTest.vala"
		break;
#line 7032 "SerializableGeeHashMapTest.c"
	}
}

static void
_vala_serializable_gee_hash_map_test_small_bag_set_property (GObject * object,
                                                             guint property_id,
                                                             const GValue * value,
                                                             GParamSpec * pspec)
{
	SerializableGeeHashMapTestSmallBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_SMALL_BAG, SerializableGeeHashMapTestSmallBag);
#line 83 "SerializableGeeHashMapTest.vala"
	switch (property_id) {
#line 83 "SerializableGeeHashMapTest.vala"
		case SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_NAME_PROPERTY:
#line 83 "SerializableGeeHashMapTest.vala"
		serializable_gee_hash_map_test_small_bag_set_name (self, g_value_get_string (value));
#line 83 "SerializableGeeHashMapTest.vala"
		break;
#line 83 "SerializableGeeHashMapTest.vala"
		case SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_BALLS_PROPERTY:
#line 83 "SerializableGeeHashMapTest.vala"
		serializable_gee_hash_map_test_small_bag_set_balls (self, g_value_get_object (value));
#line 83 "SerializableGeeHashMapTest.vala"
		break;
#line 7058 "SerializableGeeHashMapTest.c"
		default:
#line 83 "SerializableGeeHashMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 83 "SerializableGeeHashMapTest.vala"
		break;
#line 7064 "SerializableGeeHashMapTest.c"
	}
}

static inline gpointer
serializable_gee_hash_map_test_big_bag_get_instance_private (SerializableGeeHashMapTestBigBag* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeHashMapTestBigBag_private_offset);
}

static gchar*
serializable_gee_hash_map_test_big_bag_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeHashMapTestBigBag * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 99 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestBigBag*) base;
#line 99 "SerializableGeeHashMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 99 "SerializableGeeHashMapTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 99 "SerializableGeeHashMapTest.vala"
	result = _tmp1_;
#line 99 "SerializableGeeHashMapTest.vala"
	return result;
#line 7091 "SerializableGeeHashMapTest.c"
}

static gchar*
serializable_gee_hash_map_test_big_bag_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeHashMapTestBigBag * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 100 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestBigBag*) base;
#line 100 "SerializableGeeHashMapTest.vala"
	_tmp0_ = g_strdup ("BigBag");
#line 100 "SerializableGeeHashMapTest.vala"
	result = _tmp0_;
#line 100 "SerializableGeeHashMapTest.vala"
	return result;
#line 7108 "SerializableGeeHashMapTest.c"
}

static SerializableGeeHashMapTestBigBag*
serializable_gee_hash_map_test_big_bag_construct (GType object_type)
{
	SerializableGeeHashMapTestBigBag * self = NULL;
#line 95 "SerializableGeeHashMapTest.vala"
	self = (SerializableGeeHashMapTestBigBag*) gxml_serializable_object_model_construct (object_type);
#line 95 "SerializableGeeHashMapTest.vala"
	return self;
#line 7119 "SerializableGeeHashMapTest.c"
}

static SerializableGeeHashMapTestBigBag*
serializable_gee_hash_map_test_big_bag_new (void)
{
#line 95 "SerializableGeeHashMapTest.vala"
	return serializable_gee_hash_map_test_big_bag_construct (SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BIG_BAG);
#line 7127 "SerializableGeeHashMapTest.c"
}

static const gchar*
serializable_gee_hash_map_test_big_bag_get_name (SerializableGeeHashMapTestBigBag* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 97 "SerializableGeeHashMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 97 "SerializableGeeHashMapTest.vala"
	_tmp0_ = self->priv->_name;
#line 97 "SerializableGeeHashMapTest.vala"
	result = _tmp0_;
#line 97 "SerializableGeeHashMapTest.vala"
	return result;
#line 7143 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_big_bag_set_name (SerializableGeeHashMapTestBigBag* self,
                                                 const gchar* value)
{
#line 97 "SerializableGeeHashMapTest.vala"
	g_return_if_fail (self != NULL);
#line 97 "SerializableGeeHashMapTest.vala"
	if (g_strcmp0 (value, serializable_gee_hash_map_test_big_bag_get_name (self)) != 0) {
#line 7154 "SerializableGeeHashMapTest.c"
		gchar* _tmp0_;
#line 97 "SerializableGeeHashMapTest.vala"
		_tmp0_ = g_strdup (value);
#line 97 "SerializableGeeHashMapTest.vala"
		_g_free0 (self->priv->_name);
#line 97 "SerializableGeeHashMapTest.vala"
		self->priv->_name = _tmp0_;
#line 97 "SerializableGeeHashMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_hash_map_test_big_bag_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_BIG_BAG_NAME_PROPERTY]);
#line 7164 "SerializableGeeHashMapTest.c"
	}
}

static SerializableGeeHashMapTestSmallBagHashMap*
serializable_gee_hash_map_test_big_bag_get_bags (SerializableGeeHashMapTestBigBag* self)
{
	SerializableGeeHashMapTestSmallBagHashMap* result;
	SerializableGeeHashMapTestSmallBagHashMap* _tmp0_;
#line 98 "SerializableGeeHashMapTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 98 "SerializableGeeHashMapTest.vala"
	_tmp0_ = self->priv->_bags;
#line 98 "SerializableGeeHashMapTest.vala"
	result = _tmp0_;
#line 98 "SerializableGeeHashMapTest.vala"
	return result;
#line 7181 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_big_bag_set_bags (SerializableGeeHashMapTestBigBag* self,
                                                 SerializableGeeHashMapTestSmallBagHashMap* value)
{
#line 98 "SerializableGeeHashMapTest.vala"
	g_return_if_fail (self != NULL);
#line 98 "SerializableGeeHashMapTest.vala"
	if (serializable_gee_hash_map_test_big_bag_get_bags (self) != value) {
#line 7192 "SerializableGeeHashMapTest.c"
		SerializableGeeHashMapTestSmallBagHashMap* _tmp0_;
#line 98 "SerializableGeeHashMapTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 98 "SerializableGeeHashMapTest.vala"
		_g_object_unref0 (self->priv->_bags);
#line 98 "SerializableGeeHashMapTest.vala"
		self->priv->_bags = _tmp0_;
#line 98 "SerializableGeeHashMapTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_hash_map_test_big_bag_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_BIG_BAG_BAGS_PROPERTY]);
#line 7202 "SerializableGeeHashMapTest.c"
	}
}

static void
serializable_gee_hash_map_test_big_bag_class_init (SerializableGeeHashMapTestBigBagClass * klass,
                                                   gpointer klass_data)
{
#line 95 "SerializableGeeHashMapTest.vala"
	serializable_gee_hash_map_test_big_bag_parent_class = g_type_class_peek_parent (klass);
#line 95 "SerializableGeeHashMapTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeHashMapTestBigBag_private_offset);
#line 95 "SerializableGeeHashMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_hash_map_test_big_bag_real_to_string;
#line 95 "SerializableGeeHashMapTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_hash_map_test_big_bag_real_node_name;
#line 95 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_hash_map_test_big_bag_get_property;
#line 95 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_hash_map_test_big_bag_set_property;
#line 95 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_hash_map_test_big_bag_finalize;
#line 95 "SerializableGeeHashMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_HASH_MAP_TEST_BIG_BAG_NAME_PROPERTY, serializable_gee_hash_map_test_big_bag_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_BIG_BAG_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 95 "SerializableGeeHashMapTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_HASH_MAP_TEST_BIG_BAG_BAGS_PROPERTY, serializable_gee_hash_map_test_big_bag_properties[SERIALIZABLE_GEE_HASH_MAP_TEST_BIG_BAG_BAGS_PROPERTY] = g_param_spec_object ("bags", "bags", "bags", SERIALIZABLE_GEE_HASH_MAP_TEST_SMALL_BAG_TYPE_HASH_MAP, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 7228 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_big_bag_instance_init (SerializableGeeHashMapTestBigBag * self,
                                                      gpointer klass)
{
	gchar* _tmp0_;
	SerializableGeeHashMapTestSmallBagHashMap* _tmp1_;
#line 95 "SerializableGeeHashMapTest.vala"
	self->priv = serializable_gee_hash_map_test_big_bag_get_instance_private (self);
#line 97 "SerializableGeeHashMapTest.vala"
	_tmp0_ = g_strdup ("ball");
#line 97 "SerializableGeeHashMapTest.vala"
	self->priv->_name = _tmp0_;
#line 98 "SerializableGeeHashMapTest.vala"
	_tmp1_ = serializable_gee_hash_map_test_small_bag_hash_map_new ();
#line 98 "SerializableGeeHashMapTest.vala"
	self->priv->_bags = _tmp1_;
#line 7247 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_big_bag_finalize (GObject * obj)
{
	SerializableGeeHashMapTestBigBag * self;
#line 95 "SerializableGeeHashMapTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BIG_BAG, SerializableGeeHashMapTestBigBag);
#line 97 "SerializableGeeHashMapTest.vala"
	_g_free0 (self->priv->_name);
#line 98 "SerializableGeeHashMapTest.vala"
	_g_object_unref0 (self->priv->_bags);
#line 95 "SerializableGeeHashMapTest.vala"
	G_OBJECT_CLASS (serializable_gee_hash_map_test_big_bag_parent_class)->finalize (obj);
#line 7262 "SerializableGeeHashMapTest.c"
}

static GType
serializable_gee_hash_map_test_big_bag_get_type (void)
{
	static volatile gsize serializable_gee_hash_map_test_big_bag_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_hash_map_test_big_bag_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeHashMapTestBigBagClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_hash_map_test_big_bag_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeHashMapTestBigBag), 0, (GInstanceInitFunc) serializable_gee_hash_map_test_big_bag_instance_init, NULL };
		GType serializable_gee_hash_map_test_big_bag_type_id;
		serializable_gee_hash_map_test_big_bag_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeHashMapTestBigBag", &g_define_type_info, 0);
		SerializableGeeHashMapTestBigBag_private_offset = g_type_add_instance_private (serializable_gee_hash_map_test_big_bag_type_id, sizeof (SerializableGeeHashMapTestBigBagPrivate));
		g_once_init_leave (&serializable_gee_hash_map_test_big_bag_type_id__volatile, serializable_gee_hash_map_test_big_bag_type_id);
	}
	return serializable_gee_hash_map_test_big_bag_type_id__volatile;
}

static void
_vala_serializable_gee_hash_map_test_big_bag_get_property (GObject * object,
                                                           guint property_id,
                                                           GValue * value,
                                                           GParamSpec * pspec)
{
	SerializableGeeHashMapTestBigBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BIG_BAG, SerializableGeeHashMapTestBigBag);
#line 95 "SerializableGeeHashMapTest.vala"
	switch (property_id) {
#line 95 "SerializableGeeHashMapTest.vala"
		case SERIALIZABLE_GEE_HASH_MAP_TEST_BIG_BAG_NAME_PROPERTY:
#line 95 "SerializableGeeHashMapTest.vala"
		g_value_set_string (value, serializable_gee_hash_map_test_big_bag_get_name (self));
#line 95 "SerializableGeeHashMapTest.vala"
		break;
#line 95 "SerializableGeeHashMapTest.vala"
		case SERIALIZABLE_GEE_HASH_MAP_TEST_BIG_BAG_BAGS_PROPERTY:
#line 95 "SerializableGeeHashMapTest.vala"
		g_value_set_object (value, serializable_gee_hash_map_test_big_bag_get_bags (self));
#line 95 "SerializableGeeHashMapTest.vala"
		break;
#line 7301 "SerializableGeeHashMapTest.c"
		default:
#line 95 "SerializableGeeHashMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 95 "SerializableGeeHashMapTest.vala"
		break;
#line 7307 "SerializableGeeHashMapTest.c"
	}
}

static void
_vala_serializable_gee_hash_map_test_big_bag_set_property (GObject * object,
                                                           guint property_id,
                                                           const GValue * value,
                                                           GParamSpec * pspec)
{
	SerializableGeeHashMapTestBigBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_HASH_MAP_TEST_TYPE_BIG_BAG, SerializableGeeHashMapTestBigBag);
#line 95 "SerializableGeeHashMapTest.vala"
	switch (property_id) {
#line 95 "SerializableGeeHashMapTest.vala"
		case SERIALIZABLE_GEE_HASH_MAP_TEST_BIG_BAG_NAME_PROPERTY:
#line 95 "SerializableGeeHashMapTest.vala"
		serializable_gee_hash_map_test_big_bag_set_name (self, g_value_get_string (value));
#line 95 "SerializableGeeHashMapTest.vala"
		break;
#line 95 "SerializableGeeHashMapTest.vala"
		case SERIALIZABLE_GEE_HASH_MAP_TEST_BIG_BAG_BAGS_PROPERTY:
#line 95 "SerializableGeeHashMapTest.vala"
		serializable_gee_hash_map_test_big_bag_set_bags (self, g_value_get_object (value));
#line 95 "SerializableGeeHashMapTest.vala"
		break;
#line 7333 "SerializableGeeHashMapTest.c"
		default:
#line 95 "SerializableGeeHashMapTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 95 "SerializableGeeHashMapTest.vala"
		break;
#line 7339 "SerializableGeeHashMapTest.c"
	}
}

static void
serializable_gee_hash_map_test_class_init (SerializableGeeHashMapTestClass * klass,
                                           gpointer klass_data)
{
#line 29 "SerializableGeeHashMapTest.vala"
	serializable_gee_hash_map_test_parent_class = g_type_class_peek_parent (klass);
#line 7349 "SerializableGeeHashMapTest.c"
}

static void
serializable_gee_hash_map_test_instance_init (SerializableGeeHashMapTest * self,
                                              gpointer klass)
{
}

/**
 *
 *  GXml.Serializable.BasicTypeTest
 *
 *  Authors:
 *
 *       Daniel Espinosa <esodan@gmail.com>
 *
 *
 *  Copyright (c) 2013-2015 Daniel Espinosa
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
GType
serializable_gee_hash_map_test_get_type (void)
{
	static volatile gsize serializable_gee_hash_map_test_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_hash_map_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeHashMapTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_hash_map_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeHashMapTest), 0, (GInstanceInitFunc) serializable_gee_hash_map_test_instance_init, NULL };
		GType serializable_gee_hash_map_test_type_id;
		serializable_gee_hash_map_test_type_id = g_type_register_static (TYPE_GXML_TEST, "SerializableGeeHashMapTest", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_hash_map_test_type_id__volatile, serializable_gee_hash_map_test_type_id);
	}
	return serializable_gee_hash_map_test_type_id__volatile;
}

