/* TDocumentTest.c generated by valac 0.44.3, the Vala compiler
 * generated from TDocumentTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* Notation.vala
 *
 * Copyright (C) 2011-2015  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib-object.h>
#include <glib.h>
#include <gxml/gxml.h>
#include <gee.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_TDOCUMENT_TEST (tdocument_test_get_type ())
#define TDOCUMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TDOCUMENT_TEST, TDocumentTest))
#define TDOCUMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TDOCUMENT_TEST, TDocumentTestClass))
#define IS_TDOCUMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TDOCUMENT_TEST))
#define IS_TDOCUMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TDOCUMENT_TEST))
#define TDOCUMENT_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TDOCUMENT_TEST, TDocumentTestClass))

typedef struct _TDocumentTest TDocumentTest;
typedef struct _TDocumentTestClass TDocumentTestClass;
typedef struct _TDocumentTestPrivate TDocumentTestPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define TDOCUMENT_TEST_TYPE_TTEST_OBJECT (tdocument_test_ttest_object_get_type ())
#define TDOCUMENT_TEST_TTEST_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TDOCUMENT_TEST_TYPE_TTEST_OBJECT, TDocumentTestTTestObject))
#define TDOCUMENT_TEST_TTEST_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TDOCUMENT_TEST_TYPE_TTEST_OBJECT, TDocumentTestTTestObjectClass))
#define TDOCUMENT_TEST_IS_TTEST_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TDOCUMENT_TEST_TYPE_TTEST_OBJECT))
#define TDOCUMENT_TEST_IS_TTEST_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TDOCUMENT_TEST_TYPE_TTEST_OBJECT))
#define TDOCUMENT_TEST_TTEST_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TDOCUMENT_TEST_TYPE_TTEST_OBJECT, TDocumentTestTTestObjectClass))

typedef struct _TDocumentTestTTestObject TDocumentTestTTestObject;
typedef struct _TDocumentTestTTestObjectClass TDocumentTestTTestObjectClass;
typedef struct _TDocumentTestTTestObjectPrivate TDocumentTestTTestObjectPrivate;
enum  {
	TDOCUMENT_TEST_TTEST_OBJECT_0_PROPERTY,
	TDOCUMENT_TEST_TTEST_OBJECT_NAME_PROPERTY,
	TDOCUMENT_TEST_TTEST_OBJECT_NUM_PROPERTIES
};
static GParamSpec* tdocument_test_ttest_object_properties[TDOCUMENT_TEST_TTEST_OBJECT_NUM_PROPERTIES];
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _TDocumentTest {
	GXmlTest parent_instance;
	TDocumentTestPrivate * priv;
};

struct _TDocumentTestClass {
	GXmlTestClass parent_class;
};

struct _TDocumentTestTTestObject {
	GXmlSerializableObjectModel parent_instance;
	TDocumentTestTTestObjectPrivate * priv;
};

struct _TDocumentTestTTestObjectClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _TDocumentTestTTestObjectPrivate {
	gchar* _name;
};

static gpointer tdocument_test_parent_class = NULL;
static gint TDocumentTestTTestObject_private_offset;
static gpointer tdocument_test_ttest_object_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType tdocument_test_get_type (void) G_GNUC_CONST;
void tdocument_test_add_tests (void);
static void __lambda208_ (void);
static void ___lambda208__gtest_func (void);
static void __lambda209_ (void);
static void ___lambda209__gtest_func (void);
static void __lambda210_ (void);
static void ___lambda210__gtest_func (void);
static void __lambda211_ (void);
static void ___lambda211__gtest_func (void);
static void __lambda212_ (void);
static void ___lambda212__gtest_func (void);
static void __lambda213_ (void);
static void ___lambda213__gtest_func (void);
static void __lambda214_ (void);
static void ___lambda214__gtest_func (void);
static void __lambda215_ (void);
GType tdocument_test_ttest_object_get_type (void) G_GNUC_CONST;
TDocumentTestTTestObject* tdocument_test_ttest_object_new (void);
TDocumentTestTTestObject* tdocument_test_ttest_object_construct (GType object_type);
void tdocument_test_ttest_object_set_name (TDocumentTestTTestObject* self,
                                           const gchar* value);
static void ___lambda215__gtest_func (void);
static void __lambda216_ (void);
static void ___lambda216__gtest_func (void);
static void __lambda217_ (void);
static void ___lambda217__gtest_func (void);
static void __lambda218_ (void);
static void ___lambda218__gtest_func (void);
static void __lambda219_ (void);
static void ___lambda219__gtest_func (void);
static void __lambda220_ (void);
static void ___lambda220__gtest_func (void);
static void __lambda221_ (void);
static void ___lambda221__gtest_func (void);
static void __lambda222_ (void);
static void ___lambda222__gtest_func (void);
static void __lambda223_ (void);
static void ___lambda223__gtest_func (void);
static void __lambda224_ (void);
static void ___lambda224__gtest_func (void);
static void __lambda225_ (void);
static void ___lambda225__gtest_func (void);
static void __lambda226_ (void);
static void ___lambda226__gtest_func (void);
static void __lambda227_ (void);
static void ___lambda227__gtest_func (void);
TDocumentTest* tdocument_test_new (void);
TDocumentTest* tdocument_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static gchar* tdocument_test_ttest_object_real_node_name (GXmlSerializableObjectModel* base);
static gchar* tdocument_test_ttest_object_real_to_string (GXmlSerializableObjectModel* base);
const gchar* tdocument_test_ttest_object_get_name (TDocumentTestTTestObject* self);
static void tdocument_test_ttest_object_finalize (GObject * obj);
static void _vala_tdocument_test_ttest_object_get_property (GObject * object,
                                                     guint property_id,
                                                     GValue * value,
                                                     GParamSpec * pspec);
static void _vala_tdocument_test_ttest_object_set_property (GObject * object,
                                                     guint property_id,
                                                     const GValue * value,
                                                     GParamSpec * pspec);
static void _vala_array_destroy (gpointer array,
                          gint array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gint array_length,
                       GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);

static void
__lambda208_ (void)
{
	GXmlTDocument* d = NULL;
	GXmlTDocument* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	GXmlNode* _tmp4_;
	GXmlNode* _tmp5_;
	GXmlNode* _tmp6_;
	GeeBidirList* _tmp7_;
	GeeBidirList* _tmp8_;
	GeeBidirList* _tmp9_;
	GeeMap* _tmp10_;
	GeeMap* _tmp11_;
	GeeMap* _tmp12_;
	GeeBidirList* _tmp13_;
	GeeBidirList* _tmp14_;
	GeeBidirList* _tmp15_;
	gint _tmp16_;
	gint _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
#line 34 "TDocumentTest.vala"
	_tmp0_ = gxml_tdocument_new ();
#line 34 "TDocumentTest.vala"
	d = _tmp0_;
#line 35 "TDocumentTest.vala"
	_tmp1_ = gxml_tnode_get_name ((GXmlTNode*) d);
#line 35 "TDocumentTest.vala"
	_tmp2_ = _tmp1_;
#line 35 "TDocumentTest.vala"
	_tmp3_ = _tmp2_;
#line 35 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp3_, "#document") == 0, "d.name == \"#document\"");
#line 35 "TDocumentTest.vala"
	_g_free0 (_tmp3_);
#line 36 "TDocumentTest.vala"
	_tmp4_ = gxml_document_get_root ((GXmlDocument*) d);
#line 36 "TDocumentTest.vala"
	_tmp5_ = _tmp4_;
#line 36 "TDocumentTest.vala"
	_tmp6_ = _tmp5_;
#line 36 "TDocumentTest.vala"
	_vala_assert (_tmp6_ == NULL, "d.root == null");
#line 36 "TDocumentTest.vala"
	_g_object_unref0 (_tmp6_);
#line 37 "TDocumentTest.vala"
	_tmp7_ = gxml_tnode_get_children_nodes ((GXmlTNode*) d);
#line 37 "TDocumentTest.vala"
	_tmp8_ = _tmp7_;
#line 37 "TDocumentTest.vala"
	_tmp9_ = _tmp8_;
#line 37 "TDocumentTest.vala"
	_vala_assert (_tmp9_ != NULL, "d.children_nodes != null");
#line 37 "TDocumentTest.vala"
	_g_object_unref0 (_tmp9_);
#line 38 "TDocumentTest.vala"
	_tmp10_ = gxml_tnode_get_attrs ((GXmlTNode*) d);
#line 38 "TDocumentTest.vala"
	_tmp11_ = _tmp10_;
#line 38 "TDocumentTest.vala"
	_tmp12_ = _tmp11_;
#line 38 "TDocumentTest.vala"
	_vala_assert (_tmp12_ != NULL, "d.attrs != null");
#line 38 "TDocumentTest.vala"
	_g_object_unref0 (_tmp12_);
#line 39 "TDocumentTest.vala"
	_tmp13_ = gxml_tnode_get_children_nodes ((GXmlTNode*) d);
#line 39 "TDocumentTest.vala"
	_tmp14_ = _tmp13_;
#line 39 "TDocumentTest.vala"
	_tmp15_ = _tmp14_;
#line 39 "TDocumentTest.vala"
	_tmp16_ = gee_collection_get_size ((GeeCollection*) _tmp15_);
#line 39 "TDocumentTest.vala"
	_tmp17_ = _tmp16_;
#line 39 "TDocumentTest.vala"
	_vala_assert (_tmp17_ == 0, "d.children_nodes.size == 0");
#line 39 "TDocumentTest.vala"
	_g_object_unref0 (_tmp15_);
#line 40 "TDocumentTest.vala"
	_tmp18_ = gxml_tnode_get_value ((GXmlTNode*) d);
#line 40 "TDocumentTest.vala"
	_tmp19_ = _tmp18_;
#line 40 "TDocumentTest.vala"
	_tmp20_ = _tmp19_;
#line 40 "TDocumentTest.vala"
	_vala_assert (_tmp20_ == NULL, "d.value == null");
#line 40 "TDocumentTest.vala"
	_g_free0 (_tmp20_);
#line 33 "TDocumentTest.vala"
	_g_object_unref0 (d);
#line 297 "TDocumentTest.c"
}

static void
___lambda208__gtest_func (void)
{
#line 33 "TDocumentTest.vala"
	__lambda208_ ();
#line 305 "TDocumentTest.c"
}

static void
__lambda209_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlTDocument* d = NULL;
		GXmlTDocument* _tmp0_;
		GXmlNode* e = NULL;
		GXmlNode* _tmp1_;
		GeeBidirList* _tmp2_;
		GeeBidirList* _tmp3_;
		GeeBidirList* _tmp4_;
		GeeBidirList* _tmp5_;
		GeeBidirList* _tmp6_;
		GeeBidirList* _tmp7_;
		gint _tmp8_;
		gint _tmp9_;
		GXmlNode* _tmp10_;
		GXmlNode* _tmp11_;
		GXmlNode* _tmp12_;
		GXmlNode* _tmp13_;
		GXmlNode* _tmp14_;
		GXmlNode* _tmp15_;
		gchar* _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_;
		GXmlNode* _tmp19_;
		GXmlNode* _tmp20_;
		GXmlNode* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
#line 44 "TDocumentTest.vala"
		_tmp0_ = gxml_tdocument_new ();
#line 44 "TDocumentTest.vala"
		d = _tmp0_;
#line 45 "TDocumentTest.vala"
		_tmp1_ = gxml_document_create_element ((GXmlDocument*) d, "root", &_inner_error0_);
#line 45 "TDocumentTest.vala"
		e = _tmp1_;
#line 45 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 45 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 352 "TDocumentTest.c"
			goto __catch266_g_error;
		}
#line 46 "TDocumentTest.vala"
		_tmp2_ = gxml_tnode_get_children_nodes ((GXmlTNode*) d);
#line 46 "TDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 46 "TDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 46 "TDocumentTest.vala"
		gee_collection_add ((GeeCollection*) _tmp4_, e);
#line 46 "TDocumentTest.vala"
		_g_object_unref0 (_tmp4_);
#line 47 "TDocumentTest.vala"
		_tmp5_ = gxml_tnode_get_children_nodes ((GXmlTNode*) d);
#line 47 "TDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 47 "TDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 47 "TDocumentTest.vala"
		_tmp8_ = gee_collection_get_size ((GeeCollection*) _tmp7_);
#line 47 "TDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 47 "TDocumentTest.vala"
		_vala_assert (_tmp9_ == 1, "d.children_nodes.size == 1");
#line 47 "TDocumentTest.vala"
		_g_object_unref0 (_tmp7_);
#line 48 "TDocumentTest.vala"
		_tmp10_ = gxml_document_get_root ((GXmlDocument*) d);
#line 48 "TDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 48 "TDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 48 "TDocumentTest.vala"
		_vala_assert (_tmp12_ != NULL, "d.root != null");
#line 48 "TDocumentTest.vala"
		_g_object_unref0 (_tmp12_);
#line 49 "TDocumentTest.vala"
		_tmp13_ = gxml_document_get_root ((GXmlDocument*) d);
#line 49 "TDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 49 "TDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 49 "TDocumentTest.vala"
		_tmp16_ = gxml_node_get_name (_tmp15_);
#line 49 "TDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 49 "TDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 49 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp18_, "root") == 0, "d.root.name == \"root\"");
#line 49 "TDocumentTest.vala"
		_g_free0 (_tmp18_);
#line 49 "TDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 50 "TDocumentTest.vala"
		_tmp19_ = gxml_document_get_root ((GXmlDocument*) d);
#line 50 "TDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 50 "TDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 50 "TDocumentTest.vala"
		_tmp22_ = gxml_node_get_value (_tmp21_);
#line 50 "TDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 50 "TDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 50 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp24_, "") == 0, "d.root.value == \"\"");
#line 50 "TDocumentTest.vala"
		_g_free0 (_tmp24_);
#line 50 "TDocumentTest.vala"
		_g_object_unref0 (_tmp21_);
#line 43 "TDocumentTest.vala"
		_g_object_unref0 (e);
#line 43 "TDocumentTest.vala"
		_g_object_unref0 (d);
#line 429 "TDocumentTest.c"
	}
	goto __finally266;
	__catch266_g_error:
	{
		GError* e = NULL;
#line 43 "TDocumentTest.vala"
		e = _inner_error0_;
#line 43 "TDocumentTest.vala"
		_inner_error0_ = NULL;
#line 56 "TDocumentTest.vala"
		g_assert_not_reached ();
#line 43 "TDocumentTest.vala"
		_g_error_free0 (e);
#line 443 "TDocumentTest.c"
	}
	__finally266:
#line 43 "TDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 43 "TDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 43 "TDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 43 "TDocumentTest.vala"
		return;
#line 454 "TDocumentTest.c"
	}
}

static void
___lambda209__gtest_func (void)
{
#line 42 "TDocumentTest.vala"
	__lambda209_ ();
#line 463 "TDocumentTest.c"
}

static gboolean
string_contains (const gchar* self,
                 const gchar* needle)
{
	gboolean result = FALSE;
	gchar* _tmp0_;
#line 1476 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1476 "glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1477 "glib-2.0.vapi"
	_tmp0_ = strstr ((gchar*) self, (gchar*) needle);
#line 1477 "glib-2.0.vapi"
	result = _tmp0_ != NULL;
#line 1477 "glib-2.0.vapi"
	return result;
#line 482 "TDocumentTest.c"
}

static void
__lambda210_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GFile* f = NULL;
		GFile* _tmp0_;
		GFile* _tmp1_;
		GXmlTDocument* d = NULL;
		GXmlTDocument* _tmp3_;
		GXmlNode* e = NULL;
		GXmlTDocument* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlTDocument* _tmp6_;
		GeeBidirList* _tmp7_;
		GeeBidirList* _tmp8_;
		GeeBidirList* _tmp9_;
		GXmlNode* _tmp10_;
		GXmlTDocument* _tmp11_;
		GeeBidirList* _tmp12_;
		GeeBidirList* _tmp13_;
		GeeBidirList* _tmp14_;
		gint _tmp15_;
		gint _tmp16_;
		GXmlTDocument* _tmp17_;
		GXmlNode* _tmp18_;
		GXmlNode* _tmp19_;
		GXmlNode* _tmp20_;
		GXmlTDocument* _tmp21_;
		GXmlNode* _tmp22_;
		GXmlNode* _tmp23_;
		GXmlNode* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		GXmlTDocument* _tmp28_;
		GXmlNode* _tmp29_;
		GXmlNode* _tmp30_;
		GXmlNode* _tmp31_;
		gchar* _tmp32_;
		gchar* _tmp33_;
		gchar* _tmp34_;
		GFile* _tmp35_;
		gchar* _tmp36_;
		gchar* _tmp37_;
		gchar* _tmp38_;
		gchar* _tmp39_;
		gboolean _tmp40_ = FALSE;
		GXmlTDocument* _tmp41_;
		GFile* _tmp42_;
		gchar* _tmp43_;
		gchar* _tmp44_;
		gchar* _tmp45_;
		gchar* _tmp46_;
		GFile* _tmp47_;
		GFileInputStream* istream = NULL;
		GFile* _tmp48_;
		GFileInputStream* _tmp49_;
		GMemoryOutputStream* ostream = NULL;
		GMemoryOutputStream* _tmp50_;
		GMemoryOutputStream* _tmp51_;
		GFileInputStream* _tmp52_;
		GMemoryOutputStream* _tmp53_;
		void* _tmp54_;
		void* _tmp55_;
		GMemoryOutputStream* _tmp56_;
		void* _tmp57_;
		void* _tmp58_;
#line 61 "TDocumentTest.vala"
		_tmp0_ = g_file_new_for_path (TEST_SAVE_DIR "/t-test.xml");
#line 61 "TDocumentTest.vala"
		f = _tmp0_;
#line 62 "TDocumentTest.vala"
		_tmp1_ = f;
#line 62 "TDocumentTest.vala"
		if (g_file_query_exists (_tmp1_, NULL)) {
#line 561 "TDocumentTest.c"
			GFile* _tmp2_;
#line 62 "TDocumentTest.vala"
			_tmp2_ = f;
#line 62 "TDocumentTest.vala"
			g_file_delete (_tmp2_, NULL, &_inner_error0_);
#line 62 "TDocumentTest.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 62 "TDocumentTest.vala"
				_g_object_unref0 (f);
#line 571 "TDocumentTest.c"
				goto __catch267_g_error;
			}
		}
#line 63 "TDocumentTest.vala"
		_tmp3_ = gxml_tdocument_new_from_path (TEST_SAVE_DIR "/t-test.xml");
#line 63 "TDocumentTest.vala"
		d = _tmp3_;
#line 64 "TDocumentTest.vala"
		_tmp4_ = d;
#line 64 "TDocumentTest.vala"
		_tmp5_ = gxml_document_create_element ((GXmlDocument*) _tmp4_, "root", &_inner_error0_);
#line 64 "TDocumentTest.vala"
		e = _tmp5_;
#line 64 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 64 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 64 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 591 "TDocumentTest.c"
			goto __catch267_g_error;
		}
#line 65 "TDocumentTest.vala"
		_tmp6_ = d;
#line 65 "TDocumentTest.vala"
		_tmp7_ = gxml_tnode_get_children_nodes ((GXmlTNode*) _tmp6_);
#line 65 "TDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 65 "TDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 65 "TDocumentTest.vala"
		_tmp10_ = e;
#line 65 "TDocumentTest.vala"
		gee_collection_add ((GeeCollection*) _tmp9_, _tmp10_);
#line 65 "TDocumentTest.vala"
		_g_object_unref0 (_tmp9_);
#line 66 "TDocumentTest.vala"
		_tmp11_ = d;
#line 66 "TDocumentTest.vala"
		_tmp12_ = gxml_tnode_get_children_nodes ((GXmlTNode*) _tmp11_);
#line 66 "TDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 66 "TDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 66 "TDocumentTest.vala"
		_tmp15_ = gee_collection_get_size ((GeeCollection*) _tmp14_);
#line 66 "TDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 66 "TDocumentTest.vala"
		_vala_assert (_tmp16_ == 1, "d.children_nodes.size == 1");
#line 66 "TDocumentTest.vala"
		_g_object_unref0 (_tmp14_);
#line 67 "TDocumentTest.vala"
		_tmp17_ = d;
#line 67 "TDocumentTest.vala"
		_tmp18_ = gxml_document_get_root ((GXmlDocument*) _tmp17_);
#line 67 "TDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 67 "TDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 67 "TDocumentTest.vala"
		_vala_assert (_tmp20_ != NULL, "d.root != null");
#line 67 "TDocumentTest.vala"
		_g_object_unref0 (_tmp20_);
#line 68 "TDocumentTest.vala"
		_tmp21_ = d;
#line 68 "TDocumentTest.vala"
		_tmp22_ = gxml_document_get_root ((GXmlDocument*) _tmp21_);
#line 68 "TDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 68 "TDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 68 "TDocumentTest.vala"
		_tmp25_ = gxml_node_get_name (_tmp24_);
#line 68 "TDocumentTest.vala"
		_tmp26_ = _tmp25_;
#line 68 "TDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 68 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp27_, "root") == 0, "d.root.name == \"root\"");
#line 68 "TDocumentTest.vala"
		_g_free0 (_tmp27_);
#line 68 "TDocumentTest.vala"
		_g_object_unref0 (_tmp24_);
#line 69 "TDocumentTest.vala"
		_tmp28_ = d;
#line 69 "TDocumentTest.vala"
		_tmp29_ = gxml_document_get_root ((GXmlDocument*) _tmp28_);
#line 69 "TDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 69 "TDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 69 "TDocumentTest.vala"
		_tmp32_ = gxml_node_get_value (_tmp31_);
#line 69 "TDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 69 "TDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 69 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "") == 0, "d.root.value == \"\"");
#line 69 "TDocumentTest.vala"
		_g_free0 (_tmp34_);
#line 69 "TDocumentTest.vala"
		_g_object_unref0 (_tmp31_);
#line 70 "TDocumentTest.vala"
		_tmp35_ = f;
#line 70 "TDocumentTest.vala"
		_tmp36_ = g_file_get_path (_tmp35_);
#line 70 "TDocumentTest.vala"
		_tmp37_ = _tmp36_;
#line 70 "TDocumentTest.vala"
		_tmp38_ = g_strconcat ("Saving document to: ", _tmp37_, NULL);
#line 70 "TDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 70 "TDocumentTest.vala"
		g_test_message ("%s", _tmp39_);
#line 70 "TDocumentTest.vala"
		_g_free0 (_tmp39_);
#line 70 "TDocumentTest.vala"
		_g_free0 (_tmp37_);
#line 71 "TDocumentTest.vala"
		_tmp41_ = d;
#line 71 "TDocumentTest.vala"
		_tmp40_ = gxml_document_save ((GXmlDocument*) _tmp41_, NULL, &_inner_error0_);
#line 71 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 71 "TDocumentTest.vala"
			_g_object_unref0 (e);
#line 71 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 71 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 704 "TDocumentTest.c"
			goto __catch267_g_error;
		}
#line 71 "TDocumentTest.vala"
		_vala_assert (_tmp40_, "d.save ()");
#line 72 "TDocumentTest.vala"
		_tmp42_ = f;
#line 72 "TDocumentTest.vala"
		_tmp43_ = g_file_get_path (_tmp42_);
#line 72 "TDocumentTest.vala"
		_tmp44_ = _tmp43_;
#line 72 "TDocumentTest.vala"
		_tmp45_ = g_strconcat ("Reading saved document to: ", _tmp44_, NULL);
#line 72 "TDocumentTest.vala"
		_tmp46_ = _tmp45_;
#line 72 "TDocumentTest.vala"
		g_test_message ("%s", _tmp46_);
#line 72 "TDocumentTest.vala"
		_g_free0 (_tmp46_);
#line 72 "TDocumentTest.vala"
		_g_free0 (_tmp44_);
#line 73 "TDocumentTest.vala"
		_tmp47_ = f;
#line 73 "TDocumentTest.vala"
		_vala_assert (g_file_query_exists (_tmp47_, NULL), "f.query_exists ()");
#line 74 "TDocumentTest.vala"
		_tmp48_ = f;
#line 74 "TDocumentTest.vala"
		_tmp49_ = g_file_read (_tmp48_, NULL, &_inner_error0_);
#line 74 "TDocumentTest.vala"
		istream = _tmp49_;
#line 74 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 74 "TDocumentTest.vala"
			_g_object_unref0 (e);
#line 74 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 74 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 743 "TDocumentTest.c"
			goto __catch267_g_error;
		}
#line 75 "TDocumentTest.vala"
		_tmp50_ = (GMemoryOutputStream*) g_memory_output_stream_new_resizable ();
#line 75 "TDocumentTest.vala"
		ostream = _tmp50_;
#line 76 "TDocumentTest.vala"
		_tmp51_ = ostream;
#line 76 "TDocumentTest.vala"
		_tmp52_ = istream;
#line 76 "TDocumentTest.vala"
		g_output_stream_splice ((GOutputStream*) _tmp51_, (GInputStream*) _tmp52_, 0, NULL, &_inner_error0_);
#line 76 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 76 "TDocumentTest.vala"
			_g_object_unref0 (ostream);
#line 76 "TDocumentTest.vala"
			_g_object_unref0 (istream);
#line 76 "TDocumentTest.vala"
			_g_object_unref0 (e);
#line 76 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 76 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 768 "TDocumentTest.c"
			goto __catch267_g_error;
		}
#line 77 "TDocumentTest.vala"
		_tmp53_ = ostream;
#line 77 "TDocumentTest.vala"
		_tmp54_ = g_memory_output_stream_get_data (_tmp53_);
#line 77 "TDocumentTest.vala"
		_tmp55_ = _tmp54_;
#line 77 "TDocumentTest.vala"
		_vala_assert (string_contains ((const gchar*) _tmp55_, "<?xml version=\"1.0\"?>"), "\"<?xml version=\\\"1.0\\\"?>\" in ((string)ostream.data)");
#line 78 "TDocumentTest.vala"
		_tmp56_ = ostream;
#line 78 "TDocumentTest.vala"
		_tmp57_ = g_memory_output_stream_get_data (_tmp56_);
#line 78 "TDocumentTest.vala"
		_tmp58_ = _tmp57_;
#line 78 "TDocumentTest.vala"
		_vala_assert (string_contains ((const gchar*) _tmp58_, "<root/>"), "\"<root/>\" in ((string)ostream.data)");
#line 60 "TDocumentTest.vala"
		_g_object_unref0 (ostream);
#line 60 "TDocumentTest.vala"
		_g_object_unref0 (istream);
#line 60 "TDocumentTest.vala"
		_g_object_unref0 (e);
#line 60 "TDocumentTest.vala"
		_g_object_unref0 (d);
#line 60 "TDocumentTest.vala"
		_g_object_unref0 (f);
#line 797 "TDocumentTest.c"
	}
	goto __finally267;
	__catch267_g_error:
	{
		GError* e = NULL;
#line 60 "TDocumentTest.vala"
		e = _inner_error0_;
#line 60 "TDocumentTest.vala"
		_inner_error0_ = NULL;
#line 84 "TDocumentTest.vala"
		g_assert_not_reached ();
#line 60 "TDocumentTest.vala"
		_g_error_free0 (e);
#line 811 "TDocumentTest.c"
	}
	__finally267:
#line 60 "TDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 60 "TDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 60 "TDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 60 "TDocumentTest.vala"
		return;
#line 822 "TDocumentTest.c"
	}
}

static void
___lambda210__gtest_func (void)
{
#line 59 "TDocumentTest.vala"
	__lambda210_ ();
#line 831 "TDocumentTest.c"
}

static void
__lambda211_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GFile* f = NULL;
		GFile* _tmp0_;
		GFile* _tmp1_;
		GXmlTDocument* d = NULL;
		GXmlTDocument* _tmp3_;
		GXmlNode* e = NULL;
		GXmlTDocument* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlTDocument* _tmp6_;
		GeeBidirList* _tmp7_;
		GeeBidirList* _tmp8_;
		GeeBidirList* _tmp9_;
		GXmlNode* _tmp10_;
		GXmlTDocument* _tmp11_;
		GeeBidirList* _tmp12_;
		GeeBidirList* _tmp13_;
		GeeBidirList* _tmp14_;
		gint _tmp15_;
		gint _tmp16_;
		GXmlTDocument* _tmp17_;
		GXmlNode* _tmp18_;
		GXmlNode* _tmp19_;
		GXmlNode* _tmp20_;
		GXmlTDocument* _tmp21_;
		GXmlNode* _tmp22_;
		GXmlNode* _tmp23_;
		GXmlNode* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		GXmlTDocument* _tmp28_;
		GXmlNode* _tmp29_;
		GXmlNode* _tmp30_;
		GXmlNode* _tmp31_;
		gchar* _tmp32_;
		gchar* _tmp33_;
		gchar* _tmp34_;
		GXmlElement* root = NULL;
		GXmlTDocument* _tmp35_;
		GXmlNode* _tmp36_;
		GXmlNode* _tmp37_;
		GXmlElement* _tmp38_;
		GXmlNode* at1 = NULL;
		GXmlElement* _tmp39_;
		GXmlNode* _tmp40_;
		GXmlNode* _tmp41_;
		GXmlNode* _tmp42_;
		gchar* _tmp43_;
		gchar* _tmp44_;
		gchar* _tmp45_;
		GXmlElement* _tmp46_;
		GXmlNode* at2 = NULL;
		GXmlElement* _tmp47_;
		GXmlNode* _tmp48_;
		GXmlNode* _tmp49_;
		GXmlNode* _tmp50_;
		gchar* _tmp51_;
		gchar* _tmp52_;
		gchar* _tmp53_;
		GXmlTDocument* _tmp54_;
		GFileInputStream* istream = NULL;
		GFile* _tmp55_;
		GFileInputStream* _tmp56_;
		guint8* buffer = NULL;
		guint8* _tmp57_;
		gint buffer_length1;
		gint _buffer_size_;
		GFileInputStream* _tmp58_;
		guint8* _tmp59_;
		gint _tmp59__length1;
		GFileInputStream* _tmp60_;
		guint8* _tmp61_;
		gint _tmp61__length1;
		guint8* _tmp62_;
		gint _tmp62__length1;
		guint8* _tmp63_;
		gint _tmp63__length1;
		guint8* _tmp64_;
		gint _tmp64__length1;
#line 89 "TDocumentTest.vala"
		_tmp0_ = g_file_new_for_path (TEST_SAVE_DIR "/t-test.xml");
#line 89 "TDocumentTest.vala"
		f = _tmp0_;
#line 90 "TDocumentTest.vala"
		_tmp1_ = f;
#line 90 "TDocumentTest.vala"
		if (g_file_query_exists (_tmp1_, NULL)) {
#line 926 "TDocumentTest.c"
			GFile* _tmp2_;
#line 90 "TDocumentTest.vala"
			_tmp2_ = f;
#line 90 "TDocumentTest.vala"
			g_file_delete (_tmp2_, NULL, &_inner_error0_);
#line 90 "TDocumentTest.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 90 "TDocumentTest.vala"
				_g_object_unref0 (f);
#line 936 "TDocumentTest.c"
				goto __catch268_g_error;
			}
		}
#line 91 "TDocumentTest.vala"
		_tmp3_ = gxml_tdocument_new_from_path (TEST_SAVE_DIR "/t-test.xml");
#line 91 "TDocumentTest.vala"
		d = _tmp3_;
#line 92 "TDocumentTest.vala"
		_tmp4_ = d;
#line 92 "TDocumentTest.vala"
		_tmp5_ = gxml_document_create_element ((GXmlDocument*) _tmp4_, "root", &_inner_error0_);
#line 92 "TDocumentTest.vala"
		e = _tmp5_;
#line 92 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 92 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 92 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 956 "TDocumentTest.c"
			goto __catch268_g_error;
		}
#line 93 "TDocumentTest.vala"
		_tmp6_ = d;
#line 93 "TDocumentTest.vala"
		_tmp7_ = gxml_tnode_get_children_nodes ((GXmlTNode*) _tmp6_);
#line 93 "TDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 93 "TDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 93 "TDocumentTest.vala"
		_tmp10_ = e;
#line 93 "TDocumentTest.vala"
		gee_collection_add ((GeeCollection*) _tmp9_, _tmp10_);
#line 93 "TDocumentTest.vala"
		_g_object_unref0 (_tmp9_);
#line 94 "TDocumentTest.vala"
		_tmp11_ = d;
#line 94 "TDocumentTest.vala"
		_tmp12_ = gxml_tnode_get_children_nodes ((GXmlTNode*) _tmp11_);
#line 94 "TDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 94 "TDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 94 "TDocumentTest.vala"
		_tmp15_ = gee_collection_get_size ((GeeCollection*) _tmp14_);
#line 94 "TDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 94 "TDocumentTest.vala"
		_vala_assert (_tmp16_ == 1, "d.children_nodes.size == 1");
#line 94 "TDocumentTest.vala"
		_g_object_unref0 (_tmp14_);
#line 95 "TDocumentTest.vala"
		_tmp17_ = d;
#line 95 "TDocumentTest.vala"
		_tmp18_ = gxml_document_get_root ((GXmlDocument*) _tmp17_);
#line 95 "TDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 95 "TDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 95 "TDocumentTest.vala"
		_vala_assert (_tmp20_ != NULL, "d.root != null");
#line 95 "TDocumentTest.vala"
		_g_object_unref0 (_tmp20_);
#line 96 "TDocumentTest.vala"
		_tmp21_ = d;
#line 96 "TDocumentTest.vala"
		_tmp22_ = gxml_document_get_root ((GXmlDocument*) _tmp21_);
#line 96 "TDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 96 "TDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 96 "TDocumentTest.vala"
		_tmp25_ = gxml_node_get_name (_tmp24_);
#line 96 "TDocumentTest.vala"
		_tmp26_ = _tmp25_;
#line 96 "TDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 96 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp27_, "root") == 0, "d.root.name == \"root\"");
#line 96 "TDocumentTest.vala"
		_g_free0 (_tmp27_);
#line 96 "TDocumentTest.vala"
		_g_object_unref0 (_tmp24_);
#line 97 "TDocumentTest.vala"
		_tmp28_ = d;
#line 97 "TDocumentTest.vala"
		_tmp29_ = gxml_document_get_root ((GXmlDocument*) _tmp28_);
#line 97 "TDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 97 "TDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 97 "TDocumentTest.vala"
		_tmp32_ = gxml_node_get_value (_tmp31_);
#line 97 "TDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 97 "TDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 97 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "") == 0, "d.root.value == \"\"");
#line 97 "TDocumentTest.vala"
		_g_free0 (_tmp34_);
#line 97 "TDocumentTest.vala"
		_g_object_unref0 (_tmp31_);
#line 98 "TDocumentTest.vala"
		_tmp35_ = d;
#line 98 "TDocumentTest.vala"
		_tmp36_ = gxml_document_get_root ((GXmlDocument*) _tmp35_);
#line 98 "TDocumentTest.vala"
		_tmp37_ = _tmp36_;
#line 98 "TDocumentTest.vala"
		root = G_TYPE_CHECK_INSTANCE_CAST (_tmp37_, GXML_TYPE_ELEMENT, GXmlElement);
#line 99 "TDocumentTest.vala"
		_tmp38_ = root;
#line 99 "TDocumentTest.vala"
		gxml_element_set_attr (_tmp38_, "Pos", "on");
#line 100 "TDocumentTest.vala"
		_tmp39_ = root;
#line 100 "TDocumentTest.vala"
		_tmp40_ = gxml_element_get_attr (_tmp39_, "Pos");
#line 100 "TDocumentTest.vala"
		at1 = _tmp40_;
#line 101 "TDocumentTest.vala"
		_tmp41_ = at1;
#line 101 "TDocumentTest.vala"
		_vala_assert (_tmp41_ != NULL, "at1 != null");
#line 102 "TDocumentTest.vala"
		_tmp42_ = at1;
#line 102 "TDocumentTest.vala"
		_tmp43_ = gxml_node_get_value (_tmp42_);
#line 102 "TDocumentTest.vala"
		_tmp44_ = _tmp43_;
#line 102 "TDocumentTest.vala"
		_tmp45_ = _tmp44_;
#line 102 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp45_, "on") == 0, "at1.value == \"on\"");
#line 102 "TDocumentTest.vala"
		_g_free0 (_tmp45_);
#line 103 "TDocumentTest.vala"
		_tmp46_ = root;
#line 103 "TDocumentTest.vala"
		gxml_element_set_attr (_tmp46_, "tKm", "1000");
#line 104 "TDocumentTest.vala"
		_tmp47_ = root;
#line 104 "TDocumentTest.vala"
		_tmp48_ = gxml_element_get_attr (_tmp47_, "tKm");
#line 104 "TDocumentTest.vala"
		at2 = _tmp48_;
#line 105 "TDocumentTest.vala"
		_tmp49_ = at2;
#line 105 "TDocumentTest.vala"
		_vala_assert (_tmp49_ != NULL, "at2 != null");
#line 106 "TDocumentTest.vala"
		_tmp50_ = at2;
#line 106 "TDocumentTest.vala"
		_tmp51_ = gxml_node_get_value (_tmp50_);
#line 106 "TDocumentTest.vala"
		_tmp52_ = _tmp51_;
#line 106 "TDocumentTest.vala"
		_tmp53_ = _tmp52_;
#line 106 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp53_, "1000") == 0, "at2.value == \"1000\"");
#line 106 "TDocumentTest.vala"
		_g_free0 (_tmp53_);
#line 107 "TDocumentTest.vala"
		_tmp54_ = d;
#line 107 "TDocumentTest.vala"
		gxml_document_save ((GXmlDocument*) _tmp54_, NULL, &_inner_error0_);
#line 107 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 107 "TDocumentTest.vala"
			_g_object_unref0 (at2);
#line 107 "TDocumentTest.vala"
			_g_object_unref0 (at1);
#line 107 "TDocumentTest.vala"
			_g_object_unref0 (root);
#line 107 "TDocumentTest.vala"
			_g_object_unref0 (e);
#line 107 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 107 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 1119 "TDocumentTest.c"
			goto __catch268_g_error;
		}
#line 108 "TDocumentTest.vala"
		_tmp55_ = f;
#line 108 "TDocumentTest.vala"
		_tmp56_ = g_file_read (_tmp55_, NULL, &_inner_error0_);
#line 108 "TDocumentTest.vala"
		istream = _tmp56_;
#line 108 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 108 "TDocumentTest.vala"
			_g_object_unref0 (at2);
#line 108 "TDocumentTest.vala"
			_g_object_unref0 (at1);
#line 108 "TDocumentTest.vala"
			_g_object_unref0 (root);
#line 108 "TDocumentTest.vala"
			_g_object_unref0 (e);
#line 108 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 108 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 1142 "TDocumentTest.c"
			goto __catch268_g_error;
		}
#line 109 "TDocumentTest.vala"
		_tmp57_ = g_new0 (guint8, 2048);
#line 109 "TDocumentTest.vala"
		buffer = _tmp57_;
#line 109 "TDocumentTest.vala"
		buffer_length1 = 2048;
#line 109 "TDocumentTest.vala"
		_buffer_size_ = buffer_length1;
#line 110 "TDocumentTest.vala"
		_tmp58_ = istream;
#line 110 "TDocumentTest.vala"
		_tmp59_ = buffer;
#line 110 "TDocumentTest.vala"
		_tmp59__length1 = buffer_length1;
#line 110 "TDocumentTest.vala"
		g_input_stream_read_all ((GInputStream*) _tmp58_, _tmp59_, (gsize) _tmp59__length1, NULL, NULL, &_inner_error0_);
#line 110 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 110 "TDocumentTest.vala"
			buffer = (g_free (buffer), NULL);
#line 110 "TDocumentTest.vala"
			_g_object_unref0 (istream);
#line 110 "TDocumentTest.vala"
			_g_object_unref0 (at2);
#line 110 "TDocumentTest.vala"
			_g_object_unref0 (at1);
#line 110 "TDocumentTest.vala"
			_g_object_unref0 (root);
#line 110 "TDocumentTest.vala"
			_g_object_unref0 (e);
#line 110 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 110 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 1179 "TDocumentTest.c"
			goto __catch268_g_error;
		}
#line 111 "TDocumentTest.vala"
		_tmp60_ = istream;
#line 111 "TDocumentTest.vala"
		g_input_stream_close ((GInputStream*) _tmp60_, NULL, &_inner_error0_);
#line 111 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 111 "TDocumentTest.vala"
			buffer = (g_free (buffer), NULL);
#line 111 "TDocumentTest.vala"
			_g_object_unref0 (istream);
#line 111 "TDocumentTest.vala"
			_g_object_unref0 (at2);
#line 111 "TDocumentTest.vala"
			_g_object_unref0 (at1);
#line 111 "TDocumentTest.vala"
			_g_object_unref0 (root);
#line 111 "TDocumentTest.vala"
			_g_object_unref0 (e);
#line 111 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 111 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 1204 "TDocumentTest.c"
			goto __catch268_g_error;
		}
#line 112 "TDocumentTest.vala"
		_tmp61_ = buffer;
#line 112 "TDocumentTest.vala"
		_tmp61__length1 = buffer_length1;
#line 112 "TDocumentTest.vala"
		_vala_assert (string_contains ((const gchar*) _tmp61_, "<?xml version=\"1.0\"?>"), "\"<?xml version=\\\"1.0\\\"?>\" in ((string)buffer)");
#line 113 "TDocumentTest.vala"
		_tmp62_ = buffer;
#line 113 "TDocumentTest.vala"
		_tmp62__length1 = buffer_length1;
#line 113 "TDocumentTest.vala"
		_vala_assert (string_contains ((const gchar*) _tmp62_, "<root"), "\"<root\" in ((string)buffer)");
#line 114 "TDocumentTest.vala"
		_tmp63_ = buffer;
#line 114 "TDocumentTest.vala"
		_tmp63__length1 = buffer_length1;
#line 114 "TDocumentTest.vala"
		_vala_assert (string_contains ((const gchar*) _tmp63_, "Pos=\"on\""), "\"Pos=\\\"on\\\"\" in ((string)buffer)");
#line 115 "TDocumentTest.vala"
		_tmp64_ = buffer;
#line 115 "TDocumentTest.vala"
		_tmp64__length1 = buffer_length1;
#line 115 "TDocumentTest.vala"
		_vala_assert (string_contains ((const gchar*) _tmp64_, "tKm=\"1000\""), "\"tKm=\\\"1000\\\"\" in ((string)buffer)");
#line 88 "TDocumentTest.vala"
		buffer = (g_free (buffer), NULL);
#line 88 "TDocumentTest.vala"
		_g_object_unref0 (istream);
#line 88 "TDocumentTest.vala"
		_g_object_unref0 (at2);
#line 88 "TDocumentTest.vala"
		_g_object_unref0 (at1);
#line 88 "TDocumentTest.vala"
		_g_object_unref0 (root);
#line 88 "TDocumentTest.vala"
		_g_object_unref0 (e);
#line 88 "TDocumentTest.vala"
		_g_object_unref0 (d);
#line 88 "TDocumentTest.vala"
		_g_object_unref0 (f);
#line 1247 "TDocumentTest.c"
	}
	goto __finally268;
	__catch268_g_error:
	{
		GError* e = NULL;
#line 88 "TDocumentTest.vala"
		e = _inner_error0_;
#line 88 "TDocumentTest.vala"
		_inner_error0_ = NULL;
#line 121 "TDocumentTest.vala"
		g_assert_not_reached ();
#line 88 "TDocumentTest.vala"
		_g_error_free0 (e);
#line 1261 "TDocumentTest.c"
	}
	__finally268:
#line 88 "TDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 88 "TDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 88 "TDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 88 "TDocumentTest.vala"
		return;
#line 1272 "TDocumentTest.c"
	}
}

static void
___lambda211__gtest_func (void)
{
#line 87 "TDocumentTest.vala"
	__lambda211_ ();
#line 1281 "TDocumentTest.c"
}

static void
__lambda212_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GFile* f = NULL;
		GFile* _tmp0_;
		GFile* _tmp1_;
		GXmlTDocument* d = NULL;
		GXmlTDocument* _tmp3_;
		GXmlNode* e = NULL;
		GXmlTDocument* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlTDocument* _tmp6_;
		GeeBidirList* _tmp7_;
		GeeBidirList* _tmp8_;
		GeeBidirList* _tmp9_;
		GXmlNode* _tmp10_;
		GXmlTDocument* _tmp11_;
		GeeBidirList* _tmp12_;
		GeeBidirList* _tmp13_;
		GeeBidirList* _tmp14_;
		gint _tmp15_;
		gint _tmp16_;
		GXmlTDocument* _tmp17_;
		GXmlNode* _tmp18_;
		GXmlNode* _tmp19_;
		GXmlNode* _tmp20_;
		GXmlTDocument* _tmp21_;
		GXmlNode* _tmp22_;
		GXmlNode* _tmp23_;
		GXmlNode* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		GXmlTDocument* _tmp28_;
		GXmlNode* _tmp29_;
		GXmlNode* _tmp30_;
		GXmlNode* _tmp31_;
		gchar* _tmp32_;
		gchar* _tmp33_;
		gchar* _tmp34_;
		GXmlElement* root = NULL;
		GXmlTDocument* _tmp35_;
		GXmlNode* _tmp36_;
		GXmlNode* _tmp37_;
		GXmlElement* _tmp38_;
		GXmlElement* _tmp39_;
		GeeBidirList* _tmp40_;
		GeeBidirList* _tmp41_;
		GeeBidirList* _tmp42_;
		gint _tmp43_;
		gint _tmp44_;
		GXmlElement* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
		GXmlNode* t = NULL;
		GXmlElement* _tmp49_;
		GeeBidirList* _tmp50_;
		GeeBidirList* _tmp51_;
		GeeBidirList* _tmp52_;
		gpointer _tmp53_;
		GXmlNode* _tmp54_;
		GXmlNode* _tmp55_;
		gchar* _tmp56_;
		gchar* _tmp57_;
		gchar* _tmp58_;
		GXmlNode* _tmp59_;
		GXmlTDocument* _tmp60_;
		GFileInputStream* istream = NULL;
		GFile* _tmp61_;
		GFileInputStream* _tmp62_;
		guint8* buffer = NULL;
		guint8* _tmp63_;
		gint buffer_length1;
		gint _buffer_size_;
		GFileInputStream* _tmp64_;
		guint8* _tmp65_;
		gint _tmp65__length1;
		GFileInputStream* _tmp66_;
		guint8* _tmp67_;
		gint _tmp67__length1;
		guint8* _tmp68_;
		gint _tmp68__length1;
		guint8* _tmp69_;
		gint _tmp69__length1;
#line 126 "TDocumentTest.vala"
		_tmp0_ = g_file_new_for_path (TEST_SAVE_DIR "/t-test.xml");
#line 126 "TDocumentTest.vala"
		f = _tmp0_;
#line 127 "TDocumentTest.vala"
		_tmp1_ = f;
#line 127 "TDocumentTest.vala"
		if (g_file_query_exists (_tmp1_, NULL)) {
#line 1379 "TDocumentTest.c"
			GFile* _tmp2_;
#line 127 "TDocumentTest.vala"
			_tmp2_ = f;
#line 127 "TDocumentTest.vala"
			g_file_delete (_tmp2_, NULL, &_inner_error0_);
#line 127 "TDocumentTest.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 127 "TDocumentTest.vala"
				_g_object_unref0 (f);
#line 1389 "TDocumentTest.c"
				goto __catch269_g_error;
			}
		}
#line 128 "TDocumentTest.vala"
		_tmp3_ = gxml_tdocument_new_from_path (TEST_SAVE_DIR "/t-test.xml");
#line 128 "TDocumentTest.vala"
		d = _tmp3_;
#line 129 "TDocumentTest.vala"
		_tmp4_ = d;
#line 129 "TDocumentTest.vala"
		_tmp5_ = gxml_document_create_element ((GXmlDocument*) _tmp4_, "root", &_inner_error0_);
#line 129 "TDocumentTest.vala"
		e = _tmp5_;
#line 129 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 129 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 129 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 1409 "TDocumentTest.c"
			goto __catch269_g_error;
		}
#line 130 "TDocumentTest.vala"
		_tmp6_ = d;
#line 130 "TDocumentTest.vala"
		_tmp7_ = gxml_tnode_get_children_nodes ((GXmlTNode*) _tmp6_);
#line 130 "TDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 130 "TDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 130 "TDocumentTest.vala"
		_tmp10_ = e;
#line 130 "TDocumentTest.vala"
		gee_collection_add ((GeeCollection*) _tmp9_, _tmp10_);
#line 130 "TDocumentTest.vala"
		_g_object_unref0 (_tmp9_);
#line 131 "TDocumentTest.vala"
		_tmp11_ = d;
#line 131 "TDocumentTest.vala"
		_tmp12_ = gxml_tnode_get_children_nodes ((GXmlTNode*) _tmp11_);
#line 131 "TDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 131 "TDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 131 "TDocumentTest.vala"
		_tmp15_ = gee_collection_get_size ((GeeCollection*) _tmp14_);
#line 131 "TDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 131 "TDocumentTest.vala"
		_vala_assert (_tmp16_ == 1, "d.children_nodes.size == 1");
#line 131 "TDocumentTest.vala"
		_g_object_unref0 (_tmp14_);
#line 132 "TDocumentTest.vala"
		_tmp17_ = d;
#line 132 "TDocumentTest.vala"
		_tmp18_ = gxml_document_get_root ((GXmlDocument*) _tmp17_);
#line 132 "TDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 132 "TDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 132 "TDocumentTest.vala"
		_vala_assert (_tmp20_ != NULL, "d.root != null");
#line 132 "TDocumentTest.vala"
		_g_object_unref0 (_tmp20_);
#line 133 "TDocumentTest.vala"
		_tmp21_ = d;
#line 133 "TDocumentTest.vala"
		_tmp22_ = gxml_document_get_root ((GXmlDocument*) _tmp21_);
#line 133 "TDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 133 "TDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 133 "TDocumentTest.vala"
		_tmp25_ = gxml_node_get_name (_tmp24_);
#line 133 "TDocumentTest.vala"
		_tmp26_ = _tmp25_;
#line 133 "TDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 133 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp27_, "root") == 0, "d.root.name == \"root\"");
#line 133 "TDocumentTest.vala"
		_g_free0 (_tmp27_);
#line 133 "TDocumentTest.vala"
		_g_object_unref0 (_tmp24_);
#line 134 "TDocumentTest.vala"
		_tmp28_ = d;
#line 134 "TDocumentTest.vala"
		_tmp29_ = gxml_document_get_root ((GXmlDocument*) _tmp28_);
#line 134 "TDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 134 "TDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 134 "TDocumentTest.vala"
		_tmp32_ = gxml_node_get_value (_tmp31_);
#line 134 "TDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 134 "TDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 134 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "") == 0, "d.root.value == \"\"");
#line 134 "TDocumentTest.vala"
		_g_free0 (_tmp34_);
#line 134 "TDocumentTest.vala"
		_g_object_unref0 (_tmp31_);
#line 135 "TDocumentTest.vala"
		_tmp35_ = d;
#line 135 "TDocumentTest.vala"
		_tmp36_ = gxml_document_get_root ((GXmlDocument*) _tmp35_);
#line 135 "TDocumentTest.vala"
		_tmp37_ = _tmp36_;
#line 135 "TDocumentTest.vala"
		root = G_TYPE_CHECK_INSTANCE_CAST (_tmp37_, GXML_TYPE_ELEMENT, GXmlElement);
#line 136 "TDocumentTest.vala"
		_tmp38_ = root;
#line 136 "TDocumentTest.vala"
		gxml_element_set_content (_tmp38_, "GXml TDocument Test");
#line 137 "TDocumentTest.vala"
		_tmp39_ = root;
#line 137 "TDocumentTest.vala"
		_tmp40_ = gxml_node_get_children_nodes ((GXmlNode*) _tmp39_);
#line 137 "TDocumentTest.vala"
		_tmp41_ = _tmp40_;
#line 137 "TDocumentTest.vala"
		_tmp42_ = _tmp41_;
#line 137 "TDocumentTest.vala"
		_tmp43_ = gee_collection_get_size ((GeeCollection*) _tmp42_);
#line 137 "TDocumentTest.vala"
		_tmp44_ = _tmp43_;
#line 137 "TDocumentTest.vala"
		_vala_assert (_tmp44_ == 1, "root.children_nodes.size == 1");
#line 137 "TDocumentTest.vala"
		_g_object_unref0 (_tmp42_);
#line 138 "TDocumentTest.vala"
		_tmp45_ = root;
#line 138 "TDocumentTest.vala"
		_tmp46_ = gxml_element_get_content (_tmp45_);
#line 138 "TDocumentTest.vala"
		_tmp47_ = _tmp46_;
#line 138 "TDocumentTest.vala"
		_tmp48_ = _tmp47_;
#line 138 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp48_, "GXml TDocument Test") == 0, "root.content == \"GXml TDocument Test\"");
#line 138 "TDocumentTest.vala"
		_g_free0 (_tmp48_);
#line 139 "TDocumentTest.vala"
		_tmp49_ = root;
#line 139 "TDocumentTest.vala"
		_tmp50_ = gxml_node_get_children_nodes ((GXmlNode*) _tmp49_);
#line 139 "TDocumentTest.vala"
		_tmp51_ = _tmp50_;
#line 139 "TDocumentTest.vala"
		_tmp52_ = _tmp51_;
#line 139 "TDocumentTest.vala"
		_tmp53_ = gee_list_get ((GeeList*) _tmp52_, 0);
#line 139 "TDocumentTest.vala"
		_tmp54_ = (GXmlNode*) _tmp53_;
#line 139 "TDocumentTest.vala"
		_g_object_unref0 (_tmp52_);
#line 139 "TDocumentTest.vala"
		t = _tmp54_;
#line 140 "TDocumentTest.vala"
		_tmp55_ = t;
#line 140 "TDocumentTest.vala"
		_tmp56_ = gxml_node_get_value (_tmp55_);
#line 140 "TDocumentTest.vala"
		_tmp57_ = _tmp56_;
#line 140 "TDocumentTest.vala"
		_tmp58_ = _tmp57_;
#line 140 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp58_, "GXml TDocument Test") == 0, "t.value == \"GXml TDocument Test\"");
#line 140 "TDocumentTest.vala"
		_g_free0 (_tmp58_);
#line 141 "TDocumentTest.vala"
		_tmp59_ = t;
#line 141 "TDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp59_, GXML_TYPE_TEXT), "t is GXml.Text");
#line 143 "TDocumentTest.vala"
		_tmp60_ = d;
#line 143 "TDocumentTest.vala"
		gxml_document_save ((GXmlDocument*) _tmp60_, NULL, &_inner_error0_);
#line 143 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 143 "TDocumentTest.vala"
			_g_object_unref0 (t);
#line 143 "TDocumentTest.vala"
			_g_object_unref0 (root);
#line 143 "TDocumentTest.vala"
			_g_object_unref0 (e);
#line 143 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 143 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 1582 "TDocumentTest.c"
			goto __catch269_g_error;
		}
#line 144 "TDocumentTest.vala"
		_tmp61_ = f;
#line 144 "TDocumentTest.vala"
		_tmp62_ = g_file_read (_tmp61_, NULL, &_inner_error0_);
#line 144 "TDocumentTest.vala"
		istream = _tmp62_;
#line 144 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 144 "TDocumentTest.vala"
			_g_object_unref0 (t);
#line 144 "TDocumentTest.vala"
			_g_object_unref0 (root);
#line 144 "TDocumentTest.vala"
			_g_object_unref0 (e);
#line 144 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 144 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 1603 "TDocumentTest.c"
			goto __catch269_g_error;
		}
#line 145 "TDocumentTest.vala"
		_tmp63_ = g_new0 (guint8, 2048);
#line 145 "TDocumentTest.vala"
		buffer = _tmp63_;
#line 145 "TDocumentTest.vala"
		buffer_length1 = 2048;
#line 145 "TDocumentTest.vala"
		_buffer_size_ = buffer_length1;
#line 146 "TDocumentTest.vala"
		_tmp64_ = istream;
#line 146 "TDocumentTest.vala"
		_tmp65_ = buffer;
#line 146 "TDocumentTest.vala"
		_tmp65__length1 = buffer_length1;
#line 146 "TDocumentTest.vala"
		g_input_stream_read_all ((GInputStream*) _tmp64_, _tmp65_, (gsize) _tmp65__length1, NULL, NULL, &_inner_error0_);
#line 146 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 146 "TDocumentTest.vala"
			buffer = (g_free (buffer), NULL);
#line 146 "TDocumentTest.vala"
			_g_object_unref0 (istream);
#line 146 "TDocumentTest.vala"
			_g_object_unref0 (t);
#line 146 "TDocumentTest.vala"
			_g_object_unref0 (root);
#line 146 "TDocumentTest.vala"
			_g_object_unref0 (e);
#line 146 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 146 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 1638 "TDocumentTest.c"
			goto __catch269_g_error;
		}
#line 147 "TDocumentTest.vala"
		_tmp66_ = istream;
#line 147 "TDocumentTest.vala"
		g_input_stream_close ((GInputStream*) _tmp66_, NULL, &_inner_error0_);
#line 147 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 147 "TDocumentTest.vala"
			buffer = (g_free (buffer), NULL);
#line 147 "TDocumentTest.vala"
			_g_object_unref0 (istream);
#line 147 "TDocumentTest.vala"
			_g_object_unref0 (t);
#line 147 "TDocumentTest.vala"
			_g_object_unref0 (root);
#line 147 "TDocumentTest.vala"
			_g_object_unref0 (e);
#line 147 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 147 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 1661 "TDocumentTest.c"
			goto __catch269_g_error;
		}
#line 148 "TDocumentTest.vala"
		_tmp67_ = buffer;
#line 148 "TDocumentTest.vala"
		_tmp67__length1 = buffer_length1;
#line 148 "TDocumentTest.vala"
		_vala_assert (string_contains ((const gchar*) _tmp67_, "<?xml version=\"1.0\"?>"), "\"<?xml version=\\\"1.0\\\"?>\" in ((string)buffer)");
#line 149 "TDocumentTest.vala"
		_tmp68_ = buffer;
#line 149 "TDocumentTest.vala"
		_tmp68__length1 = buffer_length1;
#line 149 "TDocumentTest.vala"
		_vala_assert (string_contains ((const gchar*) _tmp68_, "<root"), "\"<root\" in ((string)buffer)");
#line 150 "TDocumentTest.vala"
		_tmp69_ = buffer;
#line 150 "TDocumentTest.vala"
		_tmp69__length1 = buffer_length1;
#line 150 "TDocumentTest.vala"
		_vala_assert (string_contains ((const gchar*) _tmp69_, ">GXml TDocument Test<"), "\">GXml TDocument Test<\" in ((string)buffer)");
#line 125 "TDocumentTest.vala"
		buffer = (g_free (buffer), NULL);
#line 125 "TDocumentTest.vala"
		_g_object_unref0 (istream);
#line 125 "TDocumentTest.vala"
		_g_object_unref0 (t);
#line 125 "TDocumentTest.vala"
		_g_object_unref0 (root);
#line 125 "TDocumentTest.vala"
		_g_object_unref0 (e);
#line 125 "TDocumentTest.vala"
		_g_object_unref0 (d);
#line 125 "TDocumentTest.vala"
		_g_object_unref0 (f);
#line 1696 "TDocumentTest.c"
	}
	goto __finally269;
	__catch269_g_error:
	{
		GError* e = NULL;
#line 125 "TDocumentTest.vala"
		e = _inner_error0_;
#line 125 "TDocumentTest.vala"
		_inner_error0_ = NULL;
#line 156 "TDocumentTest.vala"
		g_assert_not_reached ();
#line 125 "TDocumentTest.vala"
		_g_error_free0 (e);
#line 1710 "TDocumentTest.c"
	}
	__finally269:
#line 125 "TDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 125 "TDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 125 "TDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 125 "TDocumentTest.vala"
		return;
#line 1721 "TDocumentTest.c"
	}
}

static void
___lambda212__gtest_func (void)
{
#line 124 "TDocumentTest.vala"
	__lambda212_ ();
#line 1730 "TDocumentTest.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 171 "TDocumentTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 1738 "TDocumentTest.c"
}

static void
__lambda213_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GFile* f = NULL;
		GFile* _tmp0_;
		GFile* _tmp1_;
		GXmlTDocument* d = NULL;
		GXmlTDocument* _tmp3_;
		GXmlNode* e = NULL;
		GXmlTDocument* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlTDocument* _tmp6_;
		GeeBidirList* _tmp7_;
		GeeBidirList* _tmp8_;
		GeeBidirList* _tmp9_;
		GXmlNode* _tmp10_;
		GXmlTDocument* _tmp11_;
		GeeBidirList* _tmp12_;
		GeeBidirList* _tmp13_;
		GeeBidirList* _tmp14_;
		gint _tmp15_;
		gint _tmp16_;
		GXmlTDocument* _tmp17_;
		GXmlNode* _tmp18_;
		GXmlNode* _tmp19_;
		GXmlNode* _tmp20_;
		GXmlTDocument* _tmp21_;
		GXmlNode* _tmp22_;
		GXmlNode* _tmp23_;
		GXmlNode* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		GXmlTDocument* _tmp28_;
		GXmlNode* _tmp29_;
		GXmlNode* _tmp30_;
		GXmlNode* _tmp31_;
		gchar* _tmp32_;
		gchar* _tmp33_;
		gchar* _tmp34_;
		GXmlElement* root = NULL;
		GXmlTDocument* _tmp35_;
		GXmlNode* _tmp36_;
		GXmlNode* _tmp37_;
		GXmlNode* _tmp38_ = NULL;
		GXmlTDocument* _tmp39_;
		GXmlNode* _tmp40_;
		GXmlElement* e1 = NULL;
		GXmlElement* _tmp41_;
		GXmlElement* _tmp42_;
		GXmlElement* _tmp43_;
		GeeBidirList* _tmp44_;
		GeeBidirList* _tmp45_;
		GeeBidirList* _tmp46_;
		gint _tmp47_;
		gint _tmp48_;
		GXmlElement* _tmp49_;
		GeeBidirList* _tmp50_;
		GeeBidirList* _tmp51_;
		GeeBidirList* _tmp52_;
		GXmlElement* _tmp53_;
		GXmlNode* _tmp54_ = NULL;
		GXmlTDocument* _tmp55_;
		GXmlNode* _tmp56_;
		GXmlElement* e2 = NULL;
		GXmlElement* _tmp57_;
		GXmlElement* _tmp58_;
		GXmlElement* _tmp59_;
		GeeBidirList* _tmp60_;
		GeeBidirList* _tmp61_;
		GeeBidirList* _tmp62_;
		gint _tmp63_;
		gint _tmp64_;
		GXmlElement* _tmp65_;
		GeeBidirList* _tmp66_;
		GeeBidirList* _tmp67_;
		GeeBidirList* _tmp68_;
		GXmlElement* _tmp69_;
		GXmlElement* _tmp70_;
		GeeBidirList* _tmp71_;
		GeeBidirList* _tmp72_;
		GeeBidirList* _tmp73_;
		gint _tmp74_;
		gint _tmp75_;
		GXmlTDocument* _tmp76_;
		GFileInputStream* istream = NULL;
		GFile* _tmp77_;
		GFileInputStream* _tmp78_;
		guint8* buffer = NULL;
		guint8* _tmp79_;
		gint buffer_length1;
		gint _buffer_size_;
		GFileInputStream* _tmp80_;
		guint8* _tmp81_;
		gint _tmp81__length1;
		GFileInputStream* _tmp82_;
		guint8* _tmp83_;
		gint _tmp83__length1;
		guint8* _tmp84_;
		gint _tmp84__length1;
		guint8* _tmp85_;
		gint _tmp85__length1;
		guint8* _tmp86_;
		gint _tmp86__length1;
		guint8* _tmp87_;
		gint _tmp87__length1;
#line 161 "TDocumentTest.vala"
		_tmp0_ = g_file_new_for_path (TEST_SAVE_DIR "/t-test.xml");
#line 161 "TDocumentTest.vala"
		f = _tmp0_;
#line 162 "TDocumentTest.vala"
		_tmp1_ = f;
#line 162 "TDocumentTest.vala"
		if (g_file_query_exists (_tmp1_, NULL)) {
#line 1857 "TDocumentTest.c"
			GFile* _tmp2_;
#line 162 "TDocumentTest.vala"
			_tmp2_ = f;
#line 162 "TDocumentTest.vala"
			g_file_delete (_tmp2_, NULL, &_inner_error0_);
#line 162 "TDocumentTest.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 162 "TDocumentTest.vala"
				_g_object_unref0 (f);
#line 1867 "TDocumentTest.c"
				goto __catch270_g_error;
			}
		}
#line 163 "TDocumentTest.vala"
		_tmp3_ = gxml_tdocument_new_from_path (TEST_SAVE_DIR "/t-test.xml");
#line 163 "TDocumentTest.vala"
		d = _tmp3_;
#line 164 "TDocumentTest.vala"
		_tmp4_ = d;
#line 164 "TDocumentTest.vala"
		_tmp5_ = gxml_document_create_element ((GXmlDocument*) _tmp4_, "root", &_inner_error0_);
#line 164 "TDocumentTest.vala"
		e = _tmp5_;
#line 164 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 164 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 164 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 1887 "TDocumentTest.c"
			goto __catch270_g_error;
		}
#line 165 "TDocumentTest.vala"
		_tmp6_ = d;
#line 165 "TDocumentTest.vala"
		_tmp7_ = gxml_tnode_get_children_nodes ((GXmlTNode*) _tmp6_);
#line 165 "TDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 165 "TDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 165 "TDocumentTest.vala"
		_tmp10_ = e;
#line 165 "TDocumentTest.vala"
		gee_collection_add ((GeeCollection*) _tmp9_, _tmp10_);
#line 165 "TDocumentTest.vala"
		_g_object_unref0 (_tmp9_);
#line 166 "TDocumentTest.vala"
		_tmp11_ = d;
#line 166 "TDocumentTest.vala"
		_tmp12_ = gxml_tnode_get_children_nodes ((GXmlTNode*) _tmp11_);
#line 166 "TDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 166 "TDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 166 "TDocumentTest.vala"
		_tmp15_ = gee_collection_get_size ((GeeCollection*) _tmp14_);
#line 166 "TDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 166 "TDocumentTest.vala"
		_vala_assert (_tmp16_ == 1, "d.children_nodes.size == 1");
#line 166 "TDocumentTest.vala"
		_g_object_unref0 (_tmp14_);
#line 167 "TDocumentTest.vala"
		_tmp17_ = d;
#line 167 "TDocumentTest.vala"
		_tmp18_ = gxml_document_get_root ((GXmlDocument*) _tmp17_);
#line 167 "TDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 167 "TDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 167 "TDocumentTest.vala"
		_vala_assert (_tmp20_ != NULL, "d.root != null");
#line 167 "TDocumentTest.vala"
		_g_object_unref0 (_tmp20_);
#line 168 "TDocumentTest.vala"
		_tmp21_ = d;
#line 168 "TDocumentTest.vala"
		_tmp22_ = gxml_document_get_root ((GXmlDocument*) _tmp21_);
#line 168 "TDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 168 "TDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 168 "TDocumentTest.vala"
		_tmp25_ = gxml_node_get_name (_tmp24_);
#line 168 "TDocumentTest.vala"
		_tmp26_ = _tmp25_;
#line 168 "TDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 168 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp27_, "root") == 0, "d.root.name == \"root\"");
#line 168 "TDocumentTest.vala"
		_g_free0 (_tmp27_);
#line 168 "TDocumentTest.vala"
		_g_object_unref0 (_tmp24_);
#line 169 "TDocumentTest.vala"
		_tmp28_ = d;
#line 169 "TDocumentTest.vala"
		_tmp29_ = gxml_document_get_root ((GXmlDocument*) _tmp28_);
#line 169 "TDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 169 "TDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 169 "TDocumentTest.vala"
		_tmp32_ = gxml_node_get_value (_tmp31_);
#line 169 "TDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 169 "TDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 169 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "") == 0, "d.root.value == \"\"");
#line 169 "TDocumentTest.vala"
		_g_free0 (_tmp34_);
#line 169 "TDocumentTest.vala"
		_g_object_unref0 (_tmp31_);
#line 170 "TDocumentTest.vala"
		_tmp35_ = d;
#line 170 "TDocumentTest.vala"
		_tmp36_ = gxml_document_get_root ((GXmlDocument*) _tmp35_);
#line 170 "TDocumentTest.vala"
		_tmp37_ = _tmp36_;
#line 170 "TDocumentTest.vala"
		root = G_TYPE_CHECK_INSTANCE_CAST (_tmp37_, GXML_TYPE_ELEMENT, GXmlElement);
#line 171 "TDocumentTest.vala"
		_tmp39_ = d;
#line 171 "TDocumentTest.vala"
		_tmp40_ = gxml_document_create_element ((GXmlDocument*) _tmp39_, "child", &_inner_error0_);
#line 171 "TDocumentTest.vala"
		_tmp38_ = _tmp40_;
#line 171 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 171 "TDocumentTest.vala"
			_g_object_unref0 (root);
#line 171 "TDocumentTest.vala"
			_g_object_unref0 (e);
#line 171 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 171 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 1996 "TDocumentTest.c"
			goto __catch270_g_error;
		}
#line 171 "TDocumentTest.vala"
		_tmp41_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp38_, GXML_TYPE_ELEMENT, GXmlElement));
#line 171 "TDocumentTest.vala"
		e1 = _tmp41_;
#line 172 "TDocumentTest.vala"
		_tmp42_ = e1;
#line 172 "TDocumentTest.vala"
		gxml_element_set_attr (_tmp42_, "name", "Test1");
#line 173 "TDocumentTest.vala"
		_tmp43_ = e1;
#line 173 "TDocumentTest.vala"
		_tmp44_ = gxml_node_get_children_nodes ((GXmlNode*) _tmp43_);
#line 173 "TDocumentTest.vala"
		_tmp45_ = _tmp44_;
#line 173 "TDocumentTest.vala"
		_tmp46_ = _tmp45_;
#line 173 "TDocumentTest.vala"
		_tmp47_ = gee_collection_get_size ((GeeCollection*) _tmp46_);
#line 173 "TDocumentTest.vala"
		_tmp48_ = _tmp47_;
#line 173 "TDocumentTest.vala"
		_vala_assert (_tmp48_ == 0, "e1.children_nodes.size == 0");
#line 173 "TDocumentTest.vala"
		_g_object_unref0 (_tmp46_);
#line 174 "TDocumentTest.vala"
		_tmp49_ = root;
#line 174 "TDocumentTest.vala"
		_tmp50_ = gxml_node_get_children_nodes ((GXmlNode*) _tmp49_);
#line 174 "TDocumentTest.vala"
		_tmp51_ = _tmp50_;
#line 174 "TDocumentTest.vala"
		_tmp52_ = _tmp51_;
#line 174 "TDocumentTest.vala"
		_tmp53_ = e1;
#line 174 "TDocumentTest.vala"
		gee_collection_add ((GeeCollection*) _tmp52_, (GXmlNode*) _tmp53_);
#line 174 "TDocumentTest.vala"
		_g_object_unref0 (_tmp52_);
#line 175 "TDocumentTest.vala"
		_tmp55_ = d;
#line 175 "TDocumentTest.vala"
		_tmp56_ = gxml_document_create_element ((GXmlDocument*) _tmp55_, "child", &_inner_error0_);
#line 175 "TDocumentTest.vala"
		_tmp54_ = _tmp56_;
#line 175 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 175 "TDocumentTest.vala"
			_g_object_unref0 (e1);
#line 175 "TDocumentTest.vala"
			_g_object_unref0 (_tmp38_);
#line 175 "TDocumentTest.vala"
			_g_object_unref0 (root);
#line 175 "TDocumentTest.vala"
			_g_object_unref0 (e);
#line 175 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 175 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 2057 "TDocumentTest.c"
			goto __catch270_g_error;
		}
#line 175 "TDocumentTest.vala"
		_tmp57_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp54_, GXML_TYPE_ELEMENT, GXmlElement));
#line 175 "TDocumentTest.vala"
		e2 = _tmp57_;
#line 176 "TDocumentTest.vala"
		_tmp58_ = e2;
#line 176 "TDocumentTest.vala"
		gxml_element_set_attr (_tmp58_, "name", "Test2");
#line 177 "TDocumentTest.vala"
		_tmp59_ = e2;
#line 177 "TDocumentTest.vala"
		_tmp60_ = gxml_node_get_children_nodes ((GXmlNode*) _tmp59_);
#line 177 "TDocumentTest.vala"
		_tmp61_ = _tmp60_;
#line 177 "TDocumentTest.vala"
		_tmp62_ = _tmp61_;
#line 177 "TDocumentTest.vala"
		_tmp63_ = gee_collection_get_size ((GeeCollection*) _tmp62_);
#line 177 "TDocumentTest.vala"
		_tmp64_ = _tmp63_;
#line 177 "TDocumentTest.vala"
		_vala_assert (_tmp64_ == 0, "e2.children_nodes.size == 0");
#line 177 "TDocumentTest.vala"
		_g_object_unref0 (_tmp62_);
#line 178 "TDocumentTest.vala"
		_tmp65_ = root;
#line 178 "TDocumentTest.vala"
		_tmp66_ = gxml_node_get_children_nodes ((GXmlNode*) _tmp65_);
#line 178 "TDocumentTest.vala"
		_tmp67_ = _tmp66_;
#line 178 "TDocumentTest.vala"
		_tmp68_ = _tmp67_;
#line 178 "TDocumentTest.vala"
		_tmp69_ = e2;
#line 178 "TDocumentTest.vala"
		gee_collection_add ((GeeCollection*) _tmp68_, (GXmlNode*) _tmp69_);
#line 178 "TDocumentTest.vala"
		_g_object_unref0 (_tmp68_);
#line 179 "TDocumentTest.vala"
		_tmp70_ = root;
#line 179 "TDocumentTest.vala"
		_tmp71_ = gxml_node_get_children_nodes ((GXmlNode*) _tmp70_);
#line 179 "TDocumentTest.vala"
		_tmp72_ = _tmp71_;
#line 179 "TDocumentTest.vala"
		_tmp73_ = _tmp72_;
#line 179 "TDocumentTest.vala"
		_tmp74_ = gee_collection_get_size ((GeeCollection*) _tmp73_);
#line 179 "TDocumentTest.vala"
		_tmp75_ = _tmp74_;
#line 179 "TDocumentTest.vala"
		_vala_assert (_tmp75_ == 2, "root.children_nodes.size == 2");
#line 179 "TDocumentTest.vala"
		_g_object_unref0 (_tmp73_);
#line 180 "TDocumentTest.vala"
		_tmp76_ = d;
#line 180 "TDocumentTest.vala"
		gxml_document_save ((GXmlDocument*) _tmp76_, NULL, &_inner_error0_);
#line 180 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 180 "TDocumentTest.vala"
			_g_object_unref0 (e2);
#line 180 "TDocumentTest.vala"
			_g_object_unref0 (_tmp54_);
#line 180 "TDocumentTest.vala"
			_g_object_unref0 (e1);
#line 180 "TDocumentTest.vala"
			_g_object_unref0 (_tmp38_);
#line 180 "TDocumentTest.vala"
			_g_object_unref0 (root);
#line 180 "TDocumentTest.vala"
			_g_object_unref0 (e);
#line 180 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 180 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 2136 "TDocumentTest.c"
			goto __catch270_g_error;
		}
#line 181 "TDocumentTest.vala"
		_tmp77_ = f;
#line 181 "TDocumentTest.vala"
		_tmp78_ = g_file_read (_tmp77_, NULL, &_inner_error0_);
#line 181 "TDocumentTest.vala"
		istream = _tmp78_;
#line 181 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 181 "TDocumentTest.vala"
			_g_object_unref0 (e2);
#line 181 "TDocumentTest.vala"
			_g_object_unref0 (_tmp54_);
#line 181 "TDocumentTest.vala"
			_g_object_unref0 (e1);
#line 181 "TDocumentTest.vala"
			_g_object_unref0 (_tmp38_);
#line 181 "TDocumentTest.vala"
			_g_object_unref0 (root);
#line 181 "TDocumentTest.vala"
			_g_object_unref0 (e);
#line 181 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 181 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 2163 "TDocumentTest.c"
			goto __catch270_g_error;
		}
#line 182 "TDocumentTest.vala"
		_tmp79_ = g_new0 (guint8, 2048);
#line 182 "TDocumentTest.vala"
		buffer = _tmp79_;
#line 182 "TDocumentTest.vala"
		buffer_length1 = 2048;
#line 182 "TDocumentTest.vala"
		_buffer_size_ = buffer_length1;
#line 183 "TDocumentTest.vala"
		_tmp80_ = istream;
#line 183 "TDocumentTest.vala"
		_tmp81_ = buffer;
#line 183 "TDocumentTest.vala"
		_tmp81__length1 = buffer_length1;
#line 183 "TDocumentTest.vala"
		g_input_stream_read_all ((GInputStream*) _tmp80_, _tmp81_, (gsize) _tmp81__length1, NULL, NULL, &_inner_error0_);
#line 183 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 183 "TDocumentTest.vala"
			buffer = (g_free (buffer), NULL);
#line 183 "TDocumentTest.vala"
			_g_object_unref0 (istream);
#line 183 "TDocumentTest.vala"
			_g_object_unref0 (e2);
#line 183 "TDocumentTest.vala"
			_g_object_unref0 (_tmp54_);
#line 183 "TDocumentTest.vala"
			_g_object_unref0 (e1);
#line 183 "TDocumentTest.vala"
			_g_object_unref0 (_tmp38_);
#line 183 "TDocumentTest.vala"
			_g_object_unref0 (root);
#line 183 "TDocumentTest.vala"
			_g_object_unref0 (e);
#line 183 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 183 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 2204 "TDocumentTest.c"
			goto __catch270_g_error;
		}
#line 184 "TDocumentTest.vala"
		_tmp82_ = istream;
#line 184 "TDocumentTest.vala"
		g_input_stream_close ((GInputStream*) _tmp82_, NULL, &_inner_error0_);
#line 184 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 184 "TDocumentTest.vala"
			buffer = (g_free (buffer), NULL);
#line 184 "TDocumentTest.vala"
			_g_object_unref0 (istream);
#line 184 "TDocumentTest.vala"
			_g_object_unref0 (e2);
#line 184 "TDocumentTest.vala"
			_g_object_unref0 (_tmp54_);
#line 184 "TDocumentTest.vala"
			_g_object_unref0 (e1);
#line 184 "TDocumentTest.vala"
			_g_object_unref0 (_tmp38_);
#line 184 "TDocumentTest.vala"
			_g_object_unref0 (root);
#line 184 "TDocumentTest.vala"
			_g_object_unref0 (e);
#line 184 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 184 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 2233 "TDocumentTest.c"
			goto __catch270_g_error;
		}
#line 185 "TDocumentTest.vala"
		_tmp83_ = buffer;
#line 185 "TDocumentTest.vala"
		_tmp83__length1 = buffer_length1;
#line 185 "TDocumentTest.vala"
		_vala_assert (string_contains ((const gchar*) _tmp83_, "<?xml version=\"1.0\"?>"), "\"<?xml version=\\\"1.0\\\"?>\" in ((string)buffer)");
#line 186 "TDocumentTest.vala"
		_tmp84_ = buffer;
#line 186 "TDocumentTest.vala"
		_tmp84__length1 = buffer_length1;
#line 186 "TDocumentTest.vala"
		_vala_assert (string_contains ((const gchar*) _tmp84_, "<root>"), "\"<root>\" in ((string)buffer)");
#line 187 "TDocumentTest.vala"
		_tmp85_ = buffer;
#line 187 "TDocumentTest.vala"
		_tmp85__length1 = buffer_length1;
#line 187 "TDocumentTest.vala"
		_vala_assert (string_contains ((const gchar*) _tmp85_, "</root>"), "\"</root>\" in ((string)buffer)");
#line 188 "TDocumentTest.vala"
		_tmp86_ = buffer;
#line 188 "TDocumentTest.vala"
		_tmp86__length1 = buffer_length1;
#line 188 "TDocumentTest.vala"
		_vala_assert (string_contains ((const gchar*) _tmp86_, "<child name=\"Test1\"/>"), "\"<child name=\\\"Test1\\\"/>\" in ((string)buffer)");
#line 189 "TDocumentTest.vala"
		_tmp87_ = buffer;
#line 189 "TDocumentTest.vala"
		_tmp87__length1 = buffer_length1;
#line 189 "TDocumentTest.vala"
		_vala_assert (string_contains ((const gchar*) _tmp87_, "<child name=\"Test2\"/>"), "\"<child name=\\\"Test2\\\"/>\" in ((string)buffer)");
#line 160 "TDocumentTest.vala"
		buffer = (g_free (buffer), NULL);
#line 160 "TDocumentTest.vala"
		_g_object_unref0 (istream);
#line 160 "TDocumentTest.vala"
		_g_object_unref0 (e2);
#line 160 "TDocumentTest.vala"
		_g_object_unref0 (_tmp54_);
#line 160 "TDocumentTest.vala"
		_g_object_unref0 (e1);
#line 160 "TDocumentTest.vala"
		_g_object_unref0 (_tmp38_);
#line 160 "TDocumentTest.vala"
		_g_object_unref0 (root);
#line 160 "TDocumentTest.vala"
		_g_object_unref0 (e);
#line 160 "TDocumentTest.vala"
		_g_object_unref0 (d);
#line 160 "TDocumentTest.vala"
		_g_object_unref0 (f);
#line 2286 "TDocumentTest.c"
	}
	goto __finally270;
	__catch270_g_error:
	{
		GError* e = NULL;
#line 160 "TDocumentTest.vala"
		e = _inner_error0_;
#line 160 "TDocumentTest.vala"
		_inner_error0_ = NULL;
#line 195 "TDocumentTest.vala"
		g_assert_not_reached ();
#line 160 "TDocumentTest.vala"
		_g_error_free0 (e);
#line 2300 "TDocumentTest.c"
	}
	__finally270:
#line 160 "TDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 160 "TDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 160 "TDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 160 "TDocumentTest.vala"
		return;
#line 2311 "TDocumentTest.c"
	}
}

static void
___lambda213__gtest_func (void)
{
#line 159 "TDocumentTest.vala"
	__lambda213_ ();
#line 2320 "TDocumentTest.c"
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result = NULL;
#line 1516 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1517 "glib-2.0.vapi"
	result = self;
#line 1517 "glib-2.0.vapi"
	return result;
#line 2333 "TDocumentTest.c"
}

static void
__lambda214_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GFile* f = NULL;
		GFile* _tmp0_;
		GFile* _tmp1_;
		GXmlTDocument* d = NULL;
		GXmlTDocument* _tmp3_;
		GXmlNode* e = NULL;
		GXmlTDocument* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlTDocument* _tmp6_;
		GeeBidirList* _tmp7_;
		GeeBidirList* _tmp8_;
		GeeBidirList* _tmp9_;
		GXmlNode* _tmp10_;
		GXmlTDocument* _tmp11_;
		GeeBidirList* _tmp12_;
		GeeBidirList* _tmp13_;
		GeeBidirList* _tmp14_;
		gint _tmp15_;
		gint _tmp16_;
		GXmlTDocument* _tmp17_;
		GXmlNode* _tmp18_;
		GXmlNode* _tmp19_;
		GXmlNode* _tmp20_;
		GXmlTDocument* _tmp21_;
		GXmlNode* _tmp22_;
		GXmlNode* _tmp23_;
		GXmlNode* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		GXmlTDocument* _tmp28_;
		GXmlNode* _tmp29_;
		GXmlNode* _tmp30_;
		GXmlNode* _tmp31_;
		gchar* _tmp32_;
		gchar* _tmp33_;
		gchar* _tmp34_;
		GXmlElement* r = NULL;
		GXmlTDocument* _tmp35_;
		GXmlNode* _tmp36_;
		GXmlNode* _tmp37_;
		GXmlElement* _tmp38_;
		GXmlTDocument* _tmp117_;
		GXmlNode* _tmp118_;
		GXmlNode* _tmp119_;
		GXmlNode* _tmp120_;
		GeeBidirList* _tmp121_;
		GeeBidirList* _tmp122_;
		GeeBidirList* _tmp123_;
		gint _tmp124_;
		gint _tmp125_;
#line 206 "TDocumentTest.vala"
		_tmp0_ = g_file_new_for_path (TEST_SAVE_DIR "/t-large.xml");
#line 206 "TDocumentTest.vala"
		f = _tmp0_;
#line 207 "TDocumentTest.vala"
		_tmp1_ = f;
#line 207 "TDocumentTest.vala"
		if (g_file_query_exists (_tmp1_, NULL)) {
#line 2400 "TDocumentTest.c"
			GFile* _tmp2_;
#line 207 "TDocumentTest.vala"
			_tmp2_ = f;
#line 207 "TDocumentTest.vala"
			g_file_delete (_tmp2_, NULL, &_inner_error0_);
#line 207 "TDocumentTest.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 207 "TDocumentTest.vala"
				_g_object_unref0 (f);
#line 2410 "TDocumentTest.c"
				goto __catch271_g_error;
			}
		}
#line 211 "TDocumentTest.vala"
		_tmp3_ = gxml_tdocument_new_from_path (TEST_SAVE_DIR "/t-large.xml");
#line 211 "TDocumentTest.vala"
		d = _tmp3_;
#line 212 "TDocumentTest.vala"
		_tmp4_ = d;
#line 212 "TDocumentTest.vala"
		_tmp5_ = gxml_document_create_element ((GXmlDocument*) _tmp4_, "bookstore", &_inner_error0_);
#line 212 "TDocumentTest.vala"
		e = _tmp5_;
#line 212 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 212 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 212 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 2430 "TDocumentTest.c"
			goto __catch271_g_error;
		}
#line 213 "TDocumentTest.vala"
		_tmp6_ = d;
#line 213 "TDocumentTest.vala"
		_tmp7_ = gxml_tnode_get_children_nodes ((GXmlTNode*) _tmp6_);
#line 213 "TDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 213 "TDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 213 "TDocumentTest.vala"
		_tmp10_ = e;
#line 213 "TDocumentTest.vala"
		gee_collection_add ((GeeCollection*) _tmp9_, _tmp10_);
#line 213 "TDocumentTest.vala"
		_g_object_unref0 (_tmp9_);
#line 214 "TDocumentTest.vala"
		_tmp11_ = d;
#line 214 "TDocumentTest.vala"
		_tmp12_ = gxml_tnode_get_children_nodes ((GXmlTNode*) _tmp11_);
#line 214 "TDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 214 "TDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 214 "TDocumentTest.vala"
		_tmp15_ = gee_collection_get_size ((GeeCollection*) _tmp14_);
#line 214 "TDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 214 "TDocumentTest.vala"
		_vala_assert (_tmp16_ == 1, "d.children_nodes.size == 1");
#line 214 "TDocumentTest.vala"
		_g_object_unref0 (_tmp14_);
#line 215 "TDocumentTest.vala"
		_tmp17_ = d;
#line 215 "TDocumentTest.vala"
		_tmp18_ = gxml_document_get_root ((GXmlDocument*) _tmp17_);
#line 215 "TDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 215 "TDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 215 "TDocumentTest.vala"
		_vala_assert (_tmp20_ != NULL, "d.root != null");
#line 215 "TDocumentTest.vala"
		_g_object_unref0 (_tmp20_);
#line 216 "TDocumentTest.vala"
		_tmp21_ = d;
#line 216 "TDocumentTest.vala"
		_tmp22_ = gxml_document_get_root ((GXmlDocument*) _tmp21_);
#line 216 "TDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 216 "TDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 216 "TDocumentTest.vala"
		_tmp25_ = gxml_node_get_name (_tmp24_);
#line 216 "TDocumentTest.vala"
		_tmp26_ = _tmp25_;
#line 216 "TDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 216 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp27_, "bookstore") == 0, "d.root.name == \"bookstore\"");
#line 216 "TDocumentTest.vala"
		_g_free0 (_tmp27_);
#line 216 "TDocumentTest.vala"
		_g_object_unref0 (_tmp24_);
#line 217 "TDocumentTest.vala"
		_tmp28_ = d;
#line 217 "TDocumentTest.vala"
		_tmp29_ = gxml_document_get_root ((GXmlDocument*) _tmp28_);
#line 217 "TDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 217 "TDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 217 "TDocumentTest.vala"
		_tmp32_ = gxml_node_get_value (_tmp31_);
#line 217 "TDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 217 "TDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 217 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "") == 0, "d.root.value == \"\"");
#line 217 "TDocumentTest.vala"
		_g_free0 (_tmp34_);
#line 217 "TDocumentTest.vala"
		_g_object_unref0 (_tmp31_);
#line 218 "TDocumentTest.vala"
		_tmp35_ = d;
#line 218 "TDocumentTest.vala"
		_tmp36_ = gxml_document_get_root ((GXmlDocument*) _tmp35_);
#line 218 "TDocumentTest.vala"
		_tmp37_ = _tmp36_;
#line 218 "TDocumentTest.vala"
		r = G_TYPE_CHECK_INSTANCE_CAST (_tmp37_, GXML_TYPE_ELEMENT, GXmlElement);
#line 219 "TDocumentTest.vala"
		_tmp38_ = r;
#line 219 "TDocumentTest.vala"
		gxml_element_set_attr (_tmp38_, "name", "The Great Book");
#line 2527 "TDocumentTest.c"
		{
			gint i = 0;
#line 223 "TDocumentTest.vala"
			i = 0;
#line 2532 "TDocumentTest.c"
			{
				gboolean _tmp39_ = FALSE;
#line 223 "TDocumentTest.vala"
				_tmp39_ = TRUE;
#line 223 "TDocumentTest.vala"
				while (TRUE) {
#line 2539 "TDocumentTest.c"
					GXmlNode* _tmp41_ = NULL;
					GXmlTDocument* _tmp42_;
					GXmlNode* _tmp43_;
					GXmlElement* b = NULL;
					GXmlElement* _tmp44_;
					GXmlElement* _tmp45_;
					GeeBidirList* _tmp46_;
					GeeBidirList* _tmp47_;
					GeeBidirList* _tmp48_;
					GXmlElement* _tmp49_;
					GXmlNode* _tmp50_ = NULL;
					GXmlTDocument* _tmp51_;
					GXmlNode* _tmp52_;
					GXmlElement* aths = NULL;
					GXmlElement* _tmp53_;
					GXmlElement* _tmp54_;
					GeeBidirList* _tmp55_;
					GeeBidirList* _tmp56_;
					GeeBidirList* _tmp57_;
					GXmlElement* _tmp58_;
					GXmlNode* _tmp59_ = NULL;
					GXmlTDocument* _tmp60_;
					GXmlNode* _tmp61_;
					GXmlElement* ath1 = NULL;
					GXmlElement* _tmp62_;
					GXmlElement* _tmp63_;
					GeeBidirList* _tmp64_;
					GeeBidirList* _tmp65_;
					GeeBidirList* _tmp66_;
					GXmlElement* _tmp67_;
					GXmlNode* _tmp68_ = NULL;
					GXmlTDocument* _tmp69_;
					GXmlNode* _tmp70_;
					GXmlElement* name1 = NULL;
					GXmlElement* _tmp71_;
					GXmlElement* _tmp72_;
					GXmlElement* _tmp73_;
					GeeBidirList* _tmp74_;
					GeeBidirList* _tmp75_;
					GeeBidirList* _tmp76_;
					GXmlElement* _tmp77_;
					GXmlNode* _tmp78_ = NULL;
					GXmlTDocument* _tmp79_;
					GXmlNode* _tmp80_;
					GXmlElement* email1 = NULL;
					GXmlElement* _tmp81_;
					GXmlElement* _tmp82_;
					GXmlElement* _tmp83_;
					GeeBidirList* _tmp84_;
					GeeBidirList* _tmp85_;
					GeeBidirList* _tmp86_;
					GXmlElement* _tmp87_;
					GXmlNode* _tmp88_ = NULL;
					GXmlTDocument* _tmp89_;
					GXmlNode* _tmp90_;
					GXmlElement* ath2 = NULL;
					GXmlElement* _tmp91_;
					GXmlElement* _tmp92_;
					GeeBidirList* _tmp93_;
					GeeBidirList* _tmp94_;
					GeeBidirList* _tmp95_;
					GXmlElement* _tmp96_;
					GXmlNode* _tmp97_ = NULL;
					GXmlTDocument* _tmp98_;
					GXmlNode* _tmp99_;
					GXmlElement* name2 = NULL;
					GXmlElement* _tmp100_;
					GXmlElement* _tmp101_;
					GXmlElement* _tmp102_;
					GeeBidirList* _tmp103_;
					GeeBidirList* _tmp104_;
					GeeBidirList* _tmp105_;
					GXmlElement* _tmp106_;
					GXmlNode* _tmp107_ = NULL;
					GXmlTDocument* _tmp108_;
					GXmlNode* _tmp109_;
					GXmlElement* email2 = NULL;
					GXmlElement* _tmp110_;
					GXmlElement* _tmp111_;
					GXmlElement* _tmp112_;
					GeeBidirList* _tmp113_;
					GeeBidirList* _tmp114_;
					GeeBidirList* _tmp115_;
					GXmlElement* _tmp116_;
#line 223 "TDocumentTest.vala"
					if (!_tmp39_) {
#line 2626 "TDocumentTest.c"
						gint _tmp40_;
#line 223 "TDocumentTest.vala"
						_tmp40_ = i;
#line 223 "TDocumentTest.vala"
						i = _tmp40_ + 1;
#line 2632 "TDocumentTest.c"
					}
#line 223 "TDocumentTest.vala"
					_tmp39_ = FALSE;
#line 223 "TDocumentTest.vala"
					if (!(i < 5000)) {
#line 223 "TDocumentTest.vala"
						break;
#line 2640 "TDocumentTest.c"
					}
#line 224 "TDocumentTest.vala"
					_tmp42_ = d;
#line 224 "TDocumentTest.vala"
					_tmp43_ = gxml_document_create_element ((GXmlDocument*) _tmp42_, "book", &_inner_error0_);
#line 224 "TDocumentTest.vala"
					_tmp41_ = _tmp43_;
#line 224 "TDocumentTest.vala"
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 224 "TDocumentTest.vala"
						_g_object_unref0 (r);
#line 224 "TDocumentTest.vala"
						_g_object_unref0 (e);
#line 224 "TDocumentTest.vala"
						_g_object_unref0 (d);
#line 224 "TDocumentTest.vala"
						_g_object_unref0 (f);
#line 2658 "TDocumentTest.c"
						goto __catch271_g_error;
					}
#line 224 "TDocumentTest.vala"
					_tmp44_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, GXML_TYPE_ELEMENT, GXmlElement));
#line 224 "TDocumentTest.vala"
					b = _tmp44_;
#line 225 "TDocumentTest.vala"
					_tmp45_ = r;
#line 225 "TDocumentTest.vala"
					_tmp46_ = gxml_node_get_children_nodes ((GXmlNode*) _tmp45_);
#line 225 "TDocumentTest.vala"
					_tmp47_ = _tmp46_;
#line 225 "TDocumentTest.vala"
					_tmp48_ = _tmp47_;
#line 225 "TDocumentTest.vala"
					_tmp49_ = b;
#line 225 "TDocumentTest.vala"
					gee_collection_add ((GeeCollection*) _tmp48_, (GXmlNode*) _tmp49_);
#line 225 "TDocumentTest.vala"
					_g_object_unref0 (_tmp48_);
#line 226 "TDocumentTest.vala"
					_tmp51_ = d;
#line 226 "TDocumentTest.vala"
					_tmp52_ = gxml_document_create_element ((GXmlDocument*) _tmp51_, "Authors", &_inner_error0_);
#line 226 "TDocumentTest.vala"
					_tmp50_ = _tmp52_;
#line 226 "TDocumentTest.vala"
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 226 "TDocumentTest.vala"
						_g_object_unref0 (b);
#line 226 "TDocumentTest.vala"
						_g_object_unref0 (_tmp41_);
#line 226 "TDocumentTest.vala"
						_g_object_unref0 (r);
#line 226 "TDocumentTest.vala"
						_g_object_unref0 (e);
#line 226 "TDocumentTest.vala"
						_g_object_unref0 (d);
#line 226 "TDocumentTest.vala"
						_g_object_unref0 (f);
#line 2699 "TDocumentTest.c"
						goto __catch271_g_error;
					}
#line 226 "TDocumentTest.vala"
					_tmp53_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp50_, GXML_TYPE_ELEMENT, GXmlElement));
#line 226 "TDocumentTest.vala"
					aths = _tmp53_;
#line 227 "TDocumentTest.vala"
					_tmp54_ = b;
#line 227 "TDocumentTest.vala"
					_tmp55_ = gxml_node_get_children_nodes ((GXmlNode*) _tmp54_);
#line 227 "TDocumentTest.vala"
					_tmp56_ = _tmp55_;
#line 227 "TDocumentTest.vala"
					_tmp57_ = _tmp56_;
#line 227 "TDocumentTest.vala"
					_tmp58_ = aths;
#line 227 "TDocumentTest.vala"
					gee_collection_add ((GeeCollection*) _tmp57_, (GXmlNode*) _tmp58_);
#line 227 "TDocumentTest.vala"
					_g_object_unref0 (_tmp57_);
#line 228 "TDocumentTest.vala"
					_tmp60_ = d;
#line 228 "TDocumentTest.vala"
					_tmp61_ = gxml_document_create_element ((GXmlDocument*) _tmp60_, "Author", &_inner_error0_);
#line 228 "TDocumentTest.vala"
					_tmp59_ = _tmp61_;
#line 228 "TDocumentTest.vala"
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 228 "TDocumentTest.vala"
						_g_object_unref0 (aths);
#line 228 "TDocumentTest.vala"
						_g_object_unref0 (_tmp50_);
#line 228 "TDocumentTest.vala"
						_g_object_unref0 (b);
#line 228 "TDocumentTest.vala"
						_g_object_unref0 (_tmp41_);
#line 228 "TDocumentTest.vala"
						_g_object_unref0 (r);
#line 228 "TDocumentTest.vala"
						_g_object_unref0 (e);
#line 228 "TDocumentTest.vala"
						_g_object_unref0 (d);
#line 228 "TDocumentTest.vala"
						_g_object_unref0 (f);
#line 2744 "TDocumentTest.c"
						goto __catch271_g_error;
					}
#line 228 "TDocumentTest.vala"
					_tmp62_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp59_, GXML_TYPE_ELEMENT, GXmlElement));
#line 228 "TDocumentTest.vala"
					ath1 = _tmp62_;
#line 229 "TDocumentTest.vala"
					_tmp63_ = aths;
#line 229 "TDocumentTest.vala"
					_tmp64_ = gxml_node_get_children_nodes ((GXmlNode*) _tmp63_);
#line 229 "TDocumentTest.vala"
					_tmp65_ = _tmp64_;
#line 229 "TDocumentTest.vala"
					_tmp66_ = _tmp65_;
#line 229 "TDocumentTest.vala"
					_tmp67_ = ath1;
#line 229 "TDocumentTest.vala"
					gee_collection_add ((GeeCollection*) _tmp66_, (GXmlNode*) _tmp67_);
#line 229 "TDocumentTest.vala"
					_g_object_unref0 (_tmp66_);
#line 230 "TDocumentTest.vala"
					_tmp69_ = d;
#line 230 "TDocumentTest.vala"
					_tmp70_ = gxml_document_create_element ((GXmlDocument*) _tmp69_, "Name", &_inner_error0_);
#line 230 "TDocumentTest.vala"
					_tmp68_ = _tmp70_;
#line 230 "TDocumentTest.vala"
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 230 "TDocumentTest.vala"
						_g_object_unref0 (ath1);
#line 230 "TDocumentTest.vala"
						_g_object_unref0 (_tmp59_);
#line 230 "TDocumentTest.vala"
						_g_object_unref0 (aths);
#line 230 "TDocumentTest.vala"
						_g_object_unref0 (_tmp50_);
#line 230 "TDocumentTest.vala"
						_g_object_unref0 (b);
#line 230 "TDocumentTest.vala"
						_g_object_unref0 (_tmp41_);
#line 230 "TDocumentTest.vala"
						_g_object_unref0 (r);
#line 230 "TDocumentTest.vala"
						_g_object_unref0 (e);
#line 230 "TDocumentTest.vala"
						_g_object_unref0 (d);
#line 230 "TDocumentTest.vala"
						_g_object_unref0 (f);
#line 2793 "TDocumentTest.c"
						goto __catch271_g_error;
					}
#line 230 "TDocumentTest.vala"
					_tmp71_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp68_, GXML_TYPE_ELEMENT, GXmlElement));
#line 230 "TDocumentTest.vala"
					name1 = _tmp71_;
#line 231 "TDocumentTest.vala"
					_tmp72_ = name1;
#line 231 "TDocumentTest.vala"
					gxml_element_set_content (_tmp72_, "Fred");
#line 232 "TDocumentTest.vala"
					_tmp73_ = ath1;
#line 232 "TDocumentTest.vala"
					_tmp74_ = gxml_node_get_children_nodes ((GXmlNode*) _tmp73_);
#line 232 "TDocumentTest.vala"
					_tmp75_ = _tmp74_;
#line 232 "TDocumentTest.vala"
					_tmp76_ = _tmp75_;
#line 232 "TDocumentTest.vala"
					_tmp77_ = name1;
#line 232 "TDocumentTest.vala"
					gee_collection_add ((GeeCollection*) _tmp76_, (GXmlNode*) _tmp77_);
#line 232 "TDocumentTest.vala"
					_g_object_unref0 (_tmp76_);
#line 233 "TDocumentTest.vala"
					_tmp79_ = d;
#line 233 "TDocumentTest.vala"
					_tmp80_ = gxml_document_create_element ((GXmlDocument*) _tmp79_, "Email", &_inner_error0_);
#line 233 "TDocumentTest.vala"
					_tmp78_ = _tmp80_;
#line 233 "TDocumentTest.vala"
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 233 "TDocumentTest.vala"
						_g_object_unref0 (name1);
#line 233 "TDocumentTest.vala"
						_g_object_unref0 (_tmp68_);
#line 233 "TDocumentTest.vala"
						_g_object_unref0 (ath1);
#line 233 "TDocumentTest.vala"
						_g_object_unref0 (_tmp59_);
#line 233 "TDocumentTest.vala"
						_g_object_unref0 (aths);
#line 233 "TDocumentTest.vala"
						_g_object_unref0 (_tmp50_);
#line 233 "TDocumentTest.vala"
						_g_object_unref0 (b);
#line 233 "TDocumentTest.vala"
						_g_object_unref0 (_tmp41_);
#line 233 "TDocumentTest.vala"
						_g_object_unref0 (r);
#line 233 "TDocumentTest.vala"
						_g_object_unref0 (e);
#line 233 "TDocumentTest.vala"
						_g_object_unref0 (d);
#line 233 "TDocumentTest.vala"
						_g_object_unref0 (f);
#line 2850 "TDocumentTest.c"
						goto __catch271_g_error;
					}
#line 233 "TDocumentTest.vala"
					_tmp81_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp78_, GXML_TYPE_ELEMENT, GXmlElement));
#line 233 "TDocumentTest.vala"
					email1 = _tmp81_;
#line 234 "TDocumentTest.vala"
					_tmp82_ = email1;
#line 234 "TDocumentTest.vala"
					gxml_element_set_content (_tmp82_, "fweasley@hogwarts.co.uk");
#line 235 "TDocumentTest.vala"
					_tmp83_ = ath1;
#line 235 "TDocumentTest.vala"
					_tmp84_ = gxml_node_get_children_nodes ((GXmlNode*) _tmp83_);
#line 235 "TDocumentTest.vala"
					_tmp85_ = _tmp84_;
#line 235 "TDocumentTest.vala"
					_tmp86_ = _tmp85_;
#line 235 "TDocumentTest.vala"
					_tmp87_ = email1;
#line 235 "TDocumentTest.vala"
					gee_collection_add ((GeeCollection*) _tmp86_, (GXmlNode*) _tmp87_);
#line 235 "TDocumentTest.vala"
					_g_object_unref0 (_tmp86_);
#line 236 "TDocumentTest.vala"
					_tmp89_ = d;
#line 236 "TDocumentTest.vala"
					_tmp90_ = gxml_document_create_element ((GXmlDocument*) _tmp89_, "Author", &_inner_error0_);
#line 236 "TDocumentTest.vala"
					_tmp88_ = _tmp90_;
#line 236 "TDocumentTest.vala"
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 236 "TDocumentTest.vala"
						_g_object_unref0 (email1);
#line 236 "TDocumentTest.vala"
						_g_object_unref0 (_tmp78_);
#line 236 "TDocumentTest.vala"
						_g_object_unref0 (name1);
#line 236 "TDocumentTest.vala"
						_g_object_unref0 (_tmp68_);
#line 236 "TDocumentTest.vala"
						_g_object_unref0 (ath1);
#line 236 "TDocumentTest.vala"
						_g_object_unref0 (_tmp59_);
#line 236 "TDocumentTest.vala"
						_g_object_unref0 (aths);
#line 236 "TDocumentTest.vala"
						_g_object_unref0 (_tmp50_);
#line 236 "TDocumentTest.vala"
						_g_object_unref0 (b);
#line 236 "TDocumentTest.vala"
						_g_object_unref0 (_tmp41_);
#line 236 "TDocumentTest.vala"
						_g_object_unref0 (r);
#line 236 "TDocumentTest.vala"
						_g_object_unref0 (e);
#line 236 "TDocumentTest.vala"
						_g_object_unref0 (d);
#line 236 "TDocumentTest.vala"
						_g_object_unref0 (f);
#line 2911 "TDocumentTest.c"
						goto __catch271_g_error;
					}
#line 236 "TDocumentTest.vala"
					_tmp91_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp88_, GXML_TYPE_ELEMENT, GXmlElement));
#line 236 "TDocumentTest.vala"
					ath2 = _tmp91_;
#line 237 "TDocumentTest.vala"
					_tmp92_ = aths;
#line 237 "TDocumentTest.vala"
					_tmp93_ = gxml_node_get_children_nodes ((GXmlNode*) _tmp92_);
#line 237 "TDocumentTest.vala"
					_tmp94_ = _tmp93_;
#line 237 "TDocumentTest.vala"
					_tmp95_ = _tmp94_;
#line 237 "TDocumentTest.vala"
					_tmp96_ = ath2;
#line 237 "TDocumentTest.vala"
					gee_collection_add ((GeeCollection*) _tmp95_, (GXmlNode*) _tmp96_);
#line 237 "TDocumentTest.vala"
					_g_object_unref0 (_tmp95_);
#line 238 "TDocumentTest.vala"
					_tmp98_ = d;
#line 238 "TDocumentTest.vala"
					_tmp99_ = gxml_document_create_element ((GXmlDocument*) _tmp98_, "Name", &_inner_error0_);
#line 238 "TDocumentTest.vala"
					_tmp97_ = _tmp99_;
#line 238 "TDocumentTest.vala"
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 238 "TDocumentTest.vala"
						_g_object_unref0 (ath2);
#line 238 "TDocumentTest.vala"
						_g_object_unref0 (_tmp88_);
#line 238 "TDocumentTest.vala"
						_g_object_unref0 (email1);
#line 238 "TDocumentTest.vala"
						_g_object_unref0 (_tmp78_);
#line 238 "TDocumentTest.vala"
						_g_object_unref0 (name1);
#line 238 "TDocumentTest.vala"
						_g_object_unref0 (_tmp68_);
#line 238 "TDocumentTest.vala"
						_g_object_unref0 (ath1);
#line 238 "TDocumentTest.vala"
						_g_object_unref0 (_tmp59_);
#line 238 "TDocumentTest.vala"
						_g_object_unref0 (aths);
#line 238 "TDocumentTest.vala"
						_g_object_unref0 (_tmp50_);
#line 238 "TDocumentTest.vala"
						_g_object_unref0 (b);
#line 238 "TDocumentTest.vala"
						_g_object_unref0 (_tmp41_);
#line 238 "TDocumentTest.vala"
						_g_object_unref0 (r);
#line 238 "TDocumentTest.vala"
						_g_object_unref0 (e);
#line 238 "TDocumentTest.vala"
						_g_object_unref0 (d);
#line 238 "TDocumentTest.vala"
						_g_object_unref0 (f);
#line 2972 "TDocumentTest.c"
						goto __catch271_g_error;
					}
#line 238 "TDocumentTest.vala"
					_tmp100_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp97_, GXML_TYPE_ELEMENT, GXmlElement));
#line 238 "TDocumentTest.vala"
					name2 = _tmp100_;
#line 239 "TDocumentTest.vala"
					_tmp101_ = name2;
#line 239 "TDocumentTest.vala"
					gxml_element_set_content (_tmp101_, "Greoge");
#line 240 "TDocumentTest.vala"
					_tmp102_ = ath2;
#line 240 "TDocumentTest.vala"
					_tmp103_ = gxml_node_get_children_nodes ((GXmlNode*) _tmp102_);
#line 240 "TDocumentTest.vala"
					_tmp104_ = _tmp103_;
#line 240 "TDocumentTest.vala"
					_tmp105_ = _tmp104_;
#line 240 "TDocumentTest.vala"
					_tmp106_ = name2;
#line 240 "TDocumentTest.vala"
					gee_collection_add ((GeeCollection*) _tmp105_, (GXmlNode*) _tmp106_);
#line 240 "TDocumentTest.vala"
					_g_object_unref0 (_tmp105_);
#line 241 "TDocumentTest.vala"
					_tmp108_ = d;
#line 241 "TDocumentTest.vala"
					_tmp109_ = gxml_document_create_element ((GXmlDocument*) _tmp108_, "Email", &_inner_error0_);
#line 241 "TDocumentTest.vala"
					_tmp107_ = _tmp109_;
#line 241 "TDocumentTest.vala"
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 241 "TDocumentTest.vala"
						_g_object_unref0 (name2);
#line 241 "TDocumentTest.vala"
						_g_object_unref0 (_tmp97_);
#line 241 "TDocumentTest.vala"
						_g_object_unref0 (ath2);
#line 241 "TDocumentTest.vala"
						_g_object_unref0 (_tmp88_);
#line 241 "TDocumentTest.vala"
						_g_object_unref0 (email1);
#line 241 "TDocumentTest.vala"
						_g_object_unref0 (_tmp78_);
#line 241 "TDocumentTest.vala"
						_g_object_unref0 (name1);
#line 241 "TDocumentTest.vala"
						_g_object_unref0 (_tmp68_);
#line 241 "TDocumentTest.vala"
						_g_object_unref0 (ath1);
#line 241 "TDocumentTest.vala"
						_g_object_unref0 (_tmp59_);
#line 241 "TDocumentTest.vala"
						_g_object_unref0 (aths);
#line 241 "TDocumentTest.vala"
						_g_object_unref0 (_tmp50_);
#line 241 "TDocumentTest.vala"
						_g_object_unref0 (b);
#line 241 "TDocumentTest.vala"
						_g_object_unref0 (_tmp41_);
#line 241 "TDocumentTest.vala"
						_g_object_unref0 (r);
#line 241 "TDocumentTest.vala"
						_g_object_unref0 (e);
#line 241 "TDocumentTest.vala"
						_g_object_unref0 (d);
#line 241 "TDocumentTest.vala"
						_g_object_unref0 (f);
#line 3041 "TDocumentTest.c"
						goto __catch271_g_error;
					}
#line 241 "TDocumentTest.vala"
					_tmp110_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp107_, GXML_TYPE_ELEMENT, GXmlElement));
#line 241 "TDocumentTest.vala"
					email2 = _tmp110_;
#line 242 "TDocumentTest.vala"
					_tmp111_ = email2;
#line 242 "TDocumentTest.vala"
					gxml_element_set_content (_tmp111_, "gweasley@hogwarts.co.uk");
#line 243 "TDocumentTest.vala"
					_tmp112_ = ath2;
#line 243 "TDocumentTest.vala"
					_tmp113_ = gxml_node_get_children_nodes ((GXmlNode*) _tmp112_);
#line 243 "TDocumentTest.vala"
					_tmp114_ = _tmp113_;
#line 243 "TDocumentTest.vala"
					_tmp115_ = _tmp114_;
#line 243 "TDocumentTest.vala"
					_tmp116_ = email2;
#line 243 "TDocumentTest.vala"
					gee_collection_add ((GeeCollection*) _tmp115_, (GXmlNode*) _tmp116_);
#line 243 "TDocumentTest.vala"
					_g_object_unref0 (_tmp115_);
#line 223 "TDocumentTest.vala"
					_g_object_unref0 (email2);
#line 223 "TDocumentTest.vala"
					_g_object_unref0 (_tmp107_);
#line 223 "TDocumentTest.vala"
					_g_object_unref0 (name2);
#line 223 "TDocumentTest.vala"
					_g_object_unref0 (_tmp97_);
#line 223 "TDocumentTest.vala"
					_g_object_unref0 (ath2);
#line 223 "TDocumentTest.vala"
					_g_object_unref0 (_tmp88_);
#line 223 "TDocumentTest.vala"
					_g_object_unref0 (email1);
#line 223 "TDocumentTest.vala"
					_g_object_unref0 (_tmp78_);
#line 223 "TDocumentTest.vala"
					_g_object_unref0 (name1);
#line 223 "TDocumentTest.vala"
					_g_object_unref0 (_tmp68_);
#line 223 "TDocumentTest.vala"
					_g_object_unref0 (ath1);
#line 223 "TDocumentTest.vala"
					_g_object_unref0 (_tmp59_);
#line 223 "TDocumentTest.vala"
					_g_object_unref0 (aths);
#line 223 "TDocumentTest.vala"
					_g_object_unref0 (_tmp50_);
#line 223 "TDocumentTest.vala"
					_g_object_unref0 (b);
#line 223 "TDocumentTest.vala"
					_g_object_unref0 (_tmp41_);
#line 3098 "TDocumentTest.c"
				}
			}
		}
#line 245 "TDocumentTest.vala"
		_tmp117_ = d;
#line 245 "TDocumentTest.vala"
		_tmp118_ = gxml_document_get_root ((GXmlDocument*) _tmp117_);
#line 245 "TDocumentTest.vala"
		_tmp119_ = _tmp118_;
#line 245 "TDocumentTest.vala"
		_tmp120_ = _tmp119_;
#line 245 "TDocumentTest.vala"
		_tmp121_ = gxml_node_get_children_nodes (_tmp120_);
#line 245 "TDocumentTest.vala"
		_tmp122_ = _tmp121_;
#line 245 "TDocumentTest.vala"
		_tmp123_ = _tmp122_;
#line 245 "TDocumentTest.vala"
		_tmp124_ = gee_collection_get_size ((GeeCollection*) _tmp123_);
#line 245 "TDocumentTest.vala"
		_tmp125_ = _tmp124_;
#line 245 "TDocumentTest.vala"
		_vala_assert (_tmp125_ == 5000, "d.root.children_nodes.size == 5000");
#line 245 "TDocumentTest.vala"
		_g_object_unref0 (_tmp123_);
#line 245 "TDocumentTest.vala"
		_g_object_unref0 (_tmp120_);
#line 3126 "TDocumentTest.c"
		{
			GeeBidirList* _n_list = NULL;
			GXmlTDocument* _tmp126_;
			GXmlNode* _tmp127_;
			GXmlNode* _tmp128_;
			GXmlNode* _tmp129_;
			GeeBidirList* _tmp130_;
			GeeBidirList* _tmp131_;
			GeeBidirList* _tmp132_;
			gint _n_size = 0;
			GeeBidirList* _tmp133_;
			gint _tmp134_;
			gint _tmp135_;
			gint _n_index = 0;
#line 246 "TDocumentTest.vala"
			_tmp126_ = d;
#line 246 "TDocumentTest.vala"
			_tmp127_ = gxml_document_get_root ((GXmlDocument*) _tmp126_);
#line 246 "TDocumentTest.vala"
			_tmp128_ = _tmp127_;
#line 246 "TDocumentTest.vala"
			_tmp129_ = _tmp128_;
#line 246 "TDocumentTest.vala"
			_tmp130_ = gxml_node_get_children_nodes (_tmp129_);
#line 246 "TDocumentTest.vala"
			_tmp131_ = _tmp130_;
#line 246 "TDocumentTest.vala"
			_tmp132_ = _tmp131_;
#line 246 "TDocumentTest.vala"
			_g_object_unref0 (_tmp129_);
#line 246 "TDocumentTest.vala"
			_n_list = _tmp132_;
#line 246 "TDocumentTest.vala"
			_tmp133_ = _n_list;
#line 246 "TDocumentTest.vala"
			_tmp134_ = gee_collection_get_size ((GeeCollection*) _tmp133_);
#line 246 "TDocumentTest.vala"
			_tmp135_ = _tmp134_;
#line 246 "TDocumentTest.vala"
			_n_size = _tmp135_;
#line 246 "TDocumentTest.vala"
			_n_index = -1;
#line 246 "TDocumentTest.vala"
			while (TRUE) {
#line 3171 "TDocumentTest.c"
				GXmlNode* n = NULL;
				GeeBidirList* _tmp136_;
				gpointer _tmp137_;
				GXmlNode* _tmp138_;
				GeeBidirList* _tmp139_;
				GeeBidirList* _tmp140_;
				GeeBidirList* _tmp141_;
				gint _tmp142_;
				gint _tmp143_;
#line 246 "TDocumentTest.vala"
				_n_index = _n_index + 1;
#line 246 "TDocumentTest.vala"
				if (!(_n_index < _n_size)) {
#line 246 "TDocumentTest.vala"
					break;
#line 3187 "TDocumentTest.c"
				}
#line 246 "TDocumentTest.vala"
				_tmp136_ = _n_list;
#line 246 "TDocumentTest.vala"
				_tmp137_ = gee_list_get ((GeeList*) _tmp136_, _n_index);
#line 246 "TDocumentTest.vala"
				n = (GXmlNode*) _tmp137_;
#line 247 "TDocumentTest.vala"
				_tmp138_ = n;
#line 247 "TDocumentTest.vala"
				_tmp139_ = gxml_node_get_children_nodes (_tmp138_);
#line 247 "TDocumentTest.vala"
				_tmp140_ = _tmp139_;
#line 247 "TDocumentTest.vala"
				_tmp141_ = _tmp140_;
#line 247 "TDocumentTest.vala"
				_tmp142_ = gee_collection_get_size ((GeeCollection*) _tmp141_);
#line 247 "TDocumentTest.vala"
				_tmp143_ = _tmp142_;
#line 247 "TDocumentTest.vala"
				_vala_assert (_tmp143_ == 1, "n.children_nodes.size == 1");
#line 247 "TDocumentTest.vala"
				_g_object_unref0 (_tmp141_);
#line 3211 "TDocumentTest.c"
				{
					GeeBidirList* _cn_list = NULL;
					GXmlNode* _tmp144_;
					GeeBidirList* _tmp145_;
					GeeBidirList* _tmp146_;
					gint _cn_size = 0;
					GeeBidirList* _tmp147_;
					gint _tmp148_;
					gint _tmp149_;
					gint _cn_index = 0;
#line 248 "TDocumentTest.vala"
					_tmp144_ = n;
#line 248 "TDocumentTest.vala"
					_tmp145_ = gxml_node_get_children_nodes (_tmp144_);
#line 248 "TDocumentTest.vala"
					_tmp146_ = _tmp145_;
#line 248 "TDocumentTest.vala"
					_cn_list = _tmp146_;
#line 248 "TDocumentTest.vala"
					_tmp147_ = _cn_list;
#line 248 "TDocumentTest.vala"
					_tmp148_ = gee_collection_get_size ((GeeCollection*) _tmp147_);
#line 248 "TDocumentTest.vala"
					_tmp149_ = _tmp148_;
#line 248 "TDocumentTest.vala"
					_cn_size = _tmp149_;
#line 248 "TDocumentTest.vala"
					_cn_index = -1;
#line 248 "TDocumentTest.vala"
					while (TRUE) {
#line 3242 "TDocumentTest.c"
						GXmlNode* cn = NULL;
						GeeBidirList* _tmp150_;
						gpointer _tmp151_;
						GXmlNode* _tmp152_;
						GeeBidirList* _tmp153_;
						GeeBidirList* _tmp154_;
						GeeBidirList* _tmp155_;
						gint _tmp156_;
						gint _tmp157_;
#line 248 "TDocumentTest.vala"
						_cn_index = _cn_index + 1;
#line 248 "TDocumentTest.vala"
						if (!(_cn_index < _cn_size)) {
#line 248 "TDocumentTest.vala"
							break;
#line 3258 "TDocumentTest.c"
						}
#line 248 "TDocumentTest.vala"
						_tmp150_ = _cn_list;
#line 248 "TDocumentTest.vala"
						_tmp151_ = gee_list_get ((GeeList*) _tmp150_, _cn_index);
#line 248 "TDocumentTest.vala"
						cn = (GXmlNode*) _tmp151_;
#line 249 "TDocumentTest.vala"
						_tmp152_ = cn;
#line 249 "TDocumentTest.vala"
						_tmp153_ = gxml_node_get_children_nodes (_tmp152_);
#line 249 "TDocumentTest.vala"
						_tmp154_ = _tmp153_;
#line 249 "TDocumentTest.vala"
						_tmp155_ = _tmp154_;
#line 249 "TDocumentTest.vala"
						_tmp156_ = gee_collection_get_size ((GeeCollection*) _tmp155_);
#line 249 "TDocumentTest.vala"
						_tmp157_ = _tmp156_;
#line 249 "TDocumentTest.vala"
						_vala_assert (_tmp157_ == 2, "cn.children_nodes.size == 2");
#line 249 "TDocumentTest.vala"
						_g_object_unref0 (_tmp155_);
#line 3282 "TDocumentTest.c"
						{
							GeeBidirList* _ccn_list = NULL;
							GXmlNode* _tmp158_;
							GeeBidirList* _tmp159_;
							GeeBidirList* _tmp160_;
							gint _ccn_size = 0;
							GeeBidirList* _tmp161_;
							gint _tmp162_;
							gint _tmp163_;
							gint _ccn_index = 0;
#line 250 "TDocumentTest.vala"
							_tmp158_ = cn;
#line 250 "TDocumentTest.vala"
							_tmp159_ = gxml_node_get_children_nodes (_tmp158_);
#line 250 "TDocumentTest.vala"
							_tmp160_ = _tmp159_;
#line 250 "TDocumentTest.vala"
							_ccn_list = _tmp160_;
#line 250 "TDocumentTest.vala"
							_tmp161_ = _ccn_list;
#line 250 "TDocumentTest.vala"
							_tmp162_ = gee_collection_get_size ((GeeCollection*) _tmp161_);
#line 250 "TDocumentTest.vala"
							_tmp163_ = _tmp162_;
#line 250 "TDocumentTest.vala"
							_ccn_size = _tmp163_;
#line 250 "TDocumentTest.vala"
							_ccn_index = -1;
#line 250 "TDocumentTest.vala"
							while (TRUE) {
#line 3313 "TDocumentTest.c"
								GXmlNode* ccn = NULL;
								GeeBidirList* _tmp164_;
								gpointer _tmp165_;
								GXmlNode* _tmp166_;
								GeeBidirList* _tmp167_;
								GeeBidirList* _tmp168_;
								GeeBidirList* _tmp169_;
								gint _tmp170_;
								gint _tmp171_;
#line 250 "TDocumentTest.vala"
								_ccn_index = _ccn_index + 1;
#line 250 "TDocumentTest.vala"
								if (!(_ccn_index < _ccn_size)) {
#line 250 "TDocumentTest.vala"
									break;
#line 3329 "TDocumentTest.c"
								}
#line 250 "TDocumentTest.vala"
								_tmp164_ = _ccn_list;
#line 250 "TDocumentTest.vala"
								_tmp165_ = gee_list_get ((GeeList*) _tmp164_, _ccn_index);
#line 250 "TDocumentTest.vala"
								ccn = (GXmlNode*) _tmp165_;
#line 251 "TDocumentTest.vala"
								_tmp166_ = ccn;
#line 251 "TDocumentTest.vala"
								_tmp167_ = gxml_node_get_children_nodes (_tmp166_);
#line 251 "TDocumentTest.vala"
								_tmp168_ = _tmp167_;
#line 251 "TDocumentTest.vala"
								_tmp169_ = _tmp168_;
#line 251 "TDocumentTest.vala"
								_tmp170_ = gee_collection_get_size ((GeeCollection*) _tmp169_);
#line 251 "TDocumentTest.vala"
								_tmp171_ = _tmp170_;
#line 251 "TDocumentTest.vala"
								_vala_assert (_tmp171_ == 2, "ccn.children_nodes.size == 2");
#line 251 "TDocumentTest.vala"
								_g_object_unref0 (_tmp169_);
#line 250 "TDocumentTest.vala"
								_g_object_unref0 (ccn);
#line 3355 "TDocumentTest.c"
							}
#line 250 "TDocumentTest.vala"
							_g_object_unref0 (_ccn_list);
#line 3359 "TDocumentTest.c"
						}
#line 248 "TDocumentTest.vala"
						_g_object_unref0 (cn);
#line 3363 "TDocumentTest.c"
					}
#line 248 "TDocumentTest.vala"
					_g_object_unref0 (_cn_list);
#line 3367 "TDocumentTest.c"
				}
#line 246 "TDocumentTest.vala"
				_g_object_unref0 (n);
#line 3371 "TDocumentTest.c"
			}
#line 246 "TDocumentTest.vala"
			_g_object_unref0 (_n_list);
#line 3375 "TDocumentTest.c"
		}
#line 202 "TDocumentTest.vala"
		_g_object_unref0 (r);
#line 202 "TDocumentTest.vala"
		_g_object_unref0 (e);
#line 202 "TDocumentTest.vala"
		_g_object_unref0 (d);
#line 202 "TDocumentTest.vala"
		_g_object_unref0 (f);
#line 3385 "TDocumentTest.c"
	}
	goto __finally271;
	__catch271_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp172_;
		const gchar* _tmp173_;
		gchar* _tmp174_;
		gchar* _tmp175_;
#line 202 "TDocumentTest.vala"
		e = _inner_error0_;
#line 202 "TDocumentTest.vala"
		_inner_error0_ = NULL;
#line 257 "TDocumentTest.vala"
		_tmp172_ = e->message;
#line 257 "TDocumentTest.vala"
		_tmp173_ = string_to_string (_tmp172_);
#line 257 "TDocumentTest.vala"
		_tmp174_ = g_strconcat ("ERROR: ", _tmp173_, NULL);
#line 257 "TDocumentTest.vala"
		_tmp175_ = _tmp174_;
#line 257 "TDocumentTest.vala"
		g_message ("TDocumentTest.vala:257: %s", _tmp175_);
#line 257 "TDocumentTest.vala"
		_g_free0 (_tmp175_);
#line 258 "TDocumentTest.vala"
		g_assert_not_reached ();
#line 202 "TDocumentTest.vala"
		_g_error_free0 (e);
#line 3415 "TDocumentTest.c"
	}
	__finally271:
#line 202 "TDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 202 "TDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 202 "TDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 202 "TDocumentTest.vala"
		return;
#line 3426 "TDocumentTest.c"
	}
}

static void
___lambda214__gtest_func (void)
{
#line 198 "TDocumentTest.vala"
	__lambda214_ ();
#line 3435 "TDocumentTest.c"
}

static void
__lambda215_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GFile* f = NULL;
		GFile* _tmp0_;
		GFile* _tmp1_;
		TDocumentTestTTestObject* ot = NULL;
		TDocumentTestTTestObject* _tmp3_;
		TDocumentTestTTestObject* _tmp4_;
		GXmlTDocument* dt = NULL;
		GXmlTDocument* _tmp5_;
		TDocumentTestTTestObject* _tmp6_;
		GXmlTDocument* _tmp7_;
		GXmlNode* _tmp8_;
		GXmlNode* _tmp9_;
		GXmlTDocument* _tmp10_;
		GFile* _tmp11_;
		GXmlTDocument* d = NULL;
		GXmlTDocument* _tmp12_;
		GXmlNode* e = NULL;
		GXmlTDocument* _tmp13_;
		GXmlNode* _tmp14_;
		GXmlTDocument* _tmp15_;
		GeeBidirList* _tmp16_;
		GeeBidirList* _tmp17_;
		GeeBidirList* _tmp18_;
		GXmlNode* _tmp19_;
		GXmlTDocument* _tmp20_;
		GeeBidirList* _tmp21_;
		GeeBidirList* _tmp22_;
		GeeBidirList* _tmp23_;
		gint _tmp24_;
		gint _tmp25_;
		GXmlTDocument* _tmp26_;
		GXmlNode* _tmp27_;
		GXmlNode* _tmp28_;
		GXmlNode* _tmp29_;
		GXmlTDocument* _tmp30_;
		GXmlNode* _tmp31_;
		GXmlNode* _tmp32_;
		GXmlNode* _tmp33_;
		gchar* _tmp34_;
		gchar* _tmp35_;
		gchar* _tmp36_;
		GXmlTDocument* _tmp37_;
		GXmlNode* _tmp38_;
		GXmlNode* _tmp39_;
		GXmlNode* _tmp40_;
		gchar* _tmp41_;
		gchar* _tmp42_;
		gchar* _tmp43_;
		GXmlTDocument* _tmp44_;
		GFile* _tmp45_;
		GFile* _tmp46_;
		GFile* bf = NULL;
		GFile* _tmp47_;
		GFile* _tmp48_;
		GFileInputStream* istream = NULL;
		GFile* _tmp49_;
		GFileInputStream* _tmp50_;
		GMemoryOutputStream* b = NULL;
		GMemoryOutputStream* _tmp51_;
		GMemoryOutputStream* _tmp52_;
		GFileInputStream* _tmp53_;
		GMemoryOutputStream* _tmp54_;
		void* _tmp55_;
		void* _tmp56_;
		GMemoryOutputStream* _tmp57_;
		void* _tmp58_;
		void* _tmp59_;
		GFile* _tmp60_;
		GFile* _tmp61_;
#line 331 "TDocumentTest.vala"
		_tmp0_ = g_file_new_for_path (TEST_SAVE_DIR "/t-test.xml");
#line 331 "TDocumentTest.vala"
		f = _tmp0_;
#line 332 "TDocumentTest.vala"
		_tmp1_ = f;
#line 332 "TDocumentTest.vala"
		if (g_file_query_exists (_tmp1_, NULL)) {
#line 3520 "TDocumentTest.c"
			GFile* _tmp2_;
#line 332 "TDocumentTest.vala"
			_tmp2_ = f;
#line 332 "TDocumentTest.vala"
			g_file_delete (_tmp2_, NULL, &_inner_error0_);
#line 332 "TDocumentTest.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 332 "TDocumentTest.vala"
				_g_object_unref0 (f);
#line 3530 "TDocumentTest.c"
				goto __catch272_g_error;
			}
		}
#line 333 "TDocumentTest.vala"
		_tmp3_ = tdocument_test_ttest_object_new ();
#line 333 "TDocumentTest.vala"
		ot = _tmp3_;
#line 334 "TDocumentTest.vala"
		_tmp4_ = ot;
#line 334 "TDocumentTest.vala"
		tdocument_test_ttest_object_set_name (_tmp4_, "test1");
#line 335 "TDocumentTest.vala"
		_tmp5_ = gxml_tdocument_new ();
#line 335 "TDocumentTest.vala"
		dt = _tmp5_;
#line 336 "TDocumentTest.vala"
		_tmp6_ = ot;
#line 336 "TDocumentTest.vala"
		_tmp7_ = dt;
#line 336 "TDocumentTest.vala"
		_tmp8_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp6_, (GXmlNode*) _tmp7_, &_inner_error0_);
#line 336 "TDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 336 "TDocumentTest.vala"
		_g_object_unref0 (_tmp9_);
#line 336 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 336 "TDocumentTest.vala"
			_g_object_unref0 (dt);
#line 336 "TDocumentTest.vala"
			_g_object_unref0 (ot);
#line 336 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 3564 "TDocumentTest.c"
			goto __catch272_g_error;
		}
#line 337 "TDocumentTest.vala"
		_tmp10_ = dt;
#line 337 "TDocumentTest.vala"
		_tmp11_ = f;
#line 337 "TDocumentTest.vala"
		gxml_document_save_as ((GXmlDocument*) _tmp10_, _tmp11_, NULL, &_inner_error0_);
#line 337 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 337 "TDocumentTest.vala"
			_g_object_unref0 (dt);
#line 337 "TDocumentTest.vala"
			_g_object_unref0 (ot);
#line 337 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 3581 "TDocumentTest.c"
			goto __catch272_g_error;
		}
#line 338 "TDocumentTest.vala"
		_tmp12_ = gxml_tdocument_new ();
#line 338 "TDocumentTest.vala"
		d = _tmp12_;
#line 339 "TDocumentTest.vala"
		_tmp13_ = d;
#line 339 "TDocumentTest.vala"
		_tmp14_ = gxml_document_create_element ((GXmlDocument*) _tmp13_, "root", &_inner_error0_);
#line 339 "TDocumentTest.vala"
		e = _tmp14_;
#line 339 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 339 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 339 "TDocumentTest.vala"
			_g_object_unref0 (dt);
#line 339 "TDocumentTest.vala"
			_g_object_unref0 (ot);
#line 339 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 3604 "TDocumentTest.c"
			goto __catch272_g_error;
		}
#line 340 "TDocumentTest.vala"
		_tmp15_ = d;
#line 340 "TDocumentTest.vala"
		_tmp16_ = gxml_tnode_get_children_nodes ((GXmlTNode*) _tmp15_);
#line 340 "TDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 340 "TDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 340 "TDocumentTest.vala"
		_tmp19_ = e;
#line 340 "TDocumentTest.vala"
		gee_collection_add ((GeeCollection*) _tmp18_, _tmp19_);
#line 340 "TDocumentTest.vala"
		_g_object_unref0 (_tmp18_);
#line 341 "TDocumentTest.vala"
		_tmp20_ = d;
#line 341 "TDocumentTest.vala"
		_tmp21_ = gxml_tnode_get_children_nodes ((GXmlTNode*) _tmp20_);
#line 341 "TDocumentTest.vala"
		_tmp22_ = _tmp21_;
#line 341 "TDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 341 "TDocumentTest.vala"
		_tmp24_ = gee_collection_get_size ((GeeCollection*) _tmp23_);
#line 341 "TDocumentTest.vala"
		_tmp25_ = _tmp24_;
#line 341 "TDocumentTest.vala"
		_vala_assert (_tmp25_ == 1, "d.children_nodes.size == 1");
#line 341 "TDocumentTest.vala"
		_g_object_unref0 (_tmp23_);
#line 342 "TDocumentTest.vala"
		_tmp26_ = d;
#line 342 "TDocumentTest.vala"
		_tmp27_ = gxml_document_get_root ((GXmlDocument*) _tmp26_);
#line 342 "TDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 342 "TDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 342 "TDocumentTest.vala"
		_vala_assert (_tmp29_ != NULL, "d.root != null");
#line 342 "TDocumentTest.vala"
		_g_object_unref0 (_tmp29_);
#line 343 "TDocumentTest.vala"
		_tmp30_ = d;
#line 343 "TDocumentTest.vala"
		_tmp31_ = gxml_document_get_root ((GXmlDocument*) _tmp30_);
#line 343 "TDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 343 "TDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 343 "TDocumentTest.vala"
		_tmp34_ = gxml_node_get_name (_tmp33_);
#line 343 "TDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 343 "TDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 343 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp36_, "root") == 0, "d.root.name == \"root\"");
#line 343 "TDocumentTest.vala"
		_g_free0 (_tmp36_);
#line 343 "TDocumentTest.vala"
		_g_object_unref0 (_tmp33_);
#line 344 "TDocumentTest.vala"
		_tmp37_ = d;
#line 344 "TDocumentTest.vala"
		_tmp38_ = gxml_document_get_root ((GXmlDocument*) _tmp37_);
#line 344 "TDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 344 "TDocumentTest.vala"
		_tmp40_ = _tmp39_;
#line 344 "TDocumentTest.vala"
		_tmp41_ = gxml_node_get_value (_tmp40_);
#line 344 "TDocumentTest.vala"
		_tmp42_ = _tmp41_;
#line 344 "TDocumentTest.vala"
		_tmp43_ = _tmp42_;
#line 344 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp43_, "") == 0, "d.root.value == \"\"");
#line 344 "TDocumentTest.vala"
		_g_free0 (_tmp43_);
#line 344 "TDocumentTest.vala"
		_g_object_unref0 (_tmp40_);
#line 345 "TDocumentTest.vala"
		_tmp44_ = d;
#line 345 "TDocumentTest.vala"
		_tmp45_ = f;
#line 345 "TDocumentTest.vala"
		gxml_document_save_as ((GXmlDocument*) _tmp44_, _tmp45_, NULL, &_inner_error0_);
#line 345 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 345 "TDocumentTest.vala"
			_g_object_unref0 (e);
#line 345 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 345 "TDocumentTest.vala"
			_g_object_unref0 (dt);
#line 345 "TDocumentTest.vala"
			_g_object_unref0 (ot);
#line 345 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 3707 "TDocumentTest.c"
			goto __catch272_g_error;
		}
#line 346 "TDocumentTest.vala"
		_tmp46_ = f;
#line 346 "TDocumentTest.vala"
		_vala_assert (g_file_query_exists (_tmp46_, NULL), "f.query_exists ()");
#line 347 "TDocumentTest.vala"
		_tmp47_ = g_file_new_for_path (TEST_SAVE_DIR "/t-test.xml~");
#line 347 "TDocumentTest.vala"
		bf = _tmp47_;
#line 348 "TDocumentTest.vala"
		_tmp48_ = bf;
#line 348 "TDocumentTest.vala"
		_vala_assert (g_file_query_exists (_tmp48_, NULL), "bf.query_exists ()");
#line 349 "TDocumentTest.vala"
		_tmp49_ = f;
#line 349 "TDocumentTest.vala"
		_tmp50_ = g_file_read (_tmp49_, NULL, &_inner_error0_);
#line 349 "TDocumentTest.vala"
		istream = _tmp50_;
#line 349 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 349 "TDocumentTest.vala"
			_g_object_unref0 (bf);
#line 349 "TDocumentTest.vala"
			_g_object_unref0 (e);
#line 349 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 349 "TDocumentTest.vala"
			_g_object_unref0 (dt);
#line 349 "TDocumentTest.vala"
			_g_object_unref0 (ot);
#line 349 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 3742 "TDocumentTest.c"
			goto __catch272_g_error;
		}
#line 350 "TDocumentTest.vala"
		_tmp51_ = (GMemoryOutputStream*) g_memory_output_stream_new_resizable ();
#line 350 "TDocumentTest.vala"
		b = _tmp51_;
#line 351 "TDocumentTest.vala"
		_tmp52_ = b;
#line 351 "TDocumentTest.vala"
		_tmp53_ = istream;
#line 351 "TDocumentTest.vala"
		g_output_stream_splice ((GOutputStream*) _tmp52_, (GInputStream*) _tmp53_, 0, NULL, &_inner_error0_);
#line 351 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 351 "TDocumentTest.vala"
			_g_object_unref0 (b);
#line 351 "TDocumentTest.vala"
			_g_object_unref0 (istream);
#line 351 "TDocumentTest.vala"
			_g_object_unref0 (bf);
#line 351 "TDocumentTest.vala"
			_g_object_unref0 (e);
#line 351 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 351 "TDocumentTest.vala"
			_g_object_unref0 (dt);
#line 351 "TDocumentTest.vala"
			_g_object_unref0 (ot);
#line 351 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 3773 "TDocumentTest.c"
			goto __catch272_g_error;
		}
#line 352 "TDocumentTest.vala"
		_tmp54_ = b;
#line 352 "TDocumentTest.vala"
		_tmp55_ = g_memory_output_stream_get_data (_tmp54_);
#line 352 "TDocumentTest.vala"
		_tmp56_ = _tmp55_;
#line 352 "TDocumentTest.vala"
		_vala_assert (string_contains ((const gchar*) _tmp56_, "<?xml version=\"1.0\"?>"), "\"<?xml version=\\\"1.0\\\"?>\" in ((string)b.data)");
#line 353 "TDocumentTest.vala"
		_tmp57_ = b;
#line 353 "TDocumentTest.vala"
		_tmp58_ = g_memory_output_stream_get_data (_tmp57_);
#line 353 "TDocumentTest.vala"
		_tmp59_ = _tmp58_;
#line 353 "TDocumentTest.vala"
		_vala_assert (string_contains ((const gchar*) _tmp59_, "<root/>"), "\"<root/>\" in ((string)b.data)");
#line 354 "TDocumentTest.vala"
		_tmp60_ = f;
#line 354 "TDocumentTest.vala"
		g_file_delete (_tmp60_, NULL, &_inner_error0_);
#line 354 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 354 "TDocumentTest.vala"
			_g_object_unref0 (b);
#line 354 "TDocumentTest.vala"
			_g_object_unref0 (istream);
#line 354 "TDocumentTest.vala"
			_g_object_unref0 (bf);
#line 354 "TDocumentTest.vala"
			_g_object_unref0 (e);
#line 354 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 354 "TDocumentTest.vala"
			_g_object_unref0 (dt);
#line 354 "TDocumentTest.vala"
			_g_object_unref0 (ot);
#line 354 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 3814 "TDocumentTest.c"
			goto __catch272_g_error;
		}
#line 355 "TDocumentTest.vala"
		_tmp61_ = bf;
#line 355 "TDocumentTest.vala"
		g_file_delete (_tmp61_, NULL, &_inner_error0_);
#line 355 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 355 "TDocumentTest.vala"
			_g_object_unref0 (b);
#line 355 "TDocumentTest.vala"
			_g_object_unref0 (istream);
#line 355 "TDocumentTest.vala"
			_g_object_unref0 (bf);
#line 355 "TDocumentTest.vala"
			_g_object_unref0 (e);
#line 355 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 355 "TDocumentTest.vala"
			_g_object_unref0 (dt);
#line 355 "TDocumentTest.vala"
			_g_object_unref0 (ot);
#line 355 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 3839 "TDocumentTest.c"
			goto __catch272_g_error;
		}
#line 330 "TDocumentTest.vala"
		_g_object_unref0 (b);
#line 330 "TDocumentTest.vala"
		_g_object_unref0 (istream);
#line 330 "TDocumentTest.vala"
		_g_object_unref0 (bf);
#line 330 "TDocumentTest.vala"
		_g_object_unref0 (e);
#line 330 "TDocumentTest.vala"
		_g_object_unref0 (d);
#line 330 "TDocumentTest.vala"
		_g_object_unref0 (dt);
#line 330 "TDocumentTest.vala"
		_g_object_unref0 (ot);
#line 330 "TDocumentTest.vala"
		_g_object_unref0 (f);
#line 3858 "TDocumentTest.c"
	}
	goto __finally272;
	__catch272_g_error:
	{
		GError* e = NULL;
#line 330 "TDocumentTest.vala"
		e = _inner_error0_;
#line 330 "TDocumentTest.vala"
		_inner_error0_ = NULL;
#line 361 "TDocumentTest.vala"
		g_assert_not_reached ();
#line 330 "TDocumentTest.vala"
		_g_error_free0 (e);
#line 3872 "TDocumentTest.c"
	}
	__finally272:
#line 330 "TDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 330 "TDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 330 "TDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 330 "TDocumentTest.vala"
		return;
#line 3883 "TDocumentTest.c"
	}
}

static void
___lambda215__gtest_func (void)
{
#line 329 "TDocumentTest.vala"
	__lambda215_ ();
#line 3892 "TDocumentTest.c"
}

static void
__lambda216_ (void)
{
	GXmlTDocument* doc = NULL;
	GXmlTDocument* _tmp0_;
	GError* _inner_error0_ = NULL;
#line 365 "TDocumentTest.vala"
	_tmp0_ = gxml_tdocument_new ();
#line 365 "TDocumentTest.vala"
	doc = _tmp0_;
#line 3905 "TDocumentTest.c"
	{
		GXmlNode* r = NULL;
		GXmlNode* _tmp1_;
		GeeBidirList* _tmp2_;
		GeeBidirList* _tmp3_;
		GeeBidirList* _tmp4_;
		gchar* str = NULL;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
#line 367 "TDocumentTest.vala"
		_tmp1_ = gxml_document_create_element ((GXmlDocument*) doc, "root", &_inner_error0_);
#line 367 "TDocumentTest.vala"
		r = _tmp1_;
#line 367 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 3922 "TDocumentTest.c"
			goto __catch273_g_error;
		}
#line 368 "TDocumentTest.vala"
		_tmp2_ = gxml_tnode_get_children_nodes ((GXmlTNode*) doc);
#line 368 "TDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 368 "TDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 368 "TDocumentTest.vala"
		gee_collection_add ((GeeCollection*) _tmp4_, r);
#line 368 "TDocumentTest.vala"
		_g_object_unref0 (_tmp4_);
#line 372 "TDocumentTest.vala"
		_tmp5_ = gxml_tnode_to_string ((GXmlTNode*) doc);
#line 372 "TDocumentTest.vala"
		str = _tmp5_;
#line 373 "TDocumentTest.vala"
		_vala_assert (string_contains (str, "<?xml version=\"1.0\"?>"), "\"<?xml version=\\\"1.0\\\"?>\" in str");
#line 374 "TDocumentTest.vala"
		_vala_assert (string_contains (str, "<root/>"), "\"<root/>\" in str");
#line 375 "TDocumentTest.vala"
		_tmp6_ = gxml_tnode_to_string ((GXmlTNode*) doc);
#line 375 "TDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 375 "TDocumentTest.vala"
		_vala_assert (string_contains (_tmp7_, "<root/>"), "\"<root/>\" in doc.to_string ()");
#line 375 "TDocumentTest.vala"
		_g_free0 (_tmp7_);
#line 366 "TDocumentTest.vala"
		_g_free0 (str);
#line 366 "TDocumentTest.vala"
		_g_object_unref0 (r);
#line 3955 "TDocumentTest.c"
	}
	goto __finally273;
	__catch273_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp8_;
#line 366 "TDocumentTest.vala"
		e = _inner_error0_;
#line 366 "TDocumentTest.vala"
		_inner_error0_ = NULL;
#line 377 "TDocumentTest.vala"
		_tmp8_ = e->message;
#line 377 "TDocumentTest.vala"
		g_test_message ("%s", _tmp8_);
#line 378 "TDocumentTest.vala"
		g_assert_not_reached ();
#line 366 "TDocumentTest.vala"
		_g_error_free0 (e);
#line 3974 "TDocumentTest.c"
	}
	__finally273:
#line 366 "TDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 366 "TDocumentTest.vala"
		_g_object_unref0 (doc);
#line 366 "TDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 366 "TDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 366 "TDocumentTest.vala"
		return;
#line 3987 "TDocumentTest.c"
	}
#line 364 "TDocumentTest.vala"
	_g_object_unref0 (doc);
#line 3991 "TDocumentTest.c"
}

static void
___lambda216__gtest_func (void)
{
#line 364 "TDocumentTest.vala"
	__lambda216_ ();
#line 3999 "TDocumentTest.c"
}

static void
__lambda217_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlTDocument* doc = NULL;
		GXmlTDocument* _tmp0_;
		GXmlNode* _tmp1_ = NULL;
		GXmlTDocument* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlTDocument* _tmp4_;
		GeeBidirList* _tmp5_;
		GeeBidirList* _tmp6_;
		GeeBidirList* _tmp7_;
		GXmlTDocument* _tmp8_;
		GXmlTDocument* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		GXmlTDocument* _tmp14_;
		GXmlNode* _tmp15_;
		GXmlNode* _tmp16_;
		GXmlNode* _tmp17_;
		GXmlTDocument* _tmp18_;
		GeeList* _tmp19_;
		GeeList* _tmp20_;
		GeeList* _tmp21_;
		GXmlTDocument* _tmp22_;
		GeeList* _tmp23_;
		GeeList* _tmp24_;
		GeeList* _tmp25_;
		gint _tmp26_;
		gint _tmp27_;
		GXmlTDocument* _tmp28_;
		GeeList* _tmp29_;
		GeeList* _tmp30_;
		GeeList* _tmp31_;
		gpointer _tmp32_;
		GXmlNamespace* _tmp33_;
		gchar* _tmp34_;
		gchar* _tmp35_;
		gchar* _tmp36_;
		GXmlTDocument* _tmp37_;
		GeeList* _tmp38_;
		GeeList* _tmp39_;
		GeeList* _tmp40_;
		gpointer _tmp41_;
		GXmlNamespace* _tmp42_;
		gchar* _tmp43_;
		gchar* _tmp44_;
		gchar* _tmp45_;
		GXmlNode* _tmp46_ = NULL;
		GXmlTDocument* _tmp47_;
		GXmlNode* _tmp48_;
		GXmlTDocument* _tmp49_;
		GXmlNode* _tmp50_;
		GXmlNode* _tmp51_;
		GXmlNode* _tmp52_;
		GeeBidirList* _tmp53_;
		GeeBidirList* _tmp54_;
		GeeBidirList* _tmp55_;
		GXmlTDocument* _tmp56_;
		GXmlNode* _tmp57_;
		GXmlNode* _tmp58_;
		GXmlNode* _tmp59_;
		GeeBidirList* _tmp60_;
		GeeBidirList* _tmp61_;
		GeeBidirList* _tmp62_;
		GXmlTDocument* _tmp63_;
		GXmlNode* _tmp64_;
		GXmlNode* _tmp65_;
		GXmlNode* _tmp66_;
		GeeBidirList* _tmp67_;
		GeeBidirList* _tmp68_;
		GeeBidirList* _tmp69_;
		gint _tmp70_;
		gint _tmp71_;
		GXmlNode* c = NULL;
		GXmlTDocument* _tmp72_;
		GXmlNode* _tmp73_;
		GXmlNode* _tmp74_;
		GXmlNode* _tmp75_;
		GeeBidirList* _tmp76_;
		GeeBidirList* _tmp77_;
		GeeBidirList* _tmp78_;
		gpointer _tmp79_;
		GXmlNode* _tmp80_;
		GeeList* _tmp81_;
		GeeList* _tmp82_;
		GeeList* _tmp83_;
		GeeList* _tmp84_;
		GeeList* _tmp85_;
		GeeList* _tmp86_;
		gint _tmp87_;
		gint _tmp88_;
		GeeList* _tmp89_;
		GeeList* _tmp90_;
		GeeList* _tmp91_;
		gpointer _tmp92_;
		GXmlNamespace* _tmp93_;
		gchar* _tmp94_;
		gchar* _tmp95_;
		gchar* _tmp96_;
		GeeList* _tmp97_;
		GeeList* _tmp98_;
		GeeList* _tmp99_;
		gpointer _tmp100_;
		GXmlNamespace* _tmp101_;
		gchar* _tmp102_;
		gchar* _tmp103_;
		gchar* _tmp104_;
		GXmlNode* p = NULL;
		GXmlNode* _tmp105_;
		GXmlTDocument* _tmp106_;
		gchar* _tmp107_;
		gchar* _tmp108_;
		gchar* _tmp109_;
		gchar* _tmp110_;
		gchar** str = NULL;
		GXmlTDocument* _tmp111_;
		gchar* _tmp112_;
		gchar* _tmp113_;
		gchar** _tmp114_;
		gchar** _tmp115_;
		gchar** _tmp116_;
		gint _tmp116__length1;
		gint str_length1;
		gint _str_size_;
		gchar** _tmp117_;
		gint _tmp117__length1;
		const gchar* _tmp118_;
		GXmlTDocument* _tmp119_;
		GeeList* _tmp120_;
		GeeList* _tmp121_;
		GeeList* _tmp122_;
		gpointer _tmp123_;
		GXmlNamespace* _tmp124_;
		gchar* _tmp125_;
		gchar* _tmp126_;
		gchar* _tmp127_;
		GXmlTDocument* _tmp128_;
		GeeList* _tmp129_;
		GeeList* _tmp130_;
		GeeList* _tmp131_;
		gpointer _tmp132_;
		GXmlNamespace* _tmp133_;
		gchar* _tmp134_;
		gchar* _tmp135_;
		gchar* _tmp136_;
		gchar* _tmp137_;
		gchar* _tmp138_;
		GXmlTDocument* _tmp139_;
		GeeList* _tmp140_;
		GeeList* _tmp141_;
		GeeList* _tmp142_;
		gpointer _tmp143_;
		GXmlNamespace* _tmp144_;
		gchar* _tmp145_;
		gchar* _tmp146_;
		gchar* _tmp147_;
		gchar* _tmp148_;
		gchar* _tmp149_;
		GXmlTDocument* _tmp150_;
		GXmlNode* _tmp151_;
		GXmlNode* _tmp152_;
		GXmlNode* _tmp153_;
		gchar* _tmp154_;
		gchar* _tmp155_;
		gchar* _tmp156_;
		gchar* _tmp157_;
		GeeMap* _tmp158_;
		GeeMap* _tmp159_;
		GeeMap* _tmp160_;
		gint _tmp161_;
		gint _tmp162_;
		GXmlNode* pt = NULL;
		GeeMap* _tmp163_;
		GeeMap* _tmp164_;
		GeeMap* _tmp165_;
		gpointer _tmp166_;
		GXmlNode* _tmp167_;
		GXmlTDocument* _tmp168_;
		gchar* _tmp169_;
		gchar* _tmp170_;
		gchar** _tmp171_;
		gchar** _tmp172_;
		gchar** _tmp173_;
		gint _tmp173__length1;
		const gchar* _tmp174_;
#line 383 "TDocumentTest.vala"
		_tmp0_ = gxml_tdocument_new ();
#line 383 "TDocumentTest.vala"
		doc = _tmp0_;
#line 384 "TDocumentTest.vala"
		_tmp2_ = doc;
#line 384 "TDocumentTest.vala"
		_tmp3_ = gxml_document_create_element ((GXmlDocument*) _tmp2_, "root", &_inner_error0_);
#line 384 "TDocumentTest.vala"
		_tmp1_ = _tmp3_;
#line 384 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 384 "TDocumentTest.vala"
			_g_object_unref0 (doc);
#line 4206 "TDocumentTest.c"
			goto __catch274_g_error;
		}
#line 384 "TDocumentTest.vala"
		_tmp4_ = doc;
#line 384 "TDocumentTest.vala"
		_tmp5_ = gxml_tnode_get_children_nodes ((GXmlTNode*) _tmp4_);
#line 384 "TDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 384 "TDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 384 "TDocumentTest.vala"
		gee_collection_add ((GeeCollection*) _tmp7_, _tmp1_);
#line 384 "TDocumentTest.vala"
		_g_object_unref0 (_tmp7_);
#line 385 "TDocumentTest.vala"
		_tmp8_ = doc;
#line 385 "TDocumentTest.vala"
		gxml_tnode_set_namespace ((GXmlTNode*) _tmp8_, "http://www.gnome.org/GXml", "gxml");
#line 386 "TDocumentTest.vala"
		_tmp9_ = doc;
#line 386 "TDocumentTest.vala"
		_tmp10_ = gxml_tnode_to_string ((GXmlTNode*) _tmp9_);
#line 386 "TDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 386 "TDocumentTest.vala"
		_tmp12_ = g_strconcat ("ROOT: ", _tmp11_, NULL);
#line 386 "TDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 386 "TDocumentTest.vala"
		g_test_message ("%s", _tmp13_);
#line 386 "TDocumentTest.vala"
		_g_free0 (_tmp13_);
#line 386 "TDocumentTest.vala"
		_g_free0 (_tmp11_);
#line 387 "TDocumentTest.vala"
		_tmp14_ = doc;
#line 387 "TDocumentTest.vala"
		_tmp15_ = gxml_document_get_root ((GXmlDocument*) _tmp14_);
#line 387 "TDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 387 "TDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 387 "TDocumentTest.vala"
		_vala_assert (_tmp17_ != NULL, "doc.root != null");
#line 387 "TDocumentTest.vala"
		_g_object_unref0 (_tmp17_);
#line 388 "TDocumentTest.vala"
		_tmp18_ = doc;
#line 388 "TDocumentTest.vala"
		_tmp19_ = gxml_tnode_get_namespaces ((GXmlTNode*) _tmp18_);
#line 388 "TDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 388 "TDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 388 "TDocumentTest.vala"
		_vala_assert (_tmp21_ != NULL, "doc.namespaces != null");
#line 388 "TDocumentTest.vala"
		_g_object_unref0 (_tmp21_);
#line 389 "TDocumentTest.vala"
		_tmp22_ = doc;
#line 389 "TDocumentTest.vala"
		_tmp23_ = gxml_tnode_get_namespaces ((GXmlTNode*) _tmp22_);
#line 389 "TDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 389 "TDocumentTest.vala"
		_tmp25_ = _tmp24_;
#line 389 "TDocumentTest.vala"
		_tmp26_ = gee_collection_get_size ((GeeCollection*) _tmp25_);
#line 389 "TDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 389 "TDocumentTest.vala"
		_vala_assert (_tmp27_ == 1, "doc.namespaces.size == 1");
#line 389 "TDocumentTest.vala"
		_g_object_unref0 (_tmp25_);
#line 390 "TDocumentTest.vala"
		_tmp28_ = doc;
#line 390 "TDocumentTest.vala"
		_tmp29_ = gxml_tnode_get_namespaces ((GXmlTNode*) _tmp28_);
#line 390 "TDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 390 "TDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 390 "TDocumentTest.vala"
		_tmp32_ = gee_list_get (_tmp31_, 0);
#line 390 "TDocumentTest.vala"
		_tmp33_ = (GXmlNamespace*) _tmp32_;
#line 390 "TDocumentTest.vala"
		_tmp34_ = gxml_namespace_get_prefix (_tmp33_);
#line 390 "TDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 390 "TDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 390 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp36_, "gxml") == 0, "doc.namespaces[0].prefix == \"gxml\"");
#line 390 "TDocumentTest.vala"
		_g_free0 (_tmp36_);
#line 390 "TDocumentTest.vala"
		_g_object_unref0 (_tmp33_);
#line 390 "TDocumentTest.vala"
		_g_object_unref0 (_tmp31_);
#line 391 "TDocumentTest.vala"
		_tmp37_ = doc;
#line 391 "TDocumentTest.vala"
		_tmp38_ = gxml_tnode_get_namespaces ((GXmlTNode*) _tmp37_);
#line 391 "TDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 391 "TDocumentTest.vala"
		_tmp40_ = _tmp39_;
#line 391 "TDocumentTest.vala"
		_tmp41_ = gee_list_get (_tmp40_, 0);
#line 391 "TDocumentTest.vala"
		_tmp42_ = (GXmlNamespace*) _tmp41_;
#line 391 "TDocumentTest.vala"
		_tmp43_ = gxml_namespace_get_uri (_tmp42_);
#line 391 "TDocumentTest.vala"
		_tmp44_ = _tmp43_;
#line 391 "TDocumentTest.vala"
		_tmp45_ = _tmp44_;
#line 391 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp45_, "http://www.gnome.org/GXml") == 0, "doc.namespaces[0].uri == \"http://www.gnome.org/GXml\"");
#line 391 "TDocumentTest.vala"
		_g_free0 (_tmp45_);
#line 391 "TDocumentTest.vala"
		_g_object_unref0 (_tmp42_);
#line 391 "TDocumentTest.vala"
		_g_object_unref0 (_tmp40_);
#line 392 "TDocumentTest.vala"
		_tmp47_ = doc;
#line 392 "TDocumentTest.vala"
		_tmp48_ = gxml_document_create_element ((GXmlDocument*) _tmp47_, "child", &_inner_error0_);
#line 392 "TDocumentTest.vala"
		_tmp46_ = _tmp48_;
#line 392 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 392 "TDocumentTest.vala"
			_g_object_unref0 (_tmp1_);
#line 392 "TDocumentTest.vala"
			_g_object_unref0 (doc);
#line 4345 "TDocumentTest.c"
			goto __catch274_g_error;
		}
#line 392 "TDocumentTest.vala"
		_tmp49_ = doc;
#line 392 "TDocumentTest.vala"
		_tmp50_ = gxml_document_get_root ((GXmlDocument*) _tmp49_);
#line 392 "TDocumentTest.vala"
		_tmp51_ = _tmp50_;
#line 392 "TDocumentTest.vala"
		_tmp52_ = _tmp51_;
#line 392 "TDocumentTest.vala"
		_tmp53_ = gxml_node_get_children_nodes (_tmp52_);
#line 392 "TDocumentTest.vala"
		_tmp54_ = _tmp53_;
#line 392 "TDocumentTest.vala"
		_tmp55_ = _tmp54_;
#line 392 "TDocumentTest.vala"
		gee_collection_add ((GeeCollection*) _tmp55_, _tmp46_);
#line 392 "TDocumentTest.vala"
		_g_object_unref0 (_tmp55_);
#line 392 "TDocumentTest.vala"
		_g_object_unref0 (_tmp52_);
#line 393 "TDocumentTest.vala"
		_tmp56_ = doc;
#line 393 "TDocumentTest.vala"
		_tmp57_ = gxml_document_get_root ((GXmlDocument*) _tmp56_);
#line 393 "TDocumentTest.vala"
		_tmp58_ = _tmp57_;
#line 393 "TDocumentTest.vala"
		_tmp59_ = _tmp58_;
#line 393 "TDocumentTest.vala"
		_tmp60_ = gxml_node_get_children_nodes (_tmp59_);
#line 393 "TDocumentTest.vala"
		_tmp61_ = _tmp60_;
#line 393 "TDocumentTest.vala"
		_tmp62_ = _tmp61_;
#line 393 "TDocumentTest.vala"
		_vala_assert (_tmp62_ != NULL, "doc.root.children_nodes != null");
#line 393 "TDocumentTest.vala"
		_g_object_unref0 (_tmp62_);
#line 393 "TDocumentTest.vala"
		_g_object_unref0 (_tmp59_);
#line 394 "TDocumentTest.vala"
		_tmp63_ = doc;
#line 394 "TDocumentTest.vala"
		_tmp64_ = gxml_document_get_root ((GXmlDocument*) _tmp63_);
#line 394 "TDocumentTest.vala"
		_tmp65_ = _tmp64_;
#line 394 "TDocumentTest.vala"
		_tmp66_ = _tmp65_;
#line 394 "TDocumentTest.vala"
		_tmp67_ = gxml_node_get_children_nodes (_tmp66_);
#line 394 "TDocumentTest.vala"
		_tmp68_ = _tmp67_;
#line 394 "TDocumentTest.vala"
		_tmp69_ = _tmp68_;
#line 394 "TDocumentTest.vala"
		_tmp70_ = gee_collection_get_size ((GeeCollection*) _tmp69_);
#line 394 "TDocumentTest.vala"
		_tmp71_ = _tmp70_;
#line 394 "TDocumentTest.vala"
		_vala_assert (_tmp71_ == 1, "doc.root.children_nodes.size == 1");
#line 394 "TDocumentTest.vala"
		_g_object_unref0 (_tmp69_);
#line 394 "TDocumentTest.vala"
		_g_object_unref0 (_tmp66_);
#line 395 "TDocumentTest.vala"
		_tmp72_ = doc;
#line 395 "TDocumentTest.vala"
		_tmp73_ = gxml_document_get_root ((GXmlDocument*) _tmp72_);
#line 395 "TDocumentTest.vala"
		_tmp74_ = _tmp73_;
#line 395 "TDocumentTest.vala"
		_tmp75_ = _tmp74_;
#line 395 "TDocumentTest.vala"
		_tmp76_ = gxml_node_get_children_nodes (_tmp75_);
#line 395 "TDocumentTest.vala"
		_tmp77_ = _tmp76_;
#line 395 "TDocumentTest.vala"
		_tmp78_ = _tmp77_;
#line 395 "TDocumentTest.vala"
		_tmp79_ = gee_list_get ((GeeList*) _tmp78_, 0);
#line 395 "TDocumentTest.vala"
		_tmp80_ = (GXmlNode*) _tmp79_;
#line 395 "TDocumentTest.vala"
		_g_object_unref0 (_tmp78_);
#line 395 "TDocumentTest.vala"
		_g_object_unref0 (_tmp75_);
#line 395 "TDocumentTest.vala"
		c = _tmp80_;
#line 396 "TDocumentTest.vala"
		gxml_node_set_namespace (c, "http://www.gnome.org/GXml2", "gxml2");
#line 397 "TDocumentTest.vala"
		_tmp81_ = gxml_node_get_namespaces (c);
#line 397 "TDocumentTest.vala"
		_tmp82_ = _tmp81_;
#line 397 "TDocumentTest.vala"
		_tmp83_ = _tmp82_;
#line 397 "TDocumentTest.vala"
		_vala_assert (_tmp83_ != NULL, "c.namespaces != null");
#line 397 "TDocumentTest.vala"
		_g_object_unref0 (_tmp83_);
#line 398 "TDocumentTest.vala"
		_tmp84_ = gxml_node_get_namespaces (c);
#line 398 "TDocumentTest.vala"
		_tmp85_ = _tmp84_;
#line 398 "TDocumentTest.vala"
		_tmp86_ = _tmp85_;
#line 398 "TDocumentTest.vala"
		_tmp87_ = gee_collection_get_size ((GeeCollection*) _tmp86_);
#line 398 "TDocumentTest.vala"
		_tmp88_ = _tmp87_;
#line 398 "TDocumentTest.vala"
		_vala_assert (_tmp88_ == 1, "c.namespaces.size == 1");
#line 398 "TDocumentTest.vala"
		_g_object_unref0 (_tmp86_);
#line 399 "TDocumentTest.vala"
		_tmp89_ = gxml_node_get_namespaces (c);
#line 399 "TDocumentTest.vala"
		_tmp90_ = _tmp89_;
#line 399 "TDocumentTest.vala"
		_tmp91_ = _tmp90_;
#line 399 "TDocumentTest.vala"
		_tmp92_ = gee_list_get (_tmp91_, 0);
#line 399 "TDocumentTest.vala"
		_tmp93_ = (GXmlNamespace*) _tmp92_;
#line 399 "TDocumentTest.vala"
		_tmp94_ = gxml_namespace_get_prefix (_tmp93_);
#line 399 "TDocumentTest.vala"
		_tmp95_ = _tmp94_;
#line 399 "TDocumentTest.vala"
		_tmp96_ = _tmp95_;
#line 399 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp96_, "gxml2") == 0, "c.namespaces[0].prefix == \"gxml2\"");
#line 399 "TDocumentTest.vala"
		_g_free0 (_tmp96_);
#line 399 "TDocumentTest.vala"
		_g_object_unref0 (_tmp93_);
#line 399 "TDocumentTest.vala"
		_g_object_unref0 (_tmp91_);
#line 400 "TDocumentTest.vala"
		_tmp97_ = gxml_node_get_namespaces (c);
#line 400 "TDocumentTest.vala"
		_tmp98_ = _tmp97_;
#line 400 "TDocumentTest.vala"
		_tmp99_ = _tmp98_;
#line 400 "TDocumentTest.vala"
		_tmp100_ = gee_list_get (_tmp99_, 0);
#line 400 "TDocumentTest.vala"
		_tmp101_ = (GXmlNamespace*) _tmp100_;
#line 400 "TDocumentTest.vala"
		_tmp102_ = gxml_namespace_get_uri (_tmp101_);
#line 400 "TDocumentTest.vala"
		_tmp103_ = _tmp102_;
#line 400 "TDocumentTest.vala"
		_tmp104_ = _tmp103_;
#line 400 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp104_, "http://www.gnome.org/GXml2") == 0, "c.namespaces[0].uri == \"http://www.gnome.org/GXml2\"");
#line 400 "TDocumentTest.vala"
		_g_free0 (_tmp104_);
#line 400 "TDocumentTest.vala"
		_g_object_unref0 (_tmp101_);
#line 400 "TDocumentTest.vala"
		_g_object_unref0 (_tmp99_);
#line 401 "TDocumentTest.vala"
		gxml_element_set_attr (G_TYPE_CHECK_INSTANCE_TYPE (c, GXML_TYPE_ELEMENT) ? ((GXmlElement*) c) : NULL, "gxml:prop", "val");
#line 402 "TDocumentTest.vala"
		_tmp105_ = gxml_element_get_attr (G_TYPE_CHECK_INSTANCE_TYPE (c, GXML_TYPE_ELEMENT) ? ((GXmlElement*) c) : NULL, "gxml:prop");
#line 402 "TDocumentTest.vala"
		p = _tmp105_;
#line 403 "TDocumentTest.vala"
		_vala_assert (p == NULL, "p == null");
#line 404 "TDocumentTest.vala"
		_tmp106_ = doc;
#line 404 "TDocumentTest.vala"
		_tmp107_ = gxml_tnode_to_string ((GXmlTNode*) _tmp106_);
#line 404 "TDocumentTest.vala"
		_tmp108_ = _tmp107_;
#line 404 "TDocumentTest.vala"
		_tmp109_ = g_strconcat ("ROOT: ", _tmp108_, NULL);
#line 404 "TDocumentTest.vala"
		_tmp110_ = _tmp109_;
#line 404 "TDocumentTest.vala"
		g_test_message ("%s", _tmp110_);
#line 404 "TDocumentTest.vala"
		_g_free0 (_tmp110_);
#line 404 "TDocumentTest.vala"
		_g_free0 (_tmp108_);
#line 405 "TDocumentTest.vala"
		_tmp111_ = doc;
#line 405 "TDocumentTest.vala"
		_tmp112_ = gxml_tnode_to_string ((GXmlTNode*) _tmp111_);
#line 405 "TDocumentTest.vala"
		_tmp113_ = _tmp112_;
#line 405 "TDocumentTest.vala"
		_tmp115_ = _tmp114_ = g_strsplit (_tmp113_, "\n", 0);
#line 405 "TDocumentTest.vala"
		_tmp116_ = _tmp115_;
#line 405 "TDocumentTest.vala"
		_tmp116__length1 = _vala_array_length (_tmp114_);
#line 405 "TDocumentTest.vala"
		_g_free0 (_tmp113_);
#line 405 "TDocumentTest.vala"
		str = _tmp116_;
#line 405 "TDocumentTest.vala"
		str_length1 = _tmp116__length1;
#line 405 "TDocumentTest.vala"
		_str_size_ = str_length1;
#line 406 "TDocumentTest.vala"
		_tmp117_ = str;
#line 406 "TDocumentTest.vala"
		_tmp117__length1 = str_length1;
#line 406 "TDocumentTest.vala"
		_tmp118_ = _tmp117_[1];
#line 406 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp118_, "<root xmlns:gxml=\"http://www.gnome.org/GXml\"><gxml2:child xmlns:gxml" \
"2=\"http://www.gnome.org/GXml2\"/></root>") == 0, "str[1] == \"<root xmlns:gxml=\\\"http://www.gnome.org/GXml\\\"><gxml2:child xmlns:gxml2=\\\"http://www.gnome.org/GXml2\\\"/></root>\"");
#line 407 "TDocumentTest.vala"
		_tmp119_ = doc;
#line 407 "TDocumentTest.vala"
		_tmp120_ = gxml_tnode_get_namespaces ((GXmlTNode*) _tmp119_);
#line 407 "TDocumentTest.vala"
		_tmp121_ = _tmp120_;
#line 407 "TDocumentTest.vala"
		_tmp122_ = _tmp121_;
#line 407 "TDocumentTest.vala"
		_tmp123_ = gee_list_get (_tmp122_, 0);
#line 407 "TDocumentTest.vala"
		_tmp124_ = (GXmlNamespace*) _tmp123_;
#line 407 "TDocumentTest.vala"
		_tmp125_ = gxml_namespace_get_prefix (_tmp124_);
#line 407 "TDocumentTest.vala"
		_tmp126_ = _tmp125_;
#line 407 "TDocumentTest.vala"
		_tmp127_ = _tmp126_;
#line 407 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp127_, "gxml") == 0, "doc.namespaces[0].prefix == \"gxml\"");
#line 407 "TDocumentTest.vala"
		_g_free0 (_tmp127_);
#line 407 "TDocumentTest.vala"
		_g_object_unref0 (_tmp124_);
#line 407 "TDocumentTest.vala"
		_g_object_unref0 (_tmp122_);
#line 408 "TDocumentTest.vala"
		_tmp128_ = doc;
#line 408 "TDocumentTest.vala"
		_tmp129_ = gxml_tnode_get_namespaces ((GXmlTNode*) _tmp128_);
#line 408 "TDocumentTest.vala"
		_tmp130_ = _tmp129_;
#line 408 "TDocumentTest.vala"
		_tmp131_ = _tmp130_;
#line 408 "TDocumentTest.vala"
		_tmp132_ = gee_list_get (_tmp131_, 0);
#line 408 "TDocumentTest.vala"
		_tmp133_ = (GXmlNamespace*) _tmp132_;
#line 408 "TDocumentTest.vala"
		_tmp134_ = gxml_namespace_get_prefix (_tmp133_);
#line 408 "TDocumentTest.vala"
		_tmp135_ = _tmp134_;
#line 408 "TDocumentTest.vala"
		_tmp136_ = _tmp135_;
#line 408 "TDocumentTest.vala"
		_tmp137_ = g_strconcat (_tmp136_, ":", NULL);
#line 408 "TDocumentTest.vala"
		_tmp138_ = _tmp137_;
#line 408 "TDocumentTest.vala"
		_tmp139_ = doc;
#line 408 "TDocumentTest.vala"
		_tmp140_ = gxml_tnode_get_namespaces ((GXmlTNode*) _tmp139_);
#line 408 "TDocumentTest.vala"
		_tmp141_ = _tmp140_;
#line 408 "TDocumentTest.vala"
		_tmp142_ = _tmp141_;
#line 408 "TDocumentTest.vala"
		_tmp143_ = gee_list_get (_tmp142_, 0);
#line 408 "TDocumentTest.vala"
		_tmp144_ = (GXmlNamespace*) _tmp143_;
#line 408 "TDocumentTest.vala"
		_tmp145_ = gxml_namespace_get_uri (_tmp144_);
#line 408 "TDocumentTest.vala"
		_tmp146_ = _tmp145_;
#line 408 "TDocumentTest.vala"
		_tmp147_ = _tmp146_;
#line 408 "TDocumentTest.vala"
		_tmp148_ = g_strconcat (_tmp138_, _tmp147_, NULL);
#line 408 "TDocumentTest.vala"
		_tmp149_ = _tmp148_;
#line 408 "TDocumentTest.vala"
		gxml_element_set_ns_attr (G_TYPE_CHECK_INSTANCE_TYPE (c, GXML_TYPE_ELEMENT) ? ((GXmlElement*) c) : NULL, _tmp149_, "prop", "Ten");
#line 408 "TDocumentTest.vala"
		_g_free0 (_tmp149_);
#line 408 "TDocumentTest.vala"
		_g_free0 (_tmp147_);
#line 408 "TDocumentTest.vala"
		_g_object_unref0 (_tmp144_);
#line 408 "TDocumentTest.vala"
		_g_object_unref0 (_tmp142_);
#line 408 "TDocumentTest.vala"
		_g_free0 (_tmp138_);
#line 408 "TDocumentTest.vala"
		_g_free0 (_tmp136_);
#line 408 "TDocumentTest.vala"
		_g_object_unref0 (_tmp133_);
#line 408 "TDocumentTest.vala"
		_g_object_unref0 (_tmp131_);
#line 409 "TDocumentTest.vala"
		_tmp150_ = doc;
#line 409 "TDocumentTest.vala"
		_tmp151_ = gxml_document_get_root ((GXmlDocument*) _tmp150_);
#line 409 "TDocumentTest.vala"
		_tmp152_ = _tmp151_;
#line 409 "TDocumentTest.vala"
		_tmp153_ = _tmp152_;
#line 409 "TDocumentTest.vala"
		_tmp154_ = gxml_node_to_string (_tmp153_);
#line 409 "TDocumentTest.vala"
		_tmp155_ = _tmp154_;
#line 409 "TDocumentTest.vala"
		_tmp156_ = g_strconcat ("ROOT: ", _tmp155_, NULL);
#line 409 "TDocumentTest.vala"
		_tmp157_ = _tmp156_;
#line 409 "TDocumentTest.vala"
		g_test_message ("%s", _tmp157_);
#line 409 "TDocumentTest.vala"
		_g_free0 (_tmp157_);
#line 409 "TDocumentTest.vala"
		_g_free0 (_tmp155_);
#line 409 "TDocumentTest.vala"
		_g_object_unref0 (_tmp153_);
#line 410 "TDocumentTest.vala"
		_tmp158_ = gxml_node_get_attrs (c);
#line 410 "TDocumentTest.vala"
		_tmp159_ = _tmp158_;
#line 410 "TDocumentTest.vala"
		_tmp160_ = _tmp159_;
#line 410 "TDocumentTest.vala"
		_tmp161_ = gee_map_get_size (_tmp160_);
#line 410 "TDocumentTest.vala"
		_tmp162_ = _tmp161_;
#line 410 "TDocumentTest.vala"
		_vala_assert (_tmp162_ == 1, "c.attrs.size == 1");
#line 410 "TDocumentTest.vala"
		_g_object_unref0 (_tmp160_);
#line 411 "TDocumentTest.vala"
		_tmp163_ = gxml_node_get_attrs (c);
#line 411 "TDocumentTest.vala"
		_tmp164_ = _tmp163_;
#line 411 "TDocumentTest.vala"
		_tmp165_ = _tmp164_;
#line 411 "TDocumentTest.vala"
		_tmp166_ = gee_map_get (_tmp165_, "gxml:prop");
#line 411 "TDocumentTest.vala"
		_tmp167_ = (GXmlNode*) _tmp166_;
#line 411 "TDocumentTest.vala"
		_g_object_unref0 (_tmp165_);
#line 411 "TDocumentTest.vala"
		pt = _tmp167_;
#line 412 "TDocumentTest.vala"
		_vala_assert (pt != NULL, "pt != null");
#line 413 "TDocumentTest.vala"
		_tmp168_ = doc;
#line 413 "TDocumentTest.vala"
		_tmp169_ = gxml_tnode_to_string ((GXmlTNode*) _tmp168_);
#line 413 "TDocumentTest.vala"
		_tmp170_ = _tmp169_;
#line 413 "TDocumentTest.vala"
		_tmp172_ = _tmp171_ = g_strsplit (_tmp170_, "\n", 0);
#line 413 "TDocumentTest.vala"
		str = (_vala_array_free (str, str_length1, (GDestroyNotify) g_free), NULL);
#line 413 "TDocumentTest.vala"
		str = _tmp172_;
#line 413 "TDocumentTest.vala"
		str_length1 = _vala_array_length (_tmp171_);
#line 413 "TDocumentTest.vala"
		_str_size_ = str_length1;
#line 413 "TDocumentTest.vala"
		_g_free0 (_tmp170_);
#line 414 "TDocumentTest.vala"
		_tmp173_ = str;
#line 414 "TDocumentTest.vala"
		_tmp173__length1 = str_length1;
#line 414 "TDocumentTest.vala"
		_tmp174_ = _tmp173_[1];
#line 414 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp174_, "<root xmlns:gxml=\"http://www.gnome.org/GXml\"><gxml2:child xmlns:gxml" \
"2=\"http://www.gnome.org/GXml2\" gxml:prop=\"Ten\"/></root>") == 0, "str[1] == \"<root xmlns:gxml=\\\"http://www.gnome.org/GXml\\\"><gxml2:child xmlns:gxml2=\\\"http://www.gnome.org/GXml2\\\" gxml:prop=\\\"Ten\\\"/></root>\"");
#line 382 "TDocumentTest.vala"
		_g_object_unref0 (pt);
#line 382 "TDocumentTest.vala"
		str = (_vala_array_free (str, str_length1, (GDestroyNotify) g_free), NULL);
#line 382 "TDocumentTest.vala"
		_g_object_unref0 (p);
#line 382 "TDocumentTest.vala"
		_g_object_unref0 (c);
#line 382 "TDocumentTest.vala"
		_g_object_unref0 (_tmp46_);
#line 382 "TDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 382 "TDocumentTest.vala"
		_g_object_unref0 (doc);
#line 4744 "TDocumentTest.c"
	}
	goto __finally274;
	__catch274_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp175_;
		gchar* _tmp176_;
		gchar* _tmp177_;
#line 382 "TDocumentTest.vala"
		e = _inner_error0_;
#line 382 "TDocumentTest.vala"
		_inner_error0_ = NULL;
#line 416 "TDocumentTest.vala"
		_tmp175_ = e->message;
#line 416 "TDocumentTest.vala"
		_tmp176_ = g_strconcat ("ERROR: ", _tmp175_, NULL);
#line 416 "TDocumentTest.vala"
		_tmp177_ = _tmp176_;
#line 416 "TDocumentTest.vala"
		g_message ("TDocumentTest.vala:416: %s", _tmp177_);
#line 416 "TDocumentTest.vala"
		_g_free0 (_tmp177_);
#line 417 "TDocumentTest.vala"
		g_assert_not_reached ();
#line 382 "TDocumentTest.vala"
		_g_error_free0 (e);
#line 4771 "TDocumentTest.c"
	}
	__finally274:
#line 382 "TDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 382 "TDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 382 "TDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 382 "TDocumentTest.vala"
		return;
#line 4782 "TDocumentTest.c"
	}
}

static void
___lambda217__gtest_func (void)
{
#line 381 "TDocumentTest.vala"
	__lambda217_ ();
#line 4791 "TDocumentTest.c"
}

static void
__lambda218_ (void)
{
	GXmlTDocument* doc = NULL;
	GXmlTDocument* _tmp0_;
	GXmlNode* _tmp1_;
	GXmlNode* _tmp2_;
	GXmlNode* _tmp3_;
#line 421 "TDocumentTest.vala"
	_tmp0_ = gxml_tdocument_new ();
#line 421 "TDocumentTest.vala"
	doc = _tmp0_;
#line 422 "TDocumentTest.vala"
	_tmp1_ = gxml_tnode_get_parent ((GXmlTNode*) doc);
#line 422 "TDocumentTest.vala"
	_tmp2_ = _tmp1_;
#line 422 "TDocumentTest.vala"
	_tmp3_ = _tmp2_;
#line 422 "TDocumentTest.vala"
	_vala_assert (_tmp3_ == NULL, "doc.parent == null");
#line 422 "TDocumentTest.vala"
	_g_object_unref0 (_tmp3_);
#line 420 "TDocumentTest.vala"
	_g_object_unref0 (doc);
#line 4818 "TDocumentTest.c"
}

static void
___lambda218__gtest_func (void)
{
#line 420 "TDocumentTest.vala"
	__lambda218_ ();
#line 4826 "TDocumentTest.c"
}

static void
__lambda219_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GFile* f = NULL;
		GFile* _tmp0_;
		GXmlTDocument* d = NULL;
		GXmlTDocument* _tmp1_;
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		GXmlNode* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		GXmlNode* _tmp11_;
		GXmlNode* _tmp12_;
		GXmlNode* _tmp13_;
		GeeMap* _tmp14_;
		GeeMap* _tmp15_;
		GeeMap* _tmp16_;
		gpointer _tmp17_;
		GXmlNode* _tmp18_;
		GXmlNode* _tmp19_;
		GXmlNode* _tmp20_;
		GXmlNode* _tmp21_;
		GeeMap* _tmp22_;
		GeeMap* _tmp23_;
		GeeMap* _tmp24_;
		gpointer _tmp25_;
		GXmlNode* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
		GXmlNode* _tmp30_;
		GXmlNode* _tmp31_;
		GXmlNode* _tmp32_;
		GeeBidirList* _tmp33_;
		GeeBidirList* _tmp34_;
		GeeBidirList* _tmp35_;
		gint _tmp36_;
		gint _tmp37_;
		GXmlNode* s1 = NULL;
		GXmlNode* _tmp38_;
		GXmlNode* _tmp39_;
		GXmlNode* _tmp40_;
		GeeBidirList* _tmp41_;
		GeeBidirList* _tmp42_;
		GeeBidirList* _tmp43_;
		gpointer _tmp44_;
		GXmlNode* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
		GXmlNode* p1 = NULL;
		GeeMap* _tmp49_;
		GeeMap* _tmp50_;
		GeeMap* _tmp51_;
		gpointer _tmp52_;
		GXmlNode* _tmp53_;
		gchar* _tmp54_;
		gchar* _tmp55_;
		gchar* _tmp56_;
		GeeBidirList* _tmp57_;
		GeeBidirList* _tmp58_;
		GeeBidirList* _tmp59_;
		gint _tmp60_;
		gint _tmp61_;
		GeeBidirList* _tmp62_;
		GeeBidirList* _tmp63_;
		GeeBidirList* _tmp64_;
		gpointer _tmp65_;
		GXmlNode* _tmp66_;
		GeeBidirList* _tmp67_;
		GeeBidirList* _tmp68_;
		GeeBidirList* _tmp69_;
		gpointer _tmp70_;
		GXmlNode* _tmp71_;
		gchar* _tmp72_;
		gchar* _tmp73_;
		gchar* _tmp74_;
		GXmlNode* s2 = NULL;
		GXmlNode* _tmp75_;
		GXmlNode* _tmp76_;
		GXmlNode* _tmp77_;
		GeeBidirList* _tmp78_;
		GeeBidirList* _tmp79_;
		GeeBidirList* _tmp80_;
		gpointer _tmp81_;
		GXmlNode* _tmp82_;
		gchar* _tmp83_;
		gchar* _tmp84_;
		gchar* _tmp85_;
		GXmlNode* p2 = NULL;
		GeeMap* _tmp86_;
		GeeMap* _tmp87_;
		GeeMap* _tmp88_;
		gpointer _tmp89_;
		GXmlNode* _tmp90_;
		gchar* _tmp91_;
		gchar* _tmp92_;
		gchar* _tmp93_;
		GeeBidirList* _tmp94_;
		GeeBidirList* _tmp95_;
		GeeBidirList* _tmp96_;
		gint _tmp97_;
		gint _tmp98_;
		GeeBidirList* _tmp99_;
		GeeBidirList* _tmp100_;
		GeeBidirList* _tmp101_;
		gpointer _tmp102_;
		GXmlNode* _tmp103_;
		GeeBidirList* _tmp104_;
		GeeBidirList* _tmp105_;
		GeeBidirList* _tmp106_;
		gpointer _tmp107_;
		GXmlNode* _tmp108_;
		gchar* _tmp109_;
		gchar* _tmp110_;
		gchar* _tmp111_;
		GXmlNode* s3 = NULL;
		GXmlNode* _tmp112_;
		GXmlNode* _tmp113_;
		GXmlNode* _tmp114_;
		GeeBidirList* _tmp115_;
		GeeBidirList* _tmp116_;
		GeeBidirList* _tmp117_;
		gpointer _tmp118_;
		GXmlNode* _tmp119_;
		gchar* _tmp120_;
		gchar* _tmp121_;
		gchar* _tmp122_;
		GXmlNode* p3 = NULL;
		GeeMap* _tmp123_;
		GeeMap* _tmp124_;
		GeeMap* _tmp125_;
		gpointer _tmp126_;
		GXmlNode* _tmp127_;
		gchar* _tmp128_;
		gchar* _tmp129_;
		gchar* _tmp130_;
		GXmlNode* p31 = NULL;
		GeeMap* _tmp131_;
		GeeMap* _tmp132_;
		GeeMap* _tmp133_;
		gpointer _tmp134_;
		GXmlNode* _tmp135_;
		gchar* _tmp136_;
		gchar* _tmp137_;
		gchar* _tmp138_;
		GeeBidirList* _tmp139_;
		GeeBidirList* _tmp140_;
		GeeBidirList* _tmp141_;
		gint _tmp142_;
		gint _tmp143_;
		GeeBidirList* _tmp144_;
		GeeBidirList* _tmp145_;
		GeeBidirList* _tmp146_;
		gpointer _tmp147_;
		GXmlNode* _tmp148_;
		GeeBidirList* _tmp149_;
		GeeBidirList* _tmp150_;
		GeeBidirList* _tmp151_;
		gpointer _tmp152_;
		GXmlNode* _tmp153_;
		gchar* _tmp154_;
		gchar* _tmp155_;
		gchar* _tmp156_;
		GeeBidirList* _tmp157_;
		GeeBidirList* _tmp158_;
		GeeBidirList* _tmp159_;
		gpointer _tmp160_;
		GXmlNode* _tmp161_;
		gchar* _tmp162_;
		gchar* _tmp163_;
		gchar* _tmp164_;
		GXmlNode* a1 = NULL;
		GeeBidirList* _tmp165_;
		GeeBidirList* _tmp166_;
		GeeBidirList* _tmp167_;
		gpointer _tmp168_;
		GXmlNode* _tmp169_;
		gchar* _tmp170_;
		gchar* _tmp171_;
		gchar* _tmp172_;
		GeeBidirList* _tmp173_;
		GeeBidirList* _tmp174_;
		GeeBidirList* _tmp175_;
		gint _tmp176_;
		gint _tmp177_;
		GeeBidirList* _tmp178_;
		GeeBidirList* _tmp179_;
		GeeBidirList* _tmp180_;
		gpointer _tmp181_;
		GXmlNode* _tmp182_;
		gchar* _tmp183_;
		gchar* _tmp184_;
		gchar* _tmp185_;
		GeeBidirList* _tmp186_;
		GeeBidirList* _tmp187_;
		GeeBidirList* _tmp188_;
		gpointer _tmp189_;
		GXmlNode* _tmp190_;
		GeeBidirList* _tmp191_;
		GeeBidirList* _tmp192_;
		GeeBidirList* _tmp193_;
		gint _tmp194_;
		gint _tmp195_;
		GeeBidirList* _tmp196_;
		GeeBidirList* _tmp197_;
		GeeBidirList* _tmp198_;
		gpointer _tmp199_;
		GXmlNode* _tmp200_;
		GeeBidirList* _tmp201_;
		GeeBidirList* _tmp202_;
		GeeBidirList* _tmp203_;
		gpointer _tmp204_;
		GXmlNode* _tmp205_;
		GeeBidirList* _tmp206_;
		GeeBidirList* _tmp207_;
		GeeBidirList* _tmp208_;
		gpointer _tmp209_;
		GXmlNode* _tmp210_;
		GeeBidirList* _tmp211_;
		GeeBidirList* _tmp212_;
		GeeBidirList* _tmp213_;
		gpointer _tmp214_;
		GXmlNode* _tmp215_;
		gchar* _tmp216_;
		gchar* _tmp217_;
		gchar* _tmp218_;
		GeeBidirList* _tmp219_;
		GeeBidirList* _tmp220_;
		GeeBidirList* _tmp221_;
		gpointer _tmp222_;
		GXmlNode* _tmp223_;
		gchar* _tmp224_;
		gchar* _tmp225_;
		gchar* _tmp226_;
		GeeBidirList* _tmp227_;
		GeeBidirList* _tmp228_;
		GeeBidirList* _tmp229_;
		gpointer _tmp230_;
		GXmlNode* _tmp231_;
		GeeBidirList* _tmp232_;
		GeeBidirList* _tmp233_;
		GeeBidirList* _tmp234_;
		gint _tmp235_;
		gint _tmp236_;
		GeeBidirList* _tmp237_;
		GeeBidirList* _tmp238_;
		GeeBidirList* _tmp239_;
		gpointer _tmp240_;
		GXmlNode* _tmp241_;
		GeeBidirList* _tmp242_;
		GeeBidirList* _tmp243_;
		GeeBidirList* _tmp244_;
		gpointer _tmp245_;
		GXmlNode* _tmp246_;
		GeeBidirList* _tmp247_;
		GeeBidirList* _tmp248_;
		GeeBidirList* _tmp249_;
		gpointer _tmp250_;
		GXmlNode* _tmp251_;
		GeeBidirList* _tmp252_;
		GeeBidirList* _tmp253_;
		GeeBidirList* _tmp254_;
		gpointer _tmp255_;
		GXmlNode* _tmp256_;
		gchar* _tmp257_;
		gchar* _tmp258_;
		gchar* _tmp259_;
		GXmlNode* a2 = NULL;
		GeeBidirList* _tmp260_;
		GeeBidirList* _tmp261_;
		GeeBidirList* _tmp262_;
		gpointer _tmp263_;
		GXmlNode* _tmp264_;
		GeeBidirList* _tmp265_;
		GeeBidirList* _tmp266_;
		GeeBidirList* _tmp267_;
		gint _tmp268_;
		gint _tmp269_;
		GeeBidirList* _tmp270_;
		GeeBidirList* _tmp271_;
		GeeBidirList* _tmp272_;
		gpointer _tmp273_;
		GXmlNode* _tmp274_;
		gchar* _tmp275_;
		gchar* _tmp276_;
		gchar* _tmp277_;
		GeeBidirList* _tmp278_;
		GeeBidirList* _tmp279_;
		GeeBidirList* _tmp280_;
		gpointer _tmp281_;
		GXmlNode* _tmp282_;
		GeeBidirList* _tmp283_;
		GeeBidirList* _tmp284_;
		GeeBidirList* _tmp285_;
		gint _tmp286_;
		gint _tmp287_;
		GeeBidirList* _tmp288_;
		GeeBidirList* _tmp289_;
		GeeBidirList* _tmp290_;
		gpointer _tmp291_;
		GXmlNode* _tmp292_;
		GeeBidirList* _tmp293_;
		GeeBidirList* _tmp294_;
		GeeBidirList* _tmp295_;
		gpointer _tmp296_;
		GXmlNode* _tmp297_;
		GeeBidirList* _tmp298_;
		GeeBidirList* _tmp299_;
		GeeBidirList* _tmp300_;
		gpointer _tmp301_;
		GXmlNode* _tmp302_;
		GeeBidirList* _tmp303_;
		GeeBidirList* _tmp304_;
		GeeBidirList* _tmp305_;
		gpointer _tmp306_;
		GXmlNode* _tmp307_;
		gchar* _tmp308_;
		gchar* _tmp309_;
		gchar* _tmp310_;
		GeeBidirList* _tmp311_;
		GeeBidirList* _tmp312_;
		GeeBidirList* _tmp313_;
		gpointer _tmp314_;
		GXmlNode* _tmp315_;
		gchar* _tmp316_;
		gchar* _tmp317_;
		gchar* _tmp318_;
		GeeBidirList* _tmp319_;
		GeeBidirList* _tmp320_;
		GeeBidirList* _tmp321_;
		gpointer _tmp322_;
		GXmlNode* _tmp323_;
		GeeBidirList* _tmp324_;
		GeeBidirList* _tmp325_;
		GeeBidirList* _tmp326_;
		gint _tmp327_;
		gint _tmp328_;
		GeeBidirList* _tmp329_;
		GeeBidirList* _tmp330_;
		GeeBidirList* _tmp331_;
		gpointer _tmp332_;
		GXmlNode* _tmp333_;
		GeeBidirList* _tmp334_;
		GeeBidirList* _tmp335_;
		GeeBidirList* _tmp336_;
		gpointer _tmp337_;
		GXmlNode* _tmp338_;
		GeeBidirList* _tmp339_;
		GeeBidirList* _tmp340_;
		GeeBidirList* _tmp341_;
		gpointer _tmp342_;
		GXmlNode* _tmp343_;
		GeeBidirList* _tmp344_;
		GeeBidirList* _tmp345_;
		GeeBidirList* _tmp346_;
		gpointer _tmp347_;
		GXmlNode* _tmp348_;
		gchar* _tmp349_;
		gchar* _tmp350_;
		gchar* _tmp351_;
#line 426 "TDocumentTest.vala"
		_tmp0_ = g_file_new_for_path (TEST_DIR "/t-read-test.xml");
#line 426 "TDocumentTest.vala"
		f = _tmp0_;
#line 427 "TDocumentTest.vala"
		_vala_assert (g_file_query_exists (f, NULL), "f.query_exists ()");
#line 428 "TDocumentTest.vala"
		_tmp1_ = gxml_tdocument_new ();
#line 428 "TDocumentTest.vala"
		d = _tmp1_;
#line 429 "TDocumentTest.vala"
		gxml_tdocument_read_doc ((GXmlDocument*) d, f, NULL, NULL, &_inner_error0_);
#line 429 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 429 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 429 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 5215 "TDocumentTest.c"
			goto __catch275_g_error;
		}
#line 431 "TDocumentTest.vala"
		_tmp2_ = gxml_document_get_root ((GXmlDocument*) d);
#line 431 "TDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 431 "TDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 431 "TDocumentTest.vala"
		_vala_assert (_tmp4_ != NULL, "d.root != null");
#line 431 "TDocumentTest.vala"
		_g_object_unref0 (_tmp4_);
#line 432 "TDocumentTest.vala"
		_tmp5_ = gxml_document_get_root ((GXmlDocument*) d);
#line 432 "TDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 432 "TDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 432 "TDocumentTest.vala"
		_tmp8_ = gxml_node_get_name (_tmp7_);
#line 432 "TDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 432 "TDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 432 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp10_, "Sentences") == 0, "d.root.name == \"Sentences\"");
#line 432 "TDocumentTest.vala"
		_g_free0 (_tmp10_);
#line 432 "TDocumentTest.vala"
		_g_object_unref0 (_tmp7_);
#line 433 "TDocumentTest.vala"
		_tmp11_ = gxml_document_get_root ((GXmlDocument*) d);
#line 433 "TDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 433 "TDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 433 "TDocumentTest.vala"
		_tmp14_ = gxml_node_get_attrs (_tmp13_);
#line 433 "TDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 433 "TDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 433 "TDocumentTest.vala"
		_tmp17_ = gee_map_get (_tmp16_, "audience");
#line 433 "TDocumentTest.vala"
		_tmp18_ = (GXmlNode*) _tmp17_;
#line 433 "TDocumentTest.vala"
		_vala_assert (_tmp18_ != NULL, "d.root.attrs[\"audience\"] != null");
#line 433 "TDocumentTest.vala"
		_g_object_unref0 (_tmp18_);
#line 433 "TDocumentTest.vala"
		_g_object_unref0 (_tmp16_);
#line 433 "TDocumentTest.vala"
		_g_object_unref0 (_tmp13_);
#line 434 "TDocumentTest.vala"
		_tmp19_ = gxml_document_get_root ((GXmlDocument*) d);
#line 434 "TDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 434 "TDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 434 "TDocumentTest.vala"
		_tmp22_ = gxml_node_get_attrs (_tmp21_);
#line 434 "TDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 434 "TDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 434 "TDocumentTest.vala"
		_tmp25_ = gee_map_get (_tmp24_, "audience");
#line 434 "TDocumentTest.vala"
		_tmp26_ = (GXmlNode*) _tmp25_;
#line 434 "TDocumentTest.vala"
		_tmp27_ = gxml_node_get_value (_tmp26_);
#line 434 "TDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 434 "TDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 434 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp29_, "All") == 0, "d.root.attrs[\"audience\"].value == \"All\"");
#line 434 "TDocumentTest.vala"
		_g_free0 (_tmp29_);
#line 434 "TDocumentTest.vala"
		_g_object_unref0 (_tmp26_);
#line 434 "TDocumentTest.vala"
		_g_object_unref0 (_tmp24_);
#line 434 "TDocumentTest.vala"
		_g_object_unref0 (_tmp21_);
#line 435 "TDocumentTest.vala"
		_tmp30_ = gxml_document_get_root ((GXmlDocument*) d);
#line 435 "TDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 435 "TDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 435 "TDocumentTest.vala"
		_tmp33_ = gxml_node_get_children_nodes (_tmp32_);
#line 435 "TDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 435 "TDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 435 "TDocumentTest.vala"
		_tmp36_ = gee_collection_get_size ((GeeCollection*) _tmp35_);
#line 435 "TDocumentTest.vala"
		_tmp37_ = _tmp36_;
#line 435 "TDocumentTest.vala"
		_vala_assert (_tmp37_ == 7, "d.root.children_nodes.size == 7");
#line 435 "TDocumentTest.vala"
		_g_object_unref0 (_tmp35_);
#line 435 "TDocumentTest.vala"
		_g_object_unref0 (_tmp32_);
#line 436 "TDocumentTest.vala"
		_tmp38_ = gxml_document_get_root ((GXmlDocument*) d);
#line 436 "TDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 436 "TDocumentTest.vala"
		_tmp40_ = _tmp39_;
#line 436 "TDocumentTest.vala"
		_tmp41_ = gxml_node_get_children_nodes (_tmp40_);
#line 436 "TDocumentTest.vala"
		_tmp42_ = _tmp41_;
#line 436 "TDocumentTest.vala"
		_tmp43_ = _tmp42_;
#line 436 "TDocumentTest.vala"
		_tmp44_ = gee_list_get ((GeeList*) _tmp43_, 0);
#line 436 "TDocumentTest.vala"
		_tmp45_ = (GXmlNode*) _tmp44_;
#line 436 "TDocumentTest.vala"
		_g_object_unref0 (_tmp43_);
#line 436 "TDocumentTest.vala"
		_g_object_unref0 (_tmp40_);
#line 436 "TDocumentTest.vala"
		s1 = _tmp45_;
#line 437 "TDocumentTest.vala"
		_vala_assert (s1 != NULL, "s1 != null");
#line 438 "TDocumentTest.vala"
		_tmp46_ = gxml_node_get_name (s1);
#line 438 "TDocumentTest.vala"
		_tmp47_ = _tmp46_;
#line 438 "TDocumentTest.vala"
		_tmp48_ = _tmp47_;
#line 438 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp48_, "Sentence") == 0, "s1.name == \"Sentence\"");
#line 438 "TDocumentTest.vala"
		_g_free0 (_tmp48_);
#line 439 "TDocumentTest.vala"
		_tmp49_ = gxml_node_get_attrs (s1);
#line 439 "TDocumentTest.vala"
		_tmp50_ = _tmp49_;
#line 439 "TDocumentTest.vala"
		_tmp51_ = _tmp50_;
#line 439 "TDocumentTest.vala"
		_tmp52_ = gee_map_get (_tmp51_, "lang");
#line 439 "TDocumentTest.vala"
		_tmp53_ = (GXmlNode*) _tmp52_;
#line 439 "TDocumentTest.vala"
		_g_object_unref0 (_tmp51_);
#line 439 "TDocumentTest.vala"
		p1 = _tmp53_;
#line 440 "TDocumentTest.vala"
		_vala_assert (p1 != NULL, "p1 != null");
#line 441 "TDocumentTest.vala"
		_tmp54_ = gxml_node_get_value (p1);
#line 441 "TDocumentTest.vala"
		_tmp55_ = _tmp54_;
#line 441 "TDocumentTest.vala"
		_tmp56_ = _tmp55_;
#line 441 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp56_, "en") == 0, "p1.value == \"en\"");
#line 441 "TDocumentTest.vala"
		_g_free0 (_tmp56_);
#line 442 "TDocumentTest.vala"
		_tmp57_ = gxml_node_get_children_nodes (s1);
#line 442 "TDocumentTest.vala"
		_tmp58_ = _tmp57_;
#line 442 "TDocumentTest.vala"
		_tmp59_ = _tmp58_;
#line 442 "TDocumentTest.vala"
		_tmp60_ = gee_collection_get_size ((GeeCollection*) _tmp59_);
#line 442 "TDocumentTest.vala"
		_tmp61_ = _tmp60_;
#line 442 "TDocumentTest.vala"
		_vala_assert (_tmp61_ == 1, "s1.children_nodes.size == 1");
#line 442 "TDocumentTest.vala"
		_g_object_unref0 (_tmp59_);
#line 443 "TDocumentTest.vala"
		_tmp62_ = gxml_node_get_children_nodes (s1);
#line 443 "TDocumentTest.vala"
		_tmp63_ = _tmp62_;
#line 443 "TDocumentTest.vala"
		_tmp64_ = _tmp63_;
#line 443 "TDocumentTest.vala"
		_tmp65_ = gee_list_get ((GeeList*) _tmp64_, 0);
#line 443 "TDocumentTest.vala"
		_tmp66_ = (GXmlNode*) _tmp65_;
#line 443 "TDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp66_, GXML_TYPE_TEXT), "s1.children_nodes[0] is GXml.Text");
#line 443 "TDocumentTest.vala"
		_g_object_unref0 (_tmp66_);
#line 443 "TDocumentTest.vala"
		_g_object_unref0 (_tmp64_);
#line 444 "TDocumentTest.vala"
		_tmp67_ = gxml_node_get_children_nodes (s1);
#line 444 "TDocumentTest.vala"
		_tmp68_ = _tmp67_;
#line 444 "TDocumentTest.vala"
		_tmp69_ = _tmp68_;
#line 444 "TDocumentTest.vala"
		_tmp70_ = gee_list_get ((GeeList*) _tmp69_, 0);
#line 444 "TDocumentTest.vala"
		_tmp71_ = (GXmlNode*) _tmp70_;
#line 444 "TDocumentTest.vala"
		_tmp72_ = gxml_node_get_value (_tmp71_);
#line 444 "TDocumentTest.vala"
		_tmp73_ = _tmp72_;
#line 444 "TDocumentTest.vala"
		_tmp74_ = _tmp73_;
#line 444 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp74_, "I like the colour blue.") == 0, "s1.children_nodes[0].value == \"I like the colour blue.\"");
#line 444 "TDocumentTest.vala"
		_g_free0 (_tmp74_);
#line 444 "TDocumentTest.vala"
		_g_object_unref0 (_tmp71_);
#line 444 "TDocumentTest.vala"
		_g_object_unref0 (_tmp69_);
#line 445 "TDocumentTest.vala"
		_tmp75_ = gxml_document_get_root ((GXmlDocument*) d);
#line 445 "TDocumentTest.vala"
		_tmp76_ = _tmp75_;
#line 445 "TDocumentTest.vala"
		_tmp77_ = _tmp76_;
#line 445 "TDocumentTest.vala"
		_tmp78_ = gxml_node_get_children_nodes (_tmp77_);
#line 445 "TDocumentTest.vala"
		_tmp79_ = _tmp78_;
#line 445 "TDocumentTest.vala"
		_tmp80_ = _tmp79_;
#line 445 "TDocumentTest.vala"
		_tmp81_ = gee_list_get ((GeeList*) _tmp80_, 1);
#line 445 "TDocumentTest.vala"
		_tmp82_ = (GXmlNode*) _tmp81_;
#line 445 "TDocumentTest.vala"
		_g_object_unref0 (_tmp80_);
#line 445 "TDocumentTest.vala"
		_g_object_unref0 (_tmp77_);
#line 445 "TDocumentTest.vala"
		s2 = _tmp82_;
#line 446 "TDocumentTest.vala"
		_vala_assert (s2 != NULL, "s2 != null");
#line 447 "TDocumentTest.vala"
		_tmp83_ = gxml_node_get_name (s2);
#line 447 "TDocumentTest.vala"
		_tmp84_ = _tmp83_;
#line 447 "TDocumentTest.vala"
		_tmp85_ = _tmp84_;
#line 447 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp85_, "Sentence") == 0, "s2.name == \"Sentence\"");
#line 447 "TDocumentTest.vala"
		_g_free0 (_tmp85_);
#line 448 "TDocumentTest.vala"
		_tmp86_ = gxml_node_get_attrs (s2);
#line 448 "TDocumentTest.vala"
		_tmp87_ = _tmp86_;
#line 448 "TDocumentTest.vala"
		_tmp88_ = _tmp87_;
#line 448 "TDocumentTest.vala"
		_tmp89_ = gee_map_get (_tmp88_, "lang");
#line 448 "TDocumentTest.vala"
		_tmp90_ = (GXmlNode*) _tmp89_;
#line 448 "TDocumentTest.vala"
		_g_object_unref0 (_tmp88_);
#line 448 "TDocumentTest.vala"
		p2 = _tmp90_;
#line 449 "TDocumentTest.vala"
		_vala_assert (p2 != NULL, "p2 != null");
#line 450 "TDocumentTest.vala"
		_tmp91_ = gxml_node_get_value (p2);
#line 450 "TDocumentTest.vala"
		_tmp92_ = _tmp91_;
#line 450 "TDocumentTest.vala"
		_tmp93_ = _tmp92_;
#line 450 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp93_, "es") == 0, "p2.value == \"es\"");
#line 450 "TDocumentTest.vala"
		_g_free0 (_tmp93_);
#line 451 "TDocumentTest.vala"
		_tmp94_ = gxml_node_get_children_nodes (s2);
#line 451 "TDocumentTest.vala"
		_tmp95_ = _tmp94_;
#line 451 "TDocumentTest.vala"
		_tmp96_ = _tmp95_;
#line 451 "TDocumentTest.vala"
		_tmp97_ = gee_collection_get_size ((GeeCollection*) _tmp96_);
#line 451 "TDocumentTest.vala"
		_tmp98_ = _tmp97_;
#line 451 "TDocumentTest.vala"
		_vala_assert (_tmp98_ == 1, "s2.children_nodes.size == 1");
#line 451 "TDocumentTest.vala"
		_g_object_unref0 (_tmp96_);
#line 452 "TDocumentTest.vala"
		_tmp99_ = gxml_node_get_children_nodes (s2);
#line 452 "TDocumentTest.vala"
		_tmp100_ = _tmp99_;
#line 452 "TDocumentTest.vala"
		_tmp101_ = _tmp100_;
#line 452 "TDocumentTest.vala"
		_tmp102_ = gee_list_get ((GeeList*) _tmp101_, 0);
#line 452 "TDocumentTest.vala"
		_tmp103_ = (GXmlNode*) _tmp102_;
#line 452 "TDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp103_, GXML_TYPE_TEXT), "s2.children_nodes[0] is GXml.Text");
#line 452 "TDocumentTest.vala"
		_g_object_unref0 (_tmp103_);
#line 452 "TDocumentTest.vala"
		_g_object_unref0 (_tmp101_);
#line 453 "TDocumentTest.vala"
		_tmp104_ = gxml_node_get_children_nodes (s2);
#line 453 "TDocumentTest.vala"
		_tmp105_ = _tmp104_;
#line 453 "TDocumentTest.vala"
		_tmp106_ = _tmp105_;
#line 453 "TDocumentTest.vala"
		_tmp107_ = gee_list_get ((GeeList*) _tmp106_, 0);
#line 453 "TDocumentTest.vala"
		_tmp108_ = (GXmlNode*) _tmp107_;
#line 453 "TDocumentTest.vala"
		_tmp109_ = gxml_node_get_value (_tmp108_);
#line 453 "TDocumentTest.vala"
		_tmp110_ = _tmp109_;
#line 453 "TDocumentTest.vala"
		_tmp111_ = _tmp110_;
#line 453 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp111_, "Español") == 0, "s2.children_nodes[0].value == \"Espa\303\261ol\"");
#line 453 "TDocumentTest.vala"
		_g_free0 (_tmp111_);
#line 453 "TDocumentTest.vala"
		_g_object_unref0 (_tmp108_);
#line 453 "TDocumentTest.vala"
		_g_object_unref0 (_tmp106_);
#line 454 "TDocumentTest.vala"
		_tmp112_ = gxml_document_get_root ((GXmlDocument*) d);
#line 454 "TDocumentTest.vala"
		_tmp113_ = _tmp112_;
#line 454 "TDocumentTest.vala"
		_tmp114_ = _tmp113_;
#line 454 "TDocumentTest.vala"
		_tmp115_ = gxml_node_get_children_nodes (_tmp114_);
#line 454 "TDocumentTest.vala"
		_tmp116_ = _tmp115_;
#line 454 "TDocumentTest.vala"
		_tmp117_ = _tmp116_;
#line 454 "TDocumentTest.vala"
		_tmp118_ = gee_list_get ((GeeList*) _tmp117_, 2);
#line 454 "TDocumentTest.vala"
		_tmp119_ = (GXmlNode*) _tmp118_;
#line 454 "TDocumentTest.vala"
		_g_object_unref0 (_tmp117_);
#line 454 "TDocumentTest.vala"
		_g_object_unref0 (_tmp114_);
#line 454 "TDocumentTest.vala"
		s3 = _tmp119_;
#line 455 "TDocumentTest.vala"
		_vala_assert (s3 != NULL, "s3 != null");
#line 456 "TDocumentTest.vala"
		_tmp120_ = gxml_node_get_name (s3);
#line 456 "TDocumentTest.vala"
		_tmp121_ = _tmp120_;
#line 456 "TDocumentTest.vala"
		_tmp122_ = _tmp121_;
#line 456 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp122_, "Authors") == 0, "s3.name == \"Authors\"");
#line 456 "TDocumentTest.vala"
		_g_free0 (_tmp122_);
#line 457 "TDocumentTest.vala"
		_tmp123_ = gxml_node_get_attrs (s3);
#line 457 "TDocumentTest.vala"
		_tmp124_ = _tmp123_;
#line 457 "TDocumentTest.vala"
		_tmp125_ = _tmp124_;
#line 457 "TDocumentTest.vala"
		_tmp126_ = gee_map_get (_tmp125_, "year");
#line 457 "TDocumentTest.vala"
		_tmp127_ = (GXmlNode*) _tmp126_;
#line 457 "TDocumentTest.vala"
		_g_object_unref0 (_tmp125_);
#line 457 "TDocumentTest.vala"
		p3 = _tmp127_;
#line 458 "TDocumentTest.vala"
		_vala_assert (p3 != NULL, "p3 != null");
#line 459 "TDocumentTest.vala"
		_tmp128_ = gxml_node_get_value (p3);
#line 459 "TDocumentTest.vala"
		_tmp129_ = _tmp128_;
#line 459 "TDocumentTest.vala"
		_tmp130_ = _tmp129_;
#line 459 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp130_, "2016") == 0, "p3.value == \"2016\"");
#line 459 "TDocumentTest.vala"
		_g_free0 (_tmp130_);
#line 460 "TDocumentTest.vala"
		_tmp131_ = gxml_node_get_attrs (s3);
#line 460 "TDocumentTest.vala"
		_tmp132_ = _tmp131_;
#line 460 "TDocumentTest.vala"
		_tmp133_ = _tmp132_;
#line 460 "TDocumentTest.vala"
		_tmp134_ = gee_map_get (_tmp133_, "collection");
#line 460 "TDocumentTest.vala"
		_tmp135_ = (GXmlNode*) _tmp134_;
#line 460 "TDocumentTest.vala"
		_g_object_unref0 (_tmp133_);
#line 460 "TDocumentTest.vala"
		p31 = _tmp135_;
#line 461 "TDocumentTest.vala"
		_vala_assert (p31 != NULL, "p31 != null");
#line 462 "TDocumentTest.vala"
		_tmp136_ = gxml_node_get_value (p31);
#line 462 "TDocumentTest.vala"
		_tmp137_ = _tmp136_;
#line 462 "TDocumentTest.vala"
		_tmp138_ = _tmp137_;
#line 462 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp138_, "Back") == 0, "p31.value == \"Back\"");
#line 462 "TDocumentTest.vala"
		_g_free0 (_tmp138_);
#line 463 "TDocumentTest.vala"
		_tmp139_ = gxml_node_get_children_nodes (s3);
#line 463 "TDocumentTest.vala"
		_tmp140_ = _tmp139_;
#line 463 "TDocumentTest.vala"
		_tmp141_ = _tmp140_;
#line 463 "TDocumentTest.vala"
		_tmp142_ = gee_collection_get_size ((GeeCollection*) _tmp141_);
#line 463 "TDocumentTest.vala"
		_tmp143_ = _tmp142_;
#line 463 "TDocumentTest.vala"
		_vala_assert (_tmp143_ == 2, "s3.children_nodes.size == 2");
#line 463 "TDocumentTest.vala"
		_g_object_unref0 (_tmp141_);
#line 464 "TDocumentTest.vala"
		_tmp144_ = gxml_node_get_children_nodes (s3);
#line 464 "TDocumentTest.vala"
		_tmp145_ = _tmp144_;
#line 464 "TDocumentTest.vala"
		_tmp146_ = _tmp145_;
#line 464 "TDocumentTest.vala"
		_tmp147_ = gee_list_get ((GeeList*) _tmp146_, 0);
#line 464 "TDocumentTest.vala"
		_tmp148_ = (GXmlNode*) _tmp147_;
#line 464 "TDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp148_, GXML_TYPE_ELEMENT), "s3.children_nodes[0] is GXml.Element");
#line 464 "TDocumentTest.vala"
		_g_object_unref0 (_tmp148_);
#line 464 "TDocumentTest.vala"
		_g_object_unref0 (_tmp146_);
#line 465 "TDocumentTest.vala"
		_tmp149_ = gxml_node_get_children_nodes (s3);
#line 465 "TDocumentTest.vala"
		_tmp150_ = _tmp149_;
#line 465 "TDocumentTest.vala"
		_tmp151_ = _tmp150_;
#line 465 "TDocumentTest.vala"
		_tmp152_ = gee_list_get ((GeeList*) _tmp151_, 0);
#line 465 "TDocumentTest.vala"
		_tmp153_ = (GXmlNode*) _tmp152_;
#line 465 "TDocumentTest.vala"
		_tmp154_ = gxml_node_get_name (_tmp153_);
#line 465 "TDocumentTest.vala"
		_tmp155_ = _tmp154_;
#line 465 "TDocumentTest.vala"
		_tmp156_ = _tmp155_;
#line 465 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp156_, "Author") == 0, "s3.children_nodes[0].name == \"Author\"");
#line 465 "TDocumentTest.vala"
		_g_free0 (_tmp156_);
#line 465 "TDocumentTest.vala"
		_g_object_unref0 (_tmp153_);
#line 465 "TDocumentTest.vala"
		_g_object_unref0 (_tmp151_);
#line 466 "TDocumentTest.vala"
		_tmp157_ = gxml_node_get_children_nodes (s3);
#line 466 "TDocumentTest.vala"
		_tmp158_ = _tmp157_;
#line 466 "TDocumentTest.vala"
		_tmp159_ = _tmp158_;
#line 466 "TDocumentTest.vala"
		_tmp160_ = gee_list_get ((GeeList*) _tmp159_, 1);
#line 466 "TDocumentTest.vala"
		_tmp161_ = (GXmlNode*) _tmp160_;
#line 466 "TDocumentTest.vala"
		_tmp162_ = gxml_node_get_name (_tmp161_);
#line 466 "TDocumentTest.vala"
		_tmp163_ = _tmp162_;
#line 466 "TDocumentTest.vala"
		_tmp164_ = _tmp163_;
#line 466 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp164_, "Author") == 0, "s3.children_nodes[1].name == \"Author\"");
#line 466 "TDocumentTest.vala"
		_g_free0 (_tmp164_);
#line 466 "TDocumentTest.vala"
		_g_object_unref0 (_tmp161_);
#line 466 "TDocumentTest.vala"
		_g_object_unref0 (_tmp159_);
#line 467 "TDocumentTest.vala"
		_tmp165_ = gxml_node_get_children_nodes (s3);
#line 467 "TDocumentTest.vala"
		_tmp166_ = _tmp165_;
#line 467 "TDocumentTest.vala"
		_tmp167_ = _tmp166_;
#line 467 "TDocumentTest.vala"
		_tmp168_ = gee_list_get ((GeeList*) _tmp167_, 0);
#line 467 "TDocumentTest.vala"
		_tmp169_ = (GXmlNode*) _tmp168_;
#line 467 "TDocumentTest.vala"
		_g_object_unref0 (_tmp167_);
#line 467 "TDocumentTest.vala"
		a1 = _tmp169_;
#line 468 "TDocumentTest.vala"
		_vala_assert (a1 != NULL, "a1 != null");
#line 469 "TDocumentTest.vala"
		_tmp170_ = gxml_node_get_name (a1);
#line 469 "TDocumentTest.vala"
		_tmp171_ = _tmp170_;
#line 469 "TDocumentTest.vala"
		_tmp172_ = _tmp171_;
#line 469 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp172_, "Author") == 0, "a1.name == \"Author\"");
#line 469 "TDocumentTest.vala"
		_g_free0 (_tmp172_);
#line 470 "TDocumentTest.vala"
		_tmp173_ = gxml_node_get_children_nodes (a1);
#line 470 "TDocumentTest.vala"
		_tmp174_ = _tmp173_;
#line 470 "TDocumentTest.vala"
		_tmp175_ = _tmp174_;
#line 470 "TDocumentTest.vala"
		_tmp176_ = gee_collection_get_size ((GeeCollection*) _tmp175_);
#line 470 "TDocumentTest.vala"
		_tmp177_ = _tmp176_;
#line 470 "TDocumentTest.vala"
		_vala_assert (_tmp177_ == 2, "a1.children_nodes.size == 2");
#line 470 "TDocumentTest.vala"
		_g_object_unref0 (_tmp175_);
#line 471 "TDocumentTest.vala"
		_tmp178_ = gxml_node_get_children_nodes (a1);
#line 471 "TDocumentTest.vala"
		_tmp179_ = _tmp178_;
#line 471 "TDocumentTest.vala"
		_tmp180_ = _tmp179_;
#line 471 "TDocumentTest.vala"
		_tmp181_ = gee_list_get ((GeeList*) _tmp180_, 0);
#line 471 "TDocumentTest.vala"
		_tmp182_ = (GXmlNode*) _tmp181_;
#line 471 "TDocumentTest.vala"
		_tmp183_ = gxml_node_get_name (_tmp182_);
#line 471 "TDocumentTest.vala"
		_tmp184_ = _tmp183_;
#line 471 "TDocumentTest.vala"
		_tmp185_ = _tmp184_;
#line 471 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp185_, "Name") == 0, "a1.children_nodes[0].name == \"Name\"");
#line 471 "TDocumentTest.vala"
		_g_free0 (_tmp185_);
#line 471 "TDocumentTest.vala"
		_g_object_unref0 (_tmp182_);
#line 471 "TDocumentTest.vala"
		_g_object_unref0 (_tmp180_);
#line 472 "TDocumentTest.vala"
		_tmp186_ = gxml_node_get_children_nodes (a1);
#line 472 "TDocumentTest.vala"
		_tmp187_ = _tmp186_;
#line 472 "TDocumentTest.vala"
		_tmp188_ = _tmp187_;
#line 472 "TDocumentTest.vala"
		_tmp189_ = gee_list_get ((GeeList*) _tmp188_, 0);
#line 472 "TDocumentTest.vala"
		_tmp190_ = (GXmlNode*) _tmp189_;
#line 472 "TDocumentTest.vala"
		_tmp191_ = gxml_node_get_children_nodes (_tmp190_);
#line 472 "TDocumentTest.vala"
		_tmp192_ = _tmp191_;
#line 472 "TDocumentTest.vala"
		_tmp193_ = _tmp192_;
#line 472 "TDocumentTest.vala"
		_tmp194_ = gee_collection_get_size ((GeeCollection*) _tmp193_);
#line 472 "TDocumentTest.vala"
		_tmp195_ = _tmp194_;
#line 472 "TDocumentTest.vala"
		_vala_assert (_tmp195_ == 1, "a1.children_nodes[0].children_nodes.size == 1");
#line 472 "TDocumentTest.vala"
		_g_object_unref0 (_tmp193_);
#line 472 "TDocumentTest.vala"
		_g_object_unref0 (_tmp190_);
#line 472 "TDocumentTest.vala"
		_g_object_unref0 (_tmp188_);
#line 473 "TDocumentTest.vala"
		_tmp196_ = gxml_node_get_children_nodes (a1);
#line 473 "TDocumentTest.vala"
		_tmp197_ = _tmp196_;
#line 473 "TDocumentTest.vala"
		_tmp198_ = _tmp197_;
#line 473 "TDocumentTest.vala"
		_tmp199_ = gee_list_get ((GeeList*) _tmp198_, 0);
#line 473 "TDocumentTest.vala"
		_tmp200_ = (GXmlNode*) _tmp199_;
#line 473 "TDocumentTest.vala"
		_tmp201_ = gxml_node_get_children_nodes (_tmp200_);
#line 473 "TDocumentTest.vala"
		_tmp202_ = _tmp201_;
#line 473 "TDocumentTest.vala"
		_tmp203_ = _tmp202_;
#line 473 "TDocumentTest.vala"
		_tmp204_ = gee_list_get ((GeeList*) _tmp203_, 0);
#line 473 "TDocumentTest.vala"
		_tmp205_ = (GXmlNode*) _tmp204_;
#line 473 "TDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp205_, GXML_TYPE_TEXT), "a1.children_nodes[0].children_nodes[0] is GXml.Text");
#line 473 "TDocumentTest.vala"
		_g_object_unref0 (_tmp205_);
#line 473 "TDocumentTest.vala"
		_g_object_unref0 (_tmp203_);
#line 473 "TDocumentTest.vala"
		_g_object_unref0 (_tmp200_);
#line 473 "TDocumentTest.vala"
		_g_object_unref0 (_tmp198_);
#line 474 "TDocumentTest.vala"
		_tmp206_ = gxml_node_get_children_nodes (a1);
#line 474 "TDocumentTest.vala"
		_tmp207_ = _tmp206_;
#line 474 "TDocumentTest.vala"
		_tmp208_ = _tmp207_;
#line 474 "TDocumentTest.vala"
		_tmp209_ = gee_list_get ((GeeList*) _tmp208_, 0);
#line 474 "TDocumentTest.vala"
		_tmp210_ = (GXmlNode*) _tmp209_;
#line 474 "TDocumentTest.vala"
		_tmp211_ = gxml_node_get_children_nodes (_tmp210_);
#line 474 "TDocumentTest.vala"
		_tmp212_ = _tmp211_;
#line 474 "TDocumentTest.vala"
		_tmp213_ = _tmp212_;
#line 474 "TDocumentTest.vala"
		_tmp214_ = gee_list_get ((GeeList*) _tmp213_, 0);
#line 474 "TDocumentTest.vala"
		_tmp215_ = (GXmlNode*) _tmp214_;
#line 474 "TDocumentTest.vala"
		_tmp216_ = gxml_node_get_value (_tmp215_);
#line 474 "TDocumentTest.vala"
		_tmp217_ = _tmp216_;
#line 474 "TDocumentTest.vala"
		_tmp218_ = _tmp217_;
#line 474 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp218_, "Fred") == 0, "a1.children_nodes[0].children_nodes[0].value == \"Fred\"");
#line 474 "TDocumentTest.vala"
		_g_free0 (_tmp218_);
#line 474 "TDocumentTest.vala"
		_g_object_unref0 (_tmp215_);
#line 474 "TDocumentTest.vala"
		_g_object_unref0 (_tmp213_);
#line 474 "TDocumentTest.vala"
		_g_object_unref0 (_tmp210_);
#line 474 "TDocumentTest.vala"
		_g_object_unref0 (_tmp208_);
#line 475 "TDocumentTest.vala"
		_tmp219_ = gxml_node_get_children_nodes (a1);
#line 475 "TDocumentTest.vala"
		_tmp220_ = _tmp219_;
#line 475 "TDocumentTest.vala"
		_tmp221_ = _tmp220_;
#line 475 "TDocumentTest.vala"
		_tmp222_ = gee_list_get ((GeeList*) _tmp221_, 1);
#line 475 "TDocumentTest.vala"
		_tmp223_ = (GXmlNode*) _tmp222_;
#line 475 "TDocumentTest.vala"
		_tmp224_ = gxml_node_get_name (_tmp223_);
#line 475 "TDocumentTest.vala"
		_tmp225_ = _tmp224_;
#line 475 "TDocumentTest.vala"
		_tmp226_ = _tmp225_;
#line 475 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp226_, "Email") == 0, "a1.children_nodes[1].name == \"Email\"");
#line 475 "TDocumentTest.vala"
		_g_free0 (_tmp226_);
#line 475 "TDocumentTest.vala"
		_g_object_unref0 (_tmp223_);
#line 475 "TDocumentTest.vala"
		_g_object_unref0 (_tmp221_);
#line 476 "TDocumentTest.vala"
		_tmp227_ = gxml_node_get_children_nodes (a1);
#line 476 "TDocumentTest.vala"
		_tmp228_ = _tmp227_;
#line 476 "TDocumentTest.vala"
		_tmp229_ = _tmp228_;
#line 476 "TDocumentTest.vala"
		_tmp230_ = gee_list_get ((GeeList*) _tmp229_, 1);
#line 476 "TDocumentTest.vala"
		_tmp231_ = (GXmlNode*) _tmp230_;
#line 476 "TDocumentTest.vala"
		_tmp232_ = gxml_node_get_children_nodes (_tmp231_);
#line 476 "TDocumentTest.vala"
		_tmp233_ = _tmp232_;
#line 476 "TDocumentTest.vala"
		_tmp234_ = _tmp233_;
#line 476 "TDocumentTest.vala"
		_tmp235_ = gee_collection_get_size ((GeeCollection*) _tmp234_);
#line 476 "TDocumentTest.vala"
		_tmp236_ = _tmp235_;
#line 476 "TDocumentTest.vala"
		_vala_assert (_tmp236_ == 1, "a1.children_nodes[1].children_nodes.size == 1");
#line 476 "TDocumentTest.vala"
		_g_object_unref0 (_tmp234_);
#line 476 "TDocumentTest.vala"
		_g_object_unref0 (_tmp231_);
#line 476 "TDocumentTest.vala"
		_g_object_unref0 (_tmp229_);
#line 477 "TDocumentTest.vala"
		_tmp237_ = gxml_node_get_children_nodes (a1);
#line 477 "TDocumentTest.vala"
		_tmp238_ = _tmp237_;
#line 477 "TDocumentTest.vala"
		_tmp239_ = _tmp238_;
#line 477 "TDocumentTest.vala"
		_tmp240_ = gee_list_get ((GeeList*) _tmp239_, 1);
#line 477 "TDocumentTest.vala"
		_tmp241_ = (GXmlNode*) _tmp240_;
#line 477 "TDocumentTest.vala"
		_tmp242_ = gxml_node_get_children_nodes (_tmp241_);
#line 477 "TDocumentTest.vala"
		_tmp243_ = _tmp242_;
#line 477 "TDocumentTest.vala"
		_tmp244_ = _tmp243_;
#line 477 "TDocumentTest.vala"
		_tmp245_ = gee_list_get ((GeeList*) _tmp244_, 0);
#line 477 "TDocumentTest.vala"
		_tmp246_ = (GXmlNode*) _tmp245_;
#line 477 "TDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp246_, GXML_TYPE_TEXT), "a1.children_nodes[1].children_nodes[0] is GXml.Text");
#line 477 "TDocumentTest.vala"
		_g_object_unref0 (_tmp246_);
#line 477 "TDocumentTest.vala"
		_g_object_unref0 (_tmp244_);
#line 477 "TDocumentTest.vala"
		_g_object_unref0 (_tmp241_);
#line 477 "TDocumentTest.vala"
		_g_object_unref0 (_tmp239_);
#line 478 "TDocumentTest.vala"
		_tmp247_ = gxml_node_get_children_nodes (a1);
#line 478 "TDocumentTest.vala"
		_tmp248_ = _tmp247_;
#line 478 "TDocumentTest.vala"
		_tmp249_ = _tmp248_;
#line 478 "TDocumentTest.vala"
		_tmp250_ = gee_list_get ((GeeList*) _tmp249_, 1);
#line 478 "TDocumentTest.vala"
		_tmp251_ = (GXmlNode*) _tmp250_;
#line 478 "TDocumentTest.vala"
		_tmp252_ = gxml_node_get_children_nodes (_tmp251_);
#line 478 "TDocumentTest.vala"
		_tmp253_ = _tmp252_;
#line 478 "TDocumentTest.vala"
		_tmp254_ = _tmp253_;
#line 478 "TDocumentTest.vala"
		_tmp255_ = gee_list_get ((GeeList*) _tmp254_, 0);
#line 478 "TDocumentTest.vala"
		_tmp256_ = (GXmlNode*) _tmp255_;
#line 478 "TDocumentTest.vala"
		_tmp257_ = gxml_node_get_value (_tmp256_);
#line 478 "TDocumentTest.vala"
		_tmp258_ = _tmp257_;
#line 478 "TDocumentTest.vala"
		_tmp259_ = _tmp258_;
#line 478 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp259_, "fweasley@hogwarts.co.uk") == 0, "a1.children_nodes[1].children_nodes[0].value == \"fweasley@hogwarts.co.uk\"");
#line 478 "TDocumentTest.vala"
		_g_free0 (_tmp259_);
#line 478 "TDocumentTest.vala"
		_g_object_unref0 (_tmp256_);
#line 478 "TDocumentTest.vala"
		_g_object_unref0 (_tmp254_);
#line 478 "TDocumentTest.vala"
		_g_object_unref0 (_tmp251_);
#line 478 "TDocumentTest.vala"
		_g_object_unref0 (_tmp249_);
#line 479 "TDocumentTest.vala"
		_tmp260_ = gxml_node_get_children_nodes (s3);
#line 479 "TDocumentTest.vala"
		_tmp261_ = _tmp260_;
#line 479 "TDocumentTest.vala"
		_tmp262_ = _tmp261_;
#line 479 "TDocumentTest.vala"
		_tmp263_ = gee_list_get ((GeeList*) _tmp262_, 1);
#line 479 "TDocumentTest.vala"
		_tmp264_ = (GXmlNode*) _tmp263_;
#line 479 "TDocumentTest.vala"
		_g_object_unref0 (_tmp262_);
#line 479 "TDocumentTest.vala"
		a2 = _tmp264_;
#line 480 "TDocumentTest.vala"
		_vala_assert (a2 != NULL, "a2 != null");
#line 481 "TDocumentTest.vala"
		_tmp265_ = gxml_node_get_children_nodes (a2);
#line 481 "TDocumentTest.vala"
		_tmp266_ = _tmp265_;
#line 481 "TDocumentTest.vala"
		_tmp267_ = _tmp266_;
#line 481 "TDocumentTest.vala"
		_tmp268_ = gee_collection_get_size ((GeeCollection*) _tmp267_);
#line 481 "TDocumentTest.vala"
		_tmp269_ = _tmp268_;
#line 481 "TDocumentTest.vala"
		_vala_assert (_tmp269_ == 3, "a2.children_nodes.size == 3");
#line 481 "TDocumentTest.vala"
		_g_object_unref0 (_tmp267_);
#line 482 "TDocumentTest.vala"
		_tmp270_ = gxml_node_get_children_nodes (a2);
#line 482 "TDocumentTest.vala"
		_tmp271_ = _tmp270_;
#line 482 "TDocumentTest.vala"
		_tmp272_ = _tmp271_;
#line 482 "TDocumentTest.vala"
		_tmp273_ = gee_list_get ((GeeList*) _tmp272_, 1);
#line 482 "TDocumentTest.vala"
		_tmp274_ = (GXmlNode*) _tmp273_;
#line 482 "TDocumentTest.vala"
		_tmp275_ = gxml_node_get_name (_tmp274_);
#line 482 "TDocumentTest.vala"
		_tmp276_ = _tmp275_;
#line 482 "TDocumentTest.vala"
		_tmp277_ = _tmp276_;
#line 482 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp277_, "Name") == 0, "a2.children_nodes[1].name == \"Name\"");
#line 482 "TDocumentTest.vala"
		_g_free0 (_tmp277_);
#line 482 "TDocumentTest.vala"
		_g_object_unref0 (_tmp274_);
#line 482 "TDocumentTest.vala"
		_g_object_unref0 (_tmp272_);
#line 483 "TDocumentTest.vala"
		_tmp278_ = gxml_node_get_children_nodes (a2);
#line 483 "TDocumentTest.vala"
		_tmp279_ = _tmp278_;
#line 483 "TDocumentTest.vala"
		_tmp280_ = _tmp279_;
#line 483 "TDocumentTest.vala"
		_tmp281_ = gee_list_get ((GeeList*) _tmp280_, 1);
#line 483 "TDocumentTest.vala"
		_tmp282_ = (GXmlNode*) _tmp281_;
#line 483 "TDocumentTest.vala"
		_tmp283_ = gxml_node_get_children_nodes (_tmp282_);
#line 483 "TDocumentTest.vala"
		_tmp284_ = _tmp283_;
#line 483 "TDocumentTest.vala"
		_tmp285_ = _tmp284_;
#line 483 "TDocumentTest.vala"
		_tmp286_ = gee_collection_get_size ((GeeCollection*) _tmp285_);
#line 483 "TDocumentTest.vala"
		_tmp287_ = _tmp286_;
#line 483 "TDocumentTest.vala"
		_vala_assert (_tmp287_ == 1, "a2.children_nodes[1].children_nodes.size == 1");
#line 483 "TDocumentTest.vala"
		_g_object_unref0 (_tmp285_);
#line 483 "TDocumentTest.vala"
		_g_object_unref0 (_tmp282_);
#line 483 "TDocumentTest.vala"
		_g_object_unref0 (_tmp280_);
#line 484 "TDocumentTest.vala"
		_tmp288_ = gxml_node_get_children_nodes (a2);
#line 484 "TDocumentTest.vala"
		_tmp289_ = _tmp288_;
#line 484 "TDocumentTest.vala"
		_tmp290_ = _tmp289_;
#line 484 "TDocumentTest.vala"
		_tmp291_ = gee_list_get ((GeeList*) _tmp290_, 1);
#line 484 "TDocumentTest.vala"
		_tmp292_ = (GXmlNode*) _tmp291_;
#line 484 "TDocumentTest.vala"
		_tmp293_ = gxml_node_get_children_nodes (_tmp292_);
#line 484 "TDocumentTest.vala"
		_tmp294_ = _tmp293_;
#line 484 "TDocumentTest.vala"
		_tmp295_ = _tmp294_;
#line 484 "TDocumentTest.vala"
		_tmp296_ = gee_list_get ((GeeList*) _tmp295_, 0);
#line 484 "TDocumentTest.vala"
		_tmp297_ = (GXmlNode*) _tmp296_;
#line 484 "TDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp297_, GXML_TYPE_TEXT), "a2.children_nodes[1].children_nodes[0] is GXml.Text");
#line 484 "TDocumentTest.vala"
		_g_object_unref0 (_tmp297_);
#line 484 "TDocumentTest.vala"
		_g_object_unref0 (_tmp295_);
#line 484 "TDocumentTest.vala"
		_g_object_unref0 (_tmp292_);
#line 484 "TDocumentTest.vala"
		_g_object_unref0 (_tmp290_);
#line 485 "TDocumentTest.vala"
		_tmp298_ = gxml_node_get_children_nodes (a2);
#line 485 "TDocumentTest.vala"
		_tmp299_ = _tmp298_;
#line 485 "TDocumentTest.vala"
		_tmp300_ = _tmp299_;
#line 485 "TDocumentTest.vala"
		_tmp301_ = gee_list_get ((GeeList*) _tmp300_, 1);
#line 485 "TDocumentTest.vala"
		_tmp302_ = (GXmlNode*) _tmp301_;
#line 485 "TDocumentTest.vala"
		_tmp303_ = gxml_node_get_children_nodes (_tmp302_);
#line 485 "TDocumentTest.vala"
		_tmp304_ = _tmp303_;
#line 485 "TDocumentTest.vala"
		_tmp305_ = _tmp304_;
#line 485 "TDocumentTest.vala"
		_tmp306_ = gee_list_get ((GeeList*) _tmp305_, 0);
#line 485 "TDocumentTest.vala"
		_tmp307_ = (GXmlNode*) _tmp306_;
#line 485 "TDocumentTest.vala"
		_tmp308_ = gxml_node_get_value (_tmp307_);
#line 485 "TDocumentTest.vala"
		_tmp309_ = _tmp308_;
#line 485 "TDocumentTest.vala"
		_tmp310_ = _tmp309_;
#line 485 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp310_, "George") == 0, "a2.children_nodes[1].children_nodes[0].value == \"George\"");
#line 485 "TDocumentTest.vala"
		_g_free0 (_tmp310_);
#line 485 "TDocumentTest.vala"
		_g_object_unref0 (_tmp307_);
#line 485 "TDocumentTest.vala"
		_g_object_unref0 (_tmp305_);
#line 485 "TDocumentTest.vala"
		_g_object_unref0 (_tmp302_);
#line 485 "TDocumentTest.vala"
		_g_object_unref0 (_tmp300_);
#line 486 "TDocumentTest.vala"
		_tmp311_ = gxml_node_get_children_nodes (a2);
#line 486 "TDocumentTest.vala"
		_tmp312_ = _tmp311_;
#line 486 "TDocumentTest.vala"
		_tmp313_ = _tmp312_;
#line 486 "TDocumentTest.vala"
		_tmp314_ = gee_list_get ((GeeList*) _tmp313_, 2);
#line 486 "TDocumentTest.vala"
		_tmp315_ = (GXmlNode*) _tmp314_;
#line 486 "TDocumentTest.vala"
		_tmp316_ = gxml_node_get_name (_tmp315_);
#line 486 "TDocumentTest.vala"
		_tmp317_ = _tmp316_;
#line 486 "TDocumentTest.vala"
		_tmp318_ = _tmp317_;
#line 486 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp318_, "Email") == 0, "a2.children_nodes[2].name == \"Email\"");
#line 486 "TDocumentTest.vala"
		_g_free0 (_tmp318_);
#line 486 "TDocumentTest.vala"
		_g_object_unref0 (_tmp315_);
#line 486 "TDocumentTest.vala"
		_g_object_unref0 (_tmp313_);
#line 487 "TDocumentTest.vala"
		_tmp319_ = gxml_node_get_children_nodes (a2);
#line 487 "TDocumentTest.vala"
		_tmp320_ = _tmp319_;
#line 487 "TDocumentTest.vala"
		_tmp321_ = _tmp320_;
#line 487 "TDocumentTest.vala"
		_tmp322_ = gee_list_get ((GeeList*) _tmp321_, 2);
#line 487 "TDocumentTest.vala"
		_tmp323_ = (GXmlNode*) _tmp322_;
#line 487 "TDocumentTest.vala"
		_tmp324_ = gxml_node_get_children_nodes (_tmp323_);
#line 487 "TDocumentTest.vala"
		_tmp325_ = _tmp324_;
#line 487 "TDocumentTest.vala"
		_tmp326_ = _tmp325_;
#line 487 "TDocumentTest.vala"
		_tmp327_ = gee_collection_get_size ((GeeCollection*) _tmp326_);
#line 487 "TDocumentTest.vala"
		_tmp328_ = _tmp327_;
#line 487 "TDocumentTest.vala"
		_vala_assert (_tmp328_ == 1, "a2.children_nodes[2].children_nodes.size == 1");
#line 487 "TDocumentTest.vala"
		_g_object_unref0 (_tmp326_);
#line 487 "TDocumentTest.vala"
		_g_object_unref0 (_tmp323_);
#line 487 "TDocumentTest.vala"
		_g_object_unref0 (_tmp321_);
#line 488 "TDocumentTest.vala"
		_tmp329_ = gxml_node_get_children_nodes (a2);
#line 488 "TDocumentTest.vala"
		_tmp330_ = _tmp329_;
#line 488 "TDocumentTest.vala"
		_tmp331_ = _tmp330_;
#line 488 "TDocumentTest.vala"
		_tmp332_ = gee_list_get ((GeeList*) _tmp331_, 2);
#line 488 "TDocumentTest.vala"
		_tmp333_ = (GXmlNode*) _tmp332_;
#line 488 "TDocumentTest.vala"
		_tmp334_ = gxml_node_get_children_nodes (_tmp333_);
#line 488 "TDocumentTest.vala"
		_tmp335_ = _tmp334_;
#line 488 "TDocumentTest.vala"
		_tmp336_ = _tmp335_;
#line 488 "TDocumentTest.vala"
		_tmp337_ = gee_list_get ((GeeList*) _tmp336_, 0);
#line 488 "TDocumentTest.vala"
		_tmp338_ = (GXmlNode*) _tmp337_;
#line 488 "TDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp338_, GXML_TYPE_TEXT), "a2.children_nodes[2].children_nodes[0] is GXml.Text");
#line 488 "TDocumentTest.vala"
		_g_object_unref0 (_tmp338_);
#line 488 "TDocumentTest.vala"
		_g_object_unref0 (_tmp336_);
#line 488 "TDocumentTest.vala"
		_g_object_unref0 (_tmp333_);
#line 488 "TDocumentTest.vala"
		_g_object_unref0 (_tmp331_);
#line 489 "TDocumentTest.vala"
		_tmp339_ = gxml_node_get_children_nodes (a2);
#line 489 "TDocumentTest.vala"
		_tmp340_ = _tmp339_;
#line 489 "TDocumentTest.vala"
		_tmp341_ = _tmp340_;
#line 489 "TDocumentTest.vala"
		_tmp342_ = gee_list_get ((GeeList*) _tmp341_, 2);
#line 489 "TDocumentTest.vala"
		_tmp343_ = (GXmlNode*) _tmp342_;
#line 489 "TDocumentTest.vala"
		_tmp344_ = gxml_node_get_children_nodes (_tmp343_);
#line 489 "TDocumentTest.vala"
		_tmp345_ = _tmp344_;
#line 489 "TDocumentTest.vala"
		_tmp346_ = _tmp345_;
#line 489 "TDocumentTest.vala"
		_tmp347_ = gee_list_get ((GeeList*) _tmp346_, 0);
#line 489 "TDocumentTest.vala"
		_tmp348_ = (GXmlNode*) _tmp347_;
#line 489 "TDocumentTest.vala"
		_tmp349_ = gxml_node_get_value (_tmp348_);
#line 489 "TDocumentTest.vala"
		_tmp350_ = _tmp349_;
#line 489 "TDocumentTest.vala"
		_tmp351_ = _tmp350_;
#line 489 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp351_, "gweasley@hogwarts.co.uk") == 0, "a2.children_nodes[2].children_nodes[0].value == \"gweasley@hogwarts.co.uk\"");
#line 489 "TDocumentTest.vala"
		_g_free0 (_tmp351_);
#line 489 "TDocumentTest.vala"
		_g_object_unref0 (_tmp348_);
#line 489 "TDocumentTest.vala"
		_g_object_unref0 (_tmp346_);
#line 489 "TDocumentTest.vala"
		_g_object_unref0 (_tmp343_);
#line 489 "TDocumentTest.vala"
		_g_object_unref0 (_tmp341_);
#line 425 "TDocumentTest.vala"
		_g_object_unref0 (a2);
#line 425 "TDocumentTest.vala"
		_g_object_unref0 (a1);
#line 425 "TDocumentTest.vala"
		_g_object_unref0 (p31);
#line 425 "TDocumentTest.vala"
		_g_object_unref0 (p3);
#line 425 "TDocumentTest.vala"
		_g_object_unref0 (s3);
#line 425 "TDocumentTest.vala"
		_g_object_unref0 (p2);
#line 425 "TDocumentTest.vala"
		_g_object_unref0 (s2);
#line 425 "TDocumentTest.vala"
		_g_object_unref0 (p1);
#line 425 "TDocumentTest.vala"
		_g_object_unref0 (s1);
#line 425 "TDocumentTest.vala"
		_g_object_unref0 (d);
#line 425 "TDocumentTest.vala"
		_g_object_unref0 (f);
#line 6288 "TDocumentTest.c"
	}
	goto __finally275;
	__catch275_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp352_;
		gchar* _tmp353_;
		gchar* _tmp354_;
#line 425 "TDocumentTest.vala"
		e = _inner_error0_;
#line 425 "TDocumentTest.vala"
		_inner_error0_ = NULL;
#line 490 "TDocumentTest.vala"
		_tmp352_ = e->message;
#line 490 "TDocumentTest.vala"
		_tmp353_ = g_strconcat ("ERROR: ", _tmp352_, NULL);
#line 490 "TDocumentTest.vala"
		_tmp354_ = _tmp353_;
#line 490 "TDocumentTest.vala"
		g_message ("TDocumentTest.vala:490: %s", _tmp354_);
#line 490 "TDocumentTest.vala"
		_g_free0 (_tmp354_);
#line 490 "TDocumentTest.vala"
		g_assert_not_reached ();
#line 425 "TDocumentTest.vala"
		_g_error_free0 (e);
#line 6315 "TDocumentTest.c"
	}
	__finally275:
#line 425 "TDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 425 "TDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 425 "TDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 425 "TDocumentTest.vala"
		return;
#line 6326 "TDocumentTest.c"
	}
}

static void
___lambda219__gtest_func (void)
{
#line 424 "TDocumentTest.vala"
	__lambda219_ ();
#line 6335 "TDocumentTest.c"
}

static void
__lambda220_ (void)
{
	GFile* f = NULL;
	GFile* _tmp0_;
	GXmlTDocument* d = NULL;
	GXmlTDocument* _tmp1_;
	GXmlNode* _tmp2_;
	GXmlNode* _tmp3_;
	GXmlNode* _tmp4_;
	GXmlNode* _tmp5_;
	GXmlNode* _tmp6_;
	GXmlNode* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	GXmlNode* _tmp11_;
	GXmlNode* _tmp12_;
	GXmlNode* _tmp13_;
	GeeList* _tmp14_;
	GeeList* _tmp15_;
	GeeList* _tmp16_;
	gint _tmp17_;
	gint _tmp18_;
	GXmlNode* _tmp19_;
	GXmlNode* _tmp20_;
	GXmlNode* _tmp21_;
	GeeList* _tmp22_;
	GeeList* _tmp23_;
	GeeList* _tmp24_;
	gpointer _tmp25_;
	GXmlNamespace* _tmp26_;
	gchar* _tmp27_;
	gchar* _tmp28_;
	gchar* _tmp29_;
	GXmlNode* _tmp30_;
	GXmlNode* _tmp31_;
	GXmlNode* _tmp32_;
	GeeList* _tmp33_;
	GeeList* _tmp34_;
	GeeList* _tmp35_;
	gpointer _tmp36_;
	GXmlNamespace* _tmp37_;
	gchar* _tmp38_;
	gchar* _tmp39_;
	gchar* _tmp40_;
	GXmlNode* _tmp41_;
	GXmlNode* _tmp42_;
	GXmlNode* _tmp43_;
	GeeList* _tmp44_;
	GeeList* _tmp45_;
	GeeList* _tmp46_;
	gpointer _tmp47_;
	GXmlNamespace* _tmp48_;
	gchar* _tmp49_;
	gchar* _tmp50_;
	gchar* _tmp51_;
	GXmlNode* _tmp52_;
	GXmlNode* _tmp53_;
	GXmlNode* _tmp54_;
	GeeList* _tmp55_;
	GeeList* _tmp56_;
	GeeList* _tmp57_;
	gpointer _tmp58_;
	GXmlNamespace* _tmp59_;
	gchar* _tmp60_;
	gchar* _tmp61_;
	gchar* _tmp62_;
	GXmlNode* a = NULL;
	GXmlNode* _tmp63_;
	GXmlNode* _tmp64_;
	GXmlNode* _tmp65_;
	GeeBidirList* _tmp66_;
	GeeBidirList* _tmp67_;
	GeeBidirList* _tmp68_;
	gpointer _tmp69_;
	GXmlNode* _tmp70_;
	gchar* _tmp71_;
	gchar* _tmp72_;
	gchar* _tmp73_;
	GeeList* _tmp74_;
	GeeList* _tmp75_;
	GeeList* _tmp76_;
	gint _tmp77_;
	gint _tmp78_;
	GeeList* _tmp79_;
	GeeList* _tmp80_;
	GeeList* _tmp81_;
	gpointer _tmp82_;
	GXmlNamespace* _tmp83_;
	gchar* _tmp84_;
	gchar* _tmp85_;
	gchar* _tmp86_;
	GeeList* _tmp87_;
	GeeList* _tmp88_;
	GeeList* _tmp89_;
	gpointer _tmp90_;
	GXmlNamespace* _tmp91_;
	gchar* _tmp92_;
	gchar* _tmp93_;
	gchar* _tmp94_;
	GeeBidirList* _tmp95_;
	GeeBidirList* _tmp96_;
	GeeBidirList* _tmp97_;
	gpointer _tmp98_;
	GXmlNode* _tmp99_;
	GXmlNode* a1 = NULL;
	GeeBidirList* _tmp100_;
	GeeBidirList* _tmp101_;
	GeeBidirList* _tmp102_;
	gpointer _tmp103_;
	GXmlNode* _tmp104_;
	gchar* _tmp105_;
	gchar* _tmp106_;
	gchar* _tmp107_;
	GXmlNode* e = NULL;
	GeeBidirList* _tmp108_;
	GeeBidirList* _tmp109_;
	GeeBidirList* _tmp110_;
	gpointer _tmp111_;
	GXmlNode* _tmp112_;
	gchar* _tmp113_;
	gchar* _tmp114_;
	gchar* _tmp115_;
	GeeList* _tmp116_;
	GeeList* _tmp117_;
	GeeList* _tmp118_;
	gint _tmp119_;
	gint _tmp120_;
	GeeList* _tmp121_;
	GeeList* _tmp122_;
	GeeList* _tmp123_;
	gpointer _tmp124_;
	GXmlNamespace* _tmp125_;
	gchar* _tmp126_;
	gchar* _tmp127_;
	gchar* _tmp128_;
	GeeList* _tmp129_;
	GeeList* _tmp130_;
	GeeList* _tmp131_;
	gpointer _tmp132_;
	GXmlNamespace* _tmp133_;
	gchar* _tmp134_;
	gchar* _tmp135_;
	gchar* _tmp136_;
	GXmlNode* b = NULL;
	GXmlNode* _tmp137_;
	GXmlNode* _tmp138_;
	GXmlNode* _tmp139_;
	GeeBidirList* _tmp140_;
	GeeBidirList* _tmp141_;
	GeeBidirList* _tmp142_;
	gpointer _tmp143_;
	GXmlNode* _tmp144_;
	gchar* _tmp145_;
	gchar* _tmp146_;
	gchar* _tmp147_;
	GeeList* _tmp148_;
	GeeList* _tmp149_;
	GeeList* _tmp150_;
	gint _tmp151_;
	gint _tmp152_;
	GeeList* _tmp153_;
	GeeList* _tmp154_;
	GeeList* _tmp155_;
	gpointer _tmp156_;
	GXmlNamespace* _tmp157_;
	gchar* _tmp158_;
	gchar* _tmp159_;
	gchar* _tmp160_;
	GeeList* _tmp161_;
	GeeList* _tmp162_;
	GeeList* _tmp163_;
	gpointer _tmp164_;
	GXmlNamespace* _tmp165_;
	gchar* _tmp166_;
	gchar* _tmp167_;
	gchar* _tmp168_;
	GXmlNode* bp = NULL;
	GeeMap* _tmp169_;
	GeeMap* _tmp170_;
	GeeMap* _tmp171_;
	gpointer _tmp172_;
	GXmlNode* _tmp173_;
	gchar* _tmp174_;
	gchar* _tmp175_;
	gchar* _tmp176_;
	GeeList* _tmp177_;
	GeeList* _tmp178_;
	GeeList* _tmp179_;
	gint _tmp180_;
	gint _tmp181_;
	GeeList* _tmp182_;
	GeeList* _tmp183_;
	GeeList* _tmp184_;
	gpointer _tmp185_;
	GXmlNamespace* _tmp186_;
	gchar* _tmp187_;
	gchar* _tmp188_;
	gchar* _tmp189_;
	GeeList* _tmp190_;
	GeeList* _tmp191_;
	GeeList* _tmp192_;
	gpointer _tmp193_;
	GXmlNamespace* _tmp194_;
	gchar* _tmp195_;
	gchar* _tmp196_;
	gchar* _tmp197_;
#line 493 "TDocumentTest.vala"
	_tmp0_ = g_file_new_for_path (TEST_DIR "/t-read-test.xml");
#line 493 "TDocumentTest.vala"
	f = _tmp0_;
#line 494 "TDocumentTest.vala"
	_vala_assert (g_file_query_exists (f, NULL), "f.query_exists ()");
#line 495 "TDocumentTest.vala"
	_tmp1_ = gxml_tdocument_new_from_file (f);
#line 495 "TDocumentTest.vala"
	d = _tmp1_;
#line 497 "TDocumentTest.vala"
	_tmp2_ = gxml_document_get_root ((GXmlDocument*) d);
#line 497 "TDocumentTest.vala"
	_tmp3_ = _tmp2_;
#line 497 "TDocumentTest.vala"
	_tmp4_ = _tmp3_;
#line 497 "TDocumentTest.vala"
	_vala_assert (_tmp4_ != NULL, "d.root != null");
#line 497 "TDocumentTest.vala"
	_g_object_unref0 (_tmp4_);
#line 498 "TDocumentTest.vala"
	_tmp5_ = gxml_document_get_root ((GXmlDocument*) d);
#line 498 "TDocumentTest.vala"
	_tmp6_ = _tmp5_;
#line 498 "TDocumentTest.vala"
	_tmp7_ = _tmp6_;
#line 498 "TDocumentTest.vala"
	_tmp8_ = gxml_node_get_name (_tmp7_);
#line 498 "TDocumentTest.vala"
	_tmp9_ = _tmp8_;
#line 498 "TDocumentTest.vala"
	_tmp10_ = _tmp9_;
#line 498 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp10_, "Sentences") == 0, "d.root.name == \"Sentences\"");
#line 498 "TDocumentTest.vala"
	_g_free0 (_tmp10_);
#line 498 "TDocumentTest.vala"
	_g_object_unref0 (_tmp7_);
#line 499 "TDocumentTest.vala"
	_tmp11_ = gxml_document_get_root ((GXmlDocument*) d);
#line 499 "TDocumentTest.vala"
	_tmp12_ = _tmp11_;
#line 499 "TDocumentTest.vala"
	_tmp13_ = _tmp12_;
#line 499 "TDocumentTest.vala"
	_tmp14_ = gxml_node_get_namespaces (_tmp13_);
#line 499 "TDocumentTest.vala"
	_tmp15_ = _tmp14_;
#line 499 "TDocumentTest.vala"
	_tmp16_ = _tmp15_;
#line 499 "TDocumentTest.vala"
	_tmp17_ = gee_collection_get_size ((GeeCollection*) _tmp16_);
#line 499 "TDocumentTest.vala"
	_tmp18_ = _tmp17_;
#line 499 "TDocumentTest.vala"
	_vala_assert (_tmp18_ == 2, "d.root.namespaces.size == 2");
#line 499 "TDocumentTest.vala"
	_g_object_unref0 (_tmp16_);
#line 499 "TDocumentTest.vala"
	_g_object_unref0 (_tmp13_);
#line 500 "TDocumentTest.vala"
	_tmp19_ = gxml_document_get_root ((GXmlDocument*) d);
#line 500 "TDocumentTest.vala"
	_tmp20_ = _tmp19_;
#line 500 "TDocumentTest.vala"
	_tmp21_ = _tmp20_;
#line 500 "TDocumentTest.vala"
	_tmp22_ = gxml_node_get_namespaces (_tmp21_);
#line 500 "TDocumentTest.vala"
	_tmp23_ = _tmp22_;
#line 500 "TDocumentTest.vala"
	_tmp24_ = _tmp23_;
#line 500 "TDocumentTest.vala"
	_tmp25_ = gee_list_get (_tmp24_, 0);
#line 500 "TDocumentTest.vala"
	_tmp26_ = (GXmlNamespace*) _tmp25_;
#line 500 "TDocumentTest.vala"
	_tmp27_ = gxml_namespace_get_prefix (_tmp26_);
#line 500 "TDocumentTest.vala"
	_tmp28_ = _tmp27_;
#line 500 "TDocumentTest.vala"
	_tmp29_ = _tmp28_;
#line 500 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp29_, "gxml") == 0, "d.root.namespaces[0].prefix == \"gxml\"");
#line 500 "TDocumentTest.vala"
	_g_free0 (_tmp29_);
#line 500 "TDocumentTest.vala"
	_g_object_unref0 (_tmp26_);
#line 500 "TDocumentTest.vala"
	_g_object_unref0 (_tmp24_);
#line 500 "TDocumentTest.vala"
	_g_object_unref0 (_tmp21_);
#line 501 "TDocumentTest.vala"
	_tmp30_ = gxml_document_get_root ((GXmlDocument*) d);
#line 501 "TDocumentTest.vala"
	_tmp31_ = _tmp30_;
#line 501 "TDocumentTest.vala"
	_tmp32_ = _tmp31_;
#line 501 "TDocumentTest.vala"
	_tmp33_ = gxml_node_get_namespaces (_tmp32_);
#line 501 "TDocumentTest.vala"
	_tmp34_ = _tmp33_;
#line 501 "TDocumentTest.vala"
	_tmp35_ = _tmp34_;
#line 501 "TDocumentTest.vala"
	_tmp36_ = gee_list_get (_tmp35_, 0);
#line 501 "TDocumentTest.vala"
	_tmp37_ = (GXmlNamespace*) _tmp36_;
#line 501 "TDocumentTest.vala"
	_tmp38_ = gxml_namespace_get_uri (_tmp37_);
#line 501 "TDocumentTest.vala"
	_tmp39_ = _tmp38_;
#line 501 "TDocumentTest.vala"
	_tmp40_ = _tmp39_;
#line 501 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp40_, "http://wiki.gnome.org/GXml") == 0, "d.root.namespaces[0].uri == \"http://wiki.gnome.org/GXml\"");
#line 501 "TDocumentTest.vala"
	_g_free0 (_tmp40_);
#line 501 "TDocumentTest.vala"
	_g_object_unref0 (_tmp37_);
#line 501 "TDocumentTest.vala"
	_g_object_unref0 (_tmp35_);
#line 501 "TDocumentTest.vala"
	_g_object_unref0 (_tmp32_);
#line 502 "TDocumentTest.vala"
	_tmp41_ = gxml_document_get_root ((GXmlDocument*) d);
#line 502 "TDocumentTest.vala"
	_tmp42_ = _tmp41_;
#line 502 "TDocumentTest.vala"
	_tmp43_ = _tmp42_;
#line 502 "TDocumentTest.vala"
	_tmp44_ = gxml_node_get_namespaces (_tmp43_);
#line 502 "TDocumentTest.vala"
	_tmp45_ = _tmp44_;
#line 502 "TDocumentTest.vala"
	_tmp46_ = _tmp45_;
#line 502 "TDocumentTest.vala"
	_tmp47_ = gee_list_get (_tmp46_, 1);
#line 502 "TDocumentTest.vala"
	_tmp48_ = (GXmlNamespace*) _tmp47_;
#line 502 "TDocumentTest.vala"
	_tmp49_ = gxml_namespace_get_prefix (_tmp48_);
#line 502 "TDocumentTest.vala"
	_tmp50_ = _tmp49_;
#line 502 "TDocumentTest.vala"
	_tmp51_ = _tmp50_;
#line 502 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp51_, "b") == 0, "d.root.namespaces[1].prefix == \"b\"");
#line 502 "TDocumentTest.vala"
	_g_free0 (_tmp51_);
#line 502 "TDocumentTest.vala"
	_g_object_unref0 (_tmp48_);
#line 502 "TDocumentTest.vala"
	_g_object_unref0 (_tmp46_);
#line 502 "TDocumentTest.vala"
	_g_object_unref0 (_tmp43_);
#line 503 "TDocumentTest.vala"
	_tmp52_ = gxml_document_get_root ((GXmlDocument*) d);
#line 503 "TDocumentTest.vala"
	_tmp53_ = _tmp52_;
#line 503 "TDocumentTest.vala"
	_tmp54_ = _tmp53_;
#line 503 "TDocumentTest.vala"
	_tmp55_ = gxml_node_get_namespaces (_tmp54_);
#line 503 "TDocumentTest.vala"
	_tmp56_ = _tmp55_;
#line 503 "TDocumentTest.vala"
	_tmp57_ = _tmp56_;
#line 503 "TDocumentTest.vala"
	_tmp58_ = gee_list_get (_tmp57_, 1);
#line 503 "TDocumentTest.vala"
	_tmp59_ = (GXmlNamespace*) _tmp58_;
#line 503 "TDocumentTest.vala"
	_tmp60_ = gxml_namespace_get_uri (_tmp59_);
#line 503 "TDocumentTest.vala"
	_tmp61_ = _tmp60_;
#line 503 "TDocumentTest.vala"
	_tmp62_ = _tmp61_;
#line 503 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp62_, "http://book.org/schema") == 0, "d.root.namespaces[1].uri == \"http://book.org/schema\"");
#line 503 "TDocumentTest.vala"
	_g_free0 (_tmp62_);
#line 503 "TDocumentTest.vala"
	_g_object_unref0 (_tmp59_);
#line 503 "TDocumentTest.vala"
	_g_object_unref0 (_tmp57_);
#line 503 "TDocumentTest.vala"
	_g_object_unref0 (_tmp54_);
#line 504 "TDocumentTest.vala"
	_tmp63_ = gxml_document_get_root ((GXmlDocument*) d);
#line 504 "TDocumentTest.vala"
	_tmp64_ = _tmp63_;
#line 504 "TDocumentTest.vala"
	_tmp65_ = _tmp64_;
#line 504 "TDocumentTest.vala"
	_tmp66_ = gxml_node_get_children_nodes (_tmp65_);
#line 504 "TDocumentTest.vala"
	_tmp67_ = _tmp66_;
#line 504 "TDocumentTest.vala"
	_tmp68_ = _tmp67_;
#line 504 "TDocumentTest.vala"
	_tmp69_ = gee_list_get ((GeeList*) _tmp68_, 2);
#line 504 "TDocumentTest.vala"
	_tmp70_ = (GXmlNode*) _tmp69_;
#line 504 "TDocumentTest.vala"
	_g_object_unref0 (_tmp68_);
#line 504 "TDocumentTest.vala"
	_g_object_unref0 (_tmp65_);
#line 504 "TDocumentTest.vala"
	a = _tmp70_;
#line 505 "TDocumentTest.vala"
	_vala_assert (a != NULL, "a != null");
#line 506 "TDocumentTest.vala"
	_tmp71_ = gxml_node_get_name (a);
#line 506 "TDocumentTest.vala"
	_tmp72_ = _tmp71_;
#line 506 "TDocumentTest.vala"
	_tmp73_ = _tmp72_;
#line 506 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp73_, "Authors") == 0, "a.name == \"Authors\"");
#line 506 "TDocumentTest.vala"
	_g_free0 (_tmp73_);
#line 507 "TDocumentTest.vala"
	_tmp74_ = gxml_node_get_namespaces (a);
#line 507 "TDocumentTest.vala"
	_tmp75_ = _tmp74_;
#line 507 "TDocumentTest.vala"
	_tmp76_ = _tmp75_;
#line 507 "TDocumentTest.vala"
	_tmp77_ = gee_collection_get_size ((GeeCollection*) _tmp76_);
#line 507 "TDocumentTest.vala"
	_tmp78_ = _tmp77_;
#line 507 "TDocumentTest.vala"
	_vala_assert (_tmp78_ == 1, "a.namespaces.size == 1");
#line 507 "TDocumentTest.vala"
	_g_object_unref0 (_tmp76_);
#line 508 "TDocumentTest.vala"
	_tmp79_ = gxml_node_get_namespaces (a);
#line 508 "TDocumentTest.vala"
	_tmp80_ = _tmp79_;
#line 508 "TDocumentTest.vala"
	_tmp81_ = _tmp80_;
#line 508 "TDocumentTest.vala"
	_tmp82_ = gee_list_get (_tmp81_, 0);
#line 508 "TDocumentTest.vala"
	_tmp83_ = (GXmlNamespace*) _tmp82_;
#line 508 "TDocumentTest.vala"
	_tmp84_ = gxml_namespace_get_uri (_tmp83_);
#line 508 "TDocumentTest.vala"
	_tmp85_ = _tmp84_;
#line 508 "TDocumentTest.vala"
	_tmp86_ = _tmp85_;
#line 508 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp86_, "http://author.org") == 0, "a.namespaces[0].uri == \"http://author.org\"");
#line 508 "TDocumentTest.vala"
	_g_free0 (_tmp86_);
#line 508 "TDocumentTest.vala"
	_g_object_unref0 (_tmp83_);
#line 508 "TDocumentTest.vala"
	_g_object_unref0 (_tmp81_);
#line 509 "TDocumentTest.vala"
	_tmp87_ = gxml_node_get_namespaces (a);
#line 509 "TDocumentTest.vala"
	_tmp88_ = _tmp87_;
#line 509 "TDocumentTest.vala"
	_tmp89_ = _tmp88_;
#line 509 "TDocumentTest.vala"
	_tmp90_ = gee_list_get (_tmp89_, 0);
#line 509 "TDocumentTest.vala"
	_tmp91_ = (GXmlNamespace*) _tmp90_;
#line 509 "TDocumentTest.vala"
	_tmp92_ = gxml_namespace_get_prefix (_tmp91_);
#line 509 "TDocumentTest.vala"
	_tmp93_ = _tmp92_;
#line 509 "TDocumentTest.vala"
	_tmp94_ = _tmp93_;
#line 509 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp94_, "auth") == 0, "a.namespaces[0].prefix == \"auth\"");
#line 509 "TDocumentTest.vala"
	_g_free0 (_tmp94_);
#line 509 "TDocumentTest.vala"
	_g_object_unref0 (_tmp91_);
#line 509 "TDocumentTest.vala"
	_g_object_unref0 (_tmp89_);
#line 510 "TDocumentTest.vala"
	_tmp95_ = gxml_node_get_children_nodes (a);
#line 510 "TDocumentTest.vala"
	_tmp96_ = _tmp95_;
#line 510 "TDocumentTest.vala"
	_tmp97_ = _tmp96_;
#line 510 "TDocumentTest.vala"
	_tmp98_ = gee_list_get ((GeeList*) _tmp97_, 0);
#line 510 "TDocumentTest.vala"
	_tmp99_ = (GXmlNode*) _tmp98_;
#line 510 "TDocumentTest.vala"
	_vala_assert (_tmp99_ != NULL, "a.children_nodes[0] != null");
#line 510 "TDocumentTest.vala"
	_g_object_unref0 (_tmp99_);
#line 510 "TDocumentTest.vala"
	_g_object_unref0 (_tmp97_);
#line 511 "TDocumentTest.vala"
	_tmp100_ = gxml_node_get_children_nodes (a);
#line 511 "TDocumentTest.vala"
	_tmp101_ = _tmp100_;
#line 511 "TDocumentTest.vala"
	_tmp102_ = _tmp101_;
#line 511 "TDocumentTest.vala"
	_tmp103_ = gee_list_get ((GeeList*) _tmp102_, 0);
#line 511 "TDocumentTest.vala"
	_tmp104_ = (GXmlNode*) _tmp103_;
#line 511 "TDocumentTest.vala"
	_g_object_unref0 (_tmp102_);
#line 511 "TDocumentTest.vala"
	a1 = _tmp104_;
#line 512 "TDocumentTest.vala"
	_vala_assert (a1 != NULL, "a1 != null");
#line 513 "TDocumentTest.vala"
	_tmp105_ = gxml_node_get_name (a1);
#line 513 "TDocumentTest.vala"
	_tmp106_ = _tmp105_;
#line 513 "TDocumentTest.vala"
	_tmp107_ = _tmp106_;
#line 513 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp107_, "Author") == 0, "a1.name == \"Author\"");
#line 513 "TDocumentTest.vala"
	_g_free0 (_tmp107_);
#line 514 "TDocumentTest.vala"
	_tmp108_ = gxml_node_get_children_nodes (a1);
#line 514 "TDocumentTest.vala"
	_tmp109_ = _tmp108_;
#line 514 "TDocumentTest.vala"
	_tmp110_ = _tmp109_;
#line 514 "TDocumentTest.vala"
	_tmp111_ = gee_list_get ((GeeList*) _tmp110_, 1);
#line 514 "TDocumentTest.vala"
	_tmp112_ = (GXmlNode*) _tmp111_;
#line 514 "TDocumentTest.vala"
	_g_object_unref0 (_tmp110_);
#line 514 "TDocumentTest.vala"
	e = _tmp112_;
#line 515 "TDocumentTest.vala"
	_vala_assert (e != NULL, "e != null");
#line 516 "TDocumentTest.vala"
	_tmp113_ = gxml_node_get_name (e);
#line 516 "TDocumentTest.vala"
	_tmp114_ = _tmp113_;
#line 516 "TDocumentTest.vala"
	_tmp115_ = _tmp114_;
#line 516 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp115_, "Email") == 0, "e.name == \"Email\"");
#line 516 "TDocumentTest.vala"
	_g_free0 (_tmp115_);
#line 517 "TDocumentTest.vala"
	_tmp116_ = gxml_node_get_namespaces (e);
#line 517 "TDocumentTest.vala"
	_tmp117_ = _tmp116_;
#line 517 "TDocumentTest.vala"
	_tmp118_ = _tmp117_;
#line 517 "TDocumentTest.vala"
	_tmp119_ = gee_collection_get_size ((GeeCollection*) _tmp118_);
#line 517 "TDocumentTest.vala"
	_tmp120_ = _tmp119_;
#line 517 "TDocumentTest.vala"
	_vala_assert (_tmp120_ == 1, "e.namespaces.size == 1");
#line 517 "TDocumentTest.vala"
	_g_object_unref0 (_tmp118_);
#line 518 "TDocumentTest.vala"
	_tmp121_ = gxml_node_get_namespaces (e);
#line 518 "TDocumentTest.vala"
	_tmp122_ = _tmp121_;
#line 518 "TDocumentTest.vala"
	_tmp123_ = _tmp122_;
#line 518 "TDocumentTest.vala"
	_tmp124_ = gee_list_get (_tmp123_, 0);
#line 518 "TDocumentTest.vala"
	_tmp125_ = (GXmlNamespace*) _tmp124_;
#line 518 "TDocumentTest.vala"
	_tmp126_ = gxml_namespace_get_prefix (_tmp125_);
#line 518 "TDocumentTest.vala"
	_tmp127_ = _tmp126_;
#line 518 "TDocumentTest.vala"
	_tmp128_ = _tmp127_;
#line 518 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp128_, "gxml") == 0, "e.namespaces[0].prefix == \"gxml\"");
#line 518 "TDocumentTest.vala"
	_g_free0 (_tmp128_);
#line 518 "TDocumentTest.vala"
	_g_object_unref0 (_tmp125_);
#line 518 "TDocumentTest.vala"
	_g_object_unref0 (_tmp123_);
#line 519 "TDocumentTest.vala"
	_tmp129_ = gxml_node_get_namespaces (e);
#line 519 "TDocumentTest.vala"
	_tmp130_ = _tmp129_;
#line 519 "TDocumentTest.vala"
	_tmp131_ = _tmp130_;
#line 519 "TDocumentTest.vala"
	_tmp132_ = gee_list_get (_tmp131_, 0);
#line 519 "TDocumentTest.vala"
	_tmp133_ = (GXmlNamespace*) _tmp132_;
#line 519 "TDocumentTest.vala"
	_tmp134_ = gxml_namespace_get_uri (_tmp133_);
#line 519 "TDocumentTest.vala"
	_tmp135_ = _tmp134_;
#line 519 "TDocumentTest.vala"
	_tmp136_ = _tmp135_;
#line 519 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp136_, "http://wiki.gnome.org/GXml") == 0, "e.namespaces[0].uri == \"http://wiki.gnome.org/GXml\"");
#line 519 "TDocumentTest.vala"
	_g_free0 (_tmp136_);
#line 519 "TDocumentTest.vala"
	_g_object_unref0 (_tmp133_);
#line 519 "TDocumentTest.vala"
	_g_object_unref0 (_tmp131_);
#line 520 "TDocumentTest.vala"
	_tmp137_ = gxml_document_get_root ((GXmlDocument*) d);
#line 520 "TDocumentTest.vala"
	_tmp138_ = _tmp137_;
#line 520 "TDocumentTest.vala"
	_tmp139_ = _tmp138_;
#line 520 "TDocumentTest.vala"
	_tmp140_ = gxml_node_get_children_nodes (_tmp139_);
#line 520 "TDocumentTest.vala"
	_tmp141_ = _tmp140_;
#line 520 "TDocumentTest.vala"
	_tmp142_ = _tmp141_;
#line 520 "TDocumentTest.vala"
	_tmp143_ = gee_list_get ((GeeList*) _tmp142_, 3);
#line 520 "TDocumentTest.vala"
	_tmp144_ = (GXmlNode*) _tmp143_;
#line 520 "TDocumentTest.vala"
	_g_object_unref0 (_tmp142_);
#line 520 "TDocumentTest.vala"
	_g_object_unref0 (_tmp139_);
#line 520 "TDocumentTest.vala"
	b = _tmp144_;
#line 521 "TDocumentTest.vala"
	_vala_assert (b != NULL, "b != null");
#line 522 "TDocumentTest.vala"
	_tmp145_ = gxml_node_get_name (b);
#line 522 "TDocumentTest.vala"
	_tmp146_ = _tmp145_;
#line 522 "TDocumentTest.vala"
	_tmp147_ = _tmp146_;
#line 522 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp147_, "Book") == 0, "b.name == \"Book\"");
#line 522 "TDocumentTest.vala"
	_g_free0 (_tmp147_);
#line 523 "TDocumentTest.vala"
	_tmp148_ = gxml_node_get_namespaces (b);
#line 523 "TDocumentTest.vala"
	_tmp149_ = _tmp148_;
#line 523 "TDocumentTest.vala"
	_tmp150_ = _tmp149_;
#line 523 "TDocumentTest.vala"
	_tmp151_ = gee_collection_get_size ((GeeCollection*) _tmp150_);
#line 523 "TDocumentTest.vala"
	_tmp152_ = _tmp151_;
#line 523 "TDocumentTest.vala"
	_vala_assert (_tmp152_ == 1, "b.namespaces.size == 1");
#line 523 "TDocumentTest.vala"
	_g_object_unref0 (_tmp150_);
#line 524 "TDocumentTest.vala"
	_tmp153_ = gxml_node_get_namespaces (b);
#line 524 "TDocumentTest.vala"
	_tmp154_ = _tmp153_;
#line 524 "TDocumentTest.vala"
	_tmp155_ = _tmp154_;
#line 524 "TDocumentTest.vala"
	_tmp156_ = gee_list_get (_tmp155_, 0);
#line 524 "TDocumentTest.vala"
	_tmp157_ = (GXmlNamespace*) _tmp156_;
#line 524 "TDocumentTest.vala"
	_tmp158_ = gxml_namespace_get_prefix (_tmp157_);
#line 524 "TDocumentTest.vala"
	_tmp159_ = _tmp158_;
#line 524 "TDocumentTest.vala"
	_tmp160_ = _tmp159_;
#line 524 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp160_, "b") == 0, "b.namespaces[0].prefix == \"b\"");
#line 524 "TDocumentTest.vala"
	_g_free0 (_tmp160_);
#line 524 "TDocumentTest.vala"
	_g_object_unref0 (_tmp157_);
#line 524 "TDocumentTest.vala"
	_g_object_unref0 (_tmp155_);
#line 525 "TDocumentTest.vala"
	_tmp161_ = gxml_node_get_namespaces (b);
#line 525 "TDocumentTest.vala"
	_tmp162_ = _tmp161_;
#line 525 "TDocumentTest.vala"
	_tmp163_ = _tmp162_;
#line 525 "TDocumentTest.vala"
	_tmp164_ = gee_list_get (_tmp163_, 0);
#line 525 "TDocumentTest.vala"
	_tmp165_ = (GXmlNamespace*) _tmp164_;
#line 525 "TDocumentTest.vala"
	_tmp166_ = gxml_namespace_get_uri (_tmp165_);
#line 525 "TDocumentTest.vala"
	_tmp167_ = _tmp166_;
#line 525 "TDocumentTest.vala"
	_tmp168_ = _tmp167_;
#line 525 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp168_, "http://book.org/schema") == 0, "b.namespaces[0].uri == \"http://book.org/schema\"");
#line 525 "TDocumentTest.vala"
	_g_free0 (_tmp168_);
#line 525 "TDocumentTest.vala"
	_g_object_unref0 (_tmp165_);
#line 525 "TDocumentTest.vala"
	_g_object_unref0 (_tmp163_);
#line 526 "TDocumentTest.vala"
	_tmp169_ = gxml_node_get_attrs (b);
#line 526 "TDocumentTest.vala"
	_tmp170_ = _tmp169_;
#line 526 "TDocumentTest.vala"
	_tmp171_ = _tmp170_;
#line 526 "TDocumentTest.vala"
	_tmp172_ = gee_map_get (_tmp171_, "gxml:name");
#line 526 "TDocumentTest.vala"
	_tmp173_ = (GXmlNode*) _tmp172_;
#line 526 "TDocumentTest.vala"
	_g_object_unref0 (_tmp171_);
#line 526 "TDocumentTest.vala"
	bp = _tmp173_;
#line 527 "TDocumentTest.vala"
	_vala_assert (bp != NULL, "bp != null");
#line 528 "TDocumentTest.vala"
	_tmp174_ = gxml_node_get_name (bp);
#line 528 "TDocumentTest.vala"
	_tmp175_ = _tmp174_;
#line 528 "TDocumentTest.vala"
	_tmp176_ = _tmp175_;
#line 528 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp176_, "name") == 0, "bp.name == \"name\"");
#line 528 "TDocumentTest.vala"
	_g_free0 (_tmp176_);
#line 529 "TDocumentTest.vala"
	_tmp177_ = gxml_node_get_namespaces (bp);
#line 529 "TDocumentTest.vala"
	_tmp178_ = _tmp177_;
#line 529 "TDocumentTest.vala"
	_tmp179_ = _tmp178_;
#line 529 "TDocumentTest.vala"
	_tmp180_ = gee_collection_get_size ((GeeCollection*) _tmp179_);
#line 529 "TDocumentTest.vala"
	_tmp181_ = _tmp180_;
#line 529 "TDocumentTest.vala"
	_vala_assert (_tmp181_ == 1, "bp.namespaces.size == 1");
#line 529 "TDocumentTest.vala"
	_g_object_unref0 (_tmp179_);
#line 530 "TDocumentTest.vala"
	_tmp182_ = gxml_node_get_namespaces (bp);
#line 530 "TDocumentTest.vala"
	_tmp183_ = _tmp182_;
#line 530 "TDocumentTest.vala"
	_tmp184_ = _tmp183_;
#line 530 "TDocumentTest.vala"
	_tmp185_ = gee_list_get (_tmp184_, 0);
#line 530 "TDocumentTest.vala"
	_tmp186_ = (GXmlNamespace*) _tmp185_;
#line 530 "TDocumentTest.vala"
	_tmp187_ = gxml_namespace_get_prefix (_tmp186_);
#line 530 "TDocumentTest.vala"
	_tmp188_ = _tmp187_;
#line 530 "TDocumentTest.vala"
	_tmp189_ = _tmp188_;
#line 530 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp189_, "gxml") == 0, "bp.namespaces[0].prefix == \"gxml\"");
#line 530 "TDocumentTest.vala"
	_g_free0 (_tmp189_);
#line 530 "TDocumentTest.vala"
	_g_object_unref0 (_tmp186_);
#line 530 "TDocumentTest.vala"
	_g_object_unref0 (_tmp184_);
#line 531 "TDocumentTest.vala"
	_tmp190_ = gxml_node_get_namespaces (bp);
#line 531 "TDocumentTest.vala"
	_tmp191_ = _tmp190_;
#line 531 "TDocumentTest.vala"
	_tmp192_ = _tmp191_;
#line 531 "TDocumentTest.vala"
	_tmp193_ = gee_list_get (_tmp192_, 0);
#line 531 "TDocumentTest.vala"
	_tmp194_ = (GXmlNamespace*) _tmp193_;
#line 531 "TDocumentTest.vala"
	_tmp195_ = gxml_namespace_get_uri (_tmp194_);
#line 531 "TDocumentTest.vala"
	_tmp196_ = _tmp195_;
#line 531 "TDocumentTest.vala"
	_tmp197_ = _tmp196_;
#line 531 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp197_, "http://wiki.gnome.org/GXml") == 0, "bp.namespaces[0].uri == \"http://wiki.gnome.org/GXml\"");
#line 531 "TDocumentTest.vala"
	_g_free0 (_tmp197_);
#line 531 "TDocumentTest.vala"
	_g_object_unref0 (_tmp194_);
#line 531 "TDocumentTest.vala"
	_g_object_unref0 (_tmp192_);
#line 492 "TDocumentTest.vala"
	_g_object_unref0 (bp);
#line 492 "TDocumentTest.vala"
	_g_object_unref0 (b);
#line 492 "TDocumentTest.vala"
	_g_object_unref0 (e);
#line 492 "TDocumentTest.vala"
	_g_object_unref0 (a1);
#line 492 "TDocumentTest.vala"
	_g_object_unref0 (a);
#line 492 "TDocumentTest.vala"
	_g_object_unref0 (d);
#line 492 "TDocumentTest.vala"
	_g_object_unref0 (f);
#line 7158 "TDocumentTest.c"
}

static void
___lambda220__gtest_func (void)
{
#line 492 "TDocumentTest.vala"
	__lambda220_ ();
#line 7166 "TDocumentTest.c"
}

static void
__lambda221_ (void)
{
	GFile* f = NULL;
	GFile* _tmp0_;
	GXmlTDocument* d = NULL;
	GXmlTDocument* _tmp1_;
	GeeBidirList* _tmp2_;
	GeeBidirList* _tmp3_;
	GeeBidirList* _tmp4_;
	gpointer _tmp5_;
	GXmlNode* _tmp6_;
	GeeBidirList* _tmp7_;
	GeeBidirList* _tmp8_;
	GeeBidirList* _tmp9_;
	gpointer _tmp10_;
	GXmlNode* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	GXmlNode* a = NULL;
	GXmlNode* _tmp15_;
	GXmlNode* _tmp16_;
	GXmlNode* _tmp17_;
	GeeBidirList* _tmp18_;
	GeeBidirList* _tmp19_;
	GeeBidirList* _tmp20_;
	gpointer _tmp21_;
	GXmlNode* _tmp22_;
	gchar* _tmp23_;
	gchar* _tmp24_;
	gchar* _tmp25_;
	GXmlNode* a1 = NULL;
	GeeBidirList* _tmp26_;
	GeeBidirList* _tmp27_;
	GeeBidirList* _tmp28_;
	gpointer _tmp29_;
	GXmlNode* _tmp30_;
	gchar* _tmp31_;
	gchar* _tmp32_;
	gchar* _tmp33_;
	GeeBidirList* _tmp34_;
	GeeBidirList* _tmp35_;
	GeeBidirList* _tmp36_;
	gpointer _tmp37_;
	GXmlNode* _tmp38_;
	GeeBidirList* _tmp39_;
	GeeBidirList* _tmp40_;
	GeeBidirList* _tmp41_;
	gpointer _tmp42_;
	GXmlNode* _tmp43_;
	gchar* _tmp44_;
	gchar* _tmp45_;
	gchar* _tmp46_;
#line 534 "TDocumentTest.vala"
	_tmp0_ = g_file_new_for_path (TEST_DIR "/t-read-test.xml");
#line 534 "TDocumentTest.vala"
	f = _tmp0_;
#line 535 "TDocumentTest.vala"
	_vala_assert (g_file_query_exists (f, NULL), "f.query_exists ()");
#line 536 "TDocumentTest.vala"
	_tmp1_ = gxml_tdocument_new_from_file (f);
#line 536 "TDocumentTest.vala"
	d = _tmp1_;
#line 537 "TDocumentTest.vala"
	_tmp2_ = gxml_tnode_get_children_nodes ((GXmlTNode*) d);
#line 537 "TDocumentTest.vala"
	_tmp3_ = _tmp2_;
#line 537 "TDocumentTest.vala"
	_tmp4_ = _tmp3_;
#line 537 "TDocumentTest.vala"
	_tmp5_ = gee_list_get ((GeeList*) _tmp4_, 0);
#line 537 "TDocumentTest.vala"
	_tmp6_ = (GXmlNode*) _tmp5_;
#line 537 "TDocumentTest.vala"
	_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, GXML_TYPE_COMMENT), "d.children_nodes[0] is GXml.Comment");
#line 537 "TDocumentTest.vala"
	_g_object_unref0 (_tmp6_);
#line 537 "TDocumentTest.vala"
	_g_object_unref0 (_tmp4_);
#line 538 "TDocumentTest.vala"
	_tmp7_ = gxml_tnode_get_children_nodes ((GXmlTNode*) d);
#line 538 "TDocumentTest.vala"
	_tmp8_ = _tmp7_;
#line 538 "TDocumentTest.vala"
	_tmp9_ = _tmp8_;
#line 538 "TDocumentTest.vala"
	_tmp10_ = gee_list_get ((GeeList*) _tmp9_, 0);
#line 538 "TDocumentTest.vala"
	_tmp11_ = (GXmlNode*) _tmp10_;
#line 538 "TDocumentTest.vala"
	_tmp12_ = gxml_node_get_value (_tmp11_);
#line 538 "TDocumentTest.vala"
	_tmp13_ = _tmp12_;
#line 538 "TDocumentTest.vala"
	_tmp14_ = _tmp13_;
#line 538 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp14_, " Top Level Comment ") == 0, "d.children_nodes[0].value == \" Top Level Comment \"");
#line 538 "TDocumentTest.vala"
	_g_free0 (_tmp14_);
#line 538 "TDocumentTest.vala"
	_g_object_unref0 (_tmp11_);
#line 538 "TDocumentTest.vala"
	_g_object_unref0 (_tmp9_);
#line 539 "TDocumentTest.vala"
	_tmp15_ = gxml_document_get_root ((GXmlDocument*) d);
#line 539 "TDocumentTest.vala"
	_tmp16_ = _tmp15_;
#line 539 "TDocumentTest.vala"
	_tmp17_ = _tmp16_;
#line 539 "TDocumentTest.vala"
	_tmp18_ = gxml_node_get_children_nodes (_tmp17_);
#line 539 "TDocumentTest.vala"
	_tmp19_ = _tmp18_;
#line 539 "TDocumentTest.vala"
	_tmp20_ = _tmp19_;
#line 539 "TDocumentTest.vala"
	_tmp21_ = gee_list_get ((GeeList*) _tmp20_, 2);
#line 539 "TDocumentTest.vala"
	_tmp22_ = (GXmlNode*) _tmp21_;
#line 539 "TDocumentTest.vala"
	_g_object_unref0 (_tmp20_);
#line 539 "TDocumentTest.vala"
	_g_object_unref0 (_tmp17_);
#line 539 "TDocumentTest.vala"
	a = _tmp22_;
#line 540 "TDocumentTest.vala"
	_tmp23_ = gxml_node_get_name (a);
#line 540 "TDocumentTest.vala"
	_tmp24_ = _tmp23_;
#line 540 "TDocumentTest.vala"
	_tmp25_ = _tmp24_;
#line 540 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp25_, "Authors") == 0, "a.name == \"Authors\"");
#line 540 "TDocumentTest.vala"
	_g_free0 (_tmp25_);
#line 541 "TDocumentTest.vala"
	_tmp26_ = gxml_node_get_children_nodes (a);
#line 541 "TDocumentTest.vala"
	_tmp27_ = _tmp26_;
#line 541 "TDocumentTest.vala"
	_tmp28_ = _tmp27_;
#line 541 "TDocumentTest.vala"
	_tmp29_ = gee_list_get ((GeeList*) _tmp28_, 1);
#line 541 "TDocumentTest.vala"
	_tmp30_ = (GXmlNode*) _tmp29_;
#line 541 "TDocumentTest.vala"
	_g_object_unref0 (_tmp28_);
#line 541 "TDocumentTest.vala"
	a1 = _tmp30_;
#line 542 "TDocumentTest.vala"
	_tmp31_ = gxml_node_get_name (a1);
#line 542 "TDocumentTest.vala"
	_tmp32_ = _tmp31_;
#line 542 "TDocumentTest.vala"
	_tmp33_ = _tmp32_;
#line 542 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp33_, "Author") == 0, "a1.name == \"Author\"");
#line 542 "TDocumentTest.vala"
	_g_free0 (_tmp33_);
#line 543 "TDocumentTest.vala"
	_tmp34_ = gxml_node_get_children_nodes (a1);
#line 543 "TDocumentTest.vala"
	_tmp35_ = _tmp34_;
#line 543 "TDocumentTest.vala"
	_tmp36_ = _tmp35_;
#line 543 "TDocumentTest.vala"
	_tmp37_ = gee_list_get ((GeeList*) _tmp36_, 0);
#line 543 "TDocumentTest.vala"
	_tmp38_ = (GXmlNode*) _tmp37_;
#line 543 "TDocumentTest.vala"
	_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp38_, GXML_TYPE_COMMENT), "a1.children_nodes[0] is GXml.Comment");
#line 543 "TDocumentTest.vala"
	_g_object_unref0 (_tmp38_);
#line 543 "TDocumentTest.vala"
	_g_object_unref0 (_tmp36_);
#line 544 "TDocumentTest.vala"
	_tmp39_ = gxml_node_get_children_nodes (a1);
#line 544 "TDocumentTest.vala"
	_tmp40_ = _tmp39_;
#line 544 "TDocumentTest.vala"
	_tmp41_ = _tmp40_;
#line 544 "TDocumentTest.vala"
	_tmp42_ = gee_list_get ((GeeList*) _tmp41_, 0);
#line 544 "TDocumentTest.vala"
	_tmp43_ = (GXmlNode*) _tmp42_;
#line 544 "TDocumentTest.vala"
	_tmp44_ = gxml_node_get_value (_tmp43_);
#line 544 "TDocumentTest.vala"
	_tmp45_ = _tmp44_;
#line 544 "TDocumentTest.vala"
	_tmp46_ = _tmp45_;
#line 544 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp46_, " Inner comment") == 0, "a1.children_nodes[0].value == \" Inner comment\"");
#line 544 "TDocumentTest.vala"
	_g_free0 (_tmp46_);
#line 544 "TDocumentTest.vala"
	_g_object_unref0 (_tmp43_);
#line 544 "TDocumentTest.vala"
	_g_object_unref0 (_tmp41_);
#line 533 "TDocumentTest.vala"
	_g_object_unref0 (a1);
#line 533 "TDocumentTest.vala"
	_g_object_unref0 (a);
#line 533 "TDocumentTest.vala"
	_g_object_unref0 (d);
#line 533 "TDocumentTest.vala"
	_g_object_unref0 (f);
#line 7377 "TDocumentTest.c"
}

static void
___lambda221__gtest_func (void)
{
#line 533 "TDocumentTest.vala"
	__lambda221_ ();
#line 7385 "TDocumentTest.c"
}

static void
__lambda222_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GFile* f = NULL;
		GFile* _tmp0_;
		GXmlTDocument* d = NULL;
		GXmlTDocument* _tmp1_;
		GeeBidirList* _tmp2_;
		GeeBidirList* _tmp3_;
		GeeBidirList* _tmp4_;
		gpointer _tmp5_;
		GXmlNode* _tmp6_;
		GeeBidirList* _tmp7_;
		GeeBidirList* _tmp8_;
		GeeBidirList* _tmp9_;
		gpointer _tmp10_;
		GXmlNode* _tmp11_;
		GXmlProcessingInstruction* _tmp12_;
		GXmlProcessingInstruction* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		gchar* _tmp16_;
		GeeBidirList* _tmp17_;
		GeeBidirList* _tmp18_;
		GeeBidirList* _tmp19_;
		gpointer _tmp20_;
		GXmlNode* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
		GXmlNode* _tmp25_;
		GXmlNode* _tmp26_;
		GXmlNode* _tmp27_;
		GeeBidirList* _tmp28_;
		GeeBidirList* _tmp29_;
		GeeBidirList* _tmp30_;
		gint _tmp31_;
		gint _tmp32_;
		GXmlNode* p = NULL;
		GXmlNode* _tmp33_;
		GXmlNode* _tmp34_;
		GXmlNode* _tmp35_;
		GeeBidirList* _tmp36_;
		GeeBidirList* _tmp37_;
		GeeBidirList* _tmp38_;
		gpointer _tmp39_;
		GXmlNode* _tmp40_;
		gchar* _tmp41_;
		gchar* _tmp42_;
		gchar* _tmp43_;
		gchar* _tmp44_;
		gchar* _tmp45_;
		gchar* _tmp46_;
#line 549 "TDocumentTest.vala"
		_tmp0_ = g_file_new_for_path (TEST_DIR "/t-read-test.xml");
#line 549 "TDocumentTest.vala"
		f = _tmp0_;
#line 550 "TDocumentTest.vala"
		_vala_assert (g_file_query_exists (f, NULL), "f.query_exists ()");
#line 551 "TDocumentTest.vala"
		_tmp1_ = gxml_tdocument_new_from_file (f);
#line 551 "TDocumentTest.vala"
		d = _tmp1_;
#line 552 "TDocumentTest.vala"
		gxml_tdocument_read_doc ((GXmlDocument*) d, f, NULL, NULL, &_inner_error0_);
#line 552 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 552 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 552 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 7461 "TDocumentTest.c"
			goto __catch276_g_error;
		}
#line 553 "TDocumentTest.vala"
		_tmp2_ = gxml_tnode_get_children_nodes ((GXmlTNode*) d);
#line 553 "TDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 553 "TDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 553 "TDocumentTest.vala"
		_tmp5_ = gee_list_get ((GeeList*) _tmp4_, 1);
#line 553 "TDocumentTest.vala"
		_tmp6_ = (GXmlNode*) _tmp5_;
#line 553 "TDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, GXML_TYPE_PROCESSING_INSTRUCTION), "d.children_nodes[1] is GXml.ProcessingInstruction");
#line 553 "TDocumentTest.vala"
		_g_object_unref0 (_tmp6_);
#line 553 "TDocumentTest.vala"
		_g_object_unref0 (_tmp4_);
#line 554 "TDocumentTest.vala"
		_tmp7_ = gxml_tnode_get_children_nodes ((GXmlTNode*) d);
#line 554 "TDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 554 "TDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 554 "TDocumentTest.vala"
		_tmp10_ = gee_list_get ((GeeList*) _tmp9_, 1);
#line 554 "TDocumentTest.vala"
		_tmp11_ = (GXmlNode*) _tmp10_;
#line 554 "TDocumentTest.vala"
		_tmp12_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, GXML_TYPE_PROCESSING_INSTRUCTION) ? ((GXmlProcessingInstruction*) _tmp11_) : NULL;
#line 554 "TDocumentTest.vala"
		if (_tmp12_ == NULL) {
#line 554 "TDocumentTest.vala"
			_g_object_unref0 (_tmp11_);
#line 7496 "TDocumentTest.c"
		}
#line 554 "TDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 554 "TDocumentTest.vala"
		_tmp14_ = gxml_processing_instruction_get_target (_tmp13_);
#line 554 "TDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 554 "TDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 554 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp16_, "target") == 0, "(d.children_nodes[1] as GXml.ProcessingInstruction).target == \"target\"");
#line 554 "TDocumentTest.vala"
		_g_free0 (_tmp16_);
#line 554 "TDocumentTest.vala"
		_g_object_unref0 (_tmp13_);
#line 554 "TDocumentTest.vala"
		_g_object_unref0 (_tmp9_);
#line 555 "TDocumentTest.vala"
		_tmp17_ = gxml_tnode_get_children_nodes ((GXmlTNode*) d);
#line 555 "TDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 555 "TDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 555 "TDocumentTest.vala"
		_tmp20_ = gee_list_get ((GeeList*) _tmp19_, 1);
#line 555 "TDocumentTest.vala"
		_tmp21_ = (GXmlNode*) _tmp20_;
#line 555 "TDocumentTest.vala"
		_tmp22_ = gxml_node_get_value (_tmp21_);
#line 555 "TDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 555 "TDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 555 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp24_, "Content in target id=\"something\"") == 0, "d.children_nodes[1].value == \"Content in target id=\\\"something\\\"\"");
#line 555 "TDocumentTest.vala"
		_g_free0 (_tmp24_);
#line 555 "TDocumentTest.vala"
		_g_object_unref0 (_tmp21_);
#line 555 "TDocumentTest.vala"
		_g_object_unref0 (_tmp19_);
#line 562 "TDocumentTest.vala"
		_tmp25_ = gxml_document_get_root ((GXmlDocument*) d);
#line 562 "TDocumentTest.vala"
		_tmp26_ = _tmp25_;
#line 562 "TDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 562 "TDocumentTest.vala"
		_tmp28_ = gxml_node_get_children_nodes (_tmp27_);
#line 562 "TDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 562 "TDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 562 "TDocumentTest.vala"
		_tmp31_ = gee_collection_get_size ((GeeCollection*) _tmp30_);
#line 562 "TDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 562 "TDocumentTest.vala"
		_vala_assert (_tmp32_ == 7, "d.root.children_nodes.size == 7");
#line 562 "TDocumentTest.vala"
		_g_object_unref0 (_tmp30_);
#line 562 "TDocumentTest.vala"
		_g_object_unref0 (_tmp27_);
#line 563 "TDocumentTest.vala"
		_tmp33_ = gxml_document_get_root ((GXmlDocument*) d);
#line 563 "TDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 563 "TDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 563 "TDocumentTest.vala"
		_tmp36_ = gxml_node_get_children_nodes (_tmp35_);
#line 563 "TDocumentTest.vala"
		_tmp37_ = _tmp36_;
#line 563 "TDocumentTest.vala"
		_tmp38_ = _tmp37_;
#line 563 "TDocumentTest.vala"
		_tmp39_ = gee_list_get ((GeeList*) _tmp38_, 4);
#line 563 "TDocumentTest.vala"
		_tmp40_ = (GXmlNode*) _tmp39_;
#line 563 "TDocumentTest.vala"
		_g_object_unref0 (_tmp38_);
#line 563 "TDocumentTest.vala"
		_g_object_unref0 (_tmp35_);
#line 563 "TDocumentTest.vala"
		p = _tmp40_;
#line 564 "TDocumentTest.vala"
		_vala_assert (p != NULL, "p != null");
#line 565 "TDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (p, GXML_TYPE_PROCESSING_INSTRUCTION), "p is GXml.ProcessingInstruction");
#line 566 "TDocumentTest.vala"
		_tmp41_ = gxml_processing_instruction_get_target (G_TYPE_CHECK_INSTANCE_TYPE (p, GXML_TYPE_PROCESSING_INSTRUCTION) ? ((GXmlProcessingInstruction*) p) : NULL);
#line 566 "TDocumentTest.vala"
		_tmp42_ = _tmp41_;
#line 566 "TDocumentTest.vala"
		_tmp43_ = _tmp42_;
#line 566 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp43_, "css") == 0, "(p as GXml.ProcessingInstruction).target == \"css\"");
#line 566 "TDocumentTest.vala"
		_g_free0 (_tmp43_);
#line 567 "TDocumentTest.vala"
		_tmp44_ = gxml_node_get_value ((GXmlNode*) (G_TYPE_CHECK_INSTANCE_TYPE (p, GXML_TYPE_PROCESSING_INSTRUCTION) ? ((GXmlProcessingInstruction*) p) : NULL));
#line 567 "TDocumentTest.vala"
		_tmp45_ = _tmp44_;
#line 567 "TDocumentTest.vala"
		_tmp46_ = _tmp45_;
#line 567 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp46_, "href=\"http://www.gnome.org\"") == 0, "(p as GXml.ProcessingInstruction).value == \"href=\\\"http://www.gnome.org\\\"\"");
#line 567 "TDocumentTest.vala"
		_g_free0 (_tmp46_);
#line 548 "TDocumentTest.vala"
		_g_object_unref0 (p);
#line 548 "TDocumentTest.vala"
		_g_object_unref0 (d);
#line 548 "TDocumentTest.vala"
		_g_object_unref0 (f);
#line 7612 "TDocumentTest.c"
	}
	goto __finally276;
	__catch276_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp47_;
		gchar* _tmp48_;
		gchar* _tmp49_;
#line 548 "TDocumentTest.vala"
		e = _inner_error0_;
#line 548 "TDocumentTest.vala"
		_inner_error0_ = NULL;
#line 569 "TDocumentTest.vala"
		_tmp47_ = e->message;
#line 569 "TDocumentTest.vala"
		_tmp48_ = g_strconcat ("ERROR: ", _tmp47_, NULL);
#line 569 "TDocumentTest.vala"
		_tmp49_ = _tmp48_;
#line 569 "TDocumentTest.vala"
		g_message ("TDocumentTest.vala:569: %s", _tmp49_);
#line 569 "TDocumentTest.vala"
		_g_free0 (_tmp49_);
#line 569 "TDocumentTest.vala"
		g_assert_not_reached ();
#line 548 "TDocumentTest.vala"
		_g_error_free0 (e);
#line 7639 "TDocumentTest.c"
	}
	__finally276:
#line 548 "TDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 548 "TDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 548 "TDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 548 "TDocumentTest.vala"
		return;
#line 7650 "TDocumentTest.c"
	}
}

static void
___lambda222__gtest_func (void)
{
#line 547 "TDocumentTest.vala"
	__lambda222_ ();
#line 7659 "TDocumentTest.c"
}

static void
__lambda223_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GFile* f = NULL;
		GFile* _tmp0_;
		GXmlTDocument* d = NULL;
		GXmlTDocument* _tmp1_;
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlNode* _tmp4_;
		GeeBidirList* _tmp5_;
		GeeBidirList* _tmp6_;
		GeeBidirList* _tmp7_;
		gint _tmp8_;
		gint _tmp9_;
		GXmlNode* p = NULL;
		GXmlNode* _tmp10_;
		GXmlNode* _tmp11_;
		GXmlNode* _tmp12_;
		GeeBidirList* _tmp13_;
		GeeBidirList* _tmp14_;
		GeeBidirList* _tmp15_;
		gpointer _tmp16_;
		GXmlNode* _tmp17_;
		gchar* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
#line 573 "TDocumentTest.vala"
		_tmp0_ = g_file_new_for_path (TEST_DIR "/t-read-test.xml");
#line 573 "TDocumentTest.vala"
		f = _tmp0_;
#line 574 "TDocumentTest.vala"
		_vala_assert (g_file_query_exists (f, NULL), "f.query_exists ()");
#line 575 "TDocumentTest.vala"
		_tmp1_ = gxml_tdocument_new_from_file (f);
#line 575 "TDocumentTest.vala"
		d = _tmp1_;
#line 576 "TDocumentTest.vala"
		gxml_tdocument_read_doc ((GXmlDocument*) d, f, NULL, NULL, &_inner_error0_);
#line 576 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 576 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 576 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 7709 "TDocumentTest.c"
			goto __catch277_g_error;
		}
#line 577 "TDocumentTest.vala"
		_tmp2_ = gxml_document_get_root ((GXmlDocument*) d);
#line 577 "TDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 577 "TDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 577 "TDocumentTest.vala"
		_tmp5_ = gxml_node_get_children_nodes (_tmp4_);
#line 577 "TDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 577 "TDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 577 "TDocumentTest.vala"
		_tmp8_ = gee_collection_get_size ((GeeCollection*) _tmp7_);
#line 577 "TDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 577 "TDocumentTest.vala"
		_vala_assert (_tmp9_ == 7, "d.root.children_nodes.size == 7");
#line 577 "TDocumentTest.vala"
		_g_object_unref0 (_tmp7_);
#line 577 "TDocumentTest.vala"
		_g_object_unref0 (_tmp4_);
#line 578 "TDocumentTest.vala"
		_tmp10_ = gxml_document_get_root ((GXmlDocument*) d);
#line 578 "TDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 578 "TDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 578 "TDocumentTest.vala"
		_tmp13_ = gxml_node_get_children_nodes (_tmp12_);
#line 578 "TDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 578 "TDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 578 "TDocumentTest.vala"
		_tmp16_ = gee_list_get ((GeeList*) _tmp15_, 5);
#line 578 "TDocumentTest.vala"
		_tmp17_ = (GXmlNode*) _tmp16_;
#line 578 "TDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 578 "TDocumentTest.vala"
		_g_object_unref0 (_tmp12_);
#line 578 "TDocumentTest.vala"
		p = _tmp17_;
#line 579 "TDocumentTest.vala"
		_vala_assert (p != NULL, "p != null");
#line 580 "TDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (p, GXML_TYPE_CDATA), "p is GXml.CDATA");
#line 581 "TDocumentTest.vala"
		_tmp18_ = gxml_cdata_get_str (G_TYPE_CHECK_INSTANCE_TYPE (p, GXML_TYPE_CDATA) ? ((GXmlCDATA*) p) : NULL);
#line 581 "TDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 581 "TDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 581 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp20_, "<greeting>Hello, world!</greeting>") == 0, "(p as GXml.CDATA).str == \"<greeting>Hello, world!</greeting>\"");
#line 581 "TDocumentTest.vala"
		_g_free0 (_tmp20_);
#line 572 "TDocumentTest.vala"
		_g_object_unref0 (p);
#line 572 "TDocumentTest.vala"
		_g_object_unref0 (d);
#line 572 "TDocumentTest.vala"
		_g_object_unref0 (f);
#line 7776 "TDocumentTest.c"
	}
	goto __finally277;
	__catch277_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
#line 572 "TDocumentTest.vala"
		e = _inner_error0_;
#line 572 "TDocumentTest.vala"
		_inner_error0_ = NULL;
#line 583 "TDocumentTest.vala"
		_tmp21_ = e->message;
#line 583 "TDocumentTest.vala"
		_tmp22_ = g_strconcat ("ERROR: ", _tmp21_, NULL);
#line 583 "TDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 583 "TDocumentTest.vala"
		g_message ("TDocumentTest.vala:583: %s", _tmp23_);
#line 583 "TDocumentTest.vala"
		_g_free0 (_tmp23_);
#line 583 "TDocumentTest.vala"
		g_assert_not_reached ();
#line 572 "TDocumentTest.vala"
		_g_error_free0 (e);
#line 7803 "TDocumentTest.c"
	}
	__finally277:
#line 572 "TDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 572 "TDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 572 "TDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 572 "TDocumentTest.vala"
		return;
#line 7814 "TDocumentTest.c"
	}
}

static void
___lambda223__gtest_func (void)
{
#line 571 "TDocumentTest.vala"
	__lambda223_ ();
#line 7823 "TDocumentTest.c"
}

static void
__lambda224_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GFile* rf = NULL;
		GFile* _tmp0_;
		GFile* _tmp1_;
		GXmlTDocument* d = NULL;
		GFile* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		GXmlTDocument* _tmp5_;
		GXmlTDocument* _tmp6_;
		GXmlTDocument* _tmp7_;
		GXmlTDocument* _tmp8_;
		GXmlNode* _tmp9_;
		GXmlNode* _tmp10_;
		GXmlNode* _tmp11_;
		GXmlTDocument* _tmp12_;
		GXmlNode* _tmp13_;
		GXmlNode* _tmp14_;
		GXmlNode* _tmp15_;
		gchar* _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_;
		gboolean fname = FALSE;
		gboolean fshordesc = FALSE;
		gboolean fdescription = FALSE;
		gboolean fhomepage = FALSE;
		GFile* f = NULL;
		GFile* _tmp51_;
		GXmlTDocument* _tmp52_;
		GFile* _tmp53_;
		GFile* _tmp54_;
		GFile* _tmp55_;
#line 587 "TDocumentTest.vala"
		_tmp0_ = g_file_new_for_uri ("https://git.gnome.org/browse/gxml/plain/gxml.doap");
#line 587 "TDocumentTest.vala"
		rf = _tmp0_;
#line 588 "TDocumentTest.vala"
		_tmp1_ = rf;
#line 588 "TDocumentTest.vala"
		if (!g_file_query_exists (_tmp1_, NULL)) {
#line 589 "TDocumentTest.vala"
			g_message ("TDocumentTest.vala:589: No remote file available. Skiping...");
#line 590 "TDocumentTest.vala"
			_g_object_unref0 (rf);
#line 590 "TDocumentTest.vala"
			return;
#line 7876 "TDocumentTest.c"
		}
#line 592 "TDocumentTest.vala"
		_tmp2_ = rf;
#line 592 "TDocumentTest.vala"
		_tmp3_ = g_file_get_uri (_tmp2_);
#line 592 "TDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 592 "TDocumentTest.vala"
		_tmp5_ = gxml_tdocument_new_from_uri (_tmp4_);
#line 592 "TDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 592 "TDocumentTest.vala"
		_g_free0 (_tmp4_);
#line 592 "TDocumentTest.vala"
		d = _tmp6_;
#line 593 "TDocumentTest.vala"
		_tmp7_ = d;
#line 593 "TDocumentTest.vala"
		_vala_assert (_tmp7_ != NULL, "d != null");
#line 594 "TDocumentTest.vala"
		_tmp8_ = d;
#line 594 "TDocumentTest.vala"
		_tmp9_ = gxml_document_get_root ((GXmlDocument*) _tmp8_);
#line 594 "TDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 594 "TDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 594 "TDocumentTest.vala"
		_vala_assert (_tmp11_ != NULL, "d.root != null");
#line 594 "TDocumentTest.vala"
		_g_object_unref0 (_tmp11_);
#line 595 "TDocumentTest.vala"
		_tmp12_ = d;
#line 595 "TDocumentTest.vala"
		_tmp13_ = gxml_document_get_root ((GXmlDocument*) _tmp12_);
#line 595 "TDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 595 "TDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 595 "TDocumentTest.vala"
		_tmp16_ = gxml_node_get_name (_tmp15_);
#line 595 "TDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 595 "TDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 595 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp18_, "Project") == 0, "d.root.name == \"Project\"");
#line 595 "TDocumentTest.vala"
		_g_free0 (_tmp18_);
#line 595 "TDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 597 "TDocumentTest.vala"
		fhomepage = FALSE;
#line 597 "TDocumentTest.vala"
		fdescription = fhomepage;
#line 597 "TDocumentTest.vala"
		fshordesc = fdescription;
#line 597 "TDocumentTest.vala"
		fname = fshordesc;
#line 7936 "TDocumentTest.c"
		{
			GeeBidirList* _n_list = NULL;
			GXmlTDocument* _tmp19_;
			GXmlNode* _tmp20_;
			GXmlNode* _tmp21_;
			GXmlNode* _tmp22_;
			GeeBidirList* _tmp23_;
			GeeBidirList* _tmp24_;
			GeeBidirList* _tmp25_;
			gint _n_size = 0;
			GeeBidirList* _tmp26_;
			gint _tmp27_;
			gint _tmp28_;
			gint _n_index = 0;
#line 598 "TDocumentTest.vala"
			_tmp19_ = d;
#line 598 "TDocumentTest.vala"
			_tmp20_ = gxml_document_get_root ((GXmlDocument*) _tmp19_);
#line 598 "TDocumentTest.vala"
			_tmp21_ = _tmp20_;
#line 598 "TDocumentTest.vala"
			_tmp22_ = _tmp21_;
#line 598 "TDocumentTest.vala"
			_tmp23_ = gxml_node_get_children_nodes (_tmp22_);
#line 598 "TDocumentTest.vala"
			_tmp24_ = _tmp23_;
#line 598 "TDocumentTest.vala"
			_tmp25_ = _tmp24_;
#line 598 "TDocumentTest.vala"
			_g_object_unref0 (_tmp22_);
#line 598 "TDocumentTest.vala"
			_n_list = _tmp25_;
#line 598 "TDocumentTest.vala"
			_tmp26_ = _n_list;
#line 598 "TDocumentTest.vala"
			_tmp27_ = gee_collection_get_size ((GeeCollection*) _tmp26_);
#line 598 "TDocumentTest.vala"
			_tmp28_ = _tmp27_;
#line 598 "TDocumentTest.vala"
			_n_size = _tmp28_;
#line 598 "TDocumentTest.vala"
			_n_index = -1;
#line 598 "TDocumentTest.vala"
			while (TRUE) {
#line 7981 "TDocumentTest.c"
				GXmlNode* n = NULL;
				GeeBidirList* _tmp29_;
				gpointer _tmp30_;
				GXmlNode* _tmp31_;
				gchar* _tmp32_;
				gchar* _tmp33_;
				gchar* _tmp34_;
				gboolean _tmp35_;
				GXmlNode* _tmp36_;
				gchar* _tmp37_;
				gchar* _tmp38_;
				gchar* _tmp39_;
				gboolean _tmp40_;
				GXmlNode* _tmp41_;
				gchar* _tmp42_;
				gchar* _tmp43_;
				gchar* _tmp44_;
				gboolean _tmp45_;
				GXmlNode* _tmp46_;
				gchar* _tmp47_;
				gchar* _tmp48_;
				gchar* _tmp49_;
				gboolean _tmp50_;
#line 598 "TDocumentTest.vala"
				_n_index = _n_index + 1;
#line 598 "TDocumentTest.vala"
				if (!(_n_index < _n_size)) {
#line 598 "TDocumentTest.vala"
					break;
#line 8011 "TDocumentTest.c"
				}
#line 598 "TDocumentTest.vala"
				_tmp29_ = _n_list;
#line 598 "TDocumentTest.vala"
				_tmp30_ = gee_list_get ((GeeList*) _tmp29_, _n_index);
#line 598 "TDocumentTest.vala"
				n = (GXmlNode*) _tmp30_;
#line 599 "TDocumentTest.vala"
				_tmp31_ = n;
#line 599 "TDocumentTest.vala"
				_tmp32_ = gxml_node_get_name (_tmp31_);
#line 599 "TDocumentTest.vala"
				_tmp33_ = _tmp32_;
#line 599 "TDocumentTest.vala"
				_tmp34_ = _tmp33_;
#line 599 "TDocumentTest.vala"
				_tmp35_ = g_strcmp0 (_tmp34_, "name") == 0;
#line 599 "TDocumentTest.vala"
				_g_free0 (_tmp34_);
#line 599 "TDocumentTest.vala"
				if (_tmp35_) {
#line 599 "TDocumentTest.vala"
					fname = TRUE;
#line 8035 "TDocumentTest.c"
				}
#line 600 "TDocumentTest.vala"
				_tmp36_ = n;
#line 600 "TDocumentTest.vala"
				_tmp37_ = gxml_node_get_name (_tmp36_);
#line 600 "TDocumentTest.vala"
				_tmp38_ = _tmp37_;
#line 600 "TDocumentTest.vala"
				_tmp39_ = _tmp38_;
#line 600 "TDocumentTest.vala"
				_tmp40_ = g_strcmp0 (_tmp39_, "shortdesc") == 0;
#line 600 "TDocumentTest.vala"
				_g_free0 (_tmp39_);
#line 600 "TDocumentTest.vala"
				if (_tmp40_) {
#line 600 "TDocumentTest.vala"
					fshordesc = TRUE;
#line 8053 "TDocumentTest.c"
				}
#line 601 "TDocumentTest.vala"
				_tmp41_ = n;
#line 601 "TDocumentTest.vala"
				_tmp42_ = gxml_node_get_name (_tmp41_);
#line 601 "TDocumentTest.vala"
				_tmp43_ = _tmp42_;
#line 601 "TDocumentTest.vala"
				_tmp44_ = _tmp43_;
#line 601 "TDocumentTest.vala"
				_tmp45_ = g_strcmp0 (_tmp44_, "description") == 0;
#line 601 "TDocumentTest.vala"
				_g_free0 (_tmp44_);
#line 601 "TDocumentTest.vala"
				if (_tmp45_) {
#line 601 "TDocumentTest.vala"
					fdescription = TRUE;
#line 8071 "TDocumentTest.c"
				}
#line 602 "TDocumentTest.vala"
				_tmp46_ = n;
#line 602 "TDocumentTest.vala"
				_tmp47_ = gxml_node_get_name (_tmp46_);
#line 602 "TDocumentTest.vala"
				_tmp48_ = _tmp47_;
#line 602 "TDocumentTest.vala"
				_tmp49_ = _tmp48_;
#line 602 "TDocumentTest.vala"
				_tmp50_ = g_strcmp0 (_tmp49_, "homepage") == 0;
#line 602 "TDocumentTest.vala"
				_g_free0 (_tmp49_);
#line 602 "TDocumentTest.vala"
				if (_tmp50_) {
#line 602 "TDocumentTest.vala"
					fhomepage = TRUE;
#line 8089 "TDocumentTest.c"
				}
#line 598 "TDocumentTest.vala"
				_g_object_unref0 (n);
#line 8093 "TDocumentTest.c"
			}
#line 598 "TDocumentTest.vala"
			_g_object_unref0 (_n_list);
#line 8097 "TDocumentTest.c"
		}
#line 604 "TDocumentTest.vala"
		_vala_assert (fname, "fname");
#line 605 "TDocumentTest.vala"
		_vala_assert (fshordesc, "fshordesc");
#line 606 "TDocumentTest.vala"
		_vala_assert (fdescription, "fdescription");
#line 607 "TDocumentTest.vala"
		_vala_assert (fhomepage, "fhomepage");
#line 608 "TDocumentTest.vala"
		_tmp51_ = g_file_new_for_path (TEST_SAVE_DIR "/xml.doap");
#line 608 "TDocumentTest.vala"
		f = _tmp51_;
#line 609 "TDocumentTest.vala"
		_tmp52_ = d;
#line 609 "TDocumentTest.vala"
		_tmp53_ = f;
#line 609 "TDocumentTest.vala"
		gxml_document_save_as ((GXmlDocument*) _tmp52_, _tmp53_, NULL, &_inner_error0_);
#line 609 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 609 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 609 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 609 "TDocumentTest.vala"
			_g_object_unref0 (rf);
#line 8125 "TDocumentTest.c"
			goto __catch278_g_error;
		}
#line 610 "TDocumentTest.vala"
		_tmp54_ = f;
#line 610 "TDocumentTest.vala"
		_vala_assert (g_file_query_exists (_tmp54_, NULL), "f.query_exists ()");
#line 611 "TDocumentTest.vala"
		_tmp55_ = f;
#line 611 "TDocumentTest.vala"
		g_file_delete (_tmp55_, NULL, &_inner_error0_);
#line 611 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 611 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 611 "TDocumentTest.vala"
			_g_object_unref0 (d);
#line 611 "TDocumentTest.vala"
			_g_object_unref0 (rf);
#line 8144 "TDocumentTest.c"
			goto __catch278_g_error;
		}
#line 586 "TDocumentTest.vala"
		_g_object_unref0 (f);
#line 586 "TDocumentTest.vala"
		_g_object_unref0 (d);
#line 586 "TDocumentTest.vala"
		_g_object_unref0 (rf);
#line 8153 "TDocumentTest.c"
	}
	goto __finally278;
	__catch278_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp56_;
		gchar* _tmp57_;
		gchar* _tmp58_;
#line 586 "TDocumentTest.vala"
		e = _inner_error0_;
#line 586 "TDocumentTest.vala"
		_inner_error0_ = NULL;
#line 613 "TDocumentTest.vala"
		_tmp56_ = e->message;
#line 613 "TDocumentTest.vala"
		_tmp57_ = g_strconcat ("Error: ", _tmp56_, NULL);
#line 613 "TDocumentTest.vala"
		_tmp58_ = _tmp57_;
#line 613 "TDocumentTest.vala"
		g_message ("TDocumentTest.vala:613: %s", _tmp58_);
#line 613 "TDocumentTest.vala"
		_g_free0 (_tmp58_);
#line 614 "TDocumentTest.vala"
		g_assert_not_reached ();
#line 586 "TDocumentTest.vala"
		_g_error_free0 (e);
#line 8180 "TDocumentTest.c"
	}
	__finally278:
#line 586 "TDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 586 "TDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 586 "TDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 586 "TDocumentTest.vala"
		return;
#line 8191 "TDocumentTest.c"
	}
}

static void
___lambda224__gtest_func (void)
{
#line 585 "TDocumentTest.vala"
	__lambda224_ ();
#line 8200 "TDocumentTest.c"
}

static void
__lambda225_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GFile* f = NULL;
		GFile* _tmp0_;
		GFileInputStream* _tmp1_ = NULL;
		GFileInputStream* _tmp2_;
		GXmlTDocument* d = NULL;
		GXmlTDocument* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		GXmlNode* _tmp7_;
		GXmlNode* _tmp8_;
		GXmlNode* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		GXmlNode* _tmp13_;
		GXmlNode* _tmp14_;
		GXmlNode* _tmp15_;
		GeeMap* _tmp16_;
		GeeMap* _tmp17_;
		GeeMap* _tmp18_;
		gpointer _tmp19_;
		GXmlNode* _tmp20_;
		GXmlNode* _tmp21_;
		GXmlNode* _tmp22_;
		GXmlNode* _tmp23_;
		GeeMap* _tmp24_;
		GeeMap* _tmp25_;
		GeeMap* _tmp26_;
		gpointer _tmp27_;
		GXmlNode* _tmp28_;
		gchar* _tmp29_;
		gchar* _tmp30_;
		gchar* _tmp31_;
		GXmlNode* _tmp32_;
		GXmlNode* _tmp33_;
		GXmlNode* _tmp34_;
		GeeBidirList* _tmp35_;
		GeeBidirList* _tmp36_;
		GeeBidirList* _tmp37_;
		gint _tmp38_;
		gint _tmp39_;
		GXmlNode* s1 = NULL;
		GXmlNode* _tmp40_;
		GXmlNode* _tmp41_;
		GXmlNode* _tmp42_;
		GeeBidirList* _tmp43_;
		GeeBidirList* _tmp44_;
		GeeBidirList* _tmp45_;
		gpointer _tmp46_;
		GXmlNode* _tmp47_;
		gchar* _tmp48_;
		gchar* _tmp49_;
		gchar* _tmp50_;
		GXmlNode* p1 = NULL;
		GeeMap* _tmp51_;
		GeeMap* _tmp52_;
		GeeMap* _tmp53_;
		gpointer _tmp54_;
		GXmlNode* _tmp55_;
		gchar* _tmp56_;
		gchar* _tmp57_;
		gchar* _tmp58_;
		GeeBidirList* _tmp59_;
		GeeBidirList* _tmp60_;
		GeeBidirList* _tmp61_;
		gint _tmp62_;
		gint _tmp63_;
		GeeBidirList* _tmp64_;
		GeeBidirList* _tmp65_;
		GeeBidirList* _tmp66_;
		gpointer _tmp67_;
		GXmlNode* _tmp68_;
		GeeBidirList* _tmp69_;
		GeeBidirList* _tmp70_;
		GeeBidirList* _tmp71_;
		gpointer _tmp72_;
		GXmlNode* _tmp73_;
		gchar* _tmp74_;
		gchar* _tmp75_;
		gchar* _tmp76_;
		GXmlNode* s2 = NULL;
		GXmlNode* _tmp77_;
		GXmlNode* _tmp78_;
		GXmlNode* _tmp79_;
		GeeBidirList* _tmp80_;
		GeeBidirList* _tmp81_;
		GeeBidirList* _tmp82_;
		gpointer _tmp83_;
		GXmlNode* _tmp84_;
		gchar* _tmp85_;
		gchar* _tmp86_;
		gchar* _tmp87_;
		GXmlNode* p2 = NULL;
		GeeMap* _tmp88_;
		GeeMap* _tmp89_;
		GeeMap* _tmp90_;
		gpointer _tmp91_;
		GXmlNode* _tmp92_;
		gchar* _tmp93_;
		gchar* _tmp94_;
		gchar* _tmp95_;
		GeeBidirList* _tmp96_;
		GeeBidirList* _tmp97_;
		GeeBidirList* _tmp98_;
		gint _tmp99_;
		gint _tmp100_;
		GeeBidirList* _tmp101_;
		GeeBidirList* _tmp102_;
		GeeBidirList* _tmp103_;
		gpointer _tmp104_;
		GXmlNode* _tmp105_;
		GeeBidirList* _tmp106_;
		GeeBidirList* _tmp107_;
		GeeBidirList* _tmp108_;
		gpointer _tmp109_;
		GXmlNode* _tmp110_;
		gchar* _tmp111_;
		gchar* _tmp112_;
		gchar* _tmp113_;
		GXmlNode* s3 = NULL;
		GXmlNode* _tmp114_;
		GXmlNode* _tmp115_;
		GXmlNode* _tmp116_;
		GeeBidirList* _tmp117_;
		GeeBidirList* _tmp118_;
		GeeBidirList* _tmp119_;
		gpointer _tmp120_;
		GXmlNode* _tmp121_;
		gchar* _tmp122_;
		gchar* _tmp123_;
		gchar* _tmp124_;
		GXmlNode* p3 = NULL;
		GeeMap* _tmp125_;
		GeeMap* _tmp126_;
		GeeMap* _tmp127_;
		gpointer _tmp128_;
		GXmlNode* _tmp129_;
		gchar* _tmp130_;
		gchar* _tmp131_;
		gchar* _tmp132_;
		GXmlNode* p31 = NULL;
		GeeMap* _tmp133_;
		GeeMap* _tmp134_;
		GeeMap* _tmp135_;
		gpointer _tmp136_;
		GXmlNode* _tmp137_;
		gchar* _tmp138_;
		gchar* _tmp139_;
		gchar* _tmp140_;
		GeeBidirList* _tmp141_;
		GeeBidirList* _tmp142_;
		GeeBidirList* _tmp143_;
		gint _tmp144_;
		gint _tmp145_;
		GeeBidirList* _tmp146_;
		GeeBidirList* _tmp147_;
		GeeBidirList* _tmp148_;
		gpointer _tmp149_;
		GXmlNode* _tmp150_;
		GeeBidirList* _tmp151_;
		GeeBidirList* _tmp152_;
		GeeBidirList* _tmp153_;
		gpointer _tmp154_;
		GXmlNode* _tmp155_;
		gchar* _tmp156_;
		gchar* _tmp157_;
		gchar* _tmp158_;
		GeeBidirList* _tmp159_;
		GeeBidirList* _tmp160_;
		GeeBidirList* _tmp161_;
		gpointer _tmp162_;
		GXmlNode* _tmp163_;
		gchar* _tmp164_;
		gchar* _tmp165_;
		gchar* _tmp166_;
		GXmlNode* a1 = NULL;
		GeeBidirList* _tmp167_;
		GeeBidirList* _tmp168_;
		GeeBidirList* _tmp169_;
		gpointer _tmp170_;
		GXmlNode* _tmp171_;
		gchar* _tmp172_;
		gchar* _tmp173_;
		gchar* _tmp174_;
		GeeBidirList* _tmp175_;
		GeeBidirList* _tmp176_;
		GeeBidirList* _tmp177_;
		gint _tmp178_;
		gint _tmp179_;
		GeeBidirList* _tmp180_;
		GeeBidirList* _tmp181_;
		GeeBidirList* _tmp182_;
		gpointer _tmp183_;
		GXmlNode* _tmp184_;
		gchar* _tmp185_;
		gchar* _tmp186_;
		gchar* _tmp187_;
		GeeBidirList* _tmp188_;
		GeeBidirList* _tmp189_;
		GeeBidirList* _tmp190_;
		gpointer _tmp191_;
		GXmlNode* _tmp192_;
		GeeBidirList* _tmp193_;
		GeeBidirList* _tmp194_;
		GeeBidirList* _tmp195_;
		gint _tmp196_;
		gint _tmp197_;
		GeeBidirList* _tmp198_;
		GeeBidirList* _tmp199_;
		GeeBidirList* _tmp200_;
		gpointer _tmp201_;
		GXmlNode* _tmp202_;
		GeeBidirList* _tmp203_;
		GeeBidirList* _tmp204_;
		GeeBidirList* _tmp205_;
		gpointer _tmp206_;
		GXmlNode* _tmp207_;
		GeeBidirList* _tmp208_;
		GeeBidirList* _tmp209_;
		GeeBidirList* _tmp210_;
		gpointer _tmp211_;
		GXmlNode* _tmp212_;
		GeeBidirList* _tmp213_;
		GeeBidirList* _tmp214_;
		GeeBidirList* _tmp215_;
		gpointer _tmp216_;
		GXmlNode* _tmp217_;
		gchar* _tmp218_;
		gchar* _tmp219_;
		gchar* _tmp220_;
		GeeBidirList* _tmp221_;
		GeeBidirList* _tmp222_;
		GeeBidirList* _tmp223_;
		gpointer _tmp224_;
		GXmlNode* _tmp225_;
		gchar* _tmp226_;
		gchar* _tmp227_;
		gchar* _tmp228_;
		GeeBidirList* _tmp229_;
		GeeBidirList* _tmp230_;
		GeeBidirList* _tmp231_;
		gpointer _tmp232_;
		GXmlNode* _tmp233_;
		GeeBidirList* _tmp234_;
		GeeBidirList* _tmp235_;
		GeeBidirList* _tmp236_;
		gint _tmp237_;
		gint _tmp238_;
		GeeBidirList* _tmp239_;
		GeeBidirList* _tmp240_;
		GeeBidirList* _tmp241_;
		gpointer _tmp242_;
		GXmlNode* _tmp243_;
		GeeBidirList* _tmp244_;
		GeeBidirList* _tmp245_;
		GeeBidirList* _tmp246_;
		gpointer _tmp247_;
		GXmlNode* _tmp248_;
		GeeBidirList* _tmp249_;
		GeeBidirList* _tmp250_;
		GeeBidirList* _tmp251_;
		gpointer _tmp252_;
		GXmlNode* _tmp253_;
		GeeBidirList* _tmp254_;
		GeeBidirList* _tmp255_;
		GeeBidirList* _tmp256_;
		gpointer _tmp257_;
		GXmlNode* _tmp258_;
		gchar* _tmp259_;
		gchar* _tmp260_;
		gchar* _tmp261_;
		GXmlNode* a2 = NULL;
		GeeBidirList* _tmp262_;
		GeeBidirList* _tmp263_;
		GeeBidirList* _tmp264_;
		gpointer _tmp265_;
		GXmlNode* _tmp266_;
		GeeBidirList* _tmp267_;
		GeeBidirList* _tmp268_;
		GeeBidirList* _tmp269_;
		gint _tmp270_;
		gint _tmp271_;
		GeeBidirList* _tmp272_;
		GeeBidirList* _tmp273_;
		GeeBidirList* _tmp274_;
		gpointer _tmp275_;
		GXmlNode* _tmp276_;
		gchar* _tmp277_;
		gchar* _tmp278_;
		gchar* _tmp279_;
		GeeBidirList* _tmp280_;
		GeeBidirList* _tmp281_;
		GeeBidirList* _tmp282_;
		gpointer _tmp283_;
		GXmlNode* _tmp284_;
		GeeBidirList* _tmp285_;
		GeeBidirList* _tmp286_;
		GeeBidirList* _tmp287_;
		gint _tmp288_;
		gint _tmp289_;
		GeeBidirList* _tmp290_;
		GeeBidirList* _tmp291_;
		GeeBidirList* _tmp292_;
		gpointer _tmp293_;
		GXmlNode* _tmp294_;
		GeeBidirList* _tmp295_;
		GeeBidirList* _tmp296_;
		GeeBidirList* _tmp297_;
		gpointer _tmp298_;
		GXmlNode* _tmp299_;
		GeeBidirList* _tmp300_;
		GeeBidirList* _tmp301_;
		GeeBidirList* _tmp302_;
		gpointer _tmp303_;
		GXmlNode* _tmp304_;
		GeeBidirList* _tmp305_;
		GeeBidirList* _tmp306_;
		GeeBidirList* _tmp307_;
		gpointer _tmp308_;
		GXmlNode* _tmp309_;
		gchar* _tmp310_;
		gchar* _tmp311_;
		gchar* _tmp312_;
		GeeBidirList* _tmp313_;
		GeeBidirList* _tmp314_;
		GeeBidirList* _tmp315_;
		gpointer _tmp316_;
		GXmlNode* _tmp317_;
		gchar* _tmp318_;
		gchar* _tmp319_;
		gchar* _tmp320_;
		GeeBidirList* _tmp321_;
		GeeBidirList* _tmp322_;
		GeeBidirList* _tmp323_;
		gpointer _tmp324_;
		GXmlNode* _tmp325_;
		GeeBidirList* _tmp326_;
		GeeBidirList* _tmp327_;
		GeeBidirList* _tmp328_;
		gint _tmp329_;
		gint _tmp330_;
		GeeBidirList* _tmp331_;
		GeeBidirList* _tmp332_;
		GeeBidirList* _tmp333_;
		gpointer _tmp334_;
		GXmlNode* _tmp335_;
		GeeBidirList* _tmp336_;
		GeeBidirList* _tmp337_;
		GeeBidirList* _tmp338_;
		gpointer _tmp339_;
		GXmlNode* _tmp340_;
		GeeBidirList* _tmp341_;
		GeeBidirList* _tmp342_;
		GeeBidirList* _tmp343_;
		gpointer _tmp344_;
		GXmlNode* _tmp345_;
		GeeBidirList* _tmp346_;
		GeeBidirList* _tmp347_;
		GeeBidirList* _tmp348_;
		gpointer _tmp349_;
		GXmlNode* _tmp350_;
		gchar* _tmp351_;
		gchar* _tmp352_;
		gchar* _tmp353_;
#line 619 "TDocumentTest.vala"
		_tmp0_ = g_file_new_for_path (TEST_DIR "/t-read-test.xml");
#line 619 "TDocumentTest.vala"
		f = _tmp0_;
#line 620 "TDocumentTest.vala"
		_vala_assert (g_file_query_exists (f, NULL), "f.query_exists ()");
#line 621 "TDocumentTest.vala"
		_tmp2_ = g_file_read (f, NULL, &_inner_error0_);
#line 621 "TDocumentTest.vala"
		_tmp1_ = _tmp2_;
#line 621 "TDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 621 "TDocumentTest.vala"
			_g_object_unref0 (f);
#line 8587 "TDocumentTest.c"
			goto __catch279_g_error;
		}
#line 621 "TDocumentTest.vala"
		_tmp3_ = gxml_tdocument_new_from_stream ((GInputStream*) _tmp1_);
#line 621 "TDocumentTest.vala"
		d = _tmp3_;
#line 623 "TDocumentTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) d);
#line 623 "TDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 623 "TDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 623 "TDocumentTest.vala"
		_vala_assert (_tmp6_ != NULL, "d.root != null");
#line 623 "TDocumentTest.vala"
		_g_object_unref0 (_tmp6_);
#line 624 "TDocumentTest.vala"
		_tmp7_ = gxml_document_get_root ((GXmlDocument*) d);
#line 624 "TDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 624 "TDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 624 "TDocumentTest.vala"
		_tmp10_ = gxml_node_get_name (_tmp9_);
#line 624 "TDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 624 "TDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 624 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp12_, "Sentences") == 0, "d.root.name == \"Sentences\"");
#line 624 "TDocumentTest.vala"
		_g_free0 (_tmp12_);
#line 624 "TDocumentTest.vala"
		_g_object_unref0 (_tmp9_);
#line 625 "TDocumentTest.vala"
		_tmp13_ = gxml_document_get_root ((GXmlDocument*) d);
#line 625 "TDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 625 "TDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 625 "TDocumentTest.vala"
		_tmp16_ = gxml_node_get_attrs (_tmp15_);
#line 625 "TDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 625 "TDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 625 "TDocumentTest.vala"
		_tmp19_ = gee_map_get (_tmp18_, "audience");
#line 625 "TDocumentTest.vala"
		_tmp20_ = (GXmlNode*) _tmp19_;
#line 625 "TDocumentTest.vala"
		_vala_assert (_tmp20_ != NULL, "d.root.attrs[\"audience\"] != null");
#line 625 "TDocumentTest.vala"
		_g_object_unref0 (_tmp20_);
#line 625 "TDocumentTest.vala"
		_g_object_unref0 (_tmp18_);
#line 625 "TDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 626 "TDocumentTest.vala"
		_tmp21_ = gxml_document_get_root ((GXmlDocument*) d);
#line 626 "TDocumentTest.vala"
		_tmp22_ = _tmp21_;
#line 626 "TDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 626 "TDocumentTest.vala"
		_tmp24_ = gxml_node_get_attrs (_tmp23_);
#line 626 "TDocumentTest.vala"
		_tmp25_ = _tmp24_;
#line 626 "TDocumentTest.vala"
		_tmp26_ = _tmp25_;
#line 626 "TDocumentTest.vala"
		_tmp27_ = gee_map_get (_tmp26_, "audience");
#line 626 "TDocumentTest.vala"
		_tmp28_ = (GXmlNode*) _tmp27_;
#line 626 "TDocumentTest.vala"
		_tmp29_ = gxml_node_get_value (_tmp28_);
#line 626 "TDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 626 "TDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 626 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp31_, "All") == 0, "d.root.attrs[\"audience\"].value == \"All\"");
#line 626 "TDocumentTest.vala"
		_g_free0 (_tmp31_);
#line 626 "TDocumentTest.vala"
		_g_object_unref0 (_tmp28_);
#line 626 "TDocumentTest.vala"
		_g_object_unref0 (_tmp26_);
#line 626 "TDocumentTest.vala"
		_g_object_unref0 (_tmp23_);
#line 627 "TDocumentTest.vala"
		_tmp32_ = gxml_document_get_root ((GXmlDocument*) d);
#line 627 "TDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 627 "TDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 627 "TDocumentTest.vala"
		_tmp35_ = gxml_node_get_children_nodes (_tmp34_);
#line 627 "TDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 627 "TDocumentTest.vala"
		_tmp37_ = _tmp36_;
#line 627 "TDocumentTest.vala"
		_tmp38_ = gee_collection_get_size ((GeeCollection*) _tmp37_);
#line 627 "TDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 627 "TDocumentTest.vala"
		_vala_assert (_tmp39_ == 7, "d.root.children_nodes.size == 7");
#line 627 "TDocumentTest.vala"
		_g_object_unref0 (_tmp37_);
#line 627 "TDocumentTest.vala"
		_g_object_unref0 (_tmp34_);
#line 628 "TDocumentTest.vala"
		_tmp40_ = gxml_document_get_root ((GXmlDocument*) d);
#line 628 "TDocumentTest.vala"
		_tmp41_ = _tmp40_;
#line 628 "TDocumentTest.vala"
		_tmp42_ = _tmp41_;
#line 628 "TDocumentTest.vala"
		_tmp43_ = gxml_node_get_children_nodes (_tmp42_);
#line 628 "TDocumentTest.vala"
		_tmp44_ = _tmp43_;
#line 628 "TDocumentTest.vala"
		_tmp45_ = _tmp44_;
#line 628 "TDocumentTest.vala"
		_tmp46_ = gee_list_get ((GeeList*) _tmp45_, 0);
#line 628 "TDocumentTest.vala"
		_tmp47_ = (GXmlNode*) _tmp46_;
#line 628 "TDocumentTest.vala"
		_g_object_unref0 (_tmp45_);
#line 628 "TDocumentTest.vala"
		_g_object_unref0 (_tmp42_);
#line 628 "TDocumentTest.vala"
		s1 = _tmp47_;
#line 629 "TDocumentTest.vala"
		_vala_assert (s1 != NULL, "s1 != null");
#line 630 "TDocumentTest.vala"
		_tmp48_ = gxml_node_get_name (s1);
#line 630 "TDocumentTest.vala"
		_tmp49_ = _tmp48_;
#line 630 "TDocumentTest.vala"
		_tmp50_ = _tmp49_;
#line 630 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp50_, "Sentence") == 0, "s1.name == \"Sentence\"");
#line 630 "TDocumentTest.vala"
		_g_free0 (_tmp50_);
#line 631 "TDocumentTest.vala"
		_tmp51_ = gxml_node_get_attrs (s1);
#line 631 "TDocumentTest.vala"
		_tmp52_ = _tmp51_;
#line 631 "TDocumentTest.vala"
		_tmp53_ = _tmp52_;
#line 631 "TDocumentTest.vala"
		_tmp54_ = gee_map_get (_tmp53_, "lang");
#line 631 "TDocumentTest.vala"
		_tmp55_ = (GXmlNode*) _tmp54_;
#line 631 "TDocumentTest.vala"
		_g_object_unref0 (_tmp53_);
#line 631 "TDocumentTest.vala"
		p1 = _tmp55_;
#line 632 "TDocumentTest.vala"
		_vala_assert (p1 != NULL, "p1 != null");
#line 633 "TDocumentTest.vala"
		_tmp56_ = gxml_node_get_value (p1);
#line 633 "TDocumentTest.vala"
		_tmp57_ = _tmp56_;
#line 633 "TDocumentTest.vala"
		_tmp58_ = _tmp57_;
#line 633 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp58_, "en") == 0, "p1.value == \"en\"");
#line 633 "TDocumentTest.vala"
		_g_free0 (_tmp58_);
#line 634 "TDocumentTest.vala"
		_tmp59_ = gxml_node_get_children_nodes (s1);
#line 634 "TDocumentTest.vala"
		_tmp60_ = _tmp59_;
#line 634 "TDocumentTest.vala"
		_tmp61_ = _tmp60_;
#line 634 "TDocumentTest.vala"
		_tmp62_ = gee_collection_get_size ((GeeCollection*) _tmp61_);
#line 634 "TDocumentTest.vala"
		_tmp63_ = _tmp62_;
#line 634 "TDocumentTest.vala"
		_vala_assert (_tmp63_ == 1, "s1.children_nodes.size == 1");
#line 634 "TDocumentTest.vala"
		_g_object_unref0 (_tmp61_);
#line 635 "TDocumentTest.vala"
		_tmp64_ = gxml_node_get_children_nodes (s1);
#line 635 "TDocumentTest.vala"
		_tmp65_ = _tmp64_;
#line 635 "TDocumentTest.vala"
		_tmp66_ = _tmp65_;
#line 635 "TDocumentTest.vala"
		_tmp67_ = gee_list_get ((GeeList*) _tmp66_, 0);
#line 635 "TDocumentTest.vala"
		_tmp68_ = (GXmlNode*) _tmp67_;
#line 635 "TDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp68_, GXML_TYPE_TEXT), "s1.children_nodes[0] is GXml.Text");
#line 635 "TDocumentTest.vala"
		_g_object_unref0 (_tmp68_);
#line 635 "TDocumentTest.vala"
		_g_object_unref0 (_tmp66_);
#line 636 "TDocumentTest.vala"
		_tmp69_ = gxml_node_get_children_nodes (s1);
#line 636 "TDocumentTest.vala"
		_tmp70_ = _tmp69_;
#line 636 "TDocumentTest.vala"
		_tmp71_ = _tmp70_;
#line 636 "TDocumentTest.vala"
		_tmp72_ = gee_list_get ((GeeList*) _tmp71_, 0);
#line 636 "TDocumentTest.vala"
		_tmp73_ = (GXmlNode*) _tmp72_;
#line 636 "TDocumentTest.vala"
		_tmp74_ = gxml_node_get_value (_tmp73_);
#line 636 "TDocumentTest.vala"
		_tmp75_ = _tmp74_;
#line 636 "TDocumentTest.vala"
		_tmp76_ = _tmp75_;
#line 636 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp76_, "I like the colour blue.") == 0, "s1.children_nodes[0].value == \"I like the colour blue.\"");
#line 636 "TDocumentTest.vala"
		_g_free0 (_tmp76_);
#line 636 "TDocumentTest.vala"
		_g_object_unref0 (_tmp73_);
#line 636 "TDocumentTest.vala"
		_g_object_unref0 (_tmp71_);
#line 637 "TDocumentTest.vala"
		_tmp77_ = gxml_document_get_root ((GXmlDocument*) d);
#line 637 "TDocumentTest.vala"
		_tmp78_ = _tmp77_;
#line 637 "TDocumentTest.vala"
		_tmp79_ = _tmp78_;
#line 637 "TDocumentTest.vala"
		_tmp80_ = gxml_node_get_children_nodes (_tmp79_);
#line 637 "TDocumentTest.vala"
		_tmp81_ = _tmp80_;
#line 637 "TDocumentTest.vala"
		_tmp82_ = _tmp81_;
#line 637 "TDocumentTest.vala"
		_tmp83_ = gee_list_get ((GeeList*) _tmp82_, 1);
#line 637 "TDocumentTest.vala"
		_tmp84_ = (GXmlNode*) _tmp83_;
#line 637 "TDocumentTest.vala"
		_g_object_unref0 (_tmp82_);
#line 637 "TDocumentTest.vala"
		_g_object_unref0 (_tmp79_);
#line 637 "TDocumentTest.vala"
		s2 = _tmp84_;
#line 638 "TDocumentTest.vala"
		_vala_assert (s2 != NULL, "s2 != null");
#line 639 "TDocumentTest.vala"
		_tmp85_ = gxml_node_get_name (s2);
#line 639 "TDocumentTest.vala"
		_tmp86_ = _tmp85_;
#line 639 "TDocumentTest.vala"
		_tmp87_ = _tmp86_;
#line 639 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp87_, "Sentence") == 0, "s2.name == \"Sentence\"");
#line 639 "TDocumentTest.vala"
		_g_free0 (_tmp87_);
#line 640 "TDocumentTest.vala"
		_tmp88_ = gxml_node_get_attrs (s2);
#line 640 "TDocumentTest.vala"
		_tmp89_ = _tmp88_;
#line 640 "TDocumentTest.vala"
		_tmp90_ = _tmp89_;
#line 640 "TDocumentTest.vala"
		_tmp91_ = gee_map_get (_tmp90_, "lang");
#line 640 "TDocumentTest.vala"
		_tmp92_ = (GXmlNode*) _tmp91_;
#line 640 "TDocumentTest.vala"
		_g_object_unref0 (_tmp90_);
#line 640 "TDocumentTest.vala"
		p2 = _tmp92_;
#line 641 "TDocumentTest.vala"
		_vala_assert (p2 != NULL, "p2 != null");
#line 642 "TDocumentTest.vala"
		_tmp93_ = gxml_node_get_value (p2);
#line 642 "TDocumentTest.vala"
		_tmp94_ = _tmp93_;
#line 642 "TDocumentTest.vala"
		_tmp95_ = _tmp94_;
#line 642 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp95_, "es") == 0, "p2.value == \"es\"");
#line 642 "TDocumentTest.vala"
		_g_free0 (_tmp95_);
#line 643 "TDocumentTest.vala"
		_tmp96_ = gxml_node_get_children_nodes (s2);
#line 643 "TDocumentTest.vala"
		_tmp97_ = _tmp96_;
#line 643 "TDocumentTest.vala"
		_tmp98_ = _tmp97_;
#line 643 "TDocumentTest.vala"
		_tmp99_ = gee_collection_get_size ((GeeCollection*) _tmp98_);
#line 643 "TDocumentTest.vala"
		_tmp100_ = _tmp99_;
#line 643 "TDocumentTest.vala"
		_vala_assert (_tmp100_ == 1, "s2.children_nodes.size == 1");
#line 643 "TDocumentTest.vala"
		_g_object_unref0 (_tmp98_);
#line 644 "TDocumentTest.vala"
		_tmp101_ = gxml_node_get_children_nodes (s2);
#line 644 "TDocumentTest.vala"
		_tmp102_ = _tmp101_;
#line 644 "TDocumentTest.vala"
		_tmp103_ = _tmp102_;
#line 644 "TDocumentTest.vala"
		_tmp104_ = gee_list_get ((GeeList*) _tmp103_, 0);
#line 644 "TDocumentTest.vala"
		_tmp105_ = (GXmlNode*) _tmp104_;
#line 644 "TDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp105_, GXML_TYPE_TEXT), "s2.children_nodes[0] is GXml.Text");
#line 644 "TDocumentTest.vala"
		_g_object_unref0 (_tmp105_);
#line 644 "TDocumentTest.vala"
		_g_object_unref0 (_tmp103_);
#line 645 "TDocumentTest.vala"
		_tmp106_ = gxml_node_get_children_nodes (s2);
#line 645 "TDocumentTest.vala"
		_tmp107_ = _tmp106_;
#line 645 "TDocumentTest.vala"
		_tmp108_ = _tmp107_;
#line 645 "TDocumentTest.vala"
		_tmp109_ = gee_list_get ((GeeList*) _tmp108_, 0);
#line 645 "TDocumentTest.vala"
		_tmp110_ = (GXmlNode*) _tmp109_;
#line 645 "TDocumentTest.vala"
		_tmp111_ = gxml_node_get_value (_tmp110_);
#line 645 "TDocumentTest.vala"
		_tmp112_ = _tmp111_;
#line 645 "TDocumentTest.vala"
		_tmp113_ = _tmp112_;
#line 645 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp113_, "Español") == 0, "s2.children_nodes[0].value == \"Espa\303\261ol\"");
#line 645 "TDocumentTest.vala"
		_g_free0 (_tmp113_);
#line 645 "TDocumentTest.vala"
		_g_object_unref0 (_tmp110_);
#line 645 "TDocumentTest.vala"
		_g_object_unref0 (_tmp108_);
#line 646 "TDocumentTest.vala"
		_tmp114_ = gxml_document_get_root ((GXmlDocument*) d);
#line 646 "TDocumentTest.vala"
		_tmp115_ = _tmp114_;
#line 646 "TDocumentTest.vala"
		_tmp116_ = _tmp115_;
#line 646 "TDocumentTest.vala"
		_tmp117_ = gxml_node_get_children_nodes (_tmp116_);
#line 646 "TDocumentTest.vala"
		_tmp118_ = _tmp117_;
#line 646 "TDocumentTest.vala"
		_tmp119_ = _tmp118_;
#line 646 "TDocumentTest.vala"
		_tmp120_ = gee_list_get ((GeeList*) _tmp119_, 2);
#line 646 "TDocumentTest.vala"
		_tmp121_ = (GXmlNode*) _tmp120_;
#line 646 "TDocumentTest.vala"
		_g_object_unref0 (_tmp119_);
#line 646 "TDocumentTest.vala"
		_g_object_unref0 (_tmp116_);
#line 646 "TDocumentTest.vala"
		s3 = _tmp121_;
#line 647 "TDocumentTest.vala"
		_vala_assert (s3 != NULL, "s3 != null");
#line 648 "TDocumentTest.vala"
		_tmp122_ = gxml_node_get_name (s3);
#line 648 "TDocumentTest.vala"
		_tmp123_ = _tmp122_;
#line 648 "TDocumentTest.vala"
		_tmp124_ = _tmp123_;
#line 648 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp124_, "Authors") == 0, "s3.name == \"Authors\"");
#line 648 "TDocumentTest.vala"
		_g_free0 (_tmp124_);
#line 649 "TDocumentTest.vala"
		_tmp125_ = gxml_node_get_attrs (s3);
#line 649 "TDocumentTest.vala"
		_tmp126_ = _tmp125_;
#line 649 "TDocumentTest.vala"
		_tmp127_ = _tmp126_;
#line 649 "TDocumentTest.vala"
		_tmp128_ = gee_map_get (_tmp127_, "year");
#line 649 "TDocumentTest.vala"
		_tmp129_ = (GXmlNode*) _tmp128_;
#line 649 "TDocumentTest.vala"
		_g_object_unref0 (_tmp127_);
#line 649 "TDocumentTest.vala"
		p3 = _tmp129_;
#line 650 "TDocumentTest.vala"
		_vala_assert (p3 != NULL, "p3 != null");
#line 651 "TDocumentTest.vala"
		_tmp130_ = gxml_node_get_value (p3);
#line 651 "TDocumentTest.vala"
		_tmp131_ = _tmp130_;
#line 651 "TDocumentTest.vala"
		_tmp132_ = _tmp131_;
#line 651 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp132_, "2016") == 0, "p3.value == \"2016\"");
#line 651 "TDocumentTest.vala"
		_g_free0 (_tmp132_);
#line 652 "TDocumentTest.vala"
		_tmp133_ = gxml_node_get_attrs (s3);
#line 652 "TDocumentTest.vala"
		_tmp134_ = _tmp133_;
#line 652 "TDocumentTest.vala"
		_tmp135_ = _tmp134_;
#line 652 "TDocumentTest.vala"
		_tmp136_ = gee_map_get (_tmp135_, "collection");
#line 652 "TDocumentTest.vala"
		_tmp137_ = (GXmlNode*) _tmp136_;
#line 652 "TDocumentTest.vala"
		_g_object_unref0 (_tmp135_);
#line 652 "TDocumentTest.vala"
		p31 = _tmp137_;
#line 653 "TDocumentTest.vala"
		_vala_assert (p31 != NULL, "p31 != null");
#line 654 "TDocumentTest.vala"
		_tmp138_ = gxml_node_get_value (p31);
#line 654 "TDocumentTest.vala"
		_tmp139_ = _tmp138_;
#line 654 "TDocumentTest.vala"
		_tmp140_ = _tmp139_;
#line 654 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp140_, "Back") == 0, "p31.value == \"Back\"");
#line 654 "TDocumentTest.vala"
		_g_free0 (_tmp140_);
#line 655 "TDocumentTest.vala"
		_tmp141_ = gxml_node_get_children_nodes (s3);
#line 655 "TDocumentTest.vala"
		_tmp142_ = _tmp141_;
#line 655 "TDocumentTest.vala"
		_tmp143_ = _tmp142_;
#line 655 "TDocumentTest.vala"
		_tmp144_ = gee_collection_get_size ((GeeCollection*) _tmp143_);
#line 655 "TDocumentTest.vala"
		_tmp145_ = _tmp144_;
#line 655 "TDocumentTest.vala"
		_vala_assert (_tmp145_ == 2, "s3.children_nodes.size == 2");
#line 655 "TDocumentTest.vala"
		_g_object_unref0 (_tmp143_);
#line 656 "TDocumentTest.vala"
		_tmp146_ = gxml_node_get_children_nodes (s3);
#line 656 "TDocumentTest.vala"
		_tmp147_ = _tmp146_;
#line 656 "TDocumentTest.vala"
		_tmp148_ = _tmp147_;
#line 656 "TDocumentTest.vala"
		_tmp149_ = gee_list_get ((GeeList*) _tmp148_, 0);
#line 656 "TDocumentTest.vala"
		_tmp150_ = (GXmlNode*) _tmp149_;
#line 656 "TDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp150_, GXML_TYPE_ELEMENT), "s3.children_nodes[0] is GXml.Element");
#line 656 "TDocumentTest.vala"
		_g_object_unref0 (_tmp150_);
#line 656 "TDocumentTest.vala"
		_g_object_unref0 (_tmp148_);
#line 657 "TDocumentTest.vala"
		_tmp151_ = gxml_node_get_children_nodes (s3);
#line 657 "TDocumentTest.vala"
		_tmp152_ = _tmp151_;
#line 657 "TDocumentTest.vala"
		_tmp153_ = _tmp152_;
#line 657 "TDocumentTest.vala"
		_tmp154_ = gee_list_get ((GeeList*) _tmp153_, 0);
#line 657 "TDocumentTest.vala"
		_tmp155_ = (GXmlNode*) _tmp154_;
#line 657 "TDocumentTest.vala"
		_tmp156_ = gxml_node_get_name (_tmp155_);
#line 657 "TDocumentTest.vala"
		_tmp157_ = _tmp156_;
#line 657 "TDocumentTest.vala"
		_tmp158_ = _tmp157_;
#line 657 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp158_, "Author") == 0, "s3.children_nodes[0].name == \"Author\"");
#line 657 "TDocumentTest.vala"
		_g_free0 (_tmp158_);
#line 657 "TDocumentTest.vala"
		_g_object_unref0 (_tmp155_);
#line 657 "TDocumentTest.vala"
		_g_object_unref0 (_tmp153_);
#line 658 "TDocumentTest.vala"
		_tmp159_ = gxml_node_get_children_nodes (s3);
#line 658 "TDocumentTest.vala"
		_tmp160_ = _tmp159_;
#line 658 "TDocumentTest.vala"
		_tmp161_ = _tmp160_;
#line 658 "TDocumentTest.vala"
		_tmp162_ = gee_list_get ((GeeList*) _tmp161_, 1);
#line 658 "TDocumentTest.vala"
		_tmp163_ = (GXmlNode*) _tmp162_;
#line 658 "TDocumentTest.vala"
		_tmp164_ = gxml_node_get_name (_tmp163_);
#line 658 "TDocumentTest.vala"
		_tmp165_ = _tmp164_;
#line 658 "TDocumentTest.vala"
		_tmp166_ = _tmp165_;
#line 658 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp166_, "Author") == 0, "s3.children_nodes[1].name == \"Author\"");
#line 658 "TDocumentTest.vala"
		_g_free0 (_tmp166_);
#line 658 "TDocumentTest.vala"
		_g_object_unref0 (_tmp163_);
#line 658 "TDocumentTest.vala"
		_g_object_unref0 (_tmp161_);
#line 659 "TDocumentTest.vala"
		_tmp167_ = gxml_node_get_children_nodes (s3);
#line 659 "TDocumentTest.vala"
		_tmp168_ = _tmp167_;
#line 659 "TDocumentTest.vala"
		_tmp169_ = _tmp168_;
#line 659 "TDocumentTest.vala"
		_tmp170_ = gee_list_get ((GeeList*) _tmp169_, 0);
#line 659 "TDocumentTest.vala"
		_tmp171_ = (GXmlNode*) _tmp170_;
#line 659 "TDocumentTest.vala"
		_g_object_unref0 (_tmp169_);
#line 659 "TDocumentTest.vala"
		a1 = _tmp171_;
#line 660 "TDocumentTest.vala"
		_vala_assert (a1 != NULL, "a1 != null");
#line 661 "TDocumentTest.vala"
		_tmp172_ = gxml_node_get_name (a1);
#line 661 "TDocumentTest.vala"
		_tmp173_ = _tmp172_;
#line 661 "TDocumentTest.vala"
		_tmp174_ = _tmp173_;
#line 661 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp174_, "Author") == 0, "a1.name == \"Author\"");
#line 661 "TDocumentTest.vala"
		_g_free0 (_tmp174_);
#line 662 "TDocumentTest.vala"
		_tmp175_ = gxml_node_get_children_nodes (a1);
#line 662 "TDocumentTest.vala"
		_tmp176_ = _tmp175_;
#line 662 "TDocumentTest.vala"
		_tmp177_ = _tmp176_;
#line 662 "TDocumentTest.vala"
		_tmp178_ = gee_collection_get_size ((GeeCollection*) _tmp177_);
#line 662 "TDocumentTest.vala"
		_tmp179_ = _tmp178_;
#line 662 "TDocumentTest.vala"
		_vala_assert (_tmp179_ == 2, "a1.children_nodes.size == 2");
#line 662 "TDocumentTest.vala"
		_g_object_unref0 (_tmp177_);
#line 663 "TDocumentTest.vala"
		_tmp180_ = gxml_node_get_children_nodes (a1);
#line 663 "TDocumentTest.vala"
		_tmp181_ = _tmp180_;
#line 663 "TDocumentTest.vala"
		_tmp182_ = _tmp181_;
#line 663 "TDocumentTest.vala"
		_tmp183_ = gee_list_get ((GeeList*) _tmp182_, 0);
#line 663 "TDocumentTest.vala"
		_tmp184_ = (GXmlNode*) _tmp183_;
#line 663 "TDocumentTest.vala"
		_tmp185_ = gxml_node_get_name (_tmp184_);
#line 663 "TDocumentTest.vala"
		_tmp186_ = _tmp185_;
#line 663 "TDocumentTest.vala"
		_tmp187_ = _tmp186_;
#line 663 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp187_, "Name") == 0, "a1.children_nodes[0].name == \"Name\"");
#line 663 "TDocumentTest.vala"
		_g_free0 (_tmp187_);
#line 663 "TDocumentTest.vala"
		_g_object_unref0 (_tmp184_);
#line 663 "TDocumentTest.vala"
		_g_object_unref0 (_tmp182_);
#line 664 "TDocumentTest.vala"
		_tmp188_ = gxml_node_get_children_nodes (a1);
#line 664 "TDocumentTest.vala"
		_tmp189_ = _tmp188_;
#line 664 "TDocumentTest.vala"
		_tmp190_ = _tmp189_;
#line 664 "TDocumentTest.vala"
		_tmp191_ = gee_list_get ((GeeList*) _tmp190_, 0);
#line 664 "TDocumentTest.vala"
		_tmp192_ = (GXmlNode*) _tmp191_;
#line 664 "TDocumentTest.vala"
		_tmp193_ = gxml_node_get_children_nodes (_tmp192_);
#line 664 "TDocumentTest.vala"
		_tmp194_ = _tmp193_;
#line 664 "TDocumentTest.vala"
		_tmp195_ = _tmp194_;
#line 664 "TDocumentTest.vala"
		_tmp196_ = gee_collection_get_size ((GeeCollection*) _tmp195_);
#line 664 "TDocumentTest.vala"
		_tmp197_ = _tmp196_;
#line 664 "TDocumentTest.vala"
		_vala_assert (_tmp197_ == 1, "a1.children_nodes[0].children_nodes.size == 1");
#line 664 "TDocumentTest.vala"
		_g_object_unref0 (_tmp195_);
#line 664 "TDocumentTest.vala"
		_g_object_unref0 (_tmp192_);
#line 664 "TDocumentTest.vala"
		_g_object_unref0 (_tmp190_);
#line 665 "TDocumentTest.vala"
		_tmp198_ = gxml_node_get_children_nodes (a1);
#line 665 "TDocumentTest.vala"
		_tmp199_ = _tmp198_;
#line 665 "TDocumentTest.vala"
		_tmp200_ = _tmp199_;
#line 665 "TDocumentTest.vala"
		_tmp201_ = gee_list_get ((GeeList*) _tmp200_, 0);
#line 665 "TDocumentTest.vala"
		_tmp202_ = (GXmlNode*) _tmp201_;
#line 665 "TDocumentTest.vala"
		_tmp203_ = gxml_node_get_children_nodes (_tmp202_);
#line 665 "TDocumentTest.vala"
		_tmp204_ = _tmp203_;
#line 665 "TDocumentTest.vala"
		_tmp205_ = _tmp204_;
#line 665 "TDocumentTest.vala"
		_tmp206_ = gee_list_get ((GeeList*) _tmp205_, 0);
#line 665 "TDocumentTest.vala"
		_tmp207_ = (GXmlNode*) _tmp206_;
#line 665 "TDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp207_, GXML_TYPE_TEXT), "a1.children_nodes[0].children_nodes[0] is GXml.Text");
#line 665 "TDocumentTest.vala"
		_g_object_unref0 (_tmp207_);
#line 665 "TDocumentTest.vala"
		_g_object_unref0 (_tmp205_);
#line 665 "TDocumentTest.vala"
		_g_object_unref0 (_tmp202_);
#line 665 "TDocumentTest.vala"
		_g_object_unref0 (_tmp200_);
#line 666 "TDocumentTest.vala"
		_tmp208_ = gxml_node_get_children_nodes (a1);
#line 666 "TDocumentTest.vala"
		_tmp209_ = _tmp208_;
#line 666 "TDocumentTest.vala"
		_tmp210_ = _tmp209_;
#line 666 "TDocumentTest.vala"
		_tmp211_ = gee_list_get ((GeeList*) _tmp210_, 0);
#line 666 "TDocumentTest.vala"
		_tmp212_ = (GXmlNode*) _tmp211_;
#line 666 "TDocumentTest.vala"
		_tmp213_ = gxml_node_get_children_nodes (_tmp212_);
#line 666 "TDocumentTest.vala"
		_tmp214_ = _tmp213_;
#line 666 "TDocumentTest.vala"
		_tmp215_ = _tmp214_;
#line 666 "TDocumentTest.vala"
		_tmp216_ = gee_list_get ((GeeList*) _tmp215_, 0);
#line 666 "TDocumentTest.vala"
		_tmp217_ = (GXmlNode*) _tmp216_;
#line 666 "TDocumentTest.vala"
		_tmp218_ = gxml_node_get_value (_tmp217_);
#line 666 "TDocumentTest.vala"
		_tmp219_ = _tmp218_;
#line 666 "TDocumentTest.vala"
		_tmp220_ = _tmp219_;
#line 666 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp220_, "Fred") == 0, "a1.children_nodes[0].children_nodes[0].value == \"Fred\"");
#line 666 "TDocumentTest.vala"
		_g_free0 (_tmp220_);
#line 666 "TDocumentTest.vala"
		_g_object_unref0 (_tmp217_);
#line 666 "TDocumentTest.vala"
		_g_object_unref0 (_tmp215_);
#line 666 "TDocumentTest.vala"
		_g_object_unref0 (_tmp212_);
#line 666 "TDocumentTest.vala"
		_g_object_unref0 (_tmp210_);
#line 667 "TDocumentTest.vala"
		_tmp221_ = gxml_node_get_children_nodes (a1);
#line 667 "TDocumentTest.vala"
		_tmp222_ = _tmp221_;
#line 667 "TDocumentTest.vala"
		_tmp223_ = _tmp222_;
#line 667 "TDocumentTest.vala"
		_tmp224_ = gee_list_get ((GeeList*) _tmp223_, 1);
#line 667 "TDocumentTest.vala"
		_tmp225_ = (GXmlNode*) _tmp224_;
#line 667 "TDocumentTest.vala"
		_tmp226_ = gxml_node_get_name (_tmp225_);
#line 667 "TDocumentTest.vala"
		_tmp227_ = _tmp226_;
#line 667 "TDocumentTest.vala"
		_tmp228_ = _tmp227_;
#line 667 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp228_, "Email") == 0, "a1.children_nodes[1].name == \"Email\"");
#line 667 "TDocumentTest.vala"
		_g_free0 (_tmp228_);
#line 667 "TDocumentTest.vala"
		_g_object_unref0 (_tmp225_);
#line 667 "TDocumentTest.vala"
		_g_object_unref0 (_tmp223_);
#line 668 "TDocumentTest.vala"
		_tmp229_ = gxml_node_get_children_nodes (a1);
#line 668 "TDocumentTest.vala"
		_tmp230_ = _tmp229_;
#line 668 "TDocumentTest.vala"
		_tmp231_ = _tmp230_;
#line 668 "TDocumentTest.vala"
		_tmp232_ = gee_list_get ((GeeList*) _tmp231_, 1);
#line 668 "TDocumentTest.vala"
		_tmp233_ = (GXmlNode*) _tmp232_;
#line 668 "TDocumentTest.vala"
		_tmp234_ = gxml_node_get_children_nodes (_tmp233_);
#line 668 "TDocumentTest.vala"
		_tmp235_ = _tmp234_;
#line 668 "TDocumentTest.vala"
		_tmp236_ = _tmp235_;
#line 668 "TDocumentTest.vala"
		_tmp237_ = gee_collection_get_size ((GeeCollection*) _tmp236_);
#line 668 "TDocumentTest.vala"
		_tmp238_ = _tmp237_;
#line 668 "TDocumentTest.vala"
		_vala_assert (_tmp238_ == 1, "a1.children_nodes[1].children_nodes.size == 1");
#line 668 "TDocumentTest.vala"
		_g_object_unref0 (_tmp236_);
#line 668 "TDocumentTest.vala"
		_g_object_unref0 (_tmp233_);
#line 668 "TDocumentTest.vala"
		_g_object_unref0 (_tmp231_);
#line 669 "TDocumentTest.vala"
		_tmp239_ = gxml_node_get_children_nodes (a1);
#line 669 "TDocumentTest.vala"
		_tmp240_ = _tmp239_;
#line 669 "TDocumentTest.vala"
		_tmp241_ = _tmp240_;
#line 669 "TDocumentTest.vala"
		_tmp242_ = gee_list_get ((GeeList*) _tmp241_, 1);
#line 669 "TDocumentTest.vala"
		_tmp243_ = (GXmlNode*) _tmp242_;
#line 669 "TDocumentTest.vala"
		_tmp244_ = gxml_node_get_children_nodes (_tmp243_);
#line 669 "TDocumentTest.vala"
		_tmp245_ = _tmp244_;
#line 669 "TDocumentTest.vala"
		_tmp246_ = _tmp245_;
#line 669 "TDocumentTest.vala"
		_tmp247_ = gee_list_get ((GeeList*) _tmp246_, 0);
#line 669 "TDocumentTest.vala"
		_tmp248_ = (GXmlNode*) _tmp247_;
#line 669 "TDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp248_, GXML_TYPE_TEXT), "a1.children_nodes[1].children_nodes[0] is GXml.Text");
#line 669 "TDocumentTest.vala"
		_g_object_unref0 (_tmp248_);
#line 669 "TDocumentTest.vala"
		_g_object_unref0 (_tmp246_);
#line 669 "TDocumentTest.vala"
		_g_object_unref0 (_tmp243_);
#line 669 "TDocumentTest.vala"
		_g_object_unref0 (_tmp241_);
#line 670 "TDocumentTest.vala"
		_tmp249_ = gxml_node_get_children_nodes (a1);
#line 670 "TDocumentTest.vala"
		_tmp250_ = _tmp249_;
#line 670 "TDocumentTest.vala"
		_tmp251_ = _tmp250_;
#line 670 "TDocumentTest.vala"
		_tmp252_ = gee_list_get ((GeeList*) _tmp251_, 1);
#line 670 "TDocumentTest.vala"
		_tmp253_ = (GXmlNode*) _tmp252_;
#line 670 "TDocumentTest.vala"
		_tmp254_ = gxml_node_get_children_nodes (_tmp253_);
#line 670 "TDocumentTest.vala"
		_tmp255_ = _tmp254_;
#line 670 "TDocumentTest.vala"
		_tmp256_ = _tmp255_;
#line 670 "TDocumentTest.vala"
		_tmp257_ = gee_list_get ((GeeList*) _tmp256_, 0);
#line 670 "TDocumentTest.vala"
		_tmp258_ = (GXmlNode*) _tmp257_;
#line 670 "TDocumentTest.vala"
		_tmp259_ = gxml_node_get_value (_tmp258_);
#line 670 "TDocumentTest.vala"
		_tmp260_ = _tmp259_;
#line 670 "TDocumentTest.vala"
		_tmp261_ = _tmp260_;
#line 670 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp261_, "fweasley@hogwarts.co.uk") == 0, "a1.children_nodes[1].children_nodes[0].value == \"fweasley@hogwarts.co.uk\"");
#line 670 "TDocumentTest.vala"
		_g_free0 (_tmp261_);
#line 670 "TDocumentTest.vala"
		_g_object_unref0 (_tmp258_);
#line 670 "TDocumentTest.vala"
		_g_object_unref0 (_tmp256_);
#line 670 "TDocumentTest.vala"
		_g_object_unref0 (_tmp253_);
#line 670 "TDocumentTest.vala"
		_g_object_unref0 (_tmp251_);
#line 671 "TDocumentTest.vala"
		_tmp262_ = gxml_node_get_children_nodes (s3);
#line 671 "TDocumentTest.vala"
		_tmp263_ = _tmp262_;
#line 671 "TDocumentTest.vala"
		_tmp264_ = _tmp263_;
#line 671 "TDocumentTest.vala"
		_tmp265_ = gee_list_get ((GeeList*) _tmp264_, 1);
#line 671 "TDocumentTest.vala"
		_tmp266_ = (GXmlNode*) _tmp265_;
#line 671 "TDocumentTest.vala"
		_g_object_unref0 (_tmp264_);
#line 671 "TDocumentTest.vala"
		a2 = _tmp266_;
#line 672 "TDocumentTest.vala"
		_vala_assert (a2 != NULL, "a2 != null");
#line 673 "TDocumentTest.vala"
		_tmp267_ = gxml_node_get_children_nodes (a2);
#line 673 "TDocumentTest.vala"
		_tmp268_ = _tmp267_;
#line 673 "TDocumentTest.vala"
		_tmp269_ = _tmp268_;
#line 673 "TDocumentTest.vala"
		_tmp270_ = gee_collection_get_size ((GeeCollection*) _tmp269_);
#line 673 "TDocumentTest.vala"
		_tmp271_ = _tmp270_;
#line 673 "TDocumentTest.vala"
		_vala_assert (_tmp271_ == 3, "a2.children_nodes.size == 3");
#line 673 "TDocumentTest.vala"
		_g_object_unref0 (_tmp269_);
#line 674 "TDocumentTest.vala"
		_tmp272_ = gxml_node_get_children_nodes (a2);
#line 674 "TDocumentTest.vala"
		_tmp273_ = _tmp272_;
#line 674 "TDocumentTest.vala"
		_tmp274_ = _tmp273_;
#line 674 "TDocumentTest.vala"
		_tmp275_ = gee_list_get ((GeeList*) _tmp274_, 1);
#line 674 "TDocumentTest.vala"
		_tmp276_ = (GXmlNode*) _tmp275_;
#line 674 "TDocumentTest.vala"
		_tmp277_ = gxml_node_get_name (_tmp276_);
#line 674 "TDocumentTest.vala"
		_tmp278_ = _tmp277_;
#line 674 "TDocumentTest.vala"
		_tmp279_ = _tmp278_;
#line 674 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp279_, "Name") == 0, "a2.children_nodes[1].name == \"Name\"");
#line 674 "TDocumentTest.vala"
		_g_free0 (_tmp279_);
#line 674 "TDocumentTest.vala"
		_g_object_unref0 (_tmp276_);
#line 674 "TDocumentTest.vala"
		_g_object_unref0 (_tmp274_);
#line 675 "TDocumentTest.vala"
		_tmp280_ = gxml_node_get_children_nodes (a2);
#line 675 "TDocumentTest.vala"
		_tmp281_ = _tmp280_;
#line 675 "TDocumentTest.vala"
		_tmp282_ = _tmp281_;
#line 675 "TDocumentTest.vala"
		_tmp283_ = gee_list_get ((GeeList*) _tmp282_, 1);
#line 675 "TDocumentTest.vala"
		_tmp284_ = (GXmlNode*) _tmp283_;
#line 675 "TDocumentTest.vala"
		_tmp285_ = gxml_node_get_children_nodes (_tmp284_);
#line 675 "TDocumentTest.vala"
		_tmp286_ = _tmp285_;
#line 675 "TDocumentTest.vala"
		_tmp287_ = _tmp286_;
#line 675 "TDocumentTest.vala"
		_tmp288_ = gee_collection_get_size ((GeeCollection*) _tmp287_);
#line 675 "TDocumentTest.vala"
		_tmp289_ = _tmp288_;
#line 675 "TDocumentTest.vala"
		_vala_assert (_tmp289_ == 1, "a2.children_nodes[1].children_nodes.size == 1");
#line 675 "TDocumentTest.vala"
		_g_object_unref0 (_tmp287_);
#line 675 "TDocumentTest.vala"
		_g_object_unref0 (_tmp284_);
#line 675 "TDocumentTest.vala"
		_g_object_unref0 (_tmp282_);
#line 676 "TDocumentTest.vala"
		_tmp290_ = gxml_node_get_children_nodes (a2);
#line 676 "TDocumentTest.vala"
		_tmp291_ = _tmp290_;
#line 676 "TDocumentTest.vala"
		_tmp292_ = _tmp291_;
#line 676 "TDocumentTest.vala"
		_tmp293_ = gee_list_get ((GeeList*) _tmp292_, 1);
#line 676 "TDocumentTest.vala"
		_tmp294_ = (GXmlNode*) _tmp293_;
#line 676 "TDocumentTest.vala"
		_tmp295_ = gxml_node_get_children_nodes (_tmp294_);
#line 676 "TDocumentTest.vala"
		_tmp296_ = _tmp295_;
#line 676 "TDocumentTest.vala"
		_tmp297_ = _tmp296_;
#line 676 "TDocumentTest.vala"
		_tmp298_ = gee_list_get ((GeeList*) _tmp297_, 0);
#line 676 "TDocumentTest.vala"
		_tmp299_ = (GXmlNode*) _tmp298_;
#line 676 "TDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp299_, GXML_TYPE_TEXT), "a2.children_nodes[1].children_nodes[0] is GXml.Text");
#line 676 "TDocumentTest.vala"
		_g_object_unref0 (_tmp299_);
#line 676 "TDocumentTest.vala"
		_g_object_unref0 (_tmp297_);
#line 676 "TDocumentTest.vala"
		_g_object_unref0 (_tmp294_);
#line 676 "TDocumentTest.vala"
		_g_object_unref0 (_tmp292_);
#line 677 "TDocumentTest.vala"
		_tmp300_ = gxml_node_get_children_nodes (a2);
#line 677 "TDocumentTest.vala"
		_tmp301_ = _tmp300_;
#line 677 "TDocumentTest.vala"
		_tmp302_ = _tmp301_;
#line 677 "TDocumentTest.vala"
		_tmp303_ = gee_list_get ((GeeList*) _tmp302_, 1);
#line 677 "TDocumentTest.vala"
		_tmp304_ = (GXmlNode*) _tmp303_;
#line 677 "TDocumentTest.vala"
		_tmp305_ = gxml_node_get_children_nodes (_tmp304_);
#line 677 "TDocumentTest.vala"
		_tmp306_ = _tmp305_;
#line 677 "TDocumentTest.vala"
		_tmp307_ = _tmp306_;
#line 677 "TDocumentTest.vala"
		_tmp308_ = gee_list_get ((GeeList*) _tmp307_, 0);
#line 677 "TDocumentTest.vala"
		_tmp309_ = (GXmlNode*) _tmp308_;
#line 677 "TDocumentTest.vala"
		_tmp310_ = gxml_node_get_value (_tmp309_);
#line 677 "TDocumentTest.vala"
		_tmp311_ = _tmp310_;
#line 677 "TDocumentTest.vala"
		_tmp312_ = _tmp311_;
#line 677 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp312_, "George") == 0, "a2.children_nodes[1].children_nodes[0].value == \"George\"");
#line 677 "TDocumentTest.vala"
		_g_free0 (_tmp312_);
#line 677 "TDocumentTest.vala"
		_g_object_unref0 (_tmp309_);
#line 677 "TDocumentTest.vala"
		_g_object_unref0 (_tmp307_);
#line 677 "TDocumentTest.vala"
		_g_object_unref0 (_tmp304_);
#line 677 "TDocumentTest.vala"
		_g_object_unref0 (_tmp302_);
#line 678 "TDocumentTest.vala"
		_tmp313_ = gxml_node_get_children_nodes (a2);
#line 678 "TDocumentTest.vala"
		_tmp314_ = _tmp313_;
#line 678 "TDocumentTest.vala"
		_tmp315_ = _tmp314_;
#line 678 "TDocumentTest.vala"
		_tmp316_ = gee_list_get ((GeeList*) _tmp315_, 2);
#line 678 "TDocumentTest.vala"
		_tmp317_ = (GXmlNode*) _tmp316_;
#line 678 "TDocumentTest.vala"
		_tmp318_ = gxml_node_get_name (_tmp317_);
#line 678 "TDocumentTest.vala"
		_tmp319_ = _tmp318_;
#line 678 "TDocumentTest.vala"
		_tmp320_ = _tmp319_;
#line 678 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp320_, "Email") == 0, "a2.children_nodes[2].name == \"Email\"");
#line 678 "TDocumentTest.vala"
		_g_free0 (_tmp320_);
#line 678 "TDocumentTest.vala"
		_g_object_unref0 (_tmp317_);
#line 678 "TDocumentTest.vala"
		_g_object_unref0 (_tmp315_);
#line 679 "TDocumentTest.vala"
		_tmp321_ = gxml_node_get_children_nodes (a2);
#line 679 "TDocumentTest.vala"
		_tmp322_ = _tmp321_;
#line 679 "TDocumentTest.vala"
		_tmp323_ = _tmp322_;
#line 679 "TDocumentTest.vala"
		_tmp324_ = gee_list_get ((GeeList*) _tmp323_, 2);
#line 679 "TDocumentTest.vala"
		_tmp325_ = (GXmlNode*) _tmp324_;
#line 679 "TDocumentTest.vala"
		_tmp326_ = gxml_node_get_children_nodes (_tmp325_);
#line 679 "TDocumentTest.vala"
		_tmp327_ = _tmp326_;
#line 679 "TDocumentTest.vala"
		_tmp328_ = _tmp327_;
#line 679 "TDocumentTest.vala"
		_tmp329_ = gee_collection_get_size ((GeeCollection*) _tmp328_);
#line 679 "TDocumentTest.vala"
		_tmp330_ = _tmp329_;
#line 679 "TDocumentTest.vala"
		_vala_assert (_tmp330_ == 1, "a2.children_nodes[2].children_nodes.size == 1");
#line 679 "TDocumentTest.vala"
		_g_object_unref0 (_tmp328_);
#line 679 "TDocumentTest.vala"
		_g_object_unref0 (_tmp325_);
#line 679 "TDocumentTest.vala"
		_g_object_unref0 (_tmp323_);
#line 680 "TDocumentTest.vala"
		_tmp331_ = gxml_node_get_children_nodes (a2);
#line 680 "TDocumentTest.vala"
		_tmp332_ = _tmp331_;
#line 680 "TDocumentTest.vala"
		_tmp333_ = _tmp332_;
#line 680 "TDocumentTest.vala"
		_tmp334_ = gee_list_get ((GeeList*) _tmp333_, 2);
#line 680 "TDocumentTest.vala"
		_tmp335_ = (GXmlNode*) _tmp334_;
#line 680 "TDocumentTest.vala"
		_tmp336_ = gxml_node_get_children_nodes (_tmp335_);
#line 680 "TDocumentTest.vala"
		_tmp337_ = _tmp336_;
#line 680 "TDocumentTest.vala"
		_tmp338_ = _tmp337_;
#line 680 "TDocumentTest.vala"
		_tmp339_ = gee_list_get ((GeeList*) _tmp338_, 0);
#line 680 "TDocumentTest.vala"
		_tmp340_ = (GXmlNode*) _tmp339_;
#line 680 "TDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp340_, GXML_TYPE_TEXT), "a2.children_nodes[2].children_nodes[0] is GXml.Text");
#line 680 "TDocumentTest.vala"
		_g_object_unref0 (_tmp340_);
#line 680 "TDocumentTest.vala"
		_g_object_unref0 (_tmp338_);
#line 680 "TDocumentTest.vala"
		_g_object_unref0 (_tmp335_);
#line 680 "TDocumentTest.vala"
		_g_object_unref0 (_tmp333_);
#line 681 "TDocumentTest.vala"
		_tmp341_ = gxml_node_get_children_nodes (a2);
#line 681 "TDocumentTest.vala"
		_tmp342_ = _tmp341_;
#line 681 "TDocumentTest.vala"
		_tmp343_ = _tmp342_;
#line 681 "TDocumentTest.vala"
		_tmp344_ = gee_list_get ((GeeList*) _tmp343_, 2);
#line 681 "TDocumentTest.vala"
		_tmp345_ = (GXmlNode*) _tmp344_;
#line 681 "TDocumentTest.vala"
		_tmp346_ = gxml_node_get_children_nodes (_tmp345_);
#line 681 "TDocumentTest.vala"
		_tmp347_ = _tmp346_;
#line 681 "TDocumentTest.vala"
		_tmp348_ = _tmp347_;
#line 681 "TDocumentTest.vala"
		_tmp349_ = gee_list_get ((GeeList*) _tmp348_, 0);
#line 681 "TDocumentTest.vala"
		_tmp350_ = (GXmlNode*) _tmp349_;
#line 681 "TDocumentTest.vala"
		_tmp351_ = gxml_node_get_value (_tmp350_);
#line 681 "TDocumentTest.vala"
		_tmp352_ = _tmp351_;
#line 681 "TDocumentTest.vala"
		_tmp353_ = _tmp352_;
#line 681 "TDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp353_, "gweasley@hogwarts.co.uk") == 0, "a2.children_nodes[2].children_nodes[0].value == \"gweasley@hogwarts.co.uk\"");
#line 681 "TDocumentTest.vala"
		_g_free0 (_tmp353_);
#line 681 "TDocumentTest.vala"
		_g_object_unref0 (_tmp350_);
#line 681 "TDocumentTest.vala"
		_g_object_unref0 (_tmp348_);
#line 681 "TDocumentTest.vala"
		_g_object_unref0 (_tmp345_);
#line 681 "TDocumentTest.vala"
		_g_object_unref0 (_tmp343_);
#line 618 "TDocumentTest.vala"
		_g_object_unref0 (a2);
#line 618 "TDocumentTest.vala"
		_g_object_unref0 (a1);
#line 618 "TDocumentTest.vala"
		_g_object_unref0 (p31);
#line 618 "TDocumentTest.vala"
		_g_object_unref0 (p3);
#line 618 "TDocumentTest.vala"
		_g_object_unref0 (s3);
#line 618 "TDocumentTest.vala"
		_g_object_unref0 (p2);
#line 618 "TDocumentTest.vala"
		_g_object_unref0 (s2);
#line 618 "TDocumentTest.vala"
		_g_object_unref0 (p1);
#line 618 "TDocumentTest.vala"
		_g_object_unref0 (s1);
#line 618 "TDocumentTest.vala"
		_g_object_unref0 (d);
#line 618 "TDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 618 "TDocumentTest.vala"
		_g_object_unref0 (f);
#line 9666 "TDocumentTest.c"
	}
	goto __finally279;
	__catch279_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp354_;
		gchar* _tmp355_;
		gchar* _tmp356_;
#line 618 "TDocumentTest.vala"
		e = _inner_error0_;
#line 618 "TDocumentTest.vala"
		_inner_error0_ = NULL;
#line 682 "TDocumentTest.vala"
		_tmp354_ = e->message;
#line 682 "TDocumentTest.vala"
		_tmp355_ = g_strconcat ("ERROR: ", _tmp354_, NULL);
#line 682 "TDocumentTest.vala"
		_tmp356_ = _tmp355_;
#line 682 "TDocumentTest.vala"
		g_message ("TDocumentTest.vala:682: %s", _tmp356_);
#line 682 "TDocumentTest.vala"
		_g_free0 (_tmp356_);
#line 682 "TDocumentTest.vala"
		g_assert_not_reached ();
#line 618 "TDocumentTest.vala"
		_g_error_free0 (e);
#line 9693 "TDocumentTest.c"
	}
	__finally279:
#line 618 "TDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 618 "TDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 618 "TDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 618 "TDocumentTest.vala"
		return;
#line 9704 "TDocumentTest.c"
	}
}

static void
___lambda225__gtest_func (void)
{
#line 617 "TDocumentTest.vala"
	__lambda225_ ();
#line 9713 "TDocumentTest.c"
}

static void
__lambda226_ (void)
{
	GFile* f = NULL;
	GFile* _tmp0_;
	GXmlTDocument* d = NULL;
	GXmlTDocument* _tmp1_;
	GXmlNode* _tmp2_;
	GXmlNode* _tmp3_;
	GXmlNode* _tmp4_;
	GXmlNode* _tmp5_;
	GXmlNode* _tmp6_;
	GXmlNode* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	GXmlNode* _tmp11_;
	GXmlNode* _tmp12_;
	GXmlNode* _tmp13_;
	GeeBidirList* _tmp14_;
	GeeBidirList* _tmp15_;
	GeeBidirList* _tmp16_;
	gpointer _tmp17_;
	GXmlNode* _tmp18_;
	GXmlNode* _tmp19_;
	GXmlNode* _tmp20_;
	GXmlNode* _tmp21_;
	GeeBidirList* _tmp22_;
	GeeBidirList* _tmp23_;
	GeeBidirList* _tmp24_;
	gpointer _tmp25_;
	GXmlNode* _tmp26_;
	gchar* _tmp27_;
	gchar* _tmp28_;
	gchar* _tmp29_;
	GXmlNode* _tmp30_;
	GXmlNode* _tmp31_;
	GXmlNode* _tmp32_;
	GeeBidirList* _tmp33_;
	GeeBidirList* _tmp34_;
	GeeBidirList* _tmp35_;
	gpointer _tmp36_;
	GXmlNode* _tmp37_;
	GeeBidirList* _tmp38_;
	GeeBidirList* _tmp39_;
	GeeBidirList* _tmp40_;
	gpointer _tmp41_;
	GXmlNode* _tmp42_;
	GXmlNode* _tmp43_;
	GXmlNode* _tmp44_;
	GXmlNode* _tmp45_;
	GeeBidirList* _tmp46_;
	GeeBidirList* _tmp47_;
	GeeBidirList* _tmp48_;
	gpointer _tmp49_;
	GXmlNode* _tmp50_;
	GeeBidirList* _tmp51_;
	GeeBidirList* _tmp52_;
	GeeBidirList* _tmp53_;
	gpointer _tmp54_;
	GXmlNode* _tmp55_;
	gchar* _tmp56_;
	gchar* _tmp57_;
	gchar* _tmp58_;
	GXmlNode* _tmp59_;
	GXmlNode* _tmp60_;
	GXmlNode* _tmp61_;
	GeeBidirList* _tmp62_;
	GeeBidirList* _tmp63_;
	GeeBidirList* _tmp64_;
	gpointer _tmp65_;
	GXmlNode* _tmp66_;
	GXmlNode* _tmp67_;
	GXmlNode* _tmp68_;
	GXmlNode* _tmp69_;
	GeeBidirList* _tmp70_;
	GeeBidirList* _tmp71_;
	GeeBidirList* _tmp72_;
	gpointer _tmp73_;
	GXmlNode* _tmp74_;
	gchar* _tmp75_;
	gchar* _tmp76_;
	gchar* _tmp77_;
	GXmlNode* _tmp78_;
	GXmlNode* _tmp79_;
	GXmlNode* _tmp80_;
	GeeBidirList* _tmp81_;
	GeeBidirList* _tmp82_;
	GeeBidirList* _tmp83_;
	gpointer _tmp84_;
	GXmlNode* _tmp85_;
	GeeMap* _tmp86_;
	GeeMap* _tmp87_;
	GeeMap* _tmp88_;
	gpointer _tmp89_;
	GXmlNode* _tmp90_;
	gchar* _tmp91_;
	gchar* _tmp92_;
	gchar* _tmp93_;
	GXmlNode* _tmp94_;
	GXmlNode* _tmp95_;
	GXmlNode* _tmp96_;
	GeeBidirList* _tmp97_;
	GeeBidirList* _tmp98_;
	GeeBidirList* _tmp99_;
	gpointer _tmp100_;
	GXmlNode* _tmp101_;
	GeeBidirList* _tmp102_;
	GeeBidirList* _tmp103_;
	GeeBidirList* _tmp104_;
	gpointer _tmp105_;
	GXmlNode* _tmp106_;
	GXmlNode* _tmp107_;
	GXmlNode* _tmp108_;
	GXmlNode* _tmp109_;
	GeeBidirList* _tmp110_;
	GeeBidirList* _tmp111_;
	GeeBidirList* _tmp112_;
	gpointer _tmp113_;
	GXmlNode* _tmp114_;
	GeeBidirList* _tmp115_;
	GeeBidirList* _tmp116_;
	GeeBidirList* _tmp117_;
	gpointer _tmp118_;
	GXmlNode* _tmp119_;
	gchar* _tmp120_;
	gchar* _tmp121_;
	gchar* _tmp122_;
	GXmlNode* _tmp123_;
	GXmlNode* _tmp124_;
	GXmlNode* _tmp125_;
	GeeBidirList* _tmp126_;
	GeeBidirList* _tmp127_;
	GeeBidirList* _tmp128_;
	gpointer _tmp129_;
	GXmlNode* _tmp130_;
	GeeBidirList* _tmp131_;
	GeeBidirList* _tmp132_;
	GeeBidirList* _tmp133_;
	gpointer _tmp134_;
	GXmlNode* _tmp135_;
	GeeBidirList* _tmp136_;
	GeeBidirList* _tmp137_;
	GeeBidirList* _tmp138_;
	gpointer _tmp139_;
	GXmlNode* _tmp140_;
	GXmlNode* _tmp141_;
	GXmlNode* _tmp142_;
	GXmlNode* _tmp143_;
	GeeBidirList* _tmp144_;
	GeeBidirList* _tmp145_;
	GeeBidirList* _tmp146_;
	gpointer _tmp147_;
	GXmlNode* _tmp148_;
	GeeBidirList* _tmp149_;
	GeeBidirList* _tmp150_;
	GeeBidirList* _tmp151_;
	gpointer _tmp152_;
	GXmlNode* _tmp153_;
	GeeBidirList* _tmp154_;
	GeeBidirList* _tmp155_;
	GeeBidirList* _tmp156_;
	gpointer _tmp157_;
	GXmlNode* _tmp158_;
	gchar* _tmp159_;
	gchar* _tmp160_;
	gchar* _tmp161_;
#line 685 "TDocumentTest.vala"
	_tmp0_ = g_file_new_for_path (TEST_DIR "/t-read-test.xml");
#line 685 "TDocumentTest.vala"
	f = _tmp0_;
#line 686 "TDocumentTest.vala"
	_vala_assert (g_file_query_exists (f, NULL), "f.query_exists ()");
#line 687 "TDocumentTest.vala"
	_tmp1_ = gxml_tdocument_new_from_string ("<root><child v=\"1\">TEXT</child><doc year=\"2016\"><name>COMMUNICATIO" \
"NS</name></doc></root>");
#line 687 "TDocumentTest.vala"
	d = _tmp1_;
#line 688 "TDocumentTest.vala"
	_tmp2_ = gxml_document_get_root ((GXmlDocument*) d);
#line 688 "TDocumentTest.vala"
	_tmp3_ = _tmp2_;
#line 688 "TDocumentTest.vala"
	_tmp4_ = _tmp3_;
#line 688 "TDocumentTest.vala"
	_vala_assert (_tmp4_ != NULL, "d.root != null");
#line 688 "TDocumentTest.vala"
	_g_object_unref0 (_tmp4_);
#line 689 "TDocumentTest.vala"
	_tmp5_ = gxml_document_get_root ((GXmlDocument*) d);
#line 689 "TDocumentTest.vala"
	_tmp6_ = _tmp5_;
#line 689 "TDocumentTest.vala"
	_tmp7_ = _tmp6_;
#line 689 "TDocumentTest.vala"
	_tmp8_ = gxml_node_get_name (_tmp7_);
#line 689 "TDocumentTest.vala"
	_tmp9_ = _tmp8_;
#line 689 "TDocumentTest.vala"
	_tmp10_ = _tmp9_;
#line 689 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp10_, "root") == 0, "d.root.name == \"root\"");
#line 689 "TDocumentTest.vala"
	_g_free0 (_tmp10_);
#line 689 "TDocumentTest.vala"
	_g_object_unref0 (_tmp7_);
#line 690 "TDocumentTest.vala"
	_tmp11_ = gxml_document_get_root ((GXmlDocument*) d);
#line 690 "TDocumentTest.vala"
	_tmp12_ = _tmp11_;
#line 690 "TDocumentTest.vala"
	_tmp13_ = _tmp12_;
#line 690 "TDocumentTest.vala"
	_tmp14_ = gxml_node_get_children_nodes (_tmp13_);
#line 690 "TDocumentTest.vala"
	_tmp15_ = _tmp14_;
#line 690 "TDocumentTest.vala"
	_tmp16_ = _tmp15_;
#line 690 "TDocumentTest.vala"
	_tmp17_ = gee_list_get ((GeeList*) _tmp16_, 0);
#line 690 "TDocumentTest.vala"
	_tmp18_ = (GXmlNode*) _tmp17_;
#line 690 "TDocumentTest.vala"
	_vala_assert (_tmp18_ != NULL, "d.root.children_nodes[0] != null");
#line 690 "TDocumentTest.vala"
	_g_object_unref0 (_tmp18_);
#line 690 "TDocumentTest.vala"
	_g_object_unref0 (_tmp16_);
#line 690 "TDocumentTest.vala"
	_g_object_unref0 (_tmp13_);
#line 691 "TDocumentTest.vala"
	_tmp19_ = gxml_document_get_root ((GXmlDocument*) d);
#line 691 "TDocumentTest.vala"
	_tmp20_ = _tmp19_;
#line 691 "TDocumentTest.vala"
	_tmp21_ = _tmp20_;
#line 691 "TDocumentTest.vala"
	_tmp22_ = gxml_node_get_children_nodes (_tmp21_);
#line 691 "TDocumentTest.vala"
	_tmp23_ = _tmp22_;
#line 691 "TDocumentTest.vala"
	_tmp24_ = _tmp23_;
#line 691 "TDocumentTest.vala"
	_tmp25_ = gee_list_get ((GeeList*) _tmp24_, 0);
#line 691 "TDocumentTest.vala"
	_tmp26_ = (GXmlNode*) _tmp25_;
#line 691 "TDocumentTest.vala"
	_tmp27_ = gxml_node_get_name (_tmp26_);
#line 691 "TDocumentTest.vala"
	_tmp28_ = _tmp27_;
#line 691 "TDocumentTest.vala"
	_tmp29_ = _tmp28_;
#line 691 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp29_, "child") == 0, "d.root.children_nodes[0].name == \"child\"");
#line 691 "TDocumentTest.vala"
	_g_free0 (_tmp29_);
#line 691 "TDocumentTest.vala"
	_g_object_unref0 (_tmp26_);
#line 691 "TDocumentTest.vala"
	_g_object_unref0 (_tmp24_);
#line 691 "TDocumentTest.vala"
	_g_object_unref0 (_tmp21_);
#line 692 "TDocumentTest.vala"
	_tmp30_ = gxml_document_get_root ((GXmlDocument*) d);
#line 692 "TDocumentTest.vala"
	_tmp31_ = _tmp30_;
#line 692 "TDocumentTest.vala"
	_tmp32_ = _tmp31_;
#line 692 "TDocumentTest.vala"
	_tmp33_ = gxml_node_get_children_nodes (_tmp32_);
#line 692 "TDocumentTest.vala"
	_tmp34_ = _tmp33_;
#line 692 "TDocumentTest.vala"
	_tmp35_ = _tmp34_;
#line 692 "TDocumentTest.vala"
	_tmp36_ = gee_list_get ((GeeList*) _tmp35_, 0);
#line 692 "TDocumentTest.vala"
	_tmp37_ = (GXmlNode*) _tmp36_;
#line 692 "TDocumentTest.vala"
	_tmp38_ = gxml_node_get_children_nodes (_tmp37_);
#line 692 "TDocumentTest.vala"
	_tmp39_ = _tmp38_;
#line 692 "TDocumentTest.vala"
	_tmp40_ = _tmp39_;
#line 692 "TDocumentTest.vala"
	_tmp41_ = gee_list_get ((GeeList*) _tmp40_, 0);
#line 692 "TDocumentTest.vala"
	_tmp42_ = (GXmlNode*) _tmp41_;
#line 692 "TDocumentTest.vala"
	_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp42_, GXML_TYPE_TEXT), "d.root.children_nodes[0].children_nodes[0] is GXml.Text");
#line 692 "TDocumentTest.vala"
	_g_object_unref0 (_tmp42_);
#line 692 "TDocumentTest.vala"
	_g_object_unref0 (_tmp40_);
#line 692 "TDocumentTest.vala"
	_g_object_unref0 (_tmp37_);
#line 692 "TDocumentTest.vala"
	_g_object_unref0 (_tmp35_);
#line 692 "TDocumentTest.vala"
	_g_object_unref0 (_tmp32_);
#line 693 "TDocumentTest.vala"
	_tmp43_ = gxml_document_get_root ((GXmlDocument*) d);
#line 693 "TDocumentTest.vala"
	_tmp44_ = _tmp43_;
#line 693 "TDocumentTest.vala"
	_tmp45_ = _tmp44_;
#line 693 "TDocumentTest.vala"
	_tmp46_ = gxml_node_get_children_nodes (_tmp45_);
#line 693 "TDocumentTest.vala"
	_tmp47_ = _tmp46_;
#line 693 "TDocumentTest.vala"
	_tmp48_ = _tmp47_;
#line 693 "TDocumentTest.vala"
	_tmp49_ = gee_list_get ((GeeList*) _tmp48_, 0);
#line 693 "TDocumentTest.vala"
	_tmp50_ = (GXmlNode*) _tmp49_;
#line 693 "TDocumentTest.vala"
	_tmp51_ = gxml_node_get_children_nodes (_tmp50_);
#line 693 "TDocumentTest.vala"
	_tmp52_ = _tmp51_;
#line 693 "TDocumentTest.vala"
	_tmp53_ = _tmp52_;
#line 693 "TDocumentTest.vala"
	_tmp54_ = gee_list_get ((GeeList*) _tmp53_, 0);
#line 693 "TDocumentTest.vala"
	_tmp55_ = (GXmlNode*) _tmp54_;
#line 693 "TDocumentTest.vala"
	_tmp56_ = gxml_node_get_value (_tmp55_);
#line 693 "TDocumentTest.vala"
	_tmp57_ = _tmp56_;
#line 693 "TDocumentTest.vala"
	_tmp58_ = _tmp57_;
#line 693 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp58_, "TEXT") == 0, "d.root.children_nodes[0].children_nodes[0].value == \"TEXT\"");
#line 693 "TDocumentTest.vala"
	_g_free0 (_tmp58_);
#line 693 "TDocumentTest.vala"
	_g_object_unref0 (_tmp55_);
#line 693 "TDocumentTest.vala"
	_g_object_unref0 (_tmp53_);
#line 693 "TDocumentTest.vala"
	_g_object_unref0 (_tmp50_);
#line 693 "TDocumentTest.vala"
	_g_object_unref0 (_tmp48_);
#line 693 "TDocumentTest.vala"
	_g_object_unref0 (_tmp45_);
#line 694 "TDocumentTest.vala"
	_tmp59_ = gxml_document_get_root ((GXmlDocument*) d);
#line 694 "TDocumentTest.vala"
	_tmp60_ = _tmp59_;
#line 694 "TDocumentTest.vala"
	_tmp61_ = _tmp60_;
#line 694 "TDocumentTest.vala"
	_tmp62_ = gxml_node_get_children_nodes (_tmp61_);
#line 694 "TDocumentTest.vala"
	_tmp63_ = _tmp62_;
#line 694 "TDocumentTest.vala"
	_tmp64_ = _tmp63_;
#line 694 "TDocumentTest.vala"
	_tmp65_ = gee_list_get ((GeeList*) _tmp64_, 1);
#line 694 "TDocumentTest.vala"
	_tmp66_ = (GXmlNode*) _tmp65_;
#line 694 "TDocumentTest.vala"
	_vala_assert (_tmp66_ != NULL, "d.root.children_nodes[1] != null");
#line 694 "TDocumentTest.vala"
	_g_object_unref0 (_tmp66_);
#line 694 "TDocumentTest.vala"
	_g_object_unref0 (_tmp64_);
#line 694 "TDocumentTest.vala"
	_g_object_unref0 (_tmp61_);
#line 695 "TDocumentTest.vala"
	_tmp67_ = gxml_document_get_root ((GXmlDocument*) d);
#line 695 "TDocumentTest.vala"
	_tmp68_ = _tmp67_;
#line 695 "TDocumentTest.vala"
	_tmp69_ = _tmp68_;
#line 695 "TDocumentTest.vala"
	_tmp70_ = gxml_node_get_children_nodes (_tmp69_);
#line 695 "TDocumentTest.vala"
	_tmp71_ = _tmp70_;
#line 695 "TDocumentTest.vala"
	_tmp72_ = _tmp71_;
#line 695 "TDocumentTest.vala"
	_tmp73_ = gee_list_get ((GeeList*) _tmp72_, 1);
#line 695 "TDocumentTest.vala"
	_tmp74_ = (GXmlNode*) _tmp73_;
#line 695 "TDocumentTest.vala"
	_tmp75_ = gxml_node_get_name (_tmp74_);
#line 695 "TDocumentTest.vala"
	_tmp76_ = _tmp75_;
#line 695 "TDocumentTest.vala"
	_tmp77_ = _tmp76_;
#line 695 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp77_, "doc") == 0, "d.root.children_nodes[1].name == \"doc\"");
#line 695 "TDocumentTest.vala"
	_g_free0 (_tmp77_);
#line 695 "TDocumentTest.vala"
	_g_object_unref0 (_tmp74_);
#line 695 "TDocumentTest.vala"
	_g_object_unref0 (_tmp72_);
#line 695 "TDocumentTest.vala"
	_g_object_unref0 (_tmp69_);
#line 696 "TDocumentTest.vala"
	_tmp78_ = gxml_document_get_root ((GXmlDocument*) d);
#line 696 "TDocumentTest.vala"
	_tmp79_ = _tmp78_;
#line 696 "TDocumentTest.vala"
	_tmp80_ = _tmp79_;
#line 696 "TDocumentTest.vala"
	_tmp81_ = gxml_node_get_children_nodes (_tmp80_);
#line 696 "TDocumentTest.vala"
	_tmp82_ = _tmp81_;
#line 696 "TDocumentTest.vala"
	_tmp83_ = _tmp82_;
#line 696 "TDocumentTest.vala"
	_tmp84_ = gee_list_get ((GeeList*) _tmp83_, 1);
#line 696 "TDocumentTest.vala"
	_tmp85_ = (GXmlNode*) _tmp84_;
#line 696 "TDocumentTest.vala"
	_tmp86_ = gxml_node_get_attrs (_tmp85_);
#line 696 "TDocumentTest.vala"
	_tmp87_ = _tmp86_;
#line 696 "TDocumentTest.vala"
	_tmp88_ = _tmp87_;
#line 696 "TDocumentTest.vala"
	_tmp89_ = gee_map_get (_tmp88_, "year");
#line 696 "TDocumentTest.vala"
	_tmp90_ = (GXmlNode*) _tmp89_;
#line 696 "TDocumentTest.vala"
	_tmp91_ = gxml_node_get_value (_tmp90_);
#line 696 "TDocumentTest.vala"
	_tmp92_ = _tmp91_;
#line 696 "TDocumentTest.vala"
	_tmp93_ = _tmp92_;
#line 696 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp93_, "2016") == 0, "d.root.children_nodes[1].attrs[\"year\"].value == \"2016\"");
#line 696 "TDocumentTest.vala"
	_g_free0 (_tmp93_);
#line 696 "TDocumentTest.vala"
	_g_object_unref0 (_tmp90_);
#line 696 "TDocumentTest.vala"
	_g_object_unref0 (_tmp88_);
#line 696 "TDocumentTest.vala"
	_g_object_unref0 (_tmp85_);
#line 696 "TDocumentTest.vala"
	_g_object_unref0 (_tmp83_);
#line 696 "TDocumentTest.vala"
	_g_object_unref0 (_tmp80_);
#line 697 "TDocumentTest.vala"
	_tmp94_ = gxml_document_get_root ((GXmlDocument*) d);
#line 697 "TDocumentTest.vala"
	_tmp95_ = _tmp94_;
#line 697 "TDocumentTest.vala"
	_tmp96_ = _tmp95_;
#line 697 "TDocumentTest.vala"
	_tmp97_ = gxml_node_get_children_nodes (_tmp96_);
#line 697 "TDocumentTest.vala"
	_tmp98_ = _tmp97_;
#line 697 "TDocumentTest.vala"
	_tmp99_ = _tmp98_;
#line 697 "TDocumentTest.vala"
	_tmp100_ = gee_list_get ((GeeList*) _tmp99_, 1);
#line 697 "TDocumentTest.vala"
	_tmp101_ = (GXmlNode*) _tmp100_;
#line 697 "TDocumentTest.vala"
	_tmp102_ = gxml_node_get_children_nodes (_tmp101_);
#line 697 "TDocumentTest.vala"
	_tmp103_ = _tmp102_;
#line 697 "TDocumentTest.vala"
	_tmp104_ = _tmp103_;
#line 697 "TDocumentTest.vala"
	_tmp105_ = gee_list_get ((GeeList*) _tmp104_, 0);
#line 697 "TDocumentTest.vala"
	_tmp106_ = (GXmlNode*) _tmp105_;
#line 697 "TDocumentTest.vala"
	_vala_assert (_tmp106_ != NULL, "d.root.children_nodes[1].children_nodes[0] != null");
#line 697 "TDocumentTest.vala"
	_g_object_unref0 (_tmp106_);
#line 697 "TDocumentTest.vala"
	_g_object_unref0 (_tmp104_);
#line 697 "TDocumentTest.vala"
	_g_object_unref0 (_tmp101_);
#line 697 "TDocumentTest.vala"
	_g_object_unref0 (_tmp99_);
#line 697 "TDocumentTest.vala"
	_g_object_unref0 (_tmp96_);
#line 698 "TDocumentTest.vala"
	_tmp107_ = gxml_document_get_root ((GXmlDocument*) d);
#line 698 "TDocumentTest.vala"
	_tmp108_ = _tmp107_;
#line 698 "TDocumentTest.vala"
	_tmp109_ = _tmp108_;
#line 698 "TDocumentTest.vala"
	_tmp110_ = gxml_node_get_children_nodes (_tmp109_);
#line 698 "TDocumentTest.vala"
	_tmp111_ = _tmp110_;
#line 698 "TDocumentTest.vala"
	_tmp112_ = _tmp111_;
#line 698 "TDocumentTest.vala"
	_tmp113_ = gee_list_get ((GeeList*) _tmp112_, 1);
#line 698 "TDocumentTest.vala"
	_tmp114_ = (GXmlNode*) _tmp113_;
#line 698 "TDocumentTest.vala"
	_tmp115_ = gxml_node_get_children_nodes (_tmp114_);
#line 698 "TDocumentTest.vala"
	_tmp116_ = _tmp115_;
#line 698 "TDocumentTest.vala"
	_tmp117_ = _tmp116_;
#line 698 "TDocumentTest.vala"
	_tmp118_ = gee_list_get ((GeeList*) _tmp117_, 0);
#line 698 "TDocumentTest.vala"
	_tmp119_ = (GXmlNode*) _tmp118_;
#line 698 "TDocumentTest.vala"
	_tmp120_ = gxml_node_get_name (_tmp119_);
#line 698 "TDocumentTest.vala"
	_tmp121_ = _tmp120_;
#line 698 "TDocumentTest.vala"
	_tmp122_ = _tmp121_;
#line 698 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp122_, "name") == 0, "d.root.children_nodes[1].children_nodes[0].name == \"name\"");
#line 698 "TDocumentTest.vala"
	_g_free0 (_tmp122_);
#line 698 "TDocumentTest.vala"
	_g_object_unref0 (_tmp119_);
#line 698 "TDocumentTest.vala"
	_g_object_unref0 (_tmp117_);
#line 698 "TDocumentTest.vala"
	_g_object_unref0 (_tmp114_);
#line 698 "TDocumentTest.vala"
	_g_object_unref0 (_tmp112_);
#line 698 "TDocumentTest.vala"
	_g_object_unref0 (_tmp109_);
#line 699 "TDocumentTest.vala"
	_tmp123_ = gxml_document_get_root ((GXmlDocument*) d);
#line 699 "TDocumentTest.vala"
	_tmp124_ = _tmp123_;
#line 699 "TDocumentTest.vala"
	_tmp125_ = _tmp124_;
#line 699 "TDocumentTest.vala"
	_tmp126_ = gxml_node_get_children_nodes (_tmp125_);
#line 699 "TDocumentTest.vala"
	_tmp127_ = _tmp126_;
#line 699 "TDocumentTest.vala"
	_tmp128_ = _tmp127_;
#line 699 "TDocumentTest.vala"
	_tmp129_ = gee_list_get ((GeeList*) _tmp128_, 1);
#line 699 "TDocumentTest.vala"
	_tmp130_ = (GXmlNode*) _tmp129_;
#line 699 "TDocumentTest.vala"
	_tmp131_ = gxml_node_get_children_nodes (_tmp130_);
#line 699 "TDocumentTest.vala"
	_tmp132_ = _tmp131_;
#line 699 "TDocumentTest.vala"
	_tmp133_ = _tmp132_;
#line 699 "TDocumentTest.vala"
	_tmp134_ = gee_list_get ((GeeList*) _tmp133_, 0);
#line 699 "TDocumentTest.vala"
	_tmp135_ = (GXmlNode*) _tmp134_;
#line 699 "TDocumentTest.vala"
	_tmp136_ = gxml_node_get_children_nodes (_tmp135_);
#line 699 "TDocumentTest.vala"
	_tmp137_ = _tmp136_;
#line 699 "TDocumentTest.vala"
	_tmp138_ = _tmp137_;
#line 699 "TDocumentTest.vala"
	_tmp139_ = gee_list_get ((GeeList*) _tmp138_, 0);
#line 699 "TDocumentTest.vala"
	_tmp140_ = (GXmlNode*) _tmp139_;
#line 699 "TDocumentTest.vala"
	_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp140_, GXML_TYPE_TEXT), "d.root.children_nodes[1].children_nodes[0].children_nodes[0] is GXml.Text");
#line 699 "TDocumentTest.vala"
	_g_object_unref0 (_tmp140_);
#line 699 "TDocumentTest.vala"
	_g_object_unref0 (_tmp138_);
#line 699 "TDocumentTest.vala"
	_g_object_unref0 (_tmp135_);
#line 699 "TDocumentTest.vala"
	_g_object_unref0 (_tmp133_);
#line 699 "TDocumentTest.vala"
	_g_object_unref0 (_tmp130_);
#line 699 "TDocumentTest.vala"
	_g_object_unref0 (_tmp128_);
#line 699 "TDocumentTest.vala"
	_g_object_unref0 (_tmp125_);
#line 700 "TDocumentTest.vala"
	_tmp141_ = gxml_document_get_root ((GXmlDocument*) d);
#line 700 "TDocumentTest.vala"
	_tmp142_ = _tmp141_;
#line 700 "TDocumentTest.vala"
	_tmp143_ = _tmp142_;
#line 700 "TDocumentTest.vala"
	_tmp144_ = gxml_node_get_children_nodes (_tmp143_);
#line 700 "TDocumentTest.vala"
	_tmp145_ = _tmp144_;
#line 700 "TDocumentTest.vala"
	_tmp146_ = _tmp145_;
#line 700 "TDocumentTest.vala"
	_tmp147_ = gee_list_get ((GeeList*) _tmp146_, 1);
#line 700 "TDocumentTest.vala"
	_tmp148_ = (GXmlNode*) _tmp147_;
#line 700 "TDocumentTest.vala"
	_tmp149_ = gxml_node_get_children_nodes (_tmp148_);
#line 700 "TDocumentTest.vala"
	_tmp150_ = _tmp149_;
#line 700 "TDocumentTest.vala"
	_tmp151_ = _tmp150_;
#line 700 "TDocumentTest.vala"
	_tmp152_ = gee_list_get ((GeeList*) _tmp151_, 0);
#line 700 "TDocumentTest.vala"
	_tmp153_ = (GXmlNode*) _tmp152_;
#line 700 "TDocumentTest.vala"
	_tmp154_ = gxml_node_get_children_nodes (_tmp153_);
#line 700 "TDocumentTest.vala"
	_tmp155_ = _tmp154_;
#line 700 "TDocumentTest.vala"
	_tmp156_ = _tmp155_;
#line 700 "TDocumentTest.vala"
	_tmp157_ = gee_list_get ((GeeList*) _tmp156_, 0);
#line 700 "TDocumentTest.vala"
	_tmp158_ = (GXmlNode*) _tmp157_;
#line 700 "TDocumentTest.vala"
	_tmp159_ = gxml_node_get_value (_tmp158_);
#line 700 "TDocumentTest.vala"
	_tmp160_ = _tmp159_;
#line 700 "TDocumentTest.vala"
	_tmp161_ = _tmp160_;
#line 700 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp161_, "COMMUNICATIONS") == 0, "d.root.children_nodes[1].children_nodes[0].children_nodes[0].value == \"COMMUNICATIONS\"");
#line 700 "TDocumentTest.vala"
	_g_free0 (_tmp161_);
#line 700 "TDocumentTest.vala"
	_g_object_unref0 (_tmp158_);
#line 700 "TDocumentTest.vala"
	_g_object_unref0 (_tmp156_);
#line 700 "TDocumentTest.vala"
	_g_object_unref0 (_tmp153_);
#line 700 "TDocumentTest.vala"
	_g_object_unref0 (_tmp151_);
#line 700 "TDocumentTest.vala"
	_g_object_unref0 (_tmp148_);
#line 700 "TDocumentTest.vala"
	_g_object_unref0 (_tmp146_);
#line 700 "TDocumentTest.vala"
	_g_object_unref0 (_tmp143_);
#line 684 "TDocumentTest.vala"
	_g_object_unref0 (d);
#line 684 "TDocumentTest.vala"
	_g_object_unref0 (f);
#line 10363 "TDocumentTest.c"
}

static void
___lambda226__gtest_func (void)
{
#line 684 "TDocumentTest.vala"
	__lambda226_ ();
#line 10371 "TDocumentTest.c"
}

static void
__lambda227_ (void)
{
	GFile* f = NULL;
	GFile* _tmp0_;
	GXmlTDocument* d = NULL;
	GXmlTDocument* _tmp1_;
	GXmlNode* _tmp2_;
	GXmlNode* _tmp3_;
	GXmlNode* _tmp4_;
	GXmlNode* _tmp5_;
	GXmlNode* _tmp6_;
	GXmlNode* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	GXmlNode* _tmp11_;
	GXmlNode* _tmp12_;
	GXmlNode* _tmp13_;
	GeeBidirList* _tmp14_;
	GeeBidirList* _tmp15_;
	GeeBidirList* _tmp16_;
	gpointer _tmp17_;
	GXmlNode* _tmp18_;
	GXmlNode* _tmp19_;
	GXmlNode* _tmp20_;
	GXmlNode* _tmp21_;
	GeeBidirList* _tmp22_;
	GeeBidirList* _tmp23_;
	GeeBidirList* _tmp24_;
	gpointer _tmp25_;
	GXmlNode* _tmp26_;
	gchar* _tmp27_;
	gchar* _tmp28_;
	gchar* _tmp29_;
	GXmlNode* _tmp30_;
	GXmlNode* _tmp31_;
	GXmlNode* _tmp32_;
	GeeBidirList* _tmp33_;
	GeeBidirList* _tmp34_;
	GeeBidirList* _tmp35_;
	gpointer _tmp36_;
	GXmlNode* _tmp37_;
	GeeMap* _tmp38_;
	GeeMap* _tmp39_;
	GeeMap* _tmp40_;
	gint _tmp41_;
	gint _tmp42_;
	GXmlNode* _tmp43_;
	GXmlNode* _tmp44_;
	GXmlNode* _tmp45_;
	GeeBidirList* _tmp46_;
	GeeBidirList* _tmp47_;
	GeeBidirList* _tmp48_;
	gpointer _tmp49_;
	GXmlNode* _tmp50_;
	GeeMap* _tmp51_;
	GeeMap* _tmp52_;
	GeeMap* _tmp53_;
	gpointer _tmp54_;
	GXmlNode* _tmp55_;
	GXmlNode* _tmp56_;
	GXmlNode* _tmp57_;
	GXmlNode* _tmp58_;
	GeeBidirList* _tmp59_;
	GeeBidirList* _tmp60_;
	GeeBidirList* _tmp61_;
	gpointer _tmp62_;
	GXmlNode* _tmp63_;
	GeeBidirList* _tmp64_;
	GeeBidirList* _tmp65_;
	GeeBidirList* _tmp66_;
	gpointer _tmp67_;
	GXmlNode* _tmp68_;
	GXmlNode* _tmp69_;
	GXmlNode* _tmp70_;
	GXmlNode* _tmp71_;
	GeeBidirList* _tmp72_;
	GeeBidirList* _tmp73_;
	GeeBidirList* _tmp74_;
	gpointer _tmp75_;
	GXmlNode* _tmp76_;
	GeeBidirList* _tmp77_;
	GeeBidirList* _tmp78_;
	GeeBidirList* _tmp79_;
	gpointer _tmp80_;
	GXmlNode* _tmp81_;
	gchar* _tmp82_;
	gchar* _tmp83_;
	gchar* _tmp84_;
	GXmlNode* _tmp85_;
	GXmlNode* _tmp86_;
	GXmlNode* _tmp87_;
	GeeBidirList* _tmp88_;
	GeeBidirList* _tmp89_;
	GeeBidirList* _tmp90_;
	gpointer _tmp91_;
	GXmlNode* _tmp92_;
	GXmlNode* _tmp93_;
	GXmlNode* _tmp94_;
	GXmlNode* _tmp95_;
	GeeBidirList* _tmp96_;
	GeeBidirList* _tmp97_;
	GeeBidirList* _tmp98_;
	gpointer _tmp99_;
	GXmlNode* _tmp100_;
	gchar* _tmp101_;
	gchar* _tmp102_;
	gchar* _tmp103_;
	GXmlNode* _tmp104_;
	GXmlNode* _tmp105_;
	GXmlNode* _tmp106_;
	GeeBidirList* _tmp107_;
	GeeBidirList* _tmp108_;
	GeeBidirList* _tmp109_;
	gpointer _tmp110_;
	GXmlNode* _tmp111_;
	GeeMap* _tmp112_;
	GeeMap* _tmp113_;
	GeeMap* _tmp114_;
	gpointer _tmp115_;
	GXmlNode* _tmp116_;
	gchar* _tmp117_;
	gchar* _tmp118_;
	gchar* _tmp119_;
	GXmlNode* _tmp120_;
	GXmlNode* _tmp121_;
	GXmlNode* _tmp122_;
	GeeBidirList* _tmp123_;
	GeeBidirList* _tmp124_;
	GeeBidirList* _tmp125_;
	gpointer _tmp126_;
	GXmlNode* _tmp127_;
	GeeBidirList* _tmp128_;
	GeeBidirList* _tmp129_;
	GeeBidirList* _tmp130_;
	gpointer _tmp131_;
	GXmlNode* _tmp132_;
	GXmlNode* _tmp133_;
	GXmlNode* _tmp134_;
	GXmlNode* _tmp135_;
	GeeBidirList* _tmp136_;
	GeeBidirList* _tmp137_;
	GeeBidirList* _tmp138_;
	gpointer _tmp139_;
	GXmlNode* _tmp140_;
	GeeBidirList* _tmp141_;
	GeeBidirList* _tmp142_;
	GeeBidirList* _tmp143_;
	gpointer _tmp144_;
	GXmlNode* _tmp145_;
	gchar* _tmp146_;
	gchar* _tmp147_;
	gchar* _tmp148_;
	GXmlNode* _tmp149_;
	GXmlNode* _tmp150_;
	GXmlNode* _tmp151_;
	GeeBidirList* _tmp152_;
	GeeBidirList* _tmp153_;
	GeeBidirList* _tmp154_;
	gpointer _tmp155_;
	GXmlNode* _tmp156_;
	GeeBidirList* _tmp157_;
	GeeBidirList* _tmp158_;
	GeeBidirList* _tmp159_;
	gpointer _tmp160_;
	GXmlNode* _tmp161_;
	GeeBidirList* _tmp162_;
	GeeBidirList* _tmp163_;
	GeeBidirList* _tmp164_;
	gpointer _tmp165_;
	GXmlNode* _tmp166_;
	GXmlNode* _tmp167_;
	GXmlNode* _tmp168_;
	GXmlNode* _tmp169_;
	GeeBidirList* _tmp170_;
	GeeBidirList* _tmp171_;
	GeeBidirList* _tmp172_;
	gpointer _tmp173_;
	GXmlNode* _tmp174_;
	GeeBidirList* _tmp175_;
	GeeBidirList* _tmp176_;
	GeeBidirList* _tmp177_;
	gpointer _tmp178_;
	GXmlNode* _tmp179_;
	GeeBidirList* _tmp180_;
	GeeBidirList* _tmp181_;
	GeeBidirList* _tmp182_;
	gpointer _tmp183_;
	GXmlNode* _tmp184_;
	gchar* _tmp185_;
	gchar* _tmp186_;
	gchar* _tmp187_;
#line 703 "TDocumentTest.vala"
	_tmp0_ = g_file_new_for_path (TEST_DIR "/t-read-test.xml");
#line 703 "TDocumentTest.vala"
	f = _tmp0_;
#line 704 "TDocumentTest.vala"
	_vala_assert (g_file_query_exists (f, NULL), "f.query_exists ()");
#line 705 "TDocumentTest.vala"
	_tmp1_ = gxml_tdocument_new_from_string ("<root xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"><child v" \
"=\"1\" xsi:v=\"VType\">TEXT</child><doc year=\"2016\"><name>COMMUNICAT" \
"IONS</name></doc></root>");
#line 705 "TDocumentTest.vala"
	d = _tmp1_;
#line 706 "TDocumentTest.vala"
	_tmp2_ = gxml_document_get_root ((GXmlDocument*) d);
#line 706 "TDocumentTest.vala"
	_tmp3_ = _tmp2_;
#line 706 "TDocumentTest.vala"
	_tmp4_ = _tmp3_;
#line 706 "TDocumentTest.vala"
	_vala_assert (_tmp4_ != NULL, "d.root != null");
#line 706 "TDocumentTest.vala"
	_g_object_unref0 (_tmp4_);
#line 707 "TDocumentTest.vala"
	_tmp5_ = gxml_document_get_root ((GXmlDocument*) d);
#line 707 "TDocumentTest.vala"
	_tmp6_ = _tmp5_;
#line 707 "TDocumentTest.vala"
	_tmp7_ = _tmp6_;
#line 707 "TDocumentTest.vala"
	_tmp8_ = gxml_node_get_name (_tmp7_);
#line 707 "TDocumentTest.vala"
	_tmp9_ = _tmp8_;
#line 707 "TDocumentTest.vala"
	_tmp10_ = _tmp9_;
#line 707 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp10_, "root") == 0, "d.root.name == \"root\"");
#line 707 "TDocumentTest.vala"
	_g_free0 (_tmp10_);
#line 707 "TDocumentTest.vala"
	_g_object_unref0 (_tmp7_);
#line 708 "TDocumentTest.vala"
	_tmp11_ = gxml_document_get_root ((GXmlDocument*) d);
#line 708 "TDocumentTest.vala"
	_tmp12_ = _tmp11_;
#line 708 "TDocumentTest.vala"
	_tmp13_ = _tmp12_;
#line 708 "TDocumentTest.vala"
	_tmp14_ = gxml_node_get_children_nodes (_tmp13_);
#line 708 "TDocumentTest.vala"
	_tmp15_ = _tmp14_;
#line 708 "TDocumentTest.vala"
	_tmp16_ = _tmp15_;
#line 708 "TDocumentTest.vala"
	_tmp17_ = gee_list_get ((GeeList*) _tmp16_, 0);
#line 708 "TDocumentTest.vala"
	_tmp18_ = (GXmlNode*) _tmp17_;
#line 708 "TDocumentTest.vala"
	_vala_assert (_tmp18_ != NULL, "d.root.children_nodes[0] != null");
#line 708 "TDocumentTest.vala"
	_g_object_unref0 (_tmp18_);
#line 708 "TDocumentTest.vala"
	_g_object_unref0 (_tmp16_);
#line 708 "TDocumentTest.vala"
	_g_object_unref0 (_tmp13_);
#line 709 "TDocumentTest.vala"
	_tmp19_ = gxml_document_get_root ((GXmlDocument*) d);
#line 709 "TDocumentTest.vala"
	_tmp20_ = _tmp19_;
#line 709 "TDocumentTest.vala"
	_tmp21_ = _tmp20_;
#line 709 "TDocumentTest.vala"
	_tmp22_ = gxml_node_get_children_nodes (_tmp21_);
#line 709 "TDocumentTest.vala"
	_tmp23_ = _tmp22_;
#line 709 "TDocumentTest.vala"
	_tmp24_ = _tmp23_;
#line 709 "TDocumentTest.vala"
	_tmp25_ = gee_list_get ((GeeList*) _tmp24_, 0);
#line 709 "TDocumentTest.vala"
	_tmp26_ = (GXmlNode*) _tmp25_;
#line 709 "TDocumentTest.vala"
	_tmp27_ = gxml_node_get_name (_tmp26_);
#line 709 "TDocumentTest.vala"
	_tmp28_ = _tmp27_;
#line 709 "TDocumentTest.vala"
	_tmp29_ = _tmp28_;
#line 709 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp29_, "child") == 0, "d.root.children_nodes[0].name == \"child\"");
#line 709 "TDocumentTest.vala"
	_g_free0 (_tmp29_);
#line 709 "TDocumentTest.vala"
	_g_object_unref0 (_tmp26_);
#line 709 "TDocumentTest.vala"
	_g_object_unref0 (_tmp24_);
#line 709 "TDocumentTest.vala"
	_g_object_unref0 (_tmp21_);
#line 713 "TDocumentTest.vala"
	_tmp30_ = gxml_document_get_root ((GXmlDocument*) d);
#line 713 "TDocumentTest.vala"
	_tmp31_ = _tmp30_;
#line 713 "TDocumentTest.vala"
	_tmp32_ = _tmp31_;
#line 713 "TDocumentTest.vala"
	_tmp33_ = gxml_node_get_children_nodes (_tmp32_);
#line 713 "TDocumentTest.vala"
	_tmp34_ = _tmp33_;
#line 713 "TDocumentTest.vala"
	_tmp35_ = _tmp34_;
#line 713 "TDocumentTest.vala"
	_tmp36_ = gee_list_get ((GeeList*) _tmp35_, 0);
#line 713 "TDocumentTest.vala"
	_tmp37_ = (GXmlNode*) _tmp36_;
#line 713 "TDocumentTest.vala"
	_tmp38_ = gxml_node_get_attrs (_tmp37_);
#line 713 "TDocumentTest.vala"
	_tmp39_ = _tmp38_;
#line 713 "TDocumentTest.vala"
	_tmp40_ = _tmp39_;
#line 713 "TDocumentTest.vala"
	_tmp41_ = gee_map_get_size (_tmp40_);
#line 713 "TDocumentTest.vala"
	_tmp42_ = _tmp41_;
#line 713 "TDocumentTest.vala"
	_vala_assert (_tmp42_ == 2, "d.root.children_nodes[0].attrs.size == 2");
#line 713 "TDocumentTest.vala"
	_g_object_unref0 (_tmp40_);
#line 713 "TDocumentTest.vala"
	_g_object_unref0 (_tmp37_);
#line 713 "TDocumentTest.vala"
	_g_object_unref0 (_tmp35_);
#line 713 "TDocumentTest.vala"
	_g_object_unref0 (_tmp32_);
#line 714 "TDocumentTest.vala"
	_tmp43_ = gxml_document_get_root ((GXmlDocument*) d);
#line 714 "TDocumentTest.vala"
	_tmp44_ = _tmp43_;
#line 714 "TDocumentTest.vala"
	_tmp45_ = _tmp44_;
#line 714 "TDocumentTest.vala"
	_tmp46_ = gxml_node_get_children_nodes (_tmp45_);
#line 714 "TDocumentTest.vala"
	_tmp47_ = _tmp46_;
#line 714 "TDocumentTest.vala"
	_tmp48_ = _tmp47_;
#line 714 "TDocumentTest.vala"
	_tmp49_ = gee_list_get ((GeeList*) _tmp48_, 0);
#line 714 "TDocumentTest.vala"
	_tmp50_ = (GXmlNode*) _tmp49_;
#line 714 "TDocumentTest.vala"
	_tmp51_ = gxml_node_get_attrs (_tmp50_);
#line 714 "TDocumentTest.vala"
	_tmp52_ = _tmp51_;
#line 714 "TDocumentTest.vala"
	_tmp53_ = _tmp52_;
#line 714 "TDocumentTest.vala"
	_tmp54_ = gee_map_get (_tmp53_, "v");
#line 714 "TDocumentTest.vala"
	_tmp55_ = (GXmlNode*) _tmp54_;
#line 714 "TDocumentTest.vala"
	_vala_assert (_tmp55_ != NULL, "d.root.children_nodes[0].attrs[\"v\"] != null");
#line 714 "TDocumentTest.vala"
	_g_object_unref0 (_tmp55_);
#line 714 "TDocumentTest.vala"
	_g_object_unref0 (_tmp53_);
#line 714 "TDocumentTest.vala"
	_g_object_unref0 (_tmp50_);
#line 714 "TDocumentTest.vala"
	_g_object_unref0 (_tmp48_);
#line 714 "TDocumentTest.vala"
	_g_object_unref0 (_tmp45_);
#line 715 "TDocumentTest.vala"
	_tmp56_ = gxml_document_get_root ((GXmlDocument*) d);
#line 715 "TDocumentTest.vala"
	_tmp57_ = _tmp56_;
#line 715 "TDocumentTest.vala"
	_tmp58_ = _tmp57_;
#line 715 "TDocumentTest.vala"
	_tmp59_ = gxml_node_get_children_nodes (_tmp58_);
#line 715 "TDocumentTest.vala"
	_tmp60_ = _tmp59_;
#line 715 "TDocumentTest.vala"
	_tmp61_ = _tmp60_;
#line 715 "TDocumentTest.vala"
	_tmp62_ = gee_list_get ((GeeList*) _tmp61_, 0);
#line 715 "TDocumentTest.vala"
	_tmp63_ = (GXmlNode*) _tmp62_;
#line 715 "TDocumentTest.vala"
	_tmp64_ = gxml_node_get_children_nodes (_tmp63_);
#line 715 "TDocumentTest.vala"
	_tmp65_ = _tmp64_;
#line 715 "TDocumentTest.vala"
	_tmp66_ = _tmp65_;
#line 715 "TDocumentTest.vala"
	_tmp67_ = gee_list_get ((GeeList*) _tmp66_, 0);
#line 715 "TDocumentTest.vala"
	_tmp68_ = (GXmlNode*) _tmp67_;
#line 715 "TDocumentTest.vala"
	_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp68_, GXML_TYPE_TEXT), "d.root.children_nodes[0].children_nodes[0] is GXml.Text");
#line 715 "TDocumentTest.vala"
	_g_object_unref0 (_tmp68_);
#line 715 "TDocumentTest.vala"
	_g_object_unref0 (_tmp66_);
#line 715 "TDocumentTest.vala"
	_g_object_unref0 (_tmp63_);
#line 715 "TDocumentTest.vala"
	_g_object_unref0 (_tmp61_);
#line 715 "TDocumentTest.vala"
	_g_object_unref0 (_tmp58_);
#line 716 "TDocumentTest.vala"
	_tmp69_ = gxml_document_get_root ((GXmlDocument*) d);
#line 716 "TDocumentTest.vala"
	_tmp70_ = _tmp69_;
#line 716 "TDocumentTest.vala"
	_tmp71_ = _tmp70_;
#line 716 "TDocumentTest.vala"
	_tmp72_ = gxml_node_get_children_nodes (_tmp71_);
#line 716 "TDocumentTest.vala"
	_tmp73_ = _tmp72_;
#line 716 "TDocumentTest.vala"
	_tmp74_ = _tmp73_;
#line 716 "TDocumentTest.vala"
	_tmp75_ = gee_list_get ((GeeList*) _tmp74_, 0);
#line 716 "TDocumentTest.vala"
	_tmp76_ = (GXmlNode*) _tmp75_;
#line 716 "TDocumentTest.vala"
	_tmp77_ = gxml_node_get_children_nodes (_tmp76_);
#line 716 "TDocumentTest.vala"
	_tmp78_ = _tmp77_;
#line 716 "TDocumentTest.vala"
	_tmp79_ = _tmp78_;
#line 716 "TDocumentTest.vala"
	_tmp80_ = gee_list_get ((GeeList*) _tmp79_, 0);
#line 716 "TDocumentTest.vala"
	_tmp81_ = (GXmlNode*) _tmp80_;
#line 716 "TDocumentTest.vala"
	_tmp82_ = gxml_node_get_value (_tmp81_);
#line 716 "TDocumentTest.vala"
	_tmp83_ = _tmp82_;
#line 716 "TDocumentTest.vala"
	_tmp84_ = _tmp83_;
#line 716 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp84_, "TEXT") == 0, "d.root.children_nodes[0].children_nodes[0].value == \"TEXT\"");
#line 716 "TDocumentTest.vala"
	_g_free0 (_tmp84_);
#line 716 "TDocumentTest.vala"
	_g_object_unref0 (_tmp81_);
#line 716 "TDocumentTest.vala"
	_g_object_unref0 (_tmp79_);
#line 716 "TDocumentTest.vala"
	_g_object_unref0 (_tmp76_);
#line 716 "TDocumentTest.vala"
	_g_object_unref0 (_tmp74_);
#line 716 "TDocumentTest.vala"
	_g_object_unref0 (_tmp71_);
#line 717 "TDocumentTest.vala"
	_tmp85_ = gxml_document_get_root ((GXmlDocument*) d);
#line 717 "TDocumentTest.vala"
	_tmp86_ = _tmp85_;
#line 717 "TDocumentTest.vala"
	_tmp87_ = _tmp86_;
#line 717 "TDocumentTest.vala"
	_tmp88_ = gxml_node_get_children_nodes (_tmp87_);
#line 717 "TDocumentTest.vala"
	_tmp89_ = _tmp88_;
#line 717 "TDocumentTest.vala"
	_tmp90_ = _tmp89_;
#line 717 "TDocumentTest.vala"
	_tmp91_ = gee_list_get ((GeeList*) _tmp90_, 1);
#line 717 "TDocumentTest.vala"
	_tmp92_ = (GXmlNode*) _tmp91_;
#line 717 "TDocumentTest.vala"
	_vala_assert (_tmp92_ != NULL, "d.root.children_nodes[1] != null");
#line 717 "TDocumentTest.vala"
	_g_object_unref0 (_tmp92_);
#line 717 "TDocumentTest.vala"
	_g_object_unref0 (_tmp90_);
#line 717 "TDocumentTest.vala"
	_g_object_unref0 (_tmp87_);
#line 718 "TDocumentTest.vala"
	_tmp93_ = gxml_document_get_root ((GXmlDocument*) d);
#line 718 "TDocumentTest.vala"
	_tmp94_ = _tmp93_;
#line 718 "TDocumentTest.vala"
	_tmp95_ = _tmp94_;
#line 718 "TDocumentTest.vala"
	_tmp96_ = gxml_node_get_children_nodes (_tmp95_);
#line 718 "TDocumentTest.vala"
	_tmp97_ = _tmp96_;
#line 718 "TDocumentTest.vala"
	_tmp98_ = _tmp97_;
#line 718 "TDocumentTest.vala"
	_tmp99_ = gee_list_get ((GeeList*) _tmp98_, 1);
#line 718 "TDocumentTest.vala"
	_tmp100_ = (GXmlNode*) _tmp99_;
#line 718 "TDocumentTest.vala"
	_tmp101_ = gxml_node_get_name (_tmp100_);
#line 718 "TDocumentTest.vala"
	_tmp102_ = _tmp101_;
#line 718 "TDocumentTest.vala"
	_tmp103_ = _tmp102_;
#line 718 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp103_, "doc") == 0, "d.root.children_nodes[1].name == \"doc\"");
#line 718 "TDocumentTest.vala"
	_g_free0 (_tmp103_);
#line 718 "TDocumentTest.vala"
	_g_object_unref0 (_tmp100_);
#line 718 "TDocumentTest.vala"
	_g_object_unref0 (_tmp98_);
#line 718 "TDocumentTest.vala"
	_g_object_unref0 (_tmp95_);
#line 719 "TDocumentTest.vala"
	_tmp104_ = gxml_document_get_root ((GXmlDocument*) d);
#line 719 "TDocumentTest.vala"
	_tmp105_ = _tmp104_;
#line 719 "TDocumentTest.vala"
	_tmp106_ = _tmp105_;
#line 719 "TDocumentTest.vala"
	_tmp107_ = gxml_node_get_children_nodes (_tmp106_);
#line 719 "TDocumentTest.vala"
	_tmp108_ = _tmp107_;
#line 719 "TDocumentTest.vala"
	_tmp109_ = _tmp108_;
#line 719 "TDocumentTest.vala"
	_tmp110_ = gee_list_get ((GeeList*) _tmp109_, 1);
#line 719 "TDocumentTest.vala"
	_tmp111_ = (GXmlNode*) _tmp110_;
#line 719 "TDocumentTest.vala"
	_tmp112_ = gxml_node_get_attrs (_tmp111_);
#line 719 "TDocumentTest.vala"
	_tmp113_ = _tmp112_;
#line 719 "TDocumentTest.vala"
	_tmp114_ = _tmp113_;
#line 719 "TDocumentTest.vala"
	_tmp115_ = gee_map_get (_tmp114_, "year");
#line 719 "TDocumentTest.vala"
	_tmp116_ = (GXmlNode*) _tmp115_;
#line 719 "TDocumentTest.vala"
	_tmp117_ = gxml_node_get_value (_tmp116_);
#line 719 "TDocumentTest.vala"
	_tmp118_ = _tmp117_;
#line 719 "TDocumentTest.vala"
	_tmp119_ = _tmp118_;
#line 719 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp119_, "2016") == 0, "d.root.children_nodes[1].attrs[\"year\"].value == \"2016\"");
#line 719 "TDocumentTest.vala"
	_g_free0 (_tmp119_);
#line 719 "TDocumentTest.vala"
	_g_object_unref0 (_tmp116_);
#line 719 "TDocumentTest.vala"
	_g_object_unref0 (_tmp114_);
#line 719 "TDocumentTest.vala"
	_g_object_unref0 (_tmp111_);
#line 719 "TDocumentTest.vala"
	_g_object_unref0 (_tmp109_);
#line 719 "TDocumentTest.vala"
	_g_object_unref0 (_tmp106_);
#line 720 "TDocumentTest.vala"
	_tmp120_ = gxml_document_get_root ((GXmlDocument*) d);
#line 720 "TDocumentTest.vala"
	_tmp121_ = _tmp120_;
#line 720 "TDocumentTest.vala"
	_tmp122_ = _tmp121_;
#line 720 "TDocumentTest.vala"
	_tmp123_ = gxml_node_get_children_nodes (_tmp122_);
#line 720 "TDocumentTest.vala"
	_tmp124_ = _tmp123_;
#line 720 "TDocumentTest.vala"
	_tmp125_ = _tmp124_;
#line 720 "TDocumentTest.vala"
	_tmp126_ = gee_list_get ((GeeList*) _tmp125_, 1);
#line 720 "TDocumentTest.vala"
	_tmp127_ = (GXmlNode*) _tmp126_;
#line 720 "TDocumentTest.vala"
	_tmp128_ = gxml_node_get_children_nodes (_tmp127_);
#line 720 "TDocumentTest.vala"
	_tmp129_ = _tmp128_;
#line 720 "TDocumentTest.vala"
	_tmp130_ = _tmp129_;
#line 720 "TDocumentTest.vala"
	_tmp131_ = gee_list_get ((GeeList*) _tmp130_, 0);
#line 720 "TDocumentTest.vala"
	_tmp132_ = (GXmlNode*) _tmp131_;
#line 720 "TDocumentTest.vala"
	_vala_assert (_tmp132_ != NULL, "d.root.children_nodes[1].children_nodes[0] != null");
#line 720 "TDocumentTest.vala"
	_g_object_unref0 (_tmp132_);
#line 720 "TDocumentTest.vala"
	_g_object_unref0 (_tmp130_);
#line 720 "TDocumentTest.vala"
	_g_object_unref0 (_tmp127_);
#line 720 "TDocumentTest.vala"
	_g_object_unref0 (_tmp125_);
#line 720 "TDocumentTest.vala"
	_g_object_unref0 (_tmp122_);
#line 721 "TDocumentTest.vala"
	_tmp133_ = gxml_document_get_root ((GXmlDocument*) d);
#line 721 "TDocumentTest.vala"
	_tmp134_ = _tmp133_;
#line 721 "TDocumentTest.vala"
	_tmp135_ = _tmp134_;
#line 721 "TDocumentTest.vala"
	_tmp136_ = gxml_node_get_children_nodes (_tmp135_);
#line 721 "TDocumentTest.vala"
	_tmp137_ = _tmp136_;
#line 721 "TDocumentTest.vala"
	_tmp138_ = _tmp137_;
#line 721 "TDocumentTest.vala"
	_tmp139_ = gee_list_get ((GeeList*) _tmp138_, 1);
#line 721 "TDocumentTest.vala"
	_tmp140_ = (GXmlNode*) _tmp139_;
#line 721 "TDocumentTest.vala"
	_tmp141_ = gxml_node_get_children_nodes (_tmp140_);
#line 721 "TDocumentTest.vala"
	_tmp142_ = _tmp141_;
#line 721 "TDocumentTest.vala"
	_tmp143_ = _tmp142_;
#line 721 "TDocumentTest.vala"
	_tmp144_ = gee_list_get ((GeeList*) _tmp143_, 0);
#line 721 "TDocumentTest.vala"
	_tmp145_ = (GXmlNode*) _tmp144_;
#line 721 "TDocumentTest.vala"
	_tmp146_ = gxml_node_get_name (_tmp145_);
#line 721 "TDocumentTest.vala"
	_tmp147_ = _tmp146_;
#line 721 "TDocumentTest.vala"
	_tmp148_ = _tmp147_;
#line 721 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp148_, "name") == 0, "d.root.children_nodes[1].children_nodes[0].name == \"name\"");
#line 721 "TDocumentTest.vala"
	_g_free0 (_tmp148_);
#line 721 "TDocumentTest.vala"
	_g_object_unref0 (_tmp145_);
#line 721 "TDocumentTest.vala"
	_g_object_unref0 (_tmp143_);
#line 721 "TDocumentTest.vala"
	_g_object_unref0 (_tmp140_);
#line 721 "TDocumentTest.vala"
	_g_object_unref0 (_tmp138_);
#line 721 "TDocumentTest.vala"
	_g_object_unref0 (_tmp135_);
#line 722 "TDocumentTest.vala"
	_tmp149_ = gxml_document_get_root ((GXmlDocument*) d);
#line 722 "TDocumentTest.vala"
	_tmp150_ = _tmp149_;
#line 722 "TDocumentTest.vala"
	_tmp151_ = _tmp150_;
#line 722 "TDocumentTest.vala"
	_tmp152_ = gxml_node_get_children_nodes (_tmp151_);
#line 722 "TDocumentTest.vala"
	_tmp153_ = _tmp152_;
#line 722 "TDocumentTest.vala"
	_tmp154_ = _tmp153_;
#line 722 "TDocumentTest.vala"
	_tmp155_ = gee_list_get ((GeeList*) _tmp154_, 1);
#line 722 "TDocumentTest.vala"
	_tmp156_ = (GXmlNode*) _tmp155_;
#line 722 "TDocumentTest.vala"
	_tmp157_ = gxml_node_get_children_nodes (_tmp156_);
#line 722 "TDocumentTest.vala"
	_tmp158_ = _tmp157_;
#line 722 "TDocumentTest.vala"
	_tmp159_ = _tmp158_;
#line 722 "TDocumentTest.vala"
	_tmp160_ = gee_list_get ((GeeList*) _tmp159_, 0);
#line 722 "TDocumentTest.vala"
	_tmp161_ = (GXmlNode*) _tmp160_;
#line 722 "TDocumentTest.vala"
	_tmp162_ = gxml_node_get_children_nodes (_tmp161_);
#line 722 "TDocumentTest.vala"
	_tmp163_ = _tmp162_;
#line 722 "TDocumentTest.vala"
	_tmp164_ = _tmp163_;
#line 722 "TDocumentTest.vala"
	_tmp165_ = gee_list_get ((GeeList*) _tmp164_, 0);
#line 722 "TDocumentTest.vala"
	_tmp166_ = (GXmlNode*) _tmp165_;
#line 722 "TDocumentTest.vala"
	_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp166_, GXML_TYPE_TEXT), "d.root.children_nodes[1].children_nodes[0].children_nodes[0] is GXml.Text");
#line 722 "TDocumentTest.vala"
	_g_object_unref0 (_tmp166_);
#line 722 "TDocumentTest.vala"
	_g_object_unref0 (_tmp164_);
#line 722 "TDocumentTest.vala"
	_g_object_unref0 (_tmp161_);
#line 722 "TDocumentTest.vala"
	_g_object_unref0 (_tmp159_);
#line 722 "TDocumentTest.vala"
	_g_object_unref0 (_tmp156_);
#line 722 "TDocumentTest.vala"
	_g_object_unref0 (_tmp154_);
#line 722 "TDocumentTest.vala"
	_g_object_unref0 (_tmp151_);
#line 723 "TDocumentTest.vala"
	_tmp167_ = gxml_document_get_root ((GXmlDocument*) d);
#line 723 "TDocumentTest.vala"
	_tmp168_ = _tmp167_;
#line 723 "TDocumentTest.vala"
	_tmp169_ = _tmp168_;
#line 723 "TDocumentTest.vala"
	_tmp170_ = gxml_node_get_children_nodes (_tmp169_);
#line 723 "TDocumentTest.vala"
	_tmp171_ = _tmp170_;
#line 723 "TDocumentTest.vala"
	_tmp172_ = _tmp171_;
#line 723 "TDocumentTest.vala"
	_tmp173_ = gee_list_get ((GeeList*) _tmp172_, 1);
#line 723 "TDocumentTest.vala"
	_tmp174_ = (GXmlNode*) _tmp173_;
#line 723 "TDocumentTest.vala"
	_tmp175_ = gxml_node_get_children_nodes (_tmp174_);
#line 723 "TDocumentTest.vala"
	_tmp176_ = _tmp175_;
#line 723 "TDocumentTest.vala"
	_tmp177_ = _tmp176_;
#line 723 "TDocumentTest.vala"
	_tmp178_ = gee_list_get ((GeeList*) _tmp177_, 0);
#line 723 "TDocumentTest.vala"
	_tmp179_ = (GXmlNode*) _tmp178_;
#line 723 "TDocumentTest.vala"
	_tmp180_ = gxml_node_get_children_nodes (_tmp179_);
#line 723 "TDocumentTest.vala"
	_tmp181_ = _tmp180_;
#line 723 "TDocumentTest.vala"
	_tmp182_ = _tmp181_;
#line 723 "TDocumentTest.vala"
	_tmp183_ = gee_list_get ((GeeList*) _tmp182_, 0);
#line 723 "TDocumentTest.vala"
	_tmp184_ = (GXmlNode*) _tmp183_;
#line 723 "TDocumentTest.vala"
	_tmp185_ = gxml_node_get_value (_tmp184_);
#line 723 "TDocumentTest.vala"
	_tmp186_ = _tmp185_;
#line 723 "TDocumentTest.vala"
	_tmp187_ = _tmp186_;
#line 723 "TDocumentTest.vala"
	_vala_assert (g_strcmp0 (_tmp187_, "COMMUNICATIONS") == 0, "d.root.children_nodes[1].children_nodes[0].children_nodes[0].value == \"COMMUNICATIONS\"");
#line 723 "TDocumentTest.vala"
	_g_free0 (_tmp187_);
#line 723 "TDocumentTest.vala"
	_g_object_unref0 (_tmp184_);
#line 723 "TDocumentTest.vala"
	_g_object_unref0 (_tmp182_);
#line 723 "TDocumentTest.vala"
	_g_object_unref0 (_tmp179_);
#line 723 "TDocumentTest.vala"
	_g_object_unref0 (_tmp177_);
#line 723 "TDocumentTest.vala"
	_g_object_unref0 (_tmp174_);
#line 723 "TDocumentTest.vala"
	_g_object_unref0 (_tmp172_);
#line 723 "TDocumentTest.vala"
	_g_object_unref0 (_tmp169_);
#line 702 "TDocumentTest.vala"
	_g_object_unref0 (d);
#line 702 "TDocumentTest.vala"
	_g_object_unref0 (f);
#line 11121 "TDocumentTest.c"
}

static void
___lambda227__gtest_func (void)
{
#line 702 "TDocumentTest.vala"
	__lambda227_ ();
#line 11129 "TDocumentTest.c"
}

void
tdocument_test_add_tests (void)
{
#line 33 "TDocumentTest.vala"
	g_test_add_func ("/gxml/t-document", ___lambda208__gtest_func);
#line 42 "TDocumentTest.vala"
	g_test_add_func ("/gxml/t-document/root", ___lambda209__gtest_func);
#line 59 "TDocumentTest.vala"
	g_test_add_func ("/gxml/t-document/save/root", ___lambda210__gtest_func);
#line 87 "TDocumentTest.vala"
	g_test_add_func ("/gxml/t-document/save/root/attribute", ___lambda211__gtest_func);
#line 124 "TDocumentTest.vala"
	g_test_add_func ("/gxml/t-document/save/root/content", ___lambda212__gtest_func);
#line 159 "TDocumentTest.vala"
	g_test_add_func ("/gxml/t-document/save/root/children", ___lambda213__gtest_func);
#line 198 "TDocumentTest.vala"
	g_test_add_func ("/gxml/t-document/root/children-children", ___lambda214__gtest_func);
#line 329 "TDocumentTest.vala"
	g_test_add_func ("/gxml/t-document/save/backup", ___lambda215__gtest_func);
#line 364 "TDocumentTest.vala"
	g_test_add_func ("/gxml/t-document/to_string", ___lambda216__gtest_func);
#line 381 "TDocumentTest.vala"
	g_test_add_func ("/gxml/t-document/namespace", ___lambda217__gtest_func);
#line 420 "TDocumentTest.vala"
	g_test_add_func ("/gxml/t-document/parent", ___lambda218__gtest_func);
#line 424 "TDocumentTest.vala"
	g_test_add_func ("/gxml/t-document/read/basic", ___lambda219__gtest_func);
#line 492 "TDocumentTest.vala"
	g_test_add_func ("/gxml/t-document/read/namespace", ___lambda220__gtest_func);
#line 533 "TDocumentTest.vala"
	g_test_add_func ("/gxml/t-document/read/comment", ___lambda221__gtest_func);
#line 547 "TDocumentTest.vala"
	g_test_add_func ("/gxml/t-document/read/pi", ___lambda222__gtest_func);
#line 571 "TDocumentTest.vala"
	g_test_add_func ("/gxml/t-document/read/cdata", ___lambda223__gtest_func);
#line 585 "TDocumentTest.vala"
	g_test_add_func ("/gxml/t-document/read/uri", ___lambda224__gtest_func);
#line 617 "TDocumentTest.vala"
	g_test_add_func ("/gxml/t-document/read/stream", ___lambda225__gtest_func);
#line 684 "TDocumentTest.vala"
	g_test_add_func ("/gxml/t-document/read/string", ___lambda226__gtest_func);
#line 702 "TDocumentTest.vala"
	g_test_add_func ("/gxml/t-document/read/string/attrs", ___lambda227__gtest_func);
#line 11175 "TDocumentTest.c"
}

TDocumentTest*
tdocument_test_construct (GType object_type)
{
	TDocumentTest* self = NULL;
#line 25 "TDocumentTest.vala"
	self = (TDocumentTest*) gxml_test_construct (object_type);
#line 25 "TDocumentTest.vala"
	return self;
#line 11186 "TDocumentTest.c"
}

TDocumentTest*
tdocument_test_new (void)
{
#line 25 "TDocumentTest.vala"
	return tdocument_test_construct (TYPE_TDOCUMENT_TEST);
#line 11194 "TDocumentTest.c"
}

static inline gpointer
tdocument_test_ttest_object_get_instance_private (TDocumentTestTTestObject* self)
{
	return G_STRUCT_MEMBER_P (self, TDocumentTestTTestObject_private_offset);
}

static gchar*
tdocument_test_ttest_object_real_node_name (GXmlSerializableObjectModel* base)
{
	TDocumentTestTTestObject * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 29 "TDocumentTest.vala"
	self = (TDocumentTestTTestObject*) base;
#line 29 "TDocumentTest.vala"
	_tmp0_ = g_strdup ("Test");
#line 29 "TDocumentTest.vala"
	result = _tmp0_;
#line 29 "TDocumentTest.vala"
	return result;
#line 11217 "TDocumentTest.c"
}

static gchar*
tdocument_test_ttest_object_real_to_string (GXmlSerializableObjectModel* base)
{
	TDocumentTestTTestObject * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 30 "TDocumentTest.vala"
	self = (TDocumentTestTTestObject*) base;
#line 30 "TDocumentTest.vala"
	_tmp0_ = g_strdup ("TestNode");
#line 30 "TDocumentTest.vala"
	result = _tmp0_;
#line 30 "TDocumentTest.vala"
	return result;
#line 11234 "TDocumentTest.c"
}

TDocumentTestTTestObject*
tdocument_test_ttest_object_construct (GType object_type)
{
	TDocumentTestTTestObject * self = NULL;
#line 26 "TDocumentTest.vala"
	self = (TDocumentTestTTestObject*) gxml_serializable_object_model_construct (object_type);
#line 26 "TDocumentTest.vala"
	return self;
#line 11245 "TDocumentTest.c"
}

TDocumentTestTTestObject*
tdocument_test_ttest_object_new (void)
{
#line 26 "TDocumentTest.vala"
	return tdocument_test_ttest_object_construct (TDOCUMENT_TEST_TYPE_TTEST_OBJECT);
#line 11253 "TDocumentTest.c"
}

const gchar*
tdocument_test_ttest_object_get_name (TDocumentTestTTestObject* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 28 "TDocumentTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 28 "TDocumentTest.vala"
	_tmp0_ = self->priv->_name;
#line 28 "TDocumentTest.vala"
	result = _tmp0_;
#line 28 "TDocumentTest.vala"
	return result;
#line 11269 "TDocumentTest.c"
}

void
tdocument_test_ttest_object_set_name (TDocumentTestTTestObject* self,
                                      const gchar* value)
{
#line 28 "TDocumentTest.vala"
	g_return_if_fail (self != NULL);
#line 28 "TDocumentTest.vala"
	if (g_strcmp0 (value, tdocument_test_ttest_object_get_name (self)) != 0) {
#line 11280 "TDocumentTest.c"
		gchar* _tmp0_;
#line 28 "TDocumentTest.vala"
		_tmp0_ = g_strdup (value);
#line 28 "TDocumentTest.vala"
		_g_free0 (self->priv->_name);
#line 28 "TDocumentTest.vala"
		self->priv->_name = _tmp0_;
#line 28 "TDocumentTest.vala"
		g_object_notify_by_pspec ((GObject *) self, tdocument_test_ttest_object_properties[TDOCUMENT_TEST_TTEST_OBJECT_NAME_PROPERTY]);
#line 11290 "TDocumentTest.c"
	}
}

static void
tdocument_test_ttest_object_class_init (TDocumentTestTTestObjectClass * klass,
                                        gpointer klass_data)
{
#line 26 "TDocumentTest.vala"
	tdocument_test_ttest_object_parent_class = g_type_class_peek_parent (klass);
#line 26 "TDocumentTest.vala"
	g_type_class_adjust_private_offset (klass, &TDocumentTestTTestObject_private_offset);
#line 26 "TDocumentTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) tdocument_test_ttest_object_real_node_name;
#line 26 "TDocumentTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) tdocument_test_ttest_object_real_to_string;
#line 26 "TDocumentTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_tdocument_test_ttest_object_get_property;
#line 26 "TDocumentTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_tdocument_test_ttest_object_set_property;
#line 26 "TDocumentTest.vala"
	G_OBJECT_CLASS (klass)->finalize = tdocument_test_ttest_object_finalize;
#line 26 "TDocumentTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), TDOCUMENT_TEST_TTEST_OBJECT_NAME_PROPERTY, tdocument_test_ttest_object_properties[TDOCUMENT_TEST_TTEST_OBJECT_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 11314 "TDocumentTest.c"
}

static void
tdocument_test_ttest_object_instance_init (TDocumentTestTTestObject * self,
                                           gpointer klass)
{
#line 26 "TDocumentTest.vala"
	self->priv = tdocument_test_ttest_object_get_instance_private (self);
#line 11323 "TDocumentTest.c"
}

static void
tdocument_test_ttest_object_finalize (GObject * obj)
{
	TDocumentTestTTestObject * self;
#line 26 "TDocumentTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TDOCUMENT_TEST_TYPE_TTEST_OBJECT, TDocumentTestTTestObject);
#line 28 "TDocumentTest.vala"
	_g_free0 (self->priv->_name);
#line 26 "TDocumentTest.vala"
	G_OBJECT_CLASS (tdocument_test_ttest_object_parent_class)->finalize (obj);
#line 11336 "TDocumentTest.c"
}

GType
tdocument_test_ttest_object_get_type (void)
{
	static volatile gsize tdocument_test_ttest_object_type_id__volatile = 0;
	if (g_once_init_enter (&tdocument_test_ttest_object_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (TDocumentTestTTestObjectClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tdocument_test_ttest_object_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TDocumentTestTTestObject), 0, (GInstanceInitFunc) tdocument_test_ttest_object_instance_init, NULL };
		GType tdocument_test_ttest_object_type_id;
		tdocument_test_ttest_object_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "TDocumentTestTTestObject", &g_define_type_info, 0);
		TDocumentTestTTestObject_private_offset = g_type_add_instance_private (tdocument_test_ttest_object_type_id, sizeof (TDocumentTestTTestObjectPrivate));
		g_once_init_leave (&tdocument_test_ttest_object_type_id__volatile, tdocument_test_ttest_object_type_id);
	}
	return tdocument_test_ttest_object_type_id__volatile;
}

static void
_vala_tdocument_test_ttest_object_get_property (GObject * object,
                                                guint property_id,
                                                GValue * value,
                                                GParamSpec * pspec)
{
	TDocumentTestTTestObject * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TDOCUMENT_TEST_TYPE_TTEST_OBJECT, TDocumentTestTTestObject);
#line 26 "TDocumentTest.vala"
	switch (property_id) {
#line 26 "TDocumentTest.vala"
		case TDOCUMENT_TEST_TTEST_OBJECT_NAME_PROPERTY:
#line 26 "TDocumentTest.vala"
		g_value_set_string (value, tdocument_test_ttest_object_get_name (self));
#line 26 "TDocumentTest.vala"
		break;
#line 11369 "TDocumentTest.c"
		default:
#line 26 "TDocumentTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 26 "TDocumentTest.vala"
		break;
#line 11375 "TDocumentTest.c"
	}
}

static void
_vala_tdocument_test_ttest_object_set_property (GObject * object,
                                                guint property_id,
                                                const GValue * value,
                                                GParamSpec * pspec)
{
	TDocumentTestTTestObject * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TDOCUMENT_TEST_TYPE_TTEST_OBJECT, TDocumentTestTTestObject);
#line 26 "TDocumentTest.vala"
	switch (property_id) {
#line 26 "TDocumentTest.vala"
		case TDOCUMENT_TEST_TTEST_OBJECT_NAME_PROPERTY:
#line 26 "TDocumentTest.vala"
		tdocument_test_ttest_object_set_name (self, g_value_get_string (value));
#line 26 "TDocumentTest.vala"
		break;
#line 11395 "TDocumentTest.c"
		default:
#line 26 "TDocumentTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 26 "TDocumentTest.vala"
		break;
#line 11401 "TDocumentTest.c"
	}
}

static void
tdocument_test_class_init (TDocumentTestClass * klass,
                           gpointer klass_data)
{
#line 25 "TDocumentTest.vala"
	tdocument_test_parent_class = g_type_class_peek_parent (klass);
#line 11411 "TDocumentTest.c"
}

static void
tdocument_test_instance_init (TDocumentTest * self,
                              gpointer klass)
{
}

GType
tdocument_test_get_type (void)
{
	static volatile gsize tdocument_test_type_id__volatile = 0;
	if (g_once_init_enter (&tdocument_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (TDocumentTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tdocument_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TDocumentTest), 0, (GInstanceInitFunc) tdocument_test_instance_init, NULL };
		GType tdocument_test_type_id;
		tdocument_test_type_id = g_type_register_static (TYPE_GXML_TEST, "TDocumentTest", &g_define_type_info, 0);
		g_once_init_leave (&tdocument_test_type_id__volatile, tdocument_test_type_id);
	}
	return tdocument_test_type_id__volatile;
}

static void
_vala_array_destroy (gpointer array,
                     gint array_length,
                     GDestroyNotify destroy_func)
{
#line 356 "GomSerializationTest.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 11440 "TDocumentTest.c"
		int i;
#line 356 "GomSerializationTest.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 356 "GomSerializationTest.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 356 "GomSerializationTest.vala"
				destroy_func (((gpointer*) array)[i]);
#line 11448 "TDocumentTest.c"
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gint array_length,
                  GDestroyNotify destroy_func)
{
#line 356 "GomSerializationTest.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 356 "GomSerializationTest.vala"
	g_free (array);
#line 11463 "TDocumentTest.c"
}

static gint
_vala_array_length (gpointer array)
{
	int length;
	length = 0;
#line 356 "GomSerializationTest.vala"
	if (array) {
#line 356 "GomSerializationTest.vala"
		while (((gpointer*) array)[length]) {
#line 356 "GomSerializationTest.vala"
			length++;
#line 11477 "TDocumentTest.c"
		}
	}
#line 356 "GomSerializationTest.vala"
	return length;
#line 11482 "TDocumentTest.c"
}

