/* GomSerializationTest.c generated by valac 0.44.3, the Vala compiler
 * generated from GomSerializationTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */
/* Notation.vala
 *
 * Copyright (C) 2016  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <gxml/gxml.h>
#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <float.h>
#include <math.h>
#include <gee.h>
#include <gio/gio.h>

#define TYPE_THREE_KEYS (three_keys_get_type ())
#define THREE_KEYS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THREE_KEYS, ThreeKeys))
#define THREE_KEYS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THREE_KEYS, ThreeKeysClass))
#define IS_THREE_KEYS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THREE_KEYS))
#define IS_THREE_KEYS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THREE_KEYS))
#define THREE_KEYS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THREE_KEYS, ThreeKeysClass))

typedef struct _ThreeKeys ThreeKeys;
typedef struct _ThreeKeysClass ThreeKeysClass;
typedef struct _ThreeKeysPrivate ThreeKeysPrivate;

#define THREE_KEY_TYPE_MAP (three_key_map_get_type ())
#define THREE_KEY_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), THREE_KEY_TYPE_MAP, ThreeKeyMap))
#define THREE_KEY_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), THREE_KEY_TYPE_MAP, ThreeKeyMapClass))
#define THREE_KEY_IS_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), THREE_KEY_TYPE_MAP))
#define THREE_KEY_IS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), THREE_KEY_TYPE_MAP))
#define THREE_KEY_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), THREE_KEY_TYPE_MAP, ThreeKeyMapClass))

typedef struct _ThreeKeyMap ThreeKeyMap;
typedef struct _ThreeKeyMapClass ThreeKeyMapClass;
enum  {
	THREE_KEYS_0_PROPERTY,
	THREE_KEYS_MAP_PROPERTY,
	THREE_KEYS_NUM_PROPERTIES
};
static GParamSpec* three_keys_properties[THREE_KEYS_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define TYPE_THREE_KEY (three_key_get_type ())
#define THREE_KEY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THREE_KEY, ThreeKey))
#define THREE_KEY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THREE_KEY, ThreeKeyClass))
#define IS_THREE_KEY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THREE_KEY))
#define IS_THREE_KEY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THREE_KEY))
#define THREE_KEY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THREE_KEY, ThreeKeyClass))

typedef struct _ThreeKey ThreeKey;
typedef struct _ThreeKeyClass ThreeKeyClass;
typedef struct _ThreeKeyPrivate ThreeKeyPrivate;
enum  {
	THREE_KEY_0_PROPERTY,
	THREE_KEY_ID_PROPERTY,
	THREE_KEY_CODE_PROPERTY,
	THREE_KEY_NAME_PROPERTY,
	THREE_KEY_NUM_PROPERTIES
};
static GParamSpec* three_key_properties[THREE_KEY_NUM_PROPERTIES];
typedef struct _ThreeKeyMapPrivate ThreeKeyMapPrivate;
enum  {
	THREE_KEY_MAP_0_PROPERTY,
	THREE_KEY_MAP_NUM_PROPERTIES
};
static GParamSpec* three_key_map_properties[THREE_KEY_MAP_NUM_PROPERTIES];

#define TYPE_OPERATIONS (operations_get_type ())
#define OPERATIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_OPERATIONS, Operations))
#define OPERATIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_OPERATIONS, OperationsClass))
#define IS_OPERATIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_OPERATIONS))
#define IS_OPERATIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_OPERATIONS))
#define OPERATIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_OPERATIONS, OperationsClass))

typedef struct _Operations Operations;
typedef struct _OperationsClass OperationsClass;
typedef struct _OperationsPrivate OperationsPrivate;

#define OPERATION_TYPE_MAP (operation_map_get_type ())
#define OPERATION_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OPERATION_TYPE_MAP, OperationMap))
#define OPERATION_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OPERATION_TYPE_MAP, OperationMapClass))
#define OPERATION_IS_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OPERATION_TYPE_MAP))
#define OPERATION_IS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OPERATION_TYPE_MAP))
#define OPERATION_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OPERATION_TYPE_MAP, OperationMapClass))

typedef struct _OperationMap OperationMap;
typedef struct _OperationMapClass OperationMapClass;
enum  {
	OPERATIONS_0_PROPERTY,
	OPERATIONS_MAP_PROPERTY,
	OPERATIONS_NUM_PROPERTIES
};
static GParamSpec* operations_properties[OPERATIONS_NUM_PROPERTIES];

#define TYPE_OPERATION (operation_get_type ())
#define OPERATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_OPERATION, Operation))
#define OPERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_OPERATION, OperationClass))
#define IS_OPERATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_OPERATION))
#define IS_OPERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_OPERATION))
#define OPERATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_OPERATION, OperationClass))

typedef struct _Operation Operation;
typedef struct _OperationClass OperationClass;
typedef struct _OperationPrivate OperationPrivate;
enum  {
	OPERATION_0_PROPERTY,
	OPERATION_ID_PROPERTY,
	OPERATION_CODE_PROPERTY,
	OPERATION_NUM_PROPERTIES
};
static GParamSpec* operation_properties[OPERATION_NUM_PROPERTIES];
typedef struct _OperationMapPrivate OperationMapPrivate;
enum  {
	OPERATION_MAP_0_PROPERTY,
	OPERATION_MAP_NUM_PROPERTIES
};
static GParamSpec* operation_map_properties[OPERATION_MAP_NUM_PROPERTIES];

#define TYPE_GOM_NAME (gom_name_get_type ())
#define GOM_NAME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_NAME, GomName))
#define GOM_NAME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_NAME, GomNameClass))
#define IS_GOM_NAME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_NAME))
#define IS_GOM_NAME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_NAME))
#define GOM_NAME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_NAME, GomNameClass))

typedef struct _GomName GomName;
typedef struct _GomNameClass GomNameClass;
typedef struct _GomNamePrivate GomNamePrivate;
enum  {
	GOM_NAME_0_PROPERTY,
	GOM_NAME_NUM_PROPERTIES
};
static GParamSpec* gom_name_properties[GOM_NAME_NUM_PROPERTIES];

#define TYPE_GOM_EMAIL (gom_email_get_type ())
#define GOM_EMAIL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_EMAIL, GomEmail))
#define GOM_EMAIL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_EMAIL, GomEmailClass))
#define IS_GOM_EMAIL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_EMAIL))
#define IS_GOM_EMAIL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_EMAIL))
#define GOM_EMAIL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_EMAIL, GomEmailClass))

typedef struct _GomEmail GomEmail;
typedef struct _GomEmailClass GomEmailClass;
typedef struct _GomEmailPrivate GomEmailPrivate;
enum  {
	GOM_EMAIL_0_PROPERTY,
	GOM_EMAIL_NUM_PROPERTIES
};
static GParamSpec* gom_email_properties[GOM_EMAIL_NUM_PROPERTIES];

#define TYPE_GOM_AUTHOR (gom_author_get_type ())
#define GOM_AUTHOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_AUTHOR, GomAuthor))
#define GOM_AUTHOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_AUTHOR, GomAuthorClass))
#define IS_GOM_AUTHOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_AUTHOR))
#define IS_GOM_AUTHOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_AUTHOR))
#define GOM_AUTHOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_AUTHOR, GomAuthorClass))

typedef struct _GomAuthor GomAuthor;
typedef struct _GomAuthorClass GomAuthorClass;
typedef struct _GomAuthorPrivate GomAuthorPrivate;
enum  {
	GOM_AUTHOR_0_PROPERTY,
	GOM_AUTHOR_NAME_PROPERTY,
	GOM_AUTHOR_EMAIL_PROPERTY,
	GOM_AUTHOR_NUM_PROPERTIES
};
static GParamSpec* gom_author_properties[GOM_AUTHOR_NUM_PROPERTIES];

#define GOM_AUTHOR_TYPE_ARRAY (gom_author_array_get_type ())
#define GOM_AUTHOR_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_AUTHOR_TYPE_ARRAY, GomAuthorArray))
#define GOM_AUTHOR_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_AUTHOR_TYPE_ARRAY, GomAuthorArrayClass))
#define GOM_AUTHOR_IS_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_AUTHOR_TYPE_ARRAY))
#define GOM_AUTHOR_IS_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_AUTHOR_TYPE_ARRAY))
#define GOM_AUTHOR_ARRAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_AUTHOR_TYPE_ARRAY, GomAuthorArrayClass))

typedef struct _GomAuthorArray GomAuthorArray;
typedef struct _GomAuthorArrayClass GomAuthorArrayClass;
typedef struct _GomAuthorArrayPrivate GomAuthorArrayPrivate;
enum  {
	GOM_AUTHOR_ARRAY_0_PROPERTY,
	GOM_AUTHOR_ARRAY_NUM_PROPERTIES
};
static GParamSpec* gom_author_array_properties[GOM_AUTHOR_ARRAY_NUM_PROPERTIES];

#define TYPE_GOM_AUTHORS (gom_authors_get_type ())
#define GOM_AUTHORS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_AUTHORS, GomAuthors))
#define GOM_AUTHORS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_AUTHORS, GomAuthorsClass))
#define IS_GOM_AUTHORS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_AUTHORS))
#define IS_GOM_AUTHORS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_AUTHORS))
#define GOM_AUTHORS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_AUTHORS, GomAuthorsClass))

typedef struct _GomAuthors GomAuthors;
typedef struct _GomAuthorsClass GomAuthorsClass;
typedef struct _GomAuthorsPrivate GomAuthorsPrivate;
enum  {
	GOM_AUTHORS_0_PROPERTY,
	GOM_AUTHORS_NUMBER_PROPERTY,
	GOM_AUTHORS_ARRAY_PROPERTY,
	GOM_AUTHORS_NUM_PROPERTIES
};
static GParamSpec* gom_authors_properties[GOM_AUTHORS_NUM_PROPERTIES];

#define TYPE_GOM_INVENTORY (gom_inventory_get_type ())
#define GOM_INVENTORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_INVENTORY, GomInventory))
#define GOM_INVENTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_INVENTORY, GomInventoryClass))
#define IS_GOM_INVENTORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_INVENTORY))
#define IS_GOM_INVENTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_INVENTORY))
#define GOM_INVENTORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_INVENTORY, GomInventoryClass))

typedef struct _GomInventory GomInventory;
typedef struct _GomInventoryClass GomInventoryClass;
typedef struct _GomInventoryPrivate GomInventoryPrivate;
enum  {
	GOM_INVENTORY_0_PROPERTY,
	GOM_INVENTORY_NUMBER_PROPERTY,
	GOM_INVENTORY_ROW_PROPERTY,
	GOM_INVENTORY_INVENTORY_PROPERTY,
	GOM_INVENTORY_NUM_PROPERTIES
};
static GParamSpec* gom_inventory_properties[GOM_INVENTORY_NUM_PROPERTIES];

#define GOM_INVENTORY_TYPE_DUAL_KEY_MAP (gom_inventory_dual_key_map_get_type ())
#define GOM_INVENTORY_DUAL_KEY_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_INVENTORY_TYPE_DUAL_KEY_MAP, GomInventoryDualKeyMap))
#define GOM_INVENTORY_DUAL_KEY_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_INVENTORY_TYPE_DUAL_KEY_MAP, GomInventoryDualKeyMapClass))
#define GOM_INVENTORY_IS_DUAL_KEY_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_INVENTORY_TYPE_DUAL_KEY_MAP))
#define GOM_INVENTORY_IS_DUAL_KEY_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_INVENTORY_TYPE_DUAL_KEY_MAP))
#define GOM_INVENTORY_DUAL_KEY_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_INVENTORY_TYPE_DUAL_KEY_MAP, GomInventoryDualKeyMapClass))

typedef struct _GomInventoryDualKeyMap GomInventoryDualKeyMap;
typedef struct _GomInventoryDualKeyMapClass GomInventoryDualKeyMapClass;
typedef struct _GomInventoryDualKeyMapPrivate GomInventoryDualKeyMapPrivate;
enum  {
	GOM_INVENTORY_DUAL_KEY_MAP_0_PROPERTY,
	GOM_INVENTORY_DUAL_KEY_MAP_NUM_PROPERTIES
};
static GParamSpec* gom_inventory_dual_key_map_properties[GOM_INVENTORY_DUAL_KEY_MAP_NUM_PROPERTIES];

#define TYPE_GOM_CATEGORY (gom_category_get_type ())
#define GOM_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_CATEGORY, GomCategory))
#define GOM_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_CATEGORY, GomCategoryClass))
#define IS_GOM_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_CATEGORY))
#define IS_GOM_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_CATEGORY))
#define GOM_CATEGORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_CATEGORY, GomCategoryClass))

typedef struct _GomCategory GomCategory;
typedef struct _GomCategoryClass GomCategoryClass;
typedef struct _GomCategoryPrivate GomCategoryPrivate;
enum  {
	GOM_CATEGORY_0_PROPERTY,
	GOM_CATEGORY_NAME_PROPERTY,
	GOM_CATEGORY_NUM_PROPERTIES
};
static GParamSpec* gom_category_properties[GOM_CATEGORY_NUM_PROPERTIES];

#define GOM_CATEGORY_TYPE_MAP (gom_category_map_get_type ())
#define GOM_CATEGORY_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_CATEGORY_TYPE_MAP, GomCategoryMap))
#define GOM_CATEGORY_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_CATEGORY_TYPE_MAP, GomCategoryMapClass))
#define GOM_CATEGORY_IS_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_CATEGORY_TYPE_MAP))
#define GOM_CATEGORY_IS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_CATEGORY_TYPE_MAP))
#define GOM_CATEGORY_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_CATEGORY_TYPE_MAP, GomCategoryMapClass))

typedef struct _GomCategoryMap GomCategoryMap;
typedef struct _GomCategoryMapClass GomCategoryMapClass;
typedef struct _GomCategoryMapPrivate GomCategoryMapPrivate;
enum  {
	GOM_CATEGORY_MAP_0_PROPERTY,
	GOM_CATEGORY_MAP_NUM_PROPERTIES
};
static GParamSpec* gom_category_map_properties[GOM_CATEGORY_MAP_NUM_PROPERTIES];

#define TYPE_GOM_RESUME (gom_resume_get_type ())
#define GOM_RESUME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_RESUME, GomResume))
#define GOM_RESUME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_RESUME, GomResumeClass))
#define IS_GOM_RESUME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_RESUME))
#define IS_GOM_RESUME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_RESUME))
#define GOM_RESUME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_RESUME, GomResumeClass))

typedef struct _GomResume GomResume;
typedef struct _GomResumeClass GomResumeClass;
typedef struct _GomResumePrivate GomResumePrivate;
enum  {
	GOM_RESUME_0_PROPERTY,
	GOM_RESUME_CHAPTER_PROPERTY,
	GOM_RESUME_TEXT_PROPERTY,
	GOM_RESUME_NUM_PROPERTIES
};
static GParamSpec* gom_resume_properties[GOM_RESUME_NUM_PROPERTIES];

#define GOM_RESUME_TYPE_MAP (gom_resume_map_get_type ())
#define GOM_RESUME_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_RESUME_TYPE_MAP, GomResumeMap))
#define GOM_RESUME_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_RESUME_TYPE_MAP, GomResumeMapClass))
#define GOM_RESUME_IS_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_RESUME_TYPE_MAP))
#define GOM_RESUME_IS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_RESUME_TYPE_MAP))
#define GOM_RESUME_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_RESUME_TYPE_MAP, GomResumeMapClass))

typedef struct _GomResumeMap GomResumeMap;
typedef struct _GomResumeMapClass GomResumeMapClass;
typedef struct _GomResumeMapPrivate GomResumeMapPrivate;
enum  {
	GOM_RESUME_MAP_0_PROPERTY,
	GOM_RESUME_MAP_NUM_PROPERTIES
};
static GParamSpec* gom_resume_map_properties[GOM_RESUME_MAP_NUM_PROPERTIES];

#define TYPE_GOM_BOOK (gom_book_get_type ())
#define GOM_BOOK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_BOOK, GomBook))
#define GOM_BOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_BOOK, GomBookClass))
#define IS_GOM_BOOK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_BOOK))
#define IS_GOM_BOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_BOOK))
#define GOM_BOOK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_BOOK, GomBookClass))

typedef struct _GomBook GomBook;
typedef struct _GomBookClass GomBookClass;
typedef struct _GomBookPrivate GomBookPrivate;
enum  {
	GOM_BOOK_0_PROPERTY,
	GOM_BOOK_YEAR_PROPERTY,
	GOM_BOOK_ISBN_PROPERTY,
	GOM_BOOK_NAME_PROPERTY,
	GOM_BOOK_AUTHORS_PROPERTY,
	GOM_BOOK_INVENTORY_REGISTERS_PROPERTY,
	GOM_BOOK_CATEGORIES_PROPERTY,
	GOM_BOOK_RESUMES_PROPERTY,
	GOM_BOOK_NUM_PROPERTIES
};
static GParamSpec* gom_book_properties[GOM_BOOK_NUM_PROPERTIES];

#define GOM_BOOK_TYPE_ARRAY (gom_book_array_get_type ())
#define GOM_BOOK_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_BOOK_TYPE_ARRAY, GomBookArray))
#define GOM_BOOK_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_BOOK_TYPE_ARRAY, GomBookArrayClass))
#define GOM_BOOK_IS_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_BOOK_TYPE_ARRAY))
#define GOM_BOOK_IS_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_BOOK_TYPE_ARRAY))
#define GOM_BOOK_ARRAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_BOOK_TYPE_ARRAY, GomBookArrayClass))

typedef struct _GomBookArray GomBookArray;
typedef struct _GomBookArrayClass GomBookArrayClass;
typedef struct _GomBookArrayPrivate GomBookArrayPrivate;
enum  {
	GOM_BOOK_ARRAY_0_PROPERTY,
	GOM_BOOK_ARRAY_NUM_PROPERTIES
};
static GParamSpec* gom_book_array_properties[GOM_BOOK_ARRAY_NUM_PROPERTIES];

#define TYPE_GOM_BOOK_STORE (gom_book_store_get_type ())
#define GOM_BOOK_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_BOOK_STORE, GomBookStore))
#define GOM_BOOK_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_BOOK_STORE, GomBookStoreClass))
#define IS_GOM_BOOK_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_BOOK_STORE))
#define IS_GOM_BOOK_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_BOOK_STORE))
#define GOM_BOOK_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_BOOK_STORE, GomBookStoreClass))

typedef struct _GomBookStore GomBookStore;
typedef struct _GomBookStoreClass GomBookStoreClass;
typedef struct _GomBookStorePrivate GomBookStorePrivate;
enum  {
	GOM_BOOK_STORE_0_PROPERTY,
	GOM_BOOK_STORE_NAME_PROPERTY,
	GOM_BOOK_STORE_BOOKS_PROPERTY,
	GOM_BOOK_STORE_NUM_PROPERTIES
};
static GParamSpec* gom_book_store_properties[GOM_BOOK_STORE_NUM_PROPERTIES];

#define TYPE_GOM_BASIC_TYPES (gom_basic_types_get_type ())
#define GOM_BASIC_TYPES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_BASIC_TYPES, GomBasicTypes))
#define GOM_BASIC_TYPES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_BASIC_TYPES, GomBasicTypesClass))
#define IS_GOM_BASIC_TYPES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_BASIC_TYPES))
#define IS_GOM_BASIC_TYPES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_BASIC_TYPES))
#define GOM_BASIC_TYPES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_BASIC_TYPES, GomBasicTypesClass))

typedef struct _GomBasicTypes GomBasicTypes;
typedef struct _GomBasicTypesClass GomBasicTypesClass;
typedef struct _GomBasicTypesPrivate GomBasicTypesPrivate;
enum  {
	GOM_BASIC_TYPES_0_PROPERTY,
	GOM_BASIC_TYPES_TEXT_PROPERTY,
	GOM_BASIC_TYPES_INTEGER_PROPERTY,
	GOM_BASIC_TYPES_REAL_DOUBLE_PROPERTY,
	GOM_BASIC_TYPES_REAL_FLOAT_PROPERTY,
	GOM_BASIC_TYPES_UNSIGNED_INTEGER_PROPERTY,
	GOM_BASIC_TYPES_BOOLEAN_PROPERTY,
	GOM_BASIC_TYPES_NUM_PROPERTIES
};
static GParamSpec* gom_basic_types_properties[GOM_BASIC_TYPES_NUM_PROPERTIES];

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_GOM_SERIALIZATION_TEST (gom_serialization_test_get_type ())
#define GOM_SERIALIZATION_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_SERIALIZATION_TEST, GomSerializationTest))
#define GOM_SERIALIZATION_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_SERIALIZATION_TEST, GomSerializationTestClass))
#define IS_GOM_SERIALIZATION_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_SERIALIZATION_TEST))
#define IS_GOM_SERIALIZATION_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_SERIALIZATION_TEST))
#define GOM_SERIALIZATION_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_SERIALIZATION_TEST, GomSerializationTestClass))

typedef struct _GomSerializationTest GomSerializationTest;
typedef struct _GomSerializationTestClass GomSerializationTestClass;
typedef struct _GomSerializationTestPrivate GomSerializationTestPrivate;

#define GOM_SERIALIZATION_TEST_TYPE_BOOK (gom_serialization_test_book_get_type ())
#define GOM_SERIALIZATION_TEST_BOOK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK, GomSerializationTestBook))
#define GOM_SERIALIZATION_TEST_BOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_BOOK, GomSerializationTestBookClass))
#define GOM_SERIALIZATION_TEST_IS_BOOK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK))
#define GOM_SERIALIZATION_TEST_IS_BOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_BOOK))
#define GOM_SERIALIZATION_TEST_BOOK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK, GomSerializationTestBookClass))

typedef struct _GomSerializationTestBook GomSerializationTestBook;
typedef struct _GomSerializationTestBookClass GomSerializationTestBookClass;

#define GOM_SERIALIZATION_TEST_TYPE_COMPUTER (gom_serialization_test_computer_get_type ())
#define GOM_SERIALIZATION_TEST_COMPUTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_COMPUTER, GomSerializationTestComputer))
#define GOM_SERIALIZATION_TEST_COMPUTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_COMPUTER, GomSerializationTestComputerClass))
#define GOM_SERIALIZATION_TEST_IS_COMPUTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_COMPUTER))
#define GOM_SERIALIZATION_TEST_IS_COMPUTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_COMPUTER))
#define GOM_SERIALIZATION_TEST_COMPUTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_COMPUTER, GomSerializationTestComputerClass))

typedef struct _GomSerializationTestComputer GomSerializationTestComputer;
typedef struct _GomSerializationTestComputerClass GomSerializationTestComputerClass;

#define GOM_SERIALIZATION_TEST_TYPE_TAXES (gom_serialization_test_taxes_get_type ())
#define GOM_SERIALIZATION_TEST_TAXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_TAXES, GomSerializationTestTaxes))
#define GOM_SERIALIZATION_TEST_TAXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_TAXES, GomSerializationTestTaxesClass))
#define GOM_SERIALIZATION_TEST_IS_TAXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_TAXES))
#define GOM_SERIALIZATION_TEST_IS_TAXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_TAXES))
#define GOM_SERIALIZATION_TEST_TAXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_TAXES, GomSerializationTestTaxesClass))

typedef struct _GomSerializationTestTaxes GomSerializationTestTaxes;
typedef struct _GomSerializationTestTaxesClass GomSerializationTestTaxesClass;
typedef enum  {
	GOM_SERIALIZATION_TEST_TAXES_MONTH_JANUARY,
	GOM_SERIALIZATION_TEST_TAXES_MONTH_FEBRUARY
} GomSerializationTestTaxesMonth;

#define GOM_SERIALIZATION_TEST_TAXES_TYPE_MONTH (gom_serialization_test_taxes_month_get_type ())
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))

#define GOM_SERIALIZATION_TEST_TYPE_BOOK_STAND (gom_serialization_test_book_stand_get_type ())
#define GOM_SERIALIZATION_TEST_BOOK_STAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK_STAND, GomSerializationTestBookStand))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_BOOK_STAND, GomSerializationTestBookStandClass))
#define GOM_SERIALIZATION_TEST_IS_BOOK_STAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK_STAND))
#define GOM_SERIALIZATION_TEST_IS_BOOK_STAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_BOOK_STAND))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK_STAND, GomSerializationTestBookStandClass))

typedef struct _GomSerializationTestBookStand GomSerializationTestBookStand;
typedef struct _GomSerializationTestBookStandClass GomSerializationTestBookStandClass;

#define GOM_SERIALIZATION_TEST_TYPE_REGISTERS (gom_serialization_test_registers_get_type ())
#define GOM_SERIALIZATION_TEST_REGISTERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_REGISTERS, GomSerializationTestRegisters))
#define GOM_SERIALIZATION_TEST_REGISTERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_REGISTERS, GomSerializationTestRegistersClass))
#define GOM_SERIALIZATION_TEST_IS_REGISTERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_REGISTERS))
#define GOM_SERIALIZATION_TEST_IS_REGISTERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_REGISTERS))
#define GOM_SERIALIZATION_TEST_REGISTERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_REGISTERS, GomSerializationTestRegistersClass))

typedef struct _GomSerializationTestRegisters GomSerializationTestRegisters;
typedef struct _GomSerializationTestRegistersClass GomSerializationTestRegistersClass;

#define GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER (gom_serialization_test_book_register_get_type ())
#define GOM_SERIALIZATION_TEST_BOOK_REGISTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, GomSerializationTestBookRegister))
#define GOM_SERIALIZATION_TEST_BOOK_REGISTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, GomSerializationTestBookRegisterClass))
#define GOM_SERIALIZATION_TEST_IS_BOOK_REGISTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER))
#define GOM_SERIALIZATION_TEST_IS_BOOK_REGISTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER))
#define GOM_SERIALIZATION_TEST_BOOK_REGISTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, GomSerializationTestBookRegisterClass))

typedef struct _GomSerializationTestBookRegister GomSerializationTestBookRegister;
typedef struct _GomSerializationTestBookRegisterClass GomSerializationTestBookRegisterClass;

#define GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION (gom_serialization_test_book_stand_dimension_get_type ())
#define GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION, GomSerializationTestBookStandDimension))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION, GomSerializationTestBookStandDimensionClass))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_IS_DIMENSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_IS_DIMENSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION, GomSerializationTestBookStandDimensionClass))

typedef struct _GomSerializationTestBookStandDimension GomSerializationTestBookStandDimension;
typedef struct _GomSerializationTestBookStandDimensionClass GomSerializationTestBookStandDimensionClass;

#define GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Y (gom_serialization_test_book_stand_dimension_y_get_type ())
#define GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Y(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Y, GomSerializationTestBookStandDimensionY))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Y_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Y, GomSerializationTestBookStandDimensionYClass))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_IS_DIMENSION_Y(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Y))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_IS_DIMENSION_Y_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Y))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Y_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Y, GomSerializationTestBookStandDimensionYClass))

typedef struct _GomSerializationTestBookStandDimensionY GomSerializationTestBookStandDimensionY;
typedef struct _GomSerializationTestBookStandDimensionYClass GomSerializationTestBookStandDimensionYClass;

#define GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Z (gom_serialization_test_book_stand_dimension_z_get_type ())
#define GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Z(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Z, GomSerializationTestBookStandDimensionZ))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Z_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Z, GomSerializationTestBookStandDimensionZClass))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_IS_DIMENSION_Z(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Z))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_IS_DIMENSION_Z_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Z))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Z_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Z, GomSerializationTestBookStandDimensionZClass))

typedef struct _GomSerializationTestBookStandDimensionZ GomSerializationTestBookStandDimensionZ;
typedef struct _GomSerializationTestBookStandDimensionZClass GomSerializationTestBookStandDimensionZClass;

#define GOM_SERIALIZATION_TEST_TYPE_BOOK_STORE (gom_serialization_test_book_store_get_type ())
#define GOM_SERIALIZATION_TEST_BOOK_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK_STORE, GomSerializationTestBookStore))
#define GOM_SERIALIZATION_TEST_BOOK_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_BOOK_STORE, GomSerializationTestBookStoreClass))
#define GOM_SERIALIZATION_TEST_IS_BOOK_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK_STORE))
#define GOM_SERIALIZATION_TEST_IS_BOOK_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_BOOK_STORE))
#define GOM_SERIALIZATION_TEST_BOOK_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK_STORE, GomSerializationTestBookStoreClass))

typedef struct _GomSerializationTestBookStore GomSerializationTestBookStore;
typedef struct _GomSerializationTestBookStoreClass GomSerializationTestBookStoreClass;

#define GOM_SERIALIZATION_TEST_TYPE_BOOKS (gom_serialization_test_books_get_type ())
#define GOM_SERIALIZATION_TEST_BOOKS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOKS, GomSerializationTestBooks))
#define GOM_SERIALIZATION_TEST_BOOKS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_BOOKS, GomSerializationTestBooksClass))
#define GOM_SERIALIZATION_TEST_IS_BOOKS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOKS))
#define GOM_SERIALIZATION_TEST_IS_BOOKS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_BOOKS))
#define GOM_SERIALIZATION_TEST_BOOKS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOKS, GomSerializationTestBooksClass))

typedef struct _GomSerializationTestBooks GomSerializationTestBooks;
typedef struct _GomSerializationTestBooksClass GomSerializationTestBooksClass;

#define GOM_SERIALIZATION_TEST_TYPE_HASH_REGISTERS (gom_serialization_test_hash_registers_get_type ())
#define GOM_SERIALIZATION_TEST_HASH_REGISTERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_HASH_REGISTERS, GomSerializationTestHashRegisters))
#define GOM_SERIALIZATION_TEST_HASH_REGISTERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_HASH_REGISTERS, GomSerializationTestHashRegistersClass))
#define GOM_SERIALIZATION_TEST_IS_HASH_REGISTERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_HASH_REGISTERS))
#define GOM_SERIALIZATION_TEST_IS_HASH_REGISTERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_HASH_REGISTERS))
#define GOM_SERIALIZATION_TEST_HASH_REGISTERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_HASH_REGISTERS, GomSerializationTestHashRegistersClass))

typedef struct _GomSerializationTestHashRegisters GomSerializationTestHashRegisters;
typedef struct _GomSerializationTestHashRegistersClass GomSerializationTestHashRegistersClass;

#define GOM_SERIALIZATION_TEST_TYPE_HASH_PAIR_REGISTERS (gom_serialization_test_hash_pair_registers_get_type ())
#define GOM_SERIALIZATION_TEST_HASH_PAIR_REGISTERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_HASH_PAIR_REGISTERS, GomSerializationTestHashPairRegisters))
#define GOM_SERIALIZATION_TEST_HASH_PAIR_REGISTERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_HASH_PAIR_REGISTERS, GomSerializationTestHashPairRegistersClass))
#define GOM_SERIALIZATION_TEST_IS_HASH_PAIR_REGISTERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_HASH_PAIR_REGISTERS))
#define GOM_SERIALIZATION_TEST_IS_HASH_PAIR_REGISTERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_HASH_PAIR_REGISTERS))
#define GOM_SERIALIZATION_TEST_HASH_PAIR_REGISTERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_HASH_PAIR_REGISTERS, GomSerializationTestHashPairRegistersClass))

typedef struct _GomSerializationTestHashPairRegisters GomSerializationTestHashPairRegisters;
typedef struct _GomSerializationTestHashPairRegistersClass GomSerializationTestHashPairRegistersClass;

#define GOM_SERIALIZATION_TEST_TYPE_HASH_THREE_REGISTERS (gom_serialization_test_hash_three_registers_get_type ())
#define GOM_SERIALIZATION_TEST_HASH_THREE_REGISTERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_HASH_THREE_REGISTERS, GomSerializationTestHashThreeRegisters))
#define GOM_SERIALIZATION_TEST_HASH_THREE_REGISTERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_HASH_THREE_REGISTERS, GomSerializationTestHashThreeRegistersClass))
#define GOM_SERIALIZATION_TEST_IS_HASH_THREE_REGISTERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_HASH_THREE_REGISTERS))
#define GOM_SERIALIZATION_TEST_IS_HASH_THREE_REGISTERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_HASH_THREE_REGISTERS))
#define GOM_SERIALIZATION_TEST_HASH_THREE_REGISTERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_HASH_THREE_REGISTERS, GomSerializationTestHashThreeRegistersClass))

typedef struct _GomSerializationTestHashThreeRegisters GomSerializationTestHashThreeRegisters;
typedef struct _GomSerializationTestHashThreeRegistersClass GomSerializationTestHashThreeRegistersClass;

#define GOM_SERIALIZATION_TEST_TYPE_MOTOR (gom_serialization_test_motor_get_type ())
#define GOM_SERIALIZATION_TEST_MOTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_MOTOR, GomSerializationTestMotor))
#define GOM_SERIALIZATION_TEST_MOTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_MOTOR, GomSerializationTestMotorClass))
#define GOM_SERIALIZATION_TEST_IS_MOTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_MOTOR))
#define GOM_SERIALIZATION_TEST_IS_MOTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_MOTOR))
#define GOM_SERIALIZATION_TEST_MOTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_MOTOR, GomSerializationTestMotorClass))

typedef struct _GomSerializationTestMotor GomSerializationTestMotor;
typedef struct _GomSerializationTestMotorClass GomSerializationTestMotorClass;

#define GOM_SERIALIZATION_TEST_MOTOR_TYPE_ON (gom_serialization_test_motor_on_get_type ())
#define GOM_SERIALIZATION_TEST_MOTOR_ON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_ON, GomSerializationTestMotorOn))
#define GOM_SERIALIZATION_TEST_MOTOR_ON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_ON, GomSerializationTestMotorOnClass))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_ON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_ON))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_ON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_ON))
#define GOM_SERIALIZATION_TEST_MOTOR_ON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_ON, GomSerializationTestMotorOnClass))

typedef struct _GomSerializationTestMotorOn GomSerializationTestMotorOn;
typedef struct _GomSerializationTestMotorOnClass GomSerializationTestMotorOnClass;

#define GOM_SERIALIZATION_TEST_MOTOR_TYPE_TORQUE (gom_serialization_test_motor_torque_get_type ())
#define GOM_SERIALIZATION_TEST_MOTOR_TORQUE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TORQUE, GomSerializationTestMotorTorque))
#define GOM_SERIALIZATION_TEST_MOTOR_TORQUE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TORQUE, GomSerializationTestMotorTorqueClass))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_TORQUE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TORQUE))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_TORQUE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TORQUE))
#define GOM_SERIALIZATION_TEST_MOTOR_TORQUE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TORQUE, GomSerializationTestMotorTorqueClass))

typedef struct _GomSerializationTestMotorTorque GomSerializationTestMotorTorque;
typedef struct _GomSerializationTestMotorTorqueClass GomSerializationTestMotorTorqueClass;

#define GOM_SERIALIZATION_TEST_MOTOR_TYPE_SPEED (gom_serialization_test_motor_speed_get_type ())
#define GOM_SERIALIZATION_TEST_MOTOR_SPEED(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_SPEED, GomSerializationTestMotorSpeed))
#define GOM_SERIALIZATION_TEST_MOTOR_SPEED_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_SPEED, GomSerializationTestMotorSpeedClass))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_SPEED(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_SPEED))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_SPEED_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_SPEED))
#define GOM_SERIALIZATION_TEST_MOTOR_SPEED_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_SPEED, GomSerializationTestMotorSpeedClass))

typedef struct _GomSerializationTestMotorSpeed GomSerializationTestMotorSpeed;
typedef struct _GomSerializationTestMotorSpeedClass GomSerializationTestMotorSpeedClass;

#define GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION_TYPE (gom_serialization_test_motor_tension_type_get_type ())
#define GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION_TYPE, GomSerializationTestMotorTensionType))
#define GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION_TYPE, GomSerializationTestMotorTensionTypeClass))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_TENSION_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION_TYPE))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_TENSION_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION_TYPE))
#define GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION_TYPE, GomSerializationTestMotorTensionTypeClass))

typedef struct _GomSerializationTestMotorTensionType GomSerializationTestMotorTensionType;
typedef struct _GomSerializationTestMotorTensionTypeClass GomSerializationTestMotorTensionTypeClass;

#define GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION (gom_serialization_test_motor_tension_get_type ())
#define GOM_SERIALIZATION_TEST_MOTOR_TENSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION, GomSerializationTestMotorTension))
#define GOM_SERIALIZATION_TEST_MOTOR_TENSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION, GomSerializationTestMotorTensionClass))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_TENSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_TENSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION))
#define GOM_SERIALIZATION_TEST_MOTOR_TENSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION, GomSerializationTestMotorTensionClass))

typedef struct _GomSerializationTestMotorTension GomSerializationTestMotorTension;
typedef struct _GomSerializationTestMotorTensionClass GomSerializationTestMotorTensionClass;
typedef enum  {
	GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_ENUM_AC,
	GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_ENUM_DC
} GomSerializationTestMotorTensionTypeEnum;

#define GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION_TYPE_ENUM (gom_serialization_test_motor_tension_type_enum_get_type ())

#define GOM_SERIALIZATION_TEST_MOTOR_TYPE_MODEL (gom_serialization_test_motor_model_get_type ())
#define GOM_SERIALIZATION_TEST_MOTOR_MODEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_MODEL, GomSerializationTestMotorModel))
#define GOM_SERIALIZATION_TEST_MOTOR_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_MODEL, GomSerializationTestMotorModelClass))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_MODEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_MODEL))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_MODEL))
#define GOM_SERIALIZATION_TEST_MOTOR_MODEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_MODEL, GomSerializationTestMotorModelClass))

typedef struct _GomSerializationTestMotorModel GomSerializationTestMotorModel;
typedef struct _GomSerializationTestMotorModelClass GomSerializationTestMotorModelClass;
typedef struct _GomSerializationTestBookPrivate GomSerializationTestBookPrivate;
enum  {
	GOM_SERIALIZATION_TEST_BOOK_0_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_NAME_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_NUM_PROPERTIES
};
static GParamSpec* gom_serialization_test_book_properties[GOM_SERIALIZATION_TEST_BOOK_NUM_PROPERTIES];
typedef struct _GomSerializationTestComputerPrivate GomSerializationTestComputerPrivate;
enum  {
	GOM_SERIALIZATION_TEST_COMPUTER_0_PROPERTY,
	GOM_SERIALIZATION_TEST_COMPUTER_MODEL_PROPERTY,
	GOM_SERIALIZATION_TEST_COMPUTER_IGNORE_PROPERTY,
	GOM_SERIALIZATION_TEST_COMPUTER_NUM_PROPERTIES
};
static GParamSpec* gom_serialization_test_computer_properties[GOM_SERIALIZATION_TEST_COMPUTER_NUM_PROPERTIES];
typedef struct _GomSerializationTestTaxesPrivate GomSerializationTestTaxesPrivate;
enum  {
	GOM_SERIALIZATION_TEST_TAXES_0_PROPERTY,
	GOM_SERIALIZATION_TEST_TAXES_MONTH_RATE_PROPERTY,
	GOM_SERIALIZATION_TEST_TAXES_TAX_FREE_PROPERTY,
	GOM_SERIALIZATION_TEST_TAXES_MONTH_PROPERTY,
	GOM_SERIALIZATION_TEST_TAXES_PAY_DATE_PROPERTY,
	GOM_SERIALIZATION_TEST_TAXES_TIMESTAMP_PROPERTY,
	GOM_SERIALIZATION_TEST_TAXES_NUM_PROPERTIES
};
static GParamSpec* gom_serialization_test_taxes_properties[GOM_SERIALIZATION_TEST_TAXES_NUM_PROPERTIES];
typedef struct _GomSerializationTestBookRegisterPrivate GomSerializationTestBookRegisterPrivate;
enum  {
	GOM_SERIALIZATION_TEST_BOOK_REGISTER_0_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_REGISTER_YEAR_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_REGISTER_COVER_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_REGISTER_BOOK_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_REGISTER_NUM_PROPERTIES
};
static GParamSpec* gom_serialization_test_book_register_properties[GOM_SERIALIZATION_TEST_BOOK_REGISTER_NUM_PROPERTIES];
typedef struct _GomSerializationTestBookStandPrivate GomSerializationTestBookStandPrivate;
enum  {
	GOM_SERIALIZATION_TEST_BOOK_STAND_0_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_CLASSIFICATION_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_X_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Y_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Z_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_REGISTERS_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_HASHMAP_REGISTERS_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_HASHPAIR_REGISTERS_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_HASHTHREE_REGISTERS_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_BOOKS_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_NUM_PROPERTIES
};
static GParamSpec* gom_serialization_test_book_stand_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_NUM_PROPERTIES];
typedef struct _GomSerializationTestBookStandDimensionPrivate GomSerializationTestBookStandDimensionPrivate;
enum  {
	GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_0_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_LENGTH_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_DTYPE_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_NUM_PROPERTIES
};
static GParamSpec* gom_serialization_test_book_stand_dimension_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_NUM_PROPERTIES];
typedef struct _GomSerializationTestBookStandDimensionYPrivate GomSerializationTestBookStandDimensionYPrivate;
enum  {
	GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Y_0_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Y_NUM_PROPERTIES
};
static GParamSpec* gom_serialization_test_book_stand_dimension_y_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Y_NUM_PROPERTIES];
typedef struct _GomSerializationTestBookStandDimensionZPrivate GomSerializationTestBookStandDimensionZPrivate;
enum  {
	GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Z_0_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Z_NUM_PROPERTIES
};
static GParamSpec* gom_serialization_test_book_stand_dimension_z_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Z_NUM_PROPERTIES];
typedef struct _GomSerializationTestRegistersPrivate GomSerializationTestRegistersPrivate;
enum  {
	GOM_SERIALIZATION_TEST_REGISTERS_0_PROPERTY,
	GOM_SERIALIZATION_TEST_REGISTERS_NUM_PROPERTIES
};
static GParamSpec* gom_serialization_test_registers_properties[GOM_SERIALIZATION_TEST_REGISTERS_NUM_PROPERTIES];
typedef struct _GomSerializationTestHashRegistersPrivate GomSerializationTestHashRegistersPrivate;
enum  {
	GOM_SERIALIZATION_TEST_HASH_REGISTERS_0_PROPERTY,
	GOM_SERIALIZATION_TEST_HASH_REGISTERS_NUM_PROPERTIES
};
static GParamSpec* gom_serialization_test_hash_registers_properties[GOM_SERIALIZATION_TEST_HASH_REGISTERS_NUM_PROPERTIES];
typedef struct _GomSerializationTestHashPairRegistersPrivate GomSerializationTestHashPairRegistersPrivate;
enum  {
	GOM_SERIALIZATION_TEST_HASH_PAIR_REGISTERS_0_PROPERTY,
	GOM_SERIALIZATION_TEST_HASH_PAIR_REGISTERS_NUM_PROPERTIES
};
static GParamSpec* gom_serialization_test_hash_pair_registers_properties[GOM_SERIALIZATION_TEST_HASH_PAIR_REGISTERS_NUM_PROPERTIES];
typedef struct _GomSerializationTestHashThreeRegistersPrivate GomSerializationTestHashThreeRegistersPrivate;
enum  {
	GOM_SERIALIZATION_TEST_HASH_THREE_REGISTERS_0_PROPERTY,
	GOM_SERIALIZATION_TEST_HASH_THREE_REGISTERS_NUM_PROPERTIES
};
static GParamSpec* gom_serialization_test_hash_three_registers_properties[GOM_SERIALIZATION_TEST_HASH_THREE_REGISTERS_NUM_PROPERTIES];
typedef struct _GomSerializationTestBooksPrivate GomSerializationTestBooksPrivate;
enum  {
	GOM_SERIALIZATION_TEST_BOOKS_0_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOKS_NUM_PROPERTIES
};
static GParamSpec* gom_serialization_test_books_properties[GOM_SERIALIZATION_TEST_BOOKS_NUM_PROPERTIES];
typedef struct _GomSerializationTestBookStorePrivate GomSerializationTestBookStorePrivate;
enum  {
	GOM_SERIALIZATION_TEST_BOOK_STORE_0_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STORE_NAME_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STORE_BOOKS_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STORE_NUM_PROPERTIES
};
static GParamSpec* gom_serialization_test_book_store_properties[GOM_SERIALIZATION_TEST_BOOK_STORE_NUM_PROPERTIES];
typedef struct _GomSerializationTestMotorPrivate GomSerializationTestMotorPrivate;
enum  {
	GOM_SERIALIZATION_TEST_MOTOR_0_PROPERTY,
	GOM_SERIALIZATION_TEST_MOTOR_IS_ON_PROPERTY,
	GOM_SERIALIZATION_TEST_MOTOR_TORQUE_PROPERTY,
	GOM_SERIALIZATION_TEST_MOTOR_SPEED_PROPERTY,
	GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_PROPERTY,
	GOM_SERIALIZATION_TEST_MOTOR_TENSION_PROPERTY,
	GOM_SERIALIZATION_TEST_MOTOR_MODEL_PROPERTY,
	GOM_SERIALIZATION_TEST_MOTOR_NUM_PROPERTIES
};
static GParamSpec* gom_serialization_test_motor_properties[GOM_SERIALIZATION_TEST_MOTOR_NUM_PROPERTIES];
typedef struct _GomSerializationTestMotorOnPrivate GomSerializationTestMotorOnPrivate;
enum  {
	GOM_SERIALIZATION_TEST_MOTOR_ON_0_PROPERTY,
	GOM_SERIALIZATION_TEST_MOTOR_ON_NUM_PROPERTIES
};
static GParamSpec* gom_serialization_test_motor_on_properties[GOM_SERIALIZATION_TEST_MOTOR_ON_NUM_PROPERTIES];
typedef struct _GomSerializationTestMotorTorquePrivate GomSerializationTestMotorTorquePrivate;
enum  {
	GOM_SERIALIZATION_TEST_MOTOR_TORQUE_0_PROPERTY,
	GOM_SERIALIZATION_TEST_MOTOR_TORQUE_NUM_PROPERTIES
};
static GParamSpec* gom_serialization_test_motor_torque_properties[GOM_SERIALIZATION_TEST_MOTOR_TORQUE_NUM_PROPERTIES];
typedef struct _GomSerializationTestMotorSpeedPrivate GomSerializationTestMotorSpeedPrivate;
enum  {
	GOM_SERIALIZATION_TEST_MOTOR_SPEED_0_PROPERTY,
	GOM_SERIALIZATION_TEST_MOTOR_SPEED_NUM_PROPERTIES
};
static GParamSpec* gom_serialization_test_motor_speed_properties[GOM_SERIALIZATION_TEST_MOTOR_SPEED_NUM_PROPERTIES];
typedef struct _GomSerializationTestMotorTensionTypePrivate GomSerializationTestMotorTensionTypePrivate;
enum  {
	GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_0_PROPERTY,
	GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_NUM_PROPERTIES
};
static GParamSpec* gom_serialization_test_motor_tension_type_properties[GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_NUM_PROPERTIES];
typedef struct _GomSerializationTestMotorTensionPrivate GomSerializationTestMotorTensionPrivate;
enum  {
	GOM_SERIALIZATION_TEST_MOTOR_TENSION_0_PROPERTY,
	GOM_SERIALIZATION_TEST_MOTOR_TENSION_NUM_PROPERTIES
};
static GParamSpec* gom_serialization_test_motor_tension_properties[GOM_SERIALIZATION_TEST_MOTOR_TENSION_NUM_PROPERTIES];
typedef struct _GomSerializationTestMotorModelPrivate GomSerializationTestMotorModelPrivate;
enum  {
	GOM_SERIALIZATION_TEST_MOTOR_MODEL_0_PROPERTY,
	GOM_SERIALIZATION_TEST_MOTOR_MODEL_NUM_PROPERTIES
};
static GParamSpec* gom_serialization_test_motor_model_properties[GOM_SERIALIZATION_TEST_MOTOR_MODEL_NUM_PROPERTIES];
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _ThreeKeys {
	GXmlGomElement parent_instance;
	ThreeKeysPrivate * priv;
};

struct _ThreeKeysClass {
	GXmlGomElementClass parent_class;
};

struct _ThreeKeysPrivate {
	ThreeKeyMap* _map;
};

struct _ThreeKey {
	GXmlGomElement parent_instance;
	ThreeKeyPrivate * priv;
};

struct _ThreeKeyClass {
	GXmlGomElementClass parent_class;
};

struct _ThreeKeyPrivate {
	gchar* _id;
	gchar* _code;
	gchar* _name;
};

struct _ThreeKeyMap {
	GXmlGomHashThreeMap parent_instance;
	ThreeKeyMapPrivate * priv;
};

struct _ThreeKeyMapClass {
	GXmlGomHashThreeMapClass parent_class;
};

struct _Operations {
	GXmlGomElement parent_instance;
	OperationsPrivate * priv;
};

struct _OperationsClass {
	GXmlGomElementClass parent_class;
};

struct _OperationsPrivate {
	OperationMap* _map;
};

struct _Operation {
	GXmlGomElement parent_instance;
	OperationPrivate * priv;
};

struct _OperationClass {
	GXmlGomElementClass parent_class;
};

struct _OperationPrivate {
	gchar* _id;
	gchar* _code;
};

struct _OperationMap {
	GXmlGomHashPairedMap parent_instance;
	OperationMapPrivate * priv;
};

struct _OperationMapClass {
	GXmlGomHashPairedMapClass parent_class;
};

struct _GomName {
	GXmlGomElement parent_instance;
	GomNamePrivate * priv;
};

struct _GomNameClass {
	GXmlGomElementClass parent_class;
};

struct _GomEmail {
	GXmlGomElement parent_instance;
	GomEmailPrivate * priv;
};

struct _GomEmailClass {
	GXmlGomElementClass parent_class;
};

struct _GomAuthor {
	GXmlGomElement parent_instance;
	GomAuthorPrivate * priv;
};

struct _GomAuthorClass {
	GXmlGomElementClass parent_class;
};

struct _GomAuthorPrivate {
	GomName* _name;
	GomEmail* _email;
};

struct _GomAuthorArray {
	GXmlGomArrayList parent_instance;
	GomAuthorArrayPrivate * priv;
};

struct _GomAuthorArrayClass {
	GXmlGomArrayListClass parent_class;
};

struct _GomAuthors {
	GXmlGomElement parent_instance;
	GomAuthorsPrivate * priv;
};

struct _GomAuthorsClass {
	GXmlGomElementClass parent_class;
};

struct _GomAuthorsPrivate {
	gchar* _number;
	GomAuthorArray* _array;
};

struct _GomInventory {
	GXmlGomElement parent_instance;
	GomInventoryPrivate * priv;
};

struct _GomInventoryClass {
	GXmlGomElementClass parent_class;
};

struct _GomInventoryPrivate {
	gint _number;
	gint _row;
	gchar* _inventory;
};

struct _GomInventoryDualKeyMap {
	GXmlGomHashMap parent_instance;
	GomInventoryDualKeyMapPrivate * priv;
};

struct _GomInventoryDualKeyMapClass {
	GXmlGomHashMapClass parent_class;
};

struct _GomCategory {
	GXmlGomElement parent_instance;
	GomCategoryPrivate * priv;
};

struct _GomCategoryClass {
	GXmlGomElementClass parent_class;
};

struct _GomCategoryPrivate {
	gchar* _name;
};

struct _GomCategoryMap {
	GXmlGomHashMap parent_instance;
	GomCategoryMapPrivate * priv;
};

struct _GomCategoryMapClass {
	GXmlGomHashMapClass parent_class;
};

struct _GomResume {
	GXmlGomElement parent_instance;
	GomResumePrivate * priv;
};

struct _GomResumeClass {
	GXmlGomElementClass parent_class;
};

struct _GomResumePrivate {
	gchar* _chapter;
	gchar* _text;
};

struct _GomResumeMap {
	GXmlGomHashMap parent_instance;
	GomResumeMapPrivate * priv;
};

struct _GomResumeMapClass {
	GXmlGomHashMapClass parent_class;
};

struct _GomBook {
	GXmlGomElement parent_instance;
	GomBookPrivate * priv;
};

struct _GomBookClass {
	GXmlGomElementClass parent_class;
};

struct _GomBookPrivate {
	gchar* _year;
	gchar* _isbn;
	GomName* _name;
	GomAuthors* _authors;
	GomInventoryDualKeyMap* _inventory_registers;
	GomCategoryMap* _categories;
	GomResumeMap* _resumes;
};

struct _GomBookArray {
	GXmlGomArrayList parent_instance;
	GomBookArrayPrivate * priv;
};

struct _GomBookArrayClass {
	GXmlGomArrayListClass parent_class;
};

struct _GomBookStore {
	GXmlGomElement parent_instance;
	GomBookStorePrivate * priv;
};

struct _GomBookStoreClass {
	GXmlGomElementClass parent_class;
};

struct _GomBookStorePrivate {
	gchar* _name;
	GomBookArray* _books;
};

struct _GomBasicTypes {
	GXmlGomElement parent_instance;
	GomBasicTypesPrivate * priv;
};

struct _GomBasicTypesClass {
	GXmlGomElementClass parent_class;
};

struct _GomBasicTypesPrivate {
	gchar* _text;
	gint _integer;
	gdouble _real_double;
	gfloat _real_float;
	guint _unsigned_integer;
	gboolean _boolean;
};

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _GomSerializationTest {
	GXmlTest parent_instance;
	GomSerializationTestPrivate * priv;
};

struct _GomSerializationTestClass {
	GXmlTestClass parent_class;
};

struct _GomSerializationTestBook {
	GXmlGomElement parent_instance;
	GomSerializationTestBookPrivate * priv;
};

struct _GomSerializationTestBookClass {
	GXmlGomElementClass parent_class;
};

struct _GomSerializationTestBookPrivate {
	gchar* _name;
};

struct _GomSerializationTestComputer {
	GXmlGomElement parent_instance;
	GomSerializationTestComputerPrivate * priv;
};

struct _GomSerializationTestComputerClass {
	GXmlGomElementClass parent_class;
};

struct _GomSerializationTestComputerPrivate {
	gchar* _model;
	gchar* _ignore;
};

struct _GomSerializationTestTaxes {
	GXmlGomElement parent_instance;
	GomSerializationTestTaxesPrivate * priv;
};

struct _GomSerializationTestTaxesClass {
	GXmlGomElementClass parent_class;
};

struct _GomSerializationTestTaxesPrivate {
	gdouble _month_rate;
	gboolean _tax_free;
	GomSerializationTestTaxesMonth _month;
	GXmlGomDate* _pay_date;
	GXmlGomDateTime* _timestamp;
};

struct _GomSerializationTestBookRegister {
	GXmlGomElement parent_instance;
	GomSerializationTestBookRegisterPrivate * priv;
};

struct _GomSerializationTestBookRegisterClass {
	GXmlGomElementClass parent_class;
};

struct _GomSerializationTestBookRegisterPrivate {
	GomSerializationTestBook* _book;
	gint _year;
	gchar* _cover;
};

struct _GomSerializationTestBookStand {
	GXmlGomElement parent_instance;
	GomSerializationTestBookStandPrivate * priv;
};

struct _GomSerializationTestBookStandClass {
	GXmlGomElementClass parent_class;
};

struct _GomSerializationTestBookStandPrivate {
	GomSerializationTestHashRegisters* _hashmap_registers;
	GomSerializationTestHashPairRegisters* _hashpair_registers;
	GomSerializationTestHashThreeRegisters* _hashthree_registers;
	gchar* _classification;
	GomSerializationTestBookStandDimension* _dimension_x;
	GomSerializationTestBookStandDimensionY* _dimension_y;
	GomSerializationTestBookStandDimensionZ* _dimension_z;
	GomSerializationTestRegisters* _registers;
	GomSerializationTestBooks* _books;
};

struct _GomSerializationTestBookStandDimension {
	GXmlGomElement parent_instance;
	GomSerializationTestBookStandDimensionPrivate * priv;
};

struct _GomSerializationTestBookStandDimensionClass {
	GXmlGomElementClass parent_class;
};

struct _GomSerializationTestBookStandDimensionPrivate {
	gdouble _length;
	gchar* _dtype;
};

struct _GomSerializationTestBookStandDimensionY {
	GomSerializationTestBookStandDimension parent_instance;
	GomSerializationTestBookStandDimensionYPrivate * priv;
};

struct _GomSerializationTestBookStandDimensionYClass {
	GomSerializationTestBookStandDimensionClass parent_class;
};

struct _GomSerializationTestBookStandDimensionZ {
	GomSerializationTestBookStandDimension parent_instance;
	GomSerializationTestBookStandDimensionZPrivate * priv;
};

struct _GomSerializationTestBookStandDimensionZClass {
	GomSerializationTestBookStandDimensionClass parent_class;
};

struct _GomSerializationTestRegisters {
	GXmlGomArrayList parent_instance;
	GomSerializationTestRegistersPrivate * priv;
};

struct _GomSerializationTestRegistersClass {
	GXmlGomArrayListClass parent_class;
};

struct _GomSerializationTestHashRegisters {
	GXmlGomHashMap parent_instance;
	GomSerializationTestHashRegistersPrivate * priv;
};

struct _GomSerializationTestHashRegistersClass {
	GXmlGomHashMapClass parent_class;
};

struct _GomSerializationTestHashPairRegisters {
	GXmlGomHashPairedMap parent_instance;
	GomSerializationTestHashPairRegistersPrivate * priv;
};

struct _GomSerializationTestHashPairRegistersClass {
	GXmlGomHashPairedMapClass parent_class;
};

struct _GomSerializationTestHashThreeRegisters {
	GXmlGomHashThreeMap parent_instance;
	GomSerializationTestHashThreeRegistersPrivate * priv;
};

struct _GomSerializationTestHashThreeRegistersClass {
	GXmlGomHashThreeMapClass parent_class;
};

struct _GomSerializationTestBooks {
	GXmlGomHashMap parent_instance;
	GomSerializationTestBooksPrivate * priv;
};

struct _GomSerializationTestBooksClass {
	GXmlGomHashMapClass parent_class;
};

struct _GomSerializationTestBookStore {
	GXmlGomElement parent_instance;
	GomSerializationTestBookStorePrivate * priv;
};

struct _GomSerializationTestBookStoreClass {
	GXmlGomElementClass parent_class;
};

struct _GomSerializationTestBookStorePrivate {
	gchar* _name;
	GomSerializationTestBooks* _books;
};

struct _GomSerializationTestMotor {
	GXmlGomElement parent_instance;
	GomSerializationTestMotorPrivate * priv;
};

struct _GomSerializationTestMotorClass {
	GXmlGomElementClass parent_class;
};

struct _GomSerializationTestMotorPrivate {
	GomSerializationTestMotorOn* _is_on;
	GomSerializationTestMotorTorque* _torque;
	GomSerializationTestMotorSpeed* _speed;
	GomSerializationTestMotorTensionType* _tension_type;
	GomSerializationTestMotorTension* _tension;
	GomSerializationTestMotorModel* _model;
};

struct _GomSerializationTestMotorOn {
	GXmlGomBoolean parent_instance;
	GomSerializationTestMotorOnPrivate * priv;
};

struct _GomSerializationTestMotorOnClass {
	GXmlGomBooleanClass parent_class;
};

struct _GomSerializationTestMotorTorque {
	GXmlGomDouble parent_instance;
	GomSerializationTestMotorTorquePrivate * priv;
};

struct _GomSerializationTestMotorTorqueClass {
	GXmlGomDoubleClass parent_class;
};

struct _GomSerializationTestMotorSpeed {
	GXmlGomFloat parent_instance;
	GomSerializationTestMotorSpeedPrivate * priv;
};

struct _GomSerializationTestMotorSpeedClass {
	GXmlGomFloatClass parent_class;
};

struct _GomSerializationTestMotorTensionType {
	GXmlGomEnum parent_instance;
	GomSerializationTestMotorTensionTypePrivate * priv;
};

struct _GomSerializationTestMotorTensionTypeClass {
	GXmlGomEnumClass parent_class;
};

struct _GomSerializationTestMotorTension {
	GXmlGomInt parent_instance;
	GomSerializationTestMotorTensionPrivate * priv;
};

struct _GomSerializationTestMotorTensionClass {
	GXmlGomIntClass parent_class;
};

struct _GomSerializationTestMotorModel {
	GXmlGomArrayString parent_instance;
	GomSerializationTestMotorModelPrivate * priv;
};

struct _GomSerializationTestMotorModelClass {
	GXmlGomArrayStringClass parent_class;
};

static gint ThreeKeys_private_offset;
static gpointer three_keys_parent_class = NULL;
static gint ThreeKey_private_offset;
static gpointer three_key_parent_class = NULL;
static gpointer three_key_map_parent_class = NULL;
static GXmlMappeableElementThreeKeyIface * three_key_gxml_mappeable_element_three_key_parent_iface = NULL;
static gint Operations_private_offset;
static gpointer operations_parent_class = NULL;
static gint Operation_private_offset;
static gpointer operation_parent_class = NULL;
static gpointer operation_map_parent_class = NULL;
static GXmlMappeableElementPairKeyIface * operation_gxml_mappeable_element_pair_key_parent_iface = NULL;
static gpointer gom_name_parent_class = NULL;
static gpointer gom_email_parent_class = NULL;
static gint GomAuthor_private_offset;
static gpointer gom_author_parent_class = NULL;
static gpointer gom_author_array_parent_class = NULL;
static gint GomAuthors_private_offset;
static gpointer gom_authors_parent_class = NULL;
static gint GomInventory_private_offset;
static gpointer gom_inventory_parent_class = NULL;
static gpointer gom_inventory_dual_key_map_parent_class = NULL;
static gint GomCategory_private_offset;
static gpointer gom_category_parent_class = NULL;
static gpointer gom_category_map_parent_class = NULL;
static gint GomResume_private_offset;
static gpointer gom_resume_parent_class = NULL;
static gpointer gom_resume_map_parent_class = NULL;
static gint GomBook_private_offset;
static gpointer gom_book_parent_class = NULL;
static gpointer gom_book_array_parent_class = NULL;
static gint GomBookStore_private_offset;
static gpointer gom_book_store_parent_class = NULL;
static gint GomBasicTypes_private_offset;
static gpointer gom_basic_types_parent_class = NULL;
static gpointer gom_serialization_test_parent_class = NULL;
static gint GomSerializationTestBook_private_offset;
static gpointer gom_serialization_test_book_parent_class = NULL;
static gint GomSerializationTestComputer_private_offset;
static gpointer gom_serialization_test_computer_parent_class = NULL;
static gint GomSerializationTestTaxes_private_offset;
static gpointer gom_serialization_test_taxes_parent_class = NULL;
static gint GomSerializationTestBookRegister_private_offset;
static gpointer gom_serialization_test_book_register_parent_class = NULL;
static GXmlMappeableElementIface * gom_serialization_test_book_register_gxml_mappeable_element_parent_iface = NULL;
static GXmlMappeableElementPairKeyIface * gom_serialization_test_book_register_gxml_mappeable_element_pair_key_parent_iface = NULL;
static GXmlMappeableElementThreeKeyIface * gom_serialization_test_book_register_gxml_mappeable_element_three_key_parent_iface = NULL;
static gint GomSerializationTestBookStand_private_offset;
static gpointer gom_serialization_test_book_stand_parent_class = NULL;
static gint GomSerializationTestBookStandDimension_private_offset;
static gpointer gom_serialization_test_book_stand_dimension_parent_class = NULL;
static gpointer gom_serialization_test_book_stand_dimension_y_parent_class = NULL;
static gpointer gom_serialization_test_book_stand_dimension_z_parent_class = NULL;
static gpointer gom_serialization_test_registers_parent_class = NULL;
static gpointer gom_serialization_test_hash_registers_parent_class = NULL;
static gpointer gom_serialization_test_hash_pair_registers_parent_class = NULL;
static gpointer gom_serialization_test_hash_three_registers_parent_class = NULL;
static gpointer gom_serialization_test_books_parent_class = NULL;
static gint GomSerializationTestBookStore_private_offset;
static gpointer gom_serialization_test_book_store_parent_class = NULL;
static gint GomSerializationTestMotor_private_offset;
static gpointer gom_serialization_test_motor_parent_class = NULL;
static gpointer gom_serialization_test_motor_on_parent_class = NULL;
static gpointer gom_serialization_test_motor_torque_parent_class = NULL;
static gpointer gom_serialization_test_motor_speed_parent_class = NULL;
static gpointer gom_serialization_test_motor_tension_type_parent_class = NULL;
static gpointer gom_serialization_test_motor_tension_parent_class = NULL;
static gpointer gom_serialization_test_motor_model_parent_class = NULL;

GType three_keys_get_type (void) G_GNUC_CONST;
GType three_key_map_get_type (void) G_GNUC_CONST;
ThreeKeys* three_keys_new (void);
ThreeKeys* three_keys_construct (GType object_type);
ThreeKeyMap* three_keys_get_map (ThreeKeys* self);
void three_keys_set_map (ThreeKeys* self,
                         ThreeKeyMap* value);
static GObject * three_keys_constructor (GType type,
                                  guint n_construct_properties,
                                  GObjectConstructParam * construct_properties);
static void three_keys_finalize (GObject * obj);
static void _vala_three_keys_get_property (GObject * object,
                                    guint property_id,
                                    GValue * value,
                                    GParamSpec * pspec);
static void _vala_three_keys_set_property (GObject * object,
                                    guint property_id,
                                    const GValue * value,
                                    GParamSpec * pspec);
GType three_key_get_type (void) G_GNUC_CONST;
static gchar* three_key_real_get_map_pkey (GXmlMappeableElementThreeKey* base);
const gchar* three_key_get_id (ThreeKey* self);
static gchar* three_key_real_get_map_skey (GXmlMappeableElementThreeKey* base);
const gchar* three_key_get_code (ThreeKey* self);
static gchar* three_key_real_get_map_tkey (GXmlMappeableElementThreeKey* base);
const gchar* three_key_get_name (ThreeKey* self);
ThreeKey* three_key_new (void);
ThreeKey* three_key_construct (GType object_type);
void three_key_set_id (ThreeKey* self,
                       const gchar* value);
void three_key_set_code (ThreeKey* self,
                         const gchar* value);
void three_key_set_name (ThreeKey* self,
                         const gchar* value);
static GObject * three_key_constructor (GType type,
                                 guint n_construct_properties,
                                 GObjectConstructParam * construct_properties);
ThreeKeyMap* three_key_map_new (void);
ThreeKeyMap* three_key_map_construct (GType object_type);
static GObject * three_key_map_constructor (GType type,
                                     guint n_construct_properties,
                                     GObjectConstructParam * construct_properties);
static void three_key_finalize (GObject * obj);
static void _vala_three_key_get_property (GObject * object,
                                   guint property_id,
                                   GValue * value,
                                   GParamSpec * pspec);
static void _vala_three_key_set_property (GObject * object,
                                   guint property_id,
                                   const GValue * value,
                                   GParamSpec * pspec);
GType operations_get_type (void) G_GNUC_CONST;
GType operation_map_get_type (void) G_GNUC_CONST;
Operations* operations_new (void);
Operations* operations_construct (GType object_type);
OperationMap* operations_get_map (Operations* self);
void operations_set_map (Operations* self,
                         OperationMap* value);
static GObject * operations_constructor (GType type,
                                  guint n_construct_properties,
                                  GObjectConstructParam * construct_properties);
static void operations_finalize (GObject * obj);
static void _vala_operations_get_property (GObject * object,
                                    guint property_id,
                                    GValue * value,
                                    GParamSpec * pspec);
static void _vala_operations_set_property (GObject * object,
                                    guint property_id,
                                    const GValue * value,
                                    GParamSpec * pspec);
GType operation_get_type (void) G_GNUC_CONST;
static gchar* operation_real_get_map_primary_key (GXmlMappeableElementPairKey* base);
const gchar* operation_get_id (Operation* self);
static gchar* operation_real_get_map_secondary_key (GXmlMappeableElementPairKey* base);
const gchar* operation_get_code (Operation* self);
Operation* operation_new (void);
Operation* operation_construct (GType object_type);
void operation_set_id (Operation* self,
                       const gchar* value);
void operation_set_code (Operation* self,
                         const gchar* value);
static GObject * operation_constructor (GType type,
                                 guint n_construct_properties,
                                 GObjectConstructParam * construct_properties);
OperationMap* operation_map_new (void);
OperationMap* operation_map_construct (GType object_type);
static GObject * operation_map_constructor (GType type,
                                     guint n_construct_properties,
                                     GObjectConstructParam * construct_properties);
static void operation_finalize (GObject * obj);
static void _vala_operation_get_property (GObject * object,
                                   guint property_id,
                                   GValue * value,
                                   GParamSpec * pspec);
static void _vala_operation_set_property (GObject * object,
                                   guint property_id,
                                   const GValue * value,
                                   GParamSpec * pspec);
GType gom_name_get_type (void) G_GNUC_CONST;
GomName* gom_name_new (void);
GomName* gom_name_construct (GType object_type);
static GObject * gom_name_constructor (GType type,
                                guint n_construct_properties,
                                GObjectConstructParam * construct_properties);
GType gom_email_get_type (void) G_GNUC_CONST;
GomEmail* gom_email_new (void);
GomEmail* gom_email_construct (GType object_type);
static GObject * gom_email_constructor (GType type,
                                 guint n_construct_properties,
                                 GObjectConstructParam * construct_properties);
GType gom_author_get_type (void) G_GNUC_CONST;
GomAuthor* gom_author_new (void);
GomAuthor* gom_author_construct (GType object_type);
GomName* gom_author_get_name (GomAuthor* self);
void gom_author_set_name (GomAuthor* self,
                          GomName* value);
GomEmail* gom_author_get_email (GomAuthor* self);
void gom_author_set_email (GomAuthor* self,
                           GomEmail* value);
static GObject * gom_author_constructor (GType type,
                                  guint n_construct_properties,
                                  GObjectConstructParam * construct_properties);
GType gom_author_array_get_type (void) G_GNUC_CONST;
GomAuthorArray* gom_author_array_new (void);
GomAuthorArray* gom_author_array_construct (GType object_type);
static GObject * gom_author_array_constructor (GType type,
                                        guint n_construct_properties,
                                        GObjectConstructParam * construct_properties);
static void gom_author_finalize (GObject * obj);
static void _vala_gom_author_get_property (GObject * object,
                                    guint property_id,
                                    GValue * value,
                                    GParamSpec * pspec);
static void _vala_gom_author_set_property (GObject * object,
                                    guint property_id,
                                    const GValue * value,
                                    GParamSpec * pspec);
GType gom_authors_get_type (void) G_GNUC_CONST;
GomAuthors* gom_authors_new (void);
GomAuthors* gom_authors_construct (GType object_type);
const gchar* gom_authors_get_number (GomAuthors* self);
void gom_authors_set_number (GomAuthors* self,
                             const gchar* value);
GomAuthorArray* gom_authors_get_array (GomAuthors* self);
void gom_authors_set_array (GomAuthors* self,
                            GomAuthorArray* value);
static GObject * gom_authors_constructor (GType type,
                                   guint n_construct_properties,
                                   GObjectConstructParam * construct_properties);
static void gom_authors_finalize (GObject * obj);
static void _vala_gom_authors_get_property (GObject * object,
                                     guint property_id,
                                     GValue * value,
                                     GParamSpec * pspec);
static void _vala_gom_authors_set_property (GObject * object,
                                     guint property_id,
                                     const GValue * value,
                                     GParamSpec * pspec);
GType gom_inventory_get_type (void) G_GNUC_CONST;
GomInventory* gom_inventory_new (void);
GomInventory* gom_inventory_construct (GType object_type);
gint gom_inventory_get_number (GomInventory* self);
void gom_inventory_set_number (GomInventory* self,
                               gint value);
gint gom_inventory_get_row (GomInventory* self);
void gom_inventory_set_row (GomInventory* self,
                            gint value);
const gchar* gom_inventory_get_inventory (GomInventory* self);
void gom_inventory_set_inventory (GomInventory* self,
                                  const gchar* value);
static GObject * gom_inventory_constructor (GType type,
                                     guint n_construct_properties,
                                     GObjectConstructParam * construct_properties);
GType gom_inventory_dual_key_map_get_type (void) G_GNUC_CONST;
GomInventoryDualKeyMap* gom_inventory_dual_key_map_new (void);
GomInventoryDualKeyMap* gom_inventory_dual_key_map_construct (GType object_type);
static GObject * gom_inventory_dual_key_map_constructor (GType type,
                                                  guint n_construct_properties,
                                                  GObjectConstructParam * construct_properties);
static void gom_inventory_finalize (GObject * obj);
static void _vala_gom_inventory_get_property (GObject * object,
                                       guint property_id,
                                       GValue * value,
                                       GParamSpec * pspec);
static void _vala_gom_inventory_set_property (GObject * object,
                                       guint property_id,
                                       const GValue * value,
                                       GParamSpec * pspec);
GType gom_category_get_type (void) G_GNUC_CONST;
GomCategory* gom_category_new (void);
GomCategory* gom_category_construct (GType object_type);
const gchar* gom_category_get_name (GomCategory* self);
void gom_category_set_name (GomCategory* self,
                            const gchar* value);
static GObject * gom_category_constructor (GType type,
                                    guint n_construct_properties,
                                    GObjectConstructParam * construct_properties);
GType gom_category_map_get_type (void) G_GNUC_CONST;
GomCategoryMap* gom_category_map_new (void);
GomCategoryMap* gom_category_map_construct (GType object_type);
static GObject * gom_category_map_constructor (GType type,
                                        guint n_construct_properties,
                                        GObjectConstructParam * construct_properties);
static void gom_category_finalize (GObject * obj);
static void _vala_gom_category_get_property (GObject * object,
                                      guint property_id,
                                      GValue * value,
                                      GParamSpec * pspec);
static void _vala_gom_category_set_property (GObject * object,
                                      guint property_id,
                                      const GValue * value,
                                      GParamSpec * pspec);
GType gom_resume_get_type (void) G_GNUC_CONST;
GomResume* gom_resume_new (void);
GomResume* gom_resume_construct (GType object_type);
const gchar* gom_resume_get_chapter (GomResume* self);
void gom_resume_set_chapter (GomResume* self,
                             const gchar* value);
const gchar* gom_resume_get_text (GomResume* self);
void gom_resume_set_text (GomResume* self,
                          const gchar* value);
static GObject * gom_resume_constructor (GType type,
                                  guint n_construct_properties,
                                  GObjectConstructParam * construct_properties);
GType gom_resume_map_get_type (void) G_GNUC_CONST;
GomResumeMap* gom_resume_map_new (void);
GomResumeMap* gom_resume_map_construct (GType object_type);
static GObject * gom_resume_map_constructor (GType type,
                                      guint n_construct_properties,
                                      GObjectConstructParam * construct_properties);
static void gom_resume_finalize (GObject * obj);
static void _vala_gom_resume_get_property (GObject * object,
                                    guint property_id,
                                    GValue * value,
                                    GParamSpec * pspec);
static void _vala_gom_resume_set_property (GObject * object,
                                    guint property_id,
                                    const GValue * value,
                                    GParamSpec * pspec);
GType gom_book_get_type (void) G_GNUC_CONST;
GomBook* gom_book_new (void);
GomBook* gom_book_construct (GType object_type);
const gchar* gom_book_get_year (GomBook* self);
void gom_book_set_year (GomBook* self,
                        const gchar* value);
const gchar* gom_book_get_isbn (GomBook* self);
void gom_book_set_isbn (GomBook* self,
                        const gchar* value);
GomName* gom_book_get_name (GomBook* self);
void gom_book_set_name (GomBook* self,
                        GomName* value);
GomAuthors* gom_book_get_authors (GomBook* self);
void gom_book_set_authors (GomBook* self,
                           GomAuthors* value);
GomInventoryDualKeyMap* gom_book_get_inventory_registers (GomBook* self);
void gom_book_set_inventory_registers (GomBook* self,
                                       GomInventoryDualKeyMap* value);
GomCategoryMap* gom_book_get_categories (GomBook* self);
void gom_book_set_categories (GomBook* self,
                              GomCategoryMap* value);
GomResumeMap* gom_book_get_resumes (GomBook* self);
void gom_book_set_resumes (GomBook* self,
                           GomResumeMap* value);
static GObject * gom_book_constructor (GType type,
                                guint n_construct_properties,
                                GObjectConstructParam * construct_properties);
GType gom_book_array_get_type (void) G_GNUC_CONST;
GomBookArray* gom_book_array_new (void);
GomBookArray* gom_book_array_construct (GType object_type);
static GObject * gom_book_array_constructor (GType type,
                                      guint n_construct_properties,
                                      GObjectConstructParam * construct_properties);
static void gom_book_finalize (GObject * obj);
static void _vala_gom_book_get_property (GObject * object,
                                  guint property_id,
                                  GValue * value,
                                  GParamSpec * pspec);
static void _vala_gom_book_set_property (GObject * object,
                                  guint property_id,
                                  const GValue * value,
                                  GParamSpec * pspec);
GType gom_book_store_get_type (void) G_GNUC_CONST;
GomBookStore* gom_book_store_new (void);
GomBookStore* gom_book_store_construct (GType object_type);
const gchar* gom_book_store_get_name (GomBookStore* self);
void gom_book_store_set_name (GomBookStore* self,
                              const gchar* value);
GomBookArray* gom_book_store_get_books (GomBookStore* self);
void gom_book_store_set_books (GomBookStore* self,
                               GomBookArray* value);
static GObject * gom_book_store_constructor (GType type,
                                      guint n_construct_properties,
                                      GObjectConstructParam * construct_properties);
static void gom_book_store_finalize (GObject * obj);
static void _vala_gom_book_store_get_property (GObject * object,
                                        guint property_id,
                                        GValue * value,
                                        GParamSpec * pspec);
static void _vala_gom_book_store_set_property (GObject * object,
                                        guint property_id,
                                        const GValue * value,
                                        GParamSpec * pspec);
GType gom_basic_types_get_type (void) G_GNUC_CONST;
GomBasicTypes* gom_basic_types_new (void);
GomBasicTypes* gom_basic_types_construct (GType object_type);
const gchar* gom_basic_types_get_text (GomBasicTypes* self);
void gom_basic_types_set_text (GomBasicTypes* self,
                               const gchar* value);
gint gom_basic_types_get_integer (GomBasicTypes* self);
void gom_basic_types_set_integer (GomBasicTypes* self,
                                  gint value);
gdouble gom_basic_types_get_real_double (GomBasicTypes* self);
void gom_basic_types_set_real_double (GomBasicTypes* self,
                                      gdouble value);
gfloat gom_basic_types_get_real_float (GomBasicTypes* self);
void gom_basic_types_set_real_float (GomBasicTypes* self,
                                     gfloat value);
guint gom_basic_types_get_unsigned_integer (GomBasicTypes* self);
void gom_basic_types_set_unsigned_integer (GomBasicTypes* self,
                                           guint value);
gboolean gom_basic_types_get_boolean (GomBasicTypes* self);
void gom_basic_types_set_boolean (GomBasicTypes* self,
                                  gboolean value);
static GObject * gom_basic_types_constructor (GType type,
                                       guint n_construct_properties,
                                       GObjectConstructParam * construct_properties);
static void gom_basic_types_finalize (GObject * obj);
static void _vala_gom_basic_types_get_property (GObject * object,
                                         guint property_id,
                                         GValue * value,
                                         GParamSpec * pspec);
static void _vala_gom_basic_types_set_property (GObject * object,
                                         guint property_id,
                                         const GValue * value,
                                         GParamSpec * pspec);
gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType gom_serialization_test_get_type (void) G_GNUC_CONST;
void gom_serialization_test_add_tests (void);
static void __lambda119_ (void);
GType gom_serialization_test_book_get_type (void) G_GNUC_CONST;
GomSerializationTestBook* gom_serialization_test_book_new (void);
GomSerializationTestBook* gom_serialization_test_book_construct (GType object_type);
void gom_serialization_test_book_set_name (GomSerializationTestBook* self,
                                           const gchar* value);
gchar* gom_serialization_test_book_to_string (GomSerializationTestBook* self);
static void ___lambda119__gtest_func (void);
static void __lambda120_ (void);
GType gom_serialization_test_computer_get_type (void) G_GNUC_CONST;
GomSerializationTestComputer* gom_serialization_test_computer_new (void);
GomSerializationTestComputer* gom_serialization_test_computer_construct (GType object_type);
gchar* gom_serialization_test_computer_to_string (GomSerializationTestComputer* self);
void gom_serialization_test_computer_set_model (GomSerializationTestComputer* self,
                                                const gchar* value);
void gom_serialization_test_computer_set_ignore (GomSerializationTestComputer* self,
                                                 const gchar* value);
const gchar* gom_serialization_test_computer_get_model (GomSerializationTestComputer* self);
const gchar* gom_serialization_test_computer_get_ignore (GomSerializationTestComputer* self);
static void ___lambda120__gtest_func (void);
static void __lambda121_ (void);
GType gom_serialization_test_taxes_get_type (void) G_GNUC_CONST;
GomSerializationTestTaxes* gom_serialization_test_taxes_new (void);
GomSerializationTestTaxes* gom_serialization_test_taxes_construct (GType object_type);
gchar* gom_serialization_test_taxes_to_string (GomSerializationTestTaxes* self);
void gom_serialization_test_taxes_set_month_rate (GomSerializationTestTaxes* self,
                                                  gdouble value);
gdouble gom_serialization_test_taxes_get_month_rate (GomSerializationTestTaxes* self);
GType gom_serialization_test_taxes_month_get_type (void) G_GNUC_CONST;
void gom_serialization_test_taxes_set_month (GomSerializationTestTaxes* self,
                                             GomSerializationTestTaxesMonth value);
GomSerializationTestTaxesMonth gom_serialization_test_taxes_get_month (GomSerializationTestTaxes* self);
void gom_serialization_test_taxes_set_tax_free (GomSerializationTestTaxes* self,
                                                gboolean value);
gboolean gom_serialization_test_taxes_get_tax_free (GomSerializationTestTaxes* self);
static void ___lambda121__gtest_func (void);
static void __lambda122_ (void);
void gom_serialization_test_taxes_set_pay_date (GomSerializationTestTaxes* self,
                                                GXmlGomDate* value);
GXmlGomDate* gom_serialization_test_taxes_get_pay_date (GomSerializationTestTaxes* self);
static void ___lambda122__gtest_func (void);
static void __lambda123_ (void);
static void ___lambda123__gtest_func (void);
static void __lambda124_ (void);
void gom_serialization_test_taxes_set_timestamp (GomSerializationTestTaxes* self,
                                                 GXmlGomDateTime* value);
GXmlGomDateTime* gom_serialization_test_taxes_get_timestamp (GomSerializationTestTaxes* self);
static void ___lambda124__gtest_func (void);
static void __lambda125_ (void);
GType gom_serialization_test_book_stand_get_type (void) G_GNUC_CONST;
GomSerializationTestBookStand* gom_serialization_test_book_stand_new (void);
GomSerializationTestBookStand* gom_serialization_test_book_stand_construct (GType object_type);
gchar* gom_serialization_test_book_stand_to_string (GomSerializationTestBookStand* self);
GType gom_serialization_test_registers_get_type (void) G_GNUC_CONST;
GomSerializationTestRegisters* gom_serialization_test_book_stand_get_registers (GomSerializationTestBookStand* self);
GType gom_serialization_test_book_register_get_type (void) G_GNUC_CONST;
GomSerializationTestBookRegister* gom_serialization_test_book_register_new (void);
GomSerializationTestBookRegister* gom_serialization_test_book_register_construct (GType object_type);
void gom_serialization_test_book_register_set_year (GomSerializationTestBookRegister* self,
                                                    gint value);
gint gom_serialization_test_book_register_get_year (GomSerializationTestBookRegister* self);
GType gom_serialization_test_book_stand_dimension_get_type (void) G_GNUC_CONST;
GomSerializationTestBookStandDimension* gom_serialization_test_book_stand_get_dimension_x (GomSerializationTestBookStand* self);
gdouble gom_serialization_test_book_stand_dimension_get_length (GomSerializationTestBookStandDimension* self);
GType gom_serialization_test_book_stand_dimension_y_get_type (void) G_GNUC_CONST;
GomSerializationTestBookStandDimensionY* gom_serialization_test_book_stand_get_dimension_y (GomSerializationTestBookStand* self);
GType gom_serialization_test_book_stand_dimension_z_get_type (void) G_GNUC_CONST;
GomSerializationTestBookStandDimensionZ* gom_serialization_test_book_stand_get_dimension_z (GomSerializationTestBookStand* self);
static void ___lambda125__gtest_func (void);
static void __lambda126_ (void);
GType gom_serialization_test_book_store_get_type (void) G_GNUC_CONST;
GomSerializationTestBookStore* gom_serialization_test_book_store_new (void);
GomSerializationTestBookStore* gom_serialization_test_book_store_construct (GType object_type);
gchar* gom_serialization_test_book_store_to_string (GomSerializationTestBookStore* self);
GType gom_serialization_test_books_get_type (void) G_GNUC_CONST;
GomSerializationTestBooks* gom_serialization_test_book_store_get_books (GomSerializationTestBookStore* self);
GomSerializationTestBook* gom_serialization_test_book_new_document (GXmlDomDocument* doc);
GomSerializationTestBook* gom_serialization_test_book_construct_document (GType object_type,
                                                                          GXmlDomDocument* doc);
const gchar* gom_serialization_test_book_get_name (GomSerializationTestBook* self);
static void ___lambda126__gtest_func (void);
static void __lambda127_ (void);
GType gom_serialization_test_hash_registers_get_type (void) G_GNUC_CONST;
GomSerializationTestHashRegisters* gom_serialization_test_book_stand_get_hashmap_registers (GomSerializationTestBookStand* self);
GomSerializationTestBook* gom_serialization_test_book_register_create_book (GomSerializationTestBookRegister* self,
                                                                            const gchar* name);
void gom_serialization_test_book_register_set_book (GomSerializationTestBookRegister* self,
                                                    GomSerializationTestBook* value);
GomSerializationTestBook* gom_serialization_test_book_register_get_book (GomSerializationTestBookRegister* self);
static void ___lambda127__gtest_func (void);
static void __lambda128_ (void);
GType gom_serialization_test_hash_pair_registers_get_type (void) G_GNUC_CONST;
GomSerializationTestHashPairRegisters* gom_serialization_test_book_stand_get_hashpair_registers (GomSerializationTestBookStand* self);
static void ___lambda128__gtest_func (void);
static void __lambda129_ (void);
GType gom_serialization_test_hash_three_registers_get_type (void) G_GNUC_CONST;
GomSerializationTestHashThreeRegisters* gom_serialization_test_book_stand_get_hashthree_registers (GomSerializationTestBookStand* self);
void gom_serialization_test_book_register_set_cover (GomSerializationTestBookRegister* self,
                                                     const gchar* value);
const gchar* gom_serialization_test_book_register_get_cover (GomSerializationTestBookRegister* self);
static void ___lambda129__gtest_func (void);
static void __lambda130_ (void);
GType gom_serialization_test_motor_get_type (void) G_GNUC_CONST;
GomSerializationTestMotor* gom_serialization_test_motor_new (void);
GomSerializationTestMotor* gom_serialization_test_motor_construct (GType object_type);
gchar* gom_serialization_test_motor_to_string (GomSerializationTestMotor* self);
GomSerializationTestMotorOn* gom_serialization_test_motor_on_new (void);
GomSerializationTestMotorOn* gom_serialization_test_motor_on_construct (GType object_type);
GType gom_serialization_test_motor_on_get_type (void) G_GNUC_CONST;
void gom_serialization_test_motor_set_is_on (GomSerializationTestMotor* self,
                                             GomSerializationTestMotorOn* value);
GomSerializationTestMotorTorque* gom_serialization_test_motor_torque_new (void);
GomSerializationTestMotorTorque* gom_serialization_test_motor_torque_construct (GType object_type);
GType gom_serialization_test_motor_torque_get_type (void) G_GNUC_CONST;
void gom_serialization_test_motor_set_torque (GomSerializationTestMotor* self,
                                              GomSerializationTestMotorTorque* value);
GomSerializationTestMotorSpeed* gom_serialization_test_motor_speed_new (void);
GomSerializationTestMotorSpeed* gom_serialization_test_motor_speed_construct (GType object_type);
GType gom_serialization_test_motor_speed_get_type (void) G_GNUC_CONST;
void gom_serialization_test_motor_set_speed (GomSerializationTestMotor* self,
                                             GomSerializationTestMotorSpeed* value);
GomSerializationTestMotorSpeed* gom_serialization_test_motor_get_speed (GomSerializationTestMotor* self);
GType gom_serialization_test_motor_tension_type_get_type (void) G_GNUC_CONST;
GomSerializationTestMotorTensionType* gom_serialization_test_motor_get_tension_type (GomSerializationTestMotor* self);
GomSerializationTestMotorTensionType* gom_serialization_test_motor_tension_type_new (void);
GomSerializationTestMotorTensionType* gom_serialization_test_motor_tension_type_construct (GType object_type);
void gom_serialization_test_motor_set_tension_type (GomSerializationTestMotor* self,
                                                    GomSerializationTestMotorTensionType* value);
GomSerializationTestMotorTension* gom_serialization_test_motor_tension_new (void);
GomSerializationTestMotorTension* gom_serialization_test_motor_tension_construct (GType object_type);
GType gom_serialization_test_motor_tension_get_type (void) G_GNUC_CONST;
void gom_serialization_test_motor_set_tension (GomSerializationTestMotor* self,
                                               GomSerializationTestMotorTension* value);
GomSerializationTestMotorOn* gom_serialization_test_motor_get_is_on (GomSerializationTestMotor* self);
GomSerializationTestMotorTorque* gom_serialization_test_motor_get_torque (GomSerializationTestMotor* self);
GType gom_serialization_test_motor_tension_type_enum_get_type (void) G_GNUC_CONST;
GomSerializationTestMotorTension* gom_serialization_test_motor_get_tension (GomSerializationTestMotor* self);
GomSerializationTestMotorModel* gom_serialization_test_motor_model_new (void);
GomSerializationTestMotorModel* gom_serialization_test_motor_model_construct (GType object_type);
GType gom_serialization_test_motor_model_get_type (void) G_GNUC_CONST;
void gom_serialization_test_motor_set_model (GomSerializationTestMotor* self,
                                             GomSerializationTestMotorModel* value);
GomSerializationTestMotorModel* gom_serialization_test_motor_get_model (GomSerializationTestMotor* self);
static void ___lambda130__gtest_func (void);
static void __lambda131_ (void);
static void ___lambda131__gtest_func (void);
static void __lambda132_ (void);
static void ___lambda132__gtest_func (void);
static void __lambda133_ (void);
gchar* gom_serialization_test_book_register_to_string (GomSerializationTestBookRegister* self);
static void ___lambda133__gtest_func (void);
static void __lambda134_ (void);
static void ___lambda134__gtest_func (void);
static void __lambda135_ (void);
static void ___lambda135__gtest_func (void);
static void __lambda136_ (void);
GomSerializationTestBooks* gom_serialization_test_book_stand_get_books (GomSerializationTestBookStand* self);
static void ___lambda136__gtest_func (void);
static void __lambda137_ (void);
static void ___lambda137__gtest_func (void);
static void __lambda138_ (void);
static void _g_free0_ (gpointer var);
static inline void _g_list_free__g_free0_ (GList* self);
static void ___lambda138__gtest_func (void);
static void __lambda139_ (void);
static void ___lambda139__gtest_func (void);
static void __lambda140_ (void);
static void ___lambda140__gtest_func (void);
static void __lambda141_ (void);
static void ___lambda141__gtest_func (void);
static void __lambda142_ (void);
static void ___lambda142__gtest_func (void);
GomSerializationTest* gom_serialization_test_new (void);
GomSerializationTest* gom_serialization_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static GObject * gom_serialization_test_book_constructor (GType type,
                                                   guint n_construct_properties,
                                                   GObjectConstructParam * construct_properties);
static void gom_serialization_test_book_finalize (GObject * obj);
static void _vala_gom_serialization_test_book_get_property (GObject * object,
                                                     guint property_id,
                                                     GValue * value,
                                                     GParamSpec * pspec);
static void _vala_gom_serialization_test_book_set_property (GObject * object,
                                                     guint property_id,
                                                     const GValue * value,
                                                     GParamSpec * pspec);
static GObject * gom_serialization_test_computer_constructor (GType type,
                                                       guint n_construct_properties,
                                                       GObjectConstructParam * construct_properties);
static void gom_serialization_test_computer_finalize (GObject * obj);
static void _vala_gom_serialization_test_computer_get_property (GObject * object,
                                                         guint property_id,
                                                         GValue * value,
                                                         GParamSpec * pspec);
static void _vala_gom_serialization_test_computer_set_property (GObject * object,
                                                         guint property_id,
                                                         const GValue * value,
                                                         GParamSpec * pspec);
static GObject * gom_serialization_test_taxes_constructor (GType type,
                                                    guint n_construct_properties,
                                                    GObjectConstructParam * construct_properties);
static void gom_serialization_test_taxes_finalize (GObject * obj);
static void _vala_gom_serialization_test_taxes_get_property (GObject * object,
                                                      guint property_id,
                                                      GValue * value,
                                                      GParamSpec * pspec);
static void _vala_gom_serialization_test_taxes_set_property (GObject * object,
                                                      guint property_id,
                                                      const GValue * value,
                                                      GParamSpec * pspec);
GomSerializationTestBookRegister* gom_serialization_test_book_register_new_document (GXmlDomDocument* doc);
GomSerializationTestBookRegister* gom_serialization_test_book_register_construct_document (GType object_type,
                                                                                           GXmlDomDocument* doc);
static gchar* gom_serialization_test_book_register_real_get_map_key (GXmlMappeableElement* base);
static gchar* gom_serialization_test_book_register_real_get_map_primary_key (GXmlMappeableElementPairKey* base);
static gchar* gom_serialization_test_book_register_real_get_map_secondary_key (GXmlMappeableElementPairKey* base);
static gchar* gom_serialization_test_book_register_real_get_map_pkey (GXmlMappeableElementThreeKey* base);
static gchar* gom_serialization_test_book_register_real_get_map_skey (GXmlMappeableElementThreeKey* base);
static gchar* gom_serialization_test_book_register_real_get_map_tkey (GXmlMappeableElementThreeKey* base);
static GObject * gom_serialization_test_book_register_constructor (GType type,
                                                            guint n_construct_properties,
                                                            GObjectConstructParam * construct_properties);
static void gom_serialization_test_book_register_finalize (GObject * obj);
static void _vala_gom_serialization_test_book_register_get_property (GObject * object,
                                                              guint property_id,
                                                              GValue * value,
                                                              GParamSpec * pspec);
static void _vala_gom_serialization_test_book_register_set_property (GObject * object,
                                                              guint property_id,
                                                              const GValue * value,
                                                              GParamSpec * pspec);
const gchar* gom_serialization_test_book_stand_get_classification (GomSerializationTestBookStand* self);
void gom_serialization_test_book_stand_set_classification (GomSerializationTestBookStand* self,
                                                           const gchar* value);
void gom_serialization_test_book_stand_set_dimension_x (GomSerializationTestBookStand* self,
                                                        GomSerializationTestBookStandDimension* value);
void gom_serialization_test_book_stand_set_dimension_y (GomSerializationTestBookStand* self,
                                                        GomSerializationTestBookStandDimensionY* value);
void gom_serialization_test_book_stand_set_dimension_z (GomSerializationTestBookStand* self,
                                                        GomSerializationTestBookStandDimensionZ* value);
void gom_serialization_test_book_stand_set_registers (GomSerializationTestBookStand* self,
                                                      GomSerializationTestRegisters* value);
void gom_serialization_test_book_stand_set_hashmap_registers (GomSerializationTestBookStand* self,
                                                              GomSerializationTestHashRegisters* value);
void gom_serialization_test_book_stand_set_hashpair_registers (GomSerializationTestBookStand* self,
                                                               GomSerializationTestHashPairRegisters* value);
void gom_serialization_test_book_stand_set_hashthree_registers (GomSerializationTestBookStand* self,
                                                                GomSerializationTestHashThreeRegisters* value);
void gom_serialization_test_book_stand_set_books (GomSerializationTestBookStand* self,
                                                  GomSerializationTestBooks* value);
static GObject * gom_serialization_test_book_stand_constructor (GType type,
                                                         guint n_construct_properties,
                                                         GObjectConstructParam * construct_properties);
GomSerializationTestBookStandDimension* gom_serialization_test_book_stand_dimension_new (void);
GomSerializationTestBookStandDimension* gom_serialization_test_book_stand_dimension_construct (GType object_type);
void gom_serialization_test_book_stand_dimension_set_length (GomSerializationTestBookStandDimension* self,
                                                             gdouble value);
const gchar* gom_serialization_test_book_stand_dimension_get_dtype (GomSerializationTestBookStandDimension* self);
void gom_serialization_test_book_stand_dimension_set_dtype (GomSerializationTestBookStandDimension* self,
                                                            const gchar* value);
static GObject * gom_serialization_test_book_stand_dimension_constructor (GType type,
                                                                   guint n_construct_properties,
                                                                   GObjectConstructParam * construct_properties);
static void gom_serialization_test_book_stand_dimension_finalize (GObject * obj);
static void _vala_gom_serialization_test_book_stand_dimension_get_property (GObject * object,
                                                                     guint property_id,
                                                                     GValue * value,
                                                                     GParamSpec * pspec);
static void _vala_gom_serialization_test_book_stand_dimension_set_property (GObject * object,
                                                                     guint property_id,
                                                                     const GValue * value,
                                                                     GParamSpec * pspec);
GomSerializationTestBookStandDimensionY* gom_serialization_test_book_stand_dimension_y_new (void);
GomSerializationTestBookStandDimensionY* gom_serialization_test_book_stand_dimension_y_construct (GType object_type);
static GObject * gom_serialization_test_book_stand_dimension_y_constructor (GType type,
                                                                     guint n_construct_properties,
                                                                     GObjectConstructParam * construct_properties);
GomSerializationTestBookStandDimensionZ* gom_serialization_test_book_stand_dimension_z_new (void);
GomSerializationTestBookStandDimensionZ* gom_serialization_test_book_stand_dimension_z_construct (GType object_type);
static GObject * gom_serialization_test_book_stand_dimension_z_constructor (GType type,
                                                                     guint n_construct_properties,
                                                                     GObjectConstructParam * construct_properties);
static void gom_serialization_test_book_stand_finalize (GObject * obj);
static void _vala_gom_serialization_test_book_stand_get_property (GObject * object,
                                                           guint property_id,
                                                           GValue * value,
                                                           GParamSpec * pspec);
static void _vala_gom_serialization_test_book_stand_set_property (GObject * object,
                                                           guint property_id,
                                                           const GValue * value,
                                                           GParamSpec * pspec);
GomSerializationTestRegisters* gom_serialization_test_registers_new (void);
GomSerializationTestRegisters* gom_serialization_test_registers_construct (GType object_type);
static GObject * gom_serialization_test_registers_constructor (GType type,
                                                        guint n_construct_properties,
                                                        GObjectConstructParam * construct_properties);
GomSerializationTestHashRegisters* gom_serialization_test_hash_registers_new (void);
GomSerializationTestHashRegisters* gom_serialization_test_hash_registers_construct (GType object_type);
static GObject * gom_serialization_test_hash_registers_constructor (GType type,
                                                             guint n_construct_properties,
                                                             GObjectConstructParam * construct_properties);
GomSerializationTestHashPairRegisters* gom_serialization_test_hash_pair_registers_new (void);
GomSerializationTestHashPairRegisters* gom_serialization_test_hash_pair_registers_construct (GType object_type);
static GObject * gom_serialization_test_hash_pair_registers_constructor (GType type,
                                                                  guint n_construct_properties,
                                                                  GObjectConstructParam * construct_properties);
GomSerializationTestHashThreeRegisters* gom_serialization_test_hash_three_registers_new (void);
GomSerializationTestHashThreeRegisters* gom_serialization_test_hash_three_registers_construct (GType object_type);
static GObject * gom_serialization_test_hash_three_registers_constructor (GType type,
                                                                   guint n_construct_properties,
                                                                   GObjectConstructParam * construct_properties);
GomSerializationTestBooks* gom_serialization_test_books_new (void);
GomSerializationTestBooks* gom_serialization_test_books_construct (GType object_type);
static GObject * gom_serialization_test_books_constructor (GType type,
                                                    guint n_construct_properties,
                                                    GObjectConstructParam * construct_properties);
const gchar* gom_serialization_test_book_store_get_name (GomSerializationTestBookStore* self);
void gom_serialization_test_book_store_set_name (GomSerializationTestBookStore* self,
                                                 const gchar* value);
void gom_serialization_test_book_store_set_books (GomSerializationTestBookStore* self,
                                                  GomSerializationTestBooks* value);
static GObject * gom_serialization_test_book_store_constructor (GType type,
                                                         guint n_construct_properties,
                                                         GObjectConstructParam * construct_properties);
static void gom_serialization_test_book_store_finalize (GObject * obj);
static void _vala_gom_serialization_test_book_store_get_property (GObject * object,
                                                           guint property_id,
                                                           GValue * value,
                                                           GParamSpec * pspec);
static void _vala_gom_serialization_test_book_store_set_property (GObject * object,
                                                           guint property_id,
                                                           const GValue * value,
                                                           GParamSpec * pspec);
static GObject * gom_serialization_test_motor_constructor (GType type,
                                                    guint n_construct_properties,
                                                    GObjectConstructParam * construct_properties);
static GObject * gom_serialization_test_motor_tension_type_constructor (GType type,
                                                                 guint n_construct_properties,
                                                                 GObjectConstructParam * construct_properties);
static GObject * gom_serialization_test_motor_model_constructor (GType type,
                                                          guint n_construct_properties,
                                                          GObjectConstructParam * construct_properties);
static void gom_serialization_test_motor_finalize (GObject * obj);
static void _vala_gom_serialization_test_motor_get_property (GObject * object,
                                                      guint property_id,
                                                      GValue * value,
                                                      GParamSpec * pspec);
static void _vala_gom_serialization_test_motor_set_property (GObject * object,
                                                      guint property_id,
                                                      const GValue * value,
                                                      GParamSpec * pspec);

static inline gpointer
three_keys_get_instance_private (ThreeKeys* self)
{
	return G_STRUCT_MEMBER_P (self, ThreeKeys_private_offset);
}

ThreeKeys*
three_keys_construct (GType object_type)
{
	ThreeKeys * self = NULL;
#line 26 "GomSerializationTest.vala"
	self = (ThreeKeys*) gxml_gom_element_construct (object_type);
#line 26 "GomSerializationTest.vala"
	return self;
#line 2120 "GomSerializationTest.c"
}

ThreeKeys*
three_keys_new (void)
{
#line 26 "GomSerializationTest.vala"
	return three_keys_construct (TYPE_THREE_KEYS);
#line 2128 "GomSerializationTest.c"
}

ThreeKeyMap*
three_keys_get_map (ThreeKeys* self)
{
	ThreeKeyMap* result;
	ThreeKeyMap* _tmp0_;
	ThreeKeyMap* _tmp1_;
#line 29 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 30 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_map;
#line 30 "GomSerializationTest.vala"
	if (_tmp0_ == NULL) {
#line 31 "GomSerializationTest.vala"
		gxml_gom_object_set_instance_property ((GXmlGomObject*) self, "map");
#line 2145 "GomSerializationTest.c"
	}
#line 32 "GomSerializationTest.vala"
	_tmp1_ = self->priv->_map;
#line 32 "GomSerializationTest.vala"
	result = _tmp1_;
#line 32 "GomSerializationTest.vala"
	return result;
#line 2153 "GomSerializationTest.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 38 "GomSerializationTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 2161 "GomSerializationTest.c"
}

void
three_keys_set_map (ThreeKeys* self,
                    ThreeKeyMap* value)
{
	ThreeKeyMap* _tmp0_;
	ThreeKeyMap* _tmp5_;
	GError* _inner_error0_ = NULL;
#line 34 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 35 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_map;
#line 35 "GomSerializationTest.vala"
	if (_tmp0_ != NULL) {
#line 2177 "GomSerializationTest.c"
		{
#line 36 "GomSerializationTest.vala"
			gxml_gom_object_clean_property_elements ((GXmlGomObject*) self, "map", &_inner_error0_);
#line 36 "GomSerializationTest.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2183 "GomSerializationTest.c"
				goto __catch151_g_error;
			}
		}
		goto __finally151;
		__catch151_g_error:
		{
			GError* e = NULL;
			GError* _tmp1_;
			const gchar* _tmp2_;
			gchar* _tmp3_;
			gchar* _tmp4_;
#line 36 "GomSerializationTest.vala"
			e = _inner_error0_;
#line 36 "GomSerializationTest.vala"
			_inner_error0_ = NULL;
#line 37 "GomSerializationTest.vala"
			_tmp1_ = e;
#line 37 "GomSerializationTest.vala"
			_tmp2_ = _tmp1_->message;
#line 37 "GomSerializationTest.vala"
			_tmp3_ = g_strconcat ("Error: ", _tmp2_, NULL);
#line 37 "GomSerializationTest.vala"
			_tmp4_ = _tmp3_;
#line 37 "GomSerializationTest.vala"
			g_warning ("GomSerializationTest.vala:37: %s", _tmp4_);
#line 37 "GomSerializationTest.vala"
			_g_free0 (_tmp4_);
#line 36 "GomSerializationTest.vala"
			_g_error_free0 (e);
#line 2213 "GomSerializationTest.c"
		}
		__finally151:
#line 36 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 36 "GomSerializationTest.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 36 "GomSerializationTest.vala"
			g_clear_error (&_inner_error0_);
#line 36 "GomSerializationTest.vala"
			return;
#line 2224 "GomSerializationTest.c"
		}
	}
#line 38 "GomSerializationTest.vala"
	_tmp5_ = _g_object_ref0 (value);
#line 38 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_map);
#line 38 "GomSerializationTest.vala"
	self->priv->_map = _tmp5_;
#line 34 "GomSerializationTest.vala"
	g_object_notify_by_pspec ((GObject *) self, three_keys_properties[THREE_KEYS_MAP_PROPERTY]);
#line 2235 "GomSerializationTest.c"
}

static GObject *
three_keys_constructor (GType type,
                        guint n_construct_properties,
                        GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	ThreeKeys * self;
	GError* _inner_error0_ = NULL;
#line 41 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (three_keys_parent_class);
#line 41 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 41 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_THREE_KEYS, ThreeKeys);
#line 2253 "GomSerializationTest.c"
	{
#line 41 "GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "ThreeKeys");
#line 2257 "GomSerializationTest.c"
	}
	goto __finally152;
	__catch152_g_error:
	{
#line 41 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 41 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 41 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 2268 "GomSerializationTest.c"
	}
	__finally152:
#line 41 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 41 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 41 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 2277 "GomSerializationTest.c"
	}
#line 41 "GomSerializationTest.vala"
	return obj;
#line 2281 "GomSerializationTest.c"
}

static void
three_keys_class_init (ThreeKeysClass * klass,
                       gpointer klass_data)
{
#line 26 "GomSerializationTest.vala"
	three_keys_parent_class = g_type_class_peek_parent (klass);
#line 26 "GomSerializationTest.vala"
	g_type_class_adjust_private_offset (klass, &ThreeKeys_private_offset);
#line 26 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_three_keys_get_property;
#line 26 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_three_keys_set_property;
#line 26 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = three_keys_constructor;
#line 26 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = three_keys_finalize;
#line 26 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), THREE_KEYS_MAP_PROPERTY, three_keys_properties[THREE_KEYS_MAP_PROPERTY] = g_param_spec_object ("map", "map", "map", THREE_KEY_TYPE_MAP, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2302 "GomSerializationTest.c"
}

static void
three_keys_instance_init (ThreeKeys * self,
                          gpointer klass)
{
#line 26 "GomSerializationTest.vala"
	self->priv = three_keys_get_instance_private (self);
#line 2311 "GomSerializationTest.c"
}

static void
three_keys_finalize (GObject * obj)
{
	ThreeKeys * self;
#line 26 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_THREE_KEYS, ThreeKeys);
#line 27 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_map);
#line 26 "GomSerializationTest.vala"
	G_OBJECT_CLASS (three_keys_parent_class)->finalize (obj);
#line 2324 "GomSerializationTest.c"
}

GType
three_keys_get_type (void)
{
	static volatile gsize three_keys_type_id__volatile = 0;
	if (g_once_init_enter (&three_keys_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ThreeKeysClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) three_keys_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ThreeKeys), 0, (GInstanceInitFunc) three_keys_instance_init, NULL };
		GType three_keys_type_id;
		three_keys_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "ThreeKeys", &g_define_type_info, 0);
		ThreeKeys_private_offset = g_type_add_instance_private (three_keys_type_id, sizeof (ThreeKeysPrivate));
		g_once_init_leave (&three_keys_type_id__volatile, three_keys_type_id);
	}
	return three_keys_type_id__volatile;
}

static void
_vala_three_keys_get_property (GObject * object,
                               guint property_id,
                               GValue * value,
                               GParamSpec * pspec)
{
	ThreeKeys * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_THREE_KEYS, ThreeKeys);
#line 26 "GomSerializationTest.vala"
	switch (property_id) {
#line 26 "GomSerializationTest.vala"
		case THREE_KEYS_MAP_PROPERTY:
#line 26 "GomSerializationTest.vala"
		g_value_set_object (value, three_keys_get_map (self));
#line 26 "GomSerializationTest.vala"
		break;
#line 2357 "GomSerializationTest.c"
		default:
#line 26 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 26 "GomSerializationTest.vala"
		break;
#line 2363 "GomSerializationTest.c"
	}
}

static void
_vala_three_keys_set_property (GObject * object,
                               guint property_id,
                               const GValue * value,
                               GParamSpec * pspec)
{
	ThreeKeys * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_THREE_KEYS, ThreeKeys);
#line 26 "GomSerializationTest.vala"
	switch (property_id) {
#line 26 "GomSerializationTest.vala"
		case THREE_KEYS_MAP_PROPERTY:
#line 26 "GomSerializationTest.vala"
		three_keys_set_map (self, g_value_get_object (value));
#line 26 "GomSerializationTest.vala"
		break;
#line 2383 "GomSerializationTest.c"
		default:
#line 26 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 26 "GomSerializationTest.vala"
		break;
#line 2389 "GomSerializationTest.c"
	}
}

static inline gpointer
three_key_get_instance_private (ThreeKey* self)
{
	return G_STRUCT_MEMBER_P (self, ThreeKey_private_offset);
}

static gchar*
three_key_real_get_map_pkey (GXmlMappeableElementThreeKey* base)
{
	ThreeKey * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 51 "GomSerializationTest.vala"
	self = (ThreeKey*) base;
#line 51 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_id;
#line 51 "GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 51 "GomSerializationTest.vala"
	result = _tmp1_;
#line 51 "GomSerializationTest.vala"
	return result;
#line 2416 "GomSerializationTest.c"
}

static gchar*
three_key_real_get_map_skey (GXmlMappeableElementThreeKey* base)
{
	ThreeKey * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 52 "GomSerializationTest.vala"
	self = (ThreeKey*) base;
#line 52 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_code;
#line 52 "GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 52 "GomSerializationTest.vala"
	result = _tmp1_;
#line 52 "GomSerializationTest.vala"
	return result;
#line 2436 "GomSerializationTest.c"
}

static gchar*
three_key_real_get_map_tkey (GXmlMappeableElementThreeKey* base)
{
	ThreeKey * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 53 "GomSerializationTest.vala"
	self = (ThreeKey*) base;
#line 53 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_name;
#line 53 "GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 53 "GomSerializationTest.vala"
	result = _tmp1_;
#line 53 "GomSerializationTest.vala"
	return result;
#line 2456 "GomSerializationTest.c"
}

ThreeKey*
three_key_construct (GType object_type)
{
	ThreeKey * self = NULL;
#line 43 "GomSerializationTest.vala"
	self = (ThreeKey*) gxml_gom_element_construct (object_type);
#line 43 "GomSerializationTest.vala"
	return self;
#line 2467 "GomSerializationTest.c"
}

ThreeKey*
three_key_new (void)
{
#line 43 "GomSerializationTest.vala"
	return three_key_construct (TYPE_THREE_KEY);
#line 2475 "GomSerializationTest.c"
}

const gchar*
three_key_get_id (ThreeKey* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 45 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 45 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_id;
#line 45 "GomSerializationTest.vala"
	result = _tmp0_;
#line 45 "GomSerializationTest.vala"
	return result;
#line 2491 "GomSerializationTest.c"
}

void
three_key_set_id (ThreeKey* self,
                  const gchar* value)
{
#line 45 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 45 "GomSerializationTest.vala"
	if (g_strcmp0 (value, three_key_get_id (self)) != 0) {
#line 2502 "GomSerializationTest.c"
		gchar* _tmp0_;
#line 45 "GomSerializationTest.vala"
		_tmp0_ = g_strdup (value);
#line 45 "GomSerializationTest.vala"
		_g_free0 (self->priv->_id);
#line 45 "GomSerializationTest.vala"
		self->priv->_id = _tmp0_;
#line 45 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, three_key_properties[THREE_KEY_ID_PROPERTY]);
#line 2512 "GomSerializationTest.c"
	}
}

const gchar*
three_key_get_code (ThreeKey* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 47 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 47 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_code;
#line 47 "GomSerializationTest.vala"
	result = _tmp0_;
#line 47 "GomSerializationTest.vala"
	return result;
#line 2529 "GomSerializationTest.c"
}

void
three_key_set_code (ThreeKey* self,
                    const gchar* value)
{
#line 47 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 47 "GomSerializationTest.vala"
	if (g_strcmp0 (value, three_key_get_code (self)) != 0) {
#line 2540 "GomSerializationTest.c"
		gchar* _tmp0_;
#line 47 "GomSerializationTest.vala"
		_tmp0_ = g_strdup (value);
#line 47 "GomSerializationTest.vala"
		_g_free0 (self->priv->_code);
#line 47 "GomSerializationTest.vala"
		self->priv->_code = _tmp0_;
#line 47 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, three_key_properties[THREE_KEY_CODE_PROPERTY]);
#line 2550 "GomSerializationTest.c"
	}
}

const gchar*
three_key_get_name (ThreeKey* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 49 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 49 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_name;
#line 49 "GomSerializationTest.vala"
	result = _tmp0_;
#line 49 "GomSerializationTest.vala"
	return result;
#line 2567 "GomSerializationTest.c"
}

void
three_key_set_name (ThreeKey* self,
                    const gchar* value)
{
#line 49 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 49 "GomSerializationTest.vala"
	if (g_strcmp0 (value, three_key_get_name (self)) != 0) {
#line 2578 "GomSerializationTest.c"
		gchar* _tmp0_;
#line 49 "GomSerializationTest.vala"
		_tmp0_ = g_strdup (value);
#line 49 "GomSerializationTest.vala"
		_g_free0 (self->priv->_name);
#line 49 "GomSerializationTest.vala"
		self->priv->_name = _tmp0_;
#line 49 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, three_key_properties[THREE_KEY_NAME_PROPERTY]);
#line 2588 "GomSerializationTest.c"
	}
}

static GObject *
three_key_constructor (GType type,
                       guint n_construct_properties,
                       GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	ThreeKey * self;
	GError* _inner_error0_ = NULL;
#line 50 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (three_key_parent_class);
#line 50 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 50 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_THREE_KEY, ThreeKey);
#line 2607 "GomSerializationTest.c"
	{
#line 50 "GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "ThreeKey");
#line 2611 "GomSerializationTest.c"
	}
	goto __finally153;
	__catch153_g_error:
	{
#line 50 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 50 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 50 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 2622 "GomSerializationTest.c"
	}
	__finally153:
#line 50 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 50 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 50 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 2631 "GomSerializationTest.c"
	}
#line 50 "GomSerializationTest.vala"
	return obj;
#line 2635 "GomSerializationTest.c"
}

ThreeKeyMap*
three_key_map_construct (GType object_type)
{
	ThreeKeyMap * self = NULL;
#line 54 "GomSerializationTest.vala"
	self = (ThreeKeyMap*) gxml_gom_hash_three_map_construct (object_type);
#line 54 "GomSerializationTest.vala"
	return self;
#line 2646 "GomSerializationTest.c"
}

ThreeKeyMap*
three_key_map_new (void)
{
#line 54 "GomSerializationTest.vala"
	return three_key_map_construct (THREE_KEY_TYPE_MAP);
#line 2654 "GomSerializationTest.c"
}

static GObject *
three_key_map_constructor (GType type,
                           guint n_construct_properties,
                           GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	ThreeKeyMap * self;
	GError* _inner_error0_ = NULL;
#line 55 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (three_key_map_parent_class);
#line 55 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 55 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, THREE_KEY_TYPE_MAP, ThreeKeyMap);
#line 2672 "GomSerializationTest.c"
	{
#line 56 "GomSerializationTest.vala"
		gxml_collection_initialize ((GXmlCollection*) self, TYPE_THREE_KEY, &_inner_error0_);
#line 56 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2678 "GomSerializationTest.c"
			goto __catch154_g_error;
		}
	}
	goto __finally154;
	__catch154_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 56 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 56 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 57 "GomSerializationTest.vala"
		_tmp0_ = e;
#line 57 "GomSerializationTest.vala"
		_tmp1_ = _tmp0_->message;
#line 57 "GomSerializationTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 57 "GomSerializationTest.vala"
		_tmp3_ = _tmp2_;
#line 57 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:57: %s", _tmp3_);
#line 57 "GomSerializationTest.vala"
		_g_free0 (_tmp3_);
#line 56 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 2708 "GomSerializationTest.c"
	}
	__finally154:
#line 56 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 56 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 56 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 2717 "GomSerializationTest.c"
	}
#line 55 "GomSerializationTest.vala"
	return obj;
#line 2721 "GomSerializationTest.c"
}

static void
three_key_map_class_init (ThreeKeyMapClass * klass,
                          gpointer klass_data)
{
#line 54 "GomSerializationTest.vala"
	three_key_map_parent_class = g_type_class_peek_parent (klass);
#line 54 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = three_key_map_constructor;
#line 2732 "GomSerializationTest.c"
}

static void
three_key_map_instance_init (ThreeKeyMap * self,
                             gpointer klass)
{
}

GType
three_key_map_get_type (void)
{
	static volatile gsize three_key_map_type_id__volatile = 0;
	if (g_once_init_enter (&three_key_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ThreeKeyMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) three_key_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ThreeKeyMap), 0, (GInstanceInitFunc) three_key_map_instance_init, NULL };
		GType three_key_map_type_id;
		three_key_map_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_THREE_MAP, "ThreeKeyMap", &g_define_type_info, 0);
		g_once_init_leave (&three_key_map_type_id__volatile, three_key_map_type_id);
	}
	return three_key_map_type_id__volatile;
}

static void
three_key_class_init (ThreeKeyClass * klass,
                      gpointer klass_data)
{
#line 43 "GomSerializationTest.vala"
	three_key_parent_class = g_type_class_peek_parent (klass);
#line 43 "GomSerializationTest.vala"
	g_type_class_adjust_private_offset (klass, &ThreeKey_private_offset);
#line 43 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_three_key_get_property;
#line 43 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_three_key_set_property;
#line 43 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = three_key_constructor;
#line 43 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = three_key_finalize;
#line 43 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), THREE_KEY_ID_PROPERTY, three_key_properties[THREE_KEY_ID_PROPERTY] = g_param_spec_string ("id", "::ID", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 43 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), THREE_KEY_CODE_PROPERTY, three_key_properties[THREE_KEY_CODE_PROPERTY] = g_param_spec_string ("code", "::Code", "code", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 43 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), THREE_KEY_NAME_PROPERTY, three_key_properties[THREE_KEY_NAME_PROPERTY] = g_param_spec_string ("name", "::name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2776 "GomSerializationTest.c"
}

static void
three_key_gxml_mappeable_element_three_key_interface_init (GXmlMappeableElementThreeKeyIface * iface,
                                                           gpointer iface_data)
{
#line 43 "GomSerializationTest.vala"
	three_key_gxml_mappeable_element_three_key_parent_iface = g_type_interface_peek_parent (iface);
#line 43 "GomSerializationTest.vala"
	iface->get_map_pkey = (gchar* (*) (GXmlMappeableElementThreeKey*)) three_key_real_get_map_pkey;
#line 43 "GomSerializationTest.vala"
	iface->get_map_skey = (gchar* (*) (GXmlMappeableElementThreeKey*)) three_key_real_get_map_skey;
#line 43 "GomSerializationTest.vala"
	iface->get_map_tkey = (gchar* (*) (GXmlMappeableElementThreeKey*)) three_key_real_get_map_tkey;
#line 2791 "GomSerializationTest.c"
}

static void
three_key_instance_init (ThreeKey * self,
                         gpointer klass)
{
#line 43 "GomSerializationTest.vala"
	self->priv = three_key_get_instance_private (self);
#line 2800 "GomSerializationTest.c"
}

static void
three_key_finalize (GObject * obj)
{
	ThreeKey * self;
#line 43 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_THREE_KEY, ThreeKey);
#line 45 "GomSerializationTest.vala"
	_g_free0 (self->priv->_id);
#line 47 "GomSerializationTest.vala"
	_g_free0 (self->priv->_code);
#line 49 "GomSerializationTest.vala"
	_g_free0 (self->priv->_name);
#line 43 "GomSerializationTest.vala"
	G_OBJECT_CLASS (three_key_parent_class)->finalize (obj);
#line 2817 "GomSerializationTest.c"
}

GType
three_key_get_type (void)
{
	static volatile gsize three_key_type_id__volatile = 0;
	if (g_once_init_enter (&three_key_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ThreeKeyClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) three_key_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ThreeKey), 0, (GInstanceInitFunc) three_key_instance_init, NULL };
		static const GInterfaceInfo gxml_mappeable_element_three_key_info = { (GInterfaceInitFunc) three_key_gxml_mappeable_element_three_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType three_key_type_id;
		three_key_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "ThreeKey", &g_define_type_info, 0);
		g_type_add_interface_static (three_key_type_id, GXML_TYPE_MAPPEABLE_ELEMENT_THREE_KEY, &gxml_mappeable_element_three_key_info);
		ThreeKey_private_offset = g_type_add_instance_private (three_key_type_id, sizeof (ThreeKeyPrivate));
		g_once_init_leave (&three_key_type_id__volatile, three_key_type_id);
	}
	return three_key_type_id__volatile;
}

static void
_vala_three_key_get_property (GObject * object,
                              guint property_id,
                              GValue * value,
                              GParamSpec * pspec)
{
	ThreeKey * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_THREE_KEY, ThreeKey);
#line 43 "GomSerializationTest.vala"
	switch (property_id) {
#line 43 "GomSerializationTest.vala"
		case THREE_KEY_ID_PROPERTY:
#line 43 "GomSerializationTest.vala"
		g_value_set_string (value, three_key_get_id (self));
#line 43 "GomSerializationTest.vala"
		break;
#line 43 "GomSerializationTest.vala"
		case THREE_KEY_CODE_PROPERTY:
#line 43 "GomSerializationTest.vala"
		g_value_set_string (value, three_key_get_code (self));
#line 43 "GomSerializationTest.vala"
		break;
#line 43 "GomSerializationTest.vala"
		case THREE_KEY_NAME_PROPERTY:
#line 43 "GomSerializationTest.vala"
		g_value_set_string (value, three_key_get_name (self));
#line 43 "GomSerializationTest.vala"
		break;
#line 2864 "GomSerializationTest.c"
		default:
#line 43 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 43 "GomSerializationTest.vala"
		break;
#line 2870 "GomSerializationTest.c"
	}
}

static void
_vala_three_key_set_property (GObject * object,
                              guint property_id,
                              const GValue * value,
                              GParamSpec * pspec)
{
	ThreeKey * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_THREE_KEY, ThreeKey);
#line 43 "GomSerializationTest.vala"
	switch (property_id) {
#line 43 "GomSerializationTest.vala"
		case THREE_KEY_ID_PROPERTY:
#line 43 "GomSerializationTest.vala"
		three_key_set_id (self, g_value_get_string (value));
#line 43 "GomSerializationTest.vala"
		break;
#line 43 "GomSerializationTest.vala"
		case THREE_KEY_CODE_PROPERTY:
#line 43 "GomSerializationTest.vala"
		three_key_set_code (self, g_value_get_string (value));
#line 43 "GomSerializationTest.vala"
		break;
#line 43 "GomSerializationTest.vala"
		case THREE_KEY_NAME_PROPERTY:
#line 43 "GomSerializationTest.vala"
		three_key_set_name (self, g_value_get_string (value));
#line 43 "GomSerializationTest.vala"
		break;
#line 2902 "GomSerializationTest.c"
		default:
#line 43 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 43 "GomSerializationTest.vala"
		break;
#line 2908 "GomSerializationTest.c"
	}
}

static inline gpointer
operations_get_instance_private (Operations* self)
{
	return G_STRUCT_MEMBER_P (self, Operations_private_offset);
}

Operations*
operations_construct (GType object_type)
{
	Operations * self = NULL;
#line 61 "GomSerializationTest.vala"
	self = (Operations*) gxml_gom_element_construct (object_type);
#line 61 "GomSerializationTest.vala"
	return self;
#line 2926 "GomSerializationTest.c"
}

Operations*
operations_new (void)
{
#line 61 "GomSerializationTest.vala"
	return operations_construct (TYPE_OPERATIONS);
#line 2934 "GomSerializationTest.c"
}

OperationMap*
operations_get_map (Operations* self)
{
	OperationMap* result;
	OperationMap* _tmp0_;
	OperationMap* _tmp1_;
#line 64 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 65 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_map;
#line 65 "GomSerializationTest.vala"
	if (_tmp0_ == NULL) {
#line 66 "GomSerializationTest.vala"
		gxml_gom_object_set_instance_property ((GXmlGomObject*) self, "map");
#line 2951 "GomSerializationTest.c"
	}
#line 67 "GomSerializationTest.vala"
	_tmp1_ = self->priv->_map;
#line 67 "GomSerializationTest.vala"
	result = _tmp1_;
#line 67 "GomSerializationTest.vala"
	return result;
#line 2959 "GomSerializationTest.c"
}

void
operations_set_map (Operations* self,
                    OperationMap* value)
{
	OperationMap* _tmp0_;
	OperationMap* _tmp5_;
	GError* _inner_error0_ = NULL;
#line 69 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 70 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_map;
#line 70 "GomSerializationTest.vala"
	if (_tmp0_ != NULL) {
#line 2975 "GomSerializationTest.c"
		{
#line 71 "GomSerializationTest.vala"
			gxml_gom_object_clean_property_elements ((GXmlGomObject*) self, "map", &_inner_error0_);
#line 71 "GomSerializationTest.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2981 "GomSerializationTest.c"
				goto __catch155_g_error;
			}
		}
		goto __finally155;
		__catch155_g_error:
		{
			GError* e = NULL;
			GError* _tmp1_;
			const gchar* _tmp2_;
			gchar* _tmp3_;
			gchar* _tmp4_;
#line 71 "GomSerializationTest.vala"
			e = _inner_error0_;
#line 71 "GomSerializationTest.vala"
			_inner_error0_ = NULL;
#line 72 "GomSerializationTest.vala"
			_tmp1_ = e;
#line 72 "GomSerializationTest.vala"
			_tmp2_ = _tmp1_->message;
#line 72 "GomSerializationTest.vala"
			_tmp3_ = g_strconcat ("Error: ", _tmp2_, NULL);
#line 72 "GomSerializationTest.vala"
			_tmp4_ = _tmp3_;
#line 72 "GomSerializationTest.vala"
			g_warning ("GomSerializationTest.vala:72: %s", _tmp4_);
#line 72 "GomSerializationTest.vala"
			_g_free0 (_tmp4_);
#line 71 "GomSerializationTest.vala"
			_g_error_free0 (e);
#line 3011 "GomSerializationTest.c"
		}
		__finally155:
#line 71 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 71 "GomSerializationTest.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 71 "GomSerializationTest.vala"
			g_clear_error (&_inner_error0_);
#line 71 "GomSerializationTest.vala"
			return;
#line 3022 "GomSerializationTest.c"
		}
	}
#line 73 "GomSerializationTest.vala"
	_tmp5_ = _g_object_ref0 (value);
#line 73 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_map);
#line 73 "GomSerializationTest.vala"
	self->priv->_map = _tmp5_;
#line 69 "GomSerializationTest.vala"
	g_object_notify_by_pspec ((GObject *) self, operations_properties[OPERATIONS_MAP_PROPERTY]);
#line 3033 "GomSerializationTest.c"
}

static GObject *
operations_constructor (GType type,
                        guint n_construct_properties,
                        GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	Operations * self;
	GError* _inner_error0_ = NULL;
#line 76 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (operations_parent_class);
#line 76 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 76 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_OPERATIONS, Operations);
#line 3051 "GomSerializationTest.c"
	{
#line 76 "GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Operations");
#line 3055 "GomSerializationTest.c"
	}
	goto __finally156;
	__catch156_g_error:
	{
#line 76 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 76 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 76 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 3066 "GomSerializationTest.c"
	}
	__finally156:
#line 76 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 76 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 76 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 3075 "GomSerializationTest.c"
	}
#line 76 "GomSerializationTest.vala"
	return obj;
#line 3079 "GomSerializationTest.c"
}

static void
operations_class_init (OperationsClass * klass,
                       gpointer klass_data)
{
#line 61 "GomSerializationTest.vala"
	operations_parent_class = g_type_class_peek_parent (klass);
#line 61 "GomSerializationTest.vala"
	g_type_class_adjust_private_offset (klass, &Operations_private_offset);
#line 61 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_operations_get_property;
#line 61 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_operations_set_property;
#line 61 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = operations_constructor;
#line 61 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = operations_finalize;
#line 61 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), OPERATIONS_MAP_PROPERTY, operations_properties[OPERATIONS_MAP_PROPERTY] = g_param_spec_object ("map", "map", "map", OPERATION_TYPE_MAP, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3100 "GomSerializationTest.c"
}

static void
operations_instance_init (Operations * self,
                          gpointer klass)
{
#line 61 "GomSerializationTest.vala"
	self->priv = operations_get_instance_private (self);
#line 3109 "GomSerializationTest.c"
}

static void
operations_finalize (GObject * obj)
{
	Operations * self;
#line 61 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_OPERATIONS, Operations);
#line 62 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_map);
#line 61 "GomSerializationTest.vala"
	G_OBJECT_CLASS (operations_parent_class)->finalize (obj);
#line 3122 "GomSerializationTest.c"
}

GType
operations_get_type (void)
{
	static volatile gsize operations_type_id__volatile = 0;
	if (g_once_init_enter (&operations_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (OperationsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) operations_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Operations), 0, (GInstanceInitFunc) operations_instance_init, NULL };
		GType operations_type_id;
		operations_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "Operations", &g_define_type_info, 0);
		Operations_private_offset = g_type_add_instance_private (operations_type_id, sizeof (OperationsPrivate));
		g_once_init_leave (&operations_type_id__volatile, operations_type_id);
	}
	return operations_type_id__volatile;
}

static void
_vala_operations_get_property (GObject * object,
                               guint property_id,
                               GValue * value,
                               GParamSpec * pspec)
{
	Operations * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_OPERATIONS, Operations);
#line 61 "GomSerializationTest.vala"
	switch (property_id) {
#line 61 "GomSerializationTest.vala"
		case OPERATIONS_MAP_PROPERTY:
#line 61 "GomSerializationTest.vala"
		g_value_set_object (value, operations_get_map (self));
#line 61 "GomSerializationTest.vala"
		break;
#line 3155 "GomSerializationTest.c"
		default:
#line 61 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 61 "GomSerializationTest.vala"
		break;
#line 3161 "GomSerializationTest.c"
	}
}

static void
_vala_operations_set_property (GObject * object,
                               guint property_id,
                               const GValue * value,
                               GParamSpec * pspec)
{
	Operations * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_OPERATIONS, Operations);
#line 61 "GomSerializationTest.vala"
	switch (property_id) {
#line 61 "GomSerializationTest.vala"
		case OPERATIONS_MAP_PROPERTY:
#line 61 "GomSerializationTest.vala"
		operations_set_map (self, g_value_get_object (value));
#line 61 "GomSerializationTest.vala"
		break;
#line 3181 "GomSerializationTest.c"
		default:
#line 61 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 61 "GomSerializationTest.vala"
		break;
#line 3187 "GomSerializationTest.c"
	}
}

static inline gpointer
operation_get_instance_private (Operation* self)
{
	return G_STRUCT_MEMBER_P (self, Operation_private_offset);
}

static gchar*
operation_real_get_map_primary_key (GXmlMappeableElementPairKey* base)
{
	Operation * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 84 "GomSerializationTest.vala"
	self = (Operation*) base;
#line 84 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_id;
#line 84 "GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 84 "GomSerializationTest.vala"
	result = _tmp1_;
#line 84 "GomSerializationTest.vala"
	return result;
#line 3214 "GomSerializationTest.c"
}

static gchar*
operation_real_get_map_secondary_key (GXmlMappeableElementPairKey* base)
{
	Operation * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 85 "GomSerializationTest.vala"
	self = (Operation*) base;
#line 85 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_code;
#line 85 "GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 85 "GomSerializationTest.vala"
	result = _tmp1_;
#line 85 "GomSerializationTest.vala"
	return result;
#line 3234 "GomSerializationTest.c"
}

Operation*
operation_construct (GType object_type)
{
	Operation * self = NULL;
#line 78 "GomSerializationTest.vala"
	self = (Operation*) gxml_gom_element_construct (object_type);
#line 78 "GomSerializationTest.vala"
	return self;
#line 3245 "GomSerializationTest.c"
}

Operation*
operation_new (void)
{
#line 78 "GomSerializationTest.vala"
	return operation_construct (TYPE_OPERATION);
#line 3253 "GomSerializationTest.c"
}

const gchar*
operation_get_id (Operation* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 80 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 80 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_id;
#line 80 "GomSerializationTest.vala"
	result = _tmp0_;
#line 80 "GomSerializationTest.vala"
	return result;
#line 3269 "GomSerializationTest.c"
}

void
operation_set_id (Operation* self,
                  const gchar* value)
{
#line 80 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 80 "GomSerializationTest.vala"
	if (g_strcmp0 (value, operation_get_id (self)) != 0) {
#line 3280 "GomSerializationTest.c"
		gchar* _tmp0_;
#line 80 "GomSerializationTest.vala"
		_tmp0_ = g_strdup (value);
#line 80 "GomSerializationTest.vala"
		_g_free0 (self->priv->_id);
#line 80 "GomSerializationTest.vala"
		self->priv->_id = _tmp0_;
#line 80 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, operation_properties[OPERATION_ID_PROPERTY]);
#line 3290 "GomSerializationTest.c"
	}
}

const gchar*
operation_get_code (Operation* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 82 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 82 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_code;
#line 82 "GomSerializationTest.vala"
	result = _tmp0_;
#line 82 "GomSerializationTest.vala"
	return result;
#line 3307 "GomSerializationTest.c"
}

void
operation_set_code (Operation* self,
                    const gchar* value)
{
#line 82 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 82 "GomSerializationTest.vala"
	if (g_strcmp0 (value, operation_get_code (self)) != 0) {
#line 3318 "GomSerializationTest.c"
		gchar* _tmp0_;
#line 82 "GomSerializationTest.vala"
		_tmp0_ = g_strdup (value);
#line 82 "GomSerializationTest.vala"
		_g_free0 (self->priv->_code);
#line 82 "GomSerializationTest.vala"
		self->priv->_code = _tmp0_;
#line 82 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, operation_properties[OPERATION_CODE_PROPERTY]);
#line 3328 "GomSerializationTest.c"
	}
}

static GObject *
operation_constructor (GType type,
                       guint n_construct_properties,
                       GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	Operation * self;
	GError* _inner_error0_ = NULL;
#line 83 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (operation_parent_class);
#line 83 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 83 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_OPERATION, Operation);
#line 3347 "GomSerializationTest.c"
	{
#line 83 "GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Operation");
#line 3351 "GomSerializationTest.c"
	}
	goto __finally157;
	__catch157_g_error:
	{
#line 83 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 83 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 83 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 3362 "GomSerializationTest.c"
	}
	__finally157:
#line 83 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 83 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 83 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 3371 "GomSerializationTest.c"
	}
#line 83 "GomSerializationTest.vala"
	return obj;
#line 3375 "GomSerializationTest.c"
}

OperationMap*
operation_map_construct (GType object_type)
{
	OperationMap * self = NULL;
#line 86 "GomSerializationTest.vala"
	self = (OperationMap*) gxml_gom_hash_paired_map_construct (object_type);
#line 86 "GomSerializationTest.vala"
	return self;
#line 3386 "GomSerializationTest.c"
}

OperationMap*
operation_map_new (void)
{
#line 86 "GomSerializationTest.vala"
	return operation_map_construct (OPERATION_TYPE_MAP);
#line 3394 "GomSerializationTest.c"
}

static GObject *
operation_map_constructor (GType type,
                           guint n_construct_properties,
                           GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	OperationMap * self;
	GError* _inner_error0_ = NULL;
#line 87 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (operation_map_parent_class);
#line 87 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 87 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, OPERATION_TYPE_MAP, OperationMap);
#line 3412 "GomSerializationTest.c"
	{
#line 88 "GomSerializationTest.vala"
		gxml_collection_initialize ((GXmlCollection*) self, TYPE_OPERATION, &_inner_error0_);
#line 88 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 3418 "GomSerializationTest.c"
			goto __catch158_g_error;
		}
	}
	goto __finally158;
	__catch158_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 88 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 88 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 89 "GomSerializationTest.vala"
		_tmp0_ = e;
#line 89 "GomSerializationTest.vala"
		_tmp1_ = _tmp0_->message;
#line 89 "GomSerializationTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 89 "GomSerializationTest.vala"
		_tmp3_ = _tmp2_;
#line 89 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:89: %s", _tmp3_);
#line 89 "GomSerializationTest.vala"
		_g_free0 (_tmp3_);
#line 88 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 3448 "GomSerializationTest.c"
	}
	__finally158:
#line 88 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 88 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 88 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 3457 "GomSerializationTest.c"
	}
#line 87 "GomSerializationTest.vala"
	return obj;
#line 3461 "GomSerializationTest.c"
}

static void
operation_map_class_init (OperationMapClass * klass,
                          gpointer klass_data)
{
#line 86 "GomSerializationTest.vala"
	operation_map_parent_class = g_type_class_peek_parent (klass);
#line 86 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = operation_map_constructor;
#line 3472 "GomSerializationTest.c"
}

static void
operation_map_instance_init (OperationMap * self,
                             gpointer klass)
{
}

GType
operation_map_get_type (void)
{
	static volatile gsize operation_map_type_id__volatile = 0;
	if (g_once_init_enter (&operation_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (OperationMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) operation_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (OperationMap), 0, (GInstanceInitFunc) operation_map_instance_init, NULL };
		GType operation_map_type_id;
		operation_map_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_PAIRED_MAP, "OperationMap", &g_define_type_info, 0);
		g_once_init_leave (&operation_map_type_id__volatile, operation_map_type_id);
	}
	return operation_map_type_id__volatile;
}

static void
operation_class_init (OperationClass * klass,
                      gpointer klass_data)
{
#line 78 "GomSerializationTest.vala"
	operation_parent_class = g_type_class_peek_parent (klass);
#line 78 "GomSerializationTest.vala"
	g_type_class_adjust_private_offset (klass, &Operation_private_offset);
#line 78 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_operation_get_property;
#line 78 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_operation_set_property;
#line 78 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = operation_constructor;
#line 78 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = operation_finalize;
#line 78 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), OPERATION_ID_PROPERTY, operation_properties[OPERATION_ID_PROPERTY] = g_param_spec_string ("id", "::ID", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 78 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), OPERATION_CODE_PROPERTY, operation_properties[OPERATION_CODE_PROPERTY] = g_param_spec_string ("code", "::Code", "code", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3514 "GomSerializationTest.c"
}

static void
operation_gxml_mappeable_element_pair_key_interface_init (GXmlMappeableElementPairKeyIface * iface,
                                                          gpointer iface_data)
{
#line 78 "GomSerializationTest.vala"
	operation_gxml_mappeable_element_pair_key_parent_iface = g_type_interface_peek_parent (iface);
#line 78 "GomSerializationTest.vala"
	iface->get_map_primary_key = (gchar* (*) (GXmlMappeableElementPairKey*)) operation_real_get_map_primary_key;
#line 78 "GomSerializationTest.vala"
	iface->get_map_secondary_key = (gchar* (*) (GXmlMappeableElementPairKey*)) operation_real_get_map_secondary_key;
#line 3527 "GomSerializationTest.c"
}

static void
operation_instance_init (Operation * self,
                         gpointer klass)
{
#line 78 "GomSerializationTest.vala"
	self->priv = operation_get_instance_private (self);
#line 3536 "GomSerializationTest.c"
}

static void
operation_finalize (GObject * obj)
{
	Operation * self;
#line 78 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_OPERATION, Operation);
#line 80 "GomSerializationTest.vala"
	_g_free0 (self->priv->_id);
#line 82 "GomSerializationTest.vala"
	_g_free0 (self->priv->_code);
#line 78 "GomSerializationTest.vala"
	G_OBJECT_CLASS (operation_parent_class)->finalize (obj);
#line 3551 "GomSerializationTest.c"
}

GType
operation_get_type (void)
{
	static volatile gsize operation_type_id__volatile = 0;
	if (g_once_init_enter (&operation_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (OperationClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) operation_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Operation), 0, (GInstanceInitFunc) operation_instance_init, NULL };
		static const GInterfaceInfo gxml_mappeable_element_pair_key_info = { (GInterfaceInitFunc) operation_gxml_mappeable_element_pair_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType operation_type_id;
		operation_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "Operation", &g_define_type_info, 0);
		g_type_add_interface_static (operation_type_id, GXML_TYPE_MAPPEABLE_ELEMENT_PAIR_KEY, &gxml_mappeable_element_pair_key_info);
		Operation_private_offset = g_type_add_instance_private (operation_type_id, sizeof (OperationPrivate));
		g_once_init_leave (&operation_type_id__volatile, operation_type_id);
	}
	return operation_type_id__volatile;
}

static void
_vala_operation_get_property (GObject * object,
                              guint property_id,
                              GValue * value,
                              GParamSpec * pspec)
{
	Operation * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_OPERATION, Operation);
#line 78 "GomSerializationTest.vala"
	switch (property_id) {
#line 78 "GomSerializationTest.vala"
		case OPERATION_ID_PROPERTY:
#line 78 "GomSerializationTest.vala"
		g_value_set_string (value, operation_get_id (self));
#line 78 "GomSerializationTest.vala"
		break;
#line 78 "GomSerializationTest.vala"
		case OPERATION_CODE_PROPERTY:
#line 78 "GomSerializationTest.vala"
		g_value_set_string (value, operation_get_code (self));
#line 78 "GomSerializationTest.vala"
		break;
#line 3592 "GomSerializationTest.c"
		default:
#line 78 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 78 "GomSerializationTest.vala"
		break;
#line 3598 "GomSerializationTest.c"
	}
}

static void
_vala_operation_set_property (GObject * object,
                              guint property_id,
                              const GValue * value,
                              GParamSpec * pspec)
{
	Operation * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_OPERATION, Operation);
#line 78 "GomSerializationTest.vala"
	switch (property_id) {
#line 78 "GomSerializationTest.vala"
		case OPERATION_ID_PROPERTY:
#line 78 "GomSerializationTest.vala"
		operation_set_id (self, g_value_get_string (value));
#line 78 "GomSerializationTest.vala"
		break;
#line 78 "GomSerializationTest.vala"
		case OPERATION_CODE_PROPERTY:
#line 78 "GomSerializationTest.vala"
		operation_set_code (self, g_value_get_string (value));
#line 78 "GomSerializationTest.vala"
		break;
#line 3624 "GomSerializationTest.c"
		default:
#line 78 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 78 "GomSerializationTest.vala"
		break;
#line 3630 "GomSerializationTest.c"
	}
}

GomName*
gom_name_construct (GType object_type)
{
	GomName * self = NULL;
#line 93 "GomSerializationTest.vala"
	self = (GomName*) gxml_gom_element_construct (object_type);
#line 93 "GomSerializationTest.vala"
	return self;
#line 3642 "GomSerializationTest.c"
}

GomName*
gom_name_new (void)
{
#line 93 "GomSerializationTest.vala"
	return gom_name_construct (TYPE_GOM_NAME);
#line 3650 "GomSerializationTest.c"
}

static GObject *
gom_name_constructor (GType type,
                      guint n_construct_properties,
                      GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomName * self;
	GError* _inner_error0_ = NULL;
#line 95 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_name_parent_class);
#line 95 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 95 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_NAME, GomName);
#line 3668 "GomSerializationTest.c"
	{
#line 95 "GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Name");
#line 3672 "GomSerializationTest.c"
	}
	goto __finally159;
	__catch159_g_error:
	{
#line 95 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 95 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 95 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 3683 "GomSerializationTest.c"
	}
	__finally159:
#line 95 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 95 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 95 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 3692 "GomSerializationTest.c"
	}
#line 95 "GomSerializationTest.vala"
	return obj;
#line 3696 "GomSerializationTest.c"
}

static void
gom_name_class_init (GomNameClass * klass,
                     gpointer klass_data)
{
#line 93 "GomSerializationTest.vala"
	gom_name_parent_class = g_type_class_peek_parent (klass);
#line 93 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_name_constructor;
#line 3707 "GomSerializationTest.c"
}

static void
gom_name_instance_init (GomName * self,
                        gpointer klass)
{
}

GType
gom_name_get_type (void)
{
	static volatile gsize gom_name_type_id__volatile = 0;
	if (g_once_init_enter (&gom_name_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomNameClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_name_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomName), 0, (GInstanceInitFunc) gom_name_instance_init, NULL };
		GType gom_name_type_id;
		gom_name_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomName", &g_define_type_info, 0);
		g_once_init_leave (&gom_name_type_id__volatile, gom_name_type_id);
	}
	return gom_name_type_id__volatile;
}

GomEmail*
gom_email_construct (GType object_type)
{
	GomEmail * self = NULL;
#line 98 "GomSerializationTest.vala"
	self = (GomEmail*) gxml_gom_element_construct (object_type);
#line 98 "GomSerializationTest.vala"
	return self;
#line 3737 "GomSerializationTest.c"
}

GomEmail*
gom_email_new (void)
{
#line 98 "GomSerializationTest.vala"
	return gom_email_construct (TYPE_GOM_EMAIL);
#line 3745 "GomSerializationTest.c"
}

static GObject *
gom_email_constructor (GType type,
                       guint n_construct_properties,
                       GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomEmail * self;
	GError* _inner_error0_ = NULL;
#line 100 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_email_parent_class);
#line 100 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 100 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_EMAIL, GomEmail);
#line 3763 "GomSerializationTest.c"
	{
#line 100 "GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Email");
#line 3767 "GomSerializationTest.c"
	}
	goto __finally160;
	__catch160_g_error:
	{
#line 100 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 100 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 100 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 3778 "GomSerializationTest.c"
	}
	__finally160:
#line 100 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 100 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 100 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 3787 "GomSerializationTest.c"
	}
#line 100 "GomSerializationTest.vala"
	return obj;
#line 3791 "GomSerializationTest.c"
}

static void
gom_email_class_init (GomEmailClass * klass,
                      gpointer klass_data)
{
#line 98 "GomSerializationTest.vala"
	gom_email_parent_class = g_type_class_peek_parent (klass);
#line 98 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_email_constructor;
#line 3802 "GomSerializationTest.c"
}

static void
gom_email_instance_init (GomEmail * self,
                         gpointer klass)
{
}

GType
gom_email_get_type (void)
{
	static volatile gsize gom_email_type_id__volatile = 0;
	if (g_once_init_enter (&gom_email_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomEmailClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_email_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomEmail), 0, (GInstanceInitFunc) gom_email_instance_init, NULL };
		GType gom_email_type_id;
		gom_email_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomEmail", &g_define_type_info, 0);
		g_once_init_leave (&gom_email_type_id__volatile, gom_email_type_id);
	}
	return gom_email_type_id__volatile;
}

static inline gpointer
gom_author_get_instance_private (GomAuthor* self)
{
	return G_STRUCT_MEMBER_P (self, GomAuthor_private_offset);
}

GomAuthor*
gom_author_construct (GType object_type)
{
	GomAuthor * self = NULL;
#line 103 "GomSerializationTest.vala"
	self = (GomAuthor*) gxml_gom_element_construct (object_type);
#line 103 "GomSerializationTest.vala"
	return self;
#line 3838 "GomSerializationTest.c"
}

GomAuthor*
gom_author_new (void)
{
#line 103 "GomSerializationTest.vala"
	return gom_author_construct (TYPE_GOM_AUTHOR);
#line 3846 "GomSerializationTest.c"
}

GomName*
gom_author_get_name (GomAuthor* self)
{
	GomName* result;
	GomName* _tmp0_;
#line 105 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 105 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_name;
#line 105 "GomSerializationTest.vala"
	result = _tmp0_;
#line 105 "GomSerializationTest.vala"
	return result;
#line 3862 "GomSerializationTest.c"
}

void
gom_author_set_name (GomAuthor* self,
                     GomName* value)
{
#line 105 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 105 "GomSerializationTest.vala"
	if (gom_author_get_name (self) != value) {
#line 3873 "GomSerializationTest.c"
		GomName* _tmp0_;
#line 105 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 105 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_name);
#line 105 "GomSerializationTest.vala"
		self->priv->_name = _tmp0_;
#line 105 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_author_properties[GOM_AUTHOR_NAME_PROPERTY]);
#line 3883 "GomSerializationTest.c"
	}
}

GomEmail*
gom_author_get_email (GomAuthor* self)
{
	GomEmail* result;
	GomEmail* _tmp0_;
#line 106 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 106 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_email;
#line 106 "GomSerializationTest.vala"
	result = _tmp0_;
#line 106 "GomSerializationTest.vala"
	return result;
#line 3900 "GomSerializationTest.c"
}

void
gom_author_set_email (GomAuthor* self,
                      GomEmail* value)
{
#line 106 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 106 "GomSerializationTest.vala"
	if (gom_author_get_email (self) != value) {
#line 3911 "GomSerializationTest.c"
		GomEmail* _tmp0_;
#line 106 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 106 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_email);
#line 106 "GomSerializationTest.vala"
		self->priv->_email = _tmp0_;
#line 106 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_author_properties[GOM_AUTHOR_EMAIL_PROPERTY]);
#line 3921 "GomSerializationTest.c"
	}
}

static GObject *
gom_author_constructor (GType type,
                        guint n_construct_properties,
                        GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomAuthor * self;
	GError* _inner_error0_ = NULL;
#line 107 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_author_parent_class);
#line 107 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 107 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_AUTHOR, GomAuthor);
#line 3940 "GomSerializationTest.c"
	{
#line 107 "GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Author");
#line 3944 "GomSerializationTest.c"
	}
	goto __finally161;
	__catch161_g_error:
	{
#line 107 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 107 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 107 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 3955 "GomSerializationTest.c"
	}
	__finally161:
#line 107 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 107 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 107 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 3964 "GomSerializationTest.c"
	}
#line 107 "GomSerializationTest.vala"
	return obj;
#line 3968 "GomSerializationTest.c"
}

GomAuthorArray*
gom_author_array_construct (GType object_type)
{
	GomAuthorArray * self = NULL;
#line 108 "GomSerializationTest.vala"
	self = (GomAuthorArray*) gxml_gom_array_list_construct (object_type);
#line 108 "GomSerializationTest.vala"
	return self;
#line 3979 "GomSerializationTest.c"
}

GomAuthorArray*
gom_author_array_new (void)
{
#line 108 "GomSerializationTest.vala"
	return gom_author_array_construct (GOM_AUTHOR_TYPE_ARRAY);
#line 3987 "GomSerializationTest.c"
}

static GObject *
gom_author_array_constructor (GType type,
                              guint n_construct_properties,
                              GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomAuthorArray * self;
	GError* _inner_error0_ = NULL;
#line 109 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_author_array_parent_class);
#line 109 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 109 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_AUTHOR_TYPE_ARRAY, GomAuthorArray);
#line 4005 "GomSerializationTest.c"
	{
#line 109 "GomSerializationTest.vala"
		gxml_collection_initialize ((GXmlCollection*) self, TYPE_GOM_AUTHOR, &_inner_error0_);
#line 109 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 4011 "GomSerializationTest.c"
			goto __catch162_g_error;
		}
	}
	goto __finally162;
	__catch162_g_error:
	{
#line 109 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 109 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 110 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 4024 "GomSerializationTest.c"
	}
	__finally162:
#line 109 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 109 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 109 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 4033 "GomSerializationTest.c"
	}
#line 109 "GomSerializationTest.vala"
	return obj;
#line 4037 "GomSerializationTest.c"
}

static void
gom_author_array_class_init (GomAuthorArrayClass * klass,
                             gpointer klass_data)
{
#line 108 "GomSerializationTest.vala"
	gom_author_array_parent_class = g_type_class_peek_parent (klass);
#line 108 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_author_array_constructor;
#line 4048 "GomSerializationTest.c"
}

static void
gom_author_array_instance_init (GomAuthorArray * self,
                                gpointer klass)
{
}

GType
gom_author_array_get_type (void)
{
	static volatile gsize gom_author_array_type_id__volatile = 0;
	if (g_once_init_enter (&gom_author_array_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomAuthorArrayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_author_array_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomAuthorArray), 0, (GInstanceInitFunc) gom_author_array_instance_init, NULL };
		GType gom_author_array_type_id;
		gom_author_array_type_id = g_type_register_static (GXML_TYPE_GOM_ARRAY_LIST, "GomAuthorArray", &g_define_type_info, 0);
		g_once_init_leave (&gom_author_array_type_id__volatile, gom_author_array_type_id);
	}
	return gom_author_array_type_id__volatile;
}

static void
gom_author_class_init (GomAuthorClass * klass,
                       gpointer klass_data)
{
#line 103 "GomSerializationTest.vala"
	gom_author_parent_class = g_type_class_peek_parent (klass);
#line 103 "GomSerializationTest.vala"
	g_type_class_adjust_private_offset (klass, &GomAuthor_private_offset);
#line 103 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_author_get_property;
#line 103 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_author_set_property;
#line 103 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_author_constructor;
#line 103 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_author_finalize;
#line 103 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_AUTHOR_NAME_PROPERTY, gom_author_properties[GOM_AUTHOR_NAME_PROPERTY] = g_param_spec_object ("name", "name", "name", TYPE_GOM_NAME, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 103 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_AUTHOR_EMAIL_PROPERTY, gom_author_properties[GOM_AUTHOR_EMAIL_PROPERTY] = g_param_spec_object ("email", "email", "email", TYPE_GOM_EMAIL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4090 "GomSerializationTest.c"
}

static void
gom_author_instance_init (GomAuthor * self,
                          gpointer klass)
{
#line 103 "GomSerializationTest.vala"
	self->priv = gom_author_get_instance_private (self);
#line 4099 "GomSerializationTest.c"
}

static void
gom_author_finalize (GObject * obj)
{
	GomAuthor * self;
#line 103 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_AUTHOR, GomAuthor);
#line 105 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_name);
#line 106 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_email);
#line 103 "GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_author_parent_class)->finalize (obj);
#line 4114 "GomSerializationTest.c"
}

GType
gom_author_get_type (void)
{
	static volatile gsize gom_author_type_id__volatile = 0;
	if (g_once_init_enter (&gom_author_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomAuthorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_author_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomAuthor), 0, (GInstanceInitFunc) gom_author_instance_init, NULL };
		GType gom_author_type_id;
		gom_author_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomAuthor", &g_define_type_info, 0);
		GomAuthor_private_offset = g_type_add_instance_private (gom_author_type_id, sizeof (GomAuthorPrivate));
		g_once_init_leave (&gom_author_type_id__volatile, gom_author_type_id);
	}
	return gom_author_type_id__volatile;
}

static void
_vala_gom_author_get_property (GObject * object,
                               guint property_id,
                               GValue * value,
                               GParamSpec * pspec)
{
	GomAuthor * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_AUTHOR, GomAuthor);
#line 103 "GomSerializationTest.vala"
	switch (property_id) {
#line 103 "GomSerializationTest.vala"
		case GOM_AUTHOR_NAME_PROPERTY:
#line 103 "GomSerializationTest.vala"
		g_value_set_object (value, gom_author_get_name (self));
#line 103 "GomSerializationTest.vala"
		break;
#line 103 "GomSerializationTest.vala"
		case GOM_AUTHOR_EMAIL_PROPERTY:
#line 103 "GomSerializationTest.vala"
		g_value_set_object (value, gom_author_get_email (self));
#line 103 "GomSerializationTest.vala"
		break;
#line 4153 "GomSerializationTest.c"
		default:
#line 103 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 103 "GomSerializationTest.vala"
		break;
#line 4159 "GomSerializationTest.c"
	}
}

static void
_vala_gom_author_set_property (GObject * object,
                               guint property_id,
                               const GValue * value,
                               GParamSpec * pspec)
{
	GomAuthor * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_AUTHOR, GomAuthor);
#line 103 "GomSerializationTest.vala"
	switch (property_id) {
#line 103 "GomSerializationTest.vala"
		case GOM_AUTHOR_NAME_PROPERTY:
#line 103 "GomSerializationTest.vala"
		gom_author_set_name (self, g_value_get_object (value));
#line 103 "GomSerializationTest.vala"
		break;
#line 103 "GomSerializationTest.vala"
		case GOM_AUTHOR_EMAIL_PROPERTY:
#line 103 "GomSerializationTest.vala"
		gom_author_set_email (self, g_value_get_object (value));
#line 103 "GomSerializationTest.vala"
		break;
#line 4185 "GomSerializationTest.c"
		default:
#line 103 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 103 "GomSerializationTest.vala"
		break;
#line 4191 "GomSerializationTest.c"
	}
}

static inline gpointer
gom_authors_get_instance_private (GomAuthors* self)
{
	return G_STRUCT_MEMBER_P (self, GomAuthors_private_offset);
}

GomAuthors*
gom_authors_construct (GType object_type)
{
	GomAuthors * self = NULL;
#line 114 "GomSerializationTest.vala"
	self = (GomAuthors*) gxml_gom_element_construct (object_type);
#line 114 "GomSerializationTest.vala"
	return self;
#line 4209 "GomSerializationTest.c"
}

GomAuthors*
gom_authors_new (void)
{
#line 114 "GomSerializationTest.vala"
	return gom_authors_construct (TYPE_GOM_AUTHORS);
#line 4217 "GomSerializationTest.c"
}

const gchar*
gom_authors_get_number (GomAuthors* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 116 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 116 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_number;
#line 116 "GomSerializationTest.vala"
	result = _tmp0_;
#line 116 "GomSerializationTest.vala"
	return result;
#line 4233 "GomSerializationTest.c"
}

void
gom_authors_set_number (GomAuthors* self,
                        const gchar* value)
{
#line 116 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 116 "GomSerializationTest.vala"
	if (g_strcmp0 (value, gom_authors_get_number (self)) != 0) {
#line 4244 "GomSerializationTest.c"
		gchar* _tmp0_;
#line 116 "GomSerializationTest.vala"
		_tmp0_ = g_strdup (value);
#line 116 "GomSerializationTest.vala"
		_g_free0 (self->priv->_number);
#line 116 "GomSerializationTest.vala"
		self->priv->_number = _tmp0_;
#line 116 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_authors_properties[GOM_AUTHORS_NUMBER_PROPERTY]);
#line 4254 "GomSerializationTest.c"
	}
}

GomAuthorArray*
gom_authors_get_array (GomAuthors* self)
{
	GomAuthorArray* result;
	GomAuthorArray* _tmp0_;
#line 118 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 118 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_array;
#line 118 "GomSerializationTest.vala"
	result = _tmp0_;
#line 118 "GomSerializationTest.vala"
	return result;
#line 4271 "GomSerializationTest.c"
}

void
gom_authors_set_array (GomAuthors* self,
                       GomAuthorArray* value)
{
#line 118 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 118 "GomSerializationTest.vala"
	if (gom_authors_get_array (self) != value) {
#line 4282 "GomSerializationTest.c"
		GomAuthorArray* _tmp0_;
#line 118 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 118 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_array);
#line 118 "GomSerializationTest.vala"
		self->priv->_array = _tmp0_;
#line 118 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_authors_properties[GOM_AUTHORS_ARRAY_PROPERTY]);
#line 4292 "GomSerializationTest.c"
	}
}

static GObject *
gom_authors_constructor (GType type,
                         guint n_construct_properties,
                         GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomAuthors * self;
	GError* _inner_error0_ = NULL;
#line 117 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_authors_parent_class);
#line 117 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 117 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_AUTHORS, GomAuthors);
#line 4311 "GomSerializationTest.c"
	{
#line 117 "GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Authors");
#line 4315 "GomSerializationTest.c"
	}
	goto __finally163;
	__catch163_g_error:
	{
#line 117 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 117 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 117 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 4326 "GomSerializationTest.c"
	}
	__finally163:
#line 117 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 117 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 117 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 4335 "GomSerializationTest.c"
	}
#line 117 "GomSerializationTest.vala"
	return obj;
#line 4339 "GomSerializationTest.c"
}

static void
gom_authors_class_init (GomAuthorsClass * klass,
                        gpointer klass_data)
{
#line 114 "GomSerializationTest.vala"
	gom_authors_parent_class = g_type_class_peek_parent (klass);
#line 114 "GomSerializationTest.vala"
	g_type_class_adjust_private_offset (klass, &GomAuthors_private_offset);
#line 114 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_authors_get_property;
#line 114 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_authors_set_property;
#line 114 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_authors_constructor;
#line 114 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_authors_finalize;
#line 114 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_AUTHORS_NUMBER_PROPERTY, gom_authors_properties[GOM_AUTHORS_NUMBER_PROPERTY] = g_param_spec_string ("number", "number", "number", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 114 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_AUTHORS_ARRAY_PROPERTY, gom_authors_properties[GOM_AUTHORS_ARRAY_PROPERTY] = g_param_spec_object ("array", "array", "array", GOM_AUTHOR_TYPE_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4362 "GomSerializationTest.c"
}

static void
gom_authors_instance_init (GomAuthors * self,
                           gpointer klass)
{
#line 114 "GomSerializationTest.vala"
	self->priv = gom_authors_get_instance_private (self);
#line 4371 "GomSerializationTest.c"
}

static void
gom_authors_finalize (GObject * obj)
{
	GomAuthors * self;
#line 114 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_AUTHORS, GomAuthors);
#line 116 "GomSerializationTest.vala"
	_g_free0 (self->priv->_number);
#line 118 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_array);
#line 114 "GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_authors_parent_class)->finalize (obj);
#line 4386 "GomSerializationTest.c"
}

GType
gom_authors_get_type (void)
{
	static volatile gsize gom_authors_type_id__volatile = 0;
	if (g_once_init_enter (&gom_authors_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomAuthorsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_authors_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomAuthors), 0, (GInstanceInitFunc) gom_authors_instance_init, NULL };
		GType gom_authors_type_id;
		gom_authors_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomAuthors", &g_define_type_info, 0);
		GomAuthors_private_offset = g_type_add_instance_private (gom_authors_type_id, sizeof (GomAuthorsPrivate));
		g_once_init_leave (&gom_authors_type_id__volatile, gom_authors_type_id);
	}
	return gom_authors_type_id__volatile;
}

static void
_vala_gom_authors_get_property (GObject * object,
                                guint property_id,
                                GValue * value,
                                GParamSpec * pspec)
{
	GomAuthors * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_AUTHORS, GomAuthors);
#line 114 "GomSerializationTest.vala"
	switch (property_id) {
#line 114 "GomSerializationTest.vala"
		case GOM_AUTHORS_NUMBER_PROPERTY:
#line 114 "GomSerializationTest.vala"
		g_value_set_string (value, gom_authors_get_number (self));
#line 114 "GomSerializationTest.vala"
		break;
#line 114 "GomSerializationTest.vala"
		case GOM_AUTHORS_ARRAY_PROPERTY:
#line 114 "GomSerializationTest.vala"
		g_value_set_object (value, gom_authors_get_array (self));
#line 114 "GomSerializationTest.vala"
		break;
#line 4425 "GomSerializationTest.c"
		default:
#line 114 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 114 "GomSerializationTest.vala"
		break;
#line 4431 "GomSerializationTest.c"
	}
}

static void
_vala_gom_authors_set_property (GObject * object,
                                guint property_id,
                                const GValue * value,
                                GParamSpec * pspec)
{
	GomAuthors * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_AUTHORS, GomAuthors);
#line 114 "GomSerializationTest.vala"
	switch (property_id) {
#line 114 "GomSerializationTest.vala"
		case GOM_AUTHORS_NUMBER_PROPERTY:
#line 114 "GomSerializationTest.vala"
		gom_authors_set_number (self, g_value_get_string (value));
#line 114 "GomSerializationTest.vala"
		break;
#line 114 "GomSerializationTest.vala"
		case GOM_AUTHORS_ARRAY_PROPERTY:
#line 114 "GomSerializationTest.vala"
		gom_authors_set_array (self, g_value_get_object (value));
#line 114 "GomSerializationTest.vala"
		break;
#line 4457 "GomSerializationTest.c"
		default:
#line 114 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 114 "GomSerializationTest.vala"
		break;
#line 4463 "GomSerializationTest.c"
	}
}

static inline gpointer
gom_inventory_get_instance_private (GomInventory* self)
{
	return G_STRUCT_MEMBER_P (self, GomInventory_private_offset);
}

GomInventory*
gom_inventory_construct (GType object_type)
{
	GomInventory * self = NULL;
#line 121 "GomSerializationTest.vala"
	self = (GomInventory*) gxml_gom_element_construct (object_type);
#line 121 "GomSerializationTest.vala"
	return self;
#line 4481 "GomSerializationTest.c"
}

GomInventory*
gom_inventory_new (void)
{
#line 121 "GomSerializationTest.vala"
	return gom_inventory_construct (TYPE_GOM_INVENTORY);
#line 4489 "GomSerializationTest.c"
}

gint
gom_inventory_get_number (GomInventory* self)
{
	gint result;
#line 124 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 124 "GomSerializationTest.vala"
	result = self->priv->_number;
#line 124 "GomSerializationTest.vala"
	return result;
#line 4502 "GomSerializationTest.c"
}

void
gom_inventory_set_number (GomInventory* self,
                          gint value)
{
#line 124 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 124 "GomSerializationTest.vala"
	if (gom_inventory_get_number (self) != value) {
#line 124 "GomSerializationTest.vala"
		self->priv->_number = value;
#line 124 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_inventory_properties[GOM_INVENTORY_NUMBER_PROPERTY]);
#line 4517 "GomSerializationTest.c"
	}
}

gint
gom_inventory_get_row (GomInventory* self)
{
	gint result;
#line 126 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 126 "GomSerializationTest.vala"
	result = self->priv->_row;
#line 126 "GomSerializationTest.vala"
	return result;
#line 4531 "GomSerializationTest.c"
}

void
gom_inventory_set_row (GomInventory* self,
                       gint value)
{
#line 126 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 126 "GomSerializationTest.vala"
	if (gom_inventory_get_row (self) != value) {
#line 126 "GomSerializationTest.vala"
		self->priv->_row = value;
#line 126 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_inventory_properties[GOM_INVENTORY_ROW_PROPERTY]);
#line 4546 "GomSerializationTest.c"
	}
}

const gchar*
gom_inventory_get_inventory (GomInventory* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 128 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 128 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_inventory;
#line 128 "GomSerializationTest.vala"
	result = _tmp0_;
#line 128 "GomSerializationTest.vala"
	return result;
#line 4563 "GomSerializationTest.c"
}

void
gom_inventory_set_inventory (GomInventory* self,
                             const gchar* value)
{
#line 128 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 128 "GomSerializationTest.vala"
	if (g_strcmp0 (value, gom_inventory_get_inventory (self)) != 0) {
#line 4574 "GomSerializationTest.c"
		gchar* _tmp0_;
#line 128 "GomSerializationTest.vala"
		_tmp0_ = g_strdup (value);
#line 128 "GomSerializationTest.vala"
		_g_free0 (self->priv->_inventory);
#line 128 "GomSerializationTest.vala"
		self->priv->_inventory = _tmp0_;
#line 128 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_inventory_properties[GOM_INVENTORY_INVENTORY_PROPERTY]);
#line 4584 "GomSerializationTest.c"
	}
}

static GObject *
gom_inventory_constructor (GType type,
                           guint n_construct_properties,
                           GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomInventory * self;
	GError* _inner_error0_ = NULL;
#line 129 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_inventory_parent_class);
#line 129 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 129 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_INVENTORY, GomInventory);
#line 4603 "GomSerializationTest.c"
	{
#line 129 "GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Inventory");
#line 4607 "GomSerializationTest.c"
	}
	goto __finally164;
	__catch164_g_error:
	{
#line 129 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 129 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 129 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 4618 "GomSerializationTest.c"
	}
	__finally164:
#line 129 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 129 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 129 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 4627 "GomSerializationTest.c"
	}
#line 129 "GomSerializationTest.vala"
	return obj;
#line 4631 "GomSerializationTest.c"
}

GomInventoryDualKeyMap*
gom_inventory_dual_key_map_construct (GType object_type)
{
	GomInventoryDualKeyMap * self = NULL;
#line 131 "GomSerializationTest.vala"
	self = (GomInventoryDualKeyMap*) gxml_gom_hash_map_construct (object_type);
#line 131 "GomSerializationTest.vala"
	return self;
#line 4642 "GomSerializationTest.c"
}

GomInventoryDualKeyMap*
gom_inventory_dual_key_map_new (void)
{
#line 131 "GomSerializationTest.vala"
	return gom_inventory_dual_key_map_construct (GOM_INVENTORY_TYPE_DUAL_KEY_MAP);
#line 4650 "GomSerializationTest.c"
}

static GObject *
gom_inventory_dual_key_map_constructor (GType type,
                                        guint n_construct_properties,
                                        GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomInventoryDualKeyMap * self;
	GError* _inner_error0_ = NULL;
#line 132 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_inventory_dual_key_map_parent_class);
#line 132 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 132 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_INVENTORY_TYPE_DUAL_KEY_MAP, GomInventoryDualKeyMap);
#line 4668 "GomSerializationTest.c"
	{
#line 133 "GomSerializationTest.vala"
		gxml_gom_hash_map_initialize_with_key ((GXmlGomHashMap*) self, TYPE_GOM_INVENTORY, "number", &_inner_error0_);
#line 133 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 4674 "GomSerializationTest.c"
			goto __catch165_g_error;
		}
	}
	goto __finally165;
	__catch165_g_error:
	{
#line 133 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 133 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 134 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 4687 "GomSerializationTest.c"
	}
	__finally165:
#line 133 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 133 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 133 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 4696 "GomSerializationTest.c"
	}
#line 132 "GomSerializationTest.vala"
	return obj;
#line 4700 "GomSerializationTest.c"
}

static void
gom_inventory_dual_key_map_class_init (GomInventoryDualKeyMapClass * klass,
                                       gpointer klass_data)
{
#line 131 "GomSerializationTest.vala"
	gom_inventory_dual_key_map_parent_class = g_type_class_peek_parent (klass);
#line 131 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_inventory_dual_key_map_constructor;
#line 4711 "GomSerializationTest.c"
}

static void
gom_inventory_dual_key_map_instance_init (GomInventoryDualKeyMap * self,
                                          gpointer klass)
{
}

GType
gom_inventory_dual_key_map_get_type (void)
{
	static volatile gsize gom_inventory_dual_key_map_type_id__volatile = 0;
	if (g_once_init_enter (&gom_inventory_dual_key_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomInventoryDualKeyMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_inventory_dual_key_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomInventoryDualKeyMap), 0, (GInstanceInitFunc) gom_inventory_dual_key_map_instance_init, NULL };
		GType gom_inventory_dual_key_map_type_id;
		gom_inventory_dual_key_map_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_MAP, "GomInventoryDualKeyMap", &g_define_type_info, 0);
		g_once_init_leave (&gom_inventory_dual_key_map_type_id__volatile, gom_inventory_dual_key_map_type_id);
	}
	return gom_inventory_dual_key_map_type_id__volatile;
}

static void
gom_inventory_class_init (GomInventoryClass * klass,
                          gpointer klass_data)
{
#line 121 "GomSerializationTest.vala"
	gom_inventory_parent_class = g_type_class_peek_parent (klass);
#line 121 "GomSerializationTest.vala"
	g_type_class_adjust_private_offset (klass, &GomInventory_private_offset);
#line 121 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_inventory_get_property;
#line 121 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_inventory_set_property;
#line 121 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_inventory_constructor;
#line 121 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_inventory_finalize;
#line 121 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_INVENTORY_NUMBER_PROPERTY, gom_inventory_properties[GOM_INVENTORY_NUMBER_PROPERTY] = g_param_spec_int ("number", "::Number", "number", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 121 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_INVENTORY_ROW_PROPERTY, gom_inventory_properties[GOM_INVENTORY_ROW_PROPERTY] = g_param_spec_int ("row", "::Row", "row", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 121 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_INVENTORY_INVENTORY_PROPERTY, gom_inventory_properties[GOM_INVENTORY_INVENTORY_PROPERTY] = g_param_spec_string ("inventory", "::Inventory", "inventory", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4755 "GomSerializationTest.c"
}

static void
gom_inventory_instance_init (GomInventory * self,
                             gpointer klass)
{
#line 121 "GomSerializationTest.vala"
	self->priv = gom_inventory_get_instance_private (self);
#line 4764 "GomSerializationTest.c"
}

static void
gom_inventory_finalize (GObject * obj)
{
	GomInventory * self;
#line 121 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_INVENTORY, GomInventory);
#line 128 "GomSerializationTest.vala"
	_g_free0 (self->priv->_inventory);
#line 121 "GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_inventory_parent_class)->finalize (obj);
#line 4777 "GomSerializationTest.c"
}

GType
gom_inventory_get_type (void)
{
	static volatile gsize gom_inventory_type_id__volatile = 0;
	if (g_once_init_enter (&gom_inventory_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomInventoryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_inventory_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomInventory), 0, (GInstanceInitFunc) gom_inventory_instance_init, NULL };
		GType gom_inventory_type_id;
		gom_inventory_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomInventory", &g_define_type_info, 0);
		GomInventory_private_offset = g_type_add_instance_private (gom_inventory_type_id, sizeof (GomInventoryPrivate));
		g_once_init_leave (&gom_inventory_type_id__volatile, gom_inventory_type_id);
	}
	return gom_inventory_type_id__volatile;
}

static void
_vala_gom_inventory_get_property (GObject * object,
                                  guint property_id,
                                  GValue * value,
                                  GParamSpec * pspec)
{
	GomInventory * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_INVENTORY, GomInventory);
#line 121 "GomSerializationTest.vala"
	switch (property_id) {
#line 121 "GomSerializationTest.vala"
		case GOM_INVENTORY_NUMBER_PROPERTY:
#line 121 "GomSerializationTest.vala"
		g_value_set_int (value, gom_inventory_get_number (self));
#line 121 "GomSerializationTest.vala"
		break;
#line 121 "GomSerializationTest.vala"
		case GOM_INVENTORY_ROW_PROPERTY:
#line 121 "GomSerializationTest.vala"
		g_value_set_int (value, gom_inventory_get_row (self));
#line 121 "GomSerializationTest.vala"
		break;
#line 121 "GomSerializationTest.vala"
		case GOM_INVENTORY_INVENTORY_PROPERTY:
#line 121 "GomSerializationTest.vala"
		g_value_set_string (value, gom_inventory_get_inventory (self));
#line 121 "GomSerializationTest.vala"
		break;
#line 4822 "GomSerializationTest.c"
		default:
#line 121 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 121 "GomSerializationTest.vala"
		break;
#line 4828 "GomSerializationTest.c"
	}
}

static void
_vala_gom_inventory_set_property (GObject * object,
                                  guint property_id,
                                  const GValue * value,
                                  GParamSpec * pspec)
{
	GomInventory * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_INVENTORY, GomInventory);
#line 121 "GomSerializationTest.vala"
	switch (property_id) {
#line 121 "GomSerializationTest.vala"
		case GOM_INVENTORY_NUMBER_PROPERTY:
#line 121 "GomSerializationTest.vala"
		gom_inventory_set_number (self, g_value_get_int (value));
#line 121 "GomSerializationTest.vala"
		break;
#line 121 "GomSerializationTest.vala"
		case GOM_INVENTORY_ROW_PROPERTY:
#line 121 "GomSerializationTest.vala"
		gom_inventory_set_row (self, g_value_get_int (value));
#line 121 "GomSerializationTest.vala"
		break;
#line 121 "GomSerializationTest.vala"
		case GOM_INVENTORY_INVENTORY_PROPERTY:
#line 121 "GomSerializationTest.vala"
		gom_inventory_set_inventory (self, g_value_get_string (value));
#line 121 "GomSerializationTest.vala"
		break;
#line 4860 "GomSerializationTest.c"
		default:
#line 121 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 121 "GomSerializationTest.vala"
		break;
#line 4866 "GomSerializationTest.c"
	}
}

static inline gpointer
gom_category_get_instance_private (GomCategory* self)
{
	return G_STRUCT_MEMBER_P (self, GomCategory_private_offset);
}

GomCategory*
gom_category_construct (GType object_type)
{
	GomCategory * self = NULL;
#line 139 "GomSerializationTest.vala"
	self = (GomCategory*) gxml_gom_element_construct (object_type);
#line 139 "GomSerializationTest.vala"
	return self;
#line 4884 "GomSerializationTest.c"
}

GomCategory*
gom_category_new (void)
{
#line 139 "GomSerializationTest.vala"
	return gom_category_construct (TYPE_GOM_CATEGORY);
#line 4892 "GomSerializationTest.c"
}

const gchar*
gom_category_get_name (GomCategory* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 142 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 142 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_name;
#line 142 "GomSerializationTest.vala"
	result = _tmp0_;
#line 142 "GomSerializationTest.vala"
	return result;
#line 4908 "GomSerializationTest.c"
}

void
gom_category_set_name (GomCategory* self,
                       const gchar* value)
{
#line 142 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 142 "GomSerializationTest.vala"
	if (g_strcmp0 (value, gom_category_get_name (self)) != 0) {
#line 4919 "GomSerializationTest.c"
		gchar* _tmp0_;
#line 142 "GomSerializationTest.vala"
		_tmp0_ = g_strdup (value);
#line 142 "GomSerializationTest.vala"
		_g_free0 (self->priv->_name);
#line 142 "GomSerializationTest.vala"
		self->priv->_name = _tmp0_;
#line 142 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_category_properties[GOM_CATEGORY_NAME_PROPERTY]);
#line 4929 "GomSerializationTest.c"
	}
}

static GObject *
gom_category_constructor (GType type,
                          guint n_construct_properties,
                          GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomCategory * self;
	GError* _inner_error0_ = NULL;
#line 143 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_category_parent_class);
#line 143 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 143 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_CATEGORY, GomCategory);
#line 4948 "GomSerializationTest.c"
	{
#line 143 "GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Category");
#line 4952 "GomSerializationTest.c"
	}
	goto __finally166;
	__catch166_g_error:
	{
#line 143 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 143 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 143 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 4963 "GomSerializationTest.c"
	}
	__finally166:
#line 143 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 143 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 143 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 4972 "GomSerializationTest.c"
	}
#line 143 "GomSerializationTest.vala"
	return obj;
#line 4976 "GomSerializationTest.c"
}

GomCategoryMap*
gom_category_map_construct (GType object_type)
{
	GomCategoryMap * self = NULL;
#line 144 "GomSerializationTest.vala"
	self = (GomCategoryMap*) gxml_gom_hash_map_construct (object_type);
#line 144 "GomSerializationTest.vala"
	return self;
#line 4987 "GomSerializationTest.c"
}

GomCategoryMap*
gom_category_map_new (void)
{
#line 144 "GomSerializationTest.vala"
	return gom_category_map_construct (GOM_CATEGORY_TYPE_MAP);
#line 4995 "GomSerializationTest.c"
}

static GObject *
gom_category_map_constructor (GType type,
                              guint n_construct_properties,
                              GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomCategoryMap * self;
	GError* _inner_error0_ = NULL;
#line 145 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_category_map_parent_class);
#line 145 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 145 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_CATEGORY_TYPE_MAP, GomCategoryMap);
#line 5013 "GomSerializationTest.c"
	{
#line 146 "GomSerializationTest.vala"
		gxml_gom_hash_map_initialize_with_key ((GXmlGomHashMap*) self, TYPE_GOM_CATEGORY, "name", &_inner_error0_);
#line 146 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 5019 "GomSerializationTest.c"
			goto __catch167_g_error;
		}
	}
	goto __finally167;
	__catch167_g_error:
	{
#line 146 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 146 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 147 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 5032 "GomSerializationTest.c"
	}
	__finally167:
#line 146 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 146 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 146 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 5041 "GomSerializationTest.c"
	}
#line 145 "GomSerializationTest.vala"
	return obj;
#line 5045 "GomSerializationTest.c"
}

static void
gom_category_map_class_init (GomCategoryMapClass * klass,
                             gpointer klass_data)
{
#line 144 "GomSerializationTest.vala"
	gom_category_map_parent_class = g_type_class_peek_parent (klass);
#line 144 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_category_map_constructor;
#line 5056 "GomSerializationTest.c"
}

static void
gom_category_map_instance_init (GomCategoryMap * self,
                                gpointer klass)
{
}

GType
gom_category_map_get_type (void)
{
	static volatile gsize gom_category_map_type_id__volatile = 0;
	if (g_once_init_enter (&gom_category_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomCategoryMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_category_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomCategoryMap), 0, (GInstanceInitFunc) gom_category_map_instance_init, NULL };
		GType gom_category_map_type_id;
		gom_category_map_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_MAP, "GomCategoryMap", &g_define_type_info, 0);
		g_once_init_leave (&gom_category_map_type_id__volatile, gom_category_map_type_id);
	}
	return gom_category_map_type_id__volatile;
}

static void
gom_category_class_init (GomCategoryClass * klass,
                         gpointer klass_data)
{
#line 139 "GomSerializationTest.vala"
	gom_category_parent_class = g_type_class_peek_parent (klass);
#line 139 "GomSerializationTest.vala"
	g_type_class_adjust_private_offset (klass, &GomCategory_private_offset);
#line 139 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_category_get_property;
#line 139 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_category_set_property;
#line 139 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_category_constructor;
#line 139 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_category_finalize;
#line 139 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_CATEGORY_NAME_PROPERTY, gom_category_properties[GOM_CATEGORY_NAME_PROPERTY] = g_param_spec_string ("name", "::Name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5096 "GomSerializationTest.c"
}

static void
gom_category_instance_init (GomCategory * self,
                            gpointer klass)
{
#line 139 "GomSerializationTest.vala"
	self->priv = gom_category_get_instance_private (self);
#line 5105 "GomSerializationTest.c"
}

static void
gom_category_finalize (GObject * obj)
{
	GomCategory * self;
#line 139 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_CATEGORY, GomCategory);
#line 142 "GomSerializationTest.vala"
	_g_free0 (self->priv->_name);
#line 139 "GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_category_parent_class)->finalize (obj);
#line 5118 "GomSerializationTest.c"
}

GType
gom_category_get_type (void)
{
	static volatile gsize gom_category_type_id__volatile = 0;
	if (g_once_init_enter (&gom_category_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomCategoryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_category_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomCategory), 0, (GInstanceInitFunc) gom_category_instance_init, NULL };
		GType gom_category_type_id;
		gom_category_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomCategory", &g_define_type_info, 0);
		GomCategory_private_offset = g_type_add_instance_private (gom_category_type_id, sizeof (GomCategoryPrivate));
		g_once_init_leave (&gom_category_type_id__volatile, gom_category_type_id);
	}
	return gom_category_type_id__volatile;
}

static void
_vala_gom_category_get_property (GObject * object,
                                 guint property_id,
                                 GValue * value,
                                 GParamSpec * pspec)
{
	GomCategory * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_CATEGORY, GomCategory);
#line 139 "GomSerializationTest.vala"
	switch (property_id) {
#line 139 "GomSerializationTest.vala"
		case GOM_CATEGORY_NAME_PROPERTY:
#line 139 "GomSerializationTest.vala"
		g_value_set_string (value, gom_category_get_name (self));
#line 139 "GomSerializationTest.vala"
		break;
#line 5151 "GomSerializationTest.c"
		default:
#line 139 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 139 "GomSerializationTest.vala"
		break;
#line 5157 "GomSerializationTest.c"
	}
}

static void
_vala_gom_category_set_property (GObject * object,
                                 guint property_id,
                                 const GValue * value,
                                 GParamSpec * pspec)
{
	GomCategory * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_CATEGORY, GomCategory);
#line 139 "GomSerializationTest.vala"
	switch (property_id) {
#line 139 "GomSerializationTest.vala"
		case GOM_CATEGORY_NAME_PROPERTY:
#line 139 "GomSerializationTest.vala"
		gom_category_set_name (self, g_value_get_string (value));
#line 139 "GomSerializationTest.vala"
		break;
#line 5177 "GomSerializationTest.c"
		default:
#line 139 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 139 "GomSerializationTest.vala"
		break;
#line 5183 "GomSerializationTest.c"
	}
}

static inline gpointer
gom_resume_get_instance_private (GomResume* self)
{
	return G_STRUCT_MEMBER_P (self, GomResume_private_offset);
}

GomResume*
gom_resume_construct (GType object_type)
{
	GomResume * self = NULL;
#line 153 "GomSerializationTest.vala"
	self = (GomResume*) gxml_gom_element_construct (object_type);
#line 153 "GomSerializationTest.vala"
	return self;
#line 5201 "GomSerializationTest.c"
}

GomResume*
gom_resume_new (void)
{
#line 153 "GomSerializationTest.vala"
	return gom_resume_construct (TYPE_GOM_RESUME);
#line 5209 "GomSerializationTest.c"
}

const gchar*
gom_resume_get_chapter (GomResume* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 156 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 156 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_chapter;
#line 156 "GomSerializationTest.vala"
	result = _tmp0_;
#line 156 "GomSerializationTest.vala"
	return result;
#line 5225 "GomSerializationTest.c"
}

void
gom_resume_set_chapter (GomResume* self,
                        const gchar* value)
{
#line 156 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 156 "GomSerializationTest.vala"
	if (g_strcmp0 (value, gom_resume_get_chapter (self)) != 0) {
#line 5236 "GomSerializationTest.c"
		gchar* _tmp0_;
#line 156 "GomSerializationTest.vala"
		_tmp0_ = g_strdup (value);
#line 156 "GomSerializationTest.vala"
		_g_free0 (self->priv->_chapter);
#line 156 "GomSerializationTest.vala"
		self->priv->_chapter = _tmp0_;
#line 156 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_resume_properties[GOM_RESUME_CHAPTER_PROPERTY]);
#line 5246 "GomSerializationTest.c"
	}
}

const gchar*
gom_resume_get_text (GomResume* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 158 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 158 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_text;
#line 158 "GomSerializationTest.vala"
	result = _tmp0_;
#line 158 "GomSerializationTest.vala"
	return result;
#line 5263 "GomSerializationTest.c"
}

void
gom_resume_set_text (GomResume* self,
                     const gchar* value)
{
#line 158 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 158 "GomSerializationTest.vala"
	if (g_strcmp0 (value, gom_resume_get_text (self)) != 0) {
#line 5274 "GomSerializationTest.c"
		gchar* _tmp0_;
#line 158 "GomSerializationTest.vala"
		_tmp0_ = g_strdup (value);
#line 158 "GomSerializationTest.vala"
		_g_free0 (self->priv->_text);
#line 158 "GomSerializationTest.vala"
		self->priv->_text = _tmp0_;
#line 158 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_resume_properties[GOM_RESUME_TEXT_PROPERTY]);
#line 5284 "GomSerializationTest.c"
	}
}

static GObject *
gom_resume_constructor (GType type,
                        guint n_construct_properties,
                        GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomResume * self;
	GError* _inner_error0_ = NULL;
#line 159 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_resume_parent_class);
#line 159 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 159 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_RESUME, GomResume);
#line 5303 "GomSerializationTest.c"
	{
#line 159 "GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Resume");
#line 5307 "GomSerializationTest.c"
	}
	goto __finally168;
	__catch168_g_error:
	{
#line 159 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 159 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 159 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 5318 "GomSerializationTest.c"
	}
	__finally168:
#line 159 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 159 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 159 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 5327 "GomSerializationTest.c"
	}
#line 159 "GomSerializationTest.vala"
	return obj;
#line 5331 "GomSerializationTest.c"
}

GomResumeMap*
gom_resume_map_construct (GType object_type)
{
	GomResumeMap * self = NULL;
#line 160 "GomSerializationTest.vala"
	self = (GomResumeMap*) gxml_gom_hash_map_construct (object_type);
#line 160 "GomSerializationTest.vala"
	return self;
#line 5342 "GomSerializationTest.c"
}

GomResumeMap*
gom_resume_map_new (void)
{
#line 160 "GomSerializationTest.vala"
	return gom_resume_map_construct (GOM_RESUME_TYPE_MAP);
#line 5350 "GomSerializationTest.c"
}

static GObject *
gom_resume_map_constructor (GType type,
                            guint n_construct_properties,
                            GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomResumeMap * self;
	GError* _inner_error0_ = NULL;
#line 161 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_resume_map_parent_class);
#line 161 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 161 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_RESUME_TYPE_MAP, GomResumeMap);
#line 5368 "GomSerializationTest.c"
	{
#line 162 "GomSerializationTest.vala"
		gxml_gom_hash_map_initialize_with_key ((GXmlGomHashMap*) self, TYPE_GOM_RESUME, "chapter", &_inner_error0_);
#line 162 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 5374 "GomSerializationTest.c"
			goto __catch169_g_error;
		}
	}
	goto __finally169;
	__catch169_g_error:
	{
#line 162 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 162 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 163 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 5387 "GomSerializationTest.c"
	}
	__finally169:
#line 162 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 162 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 162 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 5396 "GomSerializationTest.c"
	}
#line 161 "GomSerializationTest.vala"
	return obj;
#line 5400 "GomSerializationTest.c"
}

static void
gom_resume_map_class_init (GomResumeMapClass * klass,
                           gpointer klass_data)
{
#line 160 "GomSerializationTest.vala"
	gom_resume_map_parent_class = g_type_class_peek_parent (klass);
#line 160 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_resume_map_constructor;
#line 5411 "GomSerializationTest.c"
}

static void
gom_resume_map_instance_init (GomResumeMap * self,
                              gpointer klass)
{
}

GType
gom_resume_map_get_type (void)
{
	static volatile gsize gom_resume_map_type_id__volatile = 0;
	if (g_once_init_enter (&gom_resume_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomResumeMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_resume_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomResumeMap), 0, (GInstanceInitFunc) gom_resume_map_instance_init, NULL };
		GType gom_resume_map_type_id;
		gom_resume_map_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_MAP, "GomResumeMap", &g_define_type_info, 0);
		g_once_init_leave (&gom_resume_map_type_id__volatile, gom_resume_map_type_id);
	}
	return gom_resume_map_type_id__volatile;
}

static void
gom_resume_class_init (GomResumeClass * klass,
                       gpointer klass_data)
{
#line 153 "GomSerializationTest.vala"
	gom_resume_parent_class = g_type_class_peek_parent (klass);
#line 153 "GomSerializationTest.vala"
	g_type_class_adjust_private_offset (klass, &GomResume_private_offset);
#line 153 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_resume_get_property;
#line 153 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_resume_set_property;
#line 153 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_resume_constructor;
#line 153 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_resume_finalize;
#line 153 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_RESUME_CHAPTER_PROPERTY, gom_resume_properties[GOM_RESUME_CHAPTER_PROPERTY] = g_param_spec_string ("chapter", "::Chapter", "chapter", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 153 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_RESUME_TEXT_PROPERTY, gom_resume_properties[GOM_RESUME_TEXT_PROPERTY] = g_param_spec_string ("text", "::Text", "text", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5453 "GomSerializationTest.c"
}

static void
gom_resume_instance_init (GomResume * self,
                          gpointer klass)
{
#line 153 "GomSerializationTest.vala"
	self->priv = gom_resume_get_instance_private (self);
#line 5462 "GomSerializationTest.c"
}

static void
gom_resume_finalize (GObject * obj)
{
	GomResume * self;
#line 153 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_RESUME, GomResume);
#line 156 "GomSerializationTest.vala"
	_g_free0 (self->priv->_chapter);
#line 158 "GomSerializationTest.vala"
	_g_free0 (self->priv->_text);
#line 153 "GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_resume_parent_class)->finalize (obj);
#line 5477 "GomSerializationTest.c"
}

GType
gom_resume_get_type (void)
{
	static volatile gsize gom_resume_type_id__volatile = 0;
	if (g_once_init_enter (&gom_resume_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomResumeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_resume_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomResume), 0, (GInstanceInitFunc) gom_resume_instance_init, NULL };
		GType gom_resume_type_id;
		gom_resume_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomResume", &g_define_type_info, 0);
		GomResume_private_offset = g_type_add_instance_private (gom_resume_type_id, sizeof (GomResumePrivate));
		g_once_init_leave (&gom_resume_type_id__volatile, gom_resume_type_id);
	}
	return gom_resume_type_id__volatile;
}

static void
_vala_gom_resume_get_property (GObject * object,
                               guint property_id,
                               GValue * value,
                               GParamSpec * pspec)
{
	GomResume * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_RESUME, GomResume);
#line 153 "GomSerializationTest.vala"
	switch (property_id) {
#line 153 "GomSerializationTest.vala"
		case GOM_RESUME_CHAPTER_PROPERTY:
#line 153 "GomSerializationTest.vala"
		g_value_set_string (value, gom_resume_get_chapter (self));
#line 153 "GomSerializationTest.vala"
		break;
#line 153 "GomSerializationTest.vala"
		case GOM_RESUME_TEXT_PROPERTY:
#line 153 "GomSerializationTest.vala"
		g_value_set_string (value, gom_resume_get_text (self));
#line 153 "GomSerializationTest.vala"
		break;
#line 5516 "GomSerializationTest.c"
		default:
#line 153 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 153 "GomSerializationTest.vala"
		break;
#line 5522 "GomSerializationTest.c"
	}
}

static void
_vala_gom_resume_set_property (GObject * object,
                               guint property_id,
                               const GValue * value,
                               GParamSpec * pspec)
{
	GomResume * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_RESUME, GomResume);
#line 153 "GomSerializationTest.vala"
	switch (property_id) {
#line 153 "GomSerializationTest.vala"
		case GOM_RESUME_CHAPTER_PROPERTY:
#line 153 "GomSerializationTest.vala"
		gom_resume_set_chapter (self, g_value_get_string (value));
#line 153 "GomSerializationTest.vala"
		break;
#line 153 "GomSerializationTest.vala"
		case GOM_RESUME_TEXT_PROPERTY:
#line 153 "GomSerializationTest.vala"
		gom_resume_set_text (self, g_value_get_string (value));
#line 153 "GomSerializationTest.vala"
		break;
#line 5548 "GomSerializationTest.c"
		default:
#line 153 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 153 "GomSerializationTest.vala"
		break;
#line 5554 "GomSerializationTest.c"
	}
}

static inline gpointer
gom_book_get_instance_private (GomBook* self)
{
	return G_STRUCT_MEMBER_P (self, GomBook_private_offset);
}

GomBook*
gom_book_construct (GType object_type)
{
	GomBook * self = NULL;
#line 168 "GomSerializationTest.vala"
	self = (GomBook*) gxml_gom_element_construct (object_type);
#line 168 "GomSerializationTest.vala"
	return self;
#line 5572 "GomSerializationTest.c"
}

GomBook*
gom_book_new (void)
{
#line 168 "GomSerializationTest.vala"
	return gom_book_construct (TYPE_GOM_BOOK);
#line 5580 "GomSerializationTest.c"
}

const gchar*
gom_book_get_year (GomBook* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 171 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 171 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_year;
#line 171 "GomSerializationTest.vala"
	result = _tmp0_;
#line 171 "GomSerializationTest.vala"
	return result;
#line 5596 "GomSerializationTest.c"
}

void
gom_book_set_year (GomBook* self,
                   const gchar* value)
{
#line 171 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 171 "GomSerializationTest.vala"
	if (g_strcmp0 (value, gom_book_get_year (self)) != 0) {
#line 5607 "GomSerializationTest.c"
		gchar* _tmp0_;
#line 171 "GomSerializationTest.vala"
		_tmp0_ = g_strdup (value);
#line 171 "GomSerializationTest.vala"
		_g_free0 (self->priv->_year);
#line 171 "GomSerializationTest.vala"
		self->priv->_year = _tmp0_;
#line 171 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_book_properties[GOM_BOOK_YEAR_PROPERTY]);
#line 5617 "GomSerializationTest.c"
	}
}

const gchar*
gom_book_get_isbn (GomBook* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 173 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 173 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_isbn;
#line 173 "GomSerializationTest.vala"
	result = _tmp0_;
#line 173 "GomSerializationTest.vala"
	return result;
#line 5634 "GomSerializationTest.c"
}

void
gom_book_set_isbn (GomBook* self,
                   const gchar* value)
{
#line 173 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 173 "GomSerializationTest.vala"
	if (g_strcmp0 (value, gom_book_get_isbn (self)) != 0) {
#line 5645 "GomSerializationTest.c"
		gchar* _tmp0_;
#line 173 "GomSerializationTest.vala"
		_tmp0_ = g_strdup (value);
#line 173 "GomSerializationTest.vala"
		_g_free0 (self->priv->_isbn);
#line 173 "GomSerializationTest.vala"
		self->priv->_isbn = _tmp0_;
#line 173 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_book_properties[GOM_BOOK_ISBN_PROPERTY]);
#line 5655 "GomSerializationTest.c"
	}
}

GomName*
gom_book_get_name (GomBook* self)
{
	GomName* result;
	GomName* _tmp0_;
#line 174 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 174 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_name;
#line 174 "GomSerializationTest.vala"
	result = _tmp0_;
#line 174 "GomSerializationTest.vala"
	return result;
#line 5672 "GomSerializationTest.c"
}

void
gom_book_set_name (GomBook* self,
                   GomName* value)
{
#line 174 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 174 "GomSerializationTest.vala"
	if (gom_book_get_name (self) != value) {
#line 5683 "GomSerializationTest.c"
		GomName* _tmp0_;
#line 174 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 174 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_name);
#line 174 "GomSerializationTest.vala"
		self->priv->_name = _tmp0_;
#line 174 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_book_properties[GOM_BOOK_NAME_PROPERTY]);
#line 5693 "GomSerializationTest.c"
	}
}

GomAuthors*
gom_book_get_authors (GomBook* self)
{
	GomAuthors* result;
	GomAuthors* _tmp0_;
#line 175 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 175 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_authors;
#line 175 "GomSerializationTest.vala"
	result = _tmp0_;
#line 175 "GomSerializationTest.vala"
	return result;
#line 5710 "GomSerializationTest.c"
}

void
gom_book_set_authors (GomBook* self,
                      GomAuthors* value)
{
#line 175 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 175 "GomSerializationTest.vala"
	if (gom_book_get_authors (self) != value) {
#line 5721 "GomSerializationTest.c"
		GomAuthors* _tmp0_;
#line 175 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 175 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_authors);
#line 175 "GomSerializationTest.vala"
		self->priv->_authors = _tmp0_;
#line 175 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_book_properties[GOM_BOOK_AUTHORS_PROPERTY]);
#line 5731 "GomSerializationTest.c"
	}
}

GomInventoryDualKeyMap*
gom_book_get_inventory_registers (GomBook* self)
{
	GomInventoryDualKeyMap* result;
	GomInventoryDualKeyMap* _tmp0_;
#line 176 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 176 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_inventory_registers;
#line 176 "GomSerializationTest.vala"
	result = _tmp0_;
#line 176 "GomSerializationTest.vala"
	return result;
#line 5748 "GomSerializationTest.c"
}

void
gom_book_set_inventory_registers (GomBook* self,
                                  GomInventoryDualKeyMap* value)
{
#line 176 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 176 "GomSerializationTest.vala"
	if (gom_book_get_inventory_registers (self) != value) {
#line 5759 "GomSerializationTest.c"
		GomInventoryDualKeyMap* _tmp0_;
#line 176 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 176 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_inventory_registers);
#line 176 "GomSerializationTest.vala"
		self->priv->_inventory_registers = _tmp0_;
#line 176 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_book_properties[GOM_BOOK_INVENTORY_REGISTERS_PROPERTY]);
#line 5769 "GomSerializationTest.c"
	}
}

GomCategoryMap*
gom_book_get_categories (GomBook* self)
{
	GomCategoryMap* result;
	GomCategoryMap* _tmp0_;
#line 177 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 177 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_categories;
#line 177 "GomSerializationTest.vala"
	result = _tmp0_;
#line 177 "GomSerializationTest.vala"
	return result;
#line 5786 "GomSerializationTest.c"
}

void
gom_book_set_categories (GomBook* self,
                         GomCategoryMap* value)
{
#line 177 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 177 "GomSerializationTest.vala"
	if (gom_book_get_categories (self) != value) {
#line 5797 "GomSerializationTest.c"
		GomCategoryMap* _tmp0_;
#line 177 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 177 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_categories);
#line 177 "GomSerializationTest.vala"
		self->priv->_categories = _tmp0_;
#line 177 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_book_properties[GOM_BOOK_CATEGORIES_PROPERTY]);
#line 5807 "GomSerializationTest.c"
	}
}

GomResumeMap*
gom_book_get_resumes (GomBook* self)
{
	GomResumeMap* result;
	GomResumeMap* _tmp0_;
#line 178 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 178 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_resumes;
#line 178 "GomSerializationTest.vala"
	result = _tmp0_;
#line 178 "GomSerializationTest.vala"
	return result;
#line 5824 "GomSerializationTest.c"
}

void
gom_book_set_resumes (GomBook* self,
                      GomResumeMap* value)
{
#line 178 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 178 "GomSerializationTest.vala"
	if (gom_book_get_resumes (self) != value) {
#line 5835 "GomSerializationTest.c"
		GomResumeMap* _tmp0_;
#line 178 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 178 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_resumes);
#line 178 "GomSerializationTest.vala"
		self->priv->_resumes = _tmp0_;
#line 178 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_book_properties[GOM_BOOK_RESUMES_PROPERTY]);
#line 5845 "GomSerializationTest.c"
	}
}

static GObject *
gom_book_constructor (GType type,
                      guint n_construct_properties,
                      GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomBook * self;
	GError* _inner_error0_ = NULL;
#line 179 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_book_parent_class);
#line 179 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 179 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_BOOK, GomBook);
#line 5864 "GomSerializationTest.c"
	{
#line 180 "GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Book");
#line 5868 "GomSerializationTest.c"
	}
	goto __finally170;
	__catch170_g_error:
	{
#line 180 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 180 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 180 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 5879 "GomSerializationTest.c"
	}
	__finally170:
#line 180 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 180 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 180 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 5888 "GomSerializationTest.c"
	}
#line 179 "GomSerializationTest.vala"
	return obj;
#line 5892 "GomSerializationTest.c"
}

GomBookArray*
gom_book_array_construct (GType object_type)
{
	GomBookArray * self = NULL;
#line 182 "GomSerializationTest.vala"
	self = (GomBookArray*) gxml_gom_array_list_construct (object_type);
#line 182 "GomSerializationTest.vala"
	return self;
#line 5903 "GomSerializationTest.c"
}

GomBookArray*
gom_book_array_new (void)
{
#line 182 "GomSerializationTest.vala"
	return gom_book_array_construct (GOM_BOOK_TYPE_ARRAY);
#line 5911 "GomSerializationTest.c"
}

static GObject *
gom_book_array_constructor (GType type,
                            guint n_construct_properties,
                            GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomBookArray * self;
	GError* _inner_error0_ = NULL;
#line 183 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_book_array_parent_class);
#line 183 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 183 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_BOOK_TYPE_ARRAY, GomBookArray);
#line 5929 "GomSerializationTest.c"
	{
#line 184 "GomSerializationTest.vala"
		gxml_collection_initialize ((GXmlCollection*) self, TYPE_GOM_BOOK, &_inner_error0_);
#line 184 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 5935 "GomSerializationTest.c"
			goto __catch171_g_error;
		}
	}
	goto __finally171;
	__catch171_g_error:
	{
#line 184 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 184 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 185 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 5948 "GomSerializationTest.c"
	}
	__finally171:
#line 184 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 184 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 184 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 5957 "GomSerializationTest.c"
	}
#line 183 "GomSerializationTest.vala"
	return obj;
#line 5961 "GomSerializationTest.c"
}

static void
gom_book_array_class_init (GomBookArrayClass * klass,
                           gpointer klass_data)
{
#line 182 "GomSerializationTest.vala"
	gom_book_array_parent_class = g_type_class_peek_parent (klass);
#line 182 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_book_array_constructor;
#line 5972 "GomSerializationTest.c"
}

static void
gom_book_array_instance_init (GomBookArray * self,
                              gpointer klass)
{
}

GType
gom_book_array_get_type (void)
{
	static volatile gsize gom_book_array_type_id__volatile = 0;
	if (g_once_init_enter (&gom_book_array_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomBookArrayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_book_array_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomBookArray), 0, (GInstanceInitFunc) gom_book_array_instance_init, NULL };
		GType gom_book_array_type_id;
		gom_book_array_type_id = g_type_register_static (GXML_TYPE_GOM_ARRAY_LIST, "GomBookArray", &g_define_type_info, 0);
		g_once_init_leave (&gom_book_array_type_id__volatile, gom_book_array_type_id);
	}
	return gom_book_array_type_id__volatile;
}

static void
gom_book_class_init (GomBookClass * klass,
                     gpointer klass_data)
{
#line 168 "GomSerializationTest.vala"
	gom_book_parent_class = g_type_class_peek_parent (klass);
#line 168 "GomSerializationTest.vala"
	g_type_class_adjust_private_offset (klass, &GomBook_private_offset);
#line 168 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_book_get_property;
#line 168 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_book_set_property;
#line 168 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_book_constructor;
#line 168 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_book_finalize;
#line 168 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BOOK_YEAR_PROPERTY, gom_book_properties[GOM_BOOK_YEAR_PROPERTY] = g_param_spec_string ("year", "::Year", "year", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 168 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BOOK_ISBN_PROPERTY, gom_book_properties[GOM_BOOK_ISBN_PROPERTY] = g_param_spec_string ("isbn", "::ISBN", "isbn", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 168 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BOOK_NAME_PROPERTY, gom_book_properties[GOM_BOOK_NAME_PROPERTY] = g_param_spec_object ("name", "name", "name", TYPE_GOM_NAME, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 168 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BOOK_AUTHORS_PROPERTY, gom_book_properties[GOM_BOOK_AUTHORS_PROPERTY] = g_param_spec_object ("authors", "authors", "authors", TYPE_GOM_AUTHORS, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 168 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BOOK_INVENTORY_REGISTERS_PROPERTY, gom_book_properties[GOM_BOOK_INVENTORY_REGISTERS_PROPERTY] = g_param_spec_object ("inventory-registers", "inventory-registers", "inventory-registers", GOM_INVENTORY_TYPE_DUAL_KEY_MAP, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 168 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BOOK_CATEGORIES_PROPERTY, gom_book_properties[GOM_BOOK_CATEGORIES_PROPERTY] = g_param_spec_object ("categories", "categories", "categories", GOM_CATEGORY_TYPE_MAP, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 168 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BOOK_RESUMES_PROPERTY, gom_book_properties[GOM_BOOK_RESUMES_PROPERTY] = g_param_spec_object ("resumes", "resumes", "resumes", GOM_RESUME_TYPE_MAP, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6024 "GomSerializationTest.c"
}

static void
gom_book_instance_init (GomBook * self,
                        gpointer klass)
{
#line 168 "GomSerializationTest.vala"
	self->priv = gom_book_get_instance_private (self);
#line 6033 "GomSerializationTest.c"
}

static void
gom_book_finalize (GObject * obj)
{
	GomBook * self;
#line 168 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_BOOK, GomBook);
#line 171 "GomSerializationTest.vala"
	_g_free0 (self->priv->_year);
#line 173 "GomSerializationTest.vala"
	_g_free0 (self->priv->_isbn);
#line 174 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_name);
#line 175 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_authors);
#line 176 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_inventory_registers);
#line 177 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_categories);
#line 178 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_resumes);
#line 168 "GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_book_parent_class)->finalize (obj);
#line 6058 "GomSerializationTest.c"
}

GType
gom_book_get_type (void)
{
	static volatile gsize gom_book_type_id__volatile = 0;
	if (g_once_init_enter (&gom_book_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomBookClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_book_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomBook), 0, (GInstanceInitFunc) gom_book_instance_init, NULL };
		GType gom_book_type_id;
		gom_book_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomBook", &g_define_type_info, 0);
		GomBook_private_offset = g_type_add_instance_private (gom_book_type_id, sizeof (GomBookPrivate));
		g_once_init_leave (&gom_book_type_id__volatile, gom_book_type_id);
	}
	return gom_book_type_id__volatile;
}

static void
_vala_gom_book_get_property (GObject * object,
                             guint property_id,
                             GValue * value,
                             GParamSpec * pspec)
{
	GomBook * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_BOOK, GomBook);
#line 168 "GomSerializationTest.vala"
	switch (property_id) {
#line 168 "GomSerializationTest.vala"
		case GOM_BOOK_YEAR_PROPERTY:
#line 168 "GomSerializationTest.vala"
		g_value_set_string (value, gom_book_get_year (self));
#line 168 "GomSerializationTest.vala"
		break;
#line 168 "GomSerializationTest.vala"
		case GOM_BOOK_ISBN_PROPERTY:
#line 168 "GomSerializationTest.vala"
		g_value_set_string (value, gom_book_get_isbn (self));
#line 168 "GomSerializationTest.vala"
		break;
#line 168 "GomSerializationTest.vala"
		case GOM_BOOK_NAME_PROPERTY:
#line 168 "GomSerializationTest.vala"
		g_value_set_object (value, gom_book_get_name (self));
#line 168 "GomSerializationTest.vala"
		break;
#line 168 "GomSerializationTest.vala"
		case GOM_BOOK_AUTHORS_PROPERTY:
#line 168 "GomSerializationTest.vala"
		g_value_set_object (value, gom_book_get_authors (self));
#line 168 "GomSerializationTest.vala"
		break;
#line 168 "GomSerializationTest.vala"
		case GOM_BOOK_INVENTORY_REGISTERS_PROPERTY:
#line 168 "GomSerializationTest.vala"
		g_value_set_object (value, gom_book_get_inventory_registers (self));
#line 168 "GomSerializationTest.vala"
		break;
#line 168 "GomSerializationTest.vala"
		case GOM_BOOK_CATEGORIES_PROPERTY:
#line 168 "GomSerializationTest.vala"
		g_value_set_object (value, gom_book_get_categories (self));
#line 168 "GomSerializationTest.vala"
		break;
#line 168 "GomSerializationTest.vala"
		case GOM_BOOK_RESUMES_PROPERTY:
#line 168 "GomSerializationTest.vala"
		g_value_set_object (value, gom_book_get_resumes (self));
#line 168 "GomSerializationTest.vala"
		break;
#line 6127 "GomSerializationTest.c"
		default:
#line 168 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 168 "GomSerializationTest.vala"
		break;
#line 6133 "GomSerializationTest.c"
	}
}

static void
_vala_gom_book_set_property (GObject * object,
                             guint property_id,
                             const GValue * value,
                             GParamSpec * pspec)
{
	GomBook * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_BOOK, GomBook);
#line 168 "GomSerializationTest.vala"
	switch (property_id) {
#line 168 "GomSerializationTest.vala"
		case GOM_BOOK_YEAR_PROPERTY:
#line 168 "GomSerializationTest.vala"
		gom_book_set_year (self, g_value_get_string (value));
#line 168 "GomSerializationTest.vala"
		break;
#line 168 "GomSerializationTest.vala"
		case GOM_BOOK_ISBN_PROPERTY:
#line 168 "GomSerializationTest.vala"
		gom_book_set_isbn (self, g_value_get_string (value));
#line 168 "GomSerializationTest.vala"
		break;
#line 168 "GomSerializationTest.vala"
		case GOM_BOOK_NAME_PROPERTY:
#line 168 "GomSerializationTest.vala"
		gom_book_set_name (self, g_value_get_object (value));
#line 168 "GomSerializationTest.vala"
		break;
#line 168 "GomSerializationTest.vala"
		case GOM_BOOK_AUTHORS_PROPERTY:
#line 168 "GomSerializationTest.vala"
		gom_book_set_authors (self, g_value_get_object (value));
#line 168 "GomSerializationTest.vala"
		break;
#line 168 "GomSerializationTest.vala"
		case GOM_BOOK_INVENTORY_REGISTERS_PROPERTY:
#line 168 "GomSerializationTest.vala"
		gom_book_set_inventory_registers (self, g_value_get_object (value));
#line 168 "GomSerializationTest.vala"
		break;
#line 168 "GomSerializationTest.vala"
		case GOM_BOOK_CATEGORIES_PROPERTY:
#line 168 "GomSerializationTest.vala"
		gom_book_set_categories (self, g_value_get_object (value));
#line 168 "GomSerializationTest.vala"
		break;
#line 168 "GomSerializationTest.vala"
		case GOM_BOOK_RESUMES_PROPERTY:
#line 168 "GomSerializationTest.vala"
		gom_book_set_resumes (self, g_value_get_object (value));
#line 168 "GomSerializationTest.vala"
		break;
#line 6189 "GomSerializationTest.c"
		default:
#line 168 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 168 "GomSerializationTest.vala"
		break;
#line 6195 "GomSerializationTest.c"
	}
}

static inline gpointer
gom_book_store_get_instance_private (GomBookStore* self)
{
	return G_STRUCT_MEMBER_P (self, GomBookStore_private_offset);
}

GomBookStore*
gom_book_store_construct (GType object_type)
{
	GomBookStore * self = NULL;
#line 190 "GomSerializationTest.vala"
	self = (GomBookStore*) gxml_gom_element_construct (object_type);
#line 190 "GomSerializationTest.vala"
	return self;
#line 6213 "GomSerializationTest.c"
}

GomBookStore*
gom_book_store_new (void)
{
#line 190 "GomSerializationTest.vala"
	return gom_book_store_construct (TYPE_GOM_BOOK_STORE);
#line 6221 "GomSerializationTest.c"
}

const gchar*
gom_book_store_get_name (GomBookStore* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 193 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 193 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_name;
#line 193 "GomSerializationTest.vala"
	result = _tmp0_;
#line 193 "GomSerializationTest.vala"
	return result;
#line 6237 "GomSerializationTest.c"
}

void
gom_book_store_set_name (GomBookStore* self,
                         const gchar* value)
{
#line 193 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 193 "GomSerializationTest.vala"
	if (g_strcmp0 (value, gom_book_store_get_name (self)) != 0) {
#line 6248 "GomSerializationTest.c"
		gchar* _tmp0_;
#line 193 "GomSerializationTest.vala"
		_tmp0_ = g_strdup (value);
#line 193 "GomSerializationTest.vala"
		_g_free0 (self->priv->_name);
#line 193 "GomSerializationTest.vala"
		self->priv->_name = _tmp0_;
#line 193 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_book_store_properties[GOM_BOOK_STORE_NAME_PROPERTY]);
#line 6258 "GomSerializationTest.c"
	}
}

GomBookArray*
gom_book_store_get_books (GomBookStore* self)
{
	GomBookArray* result;
	GomBookArray* _tmp0_;
#line 194 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 194 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_books;
#line 194 "GomSerializationTest.vala"
	result = _tmp0_;
#line 194 "GomSerializationTest.vala"
	return result;
#line 6275 "GomSerializationTest.c"
}

void
gom_book_store_set_books (GomBookStore* self,
                          GomBookArray* value)
{
#line 194 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 194 "GomSerializationTest.vala"
	if (gom_book_store_get_books (self) != value) {
#line 6286 "GomSerializationTest.c"
		GomBookArray* _tmp0_;
#line 194 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 194 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_books);
#line 194 "GomSerializationTest.vala"
		self->priv->_books = _tmp0_;
#line 194 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_book_store_properties[GOM_BOOK_STORE_BOOKS_PROPERTY]);
#line 6296 "GomSerializationTest.c"
	}
}

static GObject *
gom_book_store_constructor (GType type,
                            guint n_construct_properties,
                            GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomBookStore * self;
	GError* _inner_error0_ = NULL;
#line 195 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_book_store_parent_class);
#line 195 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 195 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_BOOK_STORE, GomBookStore);
#line 6315 "GomSerializationTest.c"
	{
#line 196 "GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "BookStore");
#line 6319 "GomSerializationTest.c"
	}
	goto __finally172;
	__catch172_g_error:
	{
#line 196 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 196 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 196 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 6330 "GomSerializationTest.c"
	}
	__finally172:
#line 196 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 196 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 196 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 6339 "GomSerializationTest.c"
	}
#line 195 "GomSerializationTest.vala"
	return obj;
#line 6343 "GomSerializationTest.c"
}

static void
gom_book_store_class_init (GomBookStoreClass * klass,
                           gpointer klass_data)
{
#line 190 "GomSerializationTest.vala"
	gom_book_store_parent_class = g_type_class_peek_parent (klass);
#line 190 "GomSerializationTest.vala"
	g_type_class_adjust_private_offset (klass, &GomBookStore_private_offset);
#line 190 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_book_store_get_property;
#line 190 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_book_store_set_property;
#line 190 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_book_store_constructor;
#line 190 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_book_store_finalize;
#line 190 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BOOK_STORE_NAME_PROPERTY, gom_book_store_properties[GOM_BOOK_STORE_NAME_PROPERTY] = g_param_spec_string ("name", "::name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 190 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BOOK_STORE_BOOKS_PROPERTY, gom_book_store_properties[GOM_BOOK_STORE_BOOKS_PROPERTY] = g_param_spec_object ("books", "books", "books", GOM_BOOK_TYPE_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6366 "GomSerializationTest.c"
}

static void
gom_book_store_instance_init (GomBookStore * self,
                              gpointer klass)
{
#line 190 "GomSerializationTest.vala"
	self->priv = gom_book_store_get_instance_private (self);
#line 6375 "GomSerializationTest.c"
}

static void
gom_book_store_finalize (GObject * obj)
{
	GomBookStore * self;
#line 190 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_BOOK_STORE, GomBookStore);
#line 193 "GomSerializationTest.vala"
	_g_free0 (self->priv->_name);
#line 194 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_books);
#line 190 "GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_book_store_parent_class)->finalize (obj);
#line 6390 "GomSerializationTest.c"
}

GType
gom_book_store_get_type (void)
{
	static volatile gsize gom_book_store_type_id__volatile = 0;
	if (g_once_init_enter (&gom_book_store_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomBookStoreClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_book_store_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomBookStore), 0, (GInstanceInitFunc) gom_book_store_instance_init, NULL };
		GType gom_book_store_type_id;
		gom_book_store_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomBookStore", &g_define_type_info, 0);
		GomBookStore_private_offset = g_type_add_instance_private (gom_book_store_type_id, sizeof (GomBookStorePrivate));
		g_once_init_leave (&gom_book_store_type_id__volatile, gom_book_store_type_id);
	}
	return gom_book_store_type_id__volatile;
}

static void
_vala_gom_book_store_get_property (GObject * object,
                                   guint property_id,
                                   GValue * value,
                                   GParamSpec * pspec)
{
	GomBookStore * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_BOOK_STORE, GomBookStore);
#line 190 "GomSerializationTest.vala"
	switch (property_id) {
#line 190 "GomSerializationTest.vala"
		case GOM_BOOK_STORE_NAME_PROPERTY:
#line 190 "GomSerializationTest.vala"
		g_value_set_string (value, gom_book_store_get_name (self));
#line 190 "GomSerializationTest.vala"
		break;
#line 190 "GomSerializationTest.vala"
		case GOM_BOOK_STORE_BOOKS_PROPERTY:
#line 190 "GomSerializationTest.vala"
		g_value_set_object (value, gom_book_store_get_books (self));
#line 190 "GomSerializationTest.vala"
		break;
#line 6429 "GomSerializationTest.c"
		default:
#line 190 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 190 "GomSerializationTest.vala"
		break;
#line 6435 "GomSerializationTest.c"
	}
}

static void
_vala_gom_book_store_set_property (GObject * object,
                                   guint property_id,
                                   const GValue * value,
                                   GParamSpec * pspec)
{
	GomBookStore * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_BOOK_STORE, GomBookStore);
#line 190 "GomSerializationTest.vala"
	switch (property_id) {
#line 190 "GomSerializationTest.vala"
		case GOM_BOOK_STORE_NAME_PROPERTY:
#line 190 "GomSerializationTest.vala"
		gom_book_store_set_name (self, g_value_get_string (value));
#line 190 "GomSerializationTest.vala"
		break;
#line 190 "GomSerializationTest.vala"
		case GOM_BOOK_STORE_BOOKS_PROPERTY:
#line 190 "GomSerializationTest.vala"
		gom_book_store_set_books (self, g_value_get_object (value));
#line 190 "GomSerializationTest.vala"
		break;
#line 6461 "GomSerializationTest.c"
		default:
#line 190 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 190 "GomSerializationTest.vala"
		break;
#line 6467 "GomSerializationTest.c"
	}
}

static inline gpointer
gom_basic_types_get_instance_private (GomBasicTypes* self)
{
	return G_STRUCT_MEMBER_P (self, GomBasicTypes_private_offset);
}

GomBasicTypes*
gom_basic_types_construct (GType object_type)
{
	GomBasicTypes * self = NULL;
#line 200 "GomSerializationTest.vala"
	self = (GomBasicTypes*) gxml_gom_element_construct (object_type);
#line 200 "GomSerializationTest.vala"
	return self;
#line 6485 "GomSerializationTest.c"
}

GomBasicTypes*
gom_basic_types_new (void)
{
#line 200 "GomSerializationTest.vala"
	return gom_basic_types_construct (TYPE_GOM_BASIC_TYPES);
#line 6493 "GomSerializationTest.c"
}

const gchar*
gom_basic_types_get_text (GomBasicTypes* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 202 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 202 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_text;
#line 202 "GomSerializationTest.vala"
	result = _tmp0_;
#line 202 "GomSerializationTest.vala"
	return result;
#line 6509 "GomSerializationTest.c"
}

void
gom_basic_types_set_text (GomBasicTypes* self,
                          const gchar* value)
{
#line 202 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 202 "GomSerializationTest.vala"
	if (g_strcmp0 (value, gom_basic_types_get_text (self)) != 0) {
#line 6520 "GomSerializationTest.c"
		gchar* _tmp0_;
#line 202 "GomSerializationTest.vala"
		_tmp0_ = g_strdup (value);
#line 202 "GomSerializationTest.vala"
		_g_free0 (self->priv->_text);
#line 202 "GomSerializationTest.vala"
		self->priv->_text = _tmp0_;
#line 202 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_basic_types_properties[GOM_BASIC_TYPES_TEXT_PROPERTY]);
#line 6530 "GomSerializationTest.c"
	}
}

gint
gom_basic_types_get_integer (GomBasicTypes* self)
{
	gint result;
#line 204 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 204 "GomSerializationTest.vala"
	result = self->priv->_integer;
#line 204 "GomSerializationTest.vala"
	return result;
#line 6544 "GomSerializationTest.c"
}

void
gom_basic_types_set_integer (GomBasicTypes* self,
                             gint value)
{
#line 204 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 204 "GomSerializationTest.vala"
	if (gom_basic_types_get_integer (self) != value) {
#line 204 "GomSerializationTest.vala"
		self->priv->_integer = value;
#line 204 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_basic_types_properties[GOM_BASIC_TYPES_INTEGER_PROPERTY]);
#line 6559 "GomSerializationTest.c"
	}
}

gdouble
gom_basic_types_get_real_double (GomBasicTypes* self)
{
	gdouble result;
#line 206 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, 0.0);
#line 206 "GomSerializationTest.vala"
	result = self->priv->_real_double;
#line 206 "GomSerializationTest.vala"
	return result;
#line 6573 "GomSerializationTest.c"
}

void
gom_basic_types_set_real_double (GomBasicTypes* self,
                                 gdouble value)
{
#line 206 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 206 "GomSerializationTest.vala"
	if (gom_basic_types_get_real_double (self) != value) {
#line 206 "GomSerializationTest.vala"
		self->priv->_real_double = value;
#line 206 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_basic_types_properties[GOM_BASIC_TYPES_REAL_DOUBLE_PROPERTY]);
#line 6588 "GomSerializationTest.c"
	}
}

gfloat
gom_basic_types_get_real_float (GomBasicTypes* self)
{
	gfloat result;
#line 208 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, 0.0F);
#line 208 "GomSerializationTest.vala"
	result = self->priv->_real_float;
#line 208 "GomSerializationTest.vala"
	return result;
#line 6602 "GomSerializationTest.c"
}

void
gom_basic_types_set_real_float (GomBasicTypes* self,
                                gfloat value)
{
#line 208 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 208 "GomSerializationTest.vala"
	if (gom_basic_types_get_real_float (self) != value) {
#line 208 "GomSerializationTest.vala"
		self->priv->_real_float = value;
#line 208 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_basic_types_properties[GOM_BASIC_TYPES_REAL_FLOAT_PROPERTY]);
#line 6617 "GomSerializationTest.c"
	}
}

guint
gom_basic_types_get_unsigned_integer (GomBasicTypes* self)
{
	guint result;
#line 210 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, 0U);
#line 210 "GomSerializationTest.vala"
	result = self->priv->_unsigned_integer;
#line 210 "GomSerializationTest.vala"
	return result;
#line 6631 "GomSerializationTest.c"
}

void
gom_basic_types_set_unsigned_integer (GomBasicTypes* self,
                                      guint value)
{
#line 210 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 210 "GomSerializationTest.vala"
	if (gom_basic_types_get_unsigned_integer (self) != value) {
#line 210 "GomSerializationTest.vala"
		self->priv->_unsigned_integer = value;
#line 210 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_basic_types_properties[GOM_BASIC_TYPES_UNSIGNED_INTEGER_PROPERTY]);
#line 6646 "GomSerializationTest.c"
	}
}

gboolean
gom_basic_types_get_boolean (GomBasicTypes* self)
{
	gboolean result;
#line 212 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 212 "GomSerializationTest.vala"
	result = self->priv->_boolean;
#line 212 "GomSerializationTest.vala"
	return result;
#line 6660 "GomSerializationTest.c"
}

void
gom_basic_types_set_boolean (GomBasicTypes* self,
                             gboolean value)
{
#line 212 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 212 "GomSerializationTest.vala"
	if (gom_basic_types_get_boolean (self) != value) {
#line 212 "GomSerializationTest.vala"
		self->priv->_boolean = value;
#line 212 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_basic_types_properties[GOM_BASIC_TYPES_BOOLEAN_PROPERTY]);
#line 6675 "GomSerializationTest.c"
	}
}

static GObject *
gom_basic_types_constructor (GType type,
                             guint n_construct_properties,
                             GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomBasicTypes * self;
	GError* _inner_error0_ = NULL;
#line 213 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_basic_types_parent_class);
#line 213 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 213 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_BASIC_TYPES, GomBasicTypes);
#line 6694 "GomSerializationTest.c"
	{
#line 214 "GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "GomBasicTypes");
#line 6698 "GomSerializationTest.c"
	}
	goto __finally173;
	__catch173_g_error:
	{
#line 214 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 214 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 214 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 6709 "GomSerializationTest.c"
	}
	__finally173:
#line 214 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 214 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 214 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 6718 "GomSerializationTest.c"
	}
#line 213 "GomSerializationTest.vala"
	return obj;
#line 6722 "GomSerializationTest.c"
}

static void
gom_basic_types_class_init (GomBasicTypesClass * klass,
                            gpointer klass_data)
{
#line 200 "GomSerializationTest.vala"
	gom_basic_types_parent_class = g_type_class_peek_parent (klass);
#line 200 "GomSerializationTest.vala"
	g_type_class_adjust_private_offset (klass, &GomBasicTypes_private_offset);
#line 200 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_basic_types_get_property;
#line 200 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_basic_types_set_property;
#line 200 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_basic_types_constructor;
#line 200 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_basic_types_finalize;
#line 200 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BASIC_TYPES_TEXT_PROPERTY, gom_basic_types_properties[GOM_BASIC_TYPES_TEXT_PROPERTY] = g_param_spec_string ("text", "::text", "text", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 200 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BASIC_TYPES_INTEGER_PROPERTY, gom_basic_types_properties[GOM_BASIC_TYPES_INTEGER_PROPERTY] = g_param_spec_int ("integer", "::integer", "integer", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 200 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BASIC_TYPES_REAL_DOUBLE_PROPERTY, gom_basic_types_properties[GOM_BASIC_TYPES_REAL_DOUBLE_PROPERTY] = g_param_spec_double ("real-double", "::realDouble", "real-double", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 200 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BASIC_TYPES_REAL_FLOAT_PROPERTY, gom_basic_types_properties[GOM_BASIC_TYPES_REAL_FLOAT_PROPERTY] = g_param_spec_float ("real-float", "::realFloat", "real-float", -G_MAXFLOAT, G_MAXFLOAT, 0.0F, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 200 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BASIC_TYPES_UNSIGNED_INTEGER_PROPERTY, gom_basic_types_properties[GOM_BASIC_TYPES_UNSIGNED_INTEGER_PROPERTY] = g_param_spec_uint ("unsigned-integer", "::unsignedInteger", "unsigned-integer", 0, G_MAXUINT, 0U, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 200 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BASIC_TYPES_BOOLEAN_PROPERTY, gom_basic_types_properties[GOM_BASIC_TYPES_BOOLEAN_PROPERTY] = g_param_spec_boolean ("boolean", "::Boolean", "boolean", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6753 "GomSerializationTest.c"
}

static void
gom_basic_types_instance_init (GomBasicTypes * self,
                               gpointer klass)
{
#line 200 "GomSerializationTest.vala"
	self->priv = gom_basic_types_get_instance_private (self);
#line 6762 "GomSerializationTest.c"
}

static void
gom_basic_types_finalize (GObject * obj)
{
	GomBasicTypes * self;
#line 200 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_BASIC_TYPES, GomBasicTypes);
#line 202 "GomSerializationTest.vala"
	_g_free0 (self->priv->_text);
#line 200 "GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_basic_types_parent_class)->finalize (obj);
#line 6775 "GomSerializationTest.c"
}

GType
gom_basic_types_get_type (void)
{
	static volatile gsize gom_basic_types_type_id__volatile = 0;
	if (g_once_init_enter (&gom_basic_types_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomBasicTypesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_basic_types_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomBasicTypes), 0, (GInstanceInitFunc) gom_basic_types_instance_init, NULL };
		GType gom_basic_types_type_id;
		gom_basic_types_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomBasicTypes", &g_define_type_info, 0);
		GomBasicTypes_private_offset = g_type_add_instance_private (gom_basic_types_type_id, sizeof (GomBasicTypesPrivate));
		g_once_init_leave (&gom_basic_types_type_id__volatile, gom_basic_types_type_id);
	}
	return gom_basic_types_type_id__volatile;
}

static void
_vala_gom_basic_types_get_property (GObject * object,
                                    guint property_id,
                                    GValue * value,
                                    GParamSpec * pspec)
{
	GomBasicTypes * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_BASIC_TYPES, GomBasicTypes);
#line 200 "GomSerializationTest.vala"
	switch (property_id) {
#line 200 "GomSerializationTest.vala"
		case GOM_BASIC_TYPES_TEXT_PROPERTY:
#line 200 "GomSerializationTest.vala"
		g_value_set_string (value, gom_basic_types_get_text (self));
#line 200 "GomSerializationTest.vala"
		break;
#line 200 "GomSerializationTest.vala"
		case GOM_BASIC_TYPES_INTEGER_PROPERTY:
#line 200 "GomSerializationTest.vala"
		g_value_set_int (value, gom_basic_types_get_integer (self));
#line 200 "GomSerializationTest.vala"
		break;
#line 200 "GomSerializationTest.vala"
		case GOM_BASIC_TYPES_REAL_DOUBLE_PROPERTY:
#line 200 "GomSerializationTest.vala"
		g_value_set_double (value, gom_basic_types_get_real_double (self));
#line 200 "GomSerializationTest.vala"
		break;
#line 200 "GomSerializationTest.vala"
		case GOM_BASIC_TYPES_REAL_FLOAT_PROPERTY:
#line 200 "GomSerializationTest.vala"
		g_value_set_float (value, gom_basic_types_get_real_float (self));
#line 200 "GomSerializationTest.vala"
		break;
#line 200 "GomSerializationTest.vala"
		case GOM_BASIC_TYPES_UNSIGNED_INTEGER_PROPERTY:
#line 200 "GomSerializationTest.vala"
		g_value_set_uint (value, gom_basic_types_get_unsigned_integer (self));
#line 200 "GomSerializationTest.vala"
		break;
#line 200 "GomSerializationTest.vala"
		case GOM_BASIC_TYPES_BOOLEAN_PROPERTY:
#line 200 "GomSerializationTest.vala"
		g_value_set_boolean (value, gom_basic_types_get_boolean (self));
#line 200 "GomSerializationTest.vala"
		break;
#line 6838 "GomSerializationTest.c"
		default:
#line 200 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 200 "GomSerializationTest.vala"
		break;
#line 6844 "GomSerializationTest.c"
	}
}

static void
_vala_gom_basic_types_set_property (GObject * object,
                                    guint property_id,
                                    const GValue * value,
                                    GParamSpec * pspec)
{
	GomBasicTypes * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_BASIC_TYPES, GomBasicTypes);
#line 200 "GomSerializationTest.vala"
	switch (property_id) {
#line 200 "GomSerializationTest.vala"
		case GOM_BASIC_TYPES_TEXT_PROPERTY:
#line 200 "GomSerializationTest.vala"
		gom_basic_types_set_text (self, g_value_get_string (value));
#line 200 "GomSerializationTest.vala"
		break;
#line 200 "GomSerializationTest.vala"
		case GOM_BASIC_TYPES_INTEGER_PROPERTY:
#line 200 "GomSerializationTest.vala"
		gom_basic_types_set_integer (self, g_value_get_int (value));
#line 200 "GomSerializationTest.vala"
		break;
#line 200 "GomSerializationTest.vala"
		case GOM_BASIC_TYPES_REAL_DOUBLE_PROPERTY:
#line 200 "GomSerializationTest.vala"
		gom_basic_types_set_real_double (self, g_value_get_double (value));
#line 200 "GomSerializationTest.vala"
		break;
#line 200 "GomSerializationTest.vala"
		case GOM_BASIC_TYPES_REAL_FLOAT_PROPERTY:
#line 200 "GomSerializationTest.vala"
		gom_basic_types_set_real_float (self, g_value_get_float (value));
#line 200 "GomSerializationTest.vala"
		break;
#line 200 "GomSerializationTest.vala"
		case GOM_BASIC_TYPES_UNSIGNED_INTEGER_PROPERTY:
#line 200 "GomSerializationTest.vala"
		gom_basic_types_set_unsigned_integer (self, g_value_get_uint (value));
#line 200 "GomSerializationTest.vala"
		break;
#line 200 "GomSerializationTest.vala"
		case GOM_BASIC_TYPES_BOOLEAN_PROPERTY:
#line 200 "GomSerializationTest.vala"
		gom_basic_types_set_boolean (self, g_value_get_boolean (value));
#line 200 "GomSerializationTest.vala"
		break;
#line 6894 "GomSerializationTest.c"
		default:
#line 200 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 200 "GomSerializationTest.vala"
		break;
#line 6900 "GomSerializationTest.c"
	}
}

static gboolean
string_contains (const gchar* self,
                 const gchar* needle)
{
	gboolean result = FALSE;
	gchar* _tmp0_;
#line 1476 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1476 "glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1477 "glib-2.0.vapi"
	_tmp0_ = strstr ((gchar*) self, (gchar*) needle);
#line 1477 "glib-2.0.vapi"
	result = _tmp0_ != NULL;
#line 1477 "glib-2.0.vapi"
	return result;
#line 6920 "GomSerializationTest.c"
}

static void
__lambda119_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GomSerializationTestBook* b = NULL;
		GomSerializationTestBook* _tmp0_;
		GXmlXParser* parser = NULL;
		GXmlXParser* _tmp1_;
		gchar* s = NULL;
		gchar* _tmp2_;
		const gchar* _tmp3_;
		const gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
#line 521 "GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_book_new ();
#line 521 "GomSerializationTest.vala"
		b = _tmp0_;
#line 522 "GomSerializationTest.vala"
		_tmp1_ = gxml_xparser_new ((GXmlDomNode*) b);
#line 522 "GomSerializationTest.vala"
		parser = _tmp1_;
#line 523 "GomSerializationTest.vala"
		_tmp2_ = gxml_parser_write_string ((GXmlParser*) parser, &_inner_error0_);
#line 523 "GomSerializationTest.vala"
		s = _tmp2_;
#line 523 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 523 "GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 523 "GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 6957 "GomSerializationTest.c"
			goto __catch174_g_error;
		}
#line 524 "GomSerializationTest.vala"
		_tmp3_ = s;
#line 524 "GomSerializationTest.vala"
		_vala_assert (_tmp3_ != NULL, "s != null");
#line 525 "GomSerializationTest.vala"
		_tmp4_ = s;
#line 525 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp4_, "<Book/>"), "\"<Book/>\" in s");
#line 526 "GomSerializationTest.vala"
		gom_serialization_test_book_set_name (b, "My Book");
#line 527 "GomSerializationTest.vala"
		_tmp5_ = gxml_dom_element_get_attribute ((GXmlDomElement*) b, "name");
#line 527 "GomSerializationTest.vala"
		_tmp6_ = _tmp5_;
#line 527 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp6_, "My Book") == 0, "b.get_attribute (\"name\") == \"My Book\"");
#line 527 "GomSerializationTest.vala"
		_g_free0 (_tmp6_);
#line 528 "GomSerializationTest.vala"
		_tmp7_ = gom_serialization_test_book_to_string (b);
#line 528 "GomSerializationTest.vala"
		_g_free0 (s);
#line 528 "GomSerializationTest.vala"
		s = _tmp7_;
#line 520 "GomSerializationTest.vala"
		_g_free0 (s);
#line 520 "GomSerializationTest.vala"
		_g_object_unref0 (parser);
#line 520 "GomSerializationTest.vala"
		_g_object_unref0 (b);
#line 6990 "GomSerializationTest.c"
	}
	goto __finally174;
	__catch174_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
#line 520 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 520 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 533 "GomSerializationTest.vala"
		_tmp8_ = e->message;
#line 533 "GomSerializationTest.vala"
		_tmp9_ = g_strconcat ("Error: ", _tmp8_, NULL);
#line 533 "GomSerializationTest.vala"
		_tmp10_ = _tmp9_;
#line 533 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:533: %s", _tmp10_);
#line 533 "GomSerializationTest.vala"
		_g_free0 (_tmp10_);
#line 534 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 520 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 7017 "GomSerializationTest.c"
	}
	__finally174:
#line 520 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 520 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 520 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 520 "GomSerializationTest.vala"
		return;
#line 7028 "GomSerializationTest.c"
	}
}

static void
___lambda119__gtest_func (void)
{
#line 519 "GomSerializationTest.vala"
	__lambda119_ ();
#line 7037 "GomSerializationTest.c"
}

static void
__lambda120_ (void)
{
	GomSerializationTestComputer* c = NULL;
	GomSerializationTestComputer* _tmp0_;
	gchar* s = NULL;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
#line 538 "GomSerializationTest.vala"
	_tmp0_ = gom_serialization_test_computer_new ();
#line 538 "GomSerializationTest.vala"
	c = _tmp0_;
#line 539 "GomSerializationTest.vala"
	_tmp1_ = gom_serialization_test_computer_to_string (c);
#line 539 "GomSerializationTest.vala"
	s = _tmp1_;
#line 540 "GomSerializationTest.vala"
	_tmp2_ = s;
#line 540 "GomSerializationTest.vala"
	_vala_assert (_tmp2_ != NULL, "s != null");
#line 541 "GomSerializationTest.vala"
	_tmp3_ = s;
#line 541 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp3_, "<Computer/>"), "\"<Computer/>\" in s");
#line 542 "GomSerializationTest.vala"
	gom_serialization_test_computer_set_model (c, "T3456-E");
#line 543 "GomSerializationTest.vala"
	gom_serialization_test_computer_set_ignore (c, "Nothing");
#line 544 "GomSerializationTest.vala"
	_tmp4_ = gom_serialization_test_computer_get_model (c);
#line 544 "GomSerializationTest.vala"
	_tmp5_ = _tmp4_;
#line 544 "GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp5_, "T3456-E") == 0, "c.model == \"T3456-E\"");
#line 545 "GomSerializationTest.vala"
	_tmp6_ = gxml_dom_element_get_attribute ((GXmlDomElement*) c, "model");
#line 545 "GomSerializationTest.vala"
	_tmp7_ = _tmp6_;
#line 545 "GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp7_, "T3456-E") == 0, "c.get_attribute (\"model\") == \"T3456-E\"");
#line 545 "GomSerializationTest.vala"
	_g_free0 (_tmp7_);
#line 546 "GomSerializationTest.vala"
	_tmp8_ = gom_serialization_test_computer_get_ignore (c);
#line 546 "GomSerializationTest.vala"
	_tmp9_ = _tmp8_;
#line 546 "GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp9_, "Nothing") == 0, "c.ignore == \"Nothing\"");
#line 547 "GomSerializationTest.vala"
	_tmp10_ = gxml_dom_element_get_attribute ((GXmlDomElement*) c, "ignore");
#line 547 "GomSerializationTest.vala"
	_tmp11_ = _tmp10_;
#line 547 "GomSerializationTest.vala"
	_vala_assert (_tmp11_ == NULL, "c.get_attribute (\"ignore\") == null");
#line 547 "GomSerializationTest.vala"
	_g_free0 (_tmp11_);
#line 548 "GomSerializationTest.vala"
	_tmp12_ = gom_serialization_test_computer_to_string (c);
#line 548 "GomSerializationTest.vala"
	_g_free0 (s);
#line 548 "GomSerializationTest.vala"
	s = _tmp12_;
#line 537 "GomSerializationTest.vala"
	_g_free0 (s);
#line 537 "GomSerializationTest.vala"
	_g_object_unref0 (c);
#line 7116 "GomSerializationTest.c"
}

static void
___lambda120__gtest_func (void)
{
#line 537 "GomSerializationTest.vala"
	__lambda120_ ();
#line 7124 "GomSerializationTest.c"
}

static void
__lambda121_ (void)
{
	GomSerializationTestTaxes* t = NULL;
	GomSerializationTestTaxes* _tmp0_;
	gchar* s = NULL;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	gdouble _tmp7_;
	gdouble _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	GomSerializationTestTaxesMonth _tmp13_;
	GomSerializationTestTaxesMonth _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	gboolean _tmp17_;
	gboolean _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	gchar* _tmp21_;
	const gchar* _tmp22_;
	const gchar* _tmp23_;
	const gchar* _tmp24_;
	const gchar* _tmp25_;
#line 554 "GomSerializationTest.vala"
	_tmp0_ = gom_serialization_test_taxes_new ();
#line 554 "GomSerializationTest.vala"
	t = _tmp0_;
#line 555 "GomSerializationTest.vala"
	_tmp1_ = gom_serialization_test_taxes_to_string (t);
#line 555 "GomSerializationTest.vala"
	s = _tmp1_;
#line 556 "GomSerializationTest.vala"
	_tmp2_ = s;
#line 556 "GomSerializationTest.vala"
	_vala_assert (_tmp2_ != NULL, "s != null");
#line 560 "GomSerializationTest.vala"
	_tmp3_ = s;
#line 560 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp3_, "<Taxes "), "\"<Taxes \" in s");
#line 561 "GomSerializationTest.vala"
	_tmp4_ = s;
#line 561 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp4_, "monthRate=\"0\""), "\"monthRate=\\\"0\\\"\" in s");
#line 562 "GomSerializationTest.vala"
	_tmp5_ = s;
#line 562 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp5_, "Month=\"january\""), "\"Month=\\\"january\\\"\" in s");
#line 563 "GomSerializationTest.vala"
	_tmp6_ = s;
#line 563 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp6_, "TaxFree=\"false\""), "\"TaxFree=\\\"false\\\"\" in s");
#line 564 "GomSerializationTest.vala"
	gom_serialization_test_taxes_set_month_rate (t, 16.5);
#line 565 "GomSerializationTest.vala"
	_tmp7_ = gom_serialization_test_taxes_get_month_rate (t);
#line 565 "GomSerializationTest.vala"
	_tmp8_ = _tmp7_;
#line 565 "GomSerializationTest.vala"
	_tmp9_ = g_strdup_printf ("%.2f", _tmp8_);
#line 565 "GomSerializationTest.vala"
	_tmp10_ = _tmp9_;
#line 565 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp10_, "16.5"), "\"16.5\" in \"%.2f\".printf (t.month_rate)");
#line 565 "GomSerializationTest.vala"
	_g_free0 (_tmp10_);
#line 566 "GomSerializationTest.vala"
	_tmp11_ = gxml_dom_element_get_attribute ((GXmlDomElement*) t, "monthrate");
#line 566 "GomSerializationTest.vala"
	_tmp12_ = _tmp11_;
#line 566 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp12_, "16.5"), "\"16.5\" in t.get_attribute (\"monthrate\")");
#line 566 "GomSerializationTest.vala"
	_g_free0 (_tmp12_);
#line 567 "GomSerializationTest.vala"
	gom_serialization_test_taxes_set_month (t, GOM_SERIALIZATION_TEST_TAXES_MONTH_FEBRUARY);
#line 568 "GomSerializationTest.vala"
	_tmp13_ = gom_serialization_test_taxes_get_month (t);
#line 568 "GomSerializationTest.vala"
	_tmp14_ = _tmp13_;
#line 568 "GomSerializationTest.vala"
	_vala_assert (_tmp14_ == GOM_SERIALIZATION_TEST_TAXES_MONTH_FEBRUARY, "t.month == Taxes.Month.FEBRUARY");
#line 569 "GomSerializationTest.vala"
	_tmp15_ = gxml_dom_element_get_attribute ((GXmlDomElement*) t, "month");
#line 569 "GomSerializationTest.vala"
	_tmp16_ = _tmp15_;
#line 569 "GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp16_, "february") == 0, "t.get_attribute (\"month\") == \"february\"");
#line 569 "GomSerializationTest.vala"
	_g_free0 (_tmp16_);
#line 570 "GomSerializationTest.vala"
	gom_serialization_test_taxes_set_tax_free (t, TRUE);
#line 571 "GomSerializationTest.vala"
	_tmp17_ = gom_serialization_test_taxes_get_tax_free (t);
#line 571 "GomSerializationTest.vala"
	_tmp18_ = _tmp17_;
#line 571 "GomSerializationTest.vala"
	_vala_assert (_tmp18_ == TRUE, "t.tax_free == true");
#line 572 "GomSerializationTest.vala"
	_tmp19_ = gxml_dom_element_get_attribute ((GXmlDomElement*) t, "taxfree");
#line 572 "GomSerializationTest.vala"
	_tmp20_ = _tmp19_;
#line 572 "GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp20_, "true") == 0, "t.get_attribute (\"taxfree\") == \"true\"");
#line 572 "GomSerializationTest.vala"
	_g_free0 (_tmp20_);
#line 573 "GomSerializationTest.vala"
	_tmp21_ = gom_serialization_test_taxes_to_string (t);
#line 573 "GomSerializationTest.vala"
	_g_free0 (s);
#line 573 "GomSerializationTest.vala"
	s = _tmp21_;
#line 574 "GomSerializationTest.vala"
	_tmp22_ = s;
#line 574 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp22_, "<Taxes "), "\"<Taxes \" in s");
#line 575 "GomSerializationTest.vala"
	_tmp23_ = s;
#line 575 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp23_, "monthRate=\"16.5\""), "\"monthRate=\\\"16.5\\\"\" in s");
#line 576 "GomSerializationTest.vala"
	_tmp24_ = s;
#line 576 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp24_, "Month=\"february\""), "\"Month=\\\"february\\\"\" in s");
#line 577 "GomSerializationTest.vala"
	_tmp25_ = s;
#line 577 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp25_, "TaxFree=\"true\""), "\"TaxFree=\\\"true\\\"\" in s");
#line 553 "GomSerializationTest.vala"
	_g_free0 (s);
#line 553 "GomSerializationTest.vala"
	_g_object_unref0 (t);
#line 7266 "GomSerializationTest.c"
}

static void
___lambda121__gtest_func (void)
{
#line 553 "GomSerializationTest.vala"
	__lambda121_ ();
#line 7274 "GomSerializationTest.c"
}

static void
__lambda122_ (void)
{
	GomSerializationTestTaxes* t = NULL;
	GomSerializationTestTaxes* _tmp0_;
	gchar* s = NULL;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	GXmlGomDate* _tmp7_;
	GXmlGomDate* _tmp8_;
	GDate d = {0};
	GXmlGomDate* _tmp9_;
	GXmlGomDate* _tmp10_;
	GXmlGomDate* _tmp11_;
	GXmlGomDate* _tmp12_;
	GDate _tmp13_;
	GXmlGomDate* _tmp14_;
	GXmlGomDate* _tmp15_;
	GDate _tmp16_ = {0};
	GXmlGomDate* _tmp17_;
	GXmlGomDate* _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	gchar* _tmp21_;
	GXmlGomDate* _tmp22_;
	GXmlGomDate* _tmp23_;
	gchar* _tmp24_;
	gchar* _tmp25_;
	gchar* _tmp26_;
	GXmlGomDate* _tmp27_;
	GXmlGomDate* _tmp28_;
	GXmlGomDate* _tmp29_;
	GXmlGomDate* _tmp30_;
	GDate _tmp31_ = {0};
	GXmlGomDate* _tmp32_;
	GXmlGomDate* _tmp33_;
	gchar* _tmp34_;
	gchar* _tmp35_;
	gchar* _tmp36_;
	GXmlGomDate* _tmp37_;
	GXmlGomDate* _tmp38_;
	gchar* _tmp39_;
	gchar* _tmp40_;
	gchar* _tmp41_;
	GXmlGomDate* _tmp42_;
	GXmlGomDate* _tmp43_;
	GXmlGomDate* _tmp44_;
	GXmlGomDate* _tmp45_;
	GDate _tmp46_ = {0};
	GXmlGomDate* _tmp47_;
	GXmlGomDate* _tmp48_;
	gchar* _tmp49_;
	gchar* _tmp50_;
	gchar* _tmp51_;
	GXmlGomDate* _tmp52_;
	GXmlGomDate* _tmp53_;
	gchar* _tmp54_;
	gchar* _tmp55_;
	gchar* _tmp56_;
	gchar* _tmp57_;
	const gchar* _tmp58_;
	const gchar* _tmp59_;
	GXmlGomDate* gd = NULL;
	GXmlGomDate* _tmp60_;
	GDate _tmp61_ = {0};
	gchar* _tmp62_;
	gchar* _tmp63_;
	gchar* _tmp64_;
#line 583 "GomSerializationTest.vala"
	_tmp0_ = gom_serialization_test_taxes_new ();
#line 583 "GomSerializationTest.vala"
	t = _tmp0_;
#line 584 "GomSerializationTest.vala"
	_tmp1_ = gom_serialization_test_taxes_to_string (t);
#line 584 "GomSerializationTest.vala"
	s = _tmp1_;
#line 585 "GomSerializationTest.vala"
	_tmp2_ = s;
#line 585 "GomSerializationTest.vala"
	_vala_assert (_tmp2_ != NULL, "s != null");
#line 589 "GomSerializationTest.vala"
	_tmp3_ = s;
#line 589 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp3_, "<Taxes "), "\"<Taxes \" in s");
#line 590 "GomSerializationTest.vala"
	_tmp4_ = s;
#line 590 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp4_, "monthRate=\"0\""), "\"monthRate=\\\"0\\\"\" in s");
#line 591 "GomSerializationTest.vala"
	_tmp5_ = s;
#line 591 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp5_, "Month=\"january\""), "\"Month=\\\"january\\\"\" in s");
#line 592 "GomSerializationTest.vala"
	_tmp6_ = s;
#line 592 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp6_, "TaxFree=\"false\""), "\"TaxFree=\\\"false\\\"\" in s");
#line 593 "GomSerializationTest.vala"
	_tmp7_ = gxml_gom_date_new ();
#line 593 "GomSerializationTest.vala"
	_tmp8_ = _tmp7_;
#line 593 "GomSerializationTest.vala"
	gom_serialization_test_taxes_set_pay_date (t, _tmp8_);
#line 593 "GomSerializationTest.vala"
	_g_object_unref0 (_tmp8_);
#line 594 "GomSerializationTest.vala"
	memset (&d, 0, sizeof (GDate));
#line 595 "GomSerializationTest.vala"
	g_date_set_dmy (&d, (GDateDay) 1, (gint) ((GDateMonth) 2), (GDateYear) 2017);
#line 596 "GomSerializationTest.vala"
	_vala_assert (g_date_valid (&d), "d.valid ()");
#line 597 "GomSerializationTest.vala"
	_tmp9_ = gom_serialization_test_taxes_get_pay_date (t);
#line 597 "GomSerializationTest.vala"
	_tmp10_ = _tmp9_;
#line 597 "GomSerializationTest.vala"
	_vala_assert (_tmp10_ != NULL, "t.pay_date != null");
#line 598 "GomSerializationTest.vala"
	_tmp11_ = gom_serialization_test_taxes_get_pay_date (t);
#line 598 "GomSerializationTest.vala"
	_tmp12_ = _tmp11_;
#line 598 "GomSerializationTest.vala"
	_tmp13_ = d;
#line 598 "GomSerializationTest.vala"
	gxml_gom_date_set_date (_tmp12_, &_tmp13_);
#line 599 "GomSerializationTest.vala"
	_tmp14_ = gom_serialization_test_taxes_get_pay_date (t);
#line 599 "GomSerializationTest.vala"
	_tmp15_ = _tmp14_;
#line 599 "GomSerializationTest.vala"
	gxml_gom_date_get_date (_tmp15_, &_tmp16_);
#line 599 "GomSerializationTest.vala"
	_vala_assert (g_date_valid (&_tmp16_), "t.pay_date.get_date ().valid ()");
#line 600 "GomSerializationTest.vala"
	_tmp17_ = gom_serialization_test_taxes_get_pay_date (t);
#line 600 "GomSerializationTest.vala"
	_tmp18_ = _tmp17_;
#line 600 "GomSerializationTest.vala"
	_tmp19_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp18_);
#line 600 "GomSerializationTest.vala"
	_tmp20_ = _tmp19_;
#line 600 "GomSerializationTest.vala"
	_tmp21_ = _tmp20_;
#line 600 "GomSerializationTest.vala"
	_vala_assert (_tmp21_ != NULL, "t.pay_date.value != null");
#line 600 "GomSerializationTest.vala"
	_g_free0 (_tmp21_);
#line 601 "GomSerializationTest.vala"
	_tmp22_ = gom_serialization_test_taxes_get_pay_date (t);
#line 601 "GomSerializationTest.vala"
	_tmp23_ = _tmp22_;
#line 601 "GomSerializationTest.vala"
	_tmp24_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp23_);
#line 601 "GomSerializationTest.vala"
	_tmp25_ = _tmp24_;
#line 601 "GomSerializationTest.vala"
	_tmp26_ = _tmp25_;
#line 601 "GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp26_, "2017-02-01") == 0, "t.pay_date.value == \"2017-02-01\"");
#line 601 "GomSerializationTest.vala"
	_g_free0 (_tmp26_);
#line 602 "GomSerializationTest.vala"
	_tmp27_ = gom_serialization_test_taxes_get_pay_date (t);
#line 602 "GomSerializationTest.vala"
	_tmp28_ = _tmp27_;
#line 602 "GomSerializationTest.vala"
	gxml_gom_property_set_value ((GXmlGomBaseProperty*) _tmp28_, "2023-3-10");
#line 603 "GomSerializationTest.vala"
	_tmp29_ = gom_serialization_test_taxes_get_pay_date (t);
#line 603 "GomSerializationTest.vala"
	_tmp30_ = _tmp29_;
#line 603 "GomSerializationTest.vala"
	gxml_gom_date_get_date (_tmp30_, &_tmp31_);
#line 603 "GomSerializationTest.vala"
	_vala_assert (g_date_valid (&_tmp31_), "t.pay_date.get_date ().valid ()");
#line 604 "GomSerializationTest.vala"
	_tmp32_ = gom_serialization_test_taxes_get_pay_date (t);
#line 604 "GomSerializationTest.vala"
	_tmp33_ = _tmp32_;
#line 604 "GomSerializationTest.vala"
	_tmp34_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp33_);
#line 604 "GomSerializationTest.vala"
	_tmp35_ = _tmp34_;
#line 604 "GomSerializationTest.vala"
	_tmp36_ = _tmp35_;
#line 604 "GomSerializationTest.vala"
	_vala_assert (_tmp36_ != NULL, "t.pay_date.value != null");
#line 604 "GomSerializationTest.vala"
	_g_free0 (_tmp36_);
#line 605 "GomSerializationTest.vala"
	_tmp37_ = gom_serialization_test_taxes_get_pay_date (t);
#line 605 "GomSerializationTest.vala"
	_tmp38_ = _tmp37_;
#line 605 "GomSerializationTest.vala"
	_tmp39_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp38_);
#line 605 "GomSerializationTest.vala"
	_tmp40_ = _tmp39_;
#line 605 "GomSerializationTest.vala"
	_tmp41_ = _tmp40_;
#line 605 "GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp41_, "2023-03-10") == 0, "t.pay_date.value == \"2023-03-10\"");
#line 605 "GomSerializationTest.vala"
	_g_free0 (_tmp41_);
#line 606 "GomSerializationTest.vala"
	_tmp42_ = gom_serialization_test_taxes_get_pay_date (t);
#line 606 "GomSerializationTest.vala"
	_tmp43_ = _tmp42_;
#line 606 "GomSerializationTest.vala"
	gxml_gom_property_set_value ((GXmlGomBaseProperty*) _tmp43_, "2075-3-17");
#line 607 "GomSerializationTest.vala"
	_tmp44_ = gom_serialization_test_taxes_get_pay_date (t);
#line 607 "GomSerializationTest.vala"
	_tmp45_ = _tmp44_;
#line 607 "GomSerializationTest.vala"
	gxml_gom_date_get_date (_tmp45_, &_tmp46_);
#line 607 "GomSerializationTest.vala"
	_vala_assert (g_date_valid (&_tmp46_), "t.pay_date.get_date ().valid ()");
#line 608 "GomSerializationTest.vala"
	_tmp47_ = gom_serialization_test_taxes_get_pay_date (t);
#line 608 "GomSerializationTest.vala"
	_tmp48_ = _tmp47_;
#line 608 "GomSerializationTest.vala"
	_tmp49_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp48_);
#line 608 "GomSerializationTest.vala"
	_tmp50_ = _tmp49_;
#line 608 "GomSerializationTest.vala"
	_tmp51_ = _tmp50_;
#line 608 "GomSerializationTest.vala"
	_vala_assert (_tmp51_ != NULL, "t.pay_date.value != null");
#line 608 "GomSerializationTest.vala"
	_g_free0 (_tmp51_);
#line 609 "GomSerializationTest.vala"
	_tmp52_ = gom_serialization_test_taxes_get_pay_date (t);
#line 609 "GomSerializationTest.vala"
	_tmp53_ = _tmp52_;
#line 609 "GomSerializationTest.vala"
	_tmp54_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp53_);
#line 609 "GomSerializationTest.vala"
	_tmp55_ = _tmp54_;
#line 609 "GomSerializationTest.vala"
	_tmp56_ = _tmp55_;
#line 609 "GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp56_, "2075-03-17") == 0, "t.pay_date.value == \"2075-03-17\"");
#line 609 "GomSerializationTest.vala"
	_g_free0 (_tmp56_);
#line 610 "GomSerializationTest.vala"
	_tmp57_ = gom_serialization_test_taxes_to_string (t);
#line 610 "GomSerializationTest.vala"
	_g_free0 (s);
#line 610 "GomSerializationTest.vala"
	s = _tmp57_;
#line 611 "GomSerializationTest.vala"
	_tmp58_ = s;
#line 611 "GomSerializationTest.vala"
	_vala_assert (_tmp58_ != NULL, "s != null");
#line 612 "GomSerializationTest.vala"
	_tmp59_ = s;
#line 612 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp59_, "PayDate=\"2075-03-17\""), "\"PayDate=\\\"2075-03-17\\\"\" in s");
#line 613 "GomSerializationTest.vala"
	_tmp60_ = gxml_gom_date_new ();
#line 613 "GomSerializationTest.vala"
	gd = _tmp60_;
#line 614 "GomSerializationTest.vala"
	gxml_gom_property_set_value ((GXmlGomBaseProperty*) gd, "2076-03-17");
#line 615 "GomSerializationTest.vala"
	gxml_gom_date_get_date (gd, &_tmp61_);
#line 615 "GomSerializationTest.vala"
	_vala_assert (g_date_valid (&_tmp61_), "gd.get_date ().valid ()");
#line 616 "GomSerializationTest.vala"
	_tmp62_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) gd);
#line 616 "GomSerializationTest.vala"
	_tmp63_ = _tmp62_;
#line 616 "GomSerializationTest.vala"
	_tmp64_ = _tmp63_;
#line 616 "GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp64_, "2076-03-17") == 0, "gd.value == \"2076-03-17\"");
#line 616 "GomSerializationTest.vala"
	_g_free0 (_tmp64_);
#line 582 "GomSerializationTest.vala"
	_g_object_unref0 (gd);
#line 582 "GomSerializationTest.vala"
	_g_free0 (s);
#line 582 "GomSerializationTest.vala"
	_g_object_unref0 (t);
#line 7565 "GomSerializationTest.c"
}

static void
___lambda122__gtest_func (void)
{
#line 582 "GomSerializationTest.vala"
	__lambda122_ ();
#line 7573 "GomSerializationTest.c"
}

static void
__lambda123_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GomSerializationTestTaxes* t = NULL;
		GomSerializationTestTaxes* _tmp0_;
		gchar* s = NULL;
		gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
		GXmlGomDate* _tmp4_;
		GXmlGomDate* _tmp5_;
		GXmlGomDate* _tmp6_;
		GXmlGomDate* _tmp7_;
		GDate _tmp8_ = {0};
		GXmlGomDate* _tmp9_;
		GXmlGomDate* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		GXmlGomDate* _tmp14_;
		GXmlGomDate* _tmp15_;
		gchar* _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_;
#line 620 "GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_taxes_new ();
#line 620 "GomSerializationTest.vala"
		t = _tmp0_;
#line 621 "GomSerializationTest.vala"
		gxml_dom_element_read_from_string ((GXmlDomElement*) t, "<Taxes PayDate=\"2050-12-09\"/>", NULL, &_inner_error0_);
#line 621 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 621 "GomSerializationTest.vala"
			_g_object_unref0 (t);
#line 7612 "GomSerializationTest.c"
			goto __catch175_g_error;
		}
#line 622 "GomSerializationTest.vala"
		_tmp1_ = gom_serialization_test_taxes_to_string (t);
#line 622 "GomSerializationTest.vala"
		s = _tmp1_;
#line 623 "GomSerializationTest.vala"
		_vala_assert (s != NULL, "s != null");
#line 625 "GomSerializationTest.vala"
		_tmp2_ = g_strconcat ("DOC:", s, NULL);
#line 625 "GomSerializationTest.vala"
		_tmp3_ = _tmp2_;
#line 625 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:625: %s", _tmp3_);
#line 625 "GomSerializationTest.vala"
		_g_free0 (_tmp3_);
#line 627 "GomSerializationTest.vala"
		_vala_assert (string_contains (s, "<Taxes "), "\"<Taxes \" in s");
#line 628 "GomSerializationTest.vala"
		_vala_assert (string_contains (s, "monthRate=\"0\""), "\"monthRate=\\\"0\\\"\" in s");
#line 629 "GomSerializationTest.vala"
		_vala_assert (string_contains (s, "Month=\"january\""), "\"Month=\\\"january\\\"\" in s");
#line 630 "GomSerializationTest.vala"
		_vala_assert (string_contains (s, "TaxFree=\"false\""), "\"TaxFree=\\\"false\\\"\" in s");
#line 631 "GomSerializationTest.vala"
		_tmp4_ = gom_serialization_test_taxes_get_pay_date (t);
#line 631 "GomSerializationTest.vala"
		_tmp5_ = _tmp4_;
#line 631 "GomSerializationTest.vala"
		_vala_assert (_tmp5_ != NULL, "t.pay_date != null");
#line 632 "GomSerializationTest.vala"
		_tmp6_ = gom_serialization_test_taxes_get_pay_date (t);
#line 632 "GomSerializationTest.vala"
		_tmp7_ = _tmp6_;
#line 632 "GomSerializationTest.vala"
		gxml_gom_date_get_date (_tmp7_, &_tmp8_);
#line 632 "GomSerializationTest.vala"
		_vala_assert (g_date_valid (&_tmp8_), "t.pay_date.get_date ().valid ()");
#line 633 "GomSerializationTest.vala"
		_tmp9_ = gom_serialization_test_taxes_get_pay_date (t);
#line 633 "GomSerializationTest.vala"
		_tmp10_ = _tmp9_;
#line 633 "GomSerializationTest.vala"
		_tmp11_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp10_);
#line 633 "GomSerializationTest.vala"
		_tmp12_ = _tmp11_;
#line 633 "GomSerializationTest.vala"
		_tmp13_ = _tmp12_;
#line 633 "GomSerializationTest.vala"
		_vala_assert (_tmp13_ != NULL, "t.pay_date.value != null");
#line 633 "GomSerializationTest.vala"
		_g_free0 (_tmp13_);
#line 634 "GomSerializationTest.vala"
		_tmp14_ = gom_serialization_test_taxes_get_pay_date (t);
#line 634 "GomSerializationTest.vala"
		_tmp15_ = _tmp14_;
#line 634 "GomSerializationTest.vala"
		_tmp16_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp15_);
#line 634 "GomSerializationTest.vala"
		_tmp17_ = _tmp16_;
#line 634 "GomSerializationTest.vala"
		_tmp18_ = _tmp17_;
#line 634 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp18_, "2050-12-09") == 0, "t.pay_date.value == \"2050-12-09\"");
#line 634 "GomSerializationTest.vala"
		_g_free0 (_tmp18_);
#line 619 "GomSerializationTest.vala"
		_g_free0 (s);
#line 619 "GomSerializationTest.vala"
		_g_object_unref0 (t);
#line 7683 "GomSerializationTest.c"
	}
	goto __finally175;
	__catch175_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
#line 619 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 619 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 636 "GomSerializationTest.vala"
		_tmp19_ = e->message;
#line 636 "GomSerializationTest.vala"
		_tmp20_ = g_strconcat ("Error: ", _tmp19_, NULL);
#line 636 "GomSerializationTest.vala"
		_tmp21_ = _tmp20_;
#line 636 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:636: %s", _tmp21_);
#line 636 "GomSerializationTest.vala"
		_g_free0 (_tmp21_);
#line 637 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 619 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 7710 "GomSerializationTest.c"
	}
	__finally175:
#line 619 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 619 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 619 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 619 "GomSerializationTest.vala"
		return;
#line 7721 "GomSerializationTest.c"
	}
}

static void
___lambda123__gtest_func (void)
{
#line 618 "GomSerializationTest.vala"
	__lambda123_ ();
#line 7730 "GomSerializationTest.c"
}

static void
__lambda124_ (void)
{
	GomSerializationTestTaxes* t = NULL;
	GomSerializationTestTaxes* _tmp0_;
	gchar* s = NULL;
	gchar* _tmp1_;
	GXmlGomDateTime* _tmp2_;
	GXmlGomDateTime* _tmp3_;
	GDateTime* d = NULL;
	GDateTime* _tmp4_;
	GXmlGomDateTime* _tmp5_;
	GXmlGomDateTime* _tmp6_;
	GXmlGomDateTime* _tmp7_;
	GXmlGomDateTime* _tmp8_;
	GXmlGomDateTime* _tmp9_;
	GXmlGomDateTime* _tmp10_;
	GXmlGomDateTime* _tmp11_;
	GXmlGomDateTime* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	GXmlGomDateTime* _tmp16_;
	GXmlGomDateTime* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	GXmlGomDateTime* _tmp21_;
	GXmlGomDateTime* _tmp22_;
	GXmlGomDateTime* _tmp23_;
	GXmlGomDateTime* _tmp24_;
	gchar* _tmp25_;
	gchar* _tmp26_;
	gchar* _tmp27_;
	GXmlGomDateTime* _tmp28_;
	GXmlGomDateTime* _tmp29_;
	gchar* _tmp30_;
	gchar* _tmp31_;
	gchar* _tmp32_;
	gchar* s2 = NULL;
	gchar* _tmp33_;
#line 641 "GomSerializationTest.vala"
	_tmp0_ = gom_serialization_test_taxes_new ();
#line 641 "GomSerializationTest.vala"
	t = _tmp0_;
#line 642 "GomSerializationTest.vala"
	_tmp1_ = gom_serialization_test_taxes_to_string (t);
#line 642 "GomSerializationTest.vala"
	s = _tmp1_;
#line 643 "GomSerializationTest.vala"
	_vala_assert (s != NULL, "s != null");
#line 647 "GomSerializationTest.vala"
	_vala_assert (string_contains (s, "<Taxes "), "\"<Taxes \" in s");
#line 648 "GomSerializationTest.vala"
	_vala_assert (string_contains (s, "monthRate=\"0\""), "\"monthRate=\\\"0\\\"\" in s");
#line 649 "GomSerializationTest.vala"
	_vala_assert (string_contains (s, "Month=\"january\""), "\"Month=\\\"january\\\"\" in s");
#line 650 "GomSerializationTest.vala"
	_vala_assert (string_contains (s, "TaxFree=\"false\""), "\"TaxFree=\\\"false\\\"\" in s");
#line 651 "GomSerializationTest.vala"
	_tmp2_ = gxml_gom_date_time_new ();
#line 651 "GomSerializationTest.vala"
	_tmp3_ = _tmp2_;
#line 651 "GomSerializationTest.vala"
	gom_serialization_test_taxes_set_timestamp (t, _tmp3_);
#line 651 "GomSerializationTest.vala"
	_g_object_unref0 (_tmp3_);
#line 652 "GomSerializationTest.vala"
	_tmp4_ = g_date_time_new_local (2017, 2, 10, 14, 14, 20.345);
#line 652 "GomSerializationTest.vala"
	d = _tmp4_;
#line 658 "GomSerializationTest.vala"
	_tmp5_ = gom_serialization_test_taxes_get_timestamp (t);
#line 658 "GomSerializationTest.vala"
	_tmp6_ = _tmp5_;
#line 658 "GomSerializationTest.vala"
	_vala_assert (_tmp6_ != NULL, "t.timestamp != null");
#line 659 "GomSerializationTest.vala"
	_tmp7_ = gom_serialization_test_taxes_get_timestamp (t);
#line 659 "GomSerializationTest.vala"
	_tmp8_ = _tmp7_;
#line 659 "GomSerializationTest.vala"
	gxml_gom_date_time_set_datetime (_tmp8_, d);
#line 660 "GomSerializationTest.vala"
	_tmp9_ = gom_serialization_test_taxes_get_timestamp (t);
#line 660 "GomSerializationTest.vala"
	_tmp10_ = _tmp9_;
#line 660 "GomSerializationTest.vala"
	_vala_assert (_tmp10_ != NULL, "t.timestamp != null");
#line 661 "GomSerializationTest.vala"
	_tmp11_ = gom_serialization_test_taxes_get_timestamp (t);
#line 661 "GomSerializationTest.vala"
	_tmp12_ = _tmp11_;
#line 661 "GomSerializationTest.vala"
	_tmp13_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp12_);
#line 661 "GomSerializationTest.vala"
	_tmp14_ = _tmp13_;
#line 661 "GomSerializationTest.vala"
	_tmp15_ = _tmp14_;
#line 661 "GomSerializationTest.vala"
	_vala_assert (_tmp15_ != NULL, "t.timestamp.value != null");
#line 661 "GomSerializationTest.vala"
	_g_free0 (_tmp15_);
#line 662 "GomSerializationTest.vala"
	_tmp16_ = gom_serialization_test_taxes_get_timestamp (t);
#line 662 "GomSerializationTest.vala"
	_tmp17_ = _tmp16_;
#line 662 "GomSerializationTest.vala"
	_tmp18_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp17_);
#line 662 "GomSerializationTest.vala"
	_tmp19_ = _tmp18_;
#line 662 "GomSerializationTest.vala"
	_tmp20_ = _tmp19_;
#line 662 "GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp20_, "2017-02-10T14:14:20") == 0, "t.timestamp.value == \"2017-02-10T14:14:20\"");
#line 662 "GomSerializationTest.vala"
	_g_free0 (_tmp20_);
#line 663 "GomSerializationTest.vala"
	_tmp21_ = gom_serialization_test_taxes_get_timestamp (t);
#line 663 "GomSerializationTest.vala"
	_tmp22_ = _tmp21_;
#line 663 "GomSerializationTest.vala"
	gxml_gom_property_set_value ((GXmlGomBaseProperty*) _tmp22_, "2023-3-10T15:23:10.356");
#line 664 "GomSerializationTest.vala"
	_tmp23_ = gom_serialization_test_taxes_get_timestamp (t);
#line 664 "GomSerializationTest.vala"
	_tmp24_ = _tmp23_;
#line 664 "GomSerializationTest.vala"
	_tmp25_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp24_);
#line 664 "GomSerializationTest.vala"
	_tmp26_ = _tmp25_;
#line 664 "GomSerializationTest.vala"
	_tmp27_ = _tmp26_;
#line 664 "GomSerializationTest.vala"
	_vala_assert (_tmp27_ != NULL, "t.timestamp.value != null");
#line 664 "GomSerializationTest.vala"
	_g_free0 (_tmp27_);
#line 665 "GomSerializationTest.vala"
	_tmp28_ = gom_serialization_test_taxes_get_timestamp (t);
#line 665 "GomSerializationTest.vala"
	_tmp29_ = _tmp28_;
#line 665 "GomSerializationTest.vala"
	_tmp30_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp29_);
#line 665 "GomSerializationTest.vala"
	_tmp31_ = _tmp30_;
#line 665 "GomSerializationTest.vala"
	_tmp32_ = _tmp31_;
#line 665 "GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp32_, "2023-03-10T15:23:10") == 0, "t.timestamp.value == \"2023-03-10T15:23:10\"");
#line 665 "GomSerializationTest.vala"
	_g_free0 (_tmp32_);
#line 666 "GomSerializationTest.vala"
	_tmp33_ = gom_serialization_test_taxes_to_string (t);
#line 666 "GomSerializationTest.vala"
	s2 = _tmp33_;
#line 667 "GomSerializationTest.vala"
	_vala_assert (s2 != NULL, "s2 != null");
#line 671 "GomSerializationTest.vala"
	_vala_assert (string_contains (s2, "Timestamp=\"2023-03-10T15:23:10\""), "\"Timestamp=\\\"2023-03-10T15:23:10\\\"\" in s2");
#line 640 "GomSerializationTest.vala"
	_g_free0 (s2);
#line 640 "GomSerializationTest.vala"
	_g_date_time_unref0 (d);
#line 640 "GomSerializationTest.vala"
	_g_free0 (s);
#line 640 "GomSerializationTest.vala"
	_g_object_unref0 (t);
#line 7900 "GomSerializationTest.c"
}

static void
___lambda124__gtest_func (void)
{
#line 640 "GomSerializationTest.vala"
	__lambda124_ ();
#line 7908 "GomSerializationTest.c"
}

static void
__lambda125_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GomSerializationTestBookStand* bs = NULL;
		GomSerializationTestBookStand* _tmp0_;
		gchar* s = NULL;
		GomSerializationTestBookStand* _tmp1_;
		gchar* _tmp2_;
		const gchar* _tmp3_;
		const gchar* _tmp4_;
		GomSerializationTestBookStand* _tmp5_;
		GXmlDomDocument* _tmp6_;
		GXmlDomDocument* _tmp7_;
		GomSerializationTestBookStand* _tmp8_;
		GomSerializationTestRegisters* _tmp9_;
		GomSerializationTestRegisters* _tmp10_;
		GomSerializationTestBookStand* _tmp11_;
		GomSerializationTestBookStand* _tmp12_;
		gchar* _tmp13_;
		const gchar* _tmp14_;
		const gchar* _tmp15_;
		GomSerializationTestBookRegister* br2 = NULL;
		GomSerializationTestBookStand* _tmp21_;
		GomSerializationTestRegisters* _tmp22_;
		GomSerializationTestRegisters* _tmp23_;
		GXmlDomElement* _tmp24_;
		GomSerializationTestBookRegister* _tmp25_;
		GomSerializationTestBookRegister* _tmp26_;
		GomSerializationTestBookStand* _tmp27_;
		GomSerializationTestRegisters* _tmp28_;
		GomSerializationTestRegisters* _tmp29_;
		GomSerializationTestBookRegister* _tmp30_;
		GomSerializationTestBookStand* _tmp31_;
		gchar* _tmp32_;
		const gchar* _tmp33_;
		const gchar* _tmp34_;
		GomSerializationTestBookRegister* br3 = NULL;
		GomSerializationTestBookStand* _tmp35_;
		GomSerializationTestRegisters* _tmp36_;
		GomSerializationTestRegisters* _tmp37_;
		GXmlDomElement* _tmp38_;
		GomSerializationTestBookRegister* _tmp39_;
		GomSerializationTestBookStand* _tmp40_;
		GomSerializationTestRegisters* _tmp41_;
		GomSerializationTestRegisters* _tmp42_;
		GomSerializationTestBookRegister* _tmp43_;
		GomSerializationTestBookRegister* _tmp44_;
		GXmlDomElement* _tmp45_ = NULL;
		GomSerializationTestBookStand* _tmp46_;
		GXmlDomDocument* _tmp47_;
		GXmlDomDocument* _tmp48_;
		GXmlDomElement* _tmp49_;
		GomSerializationTestBookStand* _tmp50_;
		GXmlDomNode* _tmp51_;
		GXmlDomNode* _tmp52_;
		GomSerializationTestBookRegister* br4 = NULL;
		GomSerializationTestBookStand* _tmp53_;
		GomSerializationTestRegisters* _tmp54_;
		GomSerializationTestRegisters* _tmp55_;
		GXmlDomElement* _tmp56_;
		GomSerializationTestBookRegister* _tmp57_;
		GomSerializationTestBookStand* _tmp58_;
		GomSerializationTestRegisters* _tmp59_;
		GomSerializationTestRegisters* _tmp60_;
		GomSerializationTestBookRegister* _tmp61_;
		GomSerializationTestBookRegister* _tmp62_;
		GomSerializationTestBookStand* _tmp63_;
		gchar* _tmp64_;
		const gchar* _tmp65_;
		const gchar* _tmp66_;
		GXmlDomElement* _tmp67_ = NULL;
		GomSerializationTestBookStand* _tmp68_;
		GomSerializationTestRegisters* _tmp69_;
		GomSerializationTestRegisters* _tmp70_;
		GXmlDomElement* _tmp71_;
		gint _tmp72_;
		gint _tmp73_;
		GXmlDomElement* _tmp74_ = NULL;
		GomSerializationTestBookStand* _tmp75_;
		GomSerializationTestRegisters* _tmp76_;
		GomSerializationTestRegisters* _tmp77_;
		GXmlDomElement* _tmp78_;
		gint _tmp79_;
		gint _tmp80_;
		GXmlDomElement* _tmp81_ = NULL;
		GomSerializationTestBookStand* _tmp82_;
		GomSerializationTestRegisters* _tmp83_;
		GomSerializationTestRegisters* _tmp84_;
		GXmlDomElement* _tmp85_;
		gint _tmp86_;
		gint _tmp87_;
		GomSerializationTestBookStand* _tmp88_;
		GomSerializationTestBookStand* _tmp89_;
		GomSerializationTestBookStandDimension* _tmp90_;
		GomSerializationTestBookStandDimension* _tmp91_;
		GomSerializationTestBookStand* _tmp92_;
		GomSerializationTestBookStandDimension* _tmp93_;
		GomSerializationTestBookStandDimension* _tmp94_;
		gdouble _tmp95_;
		gdouble _tmp96_;
		GomSerializationTestBookStand* _tmp97_;
		gchar* _tmp98_;
		const gchar* _tmp99_;
		const gchar* _tmp100_;
		gchar* _tmp101_;
		gchar* _tmp102_;
		const gchar* _tmp103_;
		GomSerializationTestBookStand* _tmp104_;
		GomSerializationTestBookStand* _tmp105_;
		GomSerializationTestBookStandDimensionY* _tmp106_;
		GomSerializationTestBookStandDimensionY* _tmp107_;
		GomSerializationTestBookStand* _tmp108_;
		GomSerializationTestBookStandDimensionY* _tmp109_;
		GomSerializationTestBookStandDimensionY* _tmp110_;
		gdouble _tmp111_;
		gdouble _tmp112_;
		GomSerializationTestBookStand* _tmp113_;
		gchar* _tmp114_;
		const gchar* _tmp115_;
		const gchar* _tmp116_;
		gchar* _tmp117_;
		gchar* _tmp118_;
		const gchar* _tmp119_;
		GomSerializationTestBookStand* _tmp120_;
		GomSerializationTestBookStand* _tmp121_;
		GomSerializationTestBookStandDimensionZ* _tmp122_;
		GomSerializationTestBookStandDimensionZ* _tmp123_;
		GomSerializationTestBookStand* _tmp124_;
		GomSerializationTestBookStandDimensionZ* _tmp125_;
		GomSerializationTestBookStandDimensionZ* _tmp126_;
		gdouble _tmp127_;
		gdouble _tmp128_;
		GomSerializationTestBookStand* _tmp129_;
		gchar* _tmp130_;
		const gchar* _tmp131_;
		const gchar* _tmp132_;
		gchar* _tmp133_;
		gchar* _tmp134_;
		const gchar* _tmp135_;
#line 675 "GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_book_stand_new ();
#line 675 "GomSerializationTest.vala"
		bs = _tmp0_;
#line 676 "GomSerializationTest.vala"
		_tmp1_ = bs;
#line 676 "GomSerializationTest.vala"
		_tmp2_ = gom_serialization_test_book_stand_to_string (_tmp1_);
#line 676 "GomSerializationTest.vala"
		s = _tmp2_;
#line 677 "GomSerializationTest.vala"
		_tmp3_ = s;
#line 677 "GomSerializationTest.vala"
		_vala_assert (_tmp3_ != NULL, "s != null");
#line 681 "GomSerializationTest.vala"
		_tmp4_ = s;
#line 681 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp4_, "<BookStand Classification=\"Science\"/>"), "\"<BookStand Classification=\\\"Science\\\"/>\" in s");
#line 682 "GomSerializationTest.vala"
		_tmp5_ = bs;
#line 682 "GomSerializationTest.vala"
		_tmp6_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _tmp5_);
#line 682 "GomSerializationTest.vala"
		_tmp7_ = _tmp6_;
#line 682 "GomSerializationTest.vala"
		_vala_assert (_tmp7_ != NULL, "bs.owner_document != null");
#line 683 "GomSerializationTest.vala"
		_tmp8_ = bs;
#line 683 "GomSerializationTest.vala"
		_tmp9_ = gom_serialization_test_book_stand_get_registers (_tmp8_);
#line 683 "GomSerializationTest.vala"
		_tmp10_ = _tmp9_;
#line 683 "GomSerializationTest.vala"
		_vala_assert (_tmp10_ == NULL, "bs.registers == null");
#line 684 "GomSerializationTest.vala"
		_tmp11_ = bs;
#line 684 "GomSerializationTest.vala"
		_vala_assert (gxml_gom_object_set_instance_property ((GXmlGomObject*) _tmp11_, "registers"), "bs.set_instance_property (\"registers\")");
#line 685 "GomSerializationTest.vala"
		_tmp12_ = bs;
#line 685 "GomSerializationTest.vala"
		_tmp13_ = gom_serialization_test_book_stand_to_string (_tmp12_);
#line 685 "GomSerializationTest.vala"
		_g_free0 (s);
#line 685 "GomSerializationTest.vala"
		s = _tmp13_;
#line 686 "GomSerializationTest.vala"
		_tmp14_ = s;
#line 686 "GomSerializationTest.vala"
		_vala_assert (_tmp14_ != NULL, "s != null");
#line 690 "GomSerializationTest.vala"
		_tmp15_ = s;
#line 690 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp15_, "<BookStand Classification=\"Science\"/>"), "\"<BookStand Classification=\\\"Science\\\"/>\" in s");
#line 8106 "GomSerializationTest.c"
		{
			GomSerializationTestBookRegister* br = NULL;
			GomSerializationTestBookRegister* _tmp16_;
			GomSerializationTestBookStand* _tmp17_;
			GomSerializationTestRegisters* _tmp18_;
			GomSerializationTestRegisters* _tmp19_;
			GomSerializationTestBookRegister* _tmp20_;
#line 692 "GomSerializationTest.vala"
			_tmp16_ = gom_serialization_test_book_register_new ();
#line 692 "GomSerializationTest.vala"
			br = _tmp16_;
#line 693 "GomSerializationTest.vala"
			_tmp17_ = bs;
#line 693 "GomSerializationTest.vala"
			_tmp18_ = gom_serialization_test_book_stand_get_registers (_tmp17_);
#line 693 "GomSerializationTest.vala"
			_tmp19_ = _tmp18_;
#line 693 "GomSerializationTest.vala"
			_tmp20_ = br;
#line 693 "GomSerializationTest.vala"
			gxml_collection_append ((GXmlCollection*) _tmp19_, (GXmlDomElement*) _tmp20_, &_inner_error0_);
#line 693 "GomSerializationTest.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 693 "GomSerializationTest.vala"
				_g_object_unref0 (br);
#line 8132 "GomSerializationTest.c"
				goto __catch177_g_error;
			}
#line 694 "GomSerializationTest.vala"
			g_assert_not_reached ();
#line 691 "GomSerializationTest.vala"
			_g_object_unref0 (br);
#line 8139 "GomSerializationTest.c"
		}
		goto __finally177;
		__catch177_g_error:
		{
#line 691 "GomSerializationTest.vala"
			g_clear_error (&_inner_error0_);
#line 691 "GomSerializationTest.vala"
			_inner_error0_ = NULL;
#line 8148 "GomSerializationTest.c"
		}
		__finally177:
#line 691 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 691 "GomSerializationTest.vala"
			_g_free0 (s);
#line 691 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 8157 "GomSerializationTest.c"
			goto __catch176_g_error;
		}
#line 696 "GomSerializationTest.vala"
		_tmp21_ = bs;
#line 696 "GomSerializationTest.vala"
		_tmp22_ = gom_serialization_test_book_stand_get_registers (_tmp21_);
#line 696 "GomSerializationTest.vala"
		_tmp23_ = _tmp22_;
#line 696 "GomSerializationTest.vala"
		_tmp24_ = gxml_collection_create_item ((GXmlCollection*) _tmp23_);
#line 696 "GomSerializationTest.vala"
		_tmp25_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp24_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp24_) : NULL;
#line 696 "GomSerializationTest.vala"
		if (_tmp25_ == NULL) {
#line 696 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp24_);
#line 8174 "GomSerializationTest.c"
		}
#line 696 "GomSerializationTest.vala"
		br2 = _tmp25_;
#line 697 "GomSerializationTest.vala"
		_tmp26_ = br2;
#line 697 "GomSerializationTest.vala"
		gom_serialization_test_book_register_set_year (_tmp26_, 2016);
#line 698 "GomSerializationTest.vala"
		_tmp27_ = bs;
#line 698 "GomSerializationTest.vala"
		_tmp28_ = gom_serialization_test_book_stand_get_registers (_tmp27_);
#line 698 "GomSerializationTest.vala"
		_tmp29_ = _tmp28_;
#line 698 "GomSerializationTest.vala"
		_tmp30_ = br2;
#line 698 "GomSerializationTest.vala"
		gxml_collection_append ((GXmlCollection*) _tmp29_, (GXmlDomElement*) _tmp30_, &_inner_error0_);
#line 698 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 698 "GomSerializationTest.vala"
			_g_object_unref0 (br2);
#line 698 "GomSerializationTest.vala"
			_g_free0 (s);
#line 698 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 8200 "GomSerializationTest.c"
			goto __catch176_g_error;
		}
#line 699 "GomSerializationTest.vala"
		_tmp31_ = bs;
#line 699 "GomSerializationTest.vala"
		_tmp32_ = gom_serialization_test_book_stand_to_string (_tmp31_);
#line 699 "GomSerializationTest.vala"
		_g_free0 (s);
#line 699 "GomSerializationTest.vala"
		s = _tmp32_;
#line 700 "GomSerializationTest.vala"
		_tmp33_ = s;
#line 700 "GomSerializationTest.vala"
		_vala_assert (_tmp33_ != NULL, "s != null");
#line 704 "GomSerializationTest.vala"
		_tmp34_ = s;
#line 704 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp34_, "<BookStand Classification=\"Science\"><BookRegister Year=\"2016\"/></B" \
"ookStand>"), "\"<BookStand Classification=\\\"Science\\\"><BookRegister Year=\\\"2016\\\"/></BookStand>\" in s");
#line 705 "GomSerializationTest.vala"
		_tmp35_ = bs;
#line 705 "GomSerializationTest.vala"
		_tmp36_ = gom_serialization_test_book_stand_get_registers (_tmp35_);
#line 705 "GomSerializationTest.vala"
		_tmp37_ = _tmp36_;
#line 705 "GomSerializationTest.vala"
		_tmp38_ = gxml_collection_create_item ((GXmlCollection*) _tmp37_);
#line 705 "GomSerializationTest.vala"
		_tmp39_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp38_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp38_) : NULL;
#line 705 "GomSerializationTest.vala"
		if (_tmp39_ == NULL) {
#line 705 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp38_);
#line 8233 "GomSerializationTest.c"
		}
#line 705 "GomSerializationTest.vala"
		br3 = _tmp39_;
#line 706 "GomSerializationTest.vala"
		_tmp40_ = bs;
#line 706 "GomSerializationTest.vala"
		_tmp41_ = gom_serialization_test_book_stand_get_registers (_tmp40_);
#line 706 "GomSerializationTest.vala"
		_tmp42_ = _tmp41_;
#line 706 "GomSerializationTest.vala"
		_tmp43_ = br3;
#line 706 "GomSerializationTest.vala"
		gxml_collection_append ((GXmlCollection*) _tmp42_, (GXmlDomElement*) _tmp43_, &_inner_error0_);
#line 706 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 706 "GomSerializationTest.vala"
			_g_object_unref0 (br3);
#line 706 "GomSerializationTest.vala"
			_g_object_unref0 (br2);
#line 706 "GomSerializationTest.vala"
			_g_free0 (s);
#line 706 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 8257 "GomSerializationTest.c"
			goto __catch176_g_error;
		}
#line 707 "GomSerializationTest.vala"
		_tmp44_ = br3;
#line 707 "GomSerializationTest.vala"
		gom_serialization_test_book_register_set_year (_tmp44_, 2010);
#line 708 "GomSerializationTest.vala"
		_tmp46_ = bs;
#line 708 "GomSerializationTest.vala"
		_tmp47_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _tmp46_);
#line 708 "GomSerializationTest.vala"
		_tmp48_ = _tmp47_;
#line 708 "GomSerializationTest.vala"
		_tmp49_ = gxml_dom_document_create_element (_tmp48_, "Test", &_inner_error0_);
#line 708 "GomSerializationTest.vala"
		_tmp45_ = _tmp49_;
#line 708 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 708 "GomSerializationTest.vala"
			_g_object_unref0 (br3);
#line 708 "GomSerializationTest.vala"
			_g_object_unref0 (br2);
#line 708 "GomSerializationTest.vala"
			_g_free0 (s);
#line 708 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 8284 "GomSerializationTest.c"
			goto __catch176_g_error;
		}
#line 708 "GomSerializationTest.vala"
		_tmp50_ = bs;
#line 708 "GomSerializationTest.vala"
		_tmp51_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp50_, (GXmlDomNode*) _tmp45_, &_inner_error0_);
#line 708 "GomSerializationTest.vala"
		_tmp52_ = _tmp51_;
#line 708 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp52_);
#line 708 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 708 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 708 "GomSerializationTest.vala"
			_g_object_unref0 (br3);
#line 708 "GomSerializationTest.vala"
			_g_object_unref0 (br2);
#line 708 "GomSerializationTest.vala"
			_g_free0 (s);
#line 708 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 8307 "GomSerializationTest.c"
			goto __catch176_g_error;
		}
#line 709 "GomSerializationTest.vala"
		_tmp53_ = bs;
#line 709 "GomSerializationTest.vala"
		_tmp54_ = gom_serialization_test_book_stand_get_registers (_tmp53_);
#line 709 "GomSerializationTest.vala"
		_tmp55_ = _tmp54_;
#line 709 "GomSerializationTest.vala"
		_tmp56_ = gxml_collection_create_item ((GXmlCollection*) _tmp55_);
#line 709 "GomSerializationTest.vala"
		_tmp57_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp56_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp56_) : NULL;
#line 709 "GomSerializationTest.vala"
		if (_tmp57_ == NULL) {
#line 709 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp56_);
#line 8324 "GomSerializationTest.c"
		}
#line 709 "GomSerializationTest.vala"
		br4 = _tmp57_;
#line 710 "GomSerializationTest.vala"
		_tmp58_ = bs;
#line 710 "GomSerializationTest.vala"
		_tmp59_ = gom_serialization_test_book_stand_get_registers (_tmp58_);
#line 710 "GomSerializationTest.vala"
		_tmp60_ = _tmp59_;
#line 710 "GomSerializationTest.vala"
		_tmp61_ = br4;
#line 710 "GomSerializationTest.vala"
		gxml_collection_append ((GXmlCollection*) _tmp60_, (GXmlDomElement*) _tmp61_, &_inner_error0_);
#line 710 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 710 "GomSerializationTest.vala"
			_g_object_unref0 (br4);
#line 710 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 710 "GomSerializationTest.vala"
			_g_object_unref0 (br3);
#line 710 "GomSerializationTest.vala"
			_g_object_unref0 (br2);
#line 710 "GomSerializationTest.vala"
			_g_free0 (s);
#line 710 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 8352 "GomSerializationTest.c"
			goto __catch176_g_error;
		}
#line 711 "GomSerializationTest.vala"
		_tmp62_ = br4;
#line 711 "GomSerializationTest.vala"
		gom_serialization_test_book_register_set_year (_tmp62_, 2000);
#line 712 "GomSerializationTest.vala"
		_tmp63_ = bs;
#line 712 "GomSerializationTest.vala"
		_tmp64_ = gom_serialization_test_book_stand_to_string (_tmp63_);
#line 712 "GomSerializationTest.vala"
		_g_free0 (s);
#line 712 "GomSerializationTest.vala"
		s = _tmp64_;
#line 713 "GomSerializationTest.vala"
		_tmp65_ = s;
#line 713 "GomSerializationTest.vala"
		_vala_assert (_tmp65_ != NULL, "s != null");
#line 717 "GomSerializationTest.vala"
		_tmp66_ = s;
#line 717 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp66_, "<BookStand Classification=\"Science\"><BookRegister Year=\"2016\"/><Bo" \
"okRegister Year=\"2010\"/><Test/><BookRegister Year=\"2000\"/></BookSt" \
"and>"), "\"<BookStand Classification=\\\"Science\\\"><BookRegister Year=\\\"2016\\\"/><BookRegister Year=\\\"2010\\\"/><Test/><BookRegister Year=\\\"2000\\\"/></BookStand>\" in s");
#line 718 "GomSerializationTest.vala"
		_tmp68_ = bs;
#line 718 "GomSerializationTest.vala"
		_tmp69_ = gom_serialization_test_book_stand_get_registers (_tmp68_);
#line 718 "GomSerializationTest.vala"
		_tmp70_ = _tmp69_;
#line 718 "GomSerializationTest.vala"
		_tmp71_ = gxml_collection_get_item ((GXmlCollection*) _tmp70_, 0, &_inner_error0_);
#line 718 "GomSerializationTest.vala"
		_tmp67_ = _tmp71_;
#line 718 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 718 "GomSerializationTest.vala"
			_g_object_unref0 (br4);
#line 718 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 718 "GomSerializationTest.vala"
			_g_object_unref0 (br3);
#line 718 "GomSerializationTest.vala"
			_g_object_unref0 (br2);
#line 718 "GomSerializationTest.vala"
			_g_free0 (s);
#line 718 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 8399 "GomSerializationTest.c"
			goto __catch176_g_error;
		}
#line 718 "GomSerializationTest.vala"
		_tmp72_ = gom_serialization_test_book_register_get_year (G_TYPE_CHECK_INSTANCE_TYPE (_tmp67_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp67_) : NULL);
#line 718 "GomSerializationTest.vala"
		_tmp73_ = _tmp72_;
#line 718 "GomSerializationTest.vala"
		_vala_assert (_tmp73_ == 2016, "(bs.registers.get_item (0) as BookRegister).year == 2016");
#line 719 "GomSerializationTest.vala"
		_tmp75_ = bs;
#line 719 "GomSerializationTest.vala"
		_tmp76_ = gom_serialization_test_book_stand_get_registers (_tmp75_);
#line 719 "GomSerializationTest.vala"
		_tmp77_ = _tmp76_;
#line 719 "GomSerializationTest.vala"
		_tmp78_ = gxml_collection_get_item ((GXmlCollection*) _tmp77_, 1, &_inner_error0_);
#line 719 "GomSerializationTest.vala"
		_tmp74_ = _tmp78_;
#line 719 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 719 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp67_);
#line 719 "GomSerializationTest.vala"
			_g_object_unref0 (br4);
#line 719 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 719 "GomSerializationTest.vala"
			_g_object_unref0 (br3);
#line 719 "GomSerializationTest.vala"
			_g_object_unref0 (br2);
#line 719 "GomSerializationTest.vala"
			_g_free0 (s);
#line 719 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 8434 "GomSerializationTest.c"
			goto __catch176_g_error;
		}
#line 719 "GomSerializationTest.vala"
		_tmp79_ = gom_serialization_test_book_register_get_year (G_TYPE_CHECK_INSTANCE_TYPE (_tmp74_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp74_) : NULL);
#line 719 "GomSerializationTest.vala"
		_tmp80_ = _tmp79_;
#line 719 "GomSerializationTest.vala"
		_vala_assert (_tmp80_ == 2010, "(bs.registers.get_item (1) as BookRegister).year == 2010");
#line 720 "GomSerializationTest.vala"
		_tmp82_ = bs;
#line 720 "GomSerializationTest.vala"
		_tmp83_ = gom_serialization_test_book_stand_get_registers (_tmp82_);
#line 720 "GomSerializationTest.vala"
		_tmp84_ = _tmp83_;
#line 720 "GomSerializationTest.vala"
		_tmp85_ = gxml_collection_get_item ((GXmlCollection*) _tmp84_, 2, &_inner_error0_);
#line 720 "GomSerializationTest.vala"
		_tmp81_ = _tmp85_;
#line 720 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 720 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp74_);
#line 720 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp67_);
#line 720 "GomSerializationTest.vala"
			_g_object_unref0 (br4);
#line 720 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 720 "GomSerializationTest.vala"
			_g_object_unref0 (br3);
#line 720 "GomSerializationTest.vala"
			_g_object_unref0 (br2);
#line 720 "GomSerializationTest.vala"
			_g_free0 (s);
#line 720 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 8471 "GomSerializationTest.c"
			goto __catch176_g_error;
		}
#line 720 "GomSerializationTest.vala"
		_tmp86_ = gom_serialization_test_book_register_get_year (G_TYPE_CHECK_INSTANCE_TYPE (_tmp81_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp81_) : NULL);
#line 720 "GomSerializationTest.vala"
		_tmp87_ = _tmp86_;
#line 720 "GomSerializationTest.vala"
		_vala_assert (_tmp87_ == 2000, "(bs.registers.get_item (2) as BookRegister).year == 2000");
#line 721 "GomSerializationTest.vala"
		_tmp88_ = bs;
#line 721 "GomSerializationTest.vala"
		_vala_assert (gxml_gom_object_set_instance_property ((GXmlGomObject*) _tmp88_, "Dimension-X"), "bs.set_instance_property(\"Dimension-X\")");
#line 722 "GomSerializationTest.vala"
		_tmp89_ = bs;
#line 722 "GomSerializationTest.vala"
		_tmp90_ = gom_serialization_test_book_stand_get_dimension_x (_tmp89_);
#line 722 "GomSerializationTest.vala"
		_tmp91_ = _tmp90_;
#line 722 "GomSerializationTest.vala"
		_vala_assert (_tmp91_ != NULL, "bs.dimension_x != null");
#line 723 "GomSerializationTest.vala"
		_tmp92_ = bs;
#line 723 "GomSerializationTest.vala"
		_tmp93_ = gom_serialization_test_book_stand_get_dimension_x (_tmp92_);
#line 723 "GomSerializationTest.vala"
		_tmp94_ = _tmp93_;
#line 723 "GomSerializationTest.vala"
		_tmp95_ = gom_serialization_test_book_stand_dimension_get_length (_tmp94_);
#line 723 "GomSerializationTest.vala"
		_tmp96_ = _tmp95_;
#line 723 "GomSerializationTest.vala"
		_vala_assert (_tmp96_ == 1.0, "bs.dimension_x.length == 1.0");
#line 724 "GomSerializationTest.vala"
		_tmp97_ = bs;
#line 724 "GomSerializationTest.vala"
		_tmp98_ = gom_serialization_test_book_stand_to_string (_tmp97_);
#line 724 "GomSerializationTest.vala"
		_g_free0 (s);
#line 724 "GomSerializationTest.vala"
		s = _tmp98_;
#line 725 "GomSerializationTest.vala"
		_tmp99_ = s;
#line 725 "GomSerializationTest.vala"
		_vala_assert (_tmp99_ != NULL, "s != null");
#line 727 "GomSerializationTest.vala"
		_tmp100_ = s;
#line 727 "GomSerializationTest.vala"
		_tmp101_ = g_strconcat ("DOC:", _tmp100_, NULL);
#line 727 "GomSerializationTest.vala"
		_tmp102_ = _tmp101_;
#line 727 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:727: %s", _tmp102_);
#line 727 "GomSerializationTest.vala"
		_g_free0 (_tmp102_);
#line 729 "GomSerializationTest.vala"
		_tmp103_ = s;
#line 729 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp103_, "<BookStand Classification=\"Science\"><BookRegister Year=\"2016\"/><Bo" \
"okRegister Year=\"2010\"/><Test/><BookRegister Year=\"2000\"/><Dimensi" \
"on Length=\"1\" Type=\"x\"/></BookStand>"), "\"<BookStand Classification=\\\"Science\\\"><BookRegister Year=\\\"2016\\\"/><BookRegister Year=\\\"2010\\\"/><Test/><BookRegister Year=\\\"2000\\\"/><Dimension Length=\\\"1\\\" Type=\\\"x\\\"/></BookStand>\" in s");
#line 730 "GomSerializationTest.vala"
		_tmp104_ = bs;
#line 730 "GomSerializationTest.vala"
		_vala_assert (gxml_gom_object_set_instance_property ((GXmlGomObject*) _tmp104_, "DimensionY"), "bs.set_instance_property(\"DimensionY\")");
#line 731 "GomSerializationTest.vala"
		_tmp105_ = bs;
#line 731 "GomSerializationTest.vala"
		_tmp106_ = gom_serialization_test_book_stand_get_dimension_y (_tmp105_);
#line 731 "GomSerializationTest.vala"
		_tmp107_ = _tmp106_;
#line 731 "GomSerializationTest.vala"
		_vala_assert (_tmp107_ != NULL, "bs.dimension_y != null");
#line 732 "GomSerializationTest.vala"
		_tmp108_ = bs;
#line 732 "GomSerializationTest.vala"
		_tmp109_ = gom_serialization_test_book_stand_get_dimension_y (_tmp108_);
#line 732 "GomSerializationTest.vala"
		_tmp110_ = _tmp109_;
#line 732 "GomSerializationTest.vala"
		_tmp111_ = gom_serialization_test_book_stand_dimension_get_length ((GomSerializationTestBookStandDimension*) _tmp110_);
#line 732 "GomSerializationTest.vala"
		_tmp112_ = _tmp111_;
#line 732 "GomSerializationTest.vala"
		_vala_assert (_tmp112_ == 1.0, "bs.dimension_y.length == 1.0");
#line 733 "GomSerializationTest.vala"
		_tmp113_ = bs;
#line 733 "GomSerializationTest.vala"
		_tmp114_ = gom_serialization_test_book_stand_to_string (_tmp113_);
#line 733 "GomSerializationTest.vala"
		_g_free0 (s);
#line 733 "GomSerializationTest.vala"
		s = _tmp114_;
#line 734 "GomSerializationTest.vala"
		_tmp115_ = s;
#line 734 "GomSerializationTest.vala"
		_vala_assert (_tmp115_ != NULL, "s != null");
#line 736 "GomSerializationTest.vala"
		_tmp116_ = s;
#line 736 "GomSerializationTest.vala"
		_tmp117_ = g_strconcat ("DOC:", _tmp116_, NULL);
#line 736 "GomSerializationTest.vala"
		_tmp118_ = _tmp117_;
#line 736 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:736: %s", _tmp118_);
#line 736 "GomSerializationTest.vala"
		_g_free0 (_tmp118_);
#line 738 "GomSerializationTest.vala"
		_tmp119_ = s;
#line 738 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp119_, "<BookStand Classification=\"Science\"><BookRegister Year=\"2016\"/><Bo" \
"okRegister Year=\"2010\"/><Test/><BookRegister Year=\"2000\"/><Dimensi" \
"on Length=\"1\" Type=\"x\"/><Dimension Length=\"1\" Type=\"y\"/></Book" \
"Stand>"), "\"<BookStand Classification=\\\"Science\\\"><BookRegister Year=\\\"2016\\\"/><BookRegister Year=\\\"2010\\\"/><Test/><BookRegister Year=\\\"2000\\\"/><Dimension Length=\\\"1\\\" Type=\\\"x\\\"/><Dimension Length=\\\"1\\\" Type=\\\"y\\\"/></BookStand>\" in s");
#line 739 "GomSerializationTest.vala"
		_tmp120_ = bs;
#line 739 "GomSerializationTest.vala"
		_vala_assert (gxml_gom_object_set_instance_property ((GXmlGomObject*) _tmp120_, "::DimensionZ"), "bs.set_instance_property(\"::DimensionZ\")");
#line 740 "GomSerializationTest.vala"
		_tmp121_ = bs;
#line 740 "GomSerializationTest.vala"
		_tmp122_ = gom_serialization_test_book_stand_get_dimension_z (_tmp121_);
#line 740 "GomSerializationTest.vala"
		_tmp123_ = _tmp122_;
#line 740 "GomSerializationTest.vala"
		_vala_assert (_tmp123_ != NULL, "bs.dimension_z != null");
#line 741 "GomSerializationTest.vala"
		_tmp124_ = bs;
#line 741 "GomSerializationTest.vala"
		_tmp125_ = gom_serialization_test_book_stand_get_dimension_z (_tmp124_);
#line 741 "GomSerializationTest.vala"
		_tmp126_ = _tmp125_;
#line 741 "GomSerializationTest.vala"
		_tmp127_ = gom_serialization_test_book_stand_dimension_get_length ((GomSerializationTestBookStandDimension*) _tmp126_);
#line 741 "GomSerializationTest.vala"
		_tmp128_ = _tmp127_;
#line 741 "GomSerializationTest.vala"
		_vala_assert (_tmp128_ == 1.0, "bs.dimension_z.length == 1.0");
#line 742 "GomSerializationTest.vala"
		_tmp129_ = bs;
#line 742 "GomSerializationTest.vala"
		_tmp130_ = gom_serialization_test_book_stand_to_string (_tmp129_);
#line 742 "GomSerializationTest.vala"
		_g_free0 (s);
#line 742 "GomSerializationTest.vala"
		s = _tmp130_;
#line 743 "GomSerializationTest.vala"
		_tmp131_ = s;
#line 743 "GomSerializationTest.vala"
		_vala_assert (_tmp131_ != NULL, "s != null");
#line 745 "GomSerializationTest.vala"
		_tmp132_ = s;
#line 745 "GomSerializationTest.vala"
		_tmp133_ = g_strconcat ("DOC:", _tmp132_, NULL);
#line 745 "GomSerializationTest.vala"
		_tmp134_ = _tmp133_;
#line 745 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:745: %s", _tmp134_);
#line 745 "GomSerializationTest.vala"
		_g_free0 (_tmp134_);
#line 747 "GomSerializationTest.vala"
		_tmp135_ = s;
#line 747 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp135_, "<BookStand Classification=\"Science\"><BookRegister Year=\"2016\"/><Bo" \
"okRegister Year=\"2010\"/><Test/><BookRegister Year=\"2000\"/><Dimensi" \
"on Length=\"1\" Type=\"x\"/><Dimension Length=\"1\" Type=\"y\"/><Dimen" \
"sion Length=\"1\" Type=\"z\"/></BookStand>"), "\"<BookStand Classification=\\\"Science\\\"><BookRegister Year=\\\"2016\\\"/><BookRegister Year=\\\"2010\\\"/><Test/><BookRegister Year=\\\"2000\\\"/><Dimension Length=\\\"1\\\" Type=\\\"x\\\"/><Dimension Length=\\\"1\\\" Type=\\\"y\\\"/><Dimension Length=\\\"1\\\" Type=\\\"z\\\"/></BookStand>\" in s");
#line 674 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp81_);
#line 674 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp74_);
#line 674 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp67_);
#line 674 "GomSerializationTest.vala"
		_g_object_unref0 (br4);
#line 674 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp45_);
#line 674 "GomSerializationTest.vala"
		_g_object_unref0 (br3);
#line 674 "GomSerializationTest.vala"
		_g_object_unref0 (br2);
#line 674 "GomSerializationTest.vala"
		_g_free0 (s);
#line 674 "GomSerializationTest.vala"
		_g_object_unref0 (bs);
#line 8648 "GomSerializationTest.c"
	}
	goto __finally176;
	__catch176_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp136_;
		gchar* _tmp137_;
		gchar* _tmp138_;
#line 674 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 674 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 749 "GomSerializationTest.vala"
		_tmp136_ = e->message;
#line 749 "GomSerializationTest.vala"
		_tmp137_ = g_strconcat ("Error: ", _tmp136_, NULL);
#line 749 "GomSerializationTest.vala"
		_tmp138_ = _tmp137_;
#line 749 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:749: %s", _tmp138_);
#line 749 "GomSerializationTest.vala"
		_g_free0 (_tmp138_);
#line 750 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 674 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 8675 "GomSerializationTest.c"
	}
	__finally176:
#line 674 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 674 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 674 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 674 "GomSerializationTest.vala"
		return;
#line 8686 "GomSerializationTest.c"
	}
}

static void
___lambda125__gtest_func (void)
{
#line 673 "GomSerializationTest.vala"
	__lambda125_ ();
#line 8695 "GomSerializationTest.c"
}

static void
__lambda126_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GomSerializationTestBookStore* bs = NULL;
		GomSerializationTestBookStore* _tmp0_;
		gchar* s = NULL;
		GomSerializationTestBookStore* _tmp1_;
		gchar* _tmp2_;
		const gchar* _tmp3_;
		const gchar* _tmp4_;
		GomSerializationTestBookStore* _tmp5_;
		GomSerializationTestBooks* _tmp6_;
		GomSerializationTestBooks* _tmp7_;
		GomSerializationTestBookStore* _tmp8_;
		GomSerializationTestBookStore* _tmp9_;
		gchar* _tmp10_;
		const gchar* _tmp11_;
		const gchar* _tmp12_;
		GomSerializationTestBook* b = NULL;
		GomSerializationTestBook* _tmp13_;
		GomSerializationTestBookStore* _tmp18_;
		GXmlDomDocument* _tmp19_;
		GXmlDomDocument* _tmp20_;
		GomSerializationTestBook* _tmp21_;
		GomSerializationTestBook* _tmp22_;
		GomSerializationTestBookStore* _tmp23_;
		GomSerializationTestBooks* _tmp24_;
		GomSerializationTestBooks* _tmp25_;
		GomSerializationTestBook* _tmp26_;
		GomSerializationTestBookStore* _tmp27_;
		gchar* _tmp28_;
		const gchar* _tmp29_;
		const gchar* _tmp30_;
		GomSerializationTestBook* b2 = NULL;
		GomSerializationTestBookStore* _tmp31_;
		GXmlDomDocument* _tmp32_;
		GXmlDomDocument* _tmp33_;
		GomSerializationTestBook* _tmp34_;
		GomSerializationTestBook* _tmp35_;
		GomSerializationTestBookStore* _tmp36_;
		GomSerializationTestBooks* _tmp37_;
		GomSerializationTestBooks* _tmp38_;
		GomSerializationTestBook* _tmp39_;
		GXmlDomElement* _tmp40_ = NULL;
		GomSerializationTestBookStore* _tmp41_;
		GXmlDomDocument* _tmp42_;
		GXmlDomDocument* _tmp43_;
		GXmlDomElement* _tmp44_;
		GomSerializationTestBookStore* _tmp45_;
		GXmlDomNode* _tmp46_;
		GXmlDomNode* _tmp47_;
		GomSerializationTestBook* b3 = NULL;
		GomSerializationTestBookStore* _tmp48_;
		GXmlDomDocument* _tmp49_;
		GXmlDomDocument* _tmp50_;
		GomSerializationTestBook* _tmp51_;
		GomSerializationTestBook* _tmp52_;
		GomSerializationTestBookStore* _tmp53_;
		GomSerializationTestBooks* _tmp54_;
		GomSerializationTestBooks* _tmp55_;
		GomSerializationTestBook* _tmp56_;
		GomSerializationTestBookStore* _tmp57_;
		gchar* _tmp58_;
		const gchar* _tmp59_;
		const gchar* _tmp60_;
		GomSerializationTestBookStore* _tmp61_;
		GomSerializationTestBooks* _tmp62_;
		GomSerializationTestBooks* _tmp63_;
		GXmlDomElement* _tmp64_;
		GXmlDomElement* _tmp65_;
		GomSerializationTestBookStore* _tmp66_;
		GomSerializationTestBooks* _tmp67_;
		GomSerializationTestBooks* _tmp68_;
		GXmlDomElement* _tmp69_;
		GXmlDomElement* _tmp70_;
		GomSerializationTestBookStore* _tmp71_;
		GomSerializationTestBooks* _tmp72_;
		GomSerializationTestBooks* _tmp73_;
		GXmlDomElement* _tmp74_;
		GXmlDomElement* _tmp75_;
		GomSerializationTestBookStore* _tmp76_;
		GomSerializationTestBooks* _tmp77_;
		GomSerializationTestBooks* _tmp78_;
		GXmlDomElement* _tmp79_;
		GomSerializationTestBook* _tmp80_;
		GomSerializationTestBook* _tmp81_;
		const gchar* _tmp82_;
		const gchar* _tmp83_;
		GomSerializationTestBookStore* _tmp84_;
		GomSerializationTestBooks* _tmp85_;
		GomSerializationTestBooks* _tmp86_;
		GXmlDomElement* _tmp87_;
		GomSerializationTestBook* _tmp88_;
		GomSerializationTestBook* _tmp89_;
		const gchar* _tmp90_;
		const gchar* _tmp91_;
		GomSerializationTestBookStore* _tmp92_;
		GomSerializationTestBooks* _tmp93_;
		GomSerializationTestBooks* _tmp94_;
		GXmlDomElement* _tmp95_;
		GomSerializationTestBook* _tmp96_;
		GomSerializationTestBook* _tmp97_;
		const gchar* _tmp98_;
		const gchar* _tmp99_;
#line 755 "GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_book_store_new ();
#line 755 "GomSerializationTest.vala"
		bs = _tmp0_;
#line 756 "GomSerializationTest.vala"
		_tmp1_ = bs;
#line 756 "GomSerializationTest.vala"
		_tmp2_ = gom_serialization_test_book_store_to_string (_tmp1_);
#line 756 "GomSerializationTest.vala"
		s = _tmp2_;
#line 757 "GomSerializationTest.vala"
		_tmp3_ = s;
#line 757 "GomSerializationTest.vala"
		_vala_assert (_tmp3_ != NULL, "s != null");
#line 761 "GomSerializationTest.vala"
		_tmp4_ = s;
#line 761 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp4_, "<BookStore/>"), "\"<BookStore/>\" in s");
#line 762 "GomSerializationTest.vala"
		_tmp5_ = bs;
#line 762 "GomSerializationTest.vala"
		_tmp6_ = gom_serialization_test_book_store_get_books (_tmp5_);
#line 762 "GomSerializationTest.vala"
		_tmp7_ = _tmp6_;
#line 762 "GomSerializationTest.vala"
		_vala_assert (_tmp7_ == NULL, "bs.books == null");
#line 763 "GomSerializationTest.vala"
		_tmp8_ = bs;
#line 763 "GomSerializationTest.vala"
		gxml_gom_object_set_instance_property ((GXmlGomObject*) _tmp8_, "books");
#line 764 "GomSerializationTest.vala"
		_tmp9_ = bs;
#line 764 "GomSerializationTest.vala"
		_tmp10_ = gom_serialization_test_book_store_to_string (_tmp9_);
#line 764 "GomSerializationTest.vala"
		_g_free0 (s);
#line 764 "GomSerializationTest.vala"
		s = _tmp10_;
#line 765 "GomSerializationTest.vala"
		_tmp11_ = s;
#line 765 "GomSerializationTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 769 "GomSerializationTest.vala"
		_tmp12_ = s;
#line 769 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp12_, "<BookStore/>"), "\"<BookStore/>\" in s");
#line 770 "GomSerializationTest.vala"
		_tmp13_ = gom_serialization_test_book_new ();
#line 770 "GomSerializationTest.vala"
		b = _tmp13_;
#line 8854 "GomSerializationTest.c"
		{
			GomSerializationTestBookStore* _tmp14_;
			GomSerializationTestBooks* _tmp15_;
			GomSerializationTestBooks* _tmp16_;
			GomSerializationTestBook* _tmp17_;
#line 772 "GomSerializationTest.vala"
			_tmp14_ = bs;
#line 772 "GomSerializationTest.vala"
			_tmp15_ = gom_serialization_test_book_store_get_books (_tmp14_);
#line 772 "GomSerializationTest.vala"
			_tmp16_ = _tmp15_;
#line 772 "GomSerializationTest.vala"
			_tmp17_ = b;
#line 772 "GomSerializationTest.vala"
			gxml_collection_append ((GXmlCollection*) _tmp16_, (GXmlDomElement*) _tmp17_, &_inner_error0_);
#line 772 "GomSerializationTest.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 8872 "GomSerializationTest.c"
				goto __catch179_g_error;
			}
#line 773 "GomSerializationTest.vala"
			g_assert_not_reached ();
#line 8877 "GomSerializationTest.c"
		}
		goto __finally179;
		__catch179_g_error:
		{
#line 771 "GomSerializationTest.vala"
			g_clear_error (&_inner_error0_);
#line 771 "GomSerializationTest.vala"
			_inner_error0_ = NULL;
#line 8886 "GomSerializationTest.c"
		}
		__finally179:
#line 771 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 771 "GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 771 "GomSerializationTest.vala"
			_g_free0 (s);
#line 771 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 8897 "GomSerializationTest.c"
			goto __catch178_g_error;
		}
#line 775 "GomSerializationTest.vala"
		_tmp18_ = bs;
#line 775 "GomSerializationTest.vala"
		_tmp19_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _tmp18_);
#line 775 "GomSerializationTest.vala"
		_tmp20_ = _tmp19_;
#line 775 "GomSerializationTest.vala"
		_tmp21_ = gom_serialization_test_book_new_document (_tmp20_);
#line 775 "GomSerializationTest.vala"
		_g_object_unref0 (b);
#line 775 "GomSerializationTest.vala"
		b = _tmp21_;
#line 776 "GomSerializationTest.vala"
		_tmp22_ = b;
#line 776 "GomSerializationTest.vala"
		gom_serialization_test_book_set_name (_tmp22_, "Title1");
#line 777 "GomSerializationTest.vala"
		_tmp23_ = bs;
#line 777 "GomSerializationTest.vala"
		_tmp24_ = gom_serialization_test_book_store_get_books (_tmp23_);
#line 777 "GomSerializationTest.vala"
		_tmp25_ = _tmp24_;
#line 777 "GomSerializationTest.vala"
		_tmp26_ = b;
#line 777 "GomSerializationTest.vala"
		gxml_collection_append ((GXmlCollection*) _tmp25_, (GXmlDomElement*) _tmp26_, &_inner_error0_);
#line 777 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 777 "GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 777 "GomSerializationTest.vala"
			_g_free0 (s);
#line 777 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 8934 "GomSerializationTest.c"
			goto __catch178_g_error;
		}
#line 778 "GomSerializationTest.vala"
		_tmp27_ = bs;
#line 778 "GomSerializationTest.vala"
		_tmp28_ = gom_serialization_test_book_store_to_string (_tmp27_);
#line 778 "GomSerializationTest.vala"
		_g_free0 (s);
#line 778 "GomSerializationTest.vala"
		s = _tmp28_;
#line 779 "GomSerializationTest.vala"
		_tmp29_ = s;
#line 779 "GomSerializationTest.vala"
		_vala_assert (_tmp29_ != NULL, "s != null");
#line 783 "GomSerializationTest.vala"
		_tmp30_ = s;
#line 783 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp30_, "<BookStore><Book Name=\"Title1\"/></BookStore>"), "\"<BookStore><Book Name=\\\"Title1\\\"/></BookStore>\" in s");
#line 784 "GomSerializationTest.vala"
		_tmp31_ = bs;
#line 784 "GomSerializationTest.vala"
		_tmp32_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _tmp31_);
#line 784 "GomSerializationTest.vala"
		_tmp33_ = _tmp32_;
#line 784 "GomSerializationTest.vala"
		_tmp34_ = gom_serialization_test_book_new_document (_tmp33_);
#line 784 "GomSerializationTest.vala"
		b2 = _tmp34_;
#line 785 "GomSerializationTest.vala"
		_tmp35_ = b2;
#line 785 "GomSerializationTest.vala"
		gom_serialization_test_book_set_name (_tmp35_, "Title2");
#line 786 "GomSerializationTest.vala"
		_tmp36_ = bs;
#line 786 "GomSerializationTest.vala"
		_tmp37_ = gom_serialization_test_book_store_get_books (_tmp36_);
#line 786 "GomSerializationTest.vala"
		_tmp38_ = _tmp37_;
#line 786 "GomSerializationTest.vala"
		_tmp39_ = b2;
#line 786 "GomSerializationTest.vala"
		gxml_collection_append ((GXmlCollection*) _tmp38_, (GXmlDomElement*) _tmp39_, &_inner_error0_);
#line 786 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 786 "GomSerializationTest.vala"
			_g_object_unref0 (b2);
#line 786 "GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 786 "GomSerializationTest.vala"
			_g_free0 (s);
#line 786 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 8987 "GomSerializationTest.c"
			goto __catch178_g_error;
		}
#line 787 "GomSerializationTest.vala"
		_tmp41_ = bs;
#line 787 "GomSerializationTest.vala"
		_tmp42_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _tmp41_);
#line 787 "GomSerializationTest.vala"
		_tmp43_ = _tmp42_;
#line 787 "GomSerializationTest.vala"
		_tmp44_ = gxml_dom_document_create_element (_tmp43_, "Test", &_inner_error0_);
#line 787 "GomSerializationTest.vala"
		_tmp40_ = _tmp44_;
#line 787 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 787 "GomSerializationTest.vala"
			_g_object_unref0 (b2);
#line 787 "GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 787 "GomSerializationTest.vala"
			_g_free0 (s);
#line 787 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 9010 "GomSerializationTest.c"
			goto __catch178_g_error;
		}
#line 787 "GomSerializationTest.vala"
		_tmp45_ = bs;
#line 787 "GomSerializationTest.vala"
		_tmp46_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp45_, (GXmlDomNode*) _tmp40_, &_inner_error0_);
#line 787 "GomSerializationTest.vala"
		_tmp47_ = _tmp46_;
#line 787 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp47_);
#line 787 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 787 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp40_);
#line 787 "GomSerializationTest.vala"
			_g_object_unref0 (b2);
#line 787 "GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 787 "GomSerializationTest.vala"
			_g_free0 (s);
#line 787 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 9033 "GomSerializationTest.c"
			goto __catch178_g_error;
		}
#line 788 "GomSerializationTest.vala"
		_tmp48_ = bs;
#line 788 "GomSerializationTest.vala"
		_tmp49_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _tmp48_);
#line 788 "GomSerializationTest.vala"
		_tmp50_ = _tmp49_;
#line 788 "GomSerializationTest.vala"
		_tmp51_ = gom_serialization_test_book_new_document (_tmp50_);
#line 788 "GomSerializationTest.vala"
		b3 = _tmp51_;
#line 789 "GomSerializationTest.vala"
		_tmp52_ = b3;
#line 789 "GomSerializationTest.vala"
		gom_serialization_test_book_set_name (_tmp52_, "Title3");
#line 790 "GomSerializationTest.vala"
		_tmp53_ = bs;
#line 790 "GomSerializationTest.vala"
		_tmp54_ = gom_serialization_test_book_store_get_books (_tmp53_);
#line 790 "GomSerializationTest.vala"
		_tmp55_ = _tmp54_;
#line 790 "GomSerializationTest.vala"
		_tmp56_ = b3;
#line 790 "GomSerializationTest.vala"
		gxml_collection_append ((GXmlCollection*) _tmp55_, (GXmlDomElement*) _tmp56_, &_inner_error0_);
#line 790 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 790 "GomSerializationTest.vala"
			_g_object_unref0 (b3);
#line 790 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp40_);
#line 790 "GomSerializationTest.vala"
			_g_object_unref0 (b2);
#line 790 "GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 790 "GomSerializationTest.vala"
			_g_free0 (s);
#line 790 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 9074 "GomSerializationTest.c"
			goto __catch178_g_error;
		}
#line 791 "GomSerializationTest.vala"
		_tmp57_ = bs;
#line 791 "GomSerializationTest.vala"
		_tmp58_ = gom_serialization_test_book_store_to_string (_tmp57_);
#line 791 "GomSerializationTest.vala"
		_g_free0 (s);
#line 791 "GomSerializationTest.vala"
		s = _tmp58_;
#line 792 "GomSerializationTest.vala"
		_tmp59_ = s;
#line 792 "GomSerializationTest.vala"
		_vala_assert (_tmp59_ != NULL, "s != null");
#line 796 "GomSerializationTest.vala"
		_tmp60_ = s;
#line 796 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp60_, "<BookStore><Book Name=\"Title1\"/><Book Name=\"Title2\"/><Test/><Book " \
"Name=\"Title3\"/></BookStore>"), "\"<BookStore><Book Name=\\\"Title1\\\"/><Book Name=\\\"Title2\\\"/><Test/><Book Name=\\\"Title3\\\"/></BookStore>\" in s");
#line 797 "GomSerializationTest.vala"
		_tmp61_ = bs;
#line 797 "GomSerializationTest.vala"
		_tmp62_ = gom_serialization_test_book_store_get_books (_tmp61_);
#line 797 "GomSerializationTest.vala"
		_tmp63_ = _tmp62_;
#line 797 "GomSerializationTest.vala"
		_tmp64_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp63_, "Title1");
#line 797 "GomSerializationTest.vala"
		_tmp65_ = _tmp64_;
#line 797 "GomSerializationTest.vala"
		_vala_assert (_tmp65_ != NULL, "bs.books.get(\"Title1\") != null");
#line 797 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp65_);
#line 798 "GomSerializationTest.vala"
		_tmp66_ = bs;
#line 798 "GomSerializationTest.vala"
		_tmp67_ = gom_serialization_test_book_store_get_books (_tmp66_);
#line 798 "GomSerializationTest.vala"
		_tmp68_ = _tmp67_;
#line 798 "GomSerializationTest.vala"
		_tmp69_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp68_, "Title2");
#line 798 "GomSerializationTest.vala"
		_tmp70_ = _tmp69_;
#line 798 "GomSerializationTest.vala"
		_vala_assert (_tmp70_ != NULL, "bs.books.get(\"Title2\") != null");
#line 798 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp70_);
#line 799 "GomSerializationTest.vala"
		_tmp71_ = bs;
#line 799 "GomSerializationTest.vala"
		_tmp72_ = gom_serialization_test_book_store_get_books (_tmp71_);
#line 799 "GomSerializationTest.vala"
		_tmp73_ = _tmp72_;
#line 799 "GomSerializationTest.vala"
		_tmp74_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp73_, "Title3");
#line 799 "GomSerializationTest.vala"
		_tmp75_ = _tmp74_;
#line 799 "GomSerializationTest.vala"
		_vala_assert (_tmp75_ != NULL, "bs.books.get(\"Title3\") != null");
#line 799 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp75_);
#line 800 "GomSerializationTest.vala"
		_tmp76_ = bs;
#line 800 "GomSerializationTest.vala"
		_tmp77_ = gom_serialization_test_book_store_get_books (_tmp76_);
#line 800 "GomSerializationTest.vala"
		_tmp78_ = _tmp77_;
#line 800 "GomSerializationTest.vala"
		_tmp79_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp78_, "Title1");
#line 800 "GomSerializationTest.vala"
		_tmp80_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp79_, GOM_SERIALIZATION_TEST_TYPE_BOOK) ? ((GomSerializationTestBook*) _tmp79_) : NULL;
#line 800 "GomSerializationTest.vala"
		if (_tmp80_ == NULL) {
#line 800 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp79_);
#line 9149 "GomSerializationTest.c"
		}
#line 800 "GomSerializationTest.vala"
		_tmp81_ = _tmp80_;
#line 800 "GomSerializationTest.vala"
		_tmp82_ = gom_serialization_test_book_get_name (_tmp81_);
#line 800 "GomSerializationTest.vala"
		_tmp83_ = _tmp82_;
#line 800 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp83_, "Title1") == 0, "(bs.books.get(\"Title1\") as Book).name == \"Title1\"");
#line 800 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp81_);
#line 801 "GomSerializationTest.vala"
		_tmp84_ = bs;
#line 801 "GomSerializationTest.vala"
		_tmp85_ = gom_serialization_test_book_store_get_books (_tmp84_);
#line 801 "GomSerializationTest.vala"
		_tmp86_ = _tmp85_;
#line 801 "GomSerializationTest.vala"
		_tmp87_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp86_, "Title2");
#line 801 "GomSerializationTest.vala"
		_tmp88_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp87_, GOM_SERIALIZATION_TEST_TYPE_BOOK) ? ((GomSerializationTestBook*) _tmp87_) : NULL;
#line 801 "GomSerializationTest.vala"
		if (_tmp88_ == NULL) {
#line 801 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp87_);
#line 9175 "GomSerializationTest.c"
		}
#line 801 "GomSerializationTest.vala"
		_tmp89_ = _tmp88_;
#line 801 "GomSerializationTest.vala"
		_tmp90_ = gom_serialization_test_book_get_name (_tmp89_);
#line 801 "GomSerializationTest.vala"
		_tmp91_ = _tmp90_;
#line 801 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp91_, "Title2") == 0, "(bs.books.get(\"Title2\") as Book).name == \"Title2\"");
#line 801 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp89_);
#line 802 "GomSerializationTest.vala"
		_tmp92_ = bs;
#line 802 "GomSerializationTest.vala"
		_tmp93_ = gom_serialization_test_book_store_get_books (_tmp92_);
#line 802 "GomSerializationTest.vala"
		_tmp94_ = _tmp93_;
#line 802 "GomSerializationTest.vala"
		_tmp95_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp94_, "Title3");
#line 802 "GomSerializationTest.vala"
		_tmp96_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp95_, GOM_SERIALIZATION_TEST_TYPE_BOOK) ? ((GomSerializationTestBook*) _tmp95_) : NULL;
#line 802 "GomSerializationTest.vala"
		if (_tmp96_ == NULL) {
#line 802 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp95_);
#line 9201 "GomSerializationTest.c"
		}
#line 802 "GomSerializationTest.vala"
		_tmp97_ = _tmp96_;
#line 802 "GomSerializationTest.vala"
		_tmp98_ = gom_serialization_test_book_get_name (_tmp97_);
#line 802 "GomSerializationTest.vala"
		_tmp99_ = _tmp98_;
#line 802 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp99_, "Title3") == 0, "(bs.books.get(\"Title3\") as Book).name == \"Title3\"");
#line 802 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp97_);
#line 754 "GomSerializationTest.vala"
		_g_object_unref0 (b3);
#line 754 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp40_);
#line 754 "GomSerializationTest.vala"
		_g_object_unref0 (b2);
#line 754 "GomSerializationTest.vala"
		_g_object_unref0 (b);
#line 754 "GomSerializationTest.vala"
		_g_free0 (s);
#line 754 "GomSerializationTest.vala"
		_g_object_unref0 (bs);
#line 9225 "GomSerializationTest.c"
	}
	goto __finally178;
	__catch178_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp100_;
		gchar* _tmp101_;
		gchar* _tmp102_;
#line 754 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 754 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 804 "GomSerializationTest.vala"
		_tmp100_ = e->message;
#line 804 "GomSerializationTest.vala"
		_tmp101_ = g_strconcat ("Error: ", _tmp100_, NULL);
#line 804 "GomSerializationTest.vala"
		_tmp102_ = _tmp101_;
#line 804 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:804: %s", _tmp102_);
#line 804 "GomSerializationTest.vala"
		_g_free0 (_tmp102_);
#line 805 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 754 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 9252 "GomSerializationTest.c"
	}
	__finally178:
#line 754 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 754 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 754 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 754 "GomSerializationTest.vala"
		return;
#line 9263 "GomSerializationTest.c"
	}
}

static void
___lambda126__gtest_func (void)
{
#line 753 "GomSerializationTest.vala"
	__lambda126_ ();
#line 9272 "GomSerializationTest.c"
}

static void
__lambda127_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GomSerializationTestBookStand* bs = NULL;
		GomSerializationTestBookStand* _tmp0_;
		GomSerializationTestBookStand* _tmp1_;
		GomSerializationTestHashRegisters* _tmp2_;
		GomSerializationTestHashRegisters* _tmp3_;
		GomSerializationTestBookRegister* br = NULL;
		GomSerializationTestBookStand* _tmp4_;
		GomSerializationTestHashRegisters* _tmp5_;
		GomSerializationTestHashRegisters* _tmp6_;
		GXmlDomElement* _tmp7_;
		GomSerializationTestBookRegister* _tmp8_;
		GomSerializationTestBook* book = NULL;
		GomSerializationTestBookRegister* _tmp9_;
		GomSerializationTestBook* _tmp10_;
		GomSerializationTestBookRegister* _tmp11_;
		GomSerializationTestBook* _tmp12_;
		GomSerializationTestBookRegister* _tmp13_;
		GomSerializationTestBookStand* _tmp14_;
		GomSerializationTestHashRegisters* _tmp15_;
		GomSerializationTestHashRegisters* _tmp16_;
		GomSerializationTestBookRegister* _tmp17_;
		GomSerializationTestBookStand* _tmp18_;
		GomSerializationTestHashRegisters* _tmp19_;
		GomSerializationTestHashRegisters* _tmp20_;
		gint _tmp21_;
		gint _tmp22_;
		GomSerializationTestBookStand* _tmp23_;
		GomSerializationTestHashRegisters* _tmp24_;
		GomSerializationTestHashRegisters* _tmp25_;
		GomSerializationTestBookRegister* b1 = NULL;
		GomSerializationTestBookStand* _tmp26_;
		GomSerializationTestHashRegisters* _tmp27_;
		GomSerializationTestHashRegisters* _tmp28_;
		GXmlDomElement* _tmp29_;
		GomSerializationTestBookRegister* _tmp30_;
		GomSerializationTestBookRegister* _tmp31_;
		GomSerializationTestBookRegister* _tmp32_;
		gint _tmp33_;
		gint _tmp34_;
		GomSerializationTestBookRegister* _tmp35_;
		GomSerializationTestBook* _tmp36_;
		GomSerializationTestBook* _tmp37_;
		GomSerializationTestBookRegister* _tmp38_;
		GomSerializationTestBook* _tmp39_;
		GomSerializationTestBook* _tmp40_;
		const gchar* _tmp41_;
		const gchar* _tmp42_;
		GomSerializationTestBookRegister* _tmp43_;
		GXmlDomNodeList* _tmp44_;
		GXmlDomNodeList* _tmp45_;
		GXmlDomNodeList* _tmp46_;
		gint _tmp47_;
		gint _tmp48_;
		GomSerializationTestBook* book2 = NULL;
		GomSerializationTestBookRegister* _tmp49_;
		GomSerializationTestBook* _tmp50_;
		GomSerializationTestBookRegister* _tmp51_;
		GomSerializationTestBook* _tmp52_;
		GXmlDomNode* _tmp53_;
		GXmlDomNode* _tmp54_;
		GomSerializationTestBookRegister* _tmp55_;
		GXmlDomNodeList* _tmp56_;
		GXmlDomNodeList* _tmp57_;
		GXmlDomNodeList* _tmp58_;
		gint _tmp59_;
		gint _tmp60_;
		GomSerializationTestBookRegister* _tmp61_;
		GomSerializationTestBook* _tmp62_;
		GomSerializationTestBookRegister* _tmp63_;
		GXmlDomNodeList* _tmp64_;
		GXmlDomNodeList* _tmp65_;
		GXmlDomNodeList* _tmp66_;
		gint _tmp67_;
		gint _tmp68_;
#line 810 "GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_book_stand_new ();
#line 810 "GomSerializationTest.vala"
		bs = _tmp0_;
#line 811 "GomSerializationTest.vala"
		_tmp1_ = bs;
#line 811 "GomSerializationTest.vala"
		_tmp2_ = gom_serialization_test_book_stand_get_hashmap_registers (_tmp1_);
#line 811 "GomSerializationTest.vala"
		_tmp3_ = _tmp2_;
#line 811 "GomSerializationTest.vala"
		_vala_assert (_tmp3_ != NULL, "bs.hashmap_registers != null");
#line 812 "GomSerializationTest.vala"
		_tmp4_ = bs;
#line 812 "GomSerializationTest.vala"
		_tmp5_ = gom_serialization_test_book_stand_get_hashmap_registers (_tmp4_);
#line 812 "GomSerializationTest.vala"
		_tmp6_ = _tmp5_;
#line 812 "GomSerializationTest.vala"
		_tmp7_ = gxml_collection_create_item ((GXmlCollection*) _tmp6_);
#line 812 "GomSerializationTest.vala"
		_tmp8_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp7_) : NULL;
#line 812 "GomSerializationTest.vala"
		if (_tmp8_ == NULL) {
#line 812 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp7_);
#line 9380 "GomSerializationTest.c"
		}
#line 812 "GomSerializationTest.vala"
		br = _tmp8_;
#line 813 "GomSerializationTest.vala"
		_tmp9_ = br;
#line 813 "GomSerializationTest.vala"
		_tmp10_ = gom_serialization_test_book_register_create_book (_tmp9_, "Book1");
#line 813 "GomSerializationTest.vala"
		book = _tmp10_;
#line 814 "GomSerializationTest.vala"
		_tmp11_ = br;
#line 814 "GomSerializationTest.vala"
		_tmp12_ = book;
#line 814 "GomSerializationTest.vala"
		gom_serialization_test_book_register_set_book (_tmp11_, _tmp12_);
#line 815 "GomSerializationTest.vala"
		_tmp13_ = br;
#line 815 "GomSerializationTest.vala"
		gom_serialization_test_book_register_set_year (_tmp13_, 2017);
#line 816 "GomSerializationTest.vala"
		_tmp14_ = bs;
#line 816 "GomSerializationTest.vala"
		_tmp15_ = gom_serialization_test_book_stand_get_hashmap_registers (_tmp14_);
#line 816 "GomSerializationTest.vala"
		_tmp16_ = _tmp15_;
#line 816 "GomSerializationTest.vala"
		_tmp17_ = br;
#line 816 "GomSerializationTest.vala"
		gxml_collection_append ((GXmlCollection*) _tmp16_, (GXmlDomElement*) _tmp17_, &_inner_error0_);
#line 816 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 816 "GomSerializationTest.vala"
			_g_object_unref0 (book);
#line 816 "GomSerializationTest.vala"
			_g_object_unref0 (br);
#line 816 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 9418 "GomSerializationTest.c"
			goto __catch180_g_error;
		}
#line 817 "GomSerializationTest.vala"
		_tmp18_ = bs;
#line 817 "GomSerializationTest.vala"
		_tmp19_ = gom_serialization_test_book_stand_get_hashmap_registers (_tmp18_);
#line 817 "GomSerializationTest.vala"
		_tmp20_ = _tmp19_;
#line 817 "GomSerializationTest.vala"
		_tmp21_ = gxml_collection_get_length ((GXmlCollection*) _tmp20_);
#line 817 "GomSerializationTest.vala"
		_tmp22_ = _tmp21_;
#line 817 "GomSerializationTest.vala"
		_vala_assert (_tmp22_ == 1, "bs.hashmap_registers.length == 1");
#line 818 "GomSerializationTest.vala"
		_tmp23_ = bs;
#line 818 "GomSerializationTest.vala"
		_tmp24_ = gom_serialization_test_book_stand_get_hashmap_registers (_tmp23_);
#line 818 "GomSerializationTest.vala"
		_tmp25_ = _tmp24_;
#line 818 "GomSerializationTest.vala"
		_vala_assert (gxml_map_has_key ((GXmlMap*) _tmp25_, "2017-Book1"), "bs.hashmap_registers.has_key (\"2017-Book1\")");
#line 819 "GomSerializationTest.vala"
		_tmp26_ = bs;
#line 819 "GomSerializationTest.vala"
		_tmp27_ = gom_serialization_test_book_stand_get_hashmap_registers (_tmp26_);
#line 819 "GomSerializationTest.vala"
		_tmp28_ = _tmp27_;
#line 819 "GomSerializationTest.vala"
		_tmp29_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp28_, "2017-Book1");
#line 819 "GomSerializationTest.vala"
		_tmp30_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp29_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp29_) : NULL;
#line 819 "GomSerializationTest.vala"
		if (_tmp30_ == NULL) {
#line 819 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp29_);
#line 9455 "GomSerializationTest.c"
		}
#line 819 "GomSerializationTest.vala"
		b1 = _tmp30_;
#line 820 "GomSerializationTest.vala"
		_tmp31_ = b1;
#line 820 "GomSerializationTest.vala"
		_vala_assert (_tmp31_ != NULL, "b1 != null");
#line 821 "GomSerializationTest.vala"
		_tmp32_ = b1;
#line 821 "GomSerializationTest.vala"
		_tmp33_ = gom_serialization_test_book_register_get_year (_tmp32_);
#line 821 "GomSerializationTest.vala"
		_tmp34_ = _tmp33_;
#line 821 "GomSerializationTest.vala"
		_vala_assert (_tmp34_ == 2017, "b1.year == 2017");
#line 822 "GomSerializationTest.vala"
		_tmp35_ = b1;
#line 822 "GomSerializationTest.vala"
		_tmp36_ = gom_serialization_test_book_register_get_book (_tmp35_);
#line 822 "GomSerializationTest.vala"
		_tmp37_ = _tmp36_;
#line 822 "GomSerializationTest.vala"
		_vala_assert (_tmp37_ != NULL, "b1.book != null");
#line 823 "GomSerializationTest.vala"
		_tmp38_ = b1;
#line 823 "GomSerializationTest.vala"
		_tmp39_ = gom_serialization_test_book_register_get_book (_tmp38_);
#line 823 "GomSerializationTest.vala"
		_tmp40_ = _tmp39_;
#line 823 "GomSerializationTest.vala"
		_tmp41_ = gom_serialization_test_book_get_name (_tmp40_);
#line 823 "GomSerializationTest.vala"
		_tmp42_ = _tmp41_;
#line 823 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp42_, "Book1") == 0, "b1.book.name == \"Book1\"");
#line 824 "GomSerializationTest.vala"
		_tmp43_ = b1;
#line 824 "GomSerializationTest.vala"
		_tmp44_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp43_);
#line 824 "GomSerializationTest.vala"
		_tmp45_ = _tmp44_;
#line 824 "GomSerializationTest.vala"
		_tmp46_ = _tmp45_;
#line 824 "GomSerializationTest.vala"
		_tmp47_ = gxml_dom_node_list_get_length (_tmp46_);
#line 824 "GomSerializationTest.vala"
		_tmp48_ = _tmp47_;
#line 824 "GomSerializationTest.vala"
		_vala_assert (_tmp48_ == 1, "b1.child_nodes.length == 1");
#line 824 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp46_);
#line 825 "GomSerializationTest.vala"
		_tmp49_ = b1;
#line 825 "GomSerializationTest.vala"
		_tmp50_ = gom_serialization_test_book_register_create_book (_tmp49_, "Book2");
#line 825 "GomSerializationTest.vala"
		book2 = _tmp50_;
#line 826 "GomSerializationTest.vala"
		_tmp51_ = b1;
#line 826 "GomSerializationTest.vala"
		_tmp52_ = book2;
#line 826 "GomSerializationTest.vala"
		_tmp53_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp51_, (GXmlDomNode*) _tmp52_, &_inner_error0_);
#line 826 "GomSerializationTest.vala"
		_tmp54_ = _tmp53_;
#line 826 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp54_);
#line 826 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 826 "GomSerializationTest.vala"
			_g_object_unref0 (book2);
#line 826 "GomSerializationTest.vala"
			_g_object_unref0 (b1);
#line 826 "GomSerializationTest.vala"
			_g_object_unref0 (book);
#line 826 "GomSerializationTest.vala"
			_g_object_unref0 (br);
#line 826 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 9535 "GomSerializationTest.c"
			goto __catch180_g_error;
		}
#line 827 "GomSerializationTest.vala"
		_tmp55_ = b1;
#line 827 "GomSerializationTest.vala"
		_tmp56_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp55_);
#line 827 "GomSerializationTest.vala"
		_tmp57_ = _tmp56_;
#line 827 "GomSerializationTest.vala"
		_tmp58_ = _tmp57_;
#line 827 "GomSerializationTest.vala"
		_tmp59_ = gxml_dom_node_list_get_length (_tmp58_);
#line 827 "GomSerializationTest.vala"
		_tmp60_ = _tmp59_;
#line 827 "GomSerializationTest.vala"
		_vala_assert (_tmp60_ == 2, "b1.child_nodes.length == 2");
#line 827 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp58_);
#line 828 "GomSerializationTest.vala"
		_tmp61_ = b1;
#line 828 "GomSerializationTest.vala"
		_tmp62_ = book2;
#line 828 "GomSerializationTest.vala"
		gom_serialization_test_book_register_set_book (_tmp61_, _tmp62_);
#line 829 "GomSerializationTest.vala"
		_tmp63_ = b1;
#line 829 "GomSerializationTest.vala"
		_tmp64_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp63_);
#line 829 "GomSerializationTest.vala"
		_tmp65_ = _tmp64_;
#line 829 "GomSerializationTest.vala"
		_tmp66_ = _tmp65_;
#line 829 "GomSerializationTest.vala"
		_tmp67_ = gxml_dom_node_list_get_length (_tmp66_);
#line 829 "GomSerializationTest.vala"
		_tmp68_ = _tmp67_;
#line 829 "GomSerializationTest.vala"
		_vala_assert (_tmp68_ == 1, "b1.child_nodes.length == 1");
#line 829 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp66_);
#line 809 "GomSerializationTest.vala"
		_g_object_unref0 (book2);
#line 809 "GomSerializationTest.vala"
		_g_object_unref0 (b1);
#line 809 "GomSerializationTest.vala"
		_g_object_unref0 (book);
#line 809 "GomSerializationTest.vala"
		_g_object_unref0 (br);
#line 809 "GomSerializationTest.vala"
		_g_object_unref0 (bs);
#line 9586 "GomSerializationTest.c"
	}
	goto __finally180;
	__catch180_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp69_;
		gchar* _tmp70_;
		gchar* _tmp71_;
#line 809 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 809 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 831 "GomSerializationTest.vala"
		_tmp69_ = e->message;
#line 831 "GomSerializationTest.vala"
		_tmp70_ = g_strconcat ("Error: ", _tmp69_, NULL);
#line 831 "GomSerializationTest.vala"
		_tmp71_ = _tmp70_;
#line 831 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:831: %s", _tmp71_);
#line 831 "GomSerializationTest.vala"
		_g_free0 (_tmp71_);
#line 832 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 809 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 9613 "GomSerializationTest.c"
	}
	__finally180:
#line 809 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 809 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 809 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 809 "GomSerializationTest.vala"
		return;
#line 9624 "GomSerializationTest.c"
	}
}

static void
___lambda127__gtest_func (void)
{
#line 808 "GomSerializationTest.vala"
	__lambda127_ ();
#line 9633 "GomSerializationTest.c"
}

static void
__lambda128_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GomSerializationTestBookStand* bs = NULL;
		GomSerializationTestBookStand* _tmp0_;
		GomSerializationTestHashPairRegisters* _tmp1_;
		GomSerializationTestHashPairRegisters* _tmp2_;
		GomSerializationTestBookRegister* br = NULL;
		GomSerializationTestHashPairRegisters* _tmp3_;
		GomSerializationTestHashPairRegisters* _tmp4_;
		GXmlDomElement* _tmp5_;
		GomSerializationTestBookRegister* _tmp6_;
		GomSerializationTestBook* book = NULL;
		GomSerializationTestBook* _tmp7_;
		const gchar* _tmp8_;
		const gchar* _tmp9_;
		GomSerializationTestHashPairRegisters* _tmp10_;
		GomSerializationTestHashPairRegisters* _tmp11_;
		gint _tmp12_;
		gint _tmp13_;
		GomSerializationTestHashPairRegisters* _tmp14_;
		GomSerializationTestHashPairRegisters* _tmp15_;
		GomSerializationTestHashPairRegisters* _tmp16_;
		GomSerializationTestHashPairRegisters* _tmp17_;
		gint _tmp18_;
		gint _tmp19_;
		GomSerializationTestBookRegister* b1 = NULL;
		GomSerializationTestHashPairRegisters* _tmp20_;
		GomSerializationTestHashPairRegisters* _tmp21_;
		GXmlDomElement* _tmp22_;
		GomSerializationTestBookRegister* _tmp23_;
		gint _tmp24_;
		gint _tmp25_;
		GomSerializationTestBook* _tmp26_;
		GomSerializationTestBook* _tmp27_;
		GomSerializationTestBook* _tmp28_;
		GomSerializationTestBook* _tmp29_;
		const gchar* _tmp30_;
		const gchar* _tmp31_;
#line 837 "GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_book_stand_new ();
#line 837 "GomSerializationTest.vala"
		bs = _tmp0_;
#line 838 "GomSerializationTest.vala"
		_tmp1_ = gom_serialization_test_book_stand_get_hashpair_registers (bs);
#line 838 "GomSerializationTest.vala"
		_tmp2_ = _tmp1_;
#line 838 "GomSerializationTest.vala"
		_vala_assert (_tmp2_ != NULL, "bs.hashpair_registers != null");
#line 839 "GomSerializationTest.vala"
		_tmp3_ = gom_serialization_test_book_stand_get_hashpair_registers (bs);
#line 839 "GomSerializationTest.vala"
		_tmp4_ = _tmp3_;
#line 839 "GomSerializationTest.vala"
		_tmp5_ = gxml_collection_create_item ((GXmlCollection*) _tmp4_);
#line 839 "GomSerializationTest.vala"
		_tmp6_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp5_) : NULL;
#line 839 "GomSerializationTest.vala"
		if (_tmp6_ == NULL) {
#line 839 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp5_);
#line 9699 "GomSerializationTest.c"
		}
#line 839 "GomSerializationTest.vala"
		br = _tmp6_;
#line 840 "GomSerializationTest.vala"
		_tmp7_ = gom_serialization_test_book_register_create_book (br, "Book1");
#line 840 "GomSerializationTest.vala"
		book = _tmp7_;
#line 841 "GomSerializationTest.vala"
		_tmp8_ = gom_serialization_test_book_get_name (book);
#line 841 "GomSerializationTest.vala"
		_tmp9_ = _tmp8_;
#line 841 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp9_, "Book1") == 0, "book.name == \"Book1\"");
#line 842 "GomSerializationTest.vala"
		gom_serialization_test_book_register_set_book (br, book);
#line 843 "GomSerializationTest.vala"
		gom_serialization_test_book_register_set_year (br, 2017);
#line 844 "GomSerializationTest.vala"
		_tmp10_ = gom_serialization_test_book_stand_get_hashpair_registers (bs);
#line 844 "GomSerializationTest.vala"
		_tmp11_ = _tmp10_;
#line 844 "GomSerializationTest.vala"
		_tmp12_ = gxml_collection_get_length ((GXmlCollection*) _tmp11_);
#line 844 "GomSerializationTest.vala"
		_tmp13_ = _tmp12_;
#line 844 "GomSerializationTest.vala"
		_vala_assert (_tmp13_ == 0, "bs.hashpair_registers.length == 0");
#line 845 "GomSerializationTest.vala"
		_tmp14_ = gom_serialization_test_book_stand_get_hashpair_registers (bs);
#line 845 "GomSerializationTest.vala"
		_tmp15_ = _tmp14_;
#line 845 "GomSerializationTest.vala"
		gxml_collection_append ((GXmlCollection*) _tmp15_, (GXmlDomElement*) br, &_inner_error0_);
#line 845 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 845 "GomSerializationTest.vala"
			_g_object_unref0 (book);
#line 845 "GomSerializationTest.vala"
			_g_object_unref0 (br);
#line 845 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 9741 "GomSerializationTest.c"
			goto __catch181_g_error;
		}
#line 846 "GomSerializationTest.vala"
		_tmp16_ = gom_serialization_test_book_stand_get_hashpair_registers (bs);
#line 846 "GomSerializationTest.vala"
		_tmp17_ = _tmp16_;
#line 846 "GomSerializationTest.vala"
		_tmp18_ = gxml_collection_get_length ((GXmlCollection*) _tmp17_);
#line 846 "GomSerializationTest.vala"
		_tmp19_ = _tmp18_;
#line 846 "GomSerializationTest.vala"
		_vala_assert (_tmp19_ == 1, "bs.hashpair_registers.length == 1");
#line 847 "GomSerializationTest.vala"
		_tmp20_ = gom_serialization_test_book_stand_get_hashpair_registers (bs);
#line 847 "GomSerializationTest.vala"
		_tmp21_ = _tmp20_;
#line 847 "GomSerializationTest.vala"
		_tmp22_ = gxml_gom_hash_paired_map_get ((GXmlGomHashPairedMap*) _tmp21_, "2017", "Book1");
#line 847 "GomSerializationTest.vala"
		_tmp23_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp22_) : NULL;
#line 847 "GomSerializationTest.vala"
		if (_tmp23_ == NULL) {
#line 847 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp22_);
#line 9766 "GomSerializationTest.c"
		}
#line 847 "GomSerializationTest.vala"
		b1 = _tmp23_;
#line 848 "GomSerializationTest.vala"
		_vala_assert (b1 != NULL, "b1 != null");
#line 849 "GomSerializationTest.vala"
		_tmp24_ = gom_serialization_test_book_register_get_year (b1);
#line 849 "GomSerializationTest.vala"
		_tmp25_ = _tmp24_;
#line 849 "GomSerializationTest.vala"
		_vala_assert (_tmp25_ == 2017, "b1.year == 2017");
#line 850 "GomSerializationTest.vala"
		_tmp26_ = gom_serialization_test_book_register_get_book (b1);
#line 850 "GomSerializationTest.vala"
		_tmp27_ = _tmp26_;
#line 850 "GomSerializationTest.vala"
		_vala_assert (_tmp27_ != NULL, "b1.book != null");
#line 851 "GomSerializationTest.vala"
		_tmp28_ = gom_serialization_test_book_register_get_book (b1);
#line 851 "GomSerializationTest.vala"
		_tmp29_ = _tmp28_;
#line 851 "GomSerializationTest.vala"
		_tmp30_ = gom_serialization_test_book_get_name (_tmp29_);
#line 851 "GomSerializationTest.vala"
		_tmp31_ = _tmp30_;
#line 851 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp31_, "Book1") == 0, "b1.book.name == \"Book1\"");
#line 836 "GomSerializationTest.vala"
		_g_object_unref0 (b1);
#line 836 "GomSerializationTest.vala"
		_g_object_unref0 (book);
#line 836 "GomSerializationTest.vala"
		_g_object_unref0 (br);
#line 836 "GomSerializationTest.vala"
		_g_object_unref0 (bs);
#line 9802 "GomSerializationTest.c"
	}
	goto __finally181;
	__catch181_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp32_;
		gchar* _tmp33_;
		gchar* _tmp34_;
#line 836 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 836 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 853 "GomSerializationTest.vala"
		_tmp32_ = e->message;
#line 853 "GomSerializationTest.vala"
		_tmp33_ = g_strconcat ("Error: ", _tmp32_, NULL);
#line 853 "GomSerializationTest.vala"
		_tmp34_ = _tmp33_;
#line 853 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:853: %s", _tmp34_);
#line 853 "GomSerializationTest.vala"
		_g_free0 (_tmp34_);
#line 854 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 836 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 9829 "GomSerializationTest.c"
	}
	__finally181:
#line 836 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 836 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 836 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 836 "GomSerializationTest.vala"
		return;
#line 9840 "GomSerializationTest.c"
	}
}

static void
___lambda128__gtest_func (void)
{
#line 835 "GomSerializationTest.vala"
	__lambda128_ ();
#line 9849 "GomSerializationTest.c"
}

static void
__lambda129_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GomSerializationTestBookStand* bs = NULL;
		GomSerializationTestBookStand* _tmp0_;
		GomSerializationTestHashThreeRegisters* _tmp1_;
		GomSerializationTestHashThreeRegisters* _tmp2_;
		GomSerializationTestBookRegister* br = NULL;
		GomSerializationTestHashThreeRegisters* _tmp3_;
		GomSerializationTestHashThreeRegisters* _tmp4_;
		GXmlDomElement* _tmp5_;
		GomSerializationTestBookRegister* _tmp6_;
		GomSerializationTestBook* book = NULL;
		GomSerializationTestBook* _tmp7_;
		const gchar* _tmp8_;
		const gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		const gchar* _tmp14_;
		const gchar* _tmp15_;
		gchar* _tmp16_;
		gchar* _tmp17_;
		GomSerializationTestHashThreeRegisters* _tmp18_;
		GomSerializationTestHashThreeRegisters* _tmp19_;
		gint _tmp20_;
		gint _tmp21_;
		GomSerializationTestHashThreeRegisters* _tmp22_;
		GomSerializationTestHashThreeRegisters* _tmp23_;
		GomSerializationTestHashThreeRegisters* _tmp24_;
		GomSerializationTestHashThreeRegisters* _tmp25_;
		gint _tmp26_;
		gint _tmp27_;
		GomSerializationTestBookRegister* b1 = NULL;
		GomSerializationTestHashThreeRegisters* _tmp28_;
		GomSerializationTestHashThreeRegisters* _tmp29_;
		GXmlDomElement* _tmp30_;
		GomSerializationTestBookRegister* _tmp31_;
		gint _tmp32_;
		gint _tmp33_;
		GomSerializationTestBook* _tmp34_;
		GomSerializationTestBook* _tmp35_;
		GomSerializationTestBook* _tmp36_;
		GomSerializationTestBook* _tmp37_;
		const gchar* _tmp38_;
		const gchar* _tmp39_;
		const gchar* _tmp40_;
		const gchar* _tmp41_;
#line 859 "GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_book_stand_new ();
#line 859 "GomSerializationTest.vala"
		bs = _tmp0_;
#line 860 "GomSerializationTest.vala"
		_tmp1_ = gom_serialization_test_book_stand_get_hashthree_registers (bs);
#line 860 "GomSerializationTest.vala"
		_tmp2_ = _tmp1_;
#line 860 "GomSerializationTest.vala"
		_vala_assert (_tmp2_ != NULL, "bs.hashthree_registers != null");
#line 861 "GomSerializationTest.vala"
		_tmp3_ = gom_serialization_test_book_stand_get_hashthree_registers (bs);
#line 861 "GomSerializationTest.vala"
		_tmp4_ = _tmp3_;
#line 861 "GomSerializationTest.vala"
		_tmp5_ = gxml_collection_create_item ((GXmlCollection*) _tmp4_);
#line 861 "GomSerializationTest.vala"
		_tmp6_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp5_) : NULL;
#line 861 "GomSerializationTest.vala"
		if (_tmp6_ == NULL) {
#line 861 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp5_);
#line 9925 "GomSerializationTest.c"
		}
#line 861 "GomSerializationTest.vala"
		br = _tmp6_;
#line 862 "GomSerializationTest.vala"
		_tmp7_ = gom_serialization_test_book_register_create_book (br, "Book1");
#line 862 "GomSerializationTest.vala"
		book = _tmp7_;
#line 863 "GomSerializationTest.vala"
		_tmp8_ = gom_serialization_test_book_get_name (book);
#line 863 "GomSerializationTest.vala"
		_tmp9_ = _tmp8_;
#line 863 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp9_, "Book1") == 0, "book.name == \"Book1\"");
#line 864 "GomSerializationTest.vala"
		gom_serialization_test_book_register_set_book (br, book);
#line 865 "GomSerializationTest.vala"
		gom_serialization_test_book_register_set_year (br, 2017);
#line 866 "GomSerializationTest.vala"
		gom_serialization_test_book_register_set_cover (br, "SYSTEMS");
#line 867 "GomSerializationTest.vala"
		_tmp10_ = gxml_mappeable_element_three_key_get_map_pkey ((GXmlMappeableElementThreeKey*) br);
#line 867 "GomSerializationTest.vala"
		_tmp11_ = _tmp10_;
#line 867 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp11_, "2017") == 0, "br.get_map_pkey () == \"2017\"");
#line 867 "GomSerializationTest.vala"
		_g_free0 (_tmp11_);
#line 868 "GomSerializationTest.vala"
		_tmp12_ = gxml_mappeable_element_three_key_get_map_skey ((GXmlMappeableElementThreeKey*) br);
#line 868 "GomSerializationTest.vala"
		_tmp13_ = _tmp12_;
#line 868 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp13_, "Book1") == 0, "br.get_map_skey () == \"Book1\"");
#line 868 "GomSerializationTest.vala"
		_g_free0 (_tmp13_);
#line 869 "GomSerializationTest.vala"
		_tmp14_ = gom_serialization_test_book_register_get_cover (br);
#line 869 "GomSerializationTest.vala"
		_tmp15_ = _tmp14_;
#line 869 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp15_, "SYSTEMS") == 0, "br.cover == \"SYSTEMS\"");
#line 870 "GomSerializationTest.vala"
		_tmp16_ = gxml_mappeable_element_three_key_get_map_tkey ((GXmlMappeableElementThreeKey*) br);
#line 870 "GomSerializationTest.vala"
		_tmp17_ = _tmp16_;
#line 870 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp17_, "SYSTEMS") == 0, "br.get_map_tkey () == \"SYSTEMS\"");
#line 870 "GomSerializationTest.vala"
		_g_free0 (_tmp17_);
#line 871 "GomSerializationTest.vala"
		_tmp18_ = gom_serialization_test_book_stand_get_hashthree_registers (bs);
#line 871 "GomSerializationTest.vala"
		_tmp19_ = _tmp18_;
#line 871 "GomSerializationTest.vala"
		_tmp20_ = gxml_collection_get_length ((GXmlCollection*) _tmp19_);
#line 871 "GomSerializationTest.vala"
		_tmp21_ = _tmp20_;
#line 871 "GomSerializationTest.vala"
		_vala_assert (_tmp21_ == 0, "bs.hashthree_registers.length == 0");
#line 872 "GomSerializationTest.vala"
		_tmp22_ = gom_serialization_test_book_stand_get_hashthree_registers (bs);
#line 872 "GomSerializationTest.vala"
		_tmp23_ = _tmp22_;
#line 872 "GomSerializationTest.vala"
		gxml_collection_append ((GXmlCollection*) _tmp23_, (GXmlDomElement*) br, &_inner_error0_);
#line 872 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 872 "GomSerializationTest.vala"
			_g_object_unref0 (book);
#line 872 "GomSerializationTest.vala"
			_g_object_unref0 (br);
#line 872 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 9999 "GomSerializationTest.c"
			goto __catch182_g_error;
		}
#line 873 "GomSerializationTest.vala"
		_tmp24_ = gom_serialization_test_book_stand_get_hashthree_registers (bs);
#line 873 "GomSerializationTest.vala"
		_tmp25_ = _tmp24_;
#line 873 "GomSerializationTest.vala"
		_tmp26_ = gxml_collection_get_length ((GXmlCollection*) _tmp25_);
#line 873 "GomSerializationTest.vala"
		_tmp27_ = _tmp26_;
#line 873 "GomSerializationTest.vala"
		_vala_assert (_tmp27_ == 1, "bs.hashthree_registers.length == 1");
#line 874 "GomSerializationTest.vala"
		_tmp28_ = gom_serialization_test_book_stand_get_hashthree_registers (bs);
#line 874 "GomSerializationTest.vala"
		_tmp29_ = _tmp28_;
#line 874 "GomSerializationTest.vala"
		_tmp30_ = gxml_gom_hash_three_map_get ((GXmlGomHashThreeMap*) _tmp29_, "2017", "Book1", "SYSTEMS");
#line 874 "GomSerializationTest.vala"
		_tmp31_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp30_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp30_) : NULL;
#line 874 "GomSerializationTest.vala"
		if (_tmp31_ == NULL) {
#line 874 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp30_);
#line 10024 "GomSerializationTest.c"
		}
#line 874 "GomSerializationTest.vala"
		b1 = _tmp31_;
#line 875 "GomSerializationTest.vala"
		_vala_assert (b1 != NULL, "b1 != null");
#line 876 "GomSerializationTest.vala"
		_tmp32_ = gom_serialization_test_book_register_get_year (b1);
#line 876 "GomSerializationTest.vala"
		_tmp33_ = _tmp32_;
#line 876 "GomSerializationTest.vala"
		_vala_assert (_tmp33_ == 2017, "b1.year == 2017");
#line 877 "GomSerializationTest.vala"
		_tmp34_ = gom_serialization_test_book_register_get_book (b1);
#line 877 "GomSerializationTest.vala"
		_tmp35_ = _tmp34_;
#line 877 "GomSerializationTest.vala"
		_vala_assert (_tmp35_ != NULL, "b1.book != null");
#line 878 "GomSerializationTest.vala"
		_tmp36_ = gom_serialization_test_book_register_get_book (b1);
#line 878 "GomSerializationTest.vala"
		_tmp37_ = _tmp36_;
#line 878 "GomSerializationTest.vala"
		_tmp38_ = gom_serialization_test_book_get_name (_tmp37_);
#line 878 "GomSerializationTest.vala"
		_tmp39_ = _tmp38_;
#line 878 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp39_, "Book1") == 0, "b1.book.name == \"Book1\"");
#line 879 "GomSerializationTest.vala"
		_tmp40_ = gom_serialization_test_book_register_get_cover (b1);
#line 879 "GomSerializationTest.vala"
		_tmp41_ = _tmp40_;
#line 879 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp41_, "SYSTEMS") == 0, "b1.cover == \"SYSTEMS\"");
#line 858 "GomSerializationTest.vala"
		_g_object_unref0 (b1);
#line 858 "GomSerializationTest.vala"
		_g_object_unref0 (book);
#line 858 "GomSerializationTest.vala"
		_g_object_unref0 (br);
#line 858 "GomSerializationTest.vala"
		_g_object_unref0 (bs);
#line 10066 "GomSerializationTest.c"
	}
	goto __finally182;
	__catch182_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp42_;
		gchar* _tmp43_;
		gchar* _tmp44_;
#line 858 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 858 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 881 "GomSerializationTest.vala"
		_tmp42_ = e->message;
#line 881 "GomSerializationTest.vala"
		_tmp43_ = g_strconcat ("Error: ", _tmp42_, NULL);
#line 881 "GomSerializationTest.vala"
		_tmp44_ = _tmp43_;
#line 881 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:881: %s", _tmp44_);
#line 881 "GomSerializationTest.vala"
		_g_free0 (_tmp44_);
#line 882 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 858 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 10093 "GomSerializationTest.c"
	}
	__finally182:
#line 858 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 858 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 858 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 858 "GomSerializationTest.vala"
		return;
#line 10104 "GomSerializationTest.c"
	}
}

static void
___lambda129__gtest_func (void)
{
#line 857 "GomSerializationTest.vala"
	__lambda129_ ();
#line 10113 "GomSerializationTest.c"
}

static void
__lambda130_ (void)
{
	GomSerializationTestMotor* m = NULL;
	GomSerializationTestMotor* _tmp0_;
	gchar* s = NULL;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	GomSerializationTestMotorOn* _tmp4_;
	GomSerializationTestMotorOn* _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	GomSerializationTestMotorTorque* _tmp9_;
	GomSerializationTestMotorTorque* _tmp10_;
	gchar* _tmp11_;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	GomSerializationTestMotorSpeed* _tmp14_;
	GomSerializationTestMotorSpeed* _tmp15_;
	GomSerializationTestMotorSpeed* _tmp16_;
	GomSerializationTestMotorSpeed* _tmp17_;
	gchar* _tmp18_;
	const gchar* _tmp19_;
	const gchar* _tmp20_;
	GomSerializationTestMotorSpeed* _tmp21_;
	GomSerializationTestMotorSpeed* _tmp22_;
	GomSerializationTestMotorSpeed* _tmp23_;
	GomSerializationTestMotorSpeed* _tmp24_;
	GomSerializationTestMotorSpeed* _tmp25_;
	GomSerializationTestMotorSpeed* _tmp26_;
	GomSerializationTestMotorSpeed* _tmp27_;
	GomSerializationTestMotorSpeed* _tmp28_;
	gchar* _tmp29_;
	gchar* _tmp30_;
	gchar* _tmp31_;
	GomSerializationTestMotorSpeed* _tmp32_;
	GomSerializationTestMotorSpeed* _tmp33_;
	gchar* _tmp34_;
	gchar* _tmp35_;
	gchar* _tmp36_;
	gchar* _tmp37_;
	gchar* _tmp38_;
	GomSerializationTestMotorTensionType* _tmp39_;
	GomSerializationTestMotorTensionType* _tmp40_;
	GomSerializationTestMotorTensionType* _tmp41_;
	GomSerializationTestMotorTensionType* _tmp42_;
	gchar* _tmp43_;
	const gchar* _tmp44_;
	const gchar* _tmp45_;
	GomSerializationTestMotorTensionType* _tmp46_;
	GomSerializationTestMotorTensionType* _tmp47_;
	GomSerializationTestMotorTensionType* _tmp48_;
	GomSerializationTestMotorTensionType* _tmp49_;
	gchar* _tmp50_;
	gchar* _tmp51_;
	gchar* _tmp52_;
	GomSerializationTestMotorTension* _tmp53_;
	GomSerializationTestMotorTension* _tmp54_;
	gchar* _tmp55_;
	const gchar* _tmp56_;
	const gchar* _tmp57_;
	GomSerializationTestMotorOn* _tmp58_;
	GomSerializationTestMotorOn* _tmp59_;
	GomSerializationTestMotorTorque* _tmp60_;
	GomSerializationTestMotorTorque* _tmp61_;
	GomSerializationTestMotorSpeed* _tmp62_;
	GomSerializationTestMotorSpeed* _tmp63_;
	GomSerializationTestMotorTensionType* _tmp64_;
	GomSerializationTestMotorTensionType* _tmp65_;
	GomSerializationTestMotorTension* _tmp66_;
	GomSerializationTestMotorTension* _tmp67_;
	gchar* _tmp68_;
	const gchar* _tmp69_;
	const gchar* _tmp70_;
	GomSerializationTestMotorModel* _tmp71_;
	GomSerializationTestMotorModel* _tmp72_;
	GomSerializationTestMotorModel* _tmp73_;
	GomSerializationTestMotorModel* _tmp74_;
	GomSerializationTestMotorModel* _tmp75_;
	GomSerializationTestMotorModel* _tmp76_;
	gchar* _tmp77_;
	gchar* _tmp78_;
	gchar* _tmp79_;
	GomSerializationTestMotorModel* _tmp80_;
	GomSerializationTestMotorModel* _tmp81_;
	gchar* _tmp82_;
	gchar* _tmp83_;
	gchar* _tmp84_;
	GomSerializationTestMotorModel* _tmp85_;
	GomSerializationTestMotorModel* _tmp86_;
	GomSerializationTestMotorModel* _tmp87_;
	GomSerializationTestMotorModel* _tmp88_;
	gchar* _tmp89_;
	gchar* _tmp90_;
	gchar* _tmp91_;
	gchar* _tmp92_;
	const gchar* _tmp93_;
	const gchar* _tmp94_;
	GomSerializationTestMotorModel* _tmp95_;
	GomSerializationTestMotorModel* _tmp96_;
	GomSerializationTestMotorModel* _tmp97_;
	GomSerializationTestMotorModel* _tmp98_;
	GomSerializationTestMotorModel* _tmp99_;
	GomSerializationTestMotorModel* _tmp100_;
	GomSerializationTestMotorModel* _tmp101_;
	GomSerializationTestMotorModel* _tmp102_;
#line 886 "GomSerializationTest.vala"
	_tmp0_ = gom_serialization_test_motor_new ();
#line 886 "GomSerializationTest.vala"
	m = _tmp0_;
#line 887 "GomSerializationTest.vala"
	_tmp1_ = gom_serialization_test_motor_to_string (m);
#line 887 "GomSerializationTest.vala"
	s = _tmp1_;
#line 888 "GomSerializationTest.vala"
	_tmp2_ = s;
#line 888 "GomSerializationTest.vala"
	_vala_assert (_tmp2_ != NULL, "s != null");
#line 892 "GomSerializationTest.vala"
	_tmp3_ = s;
#line 892 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp3_, "<Motor/>"), "\"<Motor/>\" in s");
#line 893 "GomSerializationTest.vala"
	_tmp4_ = gom_serialization_test_motor_on_new ();
#line 893 "GomSerializationTest.vala"
	_tmp5_ = _tmp4_;
#line 893 "GomSerializationTest.vala"
	gom_serialization_test_motor_set_is_on (m, _tmp5_);
#line 893 "GomSerializationTest.vala"
	_g_object_unref0 (_tmp5_);
#line 894 "GomSerializationTest.vala"
	_tmp6_ = gom_serialization_test_motor_to_string (m);
#line 894 "GomSerializationTest.vala"
	_g_free0 (s);
#line 894 "GomSerializationTest.vala"
	s = _tmp6_;
#line 895 "GomSerializationTest.vala"
	_tmp7_ = s;
#line 895 "GomSerializationTest.vala"
	_vala_assert (_tmp7_ != NULL, "s != null");
#line 899 "GomSerializationTest.vala"
	_tmp8_ = s;
#line 899 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp8_, "<Motor On=\"false\"/>"), "\"<Motor On=\\\"false\\\"/>\" in s");
#line 900 "GomSerializationTest.vala"
	_tmp9_ = gom_serialization_test_motor_torque_new ();
#line 900 "GomSerializationTest.vala"
	_tmp10_ = _tmp9_;
#line 900 "GomSerializationTest.vala"
	gom_serialization_test_motor_set_torque (m, _tmp10_);
#line 900 "GomSerializationTest.vala"
	_g_object_unref0 (_tmp10_);
#line 901 "GomSerializationTest.vala"
	_tmp11_ = gom_serialization_test_motor_to_string (m);
#line 901 "GomSerializationTest.vala"
	_g_free0 (s);
#line 901 "GomSerializationTest.vala"
	s = _tmp11_;
#line 902 "GomSerializationTest.vala"
	_tmp12_ = s;
#line 902 "GomSerializationTest.vala"
	_vala_assert (_tmp12_ != NULL, "s != null");
#line 906 "GomSerializationTest.vala"
	_tmp13_ = s;
#line 906 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp13_, "<Motor On=\"false\" Torque=\"0.0000\"/>"), "\"<Motor On=\\\"false\\\" Torque=\\\"0.0000\\\"/>\" in s");
#line 907 "GomSerializationTest.vala"
	_tmp14_ = gom_serialization_test_motor_speed_new ();
#line 907 "GomSerializationTest.vala"
	_tmp15_ = _tmp14_;
#line 907 "GomSerializationTest.vala"
	gom_serialization_test_motor_set_speed (m, _tmp15_);
#line 907 "GomSerializationTest.vala"
	_g_object_unref0 (_tmp15_);
#line 908 "GomSerializationTest.vala"
	_tmp16_ = gom_serialization_test_motor_get_speed (m);
#line 908 "GomSerializationTest.vala"
	_tmp17_ = _tmp16_;
#line 908 "GomSerializationTest.vala"
	gxml_gom_double_set_double ((GXmlGomDouble*) _tmp17_, 1.0);
#line 909 "GomSerializationTest.vala"
	_tmp18_ = gom_serialization_test_motor_to_string (m);
#line 909 "GomSerializationTest.vala"
	_g_free0 (s);
#line 909 "GomSerializationTest.vala"
	s = _tmp18_;
#line 910 "GomSerializationTest.vala"
	_tmp19_ = s;
#line 910 "GomSerializationTest.vala"
	_vala_assert (_tmp19_ != NULL, "s != null");
#line 914 "GomSerializationTest.vala"
	_tmp20_ = s;
#line 914 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp20_, "<Motor On=\"false\" Torque=\"0.0000\" Speed=\"1.0000\"/>"), "\"<Motor On=\\\"false\\\" Torque=\\\"0.0000\\\" Speed=\\\"1.0000\\\"/>\" in s");
#line 915 "GomSerializationTest.vala"
	_tmp21_ = gom_serialization_test_motor_get_speed (m);
#line 915 "GomSerializationTest.vala"
	_tmp22_ = _tmp21_;
#line 915 "GomSerializationTest.vala"
	_vala_assert (_tmp22_ != NULL, "m.speed != null");
#line 916 "GomSerializationTest.vala"
	_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (m, GXML_TYPE_GOM_OBJECT), "m is GomObject");
#line 917 "GomSerializationTest.vala"
	_tmp23_ = gom_serialization_test_motor_get_speed (m);
#line 917 "GomSerializationTest.vala"
	_tmp24_ = _tmp23_;
#line 917 "GomSerializationTest.vala"
	_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp24_, GXML_TYPE_GOM_PROPERTY), "m.speed is GomProperty");
#line 918 "GomSerializationTest.vala"
	_tmp25_ = gom_serialization_test_motor_get_speed (m);
#line 918 "GomSerializationTest.vala"
	_tmp26_ = _tmp25_;
#line 918 "GomSerializationTest.vala"
	_vala_assert (gxml_gom_double_get_double ((GXmlGomDouble*) _tmp26_) == 1.0, "m.speed.get_double () == 1.0");
#line 919 "GomSerializationTest.vala"
	_tmp27_ = gom_serialization_test_motor_get_speed (m);
#line 919 "GomSerializationTest.vala"
	_tmp28_ = _tmp27_;
#line 919 "GomSerializationTest.vala"
	_tmp29_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp28_);
#line 919 "GomSerializationTest.vala"
	_tmp30_ = _tmp29_;
#line 919 "GomSerializationTest.vala"
	_tmp31_ = _tmp30_;
#line 919 "GomSerializationTest.vala"
	_vala_assert (_tmp31_ != NULL, "m.speed.value != null");
#line 919 "GomSerializationTest.vala"
	_g_free0 (_tmp31_);
#line 920 "GomSerializationTest.vala"
	_tmp32_ = gom_serialization_test_motor_get_speed (m);
#line 920 "GomSerializationTest.vala"
	_tmp33_ = _tmp32_;
#line 920 "GomSerializationTest.vala"
	_tmp34_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp33_);
#line 920 "GomSerializationTest.vala"
	_tmp35_ = _tmp34_;
#line 920 "GomSerializationTest.vala"
	_tmp36_ = _tmp35_;
#line 920 "GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp36_, "1.0000") == 0, "m.speed.value == \"1.0000\"");
#line 920 "GomSerializationTest.vala"
	_g_free0 (_tmp36_);
#line 924 "GomSerializationTest.vala"
	_tmp37_ = gxml_dom_element_get_attribute ((GXmlDomElement*) m, "speed");
#line 924 "GomSerializationTest.vala"
	_tmp38_ = _tmp37_;
#line 924 "GomSerializationTest.vala"
	_vala_assert (_tmp38_ != NULL, "m.get_attribute (\"speed\") != null");
#line 924 "GomSerializationTest.vala"
	_g_free0 (_tmp38_);
#line 925 "GomSerializationTest.vala"
	_tmp39_ = gom_serialization_test_motor_get_tension_type (m);
#line 925 "GomSerializationTest.vala"
	_tmp40_ = _tmp39_;
#line 925 "GomSerializationTest.vala"
	_vala_assert (_tmp40_ == NULL, "m.tension_type == null");
#line 926 "GomSerializationTest.vala"
	_tmp41_ = gom_serialization_test_motor_tension_type_new ();
#line 926 "GomSerializationTest.vala"
	_tmp42_ = _tmp41_;
#line 926 "GomSerializationTest.vala"
	gom_serialization_test_motor_set_tension_type (m, _tmp42_);
#line 926 "GomSerializationTest.vala"
	_g_object_unref0 (_tmp42_);
#line 927 "GomSerializationTest.vala"
	_tmp43_ = gom_serialization_test_motor_to_string (m);
#line 927 "GomSerializationTest.vala"
	_g_free0 (s);
#line 927 "GomSerializationTest.vala"
	s = _tmp43_;
#line 928 "GomSerializationTest.vala"
	_tmp44_ = s;
#line 928 "GomSerializationTest.vala"
	_vala_assert (_tmp44_ != NULL, "s != null");
#line 932 "GomSerializationTest.vala"
	_tmp45_ = s;
#line 932 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp45_, "<Motor On=\"false\" Torque=\"0.0000\" Speed=\"1.0000\" TensionType=\"a" \
"c\"/>"), "\"<Motor On=\\\"false\\\" Torque=\\\"0.0000\\\" Speed=\\\"1.0000\\\" TensionType=\\\"ac\\\"/>\" in s");
#line 933 "GomSerializationTest.vala"
	_tmp46_ = gom_serialization_test_motor_get_tension_type (m);
#line 933 "GomSerializationTest.vala"
	_tmp47_ = _tmp46_;
#line 933 "GomSerializationTest.vala"
	_vala_assert (_tmp47_ != NULL, "m.tension_type != null");
#line 934 "GomSerializationTest.vala"
	_tmp48_ = gom_serialization_test_motor_get_tension_type (m);
#line 934 "GomSerializationTest.vala"
	_tmp49_ = _tmp48_;
#line 934 "GomSerializationTest.vala"
	_tmp50_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp49_);
#line 934 "GomSerializationTest.vala"
	_tmp51_ = _tmp50_;
#line 934 "GomSerializationTest.vala"
	_tmp52_ = _tmp51_;
#line 934 "GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp52_, "ac") == 0, "m.tension_type.value == \"ac\"");
#line 934 "GomSerializationTest.vala"
	_g_free0 (_tmp52_);
#line 935 "GomSerializationTest.vala"
	_tmp53_ = gom_serialization_test_motor_tension_new ();
#line 935 "GomSerializationTest.vala"
	_tmp54_ = _tmp53_;
#line 935 "GomSerializationTest.vala"
	gom_serialization_test_motor_set_tension (m, _tmp54_);
#line 935 "GomSerializationTest.vala"
	_g_object_unref0 (_tmp54_);
#line 936 "GomSerializationTest.vala"
	_tmp55_ = gom_serialization_test_motor_to_string (m);
#line 936 "GomSerializationTest.vala"
	_g_free0 (s);
#line 936 "GomSerializationTest.vala"
	s = _tmp55_;
#line 937 "GomSerializationTest.vala"
	_tmp56_ = s;
#line 937 "GomSerializationTest.vala"
	_vala_assert (_tmp56_ != NULL, "s != null");
#line 941 "GomSerializationTest.vala"
	_tmp57_ = s;
#line 941 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp57_, "<Motor On=\"false\" Torque=\"0.0000\" Speed=\"1.0000\" TensionType=\"a" \
"c\" Tension=\"0\"/>"), "\"<Motor On=\\\"false\\\" Torque=\\\"0.0000\\\" Speed=\\\"1.0000\\\" TensionType=\\\"ac\\\" Tension=\\\"0\\\"/>\" in s");
#line 942 "GomSerializationTest.vala"
	_tmp58_ = gom_serialization_test_motor_get_is_on (m);
#line 942 "GomSerializationTest.vala"
	_tmp59_ = _tmp58_;
#line 942 "GomSerializationTest.vala"
	gxml_gom_boolean_set_boolean ((GXmlGomBoolean*) _tmp59_, TRUE);
#line 943 "GomSerializationTest.vala"
	_tmp60_ = gom_serialization_test_motor_get_torque (m);
#line 943 "GomSerializationTest.vala"
	_tmp61_ = _tmp60_;
#line 943 "GomSerializationTest.vala"
	gxml_gom_double_set_double ((GXmlGomDouble*) _tmp61_, 3.1416);
#line 944 "GomSerializationTest.vala"
	_tmp62_ = gom_serialization_test_motor_get_speed (m);
#line 944 "GomSerializationTest.vala"
	_tmp63_ = _tmp62_;
#line 944 "GomSerializationTest.vala"
	gxml_gom_float_set_float ((GXmlGomFloat*) _tmp63_, (gfloat) 3600.1011);
#line 945 "GomSerializationTest.vala"
	_tmp64_ = gom_serialization_test_motor_get_tension_type (m);
#line 945 "GomSerializationTest.vala"
	_tmp65_ = _tmp64_;
#line 945 "GomSerializationTest.vala"
	gxml_gom_enum_set_enum ((GXmlGomEnum*) _tmp65_, (gint) GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_ENUM_DC);
#line 946 "GomSerializationTest.vala"
	_tmp66_ = gom_serialization_test_motor_get_tension (m);
#line 946 "GomSerializationTest.vala"
	_tmp67_ = _tmp66_;
#line 946 "GomSerializationTest.vala"
	gxml_gom_int_set_integer ((GXmlGomInt*) _tmp67_, 125);
#line 947 "GomSerializationTest.vala"
	_tmp68_ = gom_serialization_test_motor_to_string (m);
#line 947 "GomSerializationTest.vala"
	_g_free0 (s);
#line 947 "GomSerializationTest.vala"
	s = _tmp68_;
#line 948 "GomSerializationTest.vala"
	_tmp69_ = s;
#line 948 "GomSerializationTest.vala"
	_vala_assert (_tmp69_ != NULL, "s != null");
#line 952 "GomSerializationTest.vala"
	_tmp70_ = s;
#line 952 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp70_, "<Motor On=\"true\" Torque=\"3.1416\" Speed=\"3600.1011\" TensionType=\"" \
"dc\" Tension=\"125\"/>"), "\"<Motor On=\\\"true\\\" Torque=\\\"3.1416\\\" Speed=\\\"3600.1011\\\" TensionType=\\\"dc\\\" Tension=\\\"125\\\"/>\" in s");
#line 953 "GomSerializationTest.vala"
	_tmp71_ = gom_serialization_test_motor_model_new ();
#line 953 "GomSerializationTest.vala"
	_tmp72_ = _tmp71_;
#line 953 "GomSerializationTest.vala"
	gom_serialization_test_motor_set_model (m, _tmp72_);
#line 953 "GomSerializationTest.vala"
	_g_object_unref0 (_tmp72_);
#line 954 "GomSerializationTest.vala"
	_tmp73_ = gom_serialization_test_motor_get_model (m);
#line 954 "GomSerializationTest.vala"
	_tmp74_ = _tmp73_;
#line 954 "GomSerializationTest.vala"
	_vala_assert (_tmp74_ != NULL, "m.model != null");
#line 955 "GomSerializationTest.vala"
	_tmp75_ = gom_serialization_test_motor_get_model (m);
#line 955 "GomSerializationTest.vala"
	_tmp76_ = _tmp75_;
#line 955 "GomSerializationTest.vala"
	_tmp77_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp76_);
#line 955 "GomSerializationTest.vala"
	_tmp78_ = _tmp77_;
#line 955 "GomSerializationTest.vala"
	_tmp79_ = _tmp78_;
#line 955 "GomSerializationTest.vala"
	_vala_assert (_tmp79_ != NULL, "m.model.value != null");
#line 955 "GomSerializationTest.vala"
	_g_free0 (_tmp79_);
#line 956 "GomSerializationTest.vala"
	_tmp80_ = gom_serialization_test_motor_get_model (m);
#line 956 "GomSerializationTest.vala"
	_tmp81_ = _tmp80_;
#line 956 "GomSerializationTest.vala"
	_tmp82_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp81_);
#line 956 "GomSerializationTest.vala"
	_tmp83_ = _tmp82_;
#line 956 "GomSerializationTest.vala"
	_tmp84_ = _tmp83_;
#line 956 "GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp84_, "") == 0, "m.model.value == \"\"");
#line 956 "GomSerializationTest.vala"
	_g_free0 (_tmp84_);
#line 957 "GomSerializationTest.vala"
	_tmp85_ = gom_serialization_test_motor_get_model (m);
#line 957 "GomSerializationTest.vala"
	_tmp86_ = _tmp85_;
#line 957 "GomSerializationTest.vala"
	gxml_gom_property_set_value ((GXmlGomBaseProperty*) _tmp86_, "Model3");
#line 958 "GomSerializationTest.vala"
	_tmp87_ = gom_serialization_test_motor_get_model (m);
#line 958 "GomSerializationTest.vala"
	_tmp88_ = _tmp87_;
#line 958 "GomSerializationTest.vala"
	_tmp89_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp88_);
#line 958 "GomSerializationTest.vala"
	_tmp90_ = _tmp89_;
#line 958 "GomSerializationTest.vala"
	_tmp91_ = _tmp90_;
#line 958 "GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp91_, "Model3") == 0, "m.model.value == \"Model3\"");
#line 958 "GomSerializationTest.vala"
	_g_free0 (_tmp91_);
#line 959 "GomSerializationTest.vala"
	_tmp92_ = gom_serialization_test_motor_to_string (m);
#line 959 "GomSerializationTest.vala"
	_g_free0 (s);
#line 959 "GomSerializationTest.vala"
	s = _tmp92_;
#line 960 "GomSerializationTest.vala"
	_tmp93_ = s;
#line 960 "GomSerializationTest.vala"
	_vala_assert (_tmp93_ != NULL, "s != null");
#line 964 "GomSerializationTest.vala"
	_tmp94_ = s;
#line 964 "GomSerializationTest.vala"
	_vala_assert (string_contains (_tmp94_, "<Motor On=\"true\" Torque=\"3.1416\" Speed=\"3600.1011\" TensionType=\"" \
"dc\" Tension=\"125\" Model=\"Model3\"/>"), "\"<Motor On=\\\"true\\\" Torque=\\\"3.1416\\\" Speed=\\\"3600.1011\\\" TensionType=\\\"dc\\\" Tension=\\\"125\\\" Model=\\\"Model3\\\"/>\" in s");
#line 965 "GomSerializationTest.vala"
	_tmp95_ = gom_serialization_test_motor_get_model (m);
#line 965 "GomSerializationTest.vala"
	_tmp96_ = _tmp95_;
#line 965 "GomSerializationTest.vala"
	_vala_assert (!gxml_gom_array_string_is_valid_value ((GXmlGomArrayString*) _tmp96_), "!m.model.is_valid_value ()");
#line 966 "GomSerializationTest.vala"
	_tmp97_ = gom_serialization_test_motor_get_model (m);
#line 966 "GomSerializationTest.vala"
	_tmp98_ = _tmp97_;
#line 966 "GomSerializationTest.vala"
	_vala_assert (gxml_gom_array_string_search ((GXmlGomArrayString*) _tmp98_, "MODEL1"), "m.model.search (\"MODEL1\")");
#line 967 "GomSerializationTest.vala"
	_tmp99_ = gom_serialization_test_motor_get_model (m);
#line 967 "GomSerializationTest.vala"
	_tmp100_ = _tmp99_;
#line 967 "GomSerializationTest.vala"
	gxml_gom_property_set_value ((GXmlGomBaseProperty*) _tmp100_, "MODEL1");
#line 968 "GomSerializationTest.vala"
	_tmp101_ = gom_serialization_test_motor_get_model (m);
#line 968 "GomSerializationTest.vala"
	_tmp102_ = _tmp101_;
#line 968 "GomSerializationTest.vala"
	_vala_assert (gxml_gom_array_string_is_valid_value ((GXmlGomArrayString*) _tmp102_), "m.model.is_valid_value ()");
#line 885 "GomSerializationTest.vala"
	_g_free0 (s);
#line 885 "GomSerializationTest.vala"
	_g_object_unref0 (m);
#line 10586 "GomSerializationTest.c"
}

static void
___lambda130__gtest_func (void)
{
#line 885 "GomSerializationTest.vala"
	__lambda130_ ();
#line 10594 "GomSerializationTest.c"
}

static void
__lambda131_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GomSerializationTestBook* b = NULL;
		GomSerializationTestBook* _tmp0_;
		GXmlXParser* parser = NULL;
		GomSerializationTestBook* _tmp1_;
		GXmlXParser* _tmp2_;
		GXmlXParser* _tmp3_;
		gchar* s = NULL;
		GXmlXParser* _tmp4_;
		gchar* _tmp5_;
		const gchar* _tmp6_;
		const gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		GomSerializationTestBook* _tmp10_;
		GomSerializationTestBook* _tmp11_;
		GXmlDomNodeList* _tmp12_;
		GXmlDomNodeList* _tmp13_;
		GXmlDomNodeList* _tmp14_;
		GomSerializationTestBook* _tmp15_;
		GXmlDomNodeList* _tmp16_;
		GXmlDomNodeList* _tmp17_;
		GXmlDomNodeList* _tmp18_;
		gint _tmp19_;
		gint _tmp20_;
		GomSerializationTestBook* _tmp21_;
		GXmlDomNamedNodeMap* _tmp22_;
		GXmlDomNamedNodeMap* _tmp23_;
		GXmlDomNamedNodeMap* _tmp24_;
		GomSerializationTestBook* _tmp25_;
		GXmlDomNamedNodeMap* _tmp26_;
		GXmlDomNamedNodeMap* _tmp27_;
		GXmlDomNamedNodeMap* _tmp28_;
		gint _tmp29_;
		gint _tmp30_;
		GomSerializationTestBook* _tmp31_;
		const gchar* _tmp32_;
		const gchar* _tmp33_;
		GomSerializationTestBook* _tmp34_;
		const gchar* _tmp35_;
		const gchar* _tmp36_;
		gchar* _tmp37_ = NULL;
		GXmlXParser* _tmp38_;
		gchar* _tmp39_;
		gchar* _tmp40_;
		const gchar* _tmp41_;
		const gchar* _tmp42_;
		const gchar* _tmp43_;
		gchar* _tmp44_;
		gchar* _tmp45_;
		GomSerializationTestBook* _tmp46_;
		GomSerializationTestBook* _tmp47_;
		gchar* _tmp48_;
		gchar* _tmp49_;
		GomSerializationTestBook* _tmp50_;
		gchar* _tmp51_;
		const gchar* _tmp52_;
#line 972 "GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_book_new ();
#line 972 "GomSerializationTest.vala"
		b = _tmp0_;
#line 973 "GomSerializationTest.vala"
		_tmp1_ = b;
#line 973 "GomSerializationTest.vala"
		_tmp2_ = gxml_xparser_new ((GXmlDomNode*) _tmp1_);
#line 973 "GomSerializationTest.vala"
		parser = _tmp2_;
#line 974 "GomSerializationTest.vala"
		_tmp3_ = parser;
#line 974 "GomSerializationTest.vala"
		gxml_parser_read_string ((GXmlParser*) _tmp3_, "<book name=\"Loco\"/>", &_inner_error0_);
#line 974 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 974 "GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 974 "GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 10678 "GomSerializationTest.c"
			goto __catch183_g_error;
		}
#line 975 "GomSerializationTest.vala"
		_tmp4_ = parser;
#line 975 "GomSerializationTest.vala"
		_tmp5_ = gxml_parser_write_string ((GXmlParser*) _tmp4_, &_inner_error0_);
#line 975 "GomSerializationTest.vala"
		s = _tmp5_;
#line 975 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 975 "GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 975 "GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 10693 "GomSerializationTest.c"
			goto __catch183_g_error;
		}
#line 976 "GomSerializationTest.vala"
		_tmp6_ = s;
#line 976 "GomSerializationTest.vala"
		_vala_assert (_tmp6_ != NULL, "s != null");
#line 977 "GomSerializationTest.vala"
		_tmp7_ = s;
#line 977 "GomSerializationTest.vala"
		_tmp8_ = g_strconcat ("Doc:", _tmp7_, NULL);
#line 977 "GomSerializationTest.vala"
		_tmp9_ = _tmp8_;
#line 977 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:977: %s", _tmp9_);
#line 977 "GomSerializationTest.vala"
		_g_free0 (_tmp9_);
#line 978 "GomSerializationTest.vala"
		_tmp10_ = b;
#line 978 "GomSerializationTest.vala"
		_vala_assert (_tmp10_ != NULL, "b != null");
#line 979 "GomSerializationTest.vala"
		_tmp11_ = b;
#line 979 "GomSerializationTest.vala"
		_tmp12_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp11_);
#line 979 "GomSerializationTest.vala"
		_tmp13_ = _tmp12_;
#line 979 "GomSerializationTest.vala"
		_tmp14_ = _tmp13_;
#line 979 "GomSerializationTest.vala"
		_vala_assert (_tmp14_ != NULL, "b.child_nodes != null");
#line 979 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp14_);
#line 980 "GomSerializationTest.vala"
		_tmp15_ = b;
#line 980 "GomSerializationTest.vala"
		_tmp16_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp15_);
#line 980 "GomSerializationTest.vala"
		_tmp17_ = _tmp16_;
#line 980 "GomSerializationTest.vala"
		_tmp18_ = _tmp17_;
#line 980 "GomSerializationTest.vala"
		_tmp19_ = gee_collection_get_size ((GeeCollection*) _tmp18_);
#line 980 "GomSerializationTest.vala"
		_tmp20_ = _tmp19_;
#line 980 "GomSerializationTest.vala"
		_vala_assert (_tmp20_ == 0, "b.child_nodes.size == 0");
#line 980 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp18_);
#line 981 "GomSerializationTest.vala"
		_tmp21_ = b;
#line 981 "GomSerializationTest.vala"
		_tmp22_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp21_);
#line 981 "GomSerializationTest.vala"
		_tmp23_ = _tmp22_;
#line 981 "GomSerializationTest.vala"
		_tmp24_ = _tmp23_;
#line 981 "GomSerializationTest.vala"
		_vala_assert (_tmp24_ != NULL, "b.attributes != null");
#line 981 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp24_);
#line 982 "GomSerializationTest.vala"
		_tmp25_ = b;
#line 982 "GomSerializationTest.vala"
		_tmp26_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp25_);
#line 982 "GomSerializationTest.vala"
		_tmp27_ = _tmp26_;
#line 982 "GomSerializationTest.vala"
		_tmp28_ = _tmp27_;
#line 982 "GomSerializationTest.vala"
		_tmp29_ = gee_map_get_size ((GeeMap*) _tmp28_);
#line 982 "GomSerializationTest.vala"
		_tmp30_ = _tmp29_;
#line 982 "GomSerializationTest.vala"
		_vala_assert (_tmp30_ == 1, "b.attributes.size == 1");
#line 982 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp28_);
#line 983 "GomSerializationTest.vala"
		_tmp31_ = b;
#line 983 "GomSerializationTest.vala"
		_tmp32_ = gom_serialization_test_book_get_name (_tmp31_);
#line 983 "GomSerializationTest.vala"
		_tmp33_ = _tmp32_;
#line 983 "GomSerializationTest.vala"
		_vala_assert (_tmp33_ != NULL, "b.name != null");
#line 984 "GomSerializationTest.vala"
		_tmp34_ = b;
#line 984 "GomSerializationTest.vala"
		_tmp35_ = gom_serialization_test_book_get_name (_tmp34_);
#line 984 "GomSerializationTest.vala"
		_tmp36_ = _tmp35_;
#line 984 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp36_, "Loco") == 0, "b.name == \"Loco\"");
#line 985 "GomSerializationTest.vala"
		_tmp38_ = parser;
#line 985 "GomSerializationTest.vala"
		_tmp39_ = gxml_parser_write_string ((GXmlParser*) _tmp38_, &_inner_error0_);
#line 985 "GomSerializationTest.vala"
		_tmp37_ = _tmp39_;
#line 985 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 985 "GomSerializationTest.vala"
			_g_free0 (s);
#line 985 "GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 985 "GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 10800 "GomSerializationTest.c"
			goto __catch183_g_error;
		}
#line 985 "GomSerializationTest.vala"
		_tmp40_ = _tmp37_;
#line 985 "GomSerializationTest.vala"
		_tmp37_ = NULL;
#line 985 "GomSerializationTest.vala"
		_g_free0 (s);
#line 985 "GomSerializationTest.vala"
		s = _tmp40_;
#line 986 "GomSerializationTest.vala"
		_tmp41_ = s;
#line 986 "GomSerializationTest.vala"
		_vala_assert (_tmp41_ != NULL, "s != null");
#line 987 "GomSerializationTest.vala"
		_tmp42_ = s;
#line 987 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp42_, "<Book Name=\"Loco\"/>"), "\"<Book Name=\\\"Loco\\\"/>\" in s");
#line 988 "GomSerializationTest.vala"
		_tmp43_ = s;
#line 988 "GomSerializationTest.vala"
		_tmp44_ = g_strconcat ("Doc:", _tmp43_, NULL);
#line 988 "GomSerializationTest.vala"
		_tmp45_ = _tmp44_;
#line 988 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:988: %s", _tmp45_);
#line 988 "GomSerializationTest.vala"
		_g_free0 (_tmp45_);
#line 989 "GomSerializationTest.vala"
		_tmp46_ = b;
#line 989 "GomSerializationTest.vala"
		gom_serialization_test_book_set_name (_tmp46_, "My Book");
#line 990 "GomSerializationTest.vala"
		_tmp47_ = b;
#line 990 "GomSerializationTest.vala"
		_tmp48_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp47_, "name");
#line 990 "GomSerializationTest.vala"
		_tmp49_ = _tmp48_;
#line 990 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp49_, "My Book") == 0, "b.get_attribute (\"name\") == \"My Book\"");
#line 990 "GomSerializationTest.vala"
		_g_free0 (_tmp49_);
#line 991 "GomSerializationTest.vala"
		_tmp50_ = b;
#line 991 "GomSerializationTest.vala"
		_tmp51_ = gom_serialization_test_book_to_string (_tmp50_);
#line 991 "GomSerializationTest.vala"
		_g_free0 (s);
#line 991 "GomSerializationTest.vala"
		s = _tmp51_;
#line 992 "GomSerializationTest.vala"
		_tmp52_ = s;
#line 992 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp52_, "<Book Name=\"My Book\"/>"), "\"<Book Name=\\\"My Book\\\"/>\" in s");
#line 971 "GomSerializationTest.vala"
		_g_free0 (_tmp37_);
#line 971 "GomSerializationTest.vala"
		_g_free0 (s);
#line 971 "GomSerializationTest.vala"
		_g_object_unref0 (parser);
#line 971 "GomSerializationTest.vala"
		_g_object_unref0 (b);
#line 10863 "GomSerializationTest.c"
	}
	goto __finally183;
	__catch183_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp53_;
		gchar* _tmp54_;
		gchar* _tmp55_;
#line 971 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 971 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 994 "GomSerializationTest.vala"
		_tmp53_ = e->message;
#line 994 "GomSerializationTest.vala"
		_tmp54_ = g_strconcat ("Error: ", _tmp53_, NULL);
#line 994 "GomSerializationTest.vala"
		_tmp55_ = _tmp54_;
#line 994 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:994: %s", _tmp55_);
#line 994 "GomSerializationTest.vala"
		_g_free0 (_tmp55_);
#line 995 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 971 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 10890 "GomSerializationTest.c"
	}
	__finally183:
#line 971 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 971 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 971 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 971 "GomSerializationTest.vala"
		return;
#line 10901 "GomSerializationTest.c"
	}
}

static void
___lambda131__gtest_func (void)
{
#line 970 "GomSerializationTest.vala"
	__lambda131_ ();
#line 10910 "GomSerializationTest.c"
}

static void
__lambda132_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GomSerializationTestBook* b = NULL;
		GomSerializationTestBook* _tmp0_;
		const gchar* _tmp1_;
		const gchar* _tmp2_;
		GXmlDomNodeList* _tmp3_;
		GXmlDomNodeList* _tmp4_;
		GXmlDomNodeList* _tmp5_;
		gint _tmp6_;
		gint _tmp7_;
		GXmlDomDocument* _tmp8_;
		GXmlDomDocument* _tmp9_;
		GXmlDomElement* _tmp10_;
		GXmlDomElement* _tmp11_;
		GXmlDomElement* _tmp12_;
		GXmlDomDocument* _tmp13_;
		GXmlDomDocument* _tmp14_;
		GXmlDomElement* _tmp15_;
		GXmlDomElement* _tmp16_;
		GXmlDomElement* _tmp17_;
		gchar* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
#line 1000 "GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_book_new ();
#line 1000 "GomSerializationTest.vala"
		b = _tmp0_;
#line 1001 "GomSerializationTest.vala"
		gxml_dom_element_read_from_string ((GXmlDomElement*) b, "<chair name=\"Tall\"/>", NULL, &_inner_error0_);
#line 1001 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1001 "GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 10950 "GomSerializationTest.c"
			goto __catch184_g_error;
		}
#line 1006 "GomSerializationTest.vala"
		_tmp1_ = gom_serialization_test_book_get_name (b);
#line 1006 "GomSerializationTest.vala"
		_tmp2_ = _tmp1_;
#line 1006 "GomSerializationTest.vala"
		_vala_assert (_tmp2_ == NULL, "b.name == null");
#line 1007 "GomSerializationTest.vala"
		_tmp3_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) b);
#line 1007 "GomSerializationTest.vala"
		_tmp4_ = _tmp3_;
#line 1007 "GomSerializationTest.vala"
		_tmp5_ = _tmp4_;
#line 1007 "GomSerializationTest.vala"
		_tmp6_ = gee_collection_get_size ((GeeCollection*) _tmp5_);
#line 1007 "GomSerializationTest.vala"
		_tmp7_ = _tmp6_;
#line 1007 "GomSerializationTest.vala"
		_vala_assert (_tmp7_ == 0, "b.child_nodes.size == 0");
#line 1007 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp5_);
#line 1008 "GomSerializationTest.vala"
		_tmp8_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) b);
#line 1008 "GomSerializationTest.vala"
		_tmp9_ = _tmp8_;
#line 1008 "GomSerializationTest.vala"
		_tmp10_ = gxml_dom_document_get_document_element (_tmp9_);
#line 1008 "GomSerializationTest.vala"
		_tmp11_ = _tmp10_;
#line 1008 "GomSerializationTest.vala"
		_tmp12_ = _tmp11_;
#line 1008 "GomSerializationTest.vala"
		_vala_assert (_tmp12_ != NULL, "b.owner_document.document_element != null");
#line 1008 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp12_);
#line 1009 "GomSerializationTest.vala"
		_tmp13_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) b);
#line 1009 "GomSerializationTest.vala"
		_tmp14_ = _tmp13_;
#line 1009 "GomSerializationTest.vala"
		_tmp15_ = gxml_dom_document_get_document_element (_tmp14_);
#line 1009 "GomSerializationTest.vala"
		_tmp16_ = _tmp15_;
#line 1009 "GomSerializationTest.vala"
		_tmp17_ = _tmp16_;
#line 1009 "GomSerializationTest.vala"
		_tmp18_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp17_);
#line 1009 "GomSerializationTest.vala"
		_tmp19_ = _tmp18_;
#line 1009 "GomSerializationTest.vala"
		_tmp20_ = _tmp19_;
#line 1009 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp20_, "Book") == 0, "b.owner_document.document_element.node_name == \"Book\"");
#line 1009 "GomSerializationTest.vala"
		_g_free0 (_tmp20_);
#line 1009 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp17_);
#line 999 "GomSerializationTest.vala"
		_g_object_unref0 (b);
#line 11011 "GomSerializationTest.c"
	}
	goto __finally184;
	__catch184_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
#line 999 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 999 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 1011 "GomSerializationTest.vala"
		_tmp21_ = e->message;
#line 1011 "GomSerializationTest.vala"
		_tmp22_ = g_strconcat ("Error: ", _tmp21_, NULL);
#line 1011 "GomSerializationTest.vala"
		_tmp23_ = _tmp22_;
#line 1011 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1011: %s", _tmp23_);
#line 1011 "GomSerializationTest.vala"
		_g_free0 (_tmp23_);
#line 1012 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 999 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 11038 "GomSerializationTest.c"
	}
	__finally184:
#line 999 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 999 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 999 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 999 "GomSerializationTest.vala"
		return;
#line 11049 "GomSerializationTest.c"
	}
}

static void
___lambda132__gtest_func (void)
{
#line 998 "GomSerializationTest.vala"
	__lambda132_ ();
#line 11058 "GomSerializationTest.c"
}

static void
__lambda133_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GomSerializationTestBookRegister* b = NULL;
		GomSerializationTestBookRegister* _tmp0_;
		gchar* s = NULL;
		gchar* _tmp1_;
		const gchar* _tmp2_;
		gchar* _tmp3_;
		const gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		const gchar* _tmp7_;
#line 1017 "GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_book_register_new ();
#line 1017 "GomSerializationTest.vala"
		b = _tmp0_;
#line 1018 "GomSerializationTest.vala"
		_tmp1_ = gom_serialization_test_book_register_to_string (b);
#line 1018 "GomSerializationTest.vala"
		s = _tmp1_;
#line 1022 "GomSerializationTest.vala"
		_tmp2_ = s;
#line 1022 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp2_, "<BookRegister Year=\"0\"/>"), "\"<BookRegister Year=\\\"0\\\"/>\" in s");
#line 1023 "GomSerializationTest.vala"
		gxml_dom_element_read_from_string ((GXmlDomElement*) b, "<bookRegister><Book/></bookRegister>", NULL, &_inner_error0_);
#line 1023 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1023 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1023 "GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 11096 "GomSerializationTest.c"
			goto __catch185_g_error;
		}
#line 1024 "GomSerializationTest.vala"
		_tmp3_ = gom_serialization_test_book_register_to_string (b);
#line 1024 "GomSerializationTest.vala"
		_g_free0 (s);
#line 1024 "GomSerializationTest.vala"
		s = _tmp3_;
#line 1026 "GomSerializationTest.vala"
		_tmp4_ = s;
#line 1026 "GomSerializationTest.vala"
		_tmp5_ = g_strconcat ("doc:", _tmp4_, NULL);
#line 1026 "GomSerializationTest.vala"
		_tmp6_ = _tmp5_;
#line 1026 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1026: %s", _tmp6_);
#line 1026 "GomSerializationTest.vala"
		_g_free0 (_tmp6_);
#line 1028 "GomSerializationTest.vala"
		_tmp7_ = s;
#line 1028 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp7_, "<BookRegister Year=\"0\"><Book/></BookRegister>"), "\"<BookRegister Year=\\\"0\\\"><Book/></BookRegister>\" in s");
#line 1016 "GomSerializationTest.vala"
		_g_free0 (s);
#line 1016 "GomSerializationTest.vala"
		_g_object_unref0 (b);
#line 11123 "GomSerializationTest.c"
	}
	goto __finally185;
	__catch185_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
#line 1016 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 1016 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 1030 "GomSerializationTest.vala"
		_tmp8_ = e->message;
#line 1030 "GomSerializationTest.vala"
		_tmp9_ = g_strconcat ("Error: ", _tmp8_, NULL);
#line 1030 "GomSerializationTest.vala"
		_tmp10_ = _tmp9_;
#line 1030 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1030: %s", _tmp10_);
#line 1030 "GomSerializationTest.vala"
		_g_free0 (_tmp10_);
#line 1031 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 1016 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 11150 "GomSerializationTest.c"
	}
	__finally185:
#line 1016 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1016 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 1016 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 1016 "GomSerializationTest.vala"
		return;
#line 11161 "GomSerializationTest.c"
	}
}

static void
___lambda133__gtest_func (void)
{
#line 1015 "GomSerializationTest.vala"
	__lambda133_ ();
#line 11170 "GomSerializationTest.c"
}

static void
__lambda134_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GomSerializationTestMotor* m = NULL;
		GomSerializationTestMotor* _tmp0_;
		gchar* s = NULL;
		gchar* _tmp1_;
		const gchar* _tmp2_;
		GXmlXParser* parser = NULL;
		GXmlXParser* _tmp3_;
		gchar* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		const gchar* _tmp7_;
		const gchar* _tmp8_;
		const gchar* _tmp9_;
		const gchar* _tmp10_;
		const gchar* _tmp11_;
		GomSerializationTestMotorOn* _tmp12_;
		GomSerializationTestMotorOn* _tmp13_;
		GomSerializationTestMotorOn* _tmp14_;
		GomSerializationTestMotorOn* _tmp15_;
		GomSerializationTestMotorTorque* _tmp16_;
		GomSerializationTestMotorTorque* _tmp17_;
		GomSerializationTestMotorTorque* _tmp18_;
		GomSerializationTestMotorTorque* _tmp19_;
		GomSerializationTestMotorSpeed* _tmp20_;
		GomSerializationTestMotorSpeed* _tmp21_;
		GomSerializationTestMotorSpeed* _tmp22_;
		GomSerializationTestMotorSpeed* _tmp23_;
		GomSerializationTestMotorTension* _tmp24_;
		GomSerializationTestMotorTension* _tmp25_;
		GomSerializationTestMotorTension* _tmp26_;
		GomSerializationTestMotorTension* _tmp27_;
		GomSerializationTestMotorTensionType* _tmp28_;
		GomSerializationTestMotorTensionType* _tmp29_;
		GomSerializationTestMotorTensionType* _tmp30_;
		GomSerializationTestMotorTensionType* _tmp31_;
		gchar* _tmp32_;
		gchar* _tmp33_;
		gchar* _tmp34_;
#line 1036 "GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_motor_new ();
#line 1036 "GomSerializationTest.vala"
		m = _tmp0_;
#line 1037 "GomSerializationTest.vala"
		_tmp1_ = gom_serialization_test_motor_to_string (m);
#line 1037 "GomSerializationTest.vala"
		s = _tmp1_;
#line 1041 "GomSerializationTest.vala"
		_tmp2_ = s;
#line 1041 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp2_, "<Motor/>"), "\"<Motor/>\" in s");
#line 1042 "GomSerializationTest.vala"
		_tmp3_ = gxml_xparser_new ((GXmlDomNode*) m);
#line 1042 "GomSerializationTest.vala"
		parser = _tmp3_;
#line 1043 "GomSerializationTest.vala"
		gxml_parser_read_string ((GXmlParser*) parser, "<Motor On=\"true\" Torque=\"3.1416\" Speed=\"3600.1011\" TensionType=\"" \
"dc\" Tension=\"125\"/>", &_inner_error0_);
#line 1043 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1043 "GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1043 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1043 "GomSerializationTest.vala"
			_g_object_unref0 (m);
#line 11242 "GomSerializationTest.c"
			goto __catch186_g_error;
		}
#line 1044 "GomSerializationTest.vala"
		_tmp4_ = gom_serialization_test_motor_to_string (m);
#line 1044 "GomSerializationTest.vala"
		_g_free0 (s);
#line 1044 "GomSerializationTest.vala"
		s = _tmp4_;
#line 1048 "GomSerializationTest.vala"
		_tmp5_ = s;
#line 1048 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp5_, "<Motor "), "\"<Motor \" in s");
#line 1049 "GomSerializationTest.vala"
		_tmp6_ = s;
#line 1049 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp6_, "On=\"true\""), "\"On=\\\"true\\\"\" in s");
#line 1050 "GomSerializationTest.vala"
		_tmp7_ = s;
#line 1050 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp7_, "Torque=\"3.1416\""), "\"Torque=\\\"3.1416\\\"\" in s");
#line 1051 "GomSerializationTest.vala"
		_tmp8_ = s;
#line 1051 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp8_, "Speed=\"3600.1011\""), "\"Speed=\\\"3600.1011\\\"\" in s");
#line 1052 "GomSerializationTest.vala"
		_tmp9_ = s;
#line 1052 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp9_, "TensionType=\"dc\""), "\"TensionType=\\\"dc\\\"\" in s");
#line 1053 "GomSerializationTest.vala"
		_tmp10_ = s;
#line 1053 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp10_, "Tension=\"125\""), "\"Tension=\\\"125\\\"\" in s");
#line 1054 "GomSerializationTest.vala"
		_tmp11_ = s;
#line 1054 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp11_, "/>"), "\"/>\" in s");
#line 1055 "GomSerializationTest.vala"
		_tmp12_ = gom_serialization_test_motor_get_is_on (m);
#line 1055 "GomSerializationTest.vala"
		_tmp13_ = _tmp12_;
#line 1055 "GomSerializationTest.vala"
		_vala_assert (_tmp13_ != NULL, "m.is_on != null");
#line 1056 "GomSerializationTest.vala"
		_tmp14_ = gom_serialization_test_motor_get_is_on (m);
#line 1056 "GomSerializationTest.vala"
		_tmp15_ = _tmp14_;
#line 1056 "GomSerializationTest.vala"
		_vala_assert (gxml_gom_boolean_get_boolean ((GXmlGomBoolean*) _tmp15_) == TRUE, "m.is_on.get_boolean() == true");
#line 1057 "GomSerializationTest.vala"
		_tmp16_ = gom_serialization_test_motor_get_torque (m);
#line 1057 "GomSerializationTest.vala"
		_tmp17_ = _tmp16_;
#line 1057 "GomSerializationTest.vala"
		_vala_assert (_tmp17_ != NULL, "m.torque != null");
#line 1058 "GomSerializationTest.vala"
		_tmp18_ = gom_serialization_test_motor_get_torque (m);
#line 1058 "GomSerializationTest.vala"
		_tmp19_ = _tmp18_;
#line 1058 "GomSerializationTest.vala"
		_vala_assert (gxml_gom_double_get_double ((GXmlGomDouble*) _tmp19_) == 3.1416, "m.torque.get_double () == 3.1416");
#line 1059 "GomSerializationTest.vala"
		_tmp20_ = gom_serialization_test_motor_get_speed (m);
#line 1059 "GomSerializationTest.vala"
		_tmp21_ = _tmp20_;
#line 1059 "GomSerializationTest.vala"
		_vala_assert (_tmp21_ != NULL, "m.speed != null");
#line 1060 "GomSerializationTest.vala"
		_tmp22_ = gom_serialization_test_motor_get_speed (m);
#line 1060 "GomSerializationTest.vala"
		_tmp23_ = _tmp22_;
#line 1060 "GomSerializationTest.vala"
		_vala_assert (gxml_gom_double_get_double ((GXmlGomDouble*) _tmp23_) == 3600.1011, "m.speed.get_double () == 3600.1011");
#line 1061 "GomSerializationTest.vala"
		_tmp24_ = gom_serialization_test_motor_get_tension (m);
#line 1061 "GomSerializationTest.vala"
		_tmp25_ = _tmp24_;
#line 1061 "GomSerializationTest.vala"
		_vala_assert (_tmp25_ != NULL, "m.tension != null");
#line 1062 "GomSerializationTest.vala"
		_tmp26_ = gom_serialization_test_motor_get_tension (m);
#line 1062 "GomSerializationTest.vala"
		_tmp27_ = _tmp26_;
#line 1062 "GomSerializationTest.vala"
		_vala_assert (gxml_gom_int_get_integer ((GXmlGomInt*) _tmp27_) == 125, "m.tension.get_integer () == 125");
#line 1063 "GomSerializationTest.vala"
		_tmp28_ = gom_serialization_test_motor_get_tension_type (m);
#line 1063 "GomSerializationTest.vala"
		_tmp29_ = _tmp28_;
#line 1063 "GomSerializationTest.vala"
		_vala_assert (_tmp29_ != NULL, "m.tension_type != null");
#line 1064 "GomSerializationTest.vala"
		_tmp30_ = gom_serialization_test_motor_get_tension_type (m);
#line 1064 "GomSerializationTest.vala"
		_tmp31_ = _tmp30_;
#line 1064 "GomSerializationTest.vala"
		_tmp32_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp31_);
#line 1064 "GomSerializationTest.vala"
		_tmp33_ = _tmp32_;
#line 1064 "GomSerializationTest.vala"
		_tmp34_ = _tmp33_;
#line 1064 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "dc") == 0, "m.tension_type.value == \"dc\"");
#line 1064 "GomSerializationTest.vala"
		_g_free0 (_tmp34_);
#line 1035 "GomSerializationTest.vala"
		_g_object_unref0 (parser);
#line 1035 "GomSerializationTest.vala"
		_g_free0 (s);
#line 1035 "GomSerializationTest.vala"
		_g_object_unref0 (m);
#line 11353 "GomSerializationTest.c"
	}
	goto __finally186;
	__catch186_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp35_;
		gchar* _tmp36_;
		gchar* _tmp37_;
#line 1035 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 1035 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 1066 "GomSerializationTest.vala"
		_tmp35_ = e->message;
#line 1066 "GomSerializationTest.vala"
		_tmp36_ = g_strconcat ("Error: ", _tmp35_, NULL);
#line 1066 "GomSerializationTest.vala"
		_tmp37_ = _tmp36_;
#line 1066 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1066: %s", _tmp37_);
#line 1066 "GomSerializationTest.vala"
		_g_free0 (_tmp37_);
#line 1067 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 1035 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 11380 "GomSerializationTest.c"
	}
	__finally186:
#line 1035 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1035 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 1035 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 1035 "GomSerializationTest.vala"
		return;
#line 11391 "GomSerializationTest.c"
	}
}

static void
___lambda134__gtest_func (void)
{
#line 1034 "GomSerializationTest.vala"
	__lambda134_ ();
#line 11400 "GomSerializationTest.c"
}

static void
__lambda135_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GomSerializationTestBookStand* bs = NULL;
		GomSerializationTestBookStand* _tmp0_;
		gchar* s = NULL;
		GomSerializationTestBookStand* _tmp1_;
		gchar* _tmp2_;
		const gchar* _tmp3_;
		GXmlXParser* parser = NULL;
		GomSerializationTestBookStand* _tmp4_;
		GXmlXParser* _tmp5_;
		GXmlXParser* _tmp6_;
		GomSerializationTestBookStand* _tmp7_;
		gchar* _tmp8_;
		GomSerializationTestBookStand* _tmp9_;
		GomSerializationTestRegisters* _tmp10_;
		GomSerializationTestRegisters* _tmp11_;
		GomSerializationTestBookStand* _tmp12_;
		GomSerializationTestRegisters* _tmp13_;
		GomSerializationTestRegisters* _tmp14_;
		gint _tmp15_;
		gint _tmp16_;
		GomSerializationTestBookStand* _tmp17_;
		GomSerializationTestRegisters* _tmp18_;
		GomSerializationTestRegisters* _tmp19_;
		GQueue* _tmp20_;
		GQueue* _tmp21_;
		gconstpointer _tmp22_;
		GomSerializationTestBookStand* _tmp23_;
		GomSerializationTestRegisters* _tmp24_;
		GomSerializationTestRegisters* _tmp25_;
		GQueue* _tmp26_;
		GQueue* _tmp27_;
		gconstpointer _tmp28_;
		GomSerializationTestBookStand* _tmp29_;
		GomSerializationTestRegisters* _tmp30_;
		GomSerializationTestRegisters* _tmp31_;
		GQueue* _tmp32_;
		GQueue* _tmp33_;
		gconstpointer _tmp34_;
		GXmlDomElement* _tmp35_ = NULL;
		GomSerializationTestBookStand* _tmp36_;
		GomSerializationTestRegisters* _tmp37_;
		GomSerializationTestRegisters* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomElement* _tmp40_ = NULL;
		GomSerializationTestBookStand* _tmp41_;
		GomSerializationTestRegisters* _tmp42_;
		GomSerializationTestRegisters* _tmp43_;
		GXmlDomElement* _tmp44_;
		GXmlDomElement* _tmp45_ = NULL;
		GomSerializationTestBookStand* _tmp46_;
		GomSerializationTestRegisters* _tmp47_;
		GomSerializationTestRegisters* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_ = NULL;
		GomSerializationTestBookStand* _tmp51_;
		GomSerializationTestRegisters* _tmp52_;
		GomSerializationTestRegisters* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_ = NULL;
		GomSerializationTestBookStand* _tmp56_;
		GomSerializationTestRegisters* _tmp57_;
		GomSerializationTestRegisters* _tmp58_;
		GXmlDomElement* _tmp59_;
		GXmlDomElement* _tmp60_ = NULL;
		GomSerializationTestBookStand* _tmp61_;
		GomSerializationTestRegisters* _tmp62_;
		GomSerializationTestRegisters* _tmp63_;
		GXmlDomElement* _tmp64_;
		GXmlDomElement* _tmp65_ = NULL;
		GomSerializationTestBookStand* _tmp66_;
		GomSerializationTestRegisters* _tmp67_;
		GomSerializationTestRegisters* _tmp68_;
		GXmlDomElement* _tmp69_;
		GXmlDomElement* _tmp70_ = NULL;
		GomSerializationTestBookStand* _tmp71_;
		GomSerializationTestRegisters* _tmp72_;
		GomSerializationTestRegisters* _tmp73_;
		GXmlDomElement* _tmp74_;
		GXmlDomElement* _tmp75_ = NULL;
		GomSerializationTestBookStand* _tmp76_;
		GomSerializationTestRegisters* _tmp77_;
		GomSerializationTestRegisters* _tmp78_;
		GXmlDomElement* _tmp79_;
		GXmlDomElement* _tmp80_ = NULL;
		GomSerializationTestBookStand* _tmp81_;
		GomSerializationTestRegisters* _tmp82_;
		GomSerializationTestRegisters* _tmp83_;
		GXmlDomElement* _tmp84_;
		gint _tmp85_;
		gint _tmp86_;
		GXmlDomElement* _tmp87_ = NULL;
		GomSerializationTestBookStand* _tmp88_;
		GomSerializationTestRegisters* _tmp89_;
		GomSerializationTestRegisters* _tmp90_;
		GXmlDomElement* _tmp91_;
		gint _tmp92_;
		gint _tmp93_;
		GXmlDomElement* _tmp94_ = NULL;
		GomSerializationTestBookStand* _tmp95_;
		GomSerializationTestRegisters* _tmp96_;
		GomSerializationTestRegisters* _tmp97_;
		GXmlDomElement* _tmp98_;
		gint _tmp99_;
		gint _tmp100_;
#line 1072 "GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_book_stand_new ();
#line 1072 "GomSerializationTest.vala"
		bs = _tmp0_;
#line 1073 "GomSerializationTest.vala"
		_tmp1_ = bs;
#line 1073 "GomSerializationTest.vala"
		_tmp2_ = gom_serialization_test_book_stand_to_string (_tmp1_);
#line 1073 "GomSerializationTest.vala"
		s = _tmp2_;
#line 1077 "GomSerializationTest.vala"
		_tmp3_ = s;
#line 1077 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp3_, "<BookStand Classification=\"Science\"/>"), "\"<BookStand Classification=\\\"Science\\\"/>\" in s");
#line 1078 "GomSerializationTest.vala"
		_tmp4_ = bs;
#line 1078 "GomSerializationTest.vala"
		_tmp5_ = gxml_xparser_new ((GXmlDomNode*) _tmp4_);
#line 1078 "GomSerializationTest.vala"
		parser = _tmp5_;
#line 1079 "GomSerializationTest.vala"
		_tmp6_ = parser;
#line 1079 "GomSerializationTest.vala"
		gxml_parser_read_string ((GXmlParser*) _tmp6_, "<BookStand Classification=\"Science\"><BookRegister Year=\"2016\"/><Bo" \
"okRegister Year=\"2010\"/><Test/><BookRegister Year=\"2000\"/></BookSt" \
"and>", &_inner_error0_);
#line 1079 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1079 "GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1079 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1079 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11544 "GomSerializationTest.c"
			goto __catch187_g_error;
		}
#line 1080 "GomSerializationTest.vala"
		_tmp7_ = bs;
#line 1080 "GomSerializationTest.vala"
		_tmp8_ = gom_serialization_test_book_stand_to_string (_tmp7_);
#line 1080 "GomSerializationTest.vala"
		_g_free0 (s);
#line 1080 "GomSerializationTest.vala"
		s = _tmp8_;
#line 1085 "GomSerializationTest.vala"
		_tmp9_ = bs;
#line 1085 "GomSerializationTest.vala"
		_tmp10_ = gom_serialization_test_book_stand_get_registers (_tmp9_);
#line 1085 "GomSerializationTest.vala"
		_tmp11_ = _tmp10_;
#line 1085 "GomSerializationTest.vala"
		_vala_assert (_tmp11_ != NULL, "bs.registers != null");
#line 1086 "GomSerializationTest.vala"
		_tmp12_ = bs;
#line 1086 "GomSerializationTest.vala"
		_tmp13_ = gom_serialization_test_book_stand_get_registers (_tmp12_);
#line 1086 "GomSerializationTest.vala"
		_tmp14_ = _tmp13_;
#line 1086 "GomSerializationTest.vala"
		_tmp15_ = gxml_collection_get_length ((GXmlCollection*) _tmp14_);
#line 1086 "GomSerializationTest.vala"
		_tmp16_ = _tmp15_;
#line 1086 "GomSerializationTest.vala"
		_vala_assert (_tmp16_ == 3, "bs.registers.length == 3");
#line 1087 "GomSerializationTest.vala"
		_tmp17_ = bs;
#line 1087 "GomSerializationTest.vala"
		_tmp18_ = gom_serialization_test_book_stand_get_registers (_tmp17_);
#line 1087 "GomSerializationTest.vala"
		_tmp19_ = _tmp18_;
#line 1087 "GomSerializationTest.vala"
		_tmp20_ = gxml_collection_get_nodes_index ((GXmlCollection*) _tmp19_);
#line 1087 "GomSerializationTest.vala"
		_tmp21_ = _tmp20_;
#line 1087 "GomSerializationTest.vala"
		_tmp22_ = g_queue_peek_nth (_tmp21_, (guint) 0);
#line 1087 "GomSerializationTest.vala"
		_vala_assert (((gint) ((gintptr) _tmp22_)) == 0, "bs.registers.nodes_index.peek_nth (0) == 0");
#line 1088 "GomSerializationTest.vala"
		_tmp23_ = bs;
#line 1088 "GomSerializationTest.vala"
		_tmp24_ = gom_serialization_test_book_stand_get_registers (_tmp23_);
#line 1088 "GomSerializationTest.vala"
		_tmp25_ = _tmp24_;
#line 1088 "GomSerializationTest.vala"
		_tmp26_ = gxml_collection_get_nodes_index ((GXmlCollection*) _tmp25_);
#line 1088 "GomSerializationTest.vala"
		_tmp27_ = _tmp26_;
#line 1088 "GomSerializationTest.vala"
		_tmp28_ = g_queue_peek_nth (_tmp27_, (guint) 1);
#line 1088 "GomSerializationTest.vala"
		_vala_assert (((gint) ((gintptr) _tmp28_)) == 1, "bs.registers.nodes_index.peek_nth (1) == 1");
#line 1089 "GomSerializationTest.vala"
		_tmp29_ = bs;
#line 1089 "GomSerializationTest.vala"
		_tmp30_ = gom_serialization_test_book_stand_get_registers (_tmp29_);
#line 1089 "GomSerializationTest.vala"
		_tmp31_ = _tmp30_;
#line 1089 "GomSerializationTest.vala"
		_tmp32_ = gxml_collection_get_nodes_index ((GXmlCollection*) _tmp31_);
#line 1089 "GomSerializationTest.vala"
		_tmp33_ = _tmp32_;
#line 1089 "GomSerializationTest.vala"
		_tmp34_ = g_queue_peek_nth (_tmp33_, (guint) 2);
#line 1089 "GomSerializationTest.vala"
		_vala_assert (((gint) ((gintptr) _tmp34_)) == 3, "bs.registers.nodes_index.peek_nth (2) == 3");
#line 1090 "GomSerializationTest.vala"
		_tmp36_ = bs;
#line 1090 "GomSerializationTest.vala"
		_tmp37_ = gom_serialization_test_book_stand_get_registers (_tmp36_);
#line 1090 "GomSerializationTest.vala"
		_tmp38_ = _tmp37_;
#line 1090 "GomSerializationTest.vala"
		_tmp39_ = gxml_collection_get_item ((GXmlCollection*) _tmp38_, 0, &_inner_error0_);
#line 1090 "GomSerializationTest.vala"
		_tmp35_ = _tmp39_;
#line 1090 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1090 "GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1090 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1090 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11635 "GomSerializationTest.c"
			goto __catch187_g_error;
		}
#line 1090 "GomSerializationTest.vala"
		_vala_assert (_tmp35_ != NULL, "bs.registers.get_item (0) != null");
#line 1091 "GomSerializationTest.vala"
		_tmp41_ = bs;
#line 1091 "GomSerializationTest.vala"
		_tmp42_ = gom_serialization_test_book_stand_get_registers (_tmp41_);
#line 1091 "GomSerializationTest.vala"
		_tmp43_ = _tmp42_;
#line 1091 "GomSerializationTest.vala"
		_tmp44_ = gxml_collection_get_item ((GXmlCollection*) _tmp43_, 0, &_inner_error0_);
#line 1091 "GomSerializationTest.vala"
		_tmp40_ = _tmp44_;
#line 1091 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1091 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp35_);
#line 1091 "GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1091 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1091 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11660 "GomSerializationTest.c"
			goto __catch187_g_error;
		}
#line 1091 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp40_, GXML_TYPE_DOM_ELEMENT), "bs.registers.get_item (0) is DomElement");
#line 1092 "GomSerializationTest.vala"
		_tmp46_ = bs;
#line 1092 "GomSerializationTest.vala"
		_tmp47_ = gom_serialization_test_book_stand_get_registers (_tmp46_);
#line 1092 "GomSerializationTest.vala"
		_tmp48_ = _tmp47_;
#line 1092 "GomSerializationTest.vala"
		_tmp49_ = gxml_collection_get_item ((GXmlCollection*) _tmp48_, 0, &_inner_error0_);
#line 1092 "GomSerializationTest.vala"
		_tmp45_ = _tmp49_;
#line 1092 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1092 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp40_);
#line 1092 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp35_);
#line 1092 "GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1092 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1092 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11687 "GomSerializationTest.c"
			goto __catch187_g_error;
		}
#line 1092 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp45_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER), "bs.registers.get_item (0) is BookRegister");
#line 1093 "GomSerializationTest.vala"
		_tmp51_ = bs;
#line 1093 "GomSerializationTest.vala"
		_tmp52_ = gom_serialization_test_book_stand_get_registers (_tmp51_);
#line 1093 "GomSerializationTest.vala"
		_tmp53_ = _tmp52_;
#line 1093 "GomSerializationTest.vala"
		_tmp54_ = gxml_collection_get_item ((GXmlCollection*) _tmp53_, 1, &_inner_error0_);
#line 1093 "GomSerializationTest.vala"
		_tmp50_ = _tmp54_;
#line 1093 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1093 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 1093 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp40_);
#line 1093 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp35_);
#line 1093 "GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1093 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1093 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11716 "GomSerializationTest.c"
			goto __catch187_g_error;
		}
#line 1093 "GomSerializationTest.vala"
		_vala_assert (_tmp50_ != NULL, "bs.registers.get_item (1) != null");
#line 1094 "GomSerializationTest.vala"
		_tmp56_ = bs;
#line 1094 "GomSerializationTest.vala"
		_tmp57_ = gom_serialization_test_book_stand_get_registers (_tmp56_);
#line 1094 "GomSerializationTest.vala"
		_tmp58_ = _tmp57_;
#line 1094 "GomSerializationTest.vala"
		_tmp59_ = gxml_collection_get_item ((GXmlCollection*) _tmp58_, 1, &_inner_error0_);
#line 1094 "GomSerializationTest.vala"
		_tmp55_ = _tmp59_;
#line 1094 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1094 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp50_);
#line 1094 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 1094 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp40_);
#line 1094 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp35_);
#line 1094 "GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1094 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1094 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11747 "GomSerializationTest.c"
			goto __catch187_g_error;
		}
#line 1094 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp55_, GXML_TYPE_DOM_ELEMENT), "bs.registers.get_item (1) is DomElement");
#line 1095 "GomSerializationTest.vala"
		_tmp61_ = bs;
#line 1095 "GomSerializationTest.vala"
		_tmp62_ = gom_serialization_test_book_stand_get_registers (_tmp61_);
#line 1095 "GomSerializationTest.vala"
		_tmp63_ = _tmp62_;
#line 1095 "GomSerializationTest.vala"
		_tmp64_ = gxml_collection_get_item ((GXmlCollection*) _tmp63_, 1, &_inner_error0_);
#line 1095 "GomSerializationTest.vala"
		_tmp60_ = _tmp64_;
#line 1095 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1095 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp55_);
#line 1095 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp50_);
#line 1095 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 1095 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp40_);
#line 1095 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp35_);
#line 1095 "GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1095 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1095 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11780 "GomSerializationTest.c"
			goto __catch187_g_error;
		}
#line 1095 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp60_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER), "bs.registers.get_item (1) is BookRegister");
#line 1096 "GomSerializationTest.vala"
		_tmp66_ = bs;
#line 1096 "GomSerializationTest.vala"
		_tmp67_ = gom_serialization_test_book_stand_get_registers (_tmp66_);
#line 1096 "GomSerializationTest.vala"
		_tmp68_ = _tmp67_;
#line 1096 "GomSerializationTest.vala"
		_tmp69_ = gxml_collection_get_item ((GXmlCollection*) _tmp68_, 2, &_inner_error0_);
#line 1096 "GomSerializationTest.vala"
		_tmp65_ = _tmp69_;
#line 1096 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1096 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp60_);
#line 1096 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp55_);
#line 1096 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp50_);
#line 1096 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 1096 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp40_);
#line 1096 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp35_);
#line 1096 "GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1096 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1096 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11815 "GomSerializationTest.c"
			goto __catch187_g_error;
		}
#line 1096 "GomSerializationTest.vala"
		_vala_assert (_tmp65_ != NULL, "bs.registers.get_item (2) != null");
#line 1097 "GomSerializationTest.vala"
		_tmp71_ = bs;
#line 1097 "GomSerializationTest.vala"
		_tmp72_ = gom_serialization_test_book_stand_get_registers (_tmp71_);
#line 1097 "GomSerializationTest.vala"
		_tmp73_ = _tmp72_;
#line 1097 "GomSerializationTest.vala"
		_tmp74_ = gxml_collection_get_item ((GXmlCollection*) _tmp73_, 2, &_inner_error0_);
#line 1097 "GomSerializationTest.vala"
		_tmp70_ = _tmp74_;
#line 1097 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1097 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp65_);
#line 1097 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp60_);
#line 1097 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp55_);
#line 1097 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp50_);
#line 1097 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 1097 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp40_);
#line 1097 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp35_);
#line 1097 "GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1097 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1097 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11852 "GomSerializationTest.c"
			goto __catch187_g_error;
		}
#line 1097 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp70_, GXML_TYPE_DOM_ELEMENT), "bs.registers.get_item (2) is DomElement");
#line 1098 "GomSerializationTest.vala"
		_tmp76_ = bs;
#line 1098 "GomSerializationTest.vala"
		_tmp77_ = gom_serialization_test_book_stand_get_registers (_tmp76_);
#line 1098 "GomSerializationTest.vala"
		_tmp78_ = _tmp77_;
#line 1098 "GomSerializationTest.vala"
		_tmp79_ = gxml_collection_get_item ((GXmlCollection*) _tmp78_, 2, &_inner_error0_);
#line 1098 "GomSerializationTest.vala"
		_tmp75_ = _tmp79_;
#line 1098 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1098 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp70_);
#line 1098 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp65_);
#line 1098 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp60_);
#line 1098 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp55_);
#line 1098 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp50_);
#line 1098 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 1098 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp40_);
#line 1098 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp35_);
#line 1098 "GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1098 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1098 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11891 "GomSerializationTest.c"
			goto __catch187_g_error;
		}
#line 1098 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp75_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER), "bs.registers.get_item (2) is BookRegister");
#line 1099 "GomSerializationTest.vala"
		_tmp81_ = bs;
#line 1099 "GomSerializationTest.vala"
		_tmp82_ = gom_serialization_test_book_stand_get_registers (_tmp81_);
#line 1099 "GomSerializationTest.vala"
		_tmp83_ = _tmp82_;
#line 1099 "GomSerializationTest.vala"
		_tmp84_ = gxml_collection_get_item ((GXmlCollection*) _tmp83_, 0, &_inner_error0_);
#line 1099 "GomSerializationTest.vala"
		_tmp80_ = _tmp84_;
#line 1099 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1099 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp75_);
#line 1099 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp70_);
#line 1099 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp65_);
#line 1099 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp60_);
#line 1099 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp55_);
#line 1099 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp50_);
#line 1099 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 1099 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp40_);
#line 1099 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp35_);
#line 1099 "GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1099 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1099 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11932 "GomSerializationTest.c"
			goto __catch187_g_error;
		}
#line 1099 "GomSerializationTest.vala"
		_tmp85_ = gom_serialization_test_book_register_get_year (G_TYPE_CHECK_INSTANCE_TYPE (_tmp80_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp80_) : NULL);
#line 1099 "GomSerializationTest.vala"
		_tmp86_ = _tmp85_;
#line 1099 "GomSerializationTest.vala"
		_vala_assert (_tmp86_ == 2016, "(bs.registers.get_item (0) as BookRegister).year == 2016");
#line 1100 "GomSerializationTest.vala"
		_tmp88_ = bs;
#line 1100 "GomSerializationTest.vala"
		_tmp89_ = gom_serialization_test_book_stand_get_registers (_tmp88_);
#line 1100 "GomSerializationTest.vala"
		_tmp90_ = _tmp89_;
#line 1100 "GomSerializationTest.vala"
		_tmp91_ = gxml_collection_get_item ((GXmlCollection*) _tmp90_, 1, &_inner_error0_);
#line 1100 "GomSerializationTest.vala"
		_tmp87_ = _tmp91_;
#line 1100 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1100 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp80_);
#line 1100 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp75_);
#line 1100 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp70_);
#line 1100 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp65_);
#line 1100 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp60_);
#line 1100 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp55_);
#line 1100 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp50_);
#line 1100 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 1100 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp40_);
#line 1100 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp35_);
#line 1100 "GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1100 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1100 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11979 "GomSerializationTest.c"
			goto __catch187_g_error;
		}
#line 1100 "GomSerializationTest.vala"
		_tmp92_ = gom_serialization_test_book_register_get_year (G_TYPE_CHECK_INSTANCE_TYPE (_tmp87_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp87_) : NULL);
#line 1100 "GomSerializationTest.vala"
		_tmp93_ = _tmp92_;
#line 1100 "GomSerializationTest.vala"
		_vala_assert (_tmp93_ == 2010, "(bs.registers.get_item (1) as BookRegister).year == 2010");
#line 1101 "GomSerializationTest.vala"
		_tmp95_ = bs;
#line 1101 "GomSerializationTest.vala"
		_tmp96_ = gom_serialization_test_book_stand_get_registers (_tmp95_);
#line 1101 "GomSerializationTest.vala"
		_tmp97_ = _tmp96_;
#line 1101 "GomSerializationTest.vala"
		_tmp98_ = gxml_collection_get_item ((GXmlCollection*) _tmp97_, 2, &_inner_error0_);
#line 1101 "GomSerializationTest.vala"
		_tmp94_ = _tmp98_;
#line 1101 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1101 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp87_);
#line 1101 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp80_);
#line 1101 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp75_);
#line 1101 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp70_);
#line 1101 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp65_);
#line 1101 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp60_);
#line 1101 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp55_);
#line 1101 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp50_);
#line 1101 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 1101 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp40_);
#line 1101 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp35_);
#line 1101 "GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1101 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1101 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 12028 "GomSerializationTest.c"
			goto __catch187_g_error;
		}
#line 1101 "GomSerializationTest.vala"
		_tmp99_ = gom_serialization_test_book_register_get_year (G_TYPE_CHECK_INSTANCE_TYPE (_tmp94_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp94_) : NULL);
#line 1101 "GomSerializationTest.vala"
		_tmp100_ = _tmp99_;
#line 1101 "GomSerializationTest.vala"
		_vala_assert (_tmp100_ == 2000, "(bs.registers.get_item (2) as BookRegister).year == 2000");
#line 1071 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp94_);
#line 1071 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp87_);
#line 1071 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp80_);
#line 1071 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp75_);
#line 1071 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp70_);
#line 1071 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp65_);
#line 1071 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp60_);
#line 1071 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp55_);
#line 1071 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp50_);
#line 1071 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp45_);
#line 1071 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp40_);
#line 1071 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp35_);
#line 1071 "GomSerializationTest.vala"
		_g_object_unref0 (parser);
#line 1071 "GomSerializationTest.vala"
		_g_free0 (s);
#line 1071 "GomSerializationTest.vala"
		_g_object_unref0 (bs);
#line 12067 "GomSerializationTest.c"
	}
	goto __finally187;
	__catch187_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp101_;
		gchar* _tmp102_;
		gchar* _tmp103_;
#line 1071 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 1071 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 1103 "GomSerializationTest.vala"
		_tmp101_ = e->message;
#line 1103 "GomSerializationTest.vala"
		_tmp102_ = g_strconcat ("Error: ", _tmp101_, NULL);
#line 1103 "GomSerializationTest.vala"
		_tmp103_ = _tmp102_;
#line 1103 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1103: %s", _tmp103_);
#line 1103 "GomSerializationTest.vala"
		_g_free0 (_tmp103_);
#line 1104 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 1071 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 12094 "GomSerializationTest.c"
	}
	__finally187:
#line 1071 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1071 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 1071 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 1071 "GomSerializationTest.vala"
		return;
#line 12105 "GomSerializationTest.c"
	}
}

static void
___lambda135__gtest_func (void)
{
#line 1070 "GomSerializationTest.vala"
	__lambda135_ ();
#line 12114 "GomSerializationTest.c"
}

static void
__lambda136_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GomSerializationTestBookStand* bs = NULL;
		GomSerializationTestBookStand* _tmp0_;
		gchar* s = NULL;
		GomSerializationTestBookStand* _tmp1_;
		gchar* _tmp2_;
		const gchar* _tmp3_;
		GomSerializationTestBookStand* _tmp4_;
		GomSerializationTestBookStand* _tmp5_;
		GomSerializationTestBooks* _tmp6_;
		GomSerializationTestBooks* _tmp7_;
		GomSerializationTestBookStand* _tmp8_;
		gchar* _tmp9_;
		const gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		GomSerializationTestBookStand* _tmp13_;
		GomSerializationTestBooks* _tmp14_;
		GomSerializationTestBooks* _tmp15_;
		gint _tmp16_;
		gint _tmp17_;
		gchar* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		GomSerializationTestBookStand* _tmp22_;
		GomSerializationTestBooks* _tmp23_;
		GomSerializationTestBooks* _tmp24_;
		gint _tmp25_;
		gint _tmp26_;
		GomSerializationTestBookStand* _tmp27_;
		GomSerializationTestBooks* _tmp28_;
		GomSerializationTestBooks* _tmp29_;
		GQueue* _tmp30_;
		GQueue* _tmp31_;
		gconstpointer _tmp32_;
		GomSerializationTestBookStand* _tmp33_;
		GomSerializationTestBooks* _tmp34_;
		GomSerializationTestBooks* _tmp35_;
		GQueue* _tmp36_;
		GQueue* _tmp37_;
		gconstpointer _tmp38_;
		GomSerializationTestBookStand* _tmp39_;
		GomSerializationTestBooks* _tmp40_;
		GomSerializationTestBooks* _tmp41_;
		GQueue* _tmp42_;
		GQueue* _tmp43_;
		gconstpointer _tmp44_;
		GXmlDomElement* _tmp45_ = NULL;
		GomSerializationTestBookStand* _tmp46_;
		GomSerializationTestBooks* _tmp47_;
		GomSerializationTestBooks* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_ = NULL;
		GomSerializationTestBookStand* _tmp51_;
		GomSerializationTestBooks* _tmp52_;
		GomSerializationTestBooks* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_ = NULL;
		GomSerializationTestBookStand* _tmp56_;
		GomSerializationTestBooks* _tmp57_;
		GomSerializationTestBooks* _tmp58_;
		GXmlDomElement* _tmp59_;
		GXmlDomElement* _tmp60_ = NULL;
		GomSerializationTestBookStand* _tmp61_;
		GomSerializationTestBooks* _tmp62_;
		GomSerializationTestBooks* _tmp63_;
		GXmlDomElement* _tmp64_;
		GXmlDomElement* _tmp65_ = NULL;
		GomSerializationTestBookStand* _tmp66_;
		GomSerializationTestBooks* _tmp67_;
		GomSerializationTestBooks* _tmp68_;
		GXmlDomElement* _tmp69_;
		GXmlDomElement* _tmp70_ = NULL;
		GomSerializationTestBookStand* _tmp71_;
		GomSerializationTestBooks* _tmp72_;
		GomSerializationTestBooks* _tmp73_;
		GXmlDomElement* _tmp74_;
		GXmlDomElement* _tmp75_ = NULL;
		GomSerializationTestBookStand* _tmp76_;
		GomSerializationTestBooks* _tmp77_;
		GomSerializationTestBooks* _tmp78_;
		GXmlDomElement* _tmp79_;
		GXmlDomElement* _tmp80_ = NULL;
		GomSerializationTestBookStand* _tmp81_;
		GomSerializationTestBooks* _tmp82_;
		GomSerializationTestBooks* _tmp83_;
		GXmlDomElement* _tmp84_;
		GXmlDomElement* _tmp85_ = NULL;
		GomSerializationTestBookStand* _tmp86_;
		GomSerializationTestBooks* _tmp87_;
		GomSerializationTestBooks* _tmp88_;
		GXmlDomElement* _tmp89_;
		GXmlDomElement* _tmp90_ = NULL;
		GomSerializationTestBookStand* _tmp91_;
		GomSerializationTestBooks* _tmp92_;
		GomSerializationTestBooks* _tmp93_;
		GXmlDomElement* _tmp94_;
		const gchar* _tmp95_;
		const gchar* _tmp96_;
		GXmlDomElement* _tmp97_ = NULL;
		GomSerializationTestBookStand* _tmp98_;
		GomSerializationTestBooks* _tmp99_;
		GomSerializationTestBooks* _tmp100_;
		GXmlDomElement* _tmp101_;
		const gchar* _tmp102_;
		const gchar* _tmp103_;
		GXmlDomElement* _tmp104_ = NULL;
		GomSerializationTestBookStand* _tmp105_;
		GomSerializationTestBooks* _tmp106_;
		GomSerializationTestBooks* _tmp107_;
		GXmlDomElement* _tmp108_;
		const gchar* _tmp109_;
		const gchar* _tmp110_;
		GomSerializationTestBookStand* _tmp111_;
		GomSerializationTestBooks* _tmp112_;
		GomSerializationTestBooks* _tmp113_;
		GXmlDomElement* _tmp114_;
		GXmlDomElement* _tmp115_;
		GomSerializationTestBookStand* _tmp116_;
		GomSerializationTestBooks* _tmp117_;
		GomSerializationTestBooks* _tmp118_;
		GXmlDomElement* _tmp119_;
		GXmlDomElement* _tmp120_;
		GomSerializationTestBookStand* _tmp121_;
		GomSerializationTestBooks* _tmp122_;
		GomSerializationTestBooks* _tmp123_;
		GXmlDomElement* _tmp124_;
		GXmlDomElement* _tmp125_;
		GomSerializationTestBookStand* _tmp126_;
		GomSerializationTestBooks* _tmp127_;
		GomSerializationTestBooks* _tmp128_;
		GXmlDomElement* _tmp129_;
		GXmlDomElement* _tmp130_;
		GomSerializationTestBookStand* _tmp131_;
		GomSerializationTestBooks* _tmp132_;
		GomSerializationTestBooks* _tmp133_;
		GXmlDomElement* _tmp134_;
		GXmlDomElement* _tmp135_;
		GomSerializationTestBookStand* _tmp136_;
		GomSerializationTestBooks* _tmp137_;
		GomSerializationTestBooks* _tmp138_;
		GXmlDomElement* _tmp139_;
		GXmlDomElement* _tmp140_;
		GomSerializationTestBookStand* _tmp141_;
		GomSerializationTestBooks* _tmp142_;
		GomSerializationTestBooks* _tmp143_;
		GXmlDomElement* _tmp144_;
		GXmlDomElement* _tmp145_;
		GomSerializationTestBookStand* _tmp146_;
		GomSerializationTestBooks* _tmp147_;
		GomSerializationTestBooks* _tmp148_;
		GXmlDomElement* _tmp149_;
		GXmlDomElement* _tmp150_;
		GomSerializationTestBookStand* _tmp151_;
		GomSerializationTestBooks* _tmp152_;
		GomSerializationTestBooks* _tmp153_;
		GXmlDomElement* _tmp154_;
		GXmlDomElement* _tmp155_;
		GomSerializationTestBookStand* _tmp156_;
		GomSerializationTestBooks* _tmp157_;
		GomSerializationTestBooks* _tmp158_;
		GXmlDomElement* _tmp159_;
		GXmlDomElement* _tmp160_;
#line 1109 "GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_book_stand_new ();
#line 1109 "GomSerializationTest.vala"
		bs = _tmp0_;
#line 1110 "GomSerializationTest.vala"
		_tmp1_ = bs;
#line 1110 "GomSerializationTest.vala"
		_tmp2_ = gom_serialization_test_book_stand_to_string (_tmp1_);
#line 1110 "GomSerializationTest.vala"
		s = _tmp2_;
#line 1114 "GomSerializationTest.vala"
		_tmp3_ = s;
#line 1114 "GomSerializationTest.vala"
		_vala_assert (string_contains (_tmp3_, "<BookStand Classification=\"Science\"/>"), "\"<BookStand Classification=\\\"Science\\\"/>\" in s");
#line 1115 "GomSerializationTest.vala"
		_tmp4_ = bs;
#line 1115 "GomSerializationTest.vala"
		gxml_dom_element_read_from_string ((GXmlDomElement*) _tmp4_, "<bookStand Classification=\"Science\"><book name=\"Title1\"/><book nam" \
"e=\"Title2\"/><Test/><book name=\"Title3\"/></bookStand>", NULL, &_inner_error0_);
#line 1115 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1115 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1115 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 12309 "GomSerializationTest.c"
			goto __catch188_g_error;
		}
#line 1117 "GomSerializationTest.vala"
		_tmp5_ = bs;
#line 1117 "GomSerializationTest.vala"
		_tmp6_ = gom_serialization_test_book_stand_get_books (_tmp5_);
#line 1117 "GomSerializationTest.vala"
		_tmp7_ = _tmp6_;
#line 1117 "GomSerializationTest.vala"
		_vala_assert (_tmp7_ != NULL, "bs.books != null");
#line 1118 "GomSerializationTest.vala"
		_tmp8_ = bs;
#line 1118 "GomSerializationTest.vala"
		_tmp9_ = gom_serialization_test_book_stand_to_string (_tmp8_);
#line 1118 "GomSerializationTest.vala"
		_g_free0 (s);
#line 1118 "GomSerializationTest.vala"
		s = _tmp9_;
#line 1119 "GomSerializationTest.vala"
		_tmp10_ = s;
#line 1119 "GomSerializationTest.vala"
		_tmp11_ = g_strconcat ("doc:", _tmp10_, NULL);
#line 1119 "GomSerializationTest.vala"
		_tmp12_ = _tmp11_;
#line 1119 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1119: %s", _tmp12_);
#line 1119 "GomSerializationTest.vala"
		_g_free0 (_tmp12_);
#line 1120 "GomSerializationTest.vala"
		_tmp13_ = bs;
#line 1120 "GomSerializationTest.vala"
		_tmp14_ = gom_serialization_test_book_stand_get_books (_tmp13_);
#line 1120 "GomSerializationTest.vala"
		_tmp15_ = _tmp14_;
#line 1120 "GomSerializationTest.vala"
		_tmp16_ = gxml_collection_get_length ((GXmlCollection*) _tmp15_);
#line 1120 "GomSerializationTest.vala"
		_tmp17_ = _tmp16_;
#line 1120 "GomSerializationTest.vala"
		_tmp18_ = g_strdup_printf ("%i", _tmp17_);
#line 1120 "GomSerializationTest.vala"
		_tmp19_ = _tmp18_;
#line 1120 "GomSerializationTest.vala"
		_tmp20_ = g_strconcat ("Books: ", _tmp19_, NULL);
#line 1120 "GomSerializationTest.vala"
		_tmp21_ = _tmp20_;
#line 1120 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1120: %s", _tmp21_);
#line 1120 "GomSerializationTest.vala"
		_g_free0 (_tmp21_);
#line 1120 "GomSerializationTest.vala"
		_g_free0 (_tmp19_);
#line 1121 "GomSerializationTest.vala"
		_tmp22_ = bs;
#line 1121 "GomSerializationTest.vala"
		_tmp23_ = gom_serialization_test_book_stand_get_books (_tmp22_);
#line 1121 "GomSerializationTest.vala"
		_tmp24_ = _tmp23_;
#line 1121 "GomSerializationTest.vala"
		_tmp25_ = gxml_collection_get_length ((GXmlCollection*) _tmp24_);
#line 1121 "GomSerializationTest.vala"
		_tmp26_ = _tmp25_;
#line 1121 "GomSerializationTest.vala"
		_vala_assert (_tmp26_ == 3, "bs.books.length == 3");
#line 1122 "GomSerializationTest.vala"
		_tmp27_ = bs;
#line 1122 "GomSerializationTest.vala"
		_tmp28_ = gom_serialization_test_book_stand_get_books (_tmp27_);
#line 1122 "GomSerializationTest.vala"
		_tmp29_ = _tmp28_;
#line 1122 "GomSerializationTest.vala"
		_tmp30_ = gxml_collection_get_nodes_index ((GXmlCollection*) _tmp29_);
#line 1122 "GomSerializationTest.vala"
		_tmp31_ = _tmp30_;
#line 1122 "GomSerializationTest.vala"
		_tmp32_ = g_queue_peek_nth (_tmp31_, (guint) 0);
#line 1122 "GomSerializationTest.vala"
		_vala_assert (((gint) ((gintptr) _tmp32_)) == 0, "bs.books.nodes_index.peek_nth (0) == 0");
#line 1123 "GomSerializationTest.vala"
		_tmp33_ = bs;
#line 1123 "GomSerializationTest.vala"
		_tmp34_ = gom_serialization_test_book_stand_get_books (_tmp33_);
#line 1123 "GomSerializationTest.vala"
		_tmp35_ = _tmp34_;
#line 1123 "GomSerializationTest.vala"
		_tmp36_ = gxml_collection_get_nodes_index ((GXmlCollection*) _tmp35_);
#line 1123 "GomSerializationTest.vala"
		_tmp37_ = _tmp36_;
#line 1123 "GomSerializationTest.vala"
		_tmp38_ = g_queue_peek_nth (_tmp37_, (guint) 1);
#line 1123 "GomSerializationTest.vala"
		_vala_assert (((gint) ((gintptr) _tmp38_)) == 1, "bs.books.nodes_index.peek_nth (1) == 1");
#line 1124 "GomSerializationTest.vala"
		_tmp39_ = bs;
#line 1124 "GomSerializationTest.vala"
		_tmp40_ = gom_serialization_test_book_stand_get_books (_tmp39_);
#line 1124 "GomSerializationTest.vala"
		_tmp41_ = _tmp40_;
#line 1124 "GomSerializationTest.vala"
		_tmp42_ = gxml_collection_get_nodes_index ((GXmlCollection*) _tmp41_);
#line 1124 "GomSerializationTest.vala"
		_tmp43_ = _tmp42_;
#line 1124 "GomSerializationTest.vala"
		_tmp44_ = g_queue_peek_nth (_tmp43_, (guint) 2);
#line 1124 "GomSerializationTest.vala"
		_vala_assert (((gint) ((gintptr) _tmp44_)) == 3, "bs.books.nodes_index.peek_nth (2) == 3");
#line 1125 "GomSerializationTest.vala"
		_tmp46_ = bs;
#line 1125 "GomSerializationTest.vala"
		_tmp47_ = gom_serialization_test_book_stand_get_books (_tmp46_);
#line 1125 "GomSerializationTest.vala"
		_tmp48_ = _tmp47_;
#line 1125 "GomSerializationTest.vala"
		_tmp49_ = gxml_collection_get_item ((GXmlCollection*) _tmp48_, 0, &_inner_error0_);
#line 1125 "GomSerializationTest.vala"
		_tmp45_ = _tmp49_;
#line 1125 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1125 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1125 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 12432 "GomSerializationTest.c"
			goto __catch188_g_error;
		}
#line 1125 "GomSerializationTest.vala"
		_vala_assert (_tmp45_ != NULL, "bs.books.get_item (0) != null");
#line 1126 "GomSerializationTest.vala"
		_tmp51_ = bs;
#line 1126 "GomSerializationTest.vala"
		_tmp52_ = gom_serialization_test_book_stand_get_books (_tmp51_);
#line 1126 "GomSerializationTest.vala"
		_tmp53_ = _tmp52_;
#line 1126 "GomSerializationTest.vala"
		_tmp54_ = gxml_collection_get_item ((GXmlCollection*) _tmp53_, 0, &_inner_error0_);
#line 1126 "GomSerializationTest.vala"
		_tmp50_ = _tmp54_;
#line 1126 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1126 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 1126 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1126 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 12455 "GomSerializationTest.c"
			goto __catch188_g_error;
		}
#line 1126 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp50_, GXML_TYPE_DOM_ELEMENT), "bs.books.get_item (0) is DomElement");
#line 1127 "GomSerializationTest.vala"
		_tmp56_ = bs;
#line 1127 "GomSerializationTest.vala"
		_tmp57_ = gom_serialization_test_book_stand_get_books (_tmp56_);
#line 1127 "GomSerializationTest.vala"
		_tmp58_ = _tmp57_;
#line 1127 "GomSerializationTest.vala"
		_tmp59_ = gxml_collection_get_item ((GXmlCollection*) _tmp58_, 0, &_inner_error0_);
#line 1127 "GomSerializationTest.vala"
		_tmp55_ = _tmp59_;
#line 1127 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1127 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp50_);
#line 1127 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 1127 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1127 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 12480 "GomSerializationTest.c"
			goto __catch188_g_error;
		}
#line 1127 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp55_, GOM_SERIALIZATION_TEST_TYPE_BOOK), "bs.books.get_item (0) is Book");
#line 1128 "GomSerializationTest.vala"
		_tmp61_ = bs;
#line 1128 "GomSerializationTest.vala"
		_tmp62_ = gom_serialization_test_book_stand_get_books (_tmp61_);
#line 1128 "GomSerializationTest.vala"
		_tmp63_ = _tmp62_;
#line 1128 "GomSerializationTest.vala"
		_tmp64_ = gxml_collection_get_item ((GXmlCollection*) _tmp63_, 1, &_inner_error0_);
#line 1128 "GomSerializationTest.vala"
		_tmp60_ = _tmp64_;
#line 1128 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1128 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp55_);
#line 1128 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp50_);
#line 1128 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 1128 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1128 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 12507 "GomSerializationTest.c"
			goto __catch188_g_error;
		}
#line 1128 "GomSerializationTest.vala"
		_vala_assert (_tmp60_ != NULL, "bs.books.get_item (1) != null");
#line 1129 "GomSerializationTest.vala"
		_tmp66_ = bs;
#line 1129 "GomSerializationTest.vala"
		_tmp67_ = gom_serialization_test_book_stand_get_books (_tmp66_);
#line 1129 "GomSerializationTest.vala"
		_tmp68_ = _tmp67_;
#line 1129 "GomSerializationTest.vala"
		_tmp69_ = gxml_collection_get_item ((GXmlCollection*) _tmp68_, 1, &_inner_error0_);
#line 1129 "GomSerializationTest.vala"
		_tmp65_ = _tmp69_;
#line 1129 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1129 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp60_);
#line 1129 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp55_);
#line 1129 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp50_);
#line 1129 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 1129 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1129 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 12536 "GomSerializationTest.c"
			goto __catch188_g_error;
		}
#line 1129 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp65_, GXML_TYPE_DOM_ELEMENT), "bs.books.get_item (1) is DomElement");
#line 1130 "GomSerializationTest.vala"
		_tmp71_ = bs;
#line 1130 "GomSerializationTest.vala"
		_tmp72_ = gom_serialization_test_book_stand_get_books (_tmp71_);
#line 1130 "GomSerializationTest.vala"
		_tmp73_ = _tmp72_;
#line 1130 "GomSerializationTest.vala"
		_tmp74_ = gxml_collection_get_item ((GXmlCollection*) _tmp73_, 1, &_inner_error0_);
#line 1130 "GomSerializationTest.vala"
		_tmp70_ = _tmp74_;
#line 1130 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1130 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp65_);
#line 1130 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp60_);
#line 1130 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp55_);
#line 1130 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp50_);
#line 1130 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 1130 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1130 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 12567 "GomSerializationTest.c"
			goto __catch188_g_error;
		}
#line 1130 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp70_, GOM_SERIALIZATION_TEST_TYPE_BOOK), "bs.books.get_item (1) is Book");
#line 1131 "GomSerializationTest.vala"
		_tmp76_ = bs;
#line 1131 "GomSerializationTest.vala"
		_tmp77_ = gom_serialization_test_book_stand_get_books (_tmp76_);
#line 1131 "GomSerializationTest.vala"
		_tmp78_ = _tmp77_;
#line 1131 "GomSerializationTest.vala"
		_tmp79_ = gxml_collection_get_item ((GXmlCollection*) _tmp78_, 2, &_inner_error0_);
#line 1131 "GomSerializationTest.vala"
		_tmp75_ = _tmp79_;
#line 1131 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1131 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp70_);
#line 1131 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp65_);
#line 1131 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp60_);
#line 1131 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp55_);
#line 1131 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp50_);
#line 1131 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 1131 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1131 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 12600 "GomSerializationTest.c"
			goto __catch188_g_error;
		}
#line 1131 "GomSerializationTest.vala"
		_vala_assert (_tmp75_ != NULL, "bs.books.get_item (2) != null");
#line 1132 "GomSerializationTest.vala"
		_tmp81_ = bs;
#line 1132 "GomSerializationTest.vala"
		_tmp82_ = gom_serialization_test_book_stand_get_books (_tmp81_);
#line 1132 "GomSerializationTest.vala"
		_tmp83_ = _tmp82_;
#line 1132 "GomSerializationTest.vala"
		_tmp84_ = gxml_collection_get_item ((GXmlCollection*) _tmp83_, 2, &_inner_error0_);
#line 1132 "GomSerializationTest.vala"
		_tmp80_ = _tmp84_;
#line 1132 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1132 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp75_);
#line 1132 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp70_);
#line 1132 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp65_);
#line 1132 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp60_);
#line 1132 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp55_);
#line 1132 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp50_);
#line 1132 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 1132 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1132 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 12635 "GomSerializationTest.c"
			goto __catch188_g_error;
		}
#line 1132 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp80_, GXML_TYPE_DOM_ELEMENT), "bs.books.get_item (2) is DomElement");
#line 1133 "GomSerializationTest.vala"
		_tmp86_ = bs;
#line 1133 "GomSerializationTest.vala"
		_tmp87_ = gom_serialization_test_book_stand_get_books (_tmp86_);
#line 1133 "GomSerializationTest.vala"
		_tmp88_ = _tmp87_;
#line 1133 "GomSerializationTest.vala"
		_tmp89_ = gxml_collection_get_item ((GXmlCollection*) _tmp88_, 2, &_inner_error0_);
#line 1133 "GomSerializationTest.vala"
		_tmp85_ = _tmp89_;
#line 1133 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1133 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp80_);
#line 1133 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp75_);
#line 1133 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp70_);
#line 1133 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp65_);
#line 1133 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp60_);
#line 1133 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp55_);
#line 1133 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp50_);
#line 1133 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 1133 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1133 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 12672 "GomSerializationTest.c"
			goto __catch188_g_error;
		}
#line 1133 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp85_, GOM_SERIALIZATION_TEST_TYPE_BOOK), "bs.books.get_item (2) is Book");
#line 1134 "GomSerializationTest.vala"
		_tmp91_ = bs;
#line 1134 "GomSerializationTest.vala"
		_tmp92_ = gom_serialization_test_book_stand_get_books (_tmp91_);
#line 1134 "GomSerializationTest.vala"
		_tmp93_ = _tmp92_;
#line 1134 "GomSerializationTest.vala"
		_tmp94_ = gxml_collection_get_item ((GXmlCollection*) _tmp93_, 0, &_inner_error0_);
#line 1134 "GomSerializationTest.vala"
		_tmp90_ = _tmp94_;
#line 1134 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1134 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp85_);
#line 1134 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp80_);
#line 1134 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp75_);
#line 1134 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp70_);
#line 1134 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp65_);
#line 1134 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp60_);
#line 1134 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp55_);
#line 1134 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp50_);
#line 1134 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 1134 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1134 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 12711 "GomSerializationTest.c"
			goto __catch188_g_error;
		}
#line 1134 "GomSerializationTest.vala"
		_tmp95_ = gom_serialization_test_book_get_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp90_, GOM_SERIALIZATION_TEST_TYPE_BOOK) ? ((GomSerializationTestBook*) _tmp90_) : NULL);
#line 1134 "GomSerializationTest.vala"
		_tmp96_ = _tmp95_;
#line 1134 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp96_, "Title1") == 0, "(bs.books.get_item (0) as Book).name == \"Title1\"");
#line 1135 "GomSerializationTest.vala"
		_tmp98_ = bs;
#line 1135 "GomSerializationTest.vala"
		_tmp99_ = gom_serialization_test_book_stand_get_books (_tmp98_);
#line 1135 "GomSerializationTest.vala"
		_tmp100_ = _tmp99_;
#line 1135 "GomSerializationTest.vala"
		_tmp101_ = gxml_collection_get_item ((GXmlCollection*) _tmp100_, 1, &_inner_error0_);
#line 1135 "GomSerializationTest.vala"
		_tmp97_ = _tmp101_;
#line 1135 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1135 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp90_);
#line 1135 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp85_);
#line 1135 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp80_);
#line 1135 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp75_);
#line 1135 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp70_);
#line 1135 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp65_);
#line 1135 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp60_);
#line 1135 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp55_);
#line 1135 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp50_);
#line 1135 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 1135 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1135 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 12756 "GomSerializationTest.c"
			goto __catch188_g_error;
		}
#line 1135 "GomSerializationTest.vala"
		_tmp102_ = gom_serialization_test_book_get_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp97_, GOM_SERIALIZATION_TEST_TYPE_BOOK) ? ((GomSerializationTestBook*) _tmp97_) : NULL);
#line 1135 "GomSerializationTest.vala"
		_tmp103_ = _tmp102_;
#line 1135 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp103_, "Title2") == 0, "(bs.books.get_item (1) as Book).name == \"Title2\"");
#line 1136 "GomSerializationTest.vala"
		_tmp105_ = bs;
#line 1136 "GomSerializationTest.vala"
		_tmp106_ = gom_serialization_test_book_stand_get_books (_tmp105_);
#line 1136 "GomSerializationTest.vala"
		_tmp107_ = _tmp106_;
#line 1136 "GomSerializationTest.vala"
		_tmp108_ = gxml_collection_get_item ((GXmlCollection*) _tmp107_, 2, &_inner_error0_);
#line 1136 "GomSerializationTest.vala"
		_tmp104_ = _tmp108_;
#line 1136 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1136 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp97_);
#line 1136 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp90_);
#line 1136 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp85_);
#line 1136 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp80_);
#line 1136 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp75_);
#line 1136 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp70_);
#line 1136 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp65_);
#line 1136 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp60_);
#line 1136 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp55_);
#line 1136 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp50_);
#line 1136 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp45_);
#line 1136 "GomSerializationTest.vala"
			_g_free0 (s);
#line 1136 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 12803 "GomSerializationTest.c"
			goto __catch188_g_error;
		}
#line 1136 "GomSerializationTest.vala"
		_tmp109_ = gom_serialization_test_book_get_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp104_, GOM_SERIALIZATION_TEST_TYPE_BOOK) ? ((GomSerializationTestBook*) _tmp104_) : NULL);
#line 1136 "GomSerializationTest.vala"
		_tmp110_ = _tmp109_;
#line 1136 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp110_, "Title3") == 0, "(bs.books.get_item (2) as Book).name == \"Title3\"");
#line 1137 "GomSerializationTest.vala"
		_tmp111_ = bs;
#line 1137 "GomSerializationTest.vala"
		_tmp112_ = gom_serialization_test_book_stand_get_books (_tmp111_);
#line 1137 "GomSerializationTest.vala"
		_tmp113_ = _tmp112_;
#line 1137 "GomSerializationTest.vala"
		_tmp114_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp113_, "Title1");
#line 1137 "GomSerializationTest.vala"
		_tmp115_ = _tmp114_;
#line 1137 "GomSerializationTest.vala"
		_vala_assert (_tmp115_ != NULL, "bs.books.get (\"Title1\") != null");
#line 1137 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp115_);
#line 1138 "GomSerializationTest.vala"
		_tmp116_ = bs;
#line 1138 "GomSerializationTest.vala"
		_tmp117_ = gom_serialization_test_book_stand_get_books (_tmp116_);
#line 1138 "GomSerializationTest.vala"
		_tmp118_ = _tmp117_;
#line 1138 "GomSerializationTest.vala"
		_tmp119_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp118_, "Title1");
#line 1138 "GomSerializationTest.vala"
		_tmp120_ = _tmp119_;
#line 1138 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp120_, GXML_TYPE_DOM_ELEMENT), "bs.books.get (\"Title1\") is DomElement");
#line 1138 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp120_);
#line 1139 "GomSerializationTest.vala"
		_tmp121_ = bs;
#line 1139 "GomSerializationTest.vala"
		_tmp122_ = gom_serialization_test_book_stand_get_books (_tmp121_);
#line 1139 "GomSerializationTest.vala"
		_tmp123_ = _tmp122_;
#line 1139 "GomSerializationTest.vala"
		_tmp124_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp123_, "Title1");
#line 1139 "GomSerializationTest.vala"
		_tmp125_ = _tmp124_;
#line 1139 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp125_, GOM_SERIALIZATION_TEST_TYPE_BOOK), "bs.books.get (\"Title1\") is Book");
#line 1139 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp125_);
#line 1140 "GomSerializationTest.vala"
		_tmp126_ = bs;
#line 1140 "GomSerializationTest.vala"
		_tmp127_ = gom_serialization_test_book_stand_get_books (_tmp126_);
#line 1140 "GomSerializationTest.vala"
		_tmp128_ = _tmp127_;
#line 1140 "GomSerializationTest.vala"
		_tmp129_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp128_, "Title2");
#line 1140 "GomSerializationTest.vala"
		_tmp130_ = _tmp129_;
#line 1140 "GomSerializationTest.vala"
		_vala_assert (_tmp130_ != NULL, "bs.books.get (\"Title2\") != null");
#line 1140 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp130_);
#line 1141 "GomSerializationTest.vala"
		_tmp131_ = bs;
#line 1141 "GomSerializationTest.vala"
		_tmp132_ = gom_serialization_test_book_stand_get_books (_tmp131_);
#line 1141 "GomSerializationTest.vala"
		_tmp133_ = _tmp132_;
#line 1141 "GomSerializationTest.vala"
		_tmp134_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp133_, "Title2");
#line 1141 "GomSerializationTest.vala"
		_tmp135_ = _tmp134_;
#line 1141 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp135_, GXML_TYPE_DOM_ELEMENT), "bs.books.get (\"Title2\") is DomElement");
#line 1141 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp135_);
#line 1142 "GomSerializationTest.vala"
		_tmp136_ = bs;
#line 1142 "GomSerializationTest.vala"
		_tmp137_ = gom_serialization_test_book_stand_get_books (_tmp136_);
#line 1142 "GomSerializationTest.vala"
		_tmp138_ = _tmp137_;
#line 1142 "GomSerializationTest.vala"
		_tmp139_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp138_, "Title2");
#line 1142 "GomSerializationTest.vala"
		_tmp140_ = _tmp139_;
#line 1142 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp140_, GOM_SERIALIZATION_TEST_TYPE_BOOK), "bs.books.get (\"Title2\") is Book");
#line 1142 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp140_);
#line 1143 "GomSerializationTest.vala"
		_tmp141_ = bs;
#line 1143 "GomSerializationTest.vala"
		_tmp142_ = gom_serialization_test_book_stand_get_books (_tmp141_);
#line 1143 "GomSerializationTest.vala"
		_tmp143_ = _tmp142_;
#line 1143 "GomSerializationTest.vala"
		_tmp144_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp143_, "Title3");
#line 1143 "GomSerializationTest.vala"
		_tmp145_ = _tmp144_;
#line 1143 "GomSerializationTest.vala"
		_vala_assert (_tmp145_ != NULL, "bs.books.get (\"Title3\") != null");
#line 1143 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp145_);
#line 1144 "GomSerializationTest.vala"
		_tmp146_ = bs;
#line 1144 "GomSerializationTest.vala"
		_tmp147_ = gom_serialization_test_book_stand_get_books (_tmp146_);
#line 1144 "GomSerializationTest.vala"
		_tmp148_ = _tmp147_;
#line 1144 "GomSerializationTest.vala"
		_tmp149_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp148_, "Title3");
#line 1144 "GomSerializationTest.vala"
		_tmp150_ = _tmp149_;
#line 1144 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp150_, GXML_TYPE_DOM_ELEMENT), "bs.books.get (\"Title3\") is DomElement");
#line 1144 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp150_);
#line 1145 "GomSerializationTest.vala"
		_tmp151_ = bs;
#line 1145 "GomSerializationTest.vala"
		_tmp152_ = gom_serialization_test_book_stand_get_books (_tmp151_);
#line 1145 "GomSerializationTest.vala"
		_tmp153_ = _tmp152_;
#line 1145 "GomSerializationTest.vala"
		_tmp154_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp153_, "Title3");
#line 1145 "GomSerializationTest.vala"
		_tmp155_ = _tmp154_;
#line 1145 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp155_, GOM_SERIALIZATION_TEST_TYPE_BOOK), "bs.books.get (\"Title3\") is Book");
#line 1145 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp155_);
#line 1146 "GomSerializationTest.vala"
		_tmp156_ = bs;
#line 1146 "GomSerializationTest.vala"
		_tmp157_ = gom_serialization_test_book_stand_get_books (_tmp156_);
#line 1146 "GomSerializationTest.vala"
		_tmp158_ = _tmp157_;
#line 1146 "GomSerializationTest.vala"
		_tmp159_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp158_, "Title4");
#line 1146 "GomSerializationTest.vala"
		_tmp160_ = _tmp159_;
#line 1146 "GomSerializationTest.vala"
		_vala_assert (_tmp160_ == NULL, "bs.books.get (\"Title4\") == null");
#line 1146 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp160_);
#line 1108 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp104_);
#line 1108 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp97_);
#line 1108 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp90_);
#line 1108 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp85_);
#line 1108 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp80_);
#line 1108 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp75_);
#line 1108 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp70_);
#line 1108 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp65_);
#line 1108 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp60_);
#line 1108 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp55_);
#line 1108 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp50_);
#line 1108 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp45_);
#line 1108 "GomSerializationTest.vala"
		_g_free0 (s);
#line 1108 "GomSerializationTest.vala"
		_g_object_unref0 (bs);
#line 12980 "GomSerializationTest.c"
	}
	goto __finally188;
	__catch188_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp161_;
		gchar* _tmp162_;
		gchar* _tmp163_;
#line 1108 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 1108 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 1148 "GomSerializationTest.vala"
		_tmp161_ = e->message;
#line 1148 "GomSerializationTest.vala"
		_tmp162_ = g_strconcat ("Error: ", _tmp161_, NULL);
#line 1148 "GomSerializationTest.vala"
		_tmp163_ = _tmp162_;
#line 1148 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1148: %s", _tmp163_);
#line 1148 "GomSerializationTest.vala"
		_g_free0 (_tmp163_);
#line 1149 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 1108 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 13007 "GomSerializationTest.c"
	}
	__finally188:
#line 1108 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1108 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 1108 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 1108 "GomSerializationTest.vala"
		return;
#line 13018 "GomSerializationTest.c"
	}
}

static void
___lambda136__gtest_func (void)
{
#line 1107 "GomSerializationTest.vala"
	__lambda136_ ();
#line 13027 "GomSerializationTest.c"
}

static void
__lambda137_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		gdouble time = 0.0;
		GFile* f = NULL;
		GFile* _tmp0_;
		GFile* _tmp1_;
		GomBookStore* bs = NULL;
		GomBookStore* _tmp2_;
		GomBookStore* _tmp3_;
		GomBookStore* _tmp4_;
		GFile* _tmp5_;
		GomBookStore* _tmp6_;
		GomBookArray* _tmp7_;
		GomBookArray* _tmp8_;
		GomBookStore* _tmp9_;
		GomBookArray* _tmp10_;
		GomBookArray* _tmp11_;
		GXmlDomElement* _tmp12_;
		GXmlDomElement* _tmp13_;
		GomBookStore* _tmp14_;
		GomBookArray* _tmp15_;
		GomBookArray* _tmp16_;
		GType _tmp17_;
		GType _tmp18_;
		GomBookStore* _tmp19_;
		GomBookArray* _tmp20_;
		GomBookArray* _tmp21_;
		const gchar* _tmp22_;
		const gchar* _tmp23_;
		GomBookStore* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		GomBookStore* _tmp28_;
		gchar* _tmp29_;
		gchar* _tmp30_;
		GomBookStore* _tmp31_;
		const gchar* _tmp32_;
		const gchar* _tmp33_;
		GomBookStore* _tmp34_;
		const gchar* _tmp35_;
		const gchar* _tmp36_;
		GFile* of = NULL;
		GFile* _tmp37_;
		GomBookStore* _tmp38_;
		GXmlDomDocument* _tmp39_;
		GXmlDomDocument* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomElement* _tmp42_;
		GXmlDomElement* _tmp43_;
		gchar* _tmp44_;
		gchar* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
		GomBookStore* _tmp49_;
		GXmlDomNodeList* _tmp50_;
		GXmlDomNodeList* _tmp51_;
		GXmlDomNodeList* _tmp52_;
		gint _tmp53_;
		gint _tmp54_;
		GXmlDomHTMLCollection* ns = NULL;
		GomBookStore* _tmp55_;
		GXmlDomHTMLCollection* _tmp56_;
		GXmlDomHTMLCollection* _tmp57_;
		gint _tmp58_;
		gint _tmp59_;
		GomBookStore* _tmp60_;
		GFile* _tmp61_;
		GFile* _tmp62_;
#line 1156 "GomSerializationTest.vala"
		_tmp0_ = g_file_new_for_path (TEST_DIR "/test-collection.xml");
#line 1156 "GomSerializationTest.vala"
		f = _tmp0_;
#line 1157 "GomSerializationTest.vala"
		_tmp1_ = f;
#line 1157 "GomSerializationTest.vala"
		_vala_assert (g_file_query_exists (_tmp1_, NULL), "f.query_exists ()");
#line 1158 "GomSerializationTest.vala"
		g_test_timer_start ();
#line 1159 "GomSerializationTest.vala"
		_tmp2_ = gom_book_store_new ();
#line 1159 "GomSerializationTest.vala"
		bs = _tmp2_;
#line 1160 "GomSerializationTest.vala"
		_tmp3_ = bs;
#line 1160 "GomSerializationTest.vala"
		_vala_assert (_tmp3_ != NULL, "bs != null");
#line 1164 "GomSerializationTest.vala"
		_tmp4_ = bs;
#line 1164 "GomSerializationTest.vala"
		_tmp5_ = f;
#line 1164 "GomSerializationTest.vala"
		gxml_dom_element_read_from_file ((GXmlDomElement*) _tmp4_, _tmp5_, NULL, &_inner_error0_);
#line 1164 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1164 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 1164 "GomSerializationTest.vala"
			_g_object_unref0 (f);
#line 13133 "GomSerializationTest.c"
			goto __catch189_g_error;
		}
#line 1165 "GomSerializationTest.vala"
		_tmp6_ = bs;
#line 1165 "GomSerializationTest.vala"
		_tmp7_ = gom_book_store_get_books (_tmp6_);
#line 1165 "GomSerializationTest.vala"
		_tmp8_ = _tmp7_;
#line 1165 "GomSerializationTest.vala"
		_vala_assert (_tmp8_ != NULL, "bs.books != null");
#line 1166 "GomSerializationTest.vala"
		_tmp9_ = bs;
#line 1166 "GomSerializationTest.vala"
		_tmp10_ = gom_book_store_get_books (_tmp9_);
#line 1166 "GomSerializationTest.vala"
		_tmp11_ = _tmp10_;
#line 1166 "GomSerializationTest.vala"
		_tmp12_ = gxml_collection_get_element ((GXmlCollection*) _tmp11_);
#line 1166 "GomSerializationTest.vala"
		_tmp13_ = _tmp12_;
#line 1166 "GomSerializationTest.vala"
		_vala_assert (_tmp13_ != NULL, "bs.books.element != null");
#line 1167 "GomSerializationTest.vala"
		_tmp14_ = bs;
#line 1167 "GomSerializationTest.vala"
		_tmp15_ = gom_book_store_get_books (_tmp14_);
#line 1167 "GomSerializationTest.vala"
		_tmp16_ = _tmp15_;
#line 1167 "GomSerializationTest.vala"
		_tmp17_ = gxml_collection_get_items_type ((GXmlCollection*) _tmp16_);
#line 1167 "GomSerializationTest.vala"
		_tmp18_ = _tmp17_;
#line 1167 "GomSerializationTest.vala"
		_vala_assert (g_type_is_a (_tmp18_, TYPE_GOM_BOOK), "bs.books.items_type.is_a (typeof(GomBook))");
#line 1168 "GomSerializationTest.vala"
		_tmp19_ = bs;
#line 1168 "GomSerializationTest.vala"
		_tmp20_ = gom_book_store_get_books (_tmp19_);
#line 1168 "GomSerializationTest.vala"
		_tmp21_ = _tmp20_;
#line 1168 "GomSerializationTest.vala"
		_tmp22_ = gxml_collection_get_items_name ((GXmlCollection*) _tmp21_);
#line 1168 "GomSerializationTest.vala"
		_tmp23_ = _tmp22_;
#line 1168 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp23_, "Book") == 0, "bs.books.items_name == \"Book\"");
#line 1169 "GomSerializationTest.vala"
		_tmp24_ = bs;
#line 1169 "GomSerializationTest.vala"
		_tmp25_ = gxml_dom_element_get_local_name ((GXmlDomElement*) _tmp24_);
#line 1169 "GomSerializationTest.vala"
		_tmp26_ = _tmp25_;
#line 1169 "GomSerializationTest.vala"
		_tmp27_ = _tmp26_;
#line 1169 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp27_, "BookStore") == 0, "bs.local_name == \"BookStore\"");
#line 1169 "GomSerializationTest.vala"
		_g_free0 (_tmp27_);
#line 1170 "GomSerializationTest.vala"
		_tmp28_ = bs;
#line 1170 "GomSerializationTest.vala"
		_tmp29_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp28_, "name");
#line 1170 "GomSerializationTest.vala"
		_tmp30_ = _tmp29_;
#line 1170 "GomSerializationTest.vala"
		_vala_assert (_tmp30_ != NULL, "bs.get_attribute (\"name\") != null");
#line 1170 "GomSerializationTest.vala"
		_g_free0 (_tmp30_);
#line 1171 "GomSerializationTest.vala"
		_tmp31_ = bs;
#line 1171 "GomSerializationTest.vala"
		_tmp32_ = gom_book_store_get_name (_tmp31_);
#line 1171 "GomSerializationTest.vala"
		_tmp33_ = _tmp32_;
#line 1171 "GomSerializationTest.vala"
		_vala_assert (_tmp33_ != NULL, "bs.name != null");
#line 1172 "GomSerializationTest.vala"
		_tmp34_ = bs;
#line 1172 "GomSerializationTest.vala"
		_tmp35_ = gom_book_store_get_name (_tmp34_);
#line 1172 "GomSerializationTest.vala"
		_tmp36_ = _tmp35_;
#line 1172 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp36_, "The Great Book") == 0, "bs.name == \"The Great Book\"");
#line 1173 "GomSerializationTest.vala"
		time = g_test_timer_elapsed ();
#line 1174 "GomSerializationTest.vala"
		g_test_minimized_result (time, "deserialize/performance: %g seconds", time);
#line 1178 "GomSerializationTest.vala"
		_tmp37_ = g_file_new_for_path (TEST_SAVE_DIR "/test-large-new.xml");
#line 1178 "GomSerializationTest.vala"
		of = _tmp37_;
#line 1179 "GomSerializationTest.vala"
		g_test_timer_start ();
#line 1184 "GomSerializationTest.vala"
		_tmp38_ = bs;
#line 1184 "GomSerializationTest.vala"
		_tmp39_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _tmp38_);
#line 1184 "GomSerializationTest.vala"
		_tmp40_ = _tmp39_;
#line 1184 "GomSerializationTest.vala"
		_tmp41_ = gxml_dom_document_get_document_element (_tmp40_);
#line 1184 "GomSerializationTest.vala"
		_tmp42_ = _tmp41_;
#line 1184 "GomSerializationTest.vala"
		_tmp43_ = _tmp42_;
#line 1184 "GomSerializationTest.vala"
		_tmp44_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp43_);
#line 1184 "GomSerializationTest.vala"
		_tmp45_ = _tmp44_;
#line 1184 "GomSerializationTest.vala"
		_tmp46_ = _tmp45_;
#line 1184 "GomSerializationTest.vala"
		_tmp47_ = g_utf8_strdown (_tmp46_, (gssize) -1);
#line 1184 "GomSerializationTest.vala"
		_tmp48_ = _tmp47_;
#line 1184 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp48_, "bookstore") == 0, "bs.owner_document.document_element.node_name.down () == \"bookstore\"");
#line 1184 "GomSerializationTest.vala"
		_g_free0 (_tmp48_);
#line 1184 "GomSerializationTest.vala"
		_g_free0 (_tmp46_);
#line 1184 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp43_);
#line 1188 "GomSerializationTest.vala"
		_tmp49_ = bs;
#line 1188 "GomSerializationTest.vala"
		_tmp50_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp49_);
#line 1188 "GomSerializationTest.vala"
		_tmp51_ = _tmp50_;
#line 1188 "GomSerializationTest.vala"
		_tmp52_ = _tmp51_;
#line 1188 "GomSerializationTest.vala"
		_tmp53_ = gxml_dom_node_list_get_length (_tmp52_);
#line 1188 "GomSerializationTest.vala"
		_tmp54_ = _tmp53_;
#line 1188 "GomSerializationTest.vala"
		_vala_assert (_tmp54_ == 7, "bs.child_nodes.length == 7");
#line 1188 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp52_);
#line 1189 "GomSerializationTest.vala"
		_tmp55_ = bs;
#line 1189 "GomSerializationTest.vala"
		_tmp56_ = gxml_dom_element_get_elements_by_tag_name ((GXmlDomElement*) _tmp55_, "Book");
#line 1189 "GomSerializationTest.vala"
		ns = _tmp56_;
#line 1194 "GomSerializationTest.vala"
		_tmp57_ = ns;
#line 1194 "GomSerializationTest.vala"
		_tmp58_ = gxml_dom_html_collection_get_length (_tmp57_);
#line 1194 "GomSerializationTest.vala"
		_tmp59_ = _tmp58_;
#line 1194 "GomSerializationTest.vala"
		_vala_assert (_tmp59_ == 3, "ns.length == 3");
#line 1199 "GomSerializationTest.vala"
		_tmp60_ = bs;
#line 1199 "GomSerializationTest.vala"
		_tmp61_ = of;
#line 1199 "GomSerializationTest.vala"
		gxml_dom_element_write_file ((GXmlDomElement*) _tmp60_, _tmp61_, NULL, &_inner_error0_);
#line 1199 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1199 "GomSerializationTest.vala"
			_g_object_unref0 (ns);
#line 1199 "GomSerializationTest.vala"
			_g_object_unref0 (of);
#line 1199 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 1199 "GomSerializationTest.vala"
			_g_object_unref0 (f);
#line 13304 "GomSerializationTest.c"
			goto __catch189_g_error;
		}
#line 1200 "GomSerializationTest.vala"
		time = g_test_timer_elapsed ();
#line 1201 "GomSerializationTest.vala"
		g_test_minimized_result (time, "Serialize/performance: %g seconds", time);
#line 1202 "GomSerializationTest.vala"
		_tmp62_ = of;
#line 1202 "GomSerializationTest.vala"
		_vala_assert (g_file_query_exists (_tmp62_, NULL), "of.query_exists ()");
#line 13315 "GomSerializationTest.c"
		{
			GFile* _tmp63_;
#line 1203 "GomSerializationTest.vala"
			_tmp63_ = of;
#line 1203 "GomSerializationTest.vala"
			g_file_delete (_tmp63_, NULL, &_inner_error0_);
#line 1203 "GomSerializationTest.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 13324 "GomSerializationTest.c"
				goto __catch190_g_error;
			}
		}
		goto __finally190;
		__catch190_g_error:
		{
#line 1203 "GomSerializationTest.vala"
			g_clear_error (&_inner_error0_);
#line 1203 "GomSerializationTest.vala"
			_inner_error0_ = NULL;
#line 1203 "GomSerializationTest.vala"
			g_assert_not_reached ();
#line 13337 "GomSerializationTest.c"
		}
		__finally190:
#line 1203 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1203 "GomSerializationTest.vala"
			_g_object_unref0 (ns);
#line 1203 "GomSerializationTest.vala"
			_g_object_unref0 (of);
#line 1203 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 1203 "GomSerializationTest.vala"
			_g_object_unref0 (f);
#line 13350 "GomSerializationTest.c"
			goto __catch189_g_error;
		}
#line 1154 "GomSerializationTest.vala"
		_g_object_unref0 (ns);
#line 1154 "GomSerializationTest.vala"
		_g_object_unref0 (of);
#line 1154 "GomSerializationTest.vala"
		_g_object_unref0 (bs);
#line 1154 "GomSerializationTest.vala"
		_g_object_unref0 (f);
#line 13361 "GomSerializationTest.c"
	}
	goto __finally189;
	__catch189_g_error:
	{
		GError* e = NULL;
#line 1154 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 1154 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 1209 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 1154 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 13375 "GomSerializationTest.c"
	}
	__finally189:
#line 1154 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1154 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 1154 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 1154 "GomSerializationTest.vala"
		return;
#line 13386 "GomSerializationTest.c"
	}
}

static void
___lambda137__gtest_func (void)
{
#line 1152 "GomSerializationTest.vala"
	__lambda137_ ();
#line 13395 "GomSerializationTest.c"
}

static void
_g_free0_ (gpointer var)
{
#line 1234 "GomSerializationTest.vala"
	var = (g_free (var), NULL);
#line 13403 "GomSerializationTest.c"
}

static inline void
_g_list_free__g_free0_ (GList* self)
{
#line 1234 "GomSerializationTest.vala"
	g_list_free_full (self, (GDestroyNotify) _g_free0_);
#line 13411 "GomSerializationTest.c"
}

static void
__lambda138_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		Operations* ops = NULL;
		Operations* _tmp0_;
		Operations* _tmp1_;
		OperationMap* _tmp2_;
		OperationMap* _tmp3_;
		Operations* _tmp4_;
		OperationMap* _tmp5_;
		OperationMap* _tmp6_;
		gint _tmp7_;
		gint _tmp8_;
		Operation* op1 = NULL;
		Operations* _tmp9_;
		OperationMap* _tmp10_;
		OperationMap* _tmp11_;
		GXmlDomElement* _tmp12_;
		Operation* _tmp13_;
		Operation* _tmp14_;
		Operation* _tmp15_;
		Operation* _tmp16_;
		Operations* _tmp17_;
		OperationMap* _tmp18_;
		OperationMap* _tmp19_;
		Operation* _tmp20_;
		Operations* _tmp21_;
		OperationMap* _tmp22_;
		OperationMap* _tmp23_;
		gint _tmp24_;
		gint _tmp25_;
		Operation* top1 = NULL;
		Operations* _tmp26_;
		OperationMap* _tmp27_;
		OperationMap* _tmp28_;
		GXmlDomElement* _tmp29_;
		Operation* _tmp30_;
		Operation* _tmp31_;
		Operation* _tmp32_;
		const gchar* _tmp33_;
		const gchar* _tmp34_;
		Operation* _tmp35_;
		const gchar* _tmp36_;
		const gchar* _tmp37_;
		GList* pkeys1 = NULL;
		Operations* _tmp38_;
		OperationMap* _tmp39_;
		OperationMap* _tmp40_;
		GList* _tmp41_;
		GList* _tmp42_;
		Operation* op2 = NULL;
		Operations* _tmp43_;
		OperationMap* _tmp44_;
		OperationMap* _tmp45_;
		GXmlDomElement* _tmp46_;
		Operation* _tmp47_;
		Operation* _tmp48_;
		Operation* _tmp49_;
		Operation* _tmp50_;
		Operations* _tmp51_;
		OperationMap* _tmp52_;
		OperationMap* _tmp53_;
		Operation* _tmp54_;
		Operation* op3 = NULL;
		Operations* _tmp55_;
		OperationMap* _tmp56_;
		OperationMap* _tmp57_;
		GXmlDomElement* _tmp58_;
		Operation* _tmp59_;
		Operation* _tmp60_;
		Operation* _tmp61_;
		Operation* _tmp62_;
		Operations* _tmp63_;
		OperationMap* _tmp64_;
		OperationMap* _tmp65_;
		Operation* _tmp66_;
		Operations* _tmp67_;
		OperationMap* _tmp68_;
		OperationMap* _tmp69_;
		gint _tmp70_;
		gint _tmp71_;
		Operation* op4 = NULL;
		Operations* _tmp72_;
		OperationMap* _tmp73_;
		OperationMap* _tmp74_;
		GXmlDomElement* _tmp75_;
		Operation* _tmp76_;
		Operation* _tmp77_;
		Operation* _tmp78_;
		Operation* _tmp79_;
		Operations* _tmp80_;
		OperationMap* _tmp81_;
		OperationMap* _tmp82_;
		Operation* _tmp83_;
		Operations* _tmp84_;
		OperationMap* _tmp85_;
		OperationMap* _tmp86_;
		gint _tmp87_;
		gint _tmp88_;
		gchar* _tmp89_ = NULL;
		Operations* _tmp90_;
		gchar* _tmp91_;
		GList* pkeys2 = NULL;
		Operations* _tmp92_;
		OperationMap* _tmp93_;
		OperationMap* _tmp94_;
		GList* _tmp95_;
		GList* _tmp96_;
		GList* _tmp97_;
		GList* skeys1 = NULL;
		Operations* _tmp100_;
		OperationMap* _tmp101_;
		OperationMap* _tmp102_;
		GList* _tmp103_;
		GList* _tmp104_;
		GList* _tmp107_;
		Operation* _tmp108_;
		Operations* _tmp109_;
		OperationMap* _tmp110_;
		OperationMap* _tmp111_;
		Operations* _tmp112_;
		OperationMap* _tmp113_;
		OperationMap* _tmp114_;
		gint _tmp115_;
		gint _tmp116_;
		GXmlDomElement* op3t = NULL;
		Operations* _tmp117_;
		OperationMap* _tmp118_;
		OperationMap* _tmp119_;
		GXmlDomElement* _tmp120_;
#line 1215 "GomSerializationTest.vala"
		_tmp0_ = operations_new ();
#line 1215 "GomSerializationTest.vala"
		ops = _tmp0_;
#line 1216 "GomSerializationTest.vala"
		_tmp1_ = ops;
#line 1216 "GomSerializationTest.vala"
		_tmp2_ = operations_get_map (_tmp1_);
#line 1216 "GomSerializationTest.vala"
		_tmp3_ = _tmp2_;
#line 1216 "GomSerializationTest.vala"
		_vala_assert (_tmp3_ != NULL, "ops.map != null");
#line 1217 "GomSerializationTest.vala"
		_tmp4_ = ops;
#line 1217 "GomSerializationTest.vala"
		_tmp5_ = operations_get_map (_tmp4_);
#line 1217 "GomSerializationTest.vala"
		_tmp6_ = _tmp5_;
#line 1217 "GomSerializationTest.vala"
		_tmp7_ = gxml_collection_get_length ((GXmlCollection*) _tmp6_);
#line 1217 "GomSerializationTest.vala"
		_tmp8_ = _tmp7_;
#line 1217 "GomSerializationTest.vala"
		_vala_assert (_tmp8_ == 0, "ops.map.length == 0");
#line 1218 "GomSerializationTest.vala"
		_tmp9_ = ops;
#line 1218 "GomSerializationTest.vala"
		_tmp10_ = operations_get_map (_tmp9_);
#line 1218 "GomSerializationTest.vala"
		_tmp11_ = _tmp10_;
#line 1218 "GomSerializationTest.vala"
		_tmp12_ = gxml_collection_create_item ((GXmlCollection*) _tmp11_);
#line 1218 "GomSerializationTest.vala"
		_tmp13_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, TYPE_OPERATION) ? ((Operation*) _tmp12_) : NULL;
#line 1218 "GomSerializationTest.vala"
		if (_tmp13_ == NULL) {
#line 1218 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp12_);
#line 13584 "GomSerializationTest.c"
		}
#line 1218 "GomSerializationTest.vala"
		op1 = _tmp13_;
#line 1219 "GomSerializationTest.vala"
		_tmp14_ = op1;
#line 1219 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp14_, TYPE_OPERATION), "op1 is Operation");
#line 1220 "GomSerializationTest.vala"
		_tmp15_ = op1;
#line 1220 "GomSerializationTest.vala"
		operation_set_id (_tmp15_, "a1");
#line 1221 "GomSerializationTest.vala"
		_tmp16_ = op1;
#line 1221 "GomSerializationTest.vala"
		operation_set_code (_tmp16_, "b1");
#line 1222 "GomSerializationTest.vala"
		_tmp17_ = ops;
#line 1222 "GomSerializationTest.vala"
		_tmp18_ = operations_get_map (_tmp17_);
#line 1222 "GomSerializationTest.vala"
		_tmp19_ = _tmp18_;
#line 1222 "GomSerializationTest.vala"
		_tmp20_ = op1;
#line 1222 "GomSerializationTest.vala"
		gxml_collection_append ((GXmlCollection*) _tmp19_, (GXmlDomElement*) _tmp20_, &_inner_error0_);
#line 1222 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1222 "GomSerializationTest.vala"
			_g_object_unref0 (op1);
#line 1222 "GomSerializationTest.vala"
			_g_object_unref0 (ops);
#line 13616 "GomSerializationTest.c"
			goto __catch191_g_error;
		}
#line 1223 "GomSerializationTest.vala"
		_tmp21_ = ops;
#line 1223 "GomSerializationTest.vala"
		_tmp22_ = operations_get_map (_tmp21_);
#line 1223 "GomSerializationTest.vala"
		_tmp23_ = _tmp22_;
#line 1223 "GomSerializationTest.vala"
		_tmp24_ = gxml_collection_get_length ((GXmlCollection*) _tmp23_);
#line 1223 "GomSerializationTest.vala"
		_tmp25_ = _tmp24_;
#line 1223 "GomSerializationTest.vala"
		_vala_assert (_tmp25_ == 1, "ops.map.length == 1");
#line 1224 "GomSerializationTest.vala"
		_tmp26_ = ops;
#line 1224 "GomSerializationTest.vala"
		_tmp27_ = operations_get_map (_tmp26_);
#line 1224 "GomSerializationTest.vala"
		_tmp28_ = _tmp27_;
#line 1224 "GomSerializationTest.vala"
		_tmp29_ = gxml_gom_hash_paired_map_get ((GXmlGomHashPairedMap*) _tmp28_, "a1", "b1");
#line 1224 "GomSerializationTest.vala"
		_tmp30_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp29_, TYPE_OPERATION) ? ((Operation*) _tmp29_) : NULL;
#line 1224 "GomSerializationTest.vala"
		if (_tmp30_ == NULL) {
#line 1224 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp29_);
#line 13645 "GomSerializationTest.c"
		}
#line 1224 "GomSerializationTest.vala"
		top1 = _tmp30_;
#line 1225 "GomSerializationTest.vala"
		_tmp31_ = top1;
#line 1225 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, TYPE_OPERATION), "top1 is Operation");
#line 1226 "GomSerializationTest.vala"
		_tmp32_ = top1;
#line 1226 "GomSerializationTest.vala"
		_tmp33_ = operation_get_id (_tmp32_);
#line 1226 "GomSerializationTest.vala"
		_tmp34_ = _tmp33_;
#line 1226 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "a1") == 0, "top1.id == \"a1\"");
#line 1227 "GomSerializationTest.vala"
		_tmp35_ = top1;
#line 1227 "GomSerializationTest.vala"
		_tmp36_ = operation_get_code (_tmp35_);
#line 1227 "GomSerializationTest.vala"
		_tmp37_ = _tmp36_;
#line 1227 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp37_, "b1") == 0, "top1.code == \"b1\"");
#line 1228 "GomSerializationTest.vala"
		_tmp38_ = ops;
#line 1228 "GomSerializationTest.vala"
		_tmp39_ = operations_get_map (_tmp38_);
#line 1228 "GomSerializationTest.vala"
		_tmp40_ = _tmp39_;
#line 1228 "GomSerializationTest.vala"
		_tmp41_ = gxml_gom_hash_paired_map_get_primary_keys ((GXmlGomHashPairedMap*) _tmp40_);
#line 1228 "GomSerializationTest.vala"
		pkeys1 = _tmp41_;
#line 1229 "GomSerializationTest.vala"
		_tmp42_ = pkeys1;
#line 1229 "GomSerializationTest.vala"
		_vala_assert (g_list_length (_tmp42_) == ((guint) 1), "pkeys1.length () == 1");
#line 1230 "GomSerializationTest.vala"
		_tmp43_ = ops;
#line 1230 "GomSerializationTest.vala"
		_tmp44_ = operations_get_map (_tmp43_);
#line 1230 "GomSerializationTest.vala"
		_tmp45_ = _tmp44_;
#line 1230 "GomSerializationTest.vala"
		_tmp46_ = gxml_collection_create_item ((GXmlCollection*) _tmp45_);
#line 1230 "GomSerializationTest.vala"
		_tmp47_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp46_, TYPE_OPERATION) ? ((Operation*) _tmp46_) : NULL;
#line 1230 "GomSerializationTest.vala"
		if (_tmp47_ == NULL) {
#line 1230 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp46_);
#line 13697 "GomSerializationTest.c"
		}
#line 1230 "GomSerializationTest.vala"
		op2 = _tmp47_;
#line 1231 "GomSerializationTest.vala"
		_tmp48_ = op2;
#line 1231 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp48_, TYPE_OPERATION), "op2 is Operation");
#line 1232 "GomSerializationTest.vala"
		_tmp49_ = op2;
#line 1232 "GomSerializationTest.vala"
		operation_set_id (_tmp49_, "a1");
#line 1233 "GomSerializationTest.vala"
		_tmp50_ = op2;
#line 1233 "GomSerializationTest.vala"
		operation_set_code (_tmp50_, "b2");
#line 1234 "GomSerializationTest.vala"
		_tmp51_ = ops;
#line 1234 "GomSerializationTest.vala"
		_tmp52_ = operations_get_map (_tmp51_);
#line 1234 "GomSerializationTest.vala"
		_tmp53_ = _tmp52_;
#line 1234 "GomSerializationTest.vala"
		_tmp54_ = op2;
#line 1234 "GomSerializationTest.vala"
		gxml_collection_append ((GXmlCollection*) _tmp53_, (GXmlDomElement*) _tmp54_, &_inner_error0_);
#line 1234 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1234 "GomSerializationTest.vala"
			_g_object_unref0 (op2);
#line 1234 "GomSerializationTest.vala"
			(pkeys1 == NULL) ? NULL : (pkeys1 = (_g_list_free__g_free0_ (pkeys1), NULL));
#line 1234 "GomSerializationTest.vala"
			_g_object_unref0 (top1);
#line 1234 "GomSerializationTest.vala"
			_g_object_unref0 (op1);
#line 1234 "GomSerializationTest.vala"
			_g_object_unref0 (ops);
#line 13735 "GomSerializationTest.c"
			goto __catch191_g_error;
		}
#line 1235 "GomSerializationTest.vala"
		_tmp55_ = ops;
#line 1235 "GomSerializationTest.vala"
		_tmp56_ = operations_get_map (_tmp55_);
#line 1235 "GomSerializationTest.vala"
		_tmp57_ = _tmp56_;
#line 1235 "GomSerializationTest.vala"
		_tmp58_ = gxml_collection_create_item ((GXmlCollection*) _tmp57_);
#line 1235 "GomSerializationTest.vala"
		_tmp59_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp58_, TYPE_OPERATION) ? ((Operation*) _tmp58_) : NULL;
#line 1235 "GomSerializationTest.vala"
		if (_tmp59_ == NULL) {
#line 1235 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp58_);
#line 13752 "GomSerializationTest.c"
		}
#line 1235 "GomSerializationTest.vala"
		op3 = _tmp59_;
#line 1236 "GomSerializationTest.vala"
		_tmp60_ = op2;
#line 1236 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp60_, TYPE_OPERATION), "op2 is Operation");
#line 1237 "GomSerializationTest.vala"
		_tmp61_ = op3;
#line 1237 "GomSerializationTest.vala"
		operation_set_id (_tmp61_, "a2");
#line 1238 "GomSerializationTest.vala"
		_tmp62_ = op3;
#line 1238 "GomSerializationTest.vala"
		operation_set_code (_tmp62_, "b1");
#line 1239 "GomSerializationTest.vala"
		_tmp63_ = ops;
#line 1239 "GomSerializationTest.vala"
		_tmp64_ = operations_get_map (_tmp63_);
#line 1239 "GomSerializationTest.vala"
		_tmp65_ = _tmp64_;
#line 1239 "GomSerializationTest.vala"
		_tmp66_ = op3;
#line 1239 "GomSerializationTest.vala"
		gxml_collection_append ((GXmlCollection*) _tmp65_, (GXmlDomElement*) _tmp66_, &_inner_error0_);
#line 1239 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1239 "GomSerializationTest.vala"
			_g_object_unref0 (op3);
#line 1239 "GomSerializationTest.vala"
			_g_object_unref0 (op2);
#line 1239 "GomSerializationTest.vala"
			(pkeys1 == NULL) ? NULL : (pkeys1 = (_g_list_free__g_free0_ (pkeys1), NULL));
#line 1239 "GomSerializationTest.vala"
			_g_object_unref0 (top1);
#line 1239 "GomSerializationTest.vala"
			_g_object_unref0 (op1);
#line 1239 "GomSerializationTest.vala"
			_g_object_unref0 (ops);
#line 13792 "GomSerializationTest.c"
			goto __catch191_g_error;
		}
#line 1240 "GomSerializationTest.vala"
		_tmp67_ = ops;
#line 1240 "GomSerializationTest.vala"
		_tmp68_ = operations_get_map (_tmp67_);
#line 1240 "GomSerializationTest.vala"
		_tmp69_ = _tmp68_;
#line 1240 "GomSerializationTest.vala"
		_tmp70_ = gxml_collection_get_length ((GXmlCollection*) _tmp69_);
#line 1240 "GomSerializationTest.vala"
		_tmp71_ = _tmp70_;
#line 1240 "GomSerializationTest.vala"
		_vala_assert (_tmp71_ == 3, "ops.map.length == 3");
#line 1241 "GomSerializationTest.vala"
		_tmp72_ = ops;
#line 1241 "GomSerializationTest.vala"
		_tmp73_ = operations_get_map (_tmp72_);
#line 1241 "GomSerializationTest.vala"
		_tmp74_ = _tmp73_;
#line 1241 "GomSerializationTest.vala"
		_tmp75_ = gxml_collection_create_item ((GXmlCollection*) _tmp74_);
#line 1241 "GomSerializationTest.vala"
		_tmp76_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp75_, TYPE_OPERATION) ? ((Operation*) _tmp75_) : NULL;
#line 1241 "GomSerializationTest.vala"
		if (_tmp76_ == NULL) {
#line 1241 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp75_);
#line 13821 "GomSerializationTest.c"
		}
#line 1241 "GomSerializationTest.vala"
		op4 = _tmp76_;
#line 1242 "GomSerializationTest.vala"
		_tmp77_ = op4;
#line 1242 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp77_, TYPE_OPERATION), "op4 is Operation");
#line 1243 "GomSerializationTest.vala"
		_tmp78_ = op4;
#line 1243 "GomSerializationTest.vala"
		operation_set_id (_tmp78_, "a2");
#line 1244 "GomSerializationTest.vala"
		_tmp79_ = op4;
#line 1244 "GomSerializationTest.vala"
		operation_set_code (_tmp79_, "b2");
#line 1245 "GomSerializationTest.vala"
		_tmp80_ = ops;
#line 1245 "GomSerializationTest.vala"
		_tmp81_ = operations_get_map (_tmp80_);
#line 1245 "GomSerializationTest.vala"
		_tmp82_ = _tmp81_;
#line 1245 "GomSerializationTest.vala"
		_tmp83_ = op4;
#line 1245 "GomSerializationTest.vala"
		gxml_collection_append ((GXmlCollection*) _tmp82_, (GXmlDomElement*) _tmp83_, &_inner_error0_);
#line 1245 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1245 "GomSerializationTest.vala"
			_g_object_unref0 (op4);
#line 1245 "GomSerializationTest.vala"
			_g_object_unref0 (op3);
#line 1245 "GomSerializationTest.vala"
			_g_object_unref0 (op2);
#line 1245 "GomSerializationTest.vala"
			(pkeys1 == NULL) ? NULL : (pkeys1 = (_g_list_free__g_free0_ (pkeys1), NULL));
#line 1245 "GomSerializationTest.vala"
			_g_object_unref0 (top1);
#line 1245 "GomSerializationTest.vala"
			_g_object_unref0 (op1);
#line 1245 "GomSerializationTest.vala"
			_g_object_unref0 (ops);
#line 13863 "GomSerializationTest.c"
			goto __catch191_g_error;
		}
#line 1246 "GomSerializationTest.vala"
		_tmp84_ = ops;
#line 1246 "GomSerializationTest.vala"
		_tmp85_ = operations_get_map (_tmp84_);
#line 1246 "GomSerializationTest.vala"
		_tmp86_ = _tmp85_;
#line 1246 "GomSerializationTest.vala"
		_tmp87_ = gxml_collection_get_length ((GXmlCollection*) _tmp86_);
#line 1246 "GomSerializationTest.vala"
		_tmp88_ = _tmp87_;
#line 1246 "GomSerializationTest.vala"
		_vala_assert (_tmp88_ == 4, "ops.map.length == 4");
#line 1247 "GomSerializationTest.vala"
		_tmp90_ = ops;
#line 1247 "GomSerializationTest.vala"
		_tmp91_ = gxml_dom_element_write_string ((GXmlDomElement*) _tmp90_, NULL, &_inner_error0_);
#line 1247 "GomSerializationTest.vala"
		_tmp89_ = _tmp91_;
#line 1247 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1247 "GomSerializationTest.vala"
			_g_object_unref0 (op4);
#line 1247 "GomSerializationTest.vala"
			_g_object_unref0 (op3);
#line 1247 "GomSerializationTest.vala"
			_g_object_unref0 (op2);
#line 1247 "GomSerializationTest.vala"
			(pkeys1 == NULL) ? NULL : (pkeys1 = (_g_list_free__g_free0_ (pkeys1), NULL));
#line 1247 "GomSerializationTest.vala"
			_g_object_unref0 (top1);
#line 1247 "GomSerializationTest.vala"
			_g_object_unref0 (op1);
#line 1247 "GomSerializationTest.vala"
			_g_object_unref0 (ops);
#line 13900 "GomSerializationTest.c"
			goto __catch191_g_error;
		}
#line 1247 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1247: %s", _tmp89_);
#line 1248 "GomSerializationTest.vala"
		_tmp92_ = ops;
#line 1248 "GomSerializationTest.vala"
		_tmp93_ = operations_get_map (_tmp92_);
#line 1248 "GomSerializationTest.vala"
		_tmp94_ = _tmp93_;
#line 1248 "GomSerializationTest.vala"
		_tmp95_ = gxml_gom_hash_paired_map_get_primary_keys ((GXmlGomHashPairedMap*) _tmp94_);
#line 1248 "GomSerializationTest.vala"
		pkeys2 = _tmp95_;
#line 1249 "GomSerializationTest.vala"
		_tmp96_ = pkeys2;
#line 1249 "GomSerializationTest.vala"
		_vala_assert (g_list_length (_tmp96_) == ((guint) 2), "pkeys2.length () == 2");
#line 1250 "GomSerializationTest.vala"
		_tmp97_ = pkeys2;
#line 13921 "GomSerializationTest.c"
		{
			GList* pk_collection = NULL;
			GList* pk_it = NULL;
#line 1250 "GomSerializationTest.vala"
			pk_collection = _tmp97_;
#line 1250 "GomSerializationTest.vala"
			for (pk_it = pk_collection; pk_it != NULL; pk_it = pk_it->next) {
#line 13929 "GomSerializationTest.c"
				gchar* _tmp98_;
				gchar* pk = NULL;
#line 1250 "GomSerializationTest.vala"
				_tmp98_ = g_strdup ((const gchar*) pk_it->data);
#line 1250 "GomSerializationTest.vala"
				pk = _tmp98_;
#line 13936 "GomSerializationTest.c"
				{
					const gchar* _tmp99_;
#line 1250 "GomSerializationTest.vala"
					_tmp99_ = pk;
#line 1250 "GomSerializationTest.vala"
					g_message ("GomSerializationTest.vala:1250: %s", _tmp99_);
#line 1250 "GomSerializationTest.vala"
					_g_free0 (pk);
#line 13945 "GomSerializationTest.c"
				}
			}
		}
#line 1251 "GomSerializationTest.vala"
		_tmp100_ = ops;
#line 1251 "GomSerializationTest.vala"
		_tmp101_ = operations_get_map (_tmp100_);
#line 1251 "GomSerializationTest.vala"
		_tmp102_ = _tmp101_;
#line 1251 "GomSerializationTest.vala"
		_tmp103_ = gxml_gom_hash_paired_map_get_secondary_keys ((GXmlGomHashPairedMap*) _tmp102_, "a1");
#line 1251 "GomSerializationTest.vala"
		skeys1 = _tmp103_;
#line 1252 "GomSerializationTest.vala"
		_tmp104_ = skeys1;
#line 13961 "GomSerializationTest.c"
		{
			GList* pk_collection = NULL;
			GList* pk_it = NULL;
#line 1252 "GomSerializationTest.vala"
			pk_collection = _tmp104_;
#line 1252 "GomSerializationTest.vala"
			for (pk_it = pk_collection; pk_it != NULL; pk_it = pk_it->next) {
#line 13969 "GomSerializationTest.c"
				gchar* _tmp105_;
				gchar* pk = NULL;
#line 1252 "GomSerializationTest.vala"
				_tmp105_ = g_strdup ((const gchar*) pk_it->data);
#line 1252 "GomSerializationTest.vala"
				pk = _tmp105_;
#line 13976 "GomSerializationTest.c"
				{
					const gchar* _tmp106_;
#line 1252 "GomSerializationTest.vala"
					_tmp106_ = pk;
#line 1252 "GomSerializationTest.vala"
					g_message ("GomSerializationTest.vala:1252: %s", _tmp106_);
#line 1252 "GomSerializationTest.vala"
					_g_free0 (pk);
#line 13985 "GomSerializationTest.c"
				}
			}
		}
#line 1253 "GomSerializationTest.vala"
		_tmp107_ = skeys1;
#line 1253 "GomSerializationTest.vala"
		_vala_assert (g_list_length (_tmp107_) == ((guint) 2), "skeys1.length () == 2");
#line 1254 "GomSerializationTest.vala"
		_tmp108_ = op4;
#line 1254 "GomSerializationTest.vala"
		gxml_dom_child_node_remove ((GXmlDomChildNode*) _tmp108_);
#line 1255 "GomSerializationTest.vala"
		_tmp109_ = ops;
#line 1255 "GomSerializationTest.vala"
		_tmp110_ = operations_get_map (_tmp109_);
#line 1255 "GomSerializationTest.vala"
		_tmp111_ = _tmp110_;
#line 1255 "GomSerializationTest.vala"
		gxml_collection_search ((GXmlCollection*) _tmp111_, &_inner_error0_);
#line 1255 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1255 "GomSerializationTest.vala"
			(skeys1 == NULL) ? NULL : (skeys1 = (_g_list_free__g_free0_ (skeys1), NULL));
#line 1255 "GomSerializationTest.vala"
			(pkeys2 == NULL) ? NULL : (pkeys2 = (_g_list_free__g_free0_ (pkeys2), NULL));
#line 1255 "GomSerializationTest.vala"
			_g_free0 (_tmp89_);
#line 1255 "GomSerializationTest.vala"
			_g_object_unref0 (op4);
#line 1255 "GomSerializationTest.vala"
			_g_object_unref0 (op3);
#line 1255 "GomSerializationTest.vala"
			_g_object_unref0 (op2);
#line 1255 "GomSerializationTest.vala"
			(pkeys1 == NULL) ? NULL : (pkeys1 = (_g_list_free__g_free0_ (pkeys1), NULL));
#line 1255 "GomSerializationTest.vala"
			_g_object_unref0 (top1);
#line 1255 "GomSerializationTest.vala"
			_g_object_unref0 (op1);
#line 1255 "GomSerializationTest.vala"
			_g_object_unref0 (ops);
#line 14027 "GomSerializationTest.c"
			goto __catch191_g_error;
		}
#line 1256 "GomSerializationTest.vala"
		_tmp112_ = ops;
#line 1256 "GomSerializationTest.vala"
		_tmp113_ = operations_get_map (_tmp112_);
#line 1256 "GomSerializationTest.vala"
		_tmp114_ = _tmp113_;
#line 1256 "GomSerializationTest.vala"
		_tmp115_ = gxml_collection_get_length ((GXmlCollection*) _tmp114_);
#line 1256 "GomSerializationTest.vala"
		_tmp116_ = _tmp115_;
#line 1256 "GomSerializationTest.vala"
		_vala_assert (_tmp116_ == 3, "ops.map.length == 3");
#line 1257 "GomSerializationTest.vala"
		_tmp117_ = ops;
#line 1257 "GomSerializationTest.vala"
		_tmp118_ = operations_get_map (_tmp117_);
#line 1257 "GomSerializationTest.vala"
		_tmp119_ = _tmp118_;
#line 1257 "GomSerializationTest.vala"
		_tmp120_ = gxml_gom_hash_paired_map_get ((GXmlGomHashPairedMap*) _tmp119_, "a2", "b1");
#line 1257 "GomSerializationTest.vala"
		op3t = _tmp120_;
#line 1258 "GomSerializationTest.vala"
		_vala_assert (op3t != NULL, "op3t != null");
#line 1214 "GomSerializationTest.vala"
		_g_object_unref0 (op3t);
#line 1214 "GomSerializationTest.vala"
		(skeys1 == NULL) ? NULL : (skeys1 = (_g_list_free__g_free0_ (skeys1), NULL));
#line 1214 "GomSerializationTest.vala"
		(pkeys2 == NULL) ? NULL : (pkeys2 = (_g_list_free__g_free0_ (pkeys2), NULL));
#line 1214 "GomSerializationTest.vala"
		_g_free0 (_tmp89_);
#line 1214 "GomSerializationTest.vala"
		_g_object_unref0 (op4);
#line 1214 "GomSerializationTest.vala"
		_g_object_unref0 (op3);
#line 1214 "GomSerializationTest.vala"
		_g_object_unref0 (op2);
#line 1214 "GomSerializationTest.vala"
		(pkeys1 == NULL) ? NULL : (pkeys1 = (_g_list_free__g_free0_ (pkeys1), NULL));
#line 1214 "GomSerializationTest.vala"
		_g_object_unref0 (top1);
#line 1214 "GomSerializationTest.vala"
		_g_object_unref0 (op1);
#line 1214 "GomSerializationTest.vala"
		_g_object_unref0 (ops);
#line 14076 "GomSerializationTest.c"
	}
	goto __finally191;
	__catch191_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp121_;
		gchar* _tmp122_;
		gchar* _tmp123_;
#line 1214 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 1214 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 1260 "GomSerializationTest.vala"
		_tmp121_ = e->message;
#line 1260 "GomSerializationTest.vala"
		_tmp122_ = g_strconcat ("ERROR: ", _tmp121_, NULL);
#line 1260 "GomSerializationTest.vala"
		_tmp123_ = _tmp122_;
#line 1260 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1260: %s", _tmp123_);
#line 1260 "GomSerializationTest.vala"
		_g_free0 (_tmp123_);
#line 1261 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 1214 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 14103 "GomSerializationTest.c"
	}
	__finally191:
#line 1214 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1214 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 1214 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 1214 "GomSerializationTest.vala"
		return;
#line 14114 "GomSerializationTest.c"
	}
}

static void
___lambda138__gtest_func (void)
{
#line 1212 "GomSerializationTest.vala"
	__lambda138_ ();
#line 14123 "GomSerializationTest.c"
}

static void
__lambda139_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		ThreeKeys* ks = NULL;
		ThreeKeys* _tmp0_;
		ThreeKeys* _tmp1_;
		ThreeKeyMap* _tmp2_;
		ThreeKeyMap* _tmp3_;
		ThreeKeys* _tmp4_;
		ThreeKeyMap* _tmp5_;
		ThreeKeyMap* _tmp6_;
		gint _tmp7_;
		gint _tmp8_;
		ThreeKey* k1 = NULL;
		ThreeKeys* _tmp9_;
		ThreeKeyMap* _tmp10_;
		ThreeKeyMap* _tmp11_;
		GXmlDomElement* _tmp12_;
		ThreeKey* _tmp13_;
		ThreeKey* _tmp14_;
		ThreeKey* _tmp15_;
		ThreeKey* _tmp16_;
		ThreeKey* _tmp17_;
		ThreeKeys* _tmp18_;
		ThreeKeyMap* _tmp19_;
		ThreeKeyMap* _tmp20_;
		ThreeKey* _tmp21_;
		ThreeKeys* _tmp22_;
		ThreeKeyMap* _tmp23_;
		ThreeKeyMap* _tmp24_;
		gint _tmp25_;
		gint _tmp26_;
		ThreeKey* tk1 = NULL;
		ThreeKeys* _tmp27_;
		ThreeKeyMap* _tmp28_;
		ThreeKeyMap* _tmp29_;
		GXmlDomElement* _tmp30_;
		ThreeKey* _tmp31_;
		ThreeKey* _tmp32_;
		ThreeKey* _tmp33_;
		const gchar* _tmp34_;
		const gchar* _tmp35_;
		ThreeKey* _tmp36_;
		const gchar* _tmp37_;
		const gchar* _tmp38_;
		ThreeKey* _tmp39_;
		const gchar* _tmp40_;
		const gchar* _tmp41_;
		GList* pkeys1 = NULL;
		ThreeKeys* _tmp42_;
		ThreeKeyMap* _tmp43_;
		ThreeKeyMap* _tmp44_;
		GList* _tmp45_;
		GList* _tmp46_;
		ThreeKey* k2 = NULL;
		ThreeKeys* _tmp47_;
		ThreeKeyMap* _tmp48_;
		ThreeKeyMap* _tmp49_;
		GXmlDomElement* _tmp50_;
		ThreeKey* _tmp51_;
		ThreeKey* _tmp52_;
		ThreeKey* _tmp53_;
		ThreeKey* _tmp54_;
		ThreeKey* _tmp55_;
		ThreeKeys* _tmp56_;
		ThreeKeyMap* _tmp57_;
		ThreeKeyMap* _tmp58_;
		ThreeKey* _tmp59_;
		ThreeKey* k3 = NULL;
		ThreeKeys* _tmp60_;
		ThreeKeyMap* _tmp61_;
		ThreeKeyMap* _tmp62_;
		GXmlDomElement* _tmp63_;
		ThreeKey* _tmp64_;
		ThreeKey* _tmp65_;
		ThreeKey* _tmp66_;
		ThreeKey* _tmp67_;
		ThreeKey* _tmp68_;
		ThreeKeys* _tmp69_;
		ThreeKeyMap* _tmp70_;
		ThreeKeyMap* _tmp71_;
		ThreeKey* _tmp72_;
		ThreeKeys* _tmp73_;
		ThreeKeyMap* _tmp74_;
		ThreeKeyMap* _tmp75_;
		gint _tmp76_;
		gint _tmp77_;
		ThreeKey* k4 = NULL;
		ThreeKeys* _tmp78_;
		ThreeKeyMap* _tmp79_;
		ThreeKeyMap* _tmp80_;
		GXmlDomElement* _tmp81_;
		ThreeKey* _tmp82_;
		ThreeKey* _tmp83_;
		ThreeKey* _tmp84_;
		ThreeKey* _tmp85_;
		ThreeKey* _tmp86_;
		ThreeKeys* _tmp87_;
		ThreeKeyMap* _tmp88_;
		ThreeKeyMap* _tmp89_;
		ThreeKey* _tmp90_;
		ThreeKeys* _tmp91_;
		ThreeKeyMap* _tmp92_;
		ThreeKeyMap* _tmp93_;
		gint _tmp94_;
		gint _tmp95_;
		gchar* _tmp96_ = NULL;
		ThreeKeys* _tmp97_;
		gchar* _tmp98_;
		GList* pkeys2 = NULL;
		ThreeKeys* _tmp99_;
		ThreeKeyMap* _tmp100_;
		ThreeKeyMap* _tmp101_;
		GList* _tmp102_;
		GList* _tmp103_;
		GList* _tmp104_;
		GList* skeys1 = NULL;
		ThreeKeys* _tmp107_;
		ThreeKeyMap* _tmp108_;
		ThreeKeyMap* _tmp109_;
		GList* _tmp110_;
		GList* _tmp111_;
		GList* _tmp114_;
		ThreeKey* _tmp115_;
		ThreeKeys* _tmp116_;
		ThreeKeyMap* _tmp117_;
		ThreeKeyMap* _tmp118_;
		GXmlDomElement* k3t = NULL;
		ThreeKeys* _tmp119_;
		ThreeKeyMap* _tmp120_;
		ThreeKeyMap* _tmp121_;
		GXmlDomElement* _tmp122_;
#line 1267 "GomSerializationTest.vala"
		_tmp0_ = three_keys_new ();
#line 1267 "GomSerializationTest.vala"
		ks = _tmp0_;
#line 1268 "GomSerializationTest.vala"
		_tmp1_ = ks;
#line 1268 "GomSerializationTest.vala"
		_tmp2_ = three_keys_get_map (_tmp1_);
#line 1268 "GomSerializationTest.vala"
		_tmp3_ = _tmp2_;
#line 1268 "GomSerializationTest.vala"
		_vala_assert (_tmp3_ != NULL, "ks.map != null");
#line 1269 "GomSerializationTest.vala"
		_tmp4_ = ks;
#line 1269 "GomSerializationTest.vala"
		_tmp5_ = three_keys_get_map (_tmp4_);
#line 1269 "GomSerializationTest.vala"
		_tmp6_ = _tmp5_;
#line 1269 "GomSerializationTest.vala"
		_tmp7_ = gxml_collection_get_length ((GXmlCollection*) _tmp6_);
#line 1269 "GomSerializationTest.vala"
		_tmp8_ = _tmp7_;
#line 1269 "GomSerializationTest.vala"
		_vala_assert (_tmp8_ == 0, "ks.map.length == 0");
#line 1270 "GomSerializationTest.vala"
		_tmp9_ = ks;
#line 1270 "GomSerializationTest.vala"
		_tmp10_ = three_keys_get_map (_tmp9_);
#line 1270 "GomSerializationTest.vala"
		_tmp11_ = _tmp10_;
#line 1270 "GomSerializationTest.vala"
		_tmp12_ = gxml_collection_create_item ((GXmlCollection*) _tmp11_);
#line 1270 "GomSerializationTest.vala"
		_tmp13_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, TYPE_THREE_KEY) ? ((ThreeKey*) _tmp12_) : NULL;
#line 1270 "GomSerializationTest.vala"
		if (_tmp13_ == NULL) {
#line 1270 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp12_);
#line 14298 "GomSerializationTest.c"
		}
#line 1270 "GomSerializationTest.vala"
		k1 = _tmp13_;
#line 1271 "GomSerializationTest.vala"
		_tmp14_ = k1;
#line 1271 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp14_, TYPE_THREE_KEY), "k1 is ThreeKey");
#line 1272 "GomSerializationTest.vala"
		_tmp15_ = k1;
#line 1272 "GomSerializationTest.vala"
		three_key_set_id (_tmp15_, "a1");
#line 1273 "GomSerializationTest.vala"
		_tmp16_ = k1;
#line 1273 "GomSerializationTest.vala"
		three_key_set_code (_tmp16_, "b1");
#line 1274 "GomSerializationTest.vala"
		_tmp17_ = k1;
#line 1274 "GomSerializationTest.vala"
		three_key_set_name (_tmp17_, "name1");
#line 1275 "GomSerializationTest.vala"
		_tmp18_ = ks;
#line 1275 "GomSerializationTest.vala"
		_tmp19_ = three_keys_get_map (_tmp18_);
#line 1275 "GomSerializationTest.vala"
		_tmp20_ = _tmp19_;
#line 1275 "GomSerializationTest.vala"
		_tmp21_ = k1;
#line 1275 "GomSerializationTest.vala"
		gxml_collection_append ((GXmlCollection*) _tmp20_, (GXmlDomElement*) _tmp21_, &_inner_error0_);
#line 1275 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1275 "GomSerializationTest.vala"
			_g_object_unref0 (k1);
#line 1275 "GomSerializationTest.vala"
			_g_object_unref0 (ks);
#line 14334 "GomSerializationTest.c"
			goto __catch192_g_error;
		}
#line 1276 "GomSerializationTest.vala"
		_tmp22_ = ks;
#line 1276 "GomSerializationTest.vala"
		_tmp23_ = three_keys_get_map (_tmp22_);
#line 1276 "GomSerializationTest.vala"
		_tmp24_ = _tmp23_;
#line 1276 "GomSerializationTest.vala"
		_tmp25_ = gxml_collection_get_length ((GXmlCollection*) _tmp24_);
#line 1276 "GomSerializationTest.vala"
		_tmp26_ = _tmp25_;
#line 1276 "GomSerializationTest.vala"
		_vala_assert (_tmp26_ == 1, "ks.map.length == 1");
#line 1277 "GomSerializationTest.vala"
		_tmp27_ = ks;
#line 1277 "GomSerializationTest.vala"
		_tmp28_ = three_keys_get_map (_tmp27_);
#line 1277 "GomSerializationTest.vala"
		_tmp29_ = _tmp28_;
#line 1277 "GomSerializationTest.vala"
		_tmp30_ = gxml_gom_hash_three_map_get ((GXmlGomHashThreeMap*) _tmp29_, "a1", "b1", "name1");
#line 1277 "GomSerializationTest.vala"
		_tmp31_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp30_, TYPE_THREE_KEY) ? ((ThreeKey*) _tmp30_) : NULL;
#line 1277 "GomSerializationTest.vala"
		if (_tmp31_ == NULL) {
#line 1277 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp30_);
#line 14363 "GomSerializationTest.c"
		}
#line 1277 "GomSerializationTest.vala"
		tk1 = _tmp31_;
#line 1278 "GomSerializationTest.vala"
		_tmp32_ = tk1;
#line 1278 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp32_, TYPE_THREE_KEY), "tk1 is ThreeKey");
#line 1279 "GomSerializationTest.vala"
		_tmp33_ = tk1;
#line 1279 "GomSerializationTest.vala"
		_tmp34_ = three_key_get_id (_tmp33_);
#line 1279 "GomSerializationTest.vala"
		_tmp35_ = _tmp34_;
#line 1279 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp35_, "a1") == 0, "tk1.id == \"a1\"");
#line 1280 "GomSerializationTest.vala"
		_tmp36_ = tk1;
#line 1280 "GomSerializationTest.vala"
		_tmp37_ = three_key_get_code (_tmp36_);
#line 1280 "GomSerializationTest.vala"
		_tmp38_ = _tmp37_;
#line 1280 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp38_, "b1") == 0, "tk1.code == \"b1\"");
#line 1281 "GomSerializationTest.vala"
		_tmp39_ = tk1;
#line 1281 "GomSerializationTest.vala"
		_tmp40_ = three_key_get_name (_tmp39_);
#line 1281 "GomSerializationTest.vala"
		_tmp41_ = _tmp40_;
#line 1281 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp41_, "name1") == 0, "tk1.name == \"name1\"");
#line 1282 "GomSerializationTest.vala"
		_tmp42_ = ks;
#line 1282 "GomSerializationTest.vala"
		_tmp43_ = three_keys_get_map (_tmp42_);
#line 1282 "GomSerializationTest.vala"
		_tmp44_ = _tmp43_;
#line 1282 "GomSerializationTest.vala"
		_tmp45_ = gxml_gom_hash_three_map_get_primary_keys ((GXmlGomHashThreeMap*) _tmp44_);
#line 1282 "GomSerializationTest.vala"
		pkeys1 = _tmp45_;
#line 1283 "GomSerializationTest.vala"
		_tmp46_ = pkeys1;
#line 1283 "GomSerializationTest.vala"
		_vala_assert (g_list_length (_tmp46_) == ((guint) 1), "pkeys1.length () == 1");
#line 1284 "GomSerializationTest.vala"
		_tmp47_ = ks;
#line 1284 "GomSerializationTest.vala"
		_tmp48_ = three_keys_get_map (_tmp47_);
#line 1284 "GomSerializationTest.vala"
		_tmp49_ = _tmp48_;
#line 1284 "GomSerializationTest.vala"
		_tmp50_ = gxml_collection_create_item ((GXmlCollection*) _tmp49_);
#line 1284 "GomSerializationTest.vala"
		_tmp51_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp50_, TYPE_THREE_KEY) ? ((ThreeKey*) _tmp50_) : NULL;
#line 1284 "GomSerializationTest.vala"
		if (_tmp51_ == NULL) {
#line 1284 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp50_);
#line 14423 "GomSerializationTest.c"
		}
#line 1284 "GomSerializationTest.vala"
		k2 = _tmp51_;
#line 1285 "GomSerializationTest.vala"
		_tmp52_ = k2;
#line 1285 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp52_, TYPE_THREE_KEY), "k2 is ThreeKey");
#line 1286 "GomSerializationTest.vala"
		_tmp53_ = k2;
#line 1286 "GomSerializationTest.vala"
		three_key_set_id (_tmp53_, "a1");
#line 1287 "GomSerializationTest.vala"
		_tmp54_ = k2;
#line 1287 "GomSerializationTest.vala"
		three_key_set_code (_tmp54_, "b2");
#line 1288 "GomSerializationTest.vala"
		_tmp55_ = k2;
#line 1288 "GomSerializationTest.vala"
		three_key_set_name (_tmp55_, "name2");
#line 1289 "GomSerializationTest.vala"
		_tmp56_ = ks;
#line 1289 "GomSerializationTest.vala"
		_tmp57_ = three_keys_get_map (_tmp56_);
#line 1289 "GomSerializationTest.vala"
		_tmp58_ = _tmp57_;
#line 1289 "GomSerializationTest.vala"
		_tmp59_ = k2;
#line 1289 "GomSerializationTest.vala"
		gxml_collection_append ((GXmlCollection*) _tmp58_, (GXmlDomElement*) _tmp59_, &_inner_error0_);
#line 1289 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1289 "GomSerializationTest.vala"
			_g_object_unref0 (k2);
#line 1289 "GomSerializationTest.vala"
			(pkeys1 == NULL) ? NULL : (pkeys1 = (_g_list_free__g_free0_ (pkeys1), NULL));
#line 1289 "GomSerializationTest.vala"
			_g_object_unref0 (tk1);
#line 1289 "GomSerializationTest.vala"
			_g_object_unref0 (k1);
#line 1289 "GomSerializationTest.vala"
			_g_object_unref0 (ks);
#line 14465 "GomSerializationTest.c"
			goto __catch192_g_error;
		}
#line 1290 "GomSerializationTest.vala"
		_tmp60_ = ks;
#line 1290 "GomSerializationTest.vala"
		_tmp61_ = three_keys_get_map (_tmp60_);
#line 1290 "GomSerializationTest.vala"
		_tmp62_ = _tmp61_;
#line 1290 "GomSerializationTest.vala"
		_tmp63_ = gxml_collection_create_item ((GXmlCollection*) _tmp62_);
#line 1290 "GomSerializationTest.vala"
		_tmp64_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp63_, TYPE_THREE_KEY) ? ((ThreeKey*) _tmp63_) : NULL;
#line 1290 "GomSerializationTest.vala"
		if (_tmp64_ == NULL) {
#line 1290 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp63_);
#line 14482 "GomSerializationTest.c"
		}
#line 1290 "GomSerializationTest.vala"
		k3 = _tmp64_;
#line 1291 "GomSerializationTest.vala"
		_tmp65_ = k3;
#line 1291 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp65_, TYPE_THREE_KEY), "k3 is ThreeKey");
#line 1292 "GomSerializationTest.vala"
		_tmp66_ = k3;
#line 1292 "GomSerializationTest.vala"
		three_key_set_id (_tmp66_, "a2");
#line 1293 "GomSerializationTest.vala"
		_tmp67_ = k3;
#line 1293 "GomSerializationTest.vala"
		three_key_set_code (_tmp67_, "b1");
#line 1294 "GomSerializationTest.vala"
		_tmp68_ = k3;
#line 1294 "GomSerializationTest.vala"
		three_key_set_name (_tmp68_, "name3");
#line 1295 "GomSerializationTest.vala"
		_tmp69_ = ks;
#line 1295 "GomSerializationTest.vala"
		_tmp70_ = three_keys_get_map (_tmp69_);
#line 1295 "GomSerializationTest.vala"
		_tmp71_ = _tmp70_;
#line 1295 "GomSerializationTest.vala"
		_tmp72_ = k3;
#line 1295 "GomSerializationTest.vala"
		gxml_collection_append ((GXmlCollection*) _tmp71_, (GXmlDomElement*) _tmp72_, &_inner_error0_);
#line 1295 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1295 "GomSerializationTest.vala"
			_g_object_unref0 (k3);
#line 1295 "GomSerializationTest.vala"
			_g_object_unref0 (k2);
#line 1295 "GomSerializationTest.vala"
			(pkeys1 == NULL) ? NULL : (pkeys1 = (_g_list_free__g_free0_ (pkeys1), NULL));
#line 1295 "GomSerializationTest.vala"
			_g_object_unref0 (tk1);
#line 1295 "GomSerializationTest.vala"
			_g_object_unref0 (k1);
#line 1295 "GomSerializationTest.vala"
			_g_object_unref0 (ks);
#line 14526 "GomSerializationTest.c"
			goto __catch192_g_error;
		}
#line 1296 "GomSerializationTest.vala"
		_tmp73_ = ks;
#line 1296 "GomSerializationTest.vala"
		_tmp74_ = three_keys_get_map (_tmp73_);
#line 1296 "GomSerializationTest.vala"
		_tmp75_ = _tmp74_;
#line 1296 "GomSerializationTest.vala"
		_tmp76_ = gxml_collection_get_length ((GXmlCollection*) _tmp75_);
#line 1296 "GomSerializationTest.vala"
		_tmp77_ = _tmp76_;
#line 1296 "GomSerializationTest.vala"
		_vala_assert (_tmp77_ == 3, "ks.map.length == 3");
#line 1297 "GomSerializationTest.vala"
		_tmp78_ = ks;
#line 1297 "GomSerializationTest.vala"
		_tmp79_ = three_keys_get_map (_tmp78_);
#line 1297 "GomSerializationTest.vala"
		_tmp80_ = _tmp79_;
#line 1297 "GomSerializationTest.vala"
		_tmp81_ = gxml_collection_create_item ((GXmlCollection*) _tmp80_);
#line 1297 "GomSerializationTest.vala"
		_tmp82_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp81_, TYPE_THREE_KEY) ? ((ThreeKey*) _tmp81_) : NULL;
#line 1297 "GomSerializationTest.vala"
		if (_tmp82_ == NULL) {
#line 1297 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp81_);
#line 14555 "GomSerializationTest.c"
		}
#line 1297 "GomSerializationTest.vala"
		k4 = _tmp82_;
#line 1298 "GomSerializationTest.vala"
		_tmp83_ = k4;
#line 1298 "GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp83_, TYPE_THREE_KEY), "k4 is ThreeKey");
#line 1299 "GomSerializationTest.vala"
		_tmp84_ = k4;
#line 1299 "GomSerializationTest.vala"
		three_key_set_id (_tmp84_, "a2");
#line 1300 "GomSerializationTest.vala"
		_tmp85_ = k4;
#line 1300 "GomSerializationTest.vala"
		three_key_set_code (_tmp85_, "b2");
#line 1301 "GomSerializationTest.vala"
		_tmp86_ = k4;
#line 1301 "GomSerializationTest.vala"
		three_key_set_name (_tmp86_, "name3");
#line 1302 "GomSerializationTest.vala"
		_tmp87_ = ks;
#line 1302 "GomSerializationTest.vala"
		_tmp88_ = three_keys_get_map (_tmp87_);
#line 1302 "GomSerializationTest.vala"
		_tmp89_ = _tmp88_;
#line 1302 "GomSerializationTest.vala"
		_tmp90_ = k4;
#line 1302 "GomSerializationTest.vala"
		gxml_collection_append ((GXmlCollection*) _tmp89_, (GXmlDomElement*) _tmp90_, &_inner_error0_);
#line 1302 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1302 "GomSerializationTest.vala"
			_g_object_unref0 (k4);
#line 1302 "GomSerializationTest.vala"
			_g_object_unref0 (k3);
#line 1302 "GomSerializationTest.vala"
			_g_object_unref0 (k2);
#line 1302 "GomSerializationTest.vala"
			(pkeys1 == NULL) ? NULL : (pkeys1 = (_g_list_free__g_free0_ (pkeys1), NULL));
#line 1302 "GomSerializationTest.vala"
			_g_object_unref0 (tk1);
#line 1302 "GomSerializationTest.vala"
			_g_object_unref0 (k1);
#line 1302 "GomSerializationTest.vala"
			_g_object_unref0 (ks);
#line 14601 "GomSerializationTest.c"
			goto __catch192_g_error;
		}
#line 1303 "GomSerializationTest.vala"
		_tmp91_ = ks;
#line 1303 "GomSerializationTest.vala"
		_tmp92_ = three_keys_get_map (_tmp91_);
#line 1303 "GomSerializationTest.vala"
		_tmp93_ = _tmp92_;
#line 1303 "GomSerializationTest.vala"
		_tmp94_ = gxml_collection_get_length ((GXmlCollection*) _tmp93_);
#line 1303 "GomSerializationTest.vala"
		_tmp95_ = _tmp94_;
#line 1303 "GomSerializationTest.vala"
		_vala_assert (_tmp95_ == 4, "ks.map.length == 4");
#line 1304 "GomSerializationTest.vala"
		_tmp97_ = ks;
#line 1304 "GomSerializationTest.vala"
		_tmp98_ = gxml_dom_element_write_string ((GXmlDomElement*) _tmp97_, NULL, &_inner_error0_);
#line 1304 "GomSerializationTest.vala"
		_tmp96_ = _tmp98_;
#line 1304 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1304 "GomSerializationTest.vala"
			_g_object_unref0 (k4);
#line 1304 "GomSerializationTest.vala"
			_g_object_unref0 (k3);
#line 1304 "GomSerializationTest.vala"
			_g_object_unref0 (k2);
#line 1304 "GomSerializationTest.vala"
			(pkeys1 == NULL) ? NULL : (pkeys1 = (_g_list_free__g_free0_ (pkeys1), NULL));
#line 1304 "GomSerializationTest.vala"
			_g_object_unref0 (tk1);
#line 1304 "GomSerializationTest.vala"
			_g_object_unref0 (k1);
#line 1304 "GomSerializationTest.vala"
			_g_object_unref0 (ks);
#line 14638 "GomSerializationTest.c"
			goto __catch192_g_error;
		}
#line 1304 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1304: %s", _tmp96_);
#line 1305 "GomSerializationTest.vala"
		_tmp99_ = ks;
#line 1305 "GomSerializationTest.vala"
		_tmp100_ = three_keys_get_map (_tmp99_);
#line 1305 "GomSerializationTest.vala"
		_tmp101_ = _tmp100_;
#line 1305 "GomSerializationTest.vala"
		_tmp102_ = gxml_gom_hash_three_map_get_primary_keys ((GXmlGomHashThreeMap*) _tmp101_);
#line 1305 "GomSerializationTest.vala"
		pkeys2 = _tmp102_;
#line 1306 "GomSerializationTest.vala"
		_tmp103_ = pkeys2;
#line 1306 "GomSerializationTest.vala"
		_vala_assert (g_list_length (_tmp103_) == ((guint) 2), "pkeys2.length () == 2");
#line 1307 "GomSerializationTest.vala"
		_tmp104_ = pkeys2;
#line 14659 "GomSerializationTest.c"
		{
			GList* pk_collection = NULL;
			GList* pk_it = NULL;
#line 1307 "GomSerializationTest.vala"
			pk_collection = _tmp104_;
#line 1307 "GomSerializationTest.vala"
			for (pk_it = pk_collection; pk_it != NULL; pk_it = pk_it->next) {
#line 14667 "GomSerializationTest.c"
				gchar* _tmp105_;
				gchar* pk = NULL;
#line 1307 "GomSerializationTest.vala"
				_tmp105_ = g_strdup ((const gchar*) pk_it->data);
#line 1307 "GomSerializationTest.vala"
				pk = _tmp105_;
#line 14674 "GomSerializationTest.c"
				{
					const gchar* _tmp106_;
#line 1307 "GomSerializationTest.vala"
					_tmp106_ = pk;
#line 1307 "GomSerializationTest.vala"
					g_message ("GomSerializationTest.vala:1307: %s", _tmp106_);
#line 1307 "GomSerializationTest.vala"
					_g_free0 (pk);
#line 14683 "GomSerializationTest.c"
				}
			}
		}
#line 1308 "GomSerializationTest.vala"
		_tmp107_ = ks;
#line 1308 "GomSerializationTest.vala"
		_tmp108_ = three_keys_get_map (_tmp107_);
#line 1308 "GomSerializationTest.vala"
		_tmp109_ = _tmp108_;
#line 1308 "GomSerializationTest.vala"
		_tmp110_ = gxml_gom_hash_three_map_get_secondary_keys ((GXmlGomHashThreeMap*) _tmp109_, "a1");
#line 1308 "GomSerializationTest.vala"
		skeys1 = _tmp110_;
#line 1309 "GomSerializationTest.vala"
		_tmp111_ = skeys1;
#line 14699 "GomSerializationTest.c"
		{
			GList* pk_collection = NULL;
			GList* pk_it = NULL;
#line 1309 "GomSerializationTest.vala"
			pk_collection = _tmp111_;
#line 1309 "GomSerializationTest.vala"
			for (pk_it = pk_collection; pk_it != NULL; pk_it = pk_it->next) {
#line 14707 "GomSerializationTest.c"
				gchar* _tmp112_;
				gchar* pk = NULL;
#line 1309 "GomSerializationTest.vala"
				_tmp112_ = g_strdup ((const gchar*) pk_it->data);
#line 1309 "GomSerializationTest.vala"
				pk = _tmp112_;
#line 14714 "GomSerializationTest.c"
				{
					const gchar* _tmp113_;
#line 1309 "GomSerializationTest.vala"
					_tmp113_ = pk;
#line 1309 "GomSerializationTest.vala"
					g_message ("GomSerializationTest.vala:1309: %s", _tmp113_);
#line 1309 "GomSerializationTest.vala"
					_g_free0 (pk);
#line 14723 "GomSerializationTest.c"
				}
			}
		}
#line 1310 "GomSerializationTest.vala"
		_tmp114_ = skeys1;
#line 1310 "GomSerializationTest.vala"
		_vala_assert (g_list_length (_tmp114_) == ((guint) 2), "skeys1.length () == 2");
#line 1311 "GomSerializationTest.vala"
		_tmp115_ = k4;
#line 1311 "GomSerializationTest.vala"
		gxml_dom_child_node_remove ((GXmlDomChildNode*) _tmp115_);
#line 1312 "GomSerializationTest.vala"
		_tmp116_ = ks;
#line 1312 "GomSerializationTest.vala"
		_tmp117_ = three_keys_get_map (_tmp116_);
#line 1312 "GomSerializationTest.vala"
		_tmp118_ = _tmp117_;
#line 1312 "GomSerializationTest.vala"
		gxml_collection_search ((GXmlCollection*) _tmp118_, &_inner_error0_);
#line 1312 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1312 "GomSerializationTest.vala"
			(skeys1 == NULL) ? NULL : (skeys1 = (_g_list_free__g_free0_ (skeys1), NULL));
#line 1312 "GomSerializationTest.vala"
			(pkeys2 == NULL) ? NULL : (pkeys2 = (_g_list_free__g_free0_ (pkeys2), NULL));
#line 1312 "GomSerializationTest.vala"
			_g_free0 (_tmp96_);
#line 1312 "GomSerializationTest.vala"
			_g_object_unref0 (k4);
#line 1312 "GomSerializationTest.vala"
			_g_object_unref0 (k3);
#line 1312 "GomSerializationTest.vala"
			_g_object_unref0 (k2);
#line 1312 "GomSerializationTest.vala"
			(pkeys1 == NULL) ? NULL : (pkeys1 = (_g_list_free__g_free0_ (pkeys1), NULL));
#line 1312 "GomSerializationTest.vala"
			_g_object_unref0 (tk1);
#line 1312 "GomSerializationTest.vala"
			_g_object_unref0 (k1);
#line 1312 "GomSerializationTest.vala"
			_g_object_unref0 (ks);
#line 14765 "GomSerializationTest.c"
			goto __catch192_g_error;
		}
#line 1313 "GomSerializationTest.vala"
		_tmp119_ = ks;
#line 1313 "GomSerializationTest.vala"
		_tmp120_ = three_keys_get_map (_tmp119_);
#line 1313 "GomSerializationTest.vala"
		_tmp121_ = _tmp120_;
#line 1313 "GomSerializationTest.vala"
		_tmp122_ = gxml_gom_hash_three_map_get ((GXmlGomHashThreeMap*) _tmp121_, "a2", "b1", "name3");
#line 1313 "GomSerializationTest.vala"
		k3t = _tmp122_;
#line 1314 "GomSerializationTest.vala"
		_vala_assert (k3t != NULL, "k3t != null");
#line 1266 "GomSerializationTest.vala"
		_g_object_unref0 (k3t);
#line 1266 "GomSerializationTest.vala"
		(skeys1 == NULL) ? NULL : (skeys1 = (_g_list_free__g_free0_ (skeys1), NULL));
#line 1266 "GomSerializationTest.vala"
		(pkeys2 == NULL) ? NULL : (pkeys2 = (_g_list_free__g_free0_ (pkeys2), NULL));
#line 1266 "GomSerializationTest.vala"
		_g_free0 (_tmp96_);
#line 1266 "GomSerializationTest.vala"
		_g_object_unref0 (k4);
#line 1266 "GomSerializationTest.vala"
		_g_object_unref0 (k3);
#line 1266 "GomSerializationTest.vala"
		_g_object_unref0 (k2);
#line 1266 "GomSerializationTest.vala"
		(pkeys1 == NULL) ? NULL : (pkeys1 = (_g_list_free__g_free0_ (pkeys1), NULL));
#line 1266 "GomSerializationTest.vala"
		_g_object_unref0 (tk1);
#line 1266 "GomSerializationTest.vala"
		_g_object_unref0 (k1);
#line 1266 "GomSerializationTest.vala"
		_g_object_unref0 (ks);
#line 14802 "GomSerializationTest.c"
	}
	goto __finally192;
	__catch192_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp123_;
		gchar* _tmp124_;
		gchar* _tmp125_;
#line 1266 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 1266 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 1316 "GomSerializationTest.vala"
		_tmp123_ = e->message;
#line 1316 "GomSerializationTest.vala"
		_tmp124_ = g_strconcat ("ERROR: ", _tmp123_, NULL);
#line 1316 "GomSerializationTest.vala"
		_tmp125_ = _tmp124_;
#line 1316 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1316: %s", _tmp125_);
#line 1316 "GomSerializationTest.vala"
		_g_free0 (_tmp125_);
#line 1317 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 1266 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 14829 "GomSerializationTest.c"
	}
	__finally192:
#line 1266 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1266 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 1266 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 1266 "GomSerializationTest.vala"
		return;
#line 14840 "GomSerializationTest.c"
	}
}

static void
___lambda139__gtest_func (void)
{
#line 1264 "GomSerializationTest.vala"
	__lambda139_ ();
#line 14849 "GomSerializationTest.c"
}

static void
__lambda140_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GomBasicTypes* bt = NULL;
		GomBasicTypes* _tmp0_;
		gchar* _tmp1_ = NULL;
		GomBasicTypes* _tmp2_;
		gchar* _tmp3_;
		GomBasicTypes* _tmp4_;
		GomBasicTypes* _tmp5_;
		GomBasicTypes* _tmp6_;
		GomBasicTypes* _tmp7_;
		GomBasicTypes* _tmp8_;
		gchar* _tmp9_ = NULL;
		GomBasicTypes* _tmp10_;
		gchar* _tmp11_;
		GomBasicTypes* _tmp12_;
		GXmlDomNamedNodeMap* _tmp13_;
		GXmlDomNamedNodeMap* _tmp14_;
		GXmlDomNamedNodeMap* _tmp15_;
		gint _tmp16_;
		gint _tmp17_;
		GomBasicTypes* _tmp18_;
		guint _tmp19_;
		guint _tmp20_;
		GomBasicTypes* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
		GomBasicTypes* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		GomBasicTypes* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
		GomBasicTypes* _tmp30_;
		gchar* _tmp31_;
		gchar* _tmp32_;
		GomBasicTypes* _tmp33_;
		gchar* _tmp34_;
		gchar* _tmp35_;
		GomBasicTypes* _tmp36_;
		gchar* _tmp37_;
		gchar* _tmp38_;
		GomBasicTypes* bt2 = NULL;
		GomBasicTypes* _tmp39_;
		gchar* _tmp40_ = NULL;
		GomBasicTypes* _tmp41_;
		gchar* _tmp42_;
		GomBasicTypes* _tmp43_;
		GomBasicTypes* _tmp44_;
		const gchar* _tmp45_;
		const gchar* _tmp46_;
		GomBasicTypes* _tmp47_;
		gint _tmp48_;
		gint _tmp49_;
		GomBasicTypes* _tmp50_;
		guint _tmp51_;
		guint _tmp52_;
		gchar* _tmp53_;
		gchar* _tmp54_;
		GomBasicTypes* _tmp55_;
		guint _tmp56_;
		guint _tmp57_;
		GomBasicTypes* _tmp58_;
		gfloat _tmp59_;
		gfloat _tmp60_;
		GomBasicTypes* _tmp61_;
		gdouble _tmp62_;
		gdouble _tmp63_;
		GomBasicTypes* _tmp64_;
		GomBasicTypes* _tmp65_;
		gdouble _tmp66_;
		gdouble _tmp67_;
		GomBasicTypes* bt3 = NULL;
		GomBasicTypes* _tmp68_;
		gchar* _tmp69_ = NULL;
		GomBasicTypes* _tmp70_;
		gchar* _tmp71_;
		GomBasicTypes* _tmp72_;
		GomBasicTypes* _tmp73_;
		const gchar* _tmp74_;
		const gchar* _tmp75_;
		GomBasicTypes* _tmp76_;
		gint _tmp77_;
		gint _tmp78_;
		GomBasicTypes* _tmp79_;
		guint _tmp80_;
		guint _tmp81_;
		GomBasicTypes* _tmp82_;
		gfloat _tmp83_;
		gfloat _tmp84_;
		GomBasicTypes* _tmp85_;
		gdouble _tmp86_;
		gdouble _tmp87_;
#line 1323 "GomSerializationTest.vala"
		_tmp0_ = gom_basic_types_new ();
#line 1323 "GomSerializationTest.vala"
		bt = _tmp0_;
#line 1324 "GomSerializationTest.vala"
		_tmp2_ = bt;
#line 1324 "GomSerializationTest.vala"
		_tmp3_ = gxml_dom_element_write_string ((GXmlDomElement*) _tmp2_, NULL, &_inner_error0_);
#line 1324 "GomSerializationTest.vala"
		_tmp1_ = _tmp3_;
#line 1324 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1324 "GomSerializationTest.vala"
			_g_object_unref0 (bt);
#line 14962 "GomSerializationTest.c"
			goto __catch193_g_error;
		}
#line 1324 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1324: %s", _tmp1_);
#line 1325 "GomSerializationTest.vala"
		_tmp4_ = bt;
#line 1325 "GomSerializationTest.vala"
		gom_basic_types_set_text (_tmp4_, "Text");
#line 1326 "GomSerializationTest.vala"
		_tmp5_ = bt;
#line 1326 "GomSerializationTest.vala"
		gom_basic_types_set_integer (_tmp5_, -1);
#line 1327 "GomSerializationTest.vala"
		_tmp6_ = bt;
#line 1327 "GomSerializationTest.vala"
		gom_basic_types_set_unsigned_integer (_tmp6_, (guint) 1);
#line 1328 "GomSerializationTest.vala"
		_tmp7_ = bt;
#line 1328 "GomSerializationTest.vala"
		gom_basic_types_set_real_float (_tmp7_, (gfloat) 1.1);
#line 1329 "GomSerializationTest.vala"
		_tmp8_ = bt;
#line 1329 "GomSerializationTest.vala"
		gom_basic_types_set_real_double (_tmp8_, 2.2);
#line 1330 "GomSerializationTest.vala"
		_tmp10_ = bt;
#line 1330 "GomSerializationTest.vala"
		_tmp11_ = gxml_dom_element_write_string ((GXmlDomElement*) _tmp10_, NULL, &_inner_error0_);
#line 1330 "GomSerializationTest.vala"
		_tmp9_ = _tmp11_;
#line 1330 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1330 "GomSerializationTest.vala"
			_g_free0 (_tmp1_);
#line 1330 "GomSerializationTest.vala"
			_g_object_unref0 (bt);
#line 14999 "GomSerializationTest.c"
			goto __catch193_g_error;
		}
#line 1330 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1330: %s", _tmp9_);
#line 1331 "GomSerializationTest.vala"
		_tmp12_ = bt;
#line 1331 "GomSerializationTest.vala"
		_tmp13_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp12_);
#line 1331 "GomSerializationTest.vala"
		_tmp14_ = _tmp13_;
#line 1331 "GomSerializationTest.vala"
		_tmp15_ = _tmp14_;
#line 1331 "GomSerializationTest.vala"
		_tmp16_ = gee_map_get_size ((GeeMap*) _tmp15_);
#line 1331 "GomSerializationTest.vala"
		_tmp17_ = _tmp16_;
#line 1331 "GomSerializationTest.vala"
		_vala_assert (_tmp17_ == 5, "bt.attributes.size == 5");
#line 1331 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp15_);
#line 1332 "GomSerializationTest.vala"
		_tmp18_ = bt;
#line 1332 "GomSerializationTest.vala"
		_tmp19_ = gom_basic_types_get_unsigned_integer (_tmp18_);
#line 1332 "GomSerializationTest.vala"
		_tmp20_ = _tmp19_;
#line 1332 "GomSerializationTest.vala"
		_vala_assert (_tmp20_ == ((guint) 1), "bt.unsigned_integer == 1");
#line 1333 "GomSerializationTest.vala"
		_tmp21_ = bt;
#line 1333 "GomSerializationTest.vala"
		_tmp22_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp21_, "text");
#line 1333 "GomSerializationTest.vala"
		_tmp23_ = _tmp22_;
#line 1333 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp23_, "Text") == 0, "bt.get_attribute (\"text\") == \"Text\"");
#line 1333 "GomSerializationTest.vala"
		_g_free0 (_tmp23_);
#line 1334 "GomSerializationTest.vala"
		_tmp24_ = bt;
#line 1334 "GomSerializationTest.vala"
		_tmp25_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp24_, "integer");
#line 1334 "GomSerializationTest.vala"
		_tmp26_ = _tmp25_;
#line 1334 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp26_, "-1") == 0, "bt.get_attribute (\"integer\") == \"-1\"");
#line 1334 "GomSerializationTest.vala"
		_g_free0 (_tmp26_);
#line 1335 "GomSerializationTest.vala"
		_tmp27_ = bt;
#line 1335 "GomSerializationTest.vala"
		_tmp28_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp27_, "realFloat");
#line 1335 "GomSerializationTest.vala"
		_tmp29_ = _tmp28_;
#line 1335 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1335: realFloat = %s", _tmp29_);
#line 1335 "GomSerializationTest.vala"
		_g_free0 (_tmp29_);
#line 1336 "GomSerializationTest.vala"
		_tmp30_ = bt;
#line 1336 "GomSerializationTest.vala"
		_tmp31_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp30_, "realFloat");
#line 1336 "GomSerializationTest.vala"
		_tmp32_ = _tmp31_;
#line 1336 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp32_, "1.1") == 0, "bt.get_attribute (\"realFloat\") == \"1.1\"");
#line 1336 "GomSerializationTest.vala"
		_g_free0 (_tmp32_);
#line 1337 "GomSerializationTest.vala"
		_tmp33_ = bt;
#line 1337 "GomSerializationTest.vala"
		_tmp34_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp33_, "unsignedInteger");
#line 1337 "GomSerializationTest.vala"
		_tmp35_ = _tmp34_;
#line 1337 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1337: unsignedInteger = %s", _tmp35_);
#line 1337 "GomSerializationTest.vala"
		_g_free0 (_tmp35_);
#line 1338 "GomSerializationTest.vala"
		_tmp36_ = bt;
#line 1338 "GomSerializationTest.vala"
		_tmp37_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp36_, "unsignedInteger");
#line 1338 "GomSerializationTest.vala"
		_tmp38_ = _tmp37_;
#line 1338 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp38_, "1") == 0, "bt.get_attribute (\"unsignedInteger\") == \"1\"");
#line 1338 "GomSerializationTest.vala"
		_g_free0 (_tmp38_);
#line 1339 "GomSerializationTest.vala"
		_tmp39_ = gom_basic_types_new ();
#line 1339 "GomSerializationTest.vala"
		bt2 = _tmp39_;
#line 1340 "GomSerializationTest.vala"
		_tmp41_ = bt;
#line 1340 "GomSerializationTest.vala"
		_tmp42_ = gxml_dom_element_write_string ((GXmlDomElement*) _tmp41_, NULL, &_inner_error0_);
#line 1340 "GomSerializationTest.vala"
		_tmp40_ = _tmp42_;
#line 1340 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1340 "GomSerializationTest.vala"
			_g_object_unref0 (bt2);
#line 1340 "GomSerializationTest.vala"
			_g_free0 (_tmp9_);
#line 1340 "GomSerializationTest.vala"
			_g_free0 (_tmp1_);
#line 1340 "GomSerializationTest.vala"
			_g_object_unref0 (bt);
#line 15108 "GomSerializationTest.c"
			goto __catch193_g_error;
		}
#line 1340 "GomSerializationTest.vala"
		_tmp43_ = bt2;
#line 1340 "GomSerializationTest.vala"
		gxml_dom_element_read_from_string ((GXmlDomElement*) _tmp43_, _tmp40_, NULL, &_inner_error0_);
#line 1340 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1340 "GomSerializationTest.vala"
			_g_free0 (_tmp40_);
#line 1340 "GomSerializationTest.vala"
			_g_object_unref0 (bt2);
#line 1340 "GomSerializationTest.vala"
			_g_free0 (_tmp9_);
#line 1340 "GomSerializationTest.vala"
			_g_free0 (_tmp1_);
#line 1340 "GomSerializationTest.vala"
			_g_object_unref0 (bt);
#line 15127 "GomSerializationTest.c"
			goto __catch193_g_error;
		}
#line 1341 "GomSerializationTest.vala"
		_tmp44_ = bt2;
#line 1341 "GomSerializationTest.vala"
		_tmp45_ = gom_basic_types_get_text (_tmp44_);
#line 1341 "GomSerializationTest.vala"
		_tmp46_ = _tmp45_;
#line 1341 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp46_, "Text") == 0, "bt2.text == \"Text\"");
#line 1342 "GomSerializationTest.vala"
		_tmp47_ = bt2;
#line 1342 "GomSerializationTest.vala"
		_tmp48_ = gom_basic_types_get_integer (_tmp47_);
#line 1342 "GomSerializationTest.vala"
		_tmp49_ = _tmp48_;
#line 1342 "GomSerializationTest.vala"
		_vala_assert (_tmp49_ == -1, "bt2.integer == -1");
#line 1343 "GomSerializationTest.vala"
		_tmp50_ = bt2;
#line 1343 "GomSerializationTest.vala"
		_tmp51_ = gom_basic_types_get_unsigned_integer (_tmp50_);
#line 1343 "GomSerializationTest.vala"
		_tmp52_ = _tmp51_;
#line 1343 "GomSerializationTest.vala"
		_tmp53_ = g_strdup_printf ("%u", _tmp52_);
#line 1343 "GomSerializationTest.vala"
		_tmp54_ = _tmp53_;
#line 1343 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1343: %s", _tmp54_);
#line 1343 "GomSerializationTest.vala"
		_g_free0 (_tmp54_);
#line 1344 "GomSerializationTest.vala"
		_tmp55_ = bt2;
#line 1344 "GomSerializationTest.vala"
		_tmp56_ = gom_basic_types_get_unsigned_integer (_tmp55_);
#line 1344 "GomSerializationTest.vala"
		_tmp57_ = _tmp56_;
#line 1344 "GomSerializationTest.vala"
		_vala_assert (_tmp57_ == ((guint) 1), "bt2.unsigned_integer == 1");
#line 1345 "GomSerializationTest.vala"
		_tmp58_ = bt2;
#line 1345 "GomSerializationTest.vala"
		_tmp59_ = gom_basic_types_get_real_float (_tmp58_);
#line 1345 "GomSerializationTest.vala"
		_tmp60_ = _tmp59_;
#line 1345 "GomSerializationTest.vala"
		_vala_assert (_tmp60_ == ((gfloat) 1.1), "bt2.real_float == (float) 1.1");
#line 1346 "GomSerializationTest.vala"
		_tmp61_ = bt2;
#line 1346 "GomSerializationTest.vala"
		_tmp62_ = gom_basic_types_get_real_double (_tmp61_);
#line 1346 "GomSerializationTest.vala"
		_tmp63_ = _tmp62_;
#line 1346 "GomSerializationTest.vala"
		_vala_assert (_tmp63_ == 2.2, "bt2.real_double == 2.2");
#line 1347 "GomSerializationTest.vala"
		_tmp64_ = bt2;
#line 1347 "GomSerializationTest.vala"
		gom_basic_types_set_real_double (_tmp64_, 100.0);
#line 1348 "GomSerializationTest.vala"
		_tmp65_ = bt2;
#line 1348 "GomSerializationTest.vala"
		_tmp66_ = gom_basic_types_get_real_double (_tmp65_);
#line 1348 "GomSerializationTest.vala"
		_tmp67_ = _tmp66_;
#line 1348 "GomSerializationTest.vala"
		_vala_assert (_tmp67_ == 100.0, "bt2.real_double == 100.0");
#line 1349 "GomSerializationTest.vala"
		_tmp68_ = gom_basic_types_new ();
#line 1349 "GomSerializationTest.vala"
		bt3 = _tmp68_;
#line 1350 "GomSerializationTest.vala"
		_tmp70_ = bt2;
#line 1350 "GomSerializationTest.vala"
		_tmp71_ = gxml_dom_element_write_string ((GXmlDomElement*) _tmp70_, NULL, &_inner_error0_);
#line 1350 "GomSerializationTest.vala"
		_tmp69_ = _tmp71_;
#line 1350 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1350 "GomSerializationTest.vala"
			_g_object_unref0 (bt3);
#line 1350 "GomSerializationTest.vala"
			_g_free0 (_tmp40_);
#line 1350 "GomSerializationTest.vala"
			_g_object_unref0 (bt2);
#line 1350 "GomSerializationTest.vala"
			_g_free0 (_tmp9_);
#line 1350 "GomSerializationTest.vala"
			_g_free0 (_tmp1_);
#line 1350 "GomSerializationTest.vala"
			_g_object_unref0 (bt);
#line 15220 "GomSerializationTest.c"
			goto __catch193_g_error;
		}
#line 1350 "GomSerializationTest.vala"
		_tmp72_ = bt3;
#line 1350 "GomSerializationTest.vala"
		gxml_dom_element_read_from_string ((GXmlDomElement*) _tmp72_, _tmp69_, NULL, &_inner_error0_);
#line 1350 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1350 "GomSerializationTest.vala"
			_g_free0 (_tmp69_);
#line 1350 "GomSerializationTest.vala"
			_g_object_unref0 (bt3);
#line 1350 "GomSerializationTest.vala"
			_g_free0 (_tmp40_);
#line 1350 "GomSerializationTest.vala"
			_g_object_unref0 (bt2);
#line 1350 "GomSerializationTest.vala"
			_g_free0 (_tmp9_);
#line 1350 "GomSerializationTest.vala"
			_g_free0 (_tmp1_);
#line 1350 "GomSerializationTest.vala"
			_g_object_unref0 (bt);
#line 15243 "GomSerializationTest.c"
			goto __catch193_g_error;
		}
#line 1351 "GomSerializationTest.vala"
		_tmp73_ = bt3;
#line 1351 "GomSerializationTest.vala"
		_tmp74_ = gom_basic_types_get_text (_tmp73_);
#line 1351 "GomSerializationTest.vala"
		_tmp75_ = _tmp74_;
#line 1351 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp75_, "Text") == 0, "bt3.text == \"Text\"");
#line 1352 "GomSerializationTest.vala"
		_tmp76_ = bt3;
#line 1352 "GomSerializationTest.vala"
		_tmp77_ = gom_basic_types_get_integer (_tmp76_);
#line 1352 "GomSerializationTest.vala"
		_tmp78_ = _tmp77_;
#line 1352 "GomSerializationTest.vala"
		_vala_assert (_tmp78_ == -1, "bt3.integer == -1");
#line 1353 "GomSerializationTest.vala"
		_tmp79_ = bt3;
#line 1353 "GomSerializationTest.vala"
		_tmp80_ = gom_basic_types_get_unsigned_integer (_tmp79_);
#line 1353 "GomSerializationTest.vala"
		_tmp81_ = _tmp80_;
#line 1353 "GomSerializationTest.vala"
		_vala_assert (_tmp81_ == ((guint) 1), "bt3.unsigned_integer == 1");
#line 1354 "GomSerializationTest.vala"
		_tmp82_ = bt3;
#line 1354 "GomSerializationTest.vala"
		_tmp83_ = gom_basic_types_get_real_float (_tmp82_);
#line 1354 "GomSerializationTest.vala"
		_tmp84_ = _tmp83_;
#line 1354 "GomSerializationTest.vala"
		_vala_assert (_tmp84_ == ((gfloat) 1.1), "bt3.real_float == (float) 1.1");
#line 1355 "GomSerializationTest.vala"
		_tmp85_ = bt3;
#line 1355 "GomSerializationTest.vala"
		_tmp86_ = gom_basic_types_get_real_double (_tmp85_);
#line 1355 "GomSerializationTest.vala"
		_tmp87_ = _tmp86_;
#line 1355 "GomSerializationTest.vala"
		_vala_assert (_tmp87_ == 100.0, "bt3.real_double == 100.0");
#line 1322 "GomSerializationTest.vala"
		_g_free0 (_tmp69_);
#line 1322 "GomSerializationTest.vala"
		_g_object_unref0 (bt3);
#line 1322 "GomSerializationTest.vala"
		_g_free0 (_tmp40_);
#line 1322 "GomSerializationTest.vala"
		_g_object_unref0 (bt2);
#line 1322 "GomSerializationTest.vala"
		_g_free0 (_tmp9_);
#line 1322 "GomSerializationTest.vala"
		_g_free0 (_tmp1_);
#line 1322 "GomSerializationTest.vala"
		_g_object_unref0 (bt);
#line 15300 "GomSerializationTest.c"
	}
	goto __finally193;
	__catch193_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp88_;
		gchar* _tmp89_;
		gchar* _tmp90_;
#line 1322 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 1322 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 1357 "GomSerializationTest.vala"
		_tmp88_ = e->message;
#line 1357 "GomSerializationTest.vala"
		_tmp89_ = g_strconcat ("ERROR: ", _tmp88_, NULL);
#line 1357 "GomSerializationTest.vala"
		_tmp90_ = _tmp89_;
#line 1357 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1357: %s", _tmp90_);
#line 1357 "GomSerializationTest.vala"
		_g_free0 (_tmp90_);
#line 1358 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 1322 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 15327 "GomSerializationTest.c"
	}
	__finally193:
#line 1322 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1322 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 1322 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 1322 "GomSerializationTest.vala"
		return;
#line 15338 "GomSerializationTest.c"
	}
}

static void
___lambda140__gtest_func (void)
{
#line 1320 "GomSerializationTest.vala"
	__lambda140_ ();
#line 15347 "GomSerializationTest.c"
}

static void
__lambda141_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GomSerializationTestBookStore* bs = NULL;
		GomSerializationTestBookStore* _tmp0_;
		GomSerializationTestBookStore* _tmp1_;
		GomSerializationTestBooks* _tmp2_;
		GomSerializationTestBooks* _tmp3_;
		GomSerializationTestBookStore* _tmp4_;
		gint n = 0;
		gchar* _tmp21_ = NULL;
		GomSerializationTestBookStore* _tmp22_;
		gchar* _tmp23_;
		GomSerializationTestBookStand* bst = NULL;
		GomSerializationTestBookStand* _tmp38_;
		GomSerializationTestBookStand* _tmp39_;
		GomSerializationTestRegisters* r = NULL;
		GomSerializationTestBookStand* _tmp40_;
		GomSerializationTestRegisters* _tmp41_;
		GomSerializationTestRegisters* _tmp42_;
		GomSerializationTestRegisters* _tmp43_;
		GomSerializationTestRegisters* _tmp44_;
		GType _tmp45_;
		GType _tmp46_;
		GomSerializationTestBookStand* _tmp67_;
		GomSerializationTestHashRegisters* hr = NULL;
		GomSerializationTestBookStand* _tmp68_;
		GomSerializationTestHashRegisters* _tmp69_;
		GomSerializationTestHashRegisters* _tmp70_;
		GomSerializationTestHashRegisters* _tmp71_;
		GomSerializationTestBookStand* _tmp98_;
		GomSerializationTestHashPairRegisters* hpr = NULL;
		GomSerializationTestBookStand* _tmp99_;
		GomSerializationTestHashPairRegisters* _tmp100_;
		GomSerializationTestHashPairRegisters* _tmp101_;
		GomSerializationTestHashPairRegisters* _tmp102_;
		GomSerializationTestBookStand* _tmp136_;
		GomSerializationTestHashThreeRegisters* htr = NULL;
		GomSerializationTestBookStand* _tmp137_;
		GomSerializationTestHashThreeRegisters* _tmp138_;
		GomSerializationTestHashThreeRegisters* _tmp139_;
		GomSerializationTestHashThreeRegisters* _tmp140_;
#line 1363 "GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_book_store_new ();
#line 1363 "GomSerializationTest.vala"
		bs = _tmp0_;
#line 1364 "GomSerializationTest.vala"
		_tmp1_ = bs;
#line 1364 "GomSerializationTest.vala"
		_tmp2_ = gom_serialization_test_book_store_get_books (_tmp1_);
#line 1364 "GomSerializationTest.vala"
		_tmp3_ = _tmp2_;
#line 1364 "GomSerializationTest.vala"
		_vala_assert (_tmp3_ == NULL, "bs.books == null");
#line 1365 "GomSerializationTest.vala"
		_tmp4_ = bs;
#line 1365 "GomSerializationTest.vala"
		gxml_gom_object_set_instance_property ((GXmlGomObject*) _tmp4_, "books");
#line 1366 "GomSerializationTest.vala"
		n = 1;
#line 15412 "GomSerializationTest.c"
		{
			gint i = 0;
#line 1367 "GomSerializationTest.vala"
			i = 0;
#line 15417 "GomSerializationTest.c"
			{
				gboolean _tmp5_ = FALSE;
#line 1367 "GomSerializationTest.vala"
				_tmp5_ = TRUE;
#line 1367 "GomSerializationTest.vala"
				while (TRUE) {
#line 15424 "GomSerializationTest.c"
					GomSerializationTestBook* b = NULL;
					GomSerializationTestBookStore* _tmp7_;
					GomSerializationTestBooks* _tmp8_;
					GomSerializationTestBooks* _tmp9_;
					GXmlDomElement* _tmp10_;
					GomSerializationTestBook* _tmp11_;
					GomSerializationTestBook* _tmp12_;
					GomSerializationTestBook* _tmp13_;
					gchar* _tmp14_;
					gchar* _tmp15_;
					gint _tmp16_;
					GomSerializationTestBookStore* _tmp17_;
					GomSerializationTestBooks* _tmp18_;
					GomSerializationTestBooks* _tmp19_;
					GomSerializationTestBook* _tmp20_;
#line 1367 "GomSerializationTest.vala"
					if (!_tmp5_) {
#line 15442 "GomSerializationTest.c"
						gint _tmp6_;
#line 1367 "GomSerializationTest.vala"
						_tmp6_ = i;
#line 1367 "GomSerializationTest.vala"
						i = _tmp6_ + 1;
#line 15448 "GomSerializationTest.c"
					}
#line 1367 "GomSerializationTest.vala"
					_tmp5_ = FALSE;
#line 1367 "GomSerializationTest.vala"
					if (!(i < 10)) {
#line 1367 "GomSerializationTest.vala"
						break;
#line 15456 "GomSerializationTest.c"
					}
#line 1368 "GomSerializationTest.vala"
					_tmp7_ = bs;
#line 1368 "GomSerializationTest.vala"
					_tmp8_ = gom_serialization_test_book_store_get_books (_tmp7_);
#line 1368 "GomSerializationTest.vala"
					_tmp9_ = _tmp8_;
#line 1368 "GomSerializationTest.vala"
					_tmp10_ = gxml_collection_create_item ((GXmlCollection*) _tmp9_);
#line 1368 "GomSerializationTest.vala"
					_tmp11_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, GOM_SERIALIZATION_TEST_TYPE_BOOK) ? ((GomSerializationTestBook*) _tmp10_) : NULL;
#line 1368 "GomSerializationTest.vala"
					if (_tmp11_ == NULL) {
#line 1368 "GomSerializationTest.vala"
						_g_object_unref0 (_tmp10_);
#line 15472 "GomSerializationTest.c"
					}
#line 1368 "GomSerializationTest.vala"
					b = _tmp11_;
#line 1369 "GomSerializationTest.vala"
					_tmp12_ = b;
#line 1369 "GomSerializationTest.vala"
					_vala_assert (_tmp12_ != NULL, "b != null");
#line 1370 "GomSerializationTest.vala"
					_tmp13_ = b;
#line 1370 "GomSerializationTest.vala"
					_tmp14_ = g_strdup_printf ("Title %d", n);
#line 1370 "GomSerializationTest.vala"
					_tmp15_ = _tmp14_;
#line 1370 "GomSerializationTest.vala"
					gom_serialization_test_book_set_name (_tmp13_, _tmp15_);
#line 1370 "GomSerializationTest.vala"
					_g_free0 (_tmp15_);
#line 1371 "GomSerializationTest.vala"
					_tmp16_ = n;
#line 1371 "GomSerializationTest.vala"
					n = _tmp16_ + 1;
#line 1372 "GomSerializationTest.vala"
					_tmp17_ = bs;
#line 1372 "GomSerializationTest.vala"
					_tmp18_ = gom_serialization_test_book_store_get_books (_tmp17_);
#line 1372 "GomSerializationTest.vala"
					_tmp19_ = _tmp18_;
#line 1372 "GomSerializationTest.vala"
					_tmp20_ = b;
#line 1372 "GomSerializationTest.vala"
					gxml_collection_append ((GXmlCollection*) _tmp19_, (GXmlDomElement*) _tmp20_, &_inner_error0_);
#line 1372 "GomSerializationTest.vala"
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1372 "GomSerializationTest.vala"
						_g_object_unref0 (b);
#line 1372 "GomSerializationTest.vala"
						_g_object_unref0 (bs);
#line 15510 "GomSerializationTest.c"
						goto __catch194_g_error;
					}
#line 1367 "GomSerializationTest.vala"
					_g_object_unref0 (b);
#line 15515 "GomSerializationTest.c"
				}
			}
		}
#line 1374 "GomSerializationTest.vala"
		_tmp22_ = bs;
#line 1374 "GomSerializationTest.vala"
		_tmp23_ = gxml_dom_element_write_string ((GXmlDomElement*) _tmp22_, NULL, &_inner_error0_);
#line 1374 "GomSerializationTest.vala"
		_tmp21_ = _tmp23_;
#line 1374 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1374 "GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 15529 "GomSerializationTest.c"
			goto __catch194_g_error;
		}
#line 1374 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1374: %s", _tmp21_);
#line 1375 "GomSerializationTest.vala"
		n = 1;
#line 15536 "GomSerializationTest.c"
		{
			GeeIterator* _e_it = NULL;
			GomSerializationTestBookStore* _tmp24_;
			GomSerializationTestBooks* _tmp25_;
			GomSerializationTestBooks* _tmp26_;
			GeeIterator* _tmp27_;
#line 1376 "GomSerializationTest.vala"
			_tmp24_ = bs;
#line 1376 "GomSerializationTest.vala"
			_tmp25_ = gom_serialization_test_book_store_get_books (_tmp24_);
#line 1376 "GomSerializationTest.vala"
			_tmp26_ = _tmp25_;
#line 1376 "GomSerializationTest.vala"
			_tmp27_ = gee_iterable_iterator ((GeeIterable*) _tmp26_);
#line 1376 "GomSerializationTest.vala"
			_e_it = _tmp27_;
#line 1376 "GomSerializationTest.vala"
			while (TRUE) {
#line 15555 "GomSerializationTest.c"
				GeeIterator* _tmp28_;
				GXmlDomElement* e = NULL;
				GeeIterator* _tmp29_;
				gpointer _tmp30_;
				GXmlDomElement* _tmp31_;
				GXmlDomElement* _tmp32_;
				const gchar* _tmp33_;
				const gchar* _tmp34_;
				gchar* _tmp35_;
				gchar* _tmp36_;
				gint _tmp37_;
#line 1376 "GomSerializationTest.vala"
				_tmp28_ = _e_it;
#line 1376 "GomSerializationTest.vala"
				if (!gee_iterator_next (_tmp28_)) {
#line 1376 "GomSerializationTest.vala"
					break;
#line 15573 "GomSerializationTest.c"
				}
#line 1376 "GomSerializationTest.vala"
				_tmp29_ = _e_it;
#line 1376 "GomSerializationTest.vala"
				_tmp30_ = gee_iterator_get (_tmp29_);
#line 1376 "GomSerializationTest.vala"
				e = (GXmlDomElement*) _tmp30_;
#line 1377 "GomSerializationTest.vala"
				_tmp31_ = e;
#line 1377 "GomSerializationTest.vala"
				_vala_assert ((G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, GOM_SERIALIZATION_TEST_TYPE_BOOK) ? ((GomSerializationTestBook*) _tmp31_) : NULL) != NULL, "(e as Book) != null");
#line 1378 "GomSerializationTest.vala"
				_tmp32_ = e;
#line 1378 "GomSerializationTest.vala"
				_tmp33_ = gom_serialization_test_book_get_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp32_, GOM_SERIALIZATION_TEST_TYPE_BOOK) ? ((GomSerializationTestBook*) _tmp32_) : NULL);
#line 1378 "GomSerializationTest.vala"
				_tmp34_ = _tmp33_;
#line 1378 "GomSerializationTest.vala"
				_tmp35_ = g_strdup_printf ("Title %d", n);
#line 1378 "GomSerializationTest.vala"
				_tmp36_ = _tmp35_;
#line 1378 "GomSerializationTest.vala"
				_vala_assert (g_strcmp0 (_tmp34_, _tmp36_) == 0, "(e as Book).name == \"Title %d\".printf (n)");
#line 1378 "GomSerializationTest.vala"
				_g_free0 (_tmp36_);
#line 1379 "GomSerializationTest.vala"
				_tmp37_ = n;
#line 1379 "GomSerializationTest.vala"
				n = _tmp37_ + 1;
#line 1376 "GomSerializationTest.vala"
				_g_object_unref0 (e);
#line 15605 "GomSerializationTest.c"
			}
#line 1376 "GomSerializationTest.vala"
			_g_object_unref0 (_e_it);
#line 15609 "GomSerializationTest.c"
		}
#line 1381 "GomSerializationTest.vala"
		_tmp38_ = gom_serialization_test_book_stand_new ();
#line 1381 "GomSerializationTest.vala"
		bst = _tmp38_;
#line 1382 "GomSerializationTest.vala"
		_tmp39_ = bst;
#line 1382 "GomSerializationTest.vala"
		gxml_gom_object_set_instance_property ((GXmlGomObject*) _tmp39_, "registers");
#line 1383 "GomSerializationTest.vala"
		_tmp40_ = bst;
#line 1383 "GomSerializationTest.vala"
		_tmp41_ = gom_serialization_test_book_stand_get_registers (_tmp40_);
#line 1383 "GomSerializationTest.vala"
		_tmp42_ = _tmp41_;
#line 1383 "GomSerializationTest.vala"
		_tmp43_ = _g_object_ref0 (_tmp42_);
#line 1383 "GomSerializationTest.vala"
		r = _tmp43_;
#line 1384 "GomSerializationTest.vala"
		_tmp44_ = r;
#line 1384 "GomSerializationTest.vala"
		_tmp45_ = gxml_collection_get_items_type ((GXmlCollection*) _tmp44_);
#line 1384 "GomSerializationTest.vala"
		_tmp46_ = _tmp45_;
#line 1384 "GomSerializationTest.vala"
		_vala_assert (g_type_is_a (_tmp46_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER), "r.items_type.is_a (typeof (BookRegister))");
#line 1385 "GomSerializationTest.vala"
		n = 1;
#line 15639 "GomSerializationTest.c"
		{
			gint i = 0;
#line 1386 "GomSerializationTest.vala"
			i = 0;
#line 15644 "GomSerializationTest.c"
			{
				gboolean _tmp47_ = FALSE;
#line 1386 "GomSerializationTest.vala"
				_tmp47_ = TRUE;
#line 1386 "GomSerializationTest.vala"
				while (TRUE) {
#line 15651 "GomSerializationTest.c"
					GomSerializationTestBookRegister* b = NULL;
					GomSerializationTestRegisters* _tmp49_;
					GXmlDomElement* _tmp50_;
					GomSerializationTestBookRegister* _tmp51_;
					GomSerializationTestBookRegister* _tmp52_;
					GomSerializationTestBookRegister* _tmp53_;
					gint _tmp54_;
					GomSerializationTestRegisters* _tmp55_;
					GomSerializationTestBookRegister* _tmp56_;
#line 1386 "GomSerializationTest.vala"
					if (!_tmp47_) {
#line 15663 "GomSerializationTest.c"
						gint _tmp48_;
#line 1386 "GomSerializationTest.vala"
						_tmp48_ = i;
#line 1386 "GomSerializationTest.vala"
						i = _tmp48_ + 1;
#line 15669 "GomSerializationTest.c"
					}
#line 1386 "GomSerializationTest.vala"
					_tmp47_ = FALSE;
#line 1386 "GomSerializationTest.vala"
					if (!(i < 10)) {
#line 1386 "GomSerializationTest.vala"
						break;
#line 15677 "GomSerializationTest.c"
					}
#line 1387 "GomSerializationTest.vala"
					_tmp49_ = r;
#line 1387 "GomSerializationTest.vala"
					_tmp50_ = gxml_collection_create_item ((GXmlCollection*) _tmp49_);
#line 1387 "GomSerializationTest.vala"
					_tmp51_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp50_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp50_) : NULL;
#line 1387 "GomSerializationTest.vala"
					if (_tmp51_ == NULL) {
#line 1387 "GomSerializationTest.vala"
						_g_object_unref0 (_tmp50_);
#line 15689 "GomSerializationTest.c"
					}
#line 1387 "GomSerializationTest.vala"
					b = _tmp51_;
#line 1388 "GomSerializationTest.vala"
					_tmp52_ = b;
#line 1388 "GomSerializationTest.vala"
					_vala_assert (_tmp52_ != NULL, "b != null");
#line 1389 "GomSerializationTest.vala"
					_tmp53_ = b;
#line 1389 "GomSerializationTest.vala"
					gom_serialization_test_book_register_set_year (_tmp53_, 2000 + n);
#line 1390 "GomSerializationTest.vala"
					_tmp54_ = n;
#line 1390 "GomSerializationTest.vala"
					n = _tmp54_ + 1;
#line 1391 "GomSerializationTest.vala"
					_tmp55_ = r;
#line 1391 "GomSerializationTest.vala"
					_tmp56_ = b;
#line 1391 "GomSerializationTest.vala"
					gxml_collection_append ((GXmlCollection*) _tmp55_, (GXmlDomElement*) _tmp56_, &_inner_error0_);
#line 1391 "GomSerializationTest.vala"
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1391 "GomSerializationTest.vala"
						_g_object_unref0 (b);
#line 1391 "GomSerializationTest.vala"
						_g_object_unref0 (r);
#line 1391 "GomSerializationTest.vala"
						_g_object_unref0 (bst);
#line 1391 "GomSerializationTest.vala"
						_g_free0 (_tmp21_);
#line 1391 "GomSerializationTest.vala"
						_g_object_unref0 (bs);
#line 15723 "GomSerializationTest.c"
						goto __catch194_g_error;
					}
#line 1386 "GomSerializationTest.vala"
					_g_object_unref0 (b);
#line 15728 "GomSerializationTest.c"
				}
			}
		}
#line 1393 "GomSerializationTest.vala"
		n = 1;
#line 15734 "GomSerializationTest.c"
		{
			GeeIterator* _e_it = NULL;
			GomSerializationTestRegisters* _tmp57_;
			GeeIterator* _tmp58_;
#line 1394 "GomSerializationTest.vala"
			_tmp57_ = r;
#line 1394 "GomSerializationTest.vala"
			_tmp58_ = gee_iterable_iterator ((GeeIterable*) _tmp57_);
#line 1394 "GomSerializationTest.vala"
			_e_it = _tmp58_;
#line 1394 "GomSerializationTest.vala"
			while (TRUE) {
#line 15747 "GomSerializationTest.c"
				GeeIterator* _tmp59_;
				GXmlDomElement* e = NULL;
				GeeIterator* _tmp60_;
				gpointer _tmp61_;
				GXmlDomElement* _tmp62_;
				GXmlDomElement* _tmp63_;
				gint _tmp64_;
				gint _tmp65_;
				gint _tmp66_;
#line 1394 "GomSerializationTest.vala"
				_tmp59_ = _e_it;
#line 1394 "GomSerializationTest.vala"
				if (!gee_iterator_next (_tmp59_)) {
#line 1394 "GomSerializationTest.vala"
					break;
#line 15763 "GomSerializationTest.c"
				}
#line 1394 "GomSerializationTest.vala"
				_tmp60_ = _e_it;
#line 1394 "GomSerializationTest.vala"
				_tmp61_ = gee_iterator_get (_tmp60_);
#line 1394 "GomSerializationTest.vala"
				e = (GXmlDomElement*) _tmp61_;
#line 1395 "GomSerializationTest.vala"
				_tmp62_ = e;
#line 1395 "GomSerializationTest.vala"
				_vala_assert ((G_TYPE_CHECK_INSTANCE_TYPE (_tmp62_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp62_) : NULL) != NULL, "(e as BookRegister) != null");
#line 1396 "GomSerializationTest.vala"
				_tmp63_ = e;
#line 1396 "GomSerializationTest.vala"
				_tmp64_ = gom_serialization_test_book_register_get_year (G_TYPE_CHECK_INSTANCE_TYPE (_tmp63_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp63_) : NULL);
#line 1396 "GomSerializationTest.vala"
				_tmp65_ = _tmp64_;
#line 1396 "GomSerializationTest.vala"
				_vala_assert (_tmp65_ == (2000 + n), "(e as BookRegister).year == 2000 + n");
#line 1397 "GomSerializationTest.vala"
				_tmp66_ = n;
#line 1397 "GomSerializationTest.vala"
				n = _tmp66_ + 1;
#line 1394 "GomSerializationTest.vala"
				_g_object_unref0 (e);
#line 15789 "GomSerializationTest.c"
			}
#line 1394 "GomSerializationTest.vala"
			_g_object_unref0 (_e_it);
#line 15793 "GomSerializationTest.c"
		}
#line 1399 "GomSerializationTest.vala"
		_tmp67_ = bst;
#line 1399 "GomSerializationTest.vala"
		gxml_gom_object_set_instance_property ((GXmlGomObject*) _tmp67_, "hashmap-registers");
#line 1400 "GomSerializationTest.vala"
		_tmp68_ = bst;
#line 1400 "GomSerializationTest.vala"
		_tmp69_ = gom_serialization_test_book_stand_get_hashmap_registers (_tmp68_);
#line 1400 "GomSerializationTest.vala"
		_tmp70_ = _tmp69_;
#line 1400 "GomSerializationTest.vala"
		_tmp71_ = _g_object_ref0 (_tmp70_);
#line 1400 "GomSerializationTest.vala"
		hr = _tmp71_;
#line 1401 "GomSerializationTest.vala"
		n = 1;
#line 15811 "GomSerializationTest.c"
		{
			gint i = 0;
#line 1402 "GomSerializationTest.vala"
			i = 0;
#line 15816 "GomSerializationTest.c"
			{
				gboolean _tmp72_ = FALSE;
#line 1402 "GomSerializationTest.vala"
				_tmp72_ = TRUE;
#line 1402 "GomSerializationTest.vala"
				while (TRUE) {
#line 15823 "GomSerializationTest.c"
					GomSerializationTestBookRegister* b = NULL;
					GomSerializationTestHashRegisters* _tmp74_;
					GXmlDomElement* _tmp75_;
					GomSerializationTestBookRegister* _tmp76_;
					GomSerializationTestBookRegister* _tmp77_;
					GomSerializationTestBookRegister* _tmp78_;
					GomSerializationTestBookRegister* _tmp79_;
					GomSerializationTestBook* _tmp80_;
					GomSerializationTestBook* _tmp81_;
					gchar* _tmp82_;
					gchar* _tmp83_;
					GomSerializationTestBookRegister* _tmp84_;
					gint _tmp85_;
					GomSerializationTestHashRegisters* _tmp86_;
					GomSerializationTestBookRegister* _tmp87_;
#line 1402 "GomSerializationTest.vala"
					if (!_tmp72_) {
#line 15841 "GomSerializationTest.c"
						gint _tmp73_;
#line 1402 "GomSerializationTest.vala"
						_tmp73_ = i;
#line 1402 "GomSerializationTest.vala"
						i = _tmp73_ + 1;
#line 15847 "GomSerializationTest.c"
					}
#line 1402 "GomSerializationTest.vala"
					_tmp72_ = FALSE;
#line 1402 "GomSerializationTest.vala"
					if (!(i < 10)) {
#line 1402 "GomSerializationTest.vala"
						break;
#line 15855 "GomSerializationTest.c"
					}
#line 1403 "GomSerializationTest.vala"
					_tmp74_ = hr;
#line 1403 "GomSerializationTest.vala"
					_tmp75_ = gxml_collection_create_item ((GXmlCollection*) _tmp74_);
#line 1403 "GomSerializationTest.vala"
					_tmp76_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp75_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp75_) : NULL;
#line 1403 "GomSerializationTest.vala"
					if (_tmp76_ == NULL) {
#line 1403 "GomSerializationTest.vala"
						_g_object_unref0 (_tmp75_);
#line 15867 "GomSerializationTest.c"
					}
#line 1403 "GomSerializationTest.vala"
					b = _tmp76_;
#line 1404 "GomSerializationTest.vala"
					_tmp77_ = b;
#line 1404 "GomSerializationTest.vala"
					_vala_assert (_tmp77_ != NULL, "b != null");
#line 1405 "GomSerializationTest.vala"
					_tmp78_ = b;
#line 1405 "GomSerializationTest.vala"
					gxml_gom_object_set_instance_property ((GXmlGomObject*) _tmp78_, "book");
#line 1406 "GomSerializationTest.vala"
					_tmp79_ = b;
#line 1406 "GomSerializationTest.vala"
					_tmp80_ = gom_serialization_test_book_register_get_book (_tmp79_);
#line 1406 "GomSerializationTest.vala"
					_tmp81_ = _tmp80_;
#line 1406 "GomSerializationTest.vala"
					_tmp82_ = g_strdup_printf ("book%d", n);
#line 1406 "GomSerializationTest.vala"
					_tmp83_ = _tmp82_;
#line 1406 "GomSerializationTest.vala"
					gom_serialization_test_book_set_name (_tmp81_, _tmp83_);
#line 1406 "GomSerializationTest.vala"
					_g_free0 (_tmp83_);
#line 1407 "GomSerializationTest.vala"
					_tmp84_ = b;
#line 1407 "GomSerializationTest.vala"
					gom_serialization_test_book_register_set_year (_tmp84_, 2000 + n);
#line 1408 "GomSerializationTest.vala"
					_tmp85_ = n;
#line 1408 "GomSerializationTest.vala"
					n = _tmp85_ + 1;
#line 1409 "GomSerializationTest.vala"
					_tmp86_ = hr;
#line 1409 "GomSerializationTest.vala"
					_tmp87_ = b;
#line 1409 "GomSerializationTest.vala"
					gxml_collection_append ((GXmlCollection*) _tmp86_, (GXmlDomElement*) _tmp87_, &_inner_error0_);
#line 1409 "GomSerializationTest.vala"
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1409 "GomSerializationTest.vala"
						_g_object_unref0 (b);
#line 1409 "GomSerializationTest.vala"
						_g_object_unref0 (hr);
#line 1409 "GomSerializationTest.vala"
						_g_object_unref0 (r);
#line 1409 "GomSerializationTest.vala"
						_g_object_unref0 (bst);
#line 1409 "GomSerializationTest.vala"
						_g_free0 (_tmp21_);
#line 1409 "GomSerializationTest.vala"
						_g_object_unref0 (bs);
#line 15921 "GomSerializationTest.c"
						goto __catch194_g_error;
					}
#line 1402 "GomSerializationTest.vala"
					_g_object_unref0 (b);
#line 15926 "GomSerializationTest.c"
				}
			}
		}
#line 1411 "GomSerializationTest.vala"
		n = 1;
#line 15932 "GomSerializationTest.c"
		{
			GeeIterator* _e_it = NULL;
			GomSerializationTestHashRegisters* _tmp88_;
			GeeIterator* _tmp89_;
#line 1412 "GomSerializationTest.vala"
			_tmp88_ = hr;
#line 1412 "GomSerializationTest.vala"
			_tmp89_ = gee_iterable_iterator ((GeeIterable*) _tmp88_);
#line 1412 "GomSerializationTest.vala"
			_e_it = _tmp89_;
#line 1412 "GomSerializationTest.vala"
			while (TRUE) {
#line 15945 "GomSerializationTest.c"
				GeeIterator* _tmp90_;
				GXmlDomElement* e = NULL;
				GeeIterator* _tmp91_;
				gpointer _tmp92_;
				GXmlDomElement* _tmp93_;
				GXmlDomElement* _tmp94_;
				gint _tmp95_;
				gint _tmp96_;
				gint _tmp97_;
#line 1412 "GomSerializationTest.vala"
				_tmp90_ = _e_it;
#line 1412 "GomSerializationTest.vala"
				if (!gee_iterator_next (_tmp90_)) {
#line 1412 "GomSerializationTest.vala"
					break;
#line 15961 "GomSerializationTest.c"
				}
#line 1412 "GomSerializationTest.vala"
				_tmp91_ = _e_it;
#line 1412 "GomSerializationTest.vala"
				_tmp92_ = gee_iterator_get (_tmp91_);
#line 1412 "GomSerializationTest.vala"
				e = (GXmlDomElement*) _tmp92_;
#line 1413 "GomSerializationTest.vala"
				_tmp93_ = e;
#line 1413 "GomSerializationTest.vala"
				_vala_assert ((G_TYPE_CHECK_INSTANCE_TYPE (_tmp93_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp93_) : NULL) != NULL, "(e as BookRegister) != null");
#line 1414 "GomSerializationTest.vala"
				_tmp94_ = e;
#line 1414 "GomSerializationTest.vala"
				_tmp95_ = gom_serialization_test_book_register_get_year (G_TYPE_CHECK_INSTANCE_TYPE (_tmp94_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp94_) : NULL);
#line 1414 "GomSerializationTest.vala"
				_tmp96_ = _tmp95_;
#line 1414 "GomSerializationTest.vala"
				_vala_assert (_tmp96_ == (2000 + n), "(e as BookRegister).year == 2000 + n");
#line 1415 "GomSerializationTest.vala"
				_tmp97_ = n;
#line 1415 "GomSerializationTest.vala"
				n = _tmp97_ + 1;
#line 1412 "GomSerializationTest.vala"
				_g_object_unref0 (e);
#line 15987 "GomSerializationTest.c"
			}
#line 1412 "GomSerializationTest.vala"
			_g_object_unref0 (_e_it);
#line 15991 "GomSerializationTest.c"
		}
#line 1418 "GomSerializationTest.vala"
		_tmp98_ = bst;
#line 1418 "GomSerializationTest.vala"
		gxml_gom_object_set_instance_property ((GXmlGomObject*) _tmp98_, "hashpair-registers");
#line 1419 "GomSerializationTest.vala"
		_tmp99_ = bst;
#line 1419 "GomSerializationTest.vala"
		_tmp100_ = gom_serialization_test_book_stand_get_hashpair_registers (_tmp99_);
#line 1419 "GomSerializationTest.vala"
		_tmp101_ = _tmp100_;
#line 1419 "GomSerializationTest.vala"
		_tmp102_ = _g_object_ref0 (_tmp101_);
#line 1419 "GomSerializationTest.vala"
		hpr = _tmp102_;
#line 1420 "GomSerializationTest.vala"
		n = 1;
#line 16009 "GomSerializationTest.c"
		{
			gint i = 0;
#line 1421 "GomSerializationTest.vala"
			i = 0;
#line 16014 "GomSerializationTest.c"
			{
				gboolean _tmp103_ = FALSE;
#line 1421 "GomSerializationTest.vala"
				_tmp103_ = TRUE;
#line 1421 "GomSerializationTest.vala"
				while (TRUE) {
#line 16021 "GomSerializationTest.c"
					GomSerializationTestBookRegister* b = NULL;
					GomSerializationTestHashPairRegisters* _tmp105_;
					GXmlDomElement* _tmp106_;
					GomSerializationTestBookRegister* _tmp107_;
					GomSerializationTestBookRegister* _tmp108_;
					GomSerializationTestBookRegister* _tmp109_;
					GomSerializationTestBookRegister* _tmp110_;
					GomSerializationTestBook* _tmp111_;
					GomSerializationTestBook* _tmp112_;
					gchar* _tmp113_;
					gchar* _tmp114_;
					GomSerializationTestBookRegister* _tmp115_;
					gint _tmp116_;
					GomSerializationTestHashPairRegisters* _tmp117_;
					GomSerializationTestBookRegister* _tmp118_;
#line 1421 "GomSerializationTest.vala"
					if (!_tmp103_) {
#line 16039 "GomSerializationTest.c"
						gint _tmp104_;
#line 1421 "GomSerializationTest.vala"
						_tmp104_ = i;
#line 1421 "GomSerializationTest.vala"
						i = _tmp104_ + 1;
#line 16045 "GomSerializationTest.c"
					}
#line 1421 "GomSerializationTest.vala"
					_tmp103_ = FALSE;
#line 1421 "GomSerializationTest.vala"
					if (!(i < 10)) {
#line 1421 "GomSerializationTest.vala"
						break;
#line 16053 "GomSerializationTest.c"
					}
#line 1422 "GomSerializationTest.vala"
					_tmp105_ = hpr;
#line 1422 "GomSerializationTest.vala"
					_tmp106_ = gxml_collection_create_item ((GXmlCollection*) _tmp105_);
#line 1422 "GomSerializationTest.vala"
					_tmp107_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp106_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp106_) : NULL;
#line 1422 "GomSerializationTest.vala"
					if (_tmp107_ == NULL) {
#line 1422 "GomSerializationTest.vala"
						_g_object_unref0 (_tmp106_);
#line 16065 "GomSerializationTest.c"
					}
#line 1422 "GomSerializationTest.vala"
					b = _tmp107_;
#line 1423 "GomSerializationTest.vala"
					_tmp108_ = b;
#line 1423 "GomSerializationTest.vala"
					_vala_assert (_tmp108_ != NULL, "b != null");
#line 1424 "GomSerializationTest.vala"
					_tmp109_ = b;
#line 1424 "GomSerializationTest.vala"
					gxml_gom_object_set_instance_property ((GXmlGomObject*) _tmp109_, "book");
#line 1425 "GomSerializationTest.vala"
					_tmp110_ = b;
#line 1425 "GomSerializationTest.vala"
					_tmp111_ = gom_serialization_test_book_register_get_book (_tmp110_);
#line 1425 "GomSerializationTest.vala"
					_tmp112_ = _tmp111_;
#line 1425 "GomSerializationTest.vala"
					_tmp113_ = g_strdup_printf ("book%d", n);
#line 1425 "GomSerializationTest.vala"
					_tmp114_ = _tmp113_;
#line 1425 "GomSerializationTest.vala"
					gom_serialization_test_book_set_name (_tmp112_, _tmp114_);
#line 1425 "GomSerializationTest.vala"
					_g_free0 (_tmp114_);
#line 1426 "GomSerializationTest.vala"
					_tmp115_ = b;
#line 1426 "GomSerializationTest.vala"
					gom_serialization_test_book_register_set_year (_tmp115_, 2000 + n);
#line 1427 "GomSerializationTest.vala"
					_tmp116_ = n;
#line 1427 "GomSerializationTest.vala"
					n = _tmp116_ + 1;
#line 1428 "GomSerializationTest.vala"
					_tmp117_ = hpr;
#line 1428 "GomSerializationTest.vala"
					_tmp118_ = b;
#line 1428 "GomSerializationTest.vala"
					gxml_collection_append ((GXmlCollection*) _tmp117_, (GXmlDomElement*) _tmp118_, &_inner_error0_);
#line 1428 "GomSerializationTest.vala"
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1428 "GomSerializationTest.vala"
						_g_object_unref0 (b);
#line 1428 "GomSerializationTest.vala"
						_g_object_unref0 (hpr);
#line 1428 "GomSerializationTest.vala"
						_g_object_unref0 (hr);
#line 1428 "GomSerializationTest.vala"
						_g_object_unref0 (r);
#line 1428 "GomSerializationTest.vala"
						_g_object_unref0 (bst);
#line 1428 "GomSerializationTest.vala"
						_g_free0 (_tmp21_);
#line 1428 "GomSerializationTest.vala"
						_g_object_unref0 (bs);
#line 16121 "GomSerializationTest.c"
						goto __catch194_g_error;
					}
#line 1421 "GomSerializationTest.vala"
					_g_object_unref0 (b);
#line 16126 "GomSerializationTest.c"
				}
			}
		}
#line 1430 "GomSerializationTest.vala"
		n = 1;
#line 16132 "GomSerializationTest.c"
		{
			GeeIterator* _e_it = NULL;
			GomSerializationTestHashPairRegisters* _tmp119_;
			GeeIterator* _tmp120_;
#line 1431 "GomSerializationTest.vala"
			_tmp119_ = hpr;
#line 1431 "GomSerializationTest.vala"
			_tmp120_ = gee_iterable_iterator ((GeeIterable*) _tmp119_);
#line 1431 "GomSerializationTest.vala"
			_e_it = _tmp120_;
#line 1431 "GomSerializationTest.vala"
			while (TRUE) {
#line 16145 "GomSerializationTest.c"
				GeeIterator* _tmp121_;
				GXmlDomElement* e = NULL;
				GeeIterator* _tmp122_;
				gpointer _tmp123_;
				GXmlDomElement* _tmp124_;
				GXmlDomElement* _tmp125_;
				GomSerializationTestBook* _tmp126_;
				GomSerializationTestBook* _tmp127_;
				const gchar* _tmp128_;
				const gchar* _tmp129_;
				gchar* _tmp130_;
				gchar* _tmp131_;
				GXmlDomElement* _tmp132_;
				gint _tmp133_;
				gint _tmp134_;
				gint _tmp135_;
#line 1431 "GomSerializationTest.vala"
				_tmp121_ = _e_it;
#line 1431 "GomSerializationTest.vala"
				if (!gee_iterator_next (_tmp121_)) {
#line 1431 "GomSerializationTest.vala"
					break;
#line 16168 "GomSerializationTest.c"
				}
#line 1431 "GomSerializationTest.vala"
				_tmp122_ = _e_it;
#line 1431 "GomSerializationTest.vala"
				_tmp123_ = gee_iterator_get (_tmp122_);
#line 1431 "GomSerializationTest.vala"
				e = (GXmlDomElement*) _tmp123_;
#line 1432 "GomSerializationTest.vala"
				_tmp124_ = e;
#line 1432 "GomSerializationTest.vala"
				_vala_assert ((G_TYPE_CHECK_INSTANCE_TYPE (_tmp124_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp124_) : NULL) != NULL, "(e as BookRegister) != null");
#line 1433 "GomSerializationTest.vala"
				_tmp125_ = e;
#line 1433 "GomSerializationTest.vala"
				_tmp126_ = gom_serialization_test_book_register_get_book (G_TYPE_CHECK_INSTANCE_TYPE (_tmp125_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp125_) : NULL);
#line 1433 "GomSerializationTest.vala"
				_tmp127_ = _tmp126_;
#line 1433 "GomSerializationTest.vala"
				_tmp128_ = gom_serialization_test_book_get_name (_tmp127_);
#line 1433 "GomSerializationTest.vala"
				_tmp129_ = _tmp128_;
#line 1433 "GomSerializationTest.vala"
				_tmp130_ = g_strdup_printf ("book%d", n);
#line 1433 "GomSerializationTest.vala"
				_tmp131_ = _tmp130_;
#line 1433 "GomSerializationTest.vala"
				_vala_assert (g_strcmp0 (_tmp129_, _tmp131_) == 0, "(e as BookRegister).book.name == \"book%d\".printf (n)");
#line 1433 "GomSerializationTest.vala"
				_g_free0 (_tmp131_);
#line 1434 "GomSerializationTest.vala"
				_tmp132_ = e;
#line 1434 "GomSerializationTest.vala"
				_tmp133_ = gom_serialization_test_book_register_get_year (G_TYPE_CHECK_INSTANCE_TYPE (_tmp132_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp132_) : NULL);
#line 1434 "GomSerializationTest.vala"
				_tmp134_ = _tmp133_;
#line 1434 "GomSerializationTest.vala"
				_vala_assert (_tmp134_ == (2000 + n), "(e as BookRegister).year ==  2000 + n");
#line 1435 "GomSerializationTest.vala"
				_tmp135_ = n;
#line 1435 "GomSerializationTest.vala"
				n = _tmp135_ + 1;
#line 1431 "GomSerializationTest.vala"
				_g_object_unref0 (e);
#line 16212 "GomSerializationTest.c"
			}
#line 1431 "GomSerializationTest.vala"
			_g_object_unref0 (_e_it);
#line 16216 "GomSerializationTest.c"
		}
#line 1438 "GomSerializationTest.vala"
		_tmp136_ = bst;
#line 1438 "GomSerializationTest.vala"
		gxml_gom_object_set_instance_property ((GXmlGomObject*) _tmp136_, "hashthree-registers");
#line 1439 "GomSerializationTest.vala"
		_tmp137_ = bst;
#line 1439 "GomSerializationTest.vala"
		_tmp138_ = gom_serialization_test_book_stand_get_hashthree_registers (_tmp137_);
#line 1439 "GomSerializationTest.vala"
		_tmp139_ = _tmp138_;
#line 1439 "GomSerializationTest.vala"
		_tmp140_ = _g_object_ref0 (_tmp139_);
#line 1439 "GomSerializationTest.vala"
		htr = _tmp140_;
#line 1440 "GomSerializationTest.vala"
		n = 1;
#line 16234 "GomSerializationTest.c"
		{
			gint i = 0;
#line 1441 "GomSerializationTest.vala"
			i = 0;
#line 16239 "GomSerializationTest.c"
			{
				gboolean _tmp141_ = FALSE;
#line 1441 "GomSerializationTest.vala"
				_tmp141_ = TRUE;
#line 1441 "GomSerializationTest.vala"
				while (TRUE) {
#line 16246 "GomSerializationTest.c"
					GomSerializationTestBookRegister* b = NULL;
					GomSerializationTestHashThreeRegisters* _tmp143_;
					GXmlDomElement* _tmp144_;
					GomSerializationTestBookRegister* _tmp145_;
					GomSerializationTestBookRegister* _tmp146_;
					GomSerializationTestBookRegister* _tmp147_;
					GomSerializationTestBookRegister* _tmp148_;
					GomSerializationTestBook* _tmp149_;
					GomSerializationTestBook* _tmp150_;
					gchar* _tmp151_;
					gchar* _tmp152_;
					GomSerializationTestBookRegister* _tmp153_;
					GomSerializationTestBookRegister* _tmp154_;
					gchar* _tmp155_;
					gchar* _tmp156_;
					gint _tmp157_;
					GomSerializationTestHashThreeRegisters* _tmp158_;
					GomSerializationTestBookRegister* _tmp159_;
#line 1441 "GomSerializationTest.vala"
					if (!_tmp141_) {
#line 16267 "GomSerializationTest.c"
						gint _tmp142_;
#line 1441 "GomSerializationTest.vala"
						_tmp142_ = i;
#line 1441 "GomSerializationTest.vala"
						i = _tmp142_ + 1;
#line 16273 "GomSerializationTest.c"
					}
#line 1441 "GomSerializationTest.vala"
					_tmp141_ = FALSE;
#line 1441 "GomSerializationTest.vala"
					if (!(i < 10)) {
#line 1441 "GomSerializationTest.vala"
						break;
#line 16281 "GomSerializationTest.c"
					}
#line 1442 "GomSerializationTest.vala"
					_tmp143_ = htr;
#line 1442 "GomSerializationTest.vala"
					_tmp144_ = gxml_collection_create_item ((GXmlCollection*) _tmp143_);
#line 1442 "GomSerializationTest.vala"
					_tmp145_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp144_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp144_) : NULL;
#line 1442 "GomSerializationTest.vala"
					if (_tmp145_ == NULL) {
#line 1442 "GomSerializationTest.vala"
						_g_object_unref0 (_tmp144_);
#line 16293 "GomSerializationTest.c"
					}
#line 1442 "GomSerializationTest.vala"
					b = _tmp145_;
#line 1443 "GomSerializationTest.vala"
					_tmp146_ = b;
#line 1443 "GomSerializationTest.vala"
					_vala_assert (_tmp146_ != NULL, "b != null");
#line 1444 "GomSerializationTest.vala"
					_tmp147_ = b;
#line 1444 "GomSerializationTest.vala"
					gxml_gom_object_set_instance_property ((GXmlGomObject*) _tmp147_, "book");
#line 1445 "GomSerializationTest.vala"
					_tmp148_ = b;
#line 1445 "GomSerializationTest.vala"
					_tmp149_ = gom_serialization_test_book_register_get_book (_tmp148_);
#line 1445 "GomSerializationTest.vala"
					_tmp150_ = _tmp149_;
#line 1445 "GomSerializationTest.vala"
					_tmp151_ = g_strdup_printf ("book%d", n);
#line 1445 "GomSerializationTest.vala"
					_tmp152_ = _tmp151_;
#line 1445 "GomSerializationTest.vala"
					gom_serialization_test_book_set_name (_tmp150_, _tmp152_);
#line 1445 "GomSerializationTest.vala"
					_g_free0 (_tmp152_);
#line 1446 "GomSerializationTest.vala"
					_tmp153_ = b;
#line 1446 "GomSerializationTest.vala"
					gom_serialization_test_book_register_set_year (_tmp153_, 2000 + n);
#line 1447 "GomSerializationTest.vala"
					_tmp154_ = b;
#line 1447 "GomSerializationTest.vala"
					_tmp155_ = g_strdup_printf ("cover%d", n);
#line 1447 "GomSerializationTest.vala"
					_tmp156_ = _tmp155_;
#line 1447 "GomSerializationTest.vala"
					gom_serialization_test_book_register_set_cover (_tmp154_, _tmp156_);
#line 1447 "GomSerializationTest.vala"
					_g_free0 (_tmp156_);
#line 1448 "GomSerializationTest.vala"
					_tmp157_ = n;
#line 1448 "GomSerializationTest.vala"
					n = _tmp157_ + 1;
#line 1449 "GomSerializationTest.vala"
					_tmp158_ = htr;
#line 1449 "GomSerializationTest.vala"
					_tmp159_ = b;
#line 1449 "GomSerializationTest.vala"
					gxml_collection_append ((GXmlCollection*) _tmp158_, (GXmlDomElement*) _tmp159_, &_inner_error0_);
#line 1449 "GomSerializationTest.vala"
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1449 "GomSerializationTest.vala"
						_g_object_unref0 (b);
#line 1449 "GomSerializationTest.vala"
						_g_object_unref0 (htr);
#line 1449 "GomSerializationTest.vala"
						_g_object_unref0 (hpr);
#line 1449 "GomSerializationTest.vala"
						_g_object_unref0 (hr);
#line 1449 "GomSerializationTest.vala"
						_g_object_unref0 (r);
#line 1449 "GomSerializationTest.vala"
						_g_object_unref0 (bst);
#line 1449 "GomSerializationTest.vala"
						_g_free0 (_tmp21_);
#line 1449 "GomSerializationTest.vala"
						_g_object_unref0 (bs);
#line 16361 "GomSerializationTest.c"
						goto __catch194_g_error;
					}
#line 1441 "GomSerializationTest.vala"
					_g_object_unref0 (b);
#line 16366 "GomSerializationTest.c"
				}
			}
		}
#line 1451 "GomSerializationTest.vala"
		n = 1;
#line 16372 "GomSerializationTest.c"
		{
			GeeIterator* _e_it = NULL;
			GomSerializationTestHashThreeRegisters* _tmp160_;
			GeeIterator* _tmp161_;
#line 1452 "GomSerializationTest.vala"
			_tmp160_ = htr;
#line 1452 "GomSerializationTest.vala"
			_tmp161_ = gee_iterable_iterator ((GeeIterable*) _tmp160_);
#line 1452 "GomSerializationTest.vala"
			_e_it = _tmp161_;
#line 1452 "GomSerializationTest.vala"
			while (TRUE) {
#line 16385 "GomSerializationTest.c"
				GeeIterator* _tmp162_;
				GXmlDomElement* e = NULL;
				GeeIterator* _tmp163_;
				gpointer _tmp164_;
				GXmlDomElement* _tmp165_;
				GXmlDomElement* _tmp166_;
				GomSerializationTestBook* _tmp167_;
				GomSerializationTestBook* _tmp168_;
				const gchar* _tmp169_;
				const gchar* _tmp170_;
				gchar* _tmp171_;
				gchar* _tmp172_;
				GXmlDomElement* _tmp173_;
				gint _tmp174_;
				gint _tmp175_;
				GXmlDomElement* _tmp176_;
				const gchar* _tmp177_;
				const gchar* _tmp178_;
				gchar* _tmp179_;
				gchar* _tmp180_;
				gint _tmp181_;
#line 1452 "GomSerializationTest.vala"
				_tmp162_ = _e_it;
#line 1452 "GomSerializationTest.vala"
				if (!gee_iterator_next (_tmp162_)) {
#line 1452 "GomSerializationTest.vala"
					break;
#line 16413 "GomSerializationTest.c"
				}
#line 1452 "GomSerializationTest.vala"
				_tmp163_ = _e_it;
#line 1452 "GomSerializationTest.vala"
				_tmp164_ = gee_iterator_get (_tmp163_);
#line 1452 "GomSerializationTest.vala"
				e = (GXmlDomElement*) _tmp164_;
#line 1453 "GomSerializationTest.vala"
				_tmp165_ = e;
#line 1453 "GomSerializationTest.vala"
				_vala_assert ((G_TYPE_CHECK_INSTANCE_TYPE (_tmp165_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp165_) : NULL) != NULL, "(e as BookRegister) != null");
#line 1454 "GomSerializationTest.vala"
				_tmp166_ = e;
#line 1454 "GomSerializationTest.vala"
				_tmp167_ = gom_serialization_test_book_register_get_book (G_TYPE_CHECK_INSTANCE_TYPE (_tmp166_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp166_) : NULL);
#line 1454 "GomSerializationTest.vala"
				_tmp168_ = _tmp167_;
#line 1454 "GomSerializationTest.vala"
				_tmp169_ = gom_serialization_test_book_get_name (_tmp168_);
#line 1454 "GomSerializationTest.vala"
				_tmp170_ = _tmp169_;
#line 1454 "GomSerializationTest.vala"
				_tmp171_ = g_strdup_printf ("book%d", n);
#line 1454 "GomSerializationTest.vala"
				_tmp172_ = _tmp171_;
#line 1454 "GomSerializationTest.vala"
				_vala_assert (g_strcmp0 (_tmp170_, _tmp172_) == 0, "(e as BookRegister).book.name == \"book%d\".printf (n)");
#line 1454 "GomSerializationTest.vala"
				_g_free0 (_tmp172_);
#line 1455 "GomSerializationTest.vala"
				_tmp173_ = e;
#line 1455 "GomSerializationTest.vala"
				_tmp174_ = gom_serialization_test_book_register_get_year (G_TYPE_CHECK_INSTANCE_TYPE (_tmp173_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp173_) : NULL);
#line 1455 "GomSerializationTest.vala"
				_tmp175_ = _tmp174_;
#line 1455 "GomSerializationTest.vala"
				_vala_assert (_tmp175_ == (2000 + n), "(e as BookRegister).year == 2000 + n");
#line 1456 "GomSerializationTest.vala"
				_tmp176_ = e;
#line 1456 "GomSerializationTest.vala"
				_tmp177_ = gom_serialization_test_book_register_get_cover (G_TYPE_CHECK_INSTANCE_TYPE (_tmp176_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp176_) : NULL);
#line 1456 "GomSerializationTest.vala"
				_tmp178_ = _tmp177_;
#line 1456 "GomSerializationTest.vala"
				_tmp179_ = g_strdup_printf ("cover%d", n);
#line 1456 "GomSerializationTest.vala"
				_tmp180_ = _tmp179_;
#line 1456 "GomSerializationTest.vala"
				_vala_assert (g_strcmp0 (_tmp178_, _tmp180_) == 0, "(e as BookRegister).cover == \"cover%d\".printf (n)");
#line 1456 "GomSerializationTest.vala"
				_g_free0 (_tmp180_);
#line 1457 "GomSerializationTest.vala"
				_tmp181_ = n;
#line 1457 "GomSerializationTest.vala"
				n = _tmp181_ + 1;
#line 1452 "GomSerializationTest.vala"
				_g_object_unref0 (e);
#line 16471 "GomSerializationTest.c"
			}
#line 1452 "GomSerializationTest.vala"
			_g_object_unref0 (_e_it);
#line 16475 "GomSerializationTest.c"
		}
#line 1362 "GomSerializationTest.vala"
		_g_object_unref0 (htr);
#line 1362 "GomSerializationTest.vala"
		_g_object_unref0 (hpr);
#line 1362 "GomSerializationTest.vala"
		_g_object_unref0 (hr);
#line 1362 "GomSerializationTest.vala"
		_g_object_unref0 (r);
#line 1362 "GomSerializationTest.vala"
		_g_object_unref0 (bst);
#line 1362 "GomSerializationTest.vala"
		_g_free0 (_tmp21_);
#line 1362 "GomSerializationTest.vala"
		_g_object_unref0 (bs);
#line 16491 "GomSerializationTest.c"
	}
	goto __finally194;
	__catch194_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp182_;
		gchar* _tmp183_;
		gchar* _tmp184_;
#line 1362 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 1362 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 1460 "GomSerializationTest.vala"
		_tmp182_ = e->message;
#line 1460 "GomSerializationTest.vala"
		_tmp183_ = g_strconcat ("Error: ", _tmp182_, NULL);
#line 1460 "GomSerializationTest.vala"
		_tmp184_ = _tmp183_;
#line 1460 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1460: %s", _tmp184_);
#line 1460 "GomSerializationTest.vala"
		_g_free0 (_tmp184_);
#line 1461 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 1362 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 16518 "GomSerializationTest.c"
	}
	__finally194:
#line 1362 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1362 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 1362 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 1362 "GomSerializationTest.vala"
		return;
#line 16529 "GomSerializationTest.c"
	}
}

static void
___lambda141__gtest_func (void)
{
#line 1361 "GomSerializationTest.vala"
	__lambda141_ ();
#line 16538 "GomSerializationTest.c"
}

static void
__lambda142_ (void)
{
	ThreeKey* tk = NULL;
	ThreeKey* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
#line 1465 "GomSerializationTest.vala"
	_tmp0_ = three_key_new ();
#line 1465 "GomSerializationTest.vala"
	tk = _tmp0_;
#line 1466 "GomSerializationTest.vala"
	_tmp1_ = three_key_get_code (tk);
#line 1466 "GomSerializationTest.vala"
	_tmp2_ = _tmp1_;
#line 1466 "GomSerializationTest.vala"
	_vala_assert (_tmp2_ == NULL, "tk.code == null");
#line 1467 "GomSerializationTest.vala"
	_tmp3_ = gxml_dom_element_get_attribute ((GXmlDomElement*) tk, "Code");
#line 1467 "GomSerializationTest.vala"
	_tmp4_ = _tmp3_;
#line 1467 "GomSerializationTest.vala"
	_vala_assert (_tmp4_ == NULL, "tk.get_attribute (\"Code\") == null");
#line 1467 "GomSerializationTest.vala"
	_g_free0 (_tmp4_);
#line 1468 "GomSerializationTest.vala"
	three_key_set_code (tk, "code");
#line 1469 "GomSerializationTest.vala"
	_tmp5_ = gxml_dom_element_get_attribute ((GXmlDomElement*) tk, "Code");
#line 1469 "GomSerializationTest.vala"
	_tmp6_ = _tmp5_;
#line 1469 "GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp6_, "code") == 0, "tk.get_attribute (\"Code\") == \"code\"");
#line 1469 "GomSerializationTest.vala"
	_g_free0 (_tmp6_);
#line 1464 "GomSerializationTest.vala"
	_g_object_unref0 (tk);
#line 16582 "GomSerializationTest.c"
}

static void
___lambda142__gtest_func (void)
{
#line 1464 "GomSerializationTest.vala"
	__lambda142_ ();
#line 16590 "GomSerializationTest.c"
}

void
gom_serialization_test_add_tests (void)
{
#line 519 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/write/properties", ___lambda119__gtest_func);
#line 537 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/write/property-ignore", ___lambda120__gtest_func);
#line 553 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/write/property-long-name", ___lambda121__gtest_func);
#line 582 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/write/property-date", ___lambda122__gtest_func);
#line 618 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/read/property-date", ___lambda123__gtest_func);
#line 640 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/write/property-datetime", ___lambda124__gtest_func);
#line 673 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/write/property-arraylist", ___lambda125__gtest_func);
#line 753 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/write/property-hashmap", ___lambda126__gtest_func);
#line 808 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/mappeable", ___lambda127__gtest_func);
#line 835 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/write/mappeablepairedkey", ___lambda128__gtest_func);
#line 857 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/write/mappeablethreekey", ___lambda129__gtest_func);
#line 885 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/write/gom-property", ___lambda130__gtest_func);
#line 970 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/read/properties", ___lambda131__gtest_func);
#line 998 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/read/bad-node-name", ___lambda132__gtest_func);
#line 1015 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/read/object-property", ___lambda133__gtest_func);
#line 1034 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/read/gom-property", ___lambda134__gtest_func);
#line 1070 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/read/property-arraylist", ___lambda135__gtest_func);
#line 1107 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/read/property-hashmap", ___lambda136__gtest_func);
#line 1152 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/multiple-child-collections", ___lambda137__gtest_func);
#line 1212 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/collections/hashpairedmap/keys", ___lambda138__gtest_func);
#line 1264 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/collections/hashthreemap/keys", ___lambda139__gtest_func);
#line 1320 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/basic-types", ___lambda140__gtest_func);
#line 1361 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/collection/iteration", ___lambda141__gtest_func);
#line 1464 "GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/attribute-gobject", ___lambda142__gtest_func);
#line 16644 "GomSerializationTest.c"
}

GomSerializationTest*
gom_serialization_test_construct (GType object_type)
{
	GomSerializationTest* self = NULL;
#line 218 "GomSerializationTest.vala"
	self = (GomSerializationTest*) gxml_test_construct (object_type);
#line 218 "GomSerializationTest.vala"
	return self;
#line 16655 "GomSerializationTest.c"
}

GomSerializationTest*
gom_serialization_test_new (void)
{
#line 218 "GomSerializationTest.vala"
	return gom_serialization_test_construct (TYPE_GOM_SERIALIZATION_TEST);
#line 16663 "GomSerializationTest.c"
}

static inline gpointer
gom_serialization_test_book_get_instance_private (GomSerializationTestBook* self)
{
	return G_STRUCT_MEMBER_P (self, GomSerializationTestBook_private_offset);
}

GomSerializationTestBook*
gom_serialization_test_book_construct_document (GType object_type,
                                                GXmlDomDocument* doc)
{
	GomSerializationTestBook * self = NULL;
	GXmlDomDocument* _tmp0_;
#line 223 "GomSerializationTest.vala"
	g_return_val_if_fail (doc != NULL, NULL);
#line 223 "GomSerializationTest.vala"
	self = (GomSerializationTestBook*) gxml_gom_element_construct (object_type);
#line 224 "GomSerializationTest.vala"
	_tmp0_ = _g_object_ref0 (doc);
#line 224 "GomSerializationTest.vala"
	_g_object_unref0 (((GXmlGomNode*) self)->_document);
#line 224 "GomSerializationTest.vala"
	((GXmlGomNode*) self)->_document = _tmp0_;
#line 223 "GomSerializationTest.vala"
	return self;
#line 16690 "GomSerializationTest.c"
}

GomSerializationTestBook*
gom_serialization_test_book_new_document (GXmlDomDocument* doc)
{
#line 223 "GomSerializationTest.vala"
	return gom_serialization_test_book_construct_document (GOM_SERIALIZATION_TEST_TYPE_BOOK, doc);
#line 16698 "GomSerializationTest.c"
}

gchar*
gom_serialization_test_book_to_string (GomSerializationTestBook* self)
{
	gchar* result = NULL;
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_;
	gchar* s = NULL;
	gchar* _tmp1_;
	GError* _inner_error0_ = NULL;
#line 226 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 227 "GomSerializationTest.vala"
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
#line 227 "GomSerializationTest.vala"
	parser = _tmp0_;
#line 228 "GomSerializationTest.vala"
	_tmp1_ = g_strdup ("");
#line 228 "GomSerializationTest.vala"
	s = _tmp1_;
#line 16720 "GomSerializationTest.c"
	{
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_;
		gchar* _tmp4_;
#line 230 "GomSerializationTest.vala"
		_tmp3_ = gxml_parser_write_string ((GXmlParser*) parser, &_inner_error0_);
#line 230 "GomSerializationTest.vala"
		_tmp2_ = _tmp3_;
#line 230 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 16731 "GomSerializationTest.c"
			goto __catch195_g_error;
		}
#line 230 "GomSerializationTest.vala"
		_tmp4_ = _tmp2_;
#line 230 "GomSerializationTest.vala"
		_tmp2_ = NULL;
#line 230 "GomSerializationTest.vala"
		_g_free0 (s);
#line 230 "GomSerializationTest.vala"
		s = _tmp4_;
#line 229 "GomSerializationTest.vala"
		_g_free0 (_tmp2_);
#line 16744 "GomSerializationTest.c"
	}
	goto __finally195;
	__catch195_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
#line 229 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 229 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 232 "GomSerializationTest.vala"
		_tmp5_ = e->message;
#line 232 "GomSerializationTest.vala"
		_tmp6_ = g_strconcat ("Error: ", _tmp5_, NULL);
#line 232 "GomSerializationTest.vala"
		_tmp7_ = _tmp6_;
#line 232 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:232: %s", _tmp7_);
#line 232 "GomSerializationTest.vala"
		_g_free0 (_tmp7_);
#line 233 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 229 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 16771 "GomSerializationTest.c"
	}
	__finally195:
#line 229 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 229 "GomSerializationTest.vala"
		_g_free0 (s);
#line 229 "GomSerializationTest.vala"
		_g_object_unref0 (parser);
#line 229 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 229 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 229 "GomSerializationTest.vala"
		return NULL;
#line 16786 "GomSerializationTest.c"
	}
#line 235 "GomSerializationTest.vala"
	result = s;
#line 235 "GomSerializationTest.vala"
	_g_object_unref0 (parser);
#line 235 "GomSerializationTest.vala"
	return result;
#line 16794 "GomSerializationTest.c"
}

GomSerializationTestBook*
gom_serialization_test_book_construct (GType object_type)
{
	GomSerializationTestBook * self = NULL;
#line 219 "GomSerializationTest.vala"
	self = (GomSerializationTestBook*) gxml_gom_element_construct (object_type);
#line 219 "GomSerializationTest.vala"
	return self;
#line 16805 "GomSerializationTest.c"
}

GomSerializationTestBook*
gom_serialization_test_book_new (void)
{
#line 219 "GomSerializationTest.vala"
	return gom_serialization_test_book_construct (GOM_SERIALIZATION_TEST_TYPE_BOOK);
#line 16813 "GomSerializationTest.c"
}

const gchar*
gom_serialization_test_book_get_name (GomSerializationTestBook* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 221 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 221 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_name;
#line 221 "GomSerializationTest.vala"
	result = _tmp0_;
#line 221 "GomSerializationTest.vala"
	return result;
#line 16829 "GomSerializationTest.c"
}

void
gom_serialization_test_book_set_name (GomSerializationTestBook* self,
                                      const gchar* value)
{
#line 221 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 221 "GomSerializationTest.vala"
	if (g_strcmp0 (value, gom_serialization_test_book_get_name (self)) != 0) {
#line 16840 "GomSerializationTest.c"
		gchar* _tmp0_;
#line 221 "GomSerializationTest.vala"
		_tmp0_ = g_strdup (value);
#line 221 "GomSerializationTest.vala"
		_g_free0 (self->priv->_name);
#line 221 "GomSerializationTest.vala"
		self->priv->_name = _tmp0_;
#line 221 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_book_properties[GOM_SERIALIZATION_TEST_BOOK_NAME_PROPERTY]);
#line 16850 "GomSerializationTest.c"
	}
}

static GObject *
gom_serialization_test_book_constructor (GType type,
                                         guint n_construct_properties,
                                         GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestBook * self;
	GError* _inner_error0_ = NULL;
#line 222 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_book_parent_class);
#line 222 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 222 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_BOOK, GomSerializationTestBook);
#line 16869 "GomSerializationTest.c"
	{
#line 222 "GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Book");
#line 16873 "GomSerializationTest.c"
	}
	goto __finally196;
	__catch196_g_error:
	{
#line 222 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 222 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 222 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 16884 "GomSerializationTest.c"
	}
	__finally196:
#line 222 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 222 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 222 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 16893 "GomSerializationTest.c"
	}
#line 222 "GomSerializationTest.vala"
	return obj;
#line 16897 "GomSerializationTest.c"
}

static void
gom_serialization_test_book_class_init (GomSerializationTestBookClass * klass,
                                        gpointer klass_data)
{
#line 219 "GomSerializationTest.vala"
	gom_serialization_test_book_parent_class = g_type_class_peek_parent (klass);
#line 219 "GomSerializationTest.vala"
	g_type_class_adjust_private_offset (klass, &GomSerializationTestBook_private_offset);
#line 219 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_serialization_test_book_get_property;
#line 219 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_serialization_test_book_set_property;
#line 219 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_book_constructor;
#line 219 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_serialization_test_book_finalize;
#line 219 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_NAME_PROPERTY, gom_serialization_test_book_properties[GOM_SERIALIZATION_TEST_BOOK_NAME_PROPERTY] = g_param_spec_string ("name", "::Name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 16918 "GomSerializationTest.c"
}

static void
gom_serialization_test_book_instance_init (GomSerializationTestBook * self,
                                           gpointer klass)
{
#line 219 "GomSerializationTest.vala"
	self->priv = gom_serialization_test_book_get_instance_private (self);
#line 16927 "GomSerializationTest.c"
}

static void
gom_serialization_test_book_finalize (GObject * obj)
{
	GomSerializationTestBook * self;
#line 219 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_BOOK, GomSerializationTestBook);
#line 221 "GomSerializationTest.vala"
	_g_free0 (self->priv->_name);
#line 219 "GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_serialization_test_book_parent_class)->finalize (obj);
#line 16940 "GomSerializationTest.c"
}

GType
gom_serialization_test_book_get_type (void)
{
	static volatile gsize gom_serialization_test_book_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_book_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestBookClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_book_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestBook), 0, (GInstanceInitFunc) gom_serialization_test_book_instance_init, NULL };
		GType gom_serialization_test_book_type_id;
		gom_serialization_test_book_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomSerializationTestBook", &g_define_type_info, 0);
		GomSerializationTestBook_private_offset = g_type_add_instance_private (gom_serialization_test_book_type_id, sizeof (GomSerializationTestBookPrivate));
		g_once_init_leave (&gom_serialization_test_book_type_id__volatile, gom_serialization_test_book_type_id);
	}
	return gom_serialization_test_book_type_id__volatile;
}

static void
_vala_gom_serialization_test_book_get_property (GObject * object,
                                                guint property_id,
                                                GValue * value,
                                                GParamSpec * pspec)
{
	GomSerializationTestBook * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_BOOK, GomSerializationTestBook);
#line 219 "GomSerializationTest.vala"
	switch (property_id) {
#line 219 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_NAME_PROPERTY:
#line 219 "GomSerializationTest.vala"
		g_value_set_string (value, gom_serialization_test_book_get_name (self));
#line 219 "GomSerializationTest.vala"
		break;
#line 16973 "GomSerializationTest.c"
		default:
#line 219 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 219 "GomSerializationTest.vala"
		break;
#line 16979 "GomSerializationTest.c"
	}
}

static void
_vala_gom_serialization_test_book_set_property (GObject * object,
                                                guint property_id,
                                                const GValue * value,
                                                GParamSpec * pspec)
{
	GomSerializationTestBook * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_BOOK, GomSerializationTestBook);
#line 219 "GomSerializationTest.vala"
	switch (property_id) {
#line 219 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_NAME_PROPERTY:
#line 219 "GomSerializationTest.vala"
		gom_serialization_test_book_set_name (self, g_value_get_string (value));
#line 219 "GomSerializationTest.vala"
		break;
#line 16999 "GomSerializationTest.c"
		default:
#line 219 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 219 "GomSerializationTest.vala"
		break;
#line 17005 "GomSerializationTest.c"
	}
}

static inline gpointer
gom_serialization_test_computer_get_instance_private (GomSerializationTestComputer* self)
{
	return G_STRUCT_MEMBER_P (self, GomSerializationTestComputer_private_offset);
}

gchar*
gom_serialization_test_computer_to_string (GomSerializationTestComputer* self)
{
	gchar* result = NULL;
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_;
	gchar* s = NULL;
	gchar* _tmp1_;
	GError* _inner_error0_ = NULL;
#line 243 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 244 "GomSerializationTest.vala"
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
#line 244 "GomSerializationTest.vala"
	parser = _tmp0_;
#line 245 "GomSerializationTest.vala"
	_tmp1_ = g_strdup ("");
#line 245 "GomSerializationTest.vala"
	s = _tmp1_;
#line 17034 "GomSerializationTest.c"
	{
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_;
		gchar* _tmp4_;
#line 247 "GomSerializationTest.vala"
		_tmp3_ = gxml_parser_write_string ((GXmlParser*) parser, &_inner_error0_);
#line 247 "GomSerializationTest.vala"
		_tmp2_ = _tmp3_;
#line 247 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 17045 "GomSerializationTest.c"
			goto __catch197_g_error;
		}
#line 247 "GomSerializationTest.vala"
		_tmp4_ = _tmp2_;
#line 247 "GomSerializationTest.vala"
		_tmp2_ = NULL;
#line 247 "GomSerializationTest.vala"
		_g_free0 (s);
#line 247 "GomSerializationTest.vala"
		s = _tmp4_;
#line 246 "GomSerializationTest.vala"
		_g_free0 (_tmp2_);
#line 17058 "GomSerializationTest.c"
	}
	goto __finally197;
	__catch197_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
#line 246 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 246 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 249 "GomSerializationTest.vala"
		_tmp5_ = e->message;
#line 249 "GomSerializationTest.vala"
		_tmp6_ = g_strconcat ("Error: ", _tmp5_, NULL);
#line 249 "GomSerializationTest.vala"
		_tmp7_ = _tmp6_;
#line 249 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:249: %s", _tmp7_);
#line 249 "GomSerializationTest.vala"
		_g_free0 (_tmp7_);
#line 250 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 246 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 17085 "GomSerializationTest.c"
	}
	__finally197:
#line 246 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 246 "GomSerializationTest.vala"
		_g_free0 (s);
#line 246 "GomSerializationTest.vala"
		_g_object_unref0 (parser);
#line 246 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 246 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 246 "GomSerializationTest.vala"
		return NULL;
#line 17100 "GomSerializationTest.c"
	}
#line 252 "GomSerializationTest.vala"
	result = s;
#line 252 "GomSerializationTest.vala"
	_g_object_unref0 (parser);
#line 252 "GomSerializationTest.vala"
	return result;
#line 17108 "GomSerializationTest.c"
}

GomSerializationTestComputer*
gom_serialization_test_computer_construct (GType object_type)
{
	GomSerializationTestComputer * self = NULL;
#line 238 "GomSerializationTest.vala"
	self = (GomSerializationTestComputer*) gxml_gom_element_construct (object_type);
#line 238 "GomSerializationTest.vala"
	return self;
#line 17119 "GomSerializationTest.c"
}

GomSerializationTestComputer*
gom_serialization_test_computer_new (void)
{
#line 238 "GomSerializationTest.vala"
	return gom_serialization_test_computer_construct (GOM_SERIALIZATION_TEST_TYPE_COMPUTER);
#line 17127 "GomSerializationTest.c"
}

const gchar*
gom_serialization_test_computer_get_model (GomSerializationTestComputer* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 240 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 240 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_model;
#line 240 "GomSerializationTest.vala"
	result = _tmp0_;
#line 240 "GomSerializationTest.vala"
	return result;
#line 17143 "GomSerializationTest.c"
}

void
gom_serialization_test_computer_set_model (GomSerializationTestComputer* self,
                                           const gchar* value)
{
#line 240 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 240 "GomSerializationTest.vala"
	if (g_strcmp0 (value, gom_serialization_test_computer_get_model (self)) != 0) {
#line 17154 "GomSerializationTest.c"
		gchar* _tmp0_;
#line 240 "GomSerializationTest.vala"
		_tmp0_ = g_strdup (value);
#line 240 "GomSerializationTest.vala"
		_g_free0 (self->priv->_model);
#line 240 "GomSerializationTest.vala"
		self->priv->_model = _tmp0_;
#line 240 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_computer_properties[GOM_SERIALIZATION_TEST_COMPUTER_MODEL_PROPERTY]);
#line 17164 "GomSerializationTest.c"
	}
}

const gchar*
gom_serialization_test_computer_get_ignore (GomSerializationTestComputer* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 241 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 241 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_ignore;
#line 241 "GomSerializationTest.vala"
	result = _tmp0_;
#line 241 "GomSerializationTest.vala"
	return result;
#line 17181 "GomSerializationTest.c"
}

void
gom_serialization_test_computer_set_ignore (GomSerializationTestComputer* self,
                                            const gchar* value)
{
#line 241 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 241 "GomSerializationTest.vala"
	if (g_strcmp0 (value, gom_serialization_test_computer_get_ignore (self)) != 0) {
#line 17192 "GomSerializationTest.c"
		gchar* _tmp0_;
#line 241 "GomSerializationTest.vala"
		_tmp0_ = g_strdup (value);
#line 241 "GomSerializationTest.vala"
		_g_free0 (self->priv->_ignore);
#line 241 "GomSerializationTest.vala"
		self->priv->_ignore = _tmp0_;
#line 241 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_computer_properties[GOM_SERIALIZATION_TEST_COMPUTER_IGNORE_PROPERTY]);
#line 17202 "GomSerializationTest.c"
	}
}

static GObject *
gom_serialization_test_computer_constructor (GType type,
                                             guint n_construct_properties,
                                             GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestComputer * self;
	GError* _inner_error0_ = NULL;
#line 242 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_computer_parent_class);
#line 242 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 242 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_COMPUTER, GomSerializationTestComputer);
#line 17221 "GomSerializationTest.c"
	{
#line 242 "GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Computer");
#line 17225 "GomSerializationTest.c"
	}
	goto __finally198;
	__catch198_g_error:
	{
#line 242 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 242 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 242 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 17236 "GomSerializationTest.c"
	}
	__finally198:
#line 242 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 242 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 242 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 17245 "GomSerializationTest.c"
	}
#line 242 "GomSerializationTest.vala"
	return obj;
#line 17249 "GomSerializationTest.c"
}

static void
gom_serialization_test_computer_class_init (GomSerializationTestComputerClass * klass,
                                            gpointer klass_data)
{
#line 238 "GomSerializationTest.vala"
	gom_serialization_test_computer_parent_class = g_type_class_peek_parent (klass);
#line 238 "GomSerializationTest.vala"
	g_type_class_adjust_private_offset (klass, &GomSerializationTestComputer_private_offset);
#line 238 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_serialization_test_computer_get_property;
#line 238 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_serialization_test_computer_set_property;
#line 238 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_computer_constructor;
#line 238 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_serialization_test_computer_finalize;
#line 238 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_COMPUTER_MODEL_PROPERTY, gom_serialization_test_computer_properties[GOM_SERIALIZATION_TEST_COMPUTER_MODEL_PROPERTY] = g_param_spec_string ("model", "::Model", "model", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 238 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_COMPUTER_IGNORE_PROPERTY, gom_serialization_test_computer_properties[GOM_SERIALIZATION_TEST_COMPUTER_IGNORE_PROPERTY] = g_param_spec_string ("ignore", "ignore", "ignore", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 17272 "GomSerializationTest.c"
}

static void
gom_serialization_test_computer_instance_init (GomSerializationTestComputer * self,
                                               gpointer klass)
{
#line 238 "GomSerializationTest.vala"
	self->priv = gom_serialization_test_computer_get_instance_private (self);
#line 17281 "GomSerializationTest.c"
}

static void
gom_serialization_test_computer_finalize (GObject * obj)
{
	GomSerializationTestComputer * self;
#line 238 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_COMPUTER, GomSerializationTestComputer);
#line 240 "GomSerializationTest.vala"
	_g_free0 (self->priv->_model);
#line 241 "GomSerializationTest.vala"
	_g_free0 (self->priv->_ignore);
#line 238 "GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_serialization_test_computer_parent_class)->finalize (obj);
#line 17296 "GomSerializationTest.c"
}

GType
gom_serialization_test_computer_get_type (void)
{
	static volatile gsize gom_serialization_test_computer_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_computer_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestComputerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_computer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestComputer), 0, (GInstanceInitFunc) gom_serialization_test_computer_instance_init, NULL };
		GType gom_serialization_test_computer_type_id;
		gom_serialization_test_computer_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomSerializationTestComputer", &g_define_type_info, 0);
		GomSerializationTestComputer_private_offset = g_type_add_instance_private (gom_serialization_test_computer_type_id, sizeof (GomSerializationTestComputerPrivate));
		g_once_init_leave (&gom_serialization_test_computer_type_id__volatile, gom_serialization_test_computer_type_id);
	}
	return gom_serialization_test_computer_type_id__volatile;
}

static void
_vala_gom_serialization_test_computer_get_property (GObject * object,
                                                    guint property_id,
                                                    GValue * value,
                                                    GParamSpec * pspec)
{
	GomSerializationTestComputer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_COMPUTER, GomSerializationTestComputer);
#line 238 "GomSerializationTest.vala"
	switch (property_id) {
#line 238 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_COMPUTER_MODEL_PROPERTY:
#line 238 "GomSerializationTest.vala"
		g_value_set_string (value, gom_serialization_test_computer_get_model (self));
#line 238 "GomSerializationTest.vala"
		break;
#line 238 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_COMPUTER_IGNORE_PROPERTY:
#line 238 "GomSerializationTest.vala"
		g_value_set_string (value, gom_serialization_test_computer_get_ignore (self));
#line 238 "GomSerializationTest.vala"
		break;
#line 17335 "GomSerializationTest.c"
		default:
#line 238 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 238 "GomSerializationTest.vala"
		break;
#line 17341 "GomSerializationTest.c"
	}
}

static void
_vala_gom_serialization_test_computer_set_property (GObject * object,
                                                    guint property_id,
                                                    const GValue * value,
                                                    GParamSpec * pspec)
{
	GomSerializationTestComputer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_COMPUTER, GomSerializationTestComputer);
#line 238 "GomSerializationTest.vala"
	switch (property_id) {
#line 238 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_COMPUTER_MODEL_PROPERTY:
#line 238 "GomSerializationTest.vala"
		gom_serialization_test_computer_set_model (self, g_value_get_string (value));
#line 238 "GomSerializationTest.vala"
		break;
#line 238 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_COMPUTER_IGNORE_PROPERTY:
#line 238 "GomSerializationTest.vala"
		gom_serialization_test_computer_set_ignore (self, g_value_get_string (value));
#line 238 "GomSerializationTest.vala"
		break;
#line 17367 "GomSerializationTest.c"
		default:
#line 238 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 238 "GomSerializationTest.vala"
		break;
#line 17373 "GomSerializationTest.c"
	}
}

static inline gpointer
gom_serialization_test_taxes_get_instance_private (GomSerializationTestTaxes* self)
{
	return G_STRUCT_MEMBER_P (self, GomSerializationTestTaxes_private_offset);
}

GType
gom_serialization_test_taxes_month_get_type (void)
{
	static volatile gsize gom_serialization_test_taxes_month_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_taxes_month_type_id__volatile)) {
		static const GEnumValue values[] = {{GOM_SERIALIZATION_TEST_TAXES_MONTH_JANUARY, "GOM_SERIALIZATION_TEST_TAXES_MONTH_JANUARY", "january"}, {GOM_SERIALIZATION_TEST_TAXES_MONTH_FEBRUARY, "GOM_SERIALIZATION_TEST_TAXES_MONTH_FEBRUARY", "february"}, {0, NULL, NULL}};
		GType gom_serialization_test_taxes_month_type_id;
		gom_serialization_test_taxes_month_type_id = g_enum_register_static ("GomSerializationTestTaxesMonth", values);
		g_once_init_leave (&gom_serialization_test_taxes_month_type_id__volatile, gom_serialization_test_taxes_month_type_id);
	}
	return gom_serialization_test_taxes_month_type_id__volatile;
}

gchar*
gom_serialization_test_taxes_to_string (GomSerializationTestTaxes* self)
{
	gchar* result = NULL;
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_;
	gchar* s = NULL;
	gchar* _tmp1_;
	GError* _inner_error0_ = NULL;
#line 267 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 268 "GomSerializationTest.vala"
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
#line 268 "GomSerializationTest.vala"
	parser = _tmp0_;
#line 269 "GomSerializationTest.vala"
	_tmp1_ = g_strdup ("");
#line 269 "GomSerializationTest.vala"
	s = _tmp1_;
#line 17415 "GomSerializationTest.c"
	{
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_;
		gchar* _tmp4_;
#line 271 "GomSerializationTest.vala"
		_tmp3_ = gxml_parser_write_string ((GXmlParser*) parser, &_inner_error0_);
#line 271 "GomSerializationTest.vala"
		_tmp2_ = _tmp3_;
#line 271 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 17426 "GomSerializationTest.c"
			goto __catch199_g_error;
		}
#line 271 "GomSerializationTest.vala"
		_tmp4_ = _tmp2_;
#line 271 "GomSerializationTest.vala"
		_tmp2_ = NULL;
#line 271 "GomSerializationTest.vala"
		_g_free0 (s);
#line 271 "GomSerializationTest.vala"
		s = _tmp4_;
#line 270 "GomSerializationTest.vala"
		_g_free0 (_tmp2_);
#line 17439 "GomSerializationTest.c"
	}
	goto __finally199;
	__catch199_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
#line 270 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 270 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 273 "GomSerializationTest.vala"
		_tmp5_ = e->message;
#line 273 "GomSerializationTest.vala"
		_tmp6_ = g_strconcat ("Error: ", _tmp5_, NULL);
#line 273 "GomSerializationTest.vala"
		_tmp7_ = _tmp6_;
#line 273 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:273: %s", _tmp7_);
#line 273 "GomSerializationTest.vala"
		_g_free0 (_tmp7_);
#line 274 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 270 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 17466 "GomSerializationTest.c"
	}
	__finally199:
#line 270 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 270 "GomSerializationTest.vala"
		_g_free0 (s);
#line 270 "GomSerializationTest.vala"
		_g_object_unref0 (parser);
#line 270 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 270 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 270 "GomSerializationTest.vala"
		return NULL;
#line 17481 "GomSerializationTest.c"
	}
#line 276 "GomSerializationTest.vala"
	result = s;
#line 276 "GomSerializationTest.vala"
	_g_object_unref0 (parser);
#line 276 "GomSerializationTest.vala"
	return result;
#line 17489 "GomSerializationTest.c"
}

GomSerializationTestTaxes*
gom_serialization_test_taxes_construct (GType object_type)
{
	GomSerializationTestTaxes * self = NULL;
#line 255 "GomSerializationTest.vala"
	self = (GomSerializationTestTaxes*) gxml_gom_element_construct (object_type);
#line 255 "GomSerializationTest.vala"
	return self;
#line 17500 "GomSerializationTest.c"
}

GomSerializationTestTaxes*
gom_serialization_test_taxes_new (void)
{
#line 255 "GomSerializationTest.vala"
	return gom_serialization_test_taxes_construct (GOM_SERIALIZATION_TEST_TYPE_TAXES);
#line 17508 "GomSerializationTest.c"
}

gdouble
gom_serialization_test_taxes_get_month_rate (GomSerializationTestTaxes* self)
{
	gdouble result;
#line 257 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, 0.0);
#line 257 "GomSerializationTest.vala"
	result = self->priv->_month_rate;
#line 257 "GomSerializationTest.vala"
	return result;
#line 17521 "GomSerializationTest.c"
}

void
gom_serialization_test_taxes_set_month_rate (GomSerializationTestTaxes* self,
                                             gdouble value)
{
#line 257 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 257 "GomSerializationTest.vala"
	if (gom_serialization_test_taxes_get_month_rate (self) != value) {
#line 257 "GomSerializationTest.vala"
		self->priv->_month_rate = value;
#line 257 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_taxes_properties[GOM_SERIALIZATION_TEST_TAXES_MONTH_RATE_PROPERTY]);
#line 17536 "GomSerializationTest.c"
	}
}

gboolean
gom_serialization_test_taxes_get_tax_free (GomSerializationTestTaxes* self)
{
	gboolean result;
#line 259 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 259 "GomSerializationTest.vala"
	result = self->priv->_tax_free;
#line 259 "GomSerializationTest.vala"
	return result;
#line 17550 "GomSerializationTest.c"
}

void
gom_serialization_test_taxes_set_tax_free (GomSerializationTestTaxes* self,
                                           gboolean value)
{
#line 259 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 259 "GomSerializationTest.vala"
	if (gom_serialization_test_taxes_get_tax_free (self) != value) {
#line 259 "GomSerializationTest.vala"
		self->priv->_tax_free = value;
#line 259 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_taxes_properties[GOM_SERIALIZATION_TEST_TAXES_TAX_FREE_PROPERTY]);
#line 17565 "GomSerializationTest.c"
	}
}

GomSerializationTestTaxesMonth
gom_serialization_test_taxes_get_month (GomSerializationTestTaxes* self)
{
	GomSerializationTestTaxesMonth result;
	GomSerializationTestTaxesMonth _tmp0_;
#line 261 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 261 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_month;
#line 261 "GomSerializationTest.vala"
	result = _tmp0_;
#line 261 "GomSerializationTest.vala"
	return result;
#line 17582 "GomSerializationTest.c"
}

void
gom_serialization_test_taxes_set_month (GomSerializationTestTaxes* self,
                                        GomSerializationTestTaxesMonth value)
{
#line 261 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 261 "GomSerializationTest.vala"
	if (gom_serialization_test_taxes_get_month (self) != value) {
#line 261 "GomSerializationTest.vala"
		self->priv->_month = value;
#line 261 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_taxes_properties[GOM_SERIALIZATION_TEST_TAXES_MONTH_PROPERTY]);
#line 17597 "GomSerializationTest.c"
	}
}

GXmlGomDate*
gom_serialization_test_taxes_get_pay_date (GomSerializationTestTaxes* self)
{
	GXmlGomDate* result;
	GXmlGomDate* _tmp0_;
#line 263 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 263 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_pay_date;
#line 263 "GomSerializationTest.vala"
	result = _tmp0_;
#line 263 "GomSerializationTest.vala"
	return result;
#line 17614 "GomSerializationTest.c"
}

void
gom_serialization_test_taxes_set_pay_date (GomSerializationTestTaxes* self,
                                           GXmlGomDate* value)
{
#line 263 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 263 "GomSerializationTest.vala"
	if (gom_serialization_test_taxes_get_pay_date (self) != value) {
#line 17625 "GomSerializationTest.c"
		GXmlGomDate* _tmp0_;
#line 263 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 263 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_pay_date);
#line 263 "GomSerializationTest.vala"
		self->priv->_pay_date = _tmp0_;
#line 263 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_taxes_properties[GOM_SERIALIZATION_TEST_TAXES_PAY_DATE_PROPERTY]);
#line 17635 "GomSerializationTest.c"
	}
}

GXmlGomDateTime*
gom_serialization_test_taxes_get_timestamp (GomSerializationTestTaxes* self)
{
	GXmlGomDateTime* result;
	GXmlGomDateTime* _tmp0_;
#line 265 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 265 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_timestamp;
#line 265 "GomSerializationTest.vala"
	result = _tmp0_;
#line 265 "GomSerializationTest.vala"
	return result;
#line 17652 "GomSerializationTest.c"
}

void
gom_serialization_test_taxes_set_timestamp (GomSerializationTestTaxes* self,
                                            GXmlGomDateTime* value)
{
#line 265 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 265 "GomSerializationTest.vala"
	if (gom_serialization_test_taxes_get_timestamp (self) != value) {
#line 17663 "GomSerializationTest.c"
		GXmlGomDateTime* _tmp0_;
#line 265 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 265 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_timestamp);
#line 265 "GomSerializationTest.vala"
		self->priv->_timestamp = _tmp0_;
#line 265 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_taxes_properties[GOM_SERIALIZATION_TEST_TAXES_TIMESTAMP_PROPERTY]);
#line 17673 "GomSerializationTest.c"
	}
}

static GObject *
gom_serialization_test_taxes_constructor (GType type,
                                          guint n_construct_properties,
                                          GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestTaxes * self;
	GError* _inner_error0_ = NULL;
#line 266 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_taxes_parent_class);
#line 266 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 266 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_TAXES, GomSerializationTestTaxes);
#line 17692 "GomSerializationTest.c"
	{
#line 266 "GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Taxes");
#line 17696 "GomSerializationTest.c"
	}
	goto __finally200;
	__catch200_g_error:
	{
#line 266 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 266 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 266 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 17707 "GomSerializationTest.c"
	}
	__finally200:
#line 266 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 266 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 266 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 17716 "GomSerializationTest.c"
	}
#line 266 "GomSerializationTest.vala"
	return obj;
#line 17720 "GomSerializationTest.c"
}

static void
gom_serialization_test_taxes_class_init (GomSerializationTestTaxesClass * klass,
                                         gpointer klass_data)
{
#line 255 "GomSerializationTest.vala"
	gom_serialization_test_taxes_parent_class = g_type_class_peek_parent (klass);
#line 255 "GomSerializationTest.vala"
	g_type_class_adjust_private_offset (klass, &GomSerializationTestTaxes_private_offset);
#line 255 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_serialization_test_taxes_get_property;
#line 255 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_serialization_test_taxes_set_property;
#line 255 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_taxes_constructor;
#line 255 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_serialization_test_taxes_finalize;
#line 255 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_TAXES_MONTH_RATE_PROPERTY, gom_serialization_test_taxes_properties[GOM_SERIALIZATION_TEST_TAXES_MONTH_RATE_PROPERTY] = g_param_spec_double ("month-rate", "::monthRate", "month-rate", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 255 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_TAXES_TAX_FREE_PROPERTY, gom_serialization_test_taxes_properties[GOM_SERIALIZATION_TEST_TAXES_TAX_FREE_PROPERTY] = g_param_spec_boolean ("tax-free", "::TaxFree", "tax-free", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 255 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_TAXES_MONTH_PROPERTY, gom_serialization_test_taxes_properties[GOM_SERIALIZATION_TEST_TAXES_MONTH_PROPERTY] = g_param_spec_enum ("month", "::Month", "month", GOM_SERIALIZATION_TEST_TAXES_TYPE_MONTH, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 255 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_TAXES_PAY_DATE_PROPERTY, gom_serialization_test_taxes_properties[GOM_SERIALIZATION_TEST_TAXES_PAY_DATE_PROPERTY] = g_param_spec_object ("pay-date", "::PayDate", "pay-date", GXML_TYPE_GOM_DATE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 255 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_TAXES_TIMESTAMP_PROPERTY, gom_serialization_test_taxes_properties[GOM_SERIALIZATION_TEST_TAXES_TIMESTAMP_PROPERTY] = g_param_spec_object ("timestamp", "::Timestamp", "timestamp", GXML_TYPE_GOM_DATE_TIME, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 17749 "GomSerializationTest.c"
}

static void
gom_serialization_test_taxes_instance_init (GomSerializationTestTaxes * self,
                                            gpointer klass)
{
#line 255 "GomSerializationTest.vala"
	self->priv = gom_serialization_test_taxes_get_instance_private (self);
#line 17758 "GomSerializationTest.c"
}

static void
gom_serialization_test_taxes_finalize (GObject * obj)
{
	GomSerializationTestTaxes * self;
#line 255 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_TAXES, GomSerializationTestTaxes);
#line 263 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_pay_date);
#line 265 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_timestamp);
#line 255 "GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_serialization_test_taxes_parent_class)->finalize (obj);
#line 17773 "GomSerializationTest.c"
}

GType
gom_serialization_test_taxes_get_type (void)
{
	static volatile gsize gom_serialization_test_taxes_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_taxes_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestTaxesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_taxes_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestTaxes), 0, (GInstanceInitFunc) gom_serialization_test_taxes_instance_init, NULL };
		GType gom_serialization_test_taxes_type_id;
		gom_serialization_test_taxes_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomSerializationTestTaxes", &g_define_type_info, 0);
		GomSerializationTestTaxes_private_offset = g_type_add_instance_private (gom_serialization_test_taxes_type_id, sizeof (GomSerializationTestTaxesPrivate));
		g_once_init_leave (&gom_serialization_test_taxes_type_id__volatile, gom_serialization_test_taxes_type_id);
	}
	return gom_serialization_test_taxes_type_id__volatile;
}

static void
_vala_gom_serialization_test_taxes_get_property (GObject * object,
                                                 guint property_id,
                                                 GValue * value,
                                                 GParamSpec * pspec)
{
	GomSerializationTestTaxes * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_TAXES, GomSerializationTestTaxes);
#line 255 "GomSerializationTest.vala"
	switch (property_id) {
#line 255 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_TAXES_MONTH_RATE_PROPERTY:
#line 255 "GomSerializationTest.vala"
		g_value_set_double (value, gom_serialization_test_taxes_get_month_rate (self));
#line 255 "GomSerializationTest.vala"
		break;
#line 255 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_TAXES_TAX_FREE_PROPERTY:
#line 255 "GomSerializationTest.vala"
		g_value_set_boolean (value, gom_serialization_test_taxes_get_tax_free (self));
#line 255 "GomSerializationTest.vala"
		break;
#line 255 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_TAXES_MONTH_PROPERTY:
#line 255 "GomSerializationTest.vala"
		g_value_set_enum (value, gom_serialization_test_taxes_get_month (self));
#line 255 "GomSerializationTest.vala"
		break;
#line 255 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_TAXES_PAY_DATE_PROPERTY:
#line 255 "GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_taxes_get_pay_date (self));
#line 255 "GomSerializationTest.vala"
		break;
#line 255 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_TAXES_TIMESTAMP_PROPERTY:
#line 255 "GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_taxes_get_timestamp (self));
#line 255 "GomSerializationTest.vala"
		break;
#line 17830 "GomSerializationTest.c"
		default:
#line 255 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 255 "GomSerializationTest.vala"
		break;
#line 17836 "GomSerializationTest.c"
	}
}

static void
_vala_gom_serialization_test_taxes_set_property (GObject * object,
                                                 guint property_id,
                                                 const GValue * value,
                                                 GParamSpec * pspec)
{
	GomSerializationTestTaxes * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_TAXES, GomSerializationTestTaxes);
#line 255 "GomSerializationTest.vala"
	switch (property_id) {
#line 255 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_TAXES_MONTH_RATE_PROPERTY:
#line 255 "GomSerializationTest.vala"
		gom_serialization_test_taxes_set_month_rate (self, g_value_get_double (value));
#line 255 "GomSerializationTest.vala"
		break;
#line 255 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_TAXES_TAX_FREE_PROPERTY:
#line 255 "GomSerializationTest.vala"
		gom_serialization_test_taxes_set_tax_free (self, g_value_get_boolean (value));
#line 255 "GomSerializationTest.vala"
		break;
#line 255 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_TAXES_MONTH_PROPERTY:
#line 255 "GomSerializationTest.vala"
		gom_serialization_test_taxes_set_month (self, g_value_get_enum (value));
#line 255 "GomSerializationTest.vala"
		break;
#line 255 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_TAXES_PAY_DATE_PROPERTY:
#line 255 "GomSerializationTest.vala"
		gom_serialization_test_taxes_set_pay_date (self, g_value_get_object (value));
#line 255 "GomSerializationTest.vala"
		break;
#line 255 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_TAXES_TIMESTAMP_PROPERTY:
#line 255 "GomSerializationTest.vala"
		gom_serialization_test_taxes_set_timestamp (self, g_value_get_object (value));
#line 255 "GomSerializationTest.vala"
		break;
#line 17880 "GomSerializationTest.c"
		default:
#line 255 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 255 "GomSerializationTest.vala"
		break;
#line 17886 "GomSerializationTest.c"
	}
}

static inline gpointer
gom_serialization_test_book_register_get_instance_private (GomSerializationTestBookRegister* self)
{
	return G_STRUCT_MEMBER_P (self, GomSerializationTestBookRegister_private_offset);
}

GomSerializationTestBookRegister*
gom_serialization_test_book_register_construct_document (GType object_type,
                                                         GXmlDomDocument* doc)
{
	GomSerializationTestBookRegister * self = NULL;
	GXmlDomDocument* _tmp0_;
#line 309 "GomSerializationTest.vala"
	g_return_val_if_fail (doc != NULL, NULL);
#line 309 "GomSerializationTest.vala"
	self = (GomSerializationTestBookRegister*) gxml_gom_element_construct (object_type);
#line 310 "GomSerializationTest.vala"
	_tmp0_ = _g_object_ref0 (doc);
#line 310 "GomSerializationTest.vala"
	_g_object_unref0 (((GXmlGomNode*) self)->_document);
#line 310 "GomSerializationTest.vala"
	((GXmlGomNode*) self)->_document = _tmp0_;
#line 309 "GomSerializationTest.vala"
	return self;
#line 17914 "GomSerializationTest.c"
}

GomSerializationTestBookRegister*
gom_serialization_test_book_register_new_document (GXmlDomDocument* doc)
{
#line 309 "GomSerializationTest.vala"
	return gom_serialization_test_book_register_construct_document (GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, doc);
#line 17922 "GomSerializationTest.c"
}

static gchar*
gom_serialization_test_book_register_real_get_map_key (GXmlMappeableElement* base)
{
	GomSerializationTestBookRegister * self;
	gchar* result = NULL;
	GomSerializationTestBook* _tmp0_;
	GomSerializationTestBook* _tmp1_;
	gint _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	GomSerializationTestBook* _tmp8_;
	GomSerializationTestBook* _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
#line 312 "GomSerializationTest.vala"
	self = (GomSerializationTestBookRegister*) base;
#line 313 "GomSerializationTest.vala"
	_tmp0_ = gom_serialization_test_book_register_get_book (self);
#line 313 "GomSerializationTest.vala"
	_tmp1_ = _tmp0_;
#line 313 "GomSerializationTest.vala"
	if (_tmp1_ == NULL) {
#line 17951 "GomSerializationTest.c"
		gchar* _tmp2_;
#line 313 "GomSerializationTest.vala"
		_tmp2_ = g_strdup ("");
#line 313 "GomSerializationTest.vala"
		result = _tmp2_;
#line 313 "GomSerializationTest.vala"
		return result;
#line 17959 "GomSerializationTest.c"
	}
#line 314 "GomSerializationTest.vala"
	_tmp3_ = self->priv->_year;
#line 314 "GomSerializationTest.vala"
	_tmp4_ = g_strdup_printf ("%d", _tmp3_);
#line 314 "GomSerializationTest.vala"
	_tmp5_ = _tmp4_;
#line 314 "GomSerializationTest.vala"
	_tmp6_ = g_strconcat (_tmp5_, "-", NULL);
#line 314 "GomSerializationTest.vala"
	_tmp7_ = _tmp6_;
#line 314 "GomSerializationTest.vala"
	_tmp8_ = gom_serialization_test_book_register_get_book (self);
#line 314 "GomSerializationTest.vala"
	_tmp9_ = _tmp8_;
#line 314 "GomSerializationTest.vala"
	_tmp10_ = gom_serialization_test_book_get_name (_tmp9_);
#line 314 "GomSerializationTest.vala"
	_tmp11_ = _tmp10_;
#line 314 "GomSerializationTest.vala"
	_tmp12_ = g_strconcat (_tmp7_, _tmp11_, NULL);
#line 314 "GomSerializationTest.vala"
	_tmp13_ = _tmp12_;
#line 314 "GomSerializationTest.vala"
	_g_free0 (_tmp7_);
#line 314 "GomSerializationTest.vala"
	_g_free0 (_tmp5_);
#line 314 "GomSerializationTest.vala"
	result = _tmp13_;
#line 314 "GomSerializationTest.vala"
	return result;
#line 17991 "GomSerializationTest.c"
}

static gchar*
gom_serialization_test_book_register_real_get_map_primary_key (GXmlMappeableElementPairKey* base)
{
	GomSerializationTestBookRegister * self;
	gchar* result = NULL;
	gint _tmp0_;
	gchar* _tmp1_;
#line 316 "GomSerializationTest.vala"
	self = (GomSerializationTestBookRegister*) base;
#line 316 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_year;
#line 316 "GomSerializationTest.vala"
	_tmp1_ = g_strdup_printf ("%d", _tmp0_);
#line 316 "GomSerializationTest.vala"
	result = _tmp1_;
#line 316 "GomSerializationTest.vala"
	return result;
#line 18011 "GomSerializationTest.c"
}

static gchar*
gom_serialization_test_book_register_real_get_map_secondary_key (GXmlMappeableElementPairKey* base)
{
	GomSerializationTestBookRegister * self;
	gchar* result = NULL;
	GomSerializationTestBook* _tmp0_;
	GomSerializationTestBook* _tmp1_;
	GomSerializationTestBook* _tmp3_;
	GomSerializationTestBook* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	gchar* _tmp7_;
#line 317 "GomSerializationTest.vala"
	self = (GomSerializationTestBookRegister*) base;
#line 318 "GomSerializationTest.vala"
	_tmp0_ = gom_serialization_test_book_register_get_book (self);
#line 318 "GomSerializationTest.vala"
	_tmp1_ = _tmp0_;
#line 318 "GomSerializationTest.vala"
	if (_tmp1_ == NULL) {
#line 18034 "GomSerializationTest.c"
		gchar* _tmp2_;
#line 318 "GomSerializationTest.vala"
		_tmp2_ = g_strdup ("");
#line 318 "GomSerializationTest.vala"
		result = _tmp2_;
#line 318 "GomSerializationTest.vala"
		return result;
#line 18042 "GomSerializationTest.c"
	}
#line 319 "GomSerializationTest.vala"
	_tmp3_ = gom_serialization_test_book_register_get_book (self);
#line 319 "GomSerializationTest.vala"
	_tmp4_ = _tmp3_;
#line 319 "GomSerializationTest.vala"
	_tmp5_ = gom_serialization_test_book_get_name (_tmp4_);
#line 319 "GomSerializationTest.vala"
	_tmp6_ = _tmp5_;
#line 319 "GomSerializationTest.vala"
	_tmp7_ = g_strdup (_tmp6_);
#line 319 "GomSerializationTest.vala"
	result = _tmp7_;
#line 319 "GomSerializationTest.vala"
	return result;
#line 18058 "GomSerializationTest.c"
}

static gchar*
gom_serialization_test_book_register_real_get_map_pkey (GXmlMappeableElementThreeKey* base)
{
	GomSerializationTestBookRegister * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 321 "GomSerializationTest.vala"
	self = (GomSerializationTestBookRegister*) base;
#line 321 "GomSerializationTest.vala"
	_tmp0_ = gxml_mappeable_element_pair_key_get_map_primary_key ((GXmlMappeableElementPairKey*) self);
#line 321 "GomSerializationTest.vala"
	result = _tmp0_;
#line 321 "GomSerializationTest.vala"
	return result;
#line 18075 "GomSerializationTest.c"
}

static gchar*
gom_serialization_test_book_register_real_get_map_skey (GXmlMappeableElementThreeKey* base)
{
	GomSerializationTestBookRegister * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 322 "GomSerializationTest.vala"
	self = (GomSerializationTestBookRegister*) base;
#line 322 "GomSerializationTest.vala"
	_tmp0_ = gxml_mappeable_element_pair_key_get_map_secondary_key ((GXmlMappeableElementPairKey*) self);
#line 322 "GomSerializationTest.vala"
	result = _tmp0_;
#line 322 "GomSerializationTest.vala"
	return result;
#line 18092 "GomSerializationTest.c"
}

static gchar*
gom_serialization_test_book_register_real_get_map_tkey (GXmlMappeableElementThreeKey* base)
{
	GomSerializationTestBookRegister * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 323 "GomSerializationTest.vala"
	self = (GomSerializationTestBookRegister*) base;
#line 323 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_cover;
#line 323 "GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 323 "GomSerializationTest.vala"
	result = _tmp1_;
#line 323 "GomSerializationTest.vala"
	return result;
#line 18112 "GomSerializationTest.c"
}

GomSerializationTestBook*
gom_serialization_test_book_register_create_book (GomSerializationTestBookRegister* self,
                                                  const gchar* name)
{
	GomSerializationTestBook* result = NULL;
	GXmlDomDocument* _tmp0_;
	GXmlDomDocument* _tmp1_;
	GObject* _tmp2_;
	GObject* _tmp3_;
	GomSerializationTestBook* _tmp4_;
#line 324 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 324 "GomSerializationTest.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 325 "GomSerializationTest.vala"
	_tmp0_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) self);
#line 325 "GomSerializationTest.vala"
	_tmp1_ = _tmp0_;
#line 325 "GomSerializationTest.vala"
	_tmp2_ = g_object_new (GOM_SERIALIZATION_TEST_TYPE_BOOK, "owner-document", _tmp1_, "name", name, NULL);
#line 325 "GomSerializationTest.vala"
	_tmp3_ = G_IS_INITIALLY_UNOWNED (_tmp2_) ? g_object_ref_sink (_tmp2_) : _tmp2_;
#line 325 "GomSerializationTest.vala"
	_tmp4_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GOM_SERIALIZATION_TEST_TYPE_BOOK) ? ((GomSerializationTestBook*) _tmp3_) : NULL;
#line 325 "GomSerializationTest.vala"
	if (_tmp4_ == NULL) {
#line 325 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp3_);
#line 18143 "GomSerializationTest.c"
	}
#line 325 "GomSerializationTest.vala"
	result = _tmp4_;
#line 325 "GomSerializationTest.vala"
	return result;
#line 18149 "GomSerializationTest.c"
}

gchar*
gom_serialization_test_book_register_to_string (GomSerializationTestBookRegister* self)
{
	gchar* result = NULL;
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_;
	gchar* s = NULL;
	gchar* _tmp1_;
	GError* _inner_error0_ = NULL;
#line 330 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 331 "GomSerializationTest.vala"
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
#line 331 "GomSerializationTest.vala"
	parser = _tmp0_;
#line 332 "GomSerializationTest.vala"
	_tmp1_ = g_strdup ("");
#line 332 "GomSerializationTest.vala"
	s = _tmp1_;
#line 18171 "GomSerializationTest.c"
	{
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_;
		gchar* _tmp4_;
		const gchar* _tmp5_;
#line 334 "GomSerializationTest.vala"
		_tmp3_ = gxml_parser_write_string ((GXmlParser*) parser, &_inner_error0_);
#line 334 "GomSerializationTest.vala"
		_tmp2_ = _tmp3_;
#line 334 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 18183 "GomSerializationTest.c"
			goto __catch201_g_error;
		}
#line 334 "GomSerializationTest.vala"
		_tmp4_ = _tmp2_;
#line 334 "GomSerializationTest.vala"
		_tmp2_ = NULL;
#line 334 "GomSerializationTest.vala"
		_g_free0 (s);
#line 334 "GomSerializationTest.vala"
		s = _tmp4_;
#line 335 "GomSerializationTest.vala"
		_tmp5_ = s;
#line 335 "GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp5_, "") != 0, "s != \"\"");
#line 333 "GomSerializationTest.vala"
		_g_free0 (_tmp2_);
#line 18200 "GomSerializationTest.c"
	}
	goto __finally201;
	__catch201_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
#line 333 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 333 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 337 "GomSerializationTest.vala"
		_tmp6_ = e->message;
#line 337 "GomSerializationTest.vala"
		_tmp7_ = g_strconcat ("Error: ", _tmp6_, NULL);
#line 337 "GomSerializationTest.vala"
		_tmp8_ = _tmp7_;
#line 337 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:337: %s", _tmp8_);
#line 337 "GomSerializationTest.vala"
		_g_free0 (_tmp8_);
#line 338 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 333 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 18227 "GomSerializationTest.c"
	}
	__finally201:
#line 333 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 333 "GomSerializationTest.vala"
		_g_free0 (s);
#line 333 "GomSerializationTest.vala"
		_g_object_unref0 (parser);
#line 333 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 333 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 333 "GomSerializationTest.vala"
		return NULL;
#line 18242 "GomSerializationTest.c"
	}
#line 340 "GomSerializationTest.vala"
	result = s;
#line 340 "GomSerializationTest.vala"
	_g_object_unref0 (parser);
#line 340 "GomSerializationTest.vala"
	return result;
#line 18250 "GomSerializationTest.c"
}

GomSerializationTestBookRegister*
gom_serialization_test_book_register_construct (GType object_type)
{
	GomSerializationTestBookRegister * self = NULL;
#line 283 "GomSerializationTest.vala"
	self = (GomSerializationTestBookRegister*) gxml_gom_element_construct (object_type);
#line 283 "GomSerializationTest.vala"
	return self;
#line 18261 "GomSerializationTest.c"
}

GomSerializationTestBookRegister*
gom_serialization_test_book_register_new (void)
{
#line 283 "GomSerializationTest.vala"
	return gom_serialization_test_book_register_construct (GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER);
#line 18269 "GomSerializationTest.c"
}

gint
gom_serialization_test_book_register_get_year (GomSerializationTestBookRegister* self)
{
	gint result;
#line 289 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 289 "GomSerializationTest.vala"
	result = self->priv->_year;
#line 289 "GomSerializationTest.vala"
	return result;
#line 18282 "GomSerializationTest.c"
}

void
gom_serialization_test_book_register_set_year (GomSerializationTestBookRegister* self,
                                               gint value)
{
#line 289 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 289 "GomSerializationTest.vala"
	if (gom_serialization_test_book_register_get_year (self) != value) {
#line 289 "GomSerializationTest.vala"
		self->priv->_year = value;
#line 289 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_book_register_properties[GOM_SERIALIZATION_TEST_BOOK_REGISTER_YEAR_PROPERTY]);
#line 18297 "GomSerializationTest.c"
	}
}

const gchar*
gom_serialization_test_book_register_get_cover (GomSerializationTestBookRegister* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 291 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 291 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_cover;
#line 291 "GomSerializationTest.vala"
	result = _tmp0_;
#line 291 "GomSerializationTest.vala"
	return result;
#line 18314 "GomSerializationTest.c"
}

void
gom_serialization_test_book_register_set_cover (GomSerializationTestBookRegister* self,
                                                const gchar* value)
{
#line 291 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 291 "GomSerializationTest.vala"
	if (g_strcmp0 (value, gom_serialization_test_book_register_get_cover (self)) != 0) {
#line 18325 "GomSerializationTest.c"
		gchar* _tmp0_;
#line 291 "GomSerializationTest.vala"
		_tmp0_ = g_strdup (value);
#line 291 "GomSerializationTest.vala"
		_g_free0 (self->priv->_cover);
#line 291 "GomSerializationTest.vala"
		self->priv->_cover = _tmp0_;
#line 291 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_book_register_properties[GOM_SERIALIZATION_TEST_BOOK_REGISTER_COVER_PROPERTY]);
#line 18335 "GomSerializationTest.c"
	}
}

GomSerializationTestBook*
gom_serialization_test_book_register_get_book (GomSerializationTestBookRegister* self)
{
	GomSerializationTestBook* result;
	GomSerializationTestBook* _tmp0_;
#line 293 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 293 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_book;
#line 293 "GomSerializationTest.vala"
	result = _tmp0_;
#line 293 "GomSerializationTest.vala"
	return result;
#line 18352 "GomSerializationTest.c"
}

void
gom_serialization_test_book_register_set_book (GomSerializationTestBookRegister* self,
                                               GomSerializationTestBook* value)
{
	GError* _inner_error0_ = NULL;
#line 294 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 18362 "GomSerializationTest.c"
	{
		GomSerializationTestBook* _tmp0_;
		GomSerializationTestBook* _tmp1_;
		GXmlDomNode* _tmp2_;
		GXmlDomNode* _tmp3_;
#line 296 "GomSerializationTest.vala"
		gxml_gom_object_clean_property_elements ((GXmlGomObject*) self, "book", &_inner_error0_);
#line 296 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 18372 "GomSerializationTest.c"
			goto __catch202_g_error;
		}
#line 297 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 297 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_book);
#line 297 "GomSerializationTest.vala"
		self->priv->_book = _tmp0_;
#line 298 "GomSerializationTest.vala"
		_tmp1_ = self->priv->_book;
#line 298 "GomSerializationTest.vala"
		_tmp2_ = gxml_dom_node_append_child ((GXmlDomNode*) self, (GXmlDomNode*) _tmp1_, &_inner_error0_);
#line 298 "GomSerializationTest.vala"
		_tmp3_ = _tmp2_;
#line 298 "GomSerializationTest.vala"
		_g_object_unref0 (_tmp3_);
#line 298 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 18391 "GomSerializationTest.c"
			goto __catch202_g_error;
		}
	}
	goto __finally202;
	__catch202_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp4_;
#line 295 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 295 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 300 "GomSerializationTest.vala"
		_tmp4_ = e->message;
#line 300 "GomSerializationTest.vala"
		g_warning ("GomSerializationTest.vala:300: %s", _tmp4_);
#line 301 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 295 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 18412 "GomSerializationTest.c"
	}
	__finally202:
#line 295 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 295 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 295 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 295 "GomSerializationTest.vala"
		return;
#line 18423 "GomSerializationTest.c"
	}
#line 294 "GomSerializationTest.vala"
	g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_book_register_properties[GOM_SERIALIZATION_TEST_BOOK_REGISTER_BOOK_PROPERTY]);
#line 18427 "GomSerializationTest.c"
}

static GObject *
gom_serialization_test_book_register_constructor (GType type,
                                                  guint n_construct_properties,
                                                  GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestBookRegister * self;
	GError* _inner_error0_ = NULL;
#line 305 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_book_register_parent_class);
#line 305 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 305 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, GomSerializationTestBookRegister);
#line 18445 "GomSerializationTest.c"
	{
#line 306 "GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "BookRegister");
#line 18449 "GomSerializationTest.c"
	}
	goto __finally203;
	__catch203_g_error:
	{
#line 306 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 306 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 307 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 18460 "GomSerializationTest.c"
	}
	__finally203:
#line 306 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 306 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 306 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 18469 "GomSerializationTest.c"
	}
#line 305 "GomSerializationTest.vala"
	return obj;
#line 18473 "GomSerializationTest.c"
}

static void
gom_serialization_test_book_register_class_init (GomSerializationTestBookRegisterClass * klass,
                                                 gpointer klass_data)
{
#line 283 "GomSerializationTest.vala"
	gom_serialization_test_book_register_parent_class = g_type_class_peek_parent (klass);
#line 283 "GomSerializationTest.vala"
	g_type_class_adjust_private_offset (klass, &GomSerializationTestBookRegister_private_offset);
#line 283 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_serialization_test_book_register_get_property;
#line 283 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_serialization_test_book_register_set_property;
#line 283 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_book_register_constructor;
#line 283 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_serialization_test_book_register_finalize;
#line 283 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_REGISTER_YEAR_PROPERTY, gom_serialization_test_book_register_properties[GOM_SERIALIZATION_TEST_BOOK_REGISTER_YEAR_PROPERTY] = g_param_spec_int ("year", "::Year", "year", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 283 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_REGISTER_COVER_PROPERTY, gom_serialization_test_book_register_properties[GOM_SERIALIZATION_TEST_BOOK_REGISTER_COVER_PROPERTY] = g_param_spec_string ("cover", "::Cover", "cover", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 283 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_REGISTER_BOOK_PROPERTY, gom_serialization_test_book_register_properties[GOM_SERIALIZATION_TEST_BOOK_REGISTER_BOOK_PROPERTY] = g_param_spec_object ("book", "book", "book", GOM_SERIALIZATION_TEST_TYPE_BOOK, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 18498 "GomSerializationTest.c"
}

static void
gom_serialization_test_book_register_gxml_mappeable_element_interface_init (GXmlMappeableElementIface * iface,
                                                                            gpointer iface_data)
{
#line 324 "GomSerializationTest.vala"
	gom_serialization_test_book_register_gxml_mappeable_element_parent_iface = g_type_interface_peek_parent (iface);
#line 324 "GomSerializationTest.vala"
	iface->get_map_key = (gchar* (*) (GXmlMappeableElement*)) gom_serialization_test_book_register_real_get_map_key;
#line 18509 "GomSerializationTest.c"
}

static void
gom_serialization_test_book_register_gxml_mappeable_element_pair_key_interface_init (GXmlMappeableElementPairKeyIface * iface,
                                                                                     gpointer iface_data)
{
#line 324 "GomSerializationTest.vala"
	gom_serialization_test_book_register_gxml_mappeable_element_pair_key_parent_iface = g_type_interface_peek_parent (iface);
#line 324 "GomSerializationTest.vala"
	iface->get_map_primary_key = (gchar* (*) (GXmlMappeableElementPairKey*)) gom_serialization_test_book_register_real_get_map_primary_key;
#line 324 "GomSerializationTest.vala"
	iface->get_map_secondary_key = (gchar* (*) (GXmlMappeableElementPairKey*)) gom_serialization_test_book_register_real_get_map_secondary_key;
#line 18522 "GomSerializationTest.c"
}

static void
gom_serialization_test_book_register_gxml_mappeable_element_three_key_interface_init (GXmlMappeableElementThreeKeyIface * iface,
                                                                                      gpointer iface_data)
{
#line 324 "GomSerializationTest.vala"
	gom_serialization_test_book_register_gxml_mappeable_element_three_key_parent_iface = g_type_interface_peek_parent (iface);
#line 324 "GomSerializationTest.vala"
	iface->get_map_pkey = (gchar* (*) (GXmlMappeableElementThreeKey*)) gom_serialization_test_book_register_real_get_map_pkey;
#line 324 "GomSerializationTest.vala"
	iface->get_map_skey = (gchar* (*) (GXmlMappeableElementThreeKey*)) gom_serialization_test_book_register_real_get_map_skey;
#line 324 "GomSerializationTest.vala"
	iface->get_map_tkey = (gchar* (*) (GXmlMappeableElementThreeKey*)) gom_serialization_test_book_register_real_get_map_tkey;
#line 18537 "GomSerializationTest.c"
}

static void
gom_serialization_test_book_register_instance_init (GomSerializationTestBookRegister * self,
                                                    gpointer klass)
{
#line 283 "GomSerializationTest.vala"
	self->priv = gom_serialization_test_book_register_get_instance_private (self);
#line 287 "GomSerializationTest.vala"
	self->priv->_book = NULL;
#line 18548 "GomSerializationTest.c"
}

static void
gom_serialization_test_book_register_finalize (GObject * obj)
{
	GomSerializationTestBookRegister * self;
#line 283 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, GomSerializationTestBookRegister);
#line 287 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_book);
#line 291 "GomSerializationTest.vala"
	_g_free0 (self->priv->_cover);
#line 324 "GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_serialization_test_book_register_parent_class)->finalize (obj);
#line 18563 "GomSerializationTest.c"
}

GType
gom_serialization_test_book_register_get_type (void)
{
	static volatile gsize gom_serialization_test_book_register_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_book_register_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestBookRegisterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_book_register_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestBookRegister), 0, (GInstanceInitFunc) gom_serialization_test_book_register_instance_init, NULL };
		static const GInterfaceInfo gxml_mappeable_element_info = { (GInterfaceInitFunc) gom_serialization_test_book_register_gxml_mappeable_element_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_mappeable_element_pair_key_info = { (GInterfaceInitFunc) gom_serialization_test_book_register_gxml_mappeable_element_pair_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_mappeable_element_three_key_info = { (GInterfaceInitFunc) gom_serialization_test_book_register_gxml_mappeable_element_three_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gom_serialization_test_book_register_type_id;
		gom_serialization_test_book_register_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomSerializationTestBookRegister", &g_define_type_info, 0);
		g_type_add_interface_static (gom_serialization_test_book_register_type_id, GXML_TYPE_MAPPEABLE_ELEMENT, &gxml_mappeable_element_info);
		g_type_add_interface_static (gom_serialization_test_book_register_type_id, GXML_TYPE_MAPPEABLE_ELEMENT_PAIR_KEY, &gxml_mappeable_element_pair_key_info);
		g_type_add_interface_static (gom_serialization_test_book_register_type_id, GXML_TYPE_MAPPEABLE_ELEMENT_THREE_KEY, &gxml_mappeable_element_three_key_info);
		GomSerializationTestBookRegister_private_offset = g_type_add_instance_private (gom_serialization_test_book_register_type_id, sizeof (GomSerializationTestBookRegisterPrivate));
		g_once_init_leave (&gom_serialization_test_book_register_type_id__volatile, gom_serialization_test_book_register_type_id);
	}
	return gom_serialization_test_book_register_type_id__volatile;
}

static void
_vala_gom_serialization_test_book_register_get_property (GObject * object,
                                                         guint property_id,
                                                         GValue * value,
                                                         GParamSpec * pspec)
{
	GomSerializationTestBookRegister * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, GomSerializationTestBookRegister);
#line 283 "GomSerializationTest.vala"
	switch (property_id) {
#line 283 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_REGISTER_YEAR_PROPERTY:
#line 283 "GomSerializationTest.vala"
		g_value_set_int (value, gom_serialization_test_book_register_get_year (self));
#line 283 "GomSerializationTest.vala"
		break;
#line 283 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_REGISTER_COVER_PROPERTY:
#line 283 "GomSerializationTest.vala"
		g_value_set_string (value, gom_serialization_test_book_register_get_cover (self));
#line 283 "GomSerializationTest.vala"
		break;
#line 283 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_REGISTER_BOOK_PROPERTY:
#line 283 "GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_book_register_get_book (self));
#line 283 "GomSerializationTest.vala"
		break;
#line 18614 "GomSerializationTest.c"
		default:
#line 283 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 283 "GomSerializationTest.vala"
		break;
#line 18620 "GomSerializationTest.c"
	}
}

static void
_vala_gom_serialization_test_book_register_set_property (GObject * object,
                                                         guint property_id,
                                                         const GValue * value,
                                                         GParamSpec * pspec)
{
	GomSerializationTestBookRegister * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, GomSerializationTestBookRegister);
#line 283 "GomSerializationTest.vala"
	switch (property_id) {
#line 283 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_REGISTER_YEAR_PROPERTY:
#line 283 "GomSerializationTest.vala"
		gom_serialization_test_book_register_set_year (self, g_value_get_int (value));
#line 283 "GomSerializationTest.vala"
		break;
#line 283 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_REGISTER_COVER_PROPERTY:
#line 283 "GomSerializationTest.vala"
		gom_serialization_test_book_register_set_cover (self, g_value_get_string (value));
#line 283 "GomSerializationTest.vala"
		break;
#line 283 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_REGISTER_BOOK_PROPERTY:
#line 283 "GomSerializationTest.vala"
		gom_serialization_test_book_register_set_book (self, g_value_get_object (value));
#line 283 "GomSerializationTest.vala"
		break;
#line 18652 "GomSerializationTest.c"
		default:
#line 283 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 283 "GomSerializationTest.vala"
		break;
#line 18658 "GomSerializationTest.c"
	}
}

static inline gpointer
gom_serialization_test_book_stand_get_instance_private (GomSerializationTestBookStand* self)
{
	return G_STRUCT_MEMBER_P (self, GomSerializationTestBookStand_private_offset);
}

gchar*
gom_serialization_test_book_stand_to_string (GomSerializationTestBookStand* self)
{
	gchar* result = NULL;
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_;
	gchar* s = NULL;
	gchar* _tmp1_;
	GError* _inner_error0_ = NULL;
#line 392 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 393 "GomSerializationTest.vala"
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
#line 393 "GomSerializationTest.vala"
	parser = _tmp0_;
#line 394 "GomSerializationTest.vala"
	_tmp1_ = g_strdup ("");
#line 394 "GomSerializationTest.vala"
	s = _tmp1_;
#line 18687 "GomSerializationTest.c"
	{
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_;
		gchar* _tmp4_;
#line 396 "GomSerializationTest.vala"
		_tmp3_ = gxml_parser_write_string ((GXmlParser*) parser, &_inner_error0_);
#line 396 "GomSerializationTest.vala"
		_tmp2_ = _tmp3_;
#line 396 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 18698 "GomSerializationTest.c"
			goto __catch204_g_error;
		}
#line 396 "GomSerializationTest.vala"
		_tmp4_ = _tmp2_;
#line 396 "GomSerializationTest.vala"
		_tmp2_ = NULL;
#line 396 "GomSerializationTest.vala"
		_g_free0 (s);
#line 396 "GomSerializationTest.vala"
		s = _tmp4_;
#line 395 "GomSerializationTest.vala"
		_g_free0 (_tmp2_);
#line 18711 "GomSerializationTest.c"
	}
	goto __finally204;
	__catch204_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
#line 395 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 395 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 398 "GomSerializationTest.vala"
		_tmp5_ = e->message;
#line 398 "GomSerializationTest.vala"
		_tmp6_ = g_strconcat ("Error: ", _tmp5_, NULL);
#line 398 "GomSerializationTest.vala"
		_tmp7_ = _tmp6_;
#line 398 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:398: %s", _tmp7_);
#line 398 "GomSerializationTest.vala"
		_g_free0 (_tmp7_);
#line 399 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 395 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 18738 "GomSerializationTest.c"
	}
	__finally204:
#line 395 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 395 "GomSerializationTest.vala"
		_g_free0 (s);
#line 395 "GomSerializationTest.vala"
		_g_object_unref0 (parser);
#line 395 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 395 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 395 "GomSerializationTest.vala"
		return NULL;
#line 18753 "GomSerializationTest.c"
	}
#line 401 "GomSerializationTest.vala"
	result = s;
#line 401 "GomSerializationTest.vala"
	_g_object_unref0 (parser);
#line 401 "GomSerializationTest.vala"
	return result;
#line 18761 "GomSerializationTest.c"
}

GomSerializationTestBookStand*
gom_serialization_test_book_stand_construct (GType object_type)
{
	GomSerializationTestBookStand * self = NULL;
#line 343 "GomSerializationTest.vala"
	self = (GomSerializationTestBookStand*) gxml_gom_element_construct (object_type);
#line 343 "GomSerializationTest.vala"
	return self;
#line 18772 "GomSerializationTest.c"
}

GomSerializationTestBookStand*
gom_serialization_test_book_stand_new (void)
{
#line 343 "GomSerializationTest.vala"
	return gom_serialization_test_book_stand_construct (GOM_SERIALIZATION_TEST_TYPE_BOOK_STAND);
#line 18780 "GomSerializationTest.c"
}

const gchar*
gom_serialization_test_book_stand_get_classification (GomSerializationTestBookStand* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 348 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 348 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_classification;
#line 348 "GomSerializationTest.vala"
	result = _tmp0_;
#line 348 "GomSerializationTest.vala"
	return result;
#line 18796 "GomSerializationTest.c"
}

void
gom_serialization_test_book_stand_set_classification (GomSerializationTestBookStand* self,
                                                      const gchar* value)
{
#line 348 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 348 "GomSerializationTest.vala"
	if (g_strcmp0 (value, gom_serialization_test_book_stand_get_classification (self)) != 0) {
#line 18807 "GomSerializationTest.c"
		gchar* _tmp0_;
#line 348 "GomSerializationTest.vala"
		_tmp0_ = g_strdup (value);
#line 348 "GomSerializationTest.vala"
		_g_free0 (self->priv->_classification);
#line 348 "GomSerializationTest.vala"
		self->priv->_classification = _tmp0_;
#line 348 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_book_stand_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_CLASSIFICATION_PROPERTY]);
#line 18817 "GomSerializationTest.c"
	}
}

GomSerializationTestBookStandDimension*
gom_serialization_test_book_stand_get_dimension_x (GomSerializationTestBookStand* self)
{
	GomSerializationTestBookStandDimension* result;
	GomSerializationTestBookStandDimension* _tmp0_;
#line 349 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 349 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_dimension_x;
#line 349 "GomSerializationTest.vala"
	result = _tmp0_;
#line 349 "GomSerializationTest.vala"
	return result;
#line 18834 "GomSerializationTest.c"
}

void
gom_serialization_test_book_stand_set_dimension_x (GomSerializationTestBookStand* self,
                                                   GomSerializationTestBookStandDimension* value)
{
#line 349 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 349 "GomSerializationTest.vala"
	if (gom_serialization_test_book_stand_get_dimension_x (self) != value) {
#line 18845 "GomSerializationTest.c"
		GomSerializationTestBookStandDimension* _tmp0_;
#line 349 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 349 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_dimension_x);
#line 349 "GomSerializationTest.vala"
		self->priv->_dimension_x = _tmp0_;
#line 349 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_book_stand_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_X_PROPERTY]);
#line 18855 "GomSerializationTest.c"
	}
}

GomSerializationTestBookStandDimensionY*
gom_serialization_test_book_stand_get_dimension_y (GomSerializationTestBookStand* self)
{
	GomSerializationTestBookStandDimensionY* result;
	GomSerializationTestBookStandDimensionY* _tmp0_;
#line 351 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 351 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_dimension_y;
#line 351 "GomSerializationTest.vala"
	result = _tmp0_;
#line 351 "GomSerializationTest.vala"
	return result;
#line 18872 "GomSerializationTest.c"
}

void
gom_serialization_test_book_stand_set_dimension_y (GomSerializationTestBookStand* self,
                                                   GomSerializationTestBookStandDimensionY* value)
{
#line 351 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 351 "GomSerializationTest.vala"
	if (gom_serialization_test_book_stand_get_dimension_y (self) != value) {
#line 18883 "GomSerializationTest.c"
		GomSerializationTestBookStandDimensionY* _tmp0_;
#line 351 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 351 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_dimension_y);
#line 351 "GomSerializationTest.vala"
		self->priv->_dimension_y = _tmp0_;
#line 351 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_book_stand_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Y_PROPERTY]);
#line 18893 "GomSerializationTest.c"
	}
}

GomSerializationTestBookStandDimensionZ*
gom_serialization_test_book_stand_get_dimension_z (GomSerializationTestBookStand* self)
{
	GomSerializationTestBookStandDimensionZ* result;
	GomSerializationTestBookStandDimensionZ* _tmp0_;
#line 353 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 353 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_dimension_z;
#line 353 "GomSerializationTest.vala"
	result = _tmp0_;
#line 353 "GomSerializationTest.vala"
	return result;
#line 18910 "GomSerializationTest.c"
}

void
gom_serialization_test_book_stand_set_dimension_z (GomSerializationTestBookStand* self,
                                                   GomSerializationTestBookStandDimensionZ* value)
{
#line 353 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 353 "GomSerializationTest.vala"
	if (gom_serialization_test_book_stand_get_dimension_z (self) != value) {
#line 18921 "GomSerializationTest.c"
		GomSerializationTestBookStandDimensionZ* _tmp0_;
#line 353 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 353 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_dimension_z);
#line 353 "GomSerializationTest.vala"
		self->priv->_dimension_z = _tmp0_;
#line 353 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_book_stand_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Z_PROPERTY]);
#line 18931 "GomSerializationTest.c"
	}
}

GomSerializationTestRegisters*
gom_serialization_test_book_stand_get_registers (GomSerializationTestBookStand* self)
{
	GomSerializationTestRegisters* result;
	GomSerializationTestRegisters* _tmp0_;
#line 354 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 354 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_registers;
#line 354 "GomSerializationTest.vala"
	result = _tmp0_;
#line 354 "GomSerializationTest.vala"
	return result;
#line 18948 "GomSerializationTest.c"
}

void
gom_serialization_test_book_stand_set_registers (GomSerializationTestBookStand* self,
                                                 GomSerializationTestRegisters* value)
{
#line 354 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 354 "GomSerializationTest.vala"
	if (gom_serialization_test_book_stand_get_registers (self) != value) {
#line 18959 "GomSerializationTest.c"
		GomSerializationTestRegisters* _tmp0_;
#line 354 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 354 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_registers);
#line 354 "GomSerializationTest.vala"
		self->priv->_registers = _tmp0_;
#line 354 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_book_stand_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_REGISTERS_PROPERTY]);
#line 18969 "GomSerializationTest.c"
	}
}

GomSerializationTestHashRegisters*
gom_serialization_test_book_stand_get_hashmap_registers (GomSerializationTestBookStand* self)
{
	GomSerializationTestHashRegisters* result;
	GomSerializationTestHashRegisters* _tmp0_;
	GomSerializationTestHashRegisters* _tmp4_;
#line 356 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 357 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_hashmap_registers;
#line 357 "GomSerializationTest.vala"
	if (_tmp0_ == NULL) {
#line 18985 "GomSerializationTest.c"
		GObject* _tmp1_;
		GObject* _tmp2_;
		GomSerializationTestHashRegisters* _tmp3_;
#line 358 "GomSerializationTest.vala"
		_tmp1_ = g_object_new (GOM_SERIALIZATION_TEST_TYPE_HASH_REGISTERS, "element", self, NULL);
#line 358 "GomSerializationTest.vala"
		_tmp2_ = G_IS_INITIALLY_UNOWNED (_tmp1_) ? g_object_ref_sink (_tmp1_) : _tmp1_;
#line 358 "GomSerializationTest.vala"
		_tmp3_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, GOM_SERIALIZATION_TEST_TYPE_HASH_REGISTERS) ? ((GomSerializationTestHashRegisters*) _tmp2_) : NULL;
#line 358 "GomSerializationTest.vala"
		if (_tmp3_ == NULL) {
#line 358 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp2_);
#line 18999 "GomSerializationTest.c"
		}
#line 358 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_hashmap_registers);
#line 358 "GomSerializationTest.vala"
		self->priv->_hashmap_registers = _tmp3_;
#line 19005 "GomSerializationTest.c"
	}
#line 360 "GomSerializationTest.vala"
	_tmp4_ = self->priv->_hashmap_registers;
#line 360 "GomSerializationTest.vala"
	result = _tmp4_;
#line 360 "GomSerializationTest.vala"
	return result;
#line 19013 "GomSerializationTest.c"
}

void
gom_serialization_test_book_stand_set_hashmap_registers (GomSerializationTestBookStand* self,
                                                         GomSerializationTestHashRegisters* value)
{
	GomSerializationTestHashRegisters* _tmp0_;
#line 362 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 363 "GomSerializationTest.vala"
	_tmp0_ = _g_object_ref0 (value);
#line 363 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_hashmap_registers);
#line 363 "GomSerializationTest.vala"
	self->priv->_hashmap_registers = _tmp0_;
#line 362 "GomSerializationTest.vala"
	g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_book_stand_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_HASHMAP_REGISTERS_PROPERTY]);
#line 19031 "GomSerializationTest.c"
}

GomSerializationTestHashPairRegisters*
gom_serialization_test_book_stand_get_hashpair_registers (GomSerializationTestBookStand* self)
{
	GomSerializationTestHashPairRegisters* result;
	GomSerializationTestHashPairRegisters* _tmp0_;
	GomSerializationTestHashPairRegisters* _tmp4_;
#line 367 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 368 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_hashpair_registers;
#line 368 "GomSerializationTest.vala"
	if (_tmp0_ == NULL) {
#line 19046 "GomSerializationTest.c"
		GObject* _tmp1_;
		GObject* _tmp2_;
		GomSerializationTestHashPairRegisters* _tmp3_;
#line 369 "GomSerializationTest.vala"
		_tmp1_ = g_object_new (GOM_SERIALIZATION_TEST_TYPE_HASH_PAIR_REGISTERS, "element", self, NULL);
#line 369 "GomSerializationTest.vala"
		_tmp2_ = G_IS_INITIALLY_UNOWNED (_tmp1_) ? g_object_ref_sink (_tmp1_) : _tmp1_;
#line 369 "GomSerializationTest.vala"
		_tmp3_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, GOM_SERIALIZATION_TEST_TYPE_HASH_PAIR_REGISTERS) ? ((GomSerializationTestHashPairRegisters*) _tmp2_) : NULL;
#line 369 "GomSerializationTest.vala"
		if (_tmp3_ == NULL) {
#line 369 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp2_);
#line 19060 "GomSerializationTest.c"
		}
#line 369 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_hashpair_registers);
#line 369 "GomSerializationTest.vala"
		self->priv->_hashpair_registers = _tmp3_;
#line 19066 "GomSerializationTest.c"
	}
#line 371 "GomSerializationTest.vala"
	_tmp4_ = self->priv->_hashpair_registers;
#line 371 "GomSerializationTest.vala"
	result = _tmp4_;
#line 371 "GomSerializationTest.vala"
	return result;
#line 19074 "GomSerializationTest.c"
}

void
gom_serialization_test_book_stand_set_hashpair_registers (GomSerializationTestBookStand* self,
                                                          GomSerializationTestHashPairRegisters* value)
{
	GomSerializationTestHashPairRegisters* _tmp0_;
#line 373 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 374 "GomSerializationTest.vala"
	_tmp0_ = _g_object_ref0 (value);
#line 374 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_hashpair_registers);
#line 374 "GomSerializationTest.vala"
	self->priv->_hashpair_registers = _tmp0_;
#line 373 "GomSerializationTest.vala"
	g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_book_stand_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_HASHPAIR_REGISTERS_PROPERTY]);
#line 19092 "GomSerializationTest.c"
}

GomSerializationTestHashThreeRegisters*
gom_serialization_test_book_stand_get_hashthree_registers (GomSerializationTestBookStand* self)
{
	GomSerializationTestHashThreeRegisters* result;
	GomSerializationTestHashThreeRegisters* _tmp0_;
	GomSerializationTestHashThreeRegisters* _tmp4_;
#line 378 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 379 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_hashthree_registers;
#line 379 "GomSerializationTest.vala"
	if (_tmp0_ == NULL) {
#line 19107 "GomSerializationTest.c"
		GObject* _tmp1_;
		GObject* _tmp2_;
		GomSerializationTestHashThreeRegisters* _tmp3_;
#line 380 "GomSerializationTest.vala"
		_tmp1_ = g_object_new (GOM_SERIALIZATION_TEST_TYPE_HASH_THREE_REGISTERS, "element", self, NULL);
#line 380 "GomSerializationTest.vala"
		_tmp2_ = G_IS_INITIALLY_UNOWNED (_tmp1_) ? g_object_ref_sink (_tmp1_) : _tmp1_;
#line 380 "GomSerializationTest.vala"
		_tmp3_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, GOM_SERIALIZATION_TEST_TYPE_HASH_THREE_REGISTERS) ? ((GomSerializationTestHashThreeRegisters*) _tmp2_) : NULL;
#line 380 "GomSerializationTest.vala"
		if (_tmp3_ == NULL) {
#line 380 "GomSerializationTest.vala"
			_g_object_unref0 (_tmp2_);
#line 19121 "GomSerializationTest.c"
		}
#line 380 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_hashthree_registers);
#line 380 "GomSerializationTest.vala"
		self->priv->_hashthree_registers = _tmp3_;
#line 19127 "GomSerializationTest.c"
	}
#line 382 "GomSerializationTest.vala"
	_tmp4_ = self->priv->_hashthree_registers;
#line 382 "GomSerializationTest.vala"
	result = _tmp4_;
#line 382 "GomSerializationTest.vala"
	return result;
#line 19135 "GomSerializationTest.c"
}

void
gom_serialization_test_book_stand_set_hashthree_registers (GomSerializationTestBookStand* self,
                                                           GomSerializationTestHashThreeRegisters* value)
{
	GomSerializationTestHashThreeRegisters* _tmp0_;
#line 384 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 385 "GomSerializationTest.vala"
	_tmp0_ = _g_object_ref0 (value);
#line 385 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_hashthree_registers);
#line 385 "GomSerializationTest.vala"
	self->priv->_hashthree_registers = _tmp0_;
#line 384 "GomSerializationTest.vala"
	g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_book_stand_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_HASHTHREE_REGISTERS_PROPERTY]);
#line 19153 "GomSerializationTest.c"
}

GomSerializationTestBooks*
gom_serialization_test_book_stand_get_books (GomSerializationTestBookStand* self)
{
	GomSerializationTestBooks* result;
	GomSerializationTestBooks* _tmp0_;
#line 388 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 388 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_books;
#line 388 "GomSerializationTest.vala"
	result = _tmp0_;
#line 388 "GomSerializationTest.vala"
	return result;
#line 19169 "GomSerializationTest.c"
}

void
gom_serialization_test_book_stand_set_books (GomSerializationTestBookStand* self,
                                             GomSerializationTestBooks* value)
{
#line 388 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 388 "GomSerializationTest.vala"
	if (gom_serialization_test_book_stand_get_books (self) != value) {
#line 19180 "GomSerializationTest.c"
		GomSerializationTestBooks* _tmp0_;
#line 388 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 388 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_books);
#line 388 "GomSerializationTest.vala"
		self->priv->_books = _tmp0_;
#line 388 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_book_stand_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_BOOKS_PROPERTY]);
#line 19190 "GomSerializationTest.c"
	}
}

static GObject *
gom_serialization_test_book_stand_constructor (GType type,
                                               guint n_construct_properties,
                                               GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestBookStand * self;
	GError* _inner_error0_ = NULL;
#line 389 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_book_stand_parent_class);
#line 389 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 389 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_BOOK_STAND, GomSerializationTestBookStand);
#line 19209 "GomSerializationTest.c"
	{
#line 390 "GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "BookStand");
#line 19213 "GomSerializationTest.c"
	}
	goto __finally205;
	__catch205_g_error:
	{
#line 390 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 390 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 390 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 19224 "GomSerializationTest.c"
	}
	__finally205:
#line 390 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 390 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 390 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 19233 "GomSerializationTest.c"
	}
#line 389 "GomSerializationTest.vala"
	return obj;
#line 19237 "GomSerializationTest.c"
}

static inline gpointer
gom_serialization_test_book_stand_dimension_get_instance_private (GomSerializationTestBookStandDimension* self)
{
	return G_STRUCT_MEMBER_P (self, GomSerializationTestBookStandDimension_private_offset);
}

GomSerializationTestBookStandDimension*
gom_serialization_test_book_stand_dimension_construct (GType object_type)
{
	GomSerializationTestBookStandDimension * self = NULL;
#line 403 "GomSerializationTest.vala"
	self = (GomSerializationTestBookStandDimension*) gxml_gom_element_construct (object_type);
#line 403 "GomSerializationTest.vala"
	return self;
#line 19254 "GomSerializationTest.c"
}

GomSerializationTestBookStandDimension*
gom_serialization_test_book_stand_dimension_new (void)
{
#line 403 "GomSerializationTest.vala"
	return gom_serialization_test_book_stand_dimension_construct (GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION);
#line 19262 "GomSerializationTest.c"
}

gdouble
gom_serialization_test_book_stand_dimension_get_length (GomSerializationTestBookStandDimension* self)
{
	gdouble result;
#line 405 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, 0.0);
#line 405 "GomSerializationTest.vala"
	result = self->priv->_length;
#line 405 "GomSerializationTest.vala"
	return result;
#line 19275 "GomSerializationTest.c"
}

void
gom_serialization_test_book_stand_dimension_set_length (GomSerializationTestBookStandDimension* self,
                                                        gdouble value)
{
#line 405 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 405 "GomSerializationTest.vala"
	if (gom_serialization_test_book_stand_dimension_get_length (self) != value) {
#line 405 "GomSerializationTest.vala"
		self->priv->_length = value;
#line 405 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_book_stand_dimension_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_LENGTH_PROPERTY]);
#line 19290 "GomSerializationTest.c"
	}
}

const gchar*
gom_serialization_test_book_stand_dimension_get_dtype (GomSerializationTestBookStandDimension* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 407 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 407 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_dtype;
#line 407 "GomSerializationTest.vala"
	result = _tmp0_;
#line 407 "GomSerializationTest.vala"
	return result;
#line 19307 "GomSerializationTest.c"
}

void
gom_serialization_test_book_stand_dimension_set_dtype (GomSerializationTestBookStandDimension* self,
                                                       const gchar* value)
{
#line 407 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 407 "GomSerializationTest.vala"
	if (g_strcmp0 (value, gom_serialization_test_book_stand_dimension_get_dtype (self)) != 0) {
#line 19318 "GomSerializationTest.c"
		gchar* _tmp0_;
#line 407 "GomSerializationTest.vala"
		_tmp0_ = g_strdup (value);
#line 407 "GomSerializationTest.vala"
		_g_free0 (self->priv->_dtype);
#line 407 "GomSerializationTest.vala"
		self->priv->_dtype = _tmp0_;
#line 407 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_book_stand_dimension_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_DTYPE_PROPERTY]);
#line 19328 "GomSerializationTest.c"
	}
}

static GObject *
gom_serialization_test_book_stand_dimension_constructor (GType type,
                                                         guint n_construct_properties,
                                                         GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestBookStandDimension * self;
	GError* _inner_error0_ = NULL;
#line 408 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_book_stand_dimension_parent_class);
#line 408 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 408 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION, GomSerializationTestBookStandDimension);
#line 19347 "GomSerializationTest.c"
	{
#line 409 "GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Dimension");
#line 19351 "GomSerializationTest.c"
	}
	goto __finally206;
	__catch206_g_error:
	{
#line 409 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 409 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 409 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 19362 "GomSerializationTest.c"
	}
	__finally206:
#line 409 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 409 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 409 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 19371 "GomSerializationTest.c"
	}
#line 408 "GomSerializationTest.vala"
	return obj;
#line 19375 "GomSerializationTest.c"
}

static void
gom_serialization_test_book_stand_dimension_class_init (GomSerializationTestBookStandDimensionClass * klass,
                                                        gpointer klass_data)
{
#line 403 "GomSerializationTest.vala"
	gom_serialization_test_book_stand_dimension_parent_class = g_type_class_peek_parent (klass);
#line 403 "GomSerializationTest.vala"
	g_type_class_adjust_private_offset (klass, &GomSerializationTestBookStandDimension_private_offset);
#line 403 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_serialization_test_book_stand_dimension_get_property;
#line 403 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_serialization_test_book_stand_dimension_set_property;
#line 403 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_book_stand_dimension_constructor;
#line 403 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_serialization_test_book_stand_dimension_finalize;
#line 403 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_LENGTH_PROPERTY, gom_serialization_test_book_stand_dimension_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_LENGTH_PROPERTY] = g_param_spec_double ("length", "::Length", "length", -G_MAXDOUBLE, G_MAXDOUBLE, 1.0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 403 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_DTYPE_PROPERTY, gom_serialization_test_book_stand_dimension_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_DTYPE_PROPERTY] = g_param_spec_string ("dtype", "::Type", "dtype", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 19398 "GomSerializationTest.c"
}

static void
gom_serialization_test_book_stand_dimension_instance_init (GomSerializationTestBookStandDimension * self,
                                                           gpointer klass)
{
	gchar* _tmp0_;
#line 403 "GomSerializationTest.vala"
	self->priv = gom_serialization_test_book_stand_dimension_get_instance_private (self);
#line 405 "GomSerializationTest.vala"
	self->priv->_length = 1.0;
#line 407 "GomSerializationTest.vala"
	_tmp0_ = g_strdup ("x");
#line 407 "GomSerializationTest.vala"
	self->priv->_dtype = _tmp0_;
#line 19414 "GomSerializationTest.c"
}

static void
gom_serialization_test_book_stand_dimension_finalize (GObject * obj)
{
	GomSerializationTestBookStandDimension * self;
#line 403 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION, GomSerializationTestBookStandDimension);
#line 407 "GomSerializationTest.vala"
	_g_free0 (self->priv->_dtype);
#line 403 "GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_serialization_test_book_stand_dimension_parent_class)->finalize (obj);
#line 19427 "GomSerializationTest.c"
}

GType
gom_serialization_test_book_stand_dimension_get_type (void)
{
	static volatile gsize gom_serialization_test_book_stand_dimension_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_book_stand_dimension_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestBookStandDimensionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_book_stand_dimension_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestBookStandDimension), 0, (GInstanceInitFunc) gom_serialization_test_book_stand_dimension_instance_init, NULL };
		GType gom_serialization_test_book_stand_dimension_type_id;
		gom_serialization_test_book_stand_dimension_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomSerializationTestBookStandDimension", &g_define_type_info, 0);
		GomSerializationTestBookStandDimension_private_offset = g_type_add_instance_private (gom_serialization_test_book_stand_dimension_type_id, sizeof (GomSerializationTestBookStandDimensionPrivate));
		g_once_init_leave (&gom_serialization_test_book_stand_dimension_type_id__volatile, gom_serialization_test_book_stand_dimension_type_id);
	}
	return gom_serialization_test_book_stand_dimension_type_id__volatile;
}

static void
_vala_gom_serialization_test_book_stand_dimension_get_property (GObject * object,
                                                                guint property_id,
                                                                GValue * value,
                                                                GParamSpec * pspec)
{
	GomSerializationTestBookStandDimension * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION, GomSerializationTestBookStandDimension);
#line 403 "GomSerializationTest.vala"
	switch (property_id) {
#line 403 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_LENGTH_PROPERTY:
#line 403 "GomSerializationTest.vala"
		g_value_set_double (value, gom_serialization_test_book_stand_dimension_get_length (self));
#line 403 "GomSerializationTest.vala"
		break;
#line 403 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_DTYPE_PROPERTY:
#line 403 "GomSerializationTest.vala"
		g_value_set_string (value, gom_serialization_test_book_stand_dimension_get_dtype (self));
#line 403 "GomSerializationTest.vala"
		break;
#line 19466 "GomSerializationTest.c"
		default:
#line 403 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 403 "GomSerializationTest.vala"
		break;
#line 19472 "GomSerializationTest.c"
	}
}

static void
_vala_gom_serialization_test_book_stand_dimension_set_property (GObject * object,
                                                                guint property_id,
                                                                const GValue * value,
                                                                GParamSpec * pspec)
{
	GomSerializationTestBookStandDimension * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION, GomSerializationTestBookStandDimension);
#line 403 "GomSerializationTest.vala"
	switch (property_id) {
#line 403 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_LENGTH_PROPERTY:
#line 403 "GomSerializationTest.vala"
		gom_serialization_test_book_stand_dimension_set_length (self, g_value_get_double (value));
#line 403 "GomSerializationTest.vala"
		break;
#line 403 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_DTYPE_PROPERTY:
#line 403 "GomSerializationTest.vala"
		gom_serialization_test_book_stand_dimension_set_dtype (self, g_value_get_string (value));
#line 403 "GomSerializationTest.vala"
		break;
#line 19498 "GomSerializationTest.c"
		default:
#line 403 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 403 "GomSerializationTest.vala"
		break;
#line 19504 "GomSerializationTest.c"
	}
}

GomSerializationTestBookStandDimensionY*
gom_serialization_test_book_stand_dimension_y_construct (GType object_type)
{
	GomSerializationTestBookStandDimensionY * self = NULL;
#line 412 "GomSerializationTest.vala"
	self = (GomSerializationTestBookStandDimensionY*) gom_serialization_test_book_stand_dimension_construct (object_type);
#line 412 "GomSerializationTest.vala"
	return self;
#line 19516 "GomSerializationTest.c"
}

GomSerializationTestBookStandDimensionY*
gom_serialization_test_book_stand_dimension_y_new (void)
{
#line 412 "GomSerializationTest.vala"
	return gom_serialization_test_book_stand_dimension_y_construct (GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Y);
#line 19524 "GomSerializationTest.c"
}

static GObject *
gom_serialization_test_book_stand_dimension_y_constructor (GType type,
                                                           guint n_construct_properties,
                                                           GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestBookStandDimensionY * self;
#line 413 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_book_stand_dimension_y_parent_class);
#line 413 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 413 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Y, GomSerializationTestBookStandDimensionY);
#line 414 "GomSerializationTest.vala"
	gom_serialization_test_book_stand_dimension_set_dtype ((GomSerializationTestBookStandDimension*) self, "y");
#line 413 "GomSerializationTest.vala"
	return obj;
#line 19545 "GomSerializationTest.c"
}

static void
gom_serialization_test_book_stand_dimension_y_class_init (GomSerializationTestBookStandDimensionYClass * klass,
                                                          gpointer klass_data)
{
#line 412 "GomSerializationTest.vala"
	gom_serialization_test_book_stand_dimension_y_parent_class = g_type_class_peek_parent (klass);
#line 412 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_book_stand_dimension_y_constructor;
#line 19556 "GomSerializationTest.c"
}

static void
gom_serialization_test_book_stand_dimension_y_instance_init (GomSerializationTestBookStandDimensionY * self,
                                                             gpointer klass)
{
}

GType
gom_serialization_test_book_stand_dimension_y_get_type (void)
{
	static volatile gsize gom_serialization_test_book_stand_dimension_y_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_book_stand_dimension_y_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestBookStandDimensionYClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_book_stand_dimension_y_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestBookStandDimensionY), 0, (GInstanceInitFunc) gom_serialization_test_book_stand_dimension_y_instance_init, NULL };
		GType gom_serialization_test_book_stand_dimension_y_type_id;
		gom_serialization_test_book_stand_dimension_y_type_id = g_type_register_static (GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION, "GomSerializationTestBookStandDimensionY", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_book_stand_dimension_y_type_id__volatile, gom_serialization_test_book_stand_dimension_y_type_id);
	}
	return gom_serialization_test_book_stand_dimension_y_type_id__volatile;
}

GomSerializationTestBookStandDimensionZ*
gom_serialization_test_book_stand_dimension_z_construct (GType object_type)
{
	GomSerializationTestBookStandDimensionZ * self = NULL;
#line 417 "GomSerializationTest.vala"
	self = (GomSerializationTestBookStandDimensionZ*) gom_serialization_test_book_stand_dimension_construct (object_type);
#line 417 "GomSerializationTest.vala"
	return self;
#line 19586 "GomSerializationTest.c"
}

GomSerializationTestBookStandDimensionZ*
gom_serialization_test_book_stand_dimension_z_new (void)
{
#line 417 "GomSerializationTest.vala"
	return gom_serialization_test_book_stand_dimension_z_construct (GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Z);
#line 19594 "GomSerializationTest.c"
}

static GObject *
gom_serialization_test_book_stand_dimension_z_constructor (GType type,
                                                           guint n_construct_properties,
                                                           GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestBookStandDimensionZ * self;
#line 418 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_book_stand_dimension_z_parent_class);
#line 418 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 418 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Z, GomSerializationTestBookStandDimensionZ);
#line 419 "GomSerializationTest.vala"
	gom_serialization_test_book_stand_dimension_set_dtype ((GomSerializationTestBookStandDimension*) self, "z");
#line 418 "GomSerializationTest.vala"
	return obj;
#line 19615 "GomSerializationTest.c"
}

static void
gom_serialization_test_book_stand_dimension_z_class_init (GomSerializationTestBookStandDimensionZClass * klass,
                                                          gpointer klass_data)
{
#line 417 "GomSerializationTest.vala"
	gom_serialization_test_book_stand_dimension_z_parent_class = g_type_class_peek_parent (klass);
#line 417 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_book_stand_dimension_z_constructor;
#line 19626 "GomSerializationTest.c"
}

static void
gom_serialization_test_book_stand_dimension_z_instance_init (GomSerializationTestBookStandDimensionZ * self,
                                                             gpointer klass)
{
}

GType
gom_serialization_test_book_stand_dimension_z_get_type (void)
{
	static volatile gsize gom_serialization_test_book_stand_dimension_z_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_book_stand_dimension_z_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestBookStandDimensionZClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_book_stand_dimension_z_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestBookStandDimensionZ), 0, (GInstanceInitFunc) gom_serialization_test_book_stand_dimension_z_instance_init, NULL };
		GType gom_serialization_test_book_stand_dimension_z_type_id;
		gom_serialization_test_book_stand_dimension_z_type_id = g_type_register_static (GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION, "GomSerializationTestBookStandDimensionZ", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_book_stand_dimension_z_type_id__volatile, gom_serialization_test_book_stand_dimension_z_type_id);
	}
	return gom_serialization_test_book_stand_dimension_z_type_id__volatile;
}

static void
gom_serialization_test_book_stand_class_init (GomSerializationTestBookStandClass * klass,
                                              gpointer klass_data)
{
#line 343 "GomSerializationTest.vala"
	gom_serialization_test_book_stand_parent_class = g_type_class_peek_parent (klass);
#line 343 "GomSerializationTest.vala"
	g_type_class_adjust_private_offset (klass, &GomSerializationTestBookStand_private_offset);
#line 343 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_serialization_test_book_stand_get_property;
#line 343 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_serialization_test_book_stand_set_property;
#line 343 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_book_stand_constructor;
#line 343 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_serialization_test_book_stand_finalize;
#line 343 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STAND_CLASSIFICATION_PROPERTY, gom_serialization_test_book_stand_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_CLASSIFICATION_PROPERTY] = g_param_spec_string ("classification", "::Classification", "classification", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 343 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_X_PROPERTY, gom_serialization_test_book_stand_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_X_PROPERTY] = g_param_spec_object ("dimension-x", "dimension-x", "dimension-x", GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 343 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Y_PROPERTY, gom_serialization_test_book_stand_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Y_PROPERTY] = g_param_spec_object ("dimension-y", "::DimensionY", "dimension-y", GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Y, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 343 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Z_PROPERTY, gom_serialization_test_book_stand_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Z_PROPERTY] = g_param_spec_object ("dimension-z", "DimensionZ", "dimension-z", GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Z, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 343 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STAND_REGISTERS_PROPERTY, gom_serialization_test_book_stand_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_REGISTERS_PROPERTY] = g_param_spec_object ("registers", "registers", "registers", GOM_SERIALIZATION_TEST_TYPE_REGISTERS, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 343 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STAND_HASHMAP_REGISTERS_PROPERTY, gom_serialization_test_book_stand_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_HASHMAP_REGISTERS_PROPERTY] = g_param_spec_object ("hashmap-registers", "hashmap-registers", "hashmap-registers", GOM_SERIALIZATION_TEST_TYPE_HASH_REGISTERS, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 343 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STAND_HASHPAIR_REGISTERS_PROPERTY, gom_serialization_test_book_stand_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_HASHPAIR_REGISTERS_PROPERTY] = g_param_spec_object ("hashpair-registers", "hashpair-registers", "hashpair-registers", GOM_SERIALIZATION_TEST_TYPE_HASH_PAIR_REGISTERS, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 343 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STAND_HASHTHREE_REGISTERS_PROPERTY, gom_serialization_test_book_stand_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_HASHTHREE_REGISTERS_PROPERTY] = g_param_spec_object ("hashthree-registers", "hashthree-registers", "hashthree-registers", GOM_SERIALIZATION_TEST_TYPE_HASH_THREE_REGISTERS, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 343 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STAND_BOOKS_PROPERTY, gom_serialization_test_book_stand_properties[GOM_SERIALIZATION_TEST_BOOK_STAND_BOOKS_PROPERTY] = g_param_spec_object ("books", "books", "books", GOM_SERIALIZATION_TEST_TYPE_BOOKS, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 19682 "GomSerializationTest.c"
}

static void
gom_serialization_test_book_stand_instance_init (GomSerializationTestBookStand * self,
                                                 gpointer klass)
{
	gchar* _tmp0_;
#line 343 "GomSerializationTest.vala"
	self->priv = gom_serialization_test_book_stand_get_instance_private (self);
#line 344 "GomSerializationTest.vala"
	self->priv->_hashmap_registers = NULL;
#line 345 "GomSerializationTest.vala"
	self->priv->_hashpair_registers = NULL;
#line 346 "GomSerializationTest.vala"
	self->priv->_hashthree_registers = NULL;
#line 348 "GomSerializationTest.vala"
	_tmp0_ = g_strdup ("Science");
#line 348 "GomSerializationTest.vala"
	self->priv->_classification = _tmp0_;
#line 19702 "GomSerializationTest.c"
}

static void
gom_serialization_test_book_stand_finalize (GObject * obj)
{
	GomSerializationTestBookStand * self;
#line 343 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_BOOK_STAND, GomSerializationTestBookStand);
#line 344 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_hashmap_registers);
#line 345 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_hashpair_registers);
#line 346 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_hashthree_registers);
#line 348 "GomSerializationTest.vala"
	_g_free0 (self->priv->_classification);
#line 349 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_dimension_x);
#line 351 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_dimension_y);
#line 353 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_dimension_z);
#line 354 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_registers);
#line 388 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_books);
#line 378 "GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_serialization_test_book_stand_parent_class)->finalize (obj);
#line 19731 "GomSerializationTest.c"
}

GType
gom_serialization_test_book_stand_get_type (void)
{
	static volatile gsize gom_serialization_test_book_stand_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_book_stand_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestBookStandClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_book_stand_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestBookStand), 0, (GInstanceInitFunc) gom_serialization_test_book_stand_instance_init, NULL };
		GType gom_serialization_test_book_stand_type_id;
		gom_serialization_test_book_stand_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomSerializationTestBookStand", &g_define_type_info, 0);
		GomSerializationTestBookStand_private_offset = g_type_add_instance_private (gom_serialization_test_book_stand_type_id, sizeof (GomSerializationTestBookStandPrivate));
		g_once_init_leave (&gom_serialization_test_book_stand_type_id__volatile, gom_serialization_test_book_stand_type_id);
	}
	return gom_serialization_test_book_stand_type_id__volatile;
}

static void
_vala_gom_serialization_test_book_stand_get_property (GObject * object,
                                                      guint property_id,
                                                      GValue * value,
                                                      GParamSpec * pspec)
{
	GomSerializationTestBookStand * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_BOOK_STAND, GomSerializationTestBookStand);
#line 343 "GomSerializationTest.vala"
	switch (property_id) {
#line 343 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_CLASSIFICATION_PROPERTY:
#line 343 "GomSerializationTest.vala"
		g_value_set_string (value, gom_serialization_test_book_stand_get_classification (self));
#line 343 "GomSerializationTest.vala"
		break;
#line 343 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_X_PROPERTY:
#line 343 "GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_book_stand_get_dimension_x (self));
#line 343 "GomSerializationTest.vala"
		break;
#line 343 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Y_PROPERTY:
#line 343 "GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_book_stand_get_dimension_y (self));
#line 343 "GomSerializationTest.vala"
		break;
#line 343 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Z_PROPERTY:
#line 343 "GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_book_stand_get_dimension_z (self));
#line 343 "GomSerializationTest.vala"
		break;
#line 343 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_REGISTERS_PROPERTY:
#line 343 "GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_book_stand_get_registers (self));
#line 343 "GomSerializationTest.vala"
		break;
#line 343 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_HASHMAP_REGISTERS_PROPERTY:
#line 343 "GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_book_stand_get_hashmap_registers (self));
#line 343 "GomSerializationTest.vala"
		break;
#line 343 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_HASHPAIR_REGISTERS_PROPERTY:
#line 343 "GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_book_stand_get_hashpair_registers (self));
#line 343 "GomSerializationTest.vala"
		break;
#line 343 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_HASHTHREE_REGISTERS_PROPERTY:
#line 343 "GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_book_stand_get_hashthree_registers (self));
#line 343 "GomSerializationTest.vala"
		break;
#line 343 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_BOOKS_PROPERTY:
#line 343 "GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_book_stand_get_books (self));
#line 343 "GomSerializationTest.vala"
		break;
#line 19812 "GomSerializationTest.c"
		default:
#line 343 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 343 "GomSerializationTest.vala"
		break;
#line 19818 "GomSerializationTest.c"
	}
}

static void
_vala_gom_serialization_test_book_stand_set_property (GObject * object,
                                                      guint property_id,
                                                      const GValue * value,
                                                      GParamSpec * pspec)
{
	GomSerializationTestBookStand * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_BOOK_STAND, GomSerializationTestBookStand);
#line 343 "GomSerializationTest.vala"
	switch (property_id) {
#line 343 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_CLASSIFICATION_PROPERTY:
#line 343 "GomSerializationTest.vala"
		gom_serialization_test_book_stand_set_classification (self, g_value_get_string (value));
#line 343 "GomSerializationTest.vala"
		break;
#line 343 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_X_PROPERTY:
#line 343 "GomSerializationTest.vala"
		gom_serialization_test_book_stand_set_dimension_x (self, g_value_get_object (value));
#line 343 "GomSerializationTest.vala"
		break;
#line 343 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Y_PROPERTY:
#line 343 "GomSerializationTest.vala"
		gom_serialization_test_book_stand_set_dimension_y (self, g_value_get_object (value));
#line 343 "GomSerializationTest.vala"
		break;
#line 343 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Z_PROPERTY:
#line 343 "GomSerializationTest.vala"
		gom_serialization_test_book_stand_set_dimension_z (self, g_value_get_object (value));
#line 343 "GomSerializationTest.vala"
		break;
#line 343 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_REGISTERS_PROPERTY:
#line 343 "GomSerializationTest.vala"
		gom_serialization_test_book_stand_set_registers (self, g_value_get_object (value));
#line 343 "GomSerializationTest.vala"
		break;
#line 343 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_HASHMAP_REGISTERS_PROPERTY:
#line 343 "GomSerializationTest.vala"
		gom_serialization_test_book_stand_set_hashmap_registers (self, g_value_get_object (value));
#line 343 "GomSerializationTest.vala"
		break;
#line 343 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_HASHPAIR_REGISTERS_PROPERTY:
#line 343 "GomSerializationTest.vala"
		gom_serialization_test_book_stand_set_hashpair_registers (self, g_value_get_object (value));
#line 343 "GomSerializationTest.vala"
		break;
#line 343 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_HASHTHREE_REGISTERS_PROPERTY:
#line 343 "GomSerializationTest.vala"
		gom_serialization_test_book_stand_set_hashthree_registers (self, g_value_get_object (value));
#line 343 "GomSerializationTest.vala"
		break;
#line 343 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_BOOKS_PROPERTY:
#line 343 "GomSerializationTest.vala"
		gom_serialization_test_book_stand_set_books (self, g_value_get_object (value));
#line 343 "GomSerializationTest.vala"
		break;
#line 19886 "GomSerializationTest.c"
		default:
#line 343 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 343 "GomSerializationTest.vala"
		break;
#line 19892 "GomSerializationTest.c"
	}
}

GomSerializationTestRegisters*
gom_serialization_test_registers_construct (GType object_type)
{
	GomSerializationTestRegisters * self = NULL;
#line 424 "GomSerializationTest.vala"
	self = (GomSerializationTestRegisters*) gxml_gom_array_list_construct (object_type);
#line 424 "GomSerializationTest.vala"
	return self;
#line 19904 "GomSerializationTest.c"
}

GomSerializationTestRegisters*
gom_serialization_test_registers_new (void)
{
#line 424 "GomSerializationTest.vala"
	return gom_serialization_test_registers_construct (GOM_SERIALIZATION_TEST_TYPE_REGISTERS);
#line 19912 "GomSerializationTest.c"
}

static GObject *
gom_serialization_test_registers_constructor (GType type,
                                              guint n_construct_properties,
                                              GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestRegisters * self;
	GError* _inner_error0_ = NULL;
#line 425 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_registers_parent_class);
#line 425 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 425 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_REGISTERS, GomSerializationTestRegisters);
#line 19930 "GomSerializationTest.c"
	{
#line 426 "GomSerializationTest.vala"
		gxml_collection_initialize ((GXmlCollection*) self, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, &_inner_error0_);
#line 426 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 19936 "GomSerializationTest.c"
			goto __catch207_g_error;
		}
	}
	goto __finally207;
	__catch207_g_error:
	{
#line 426 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 426 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 427 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 19949 "GomSerializationTest.c"
	}
	__finally207:
#line 426 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 426 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 426 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 19958 "GomSerializationTest.c"
	}
#line 425 "GomSerializationTest.vala"
	return obj;
#line 19962 "GomSerializationTest.c"
}

static void
gom_serialization_test_registers_class_init (GomSerializationTestRegistersClass * klass,
                                             gpointer klass_data)
{
#line 424 "GomSerializationTest.vala"
	gom_serialization_test_registers_parent_class = g_type_class_peek_parent (klass);
#line 424 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_registers_constructor;
#line 19973 "GomSerializationTest.c"
}

static void
gom_serialization_test_registers_instance_init (GomSerializationTestRegisters * self,
                                                gpointer klass)
{
}

GType
gom_serialization_test_registers_get_type (void)
{
	static volatile gsize gom_serialization_test_registers_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_registers_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestRegistersClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_registers_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestRegisters), 0, (GInstanceInitFunc) gom_serialization_test_registers_instance_init, NULL };
		GType gom_serialization_test_registers_type_id;
		gom_serialization_test_registers_type_id = g_type_register_static (GXML_TYPE_GOM_ARRAY_LIST, "GomSerializationTestRegisters", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_registers_type_id__volatile, gom_serialization_test_registers_type_id);
	}
	return gom_serialization_test_registers_type_id__volatile;
}

GomSerializationTestHashRegisters*
gom_serialization_test_hash_registers_construct (GType object_type)
{
	GomSerializationTestHashRegisters * self = NULL;
#line 430 "GomSerializationTest.vala"
	self = (GomSerializationTestHashRegisters*) gxml_gom_hash_map_construct (object_type);
#line 430 "GomSerializationTest.vala"
	return self;
#line 20003 "GomSerializationTest.c"
}

GomSerializationTestHashRegisters*
gom_serialization_test_hash_registers_new (void)
{
#line 430 "GomSerializationTest.vala"
	return gom_serialization_test_hash_registers_construct (GOM_SERIALIZATION_TEST_TYPE_HASH_REGISTERS);
#line 20011 "GomSerializationTest.c"
}

static GObject *
gom_serialization_test_hash_registers_constructor (GType type,
                                                   guint n_construct_properties,
                                                   GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestHashRegisters * self;
	GError* _inner_error0_ = NULL;
#line 431 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_hash_registers_parent_class);
#line 431 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 431 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_HASH_REGISTERS, GomSerializationTestHashRegisters);
#line 20029 "GomSerializationTest.c"
	{
#line 432 "GomSerializationTest.vala"
		gxml_collection_initialize ((GXmlCollection*) self, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, &_inner_error0_);
#line 432 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 20035 "GomSerializationTest.c"
			goto __catch208_g_error;
		}
	}
	goto __finally208;
	__catch208_g_error:
	{
#line 432 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 432 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 433 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 20048 "GomSerializationTest.c"
	}
	__finally208:
#line 432 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 432 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 432 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 20057 "GomSerializationTest.c"
	}
#line 431 "GomSerializationTest.vala"
	return obj;
#line 20061 "GomSerializationTest.c"
}

static void
gom_serialization_test_hash_registers_class_init (GomSerializationTestHashRegistersClass * klass,
                                                  gpointer klass_data)
{
#line 430 "GomSerializationTest.vala"
	gom_serialization_test_hash_registers_parent_class = g_type_class_peek_parent (klass);
#line 430 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_hash_registers_constructor;
#line 20072 "GomSerializationTest.c"
}

static void
gom_serialization_test_hash_registers_instance_init (GomSerializationTestHashRegisters * self,
                                                     gpointer klass)
{
}

GType
gom_serialization_test_hash_registers_get_type (void)
{
	static volatile gsize gom_serialization_test_hash_registers_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_hash_registers_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestHashRegistersClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_hash_registers_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestHashRegisters), 0, (GInstanceInitFunc) gom_serialization_test_hash_registers_instance_init, NULL };
		GType gom_serialization_test_hash_registers_type_id;
		gom_serialization_test_hash_registers_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_MAP, "GomSerializationTestHashRegisters", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_hash_registers_type_id__volatile, gom_serialization_test_hash_registers_type_id);
	}
	return gom_serialization_test_hash_registers_type_id__volatile;
}

GomSerializationTestHashPairRegisters*
gom_serialization_test_hash_pair_registers_construct (GType object_type)
{
	GomSerializationTestHashPairRegisters * self = NULL;
#line 436 "GomSerializationTest.vala"
	self = (GomSerializationTestHashPairRegisters*) gxml_gom_hash_paired_map_construct (object_type);
#line 436 "GomSerializationTest.vala"
	return self;
#line 20102 "GomSerializationTest.c"
}

GomSerializationTestHashPairRegisters*
gom_serialization_test_hash_pair_registers_new (void)
{
#line 436 "GomSerializationTest.vala"
	return gom_serialization_test_hash_pair_registers_construct (GOM_SERIALIZATION_TEST_TYPE_HASH_PAIR_REGISTERS);
#line 20110 "GomSerializationTest.c"
}

static GObject *
gom_serialization_test_hash_pair_registers_constructor (GType type,
                                                        guint n_construct_properties,
                                                        GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestHashPairRegisters * self;
	GError* _inner_error0_ = NULL;
#line 437 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_hash_pair_registers_parent_class);
#line 437 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 437 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_HASH_PAIR_REGISTERS, GomSerializationTestHashPairRegisters);
#line 20128 "GomSerializationTest.c"
	{
#line 438 "GomSerializationTest.vala"
		gxml_collection_initialize ((GXmlCollection*) self, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, &_inner_error0_);
#line 438 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 20134 "GomSerializationTest.c"
			goto __catch209_g_error;
		}
	}
	goto __finally209;
	__catch209_g_error:
	{
#line 438 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 438 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 439 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 20147 "GomSerializationTest.c"
	}
	__finally209:
#line 438 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 438 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 438 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 20156 "GomSerializationTest.c"
	}
#line 437 "GomSerializationTest.vala"
	return obj;
#line 20160 "GomSerializationTest.c"
}

static void
gom_serialization_test_hash_pair_registers_class_init (GomSerializationTestHashPairRegistersClass * klass,
                                                       gpointer klass_data)
{
#line 436 "GomSerializationTest.vala"
	gom_serialization_test_hash_pair_registers_parent_class = g_type_class_peek_parent (klass);
#line 436 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_hash_pair_registers_constructor;
#line 20171 "GomSerializationTest.c"
}

static void
gom_serialization_test_hash_pair_registers_instance_init (GomSerializationTestHashPairRegisters * self,
                                                          gpointer klass)
{
}

GType
gom_serialization_test_hash_pair_registers_get_type (void)
{
	static volatile gsize gom_serialization_test_hash_pair_registers_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_hash_pair_registers_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestHashPairRegistersClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_hash_pair_registers_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestHashPairRegisters), 0, (GInstanceInitFunc) gom_serialization_test_hash_pair_registers_instance_init, NULL };
		GType gom_serialization_test_hash_pair_registers_type_id;
		gom_serialization_test_hash_pair_registers_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_PAIRED_MAP, "GomSerializationTestHashPairRegisters", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_hash_pair_registers_type_id__volatile, gom_serialization_test_hash_pair_registers_type_id);
	}
	return gom_serialization_test_hash_pair_registers_type_id__volatile;
}

GomSerializationTestHashThreeRegisters*
gom_serialization_test_hash_three_registers_construct (GType object_type)
{
	GomSerializationTestHashThreeRegisters * self = NULL;
#line 442 "GomSerializationTest.vala"
	self = (GomSerializationTestHashThreeRegisters*) gxml_gom_hash_three_map_construct (object_type);
#line 442 "GomSerializationTest.vala"
	return self;
#line 20201 "GomSerializationTest.c"
}

GomSerializationTestHashThreeRegisters*
gom_serialization_test_hash_three_registers_new (void)
{
#line 442 "GomSerializationTest.vala"
	return gom_serialization_test_hash_three_registers_construct (GOM_SERIALIZATION_TEST_TYPE_HASH_THREE_REGISTERS);
#line 20209 "GomSerializationTest.c"
}

static GObject *
gom_serialization_test_hash_three_registers_constructor (GType type,
                                                         guint n_construct_properties,
                                                         GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestHashThreeRegisters * self;
	GError* _inner_error0_ = NULL;
#line 443 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_hash_three_registers_parent_class);
#line 443 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 443 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_HASH_THREE_REGISTERS, GomSerializationTestHashThreeRegisters);
#line 20227 "GomSerializationTest.c"
	{
#line 444 "GomSerializationTest.vala"
		gxml_collection_initialize ((GXmlCollection*) self, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, &_inner_error0_);
#line 444 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 20233 "GomSerializationTest.c"
			goto __catch210_g_error;
		}
	}
	goto __finally210;
	__catch210_g_error:
	{
#line 444 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 444 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 445 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 20246 "GomSerializationTest.c"
	}
	__finally210:
#line 444 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 444 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 444 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 20255 "GomSerializationTest.c"
	}
#line 443 "GomSerializationTest.vala"
	return obj;
#line 20259 "GomSerializationTest.c"
}

static void
gom_serialization_test_hash_three_registers_class_init (GomSerializationTestHashThreeRegistersClass * klass,
                                                        gpointer klass_data)
{
#line 442 "GomSerializationTest.vala"
	gom_serialization_test_hash_three_registers_parent_class = g_type_class_peek_parent (klass);
#line 442 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_hash_three_registers_constructor;
#line 20270 "GomSerializationTest.c"
}

static void
gom_serialization_test_hash_three_registers_instance_init (GomSerializationTestHashThreeRegisters * self,
                                                           gpointer klass)
{
}

GType
gom_serialization_test_hash_three_registers_get_type (void)
{
	static volatile gsize gom_serialization_test_hash_three_registers_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_hash_three_registers_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestHashThreeRegistersClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_hash_three_registers_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestHashThreeRegisters), 0, (GInstanceInitFunc) gom_serialization_test_hash_three_registers_instance_init, NULL };
		GType gom_serialization_test_hash_three_registers_type_id;
		gom_serialization_test_hash_three_registers_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_THREE_MAP, "GomSerializationTestHashThreeRegisters", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_hash_three_registers_type_id__volatile, gom_serialization_test_hash_three_registers_type_id);
	}
	return gom_serialization_test_hash_three_registers_type_id__volatile;
}

GomSerializationTestBooks*
gom_serialization_test_books_construct (GType object_type)
{
	GomSerializationTestBooks * self = NULL;
#line 448 "GomSerializationTest.vala"
	self = (GomSerializationTestBooks*) gxml_gom_hash_map_construct (object_type);
#line 448 "GomSerializationTest.vala"
	return self;
#line 20300 "GomSerializationTest.c"
}

GomSerializationTestBooks*
gom_serialization_test_books_new (void)
{
#line 448 "GomSerializationTest.vala"
	return gom_serialization_test_books_construct (GOM_SERIALIZATION_TEST_TYPE_BOOKS);
#line 20308 "GomSerializationTest.c"
}

static GObject *
gom_serialization_test_books_constructor (GType type,
                                          guint n_construct_properties,
                                          GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestBooks * self;
	GError* _inner_error0_ = NULL;
#line 449 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_books_parent_class);
#line 449 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 449 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_BOOKS, GomSerializationTestBooks);
#line 20326 "GomSerializationTest.c"
	{
#line 450 "GomSerializationTest.vala"
		gxml_gom_hash_map_initialize_with_key ((GXmlGomHashMap*) self, GOM_SERIALIZATION_TEST_TYPE_BOOK, "Name", &_inner_error0_);
#line 450 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 20332 "GomSerializationTest.c"
			goto __catch211_g_error;
		}
	}
	goto __finally211;
	__catch211_g_error:
	{
#line 450 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 450 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 451 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 20345 "GomSerializationTest.c"
	}
	__finally211:
#line 450 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 450 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 450 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 20354 "GomSerializationTest.c"
	}
#line 449 "GomSerializationTest.vala"
	return obj;
#line 20358 "GomSerializationTest.c"
}

static void
gom_serialization_test_books_class_init (GomSerializationTestBooksClass * klass,
                                         gpointer klass_data)
{
#line 448 "GomSerializationTest.vala"
	gom_serialization_test_books_parent_class = g_type_class_peek_parent (klass);
#line 448 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_books_constructor;
#line 20369 "GomSerializationTest.c"
}

static void
gom_serialization_test_books_instance_init (GomSerializationTestBooks * self,
                                            gpointer klass)
{
}

GType
gom_serialization_test_books_get_type (void)
{
	static volatile gsize gom_serialization_test_books_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_books_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestBooksClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_books_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestBooks), 0, (GInstanceInitFunc) gom_serialization_test_books_instance_init, NULL };
		GType gom_serialization_test_books_type_id;
		gom_serialization_test_books_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_MAP, "GomSerializationTestBooks", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_books_type_id__volatile, gom_serialization_test_books_type_id);
	}
	return gom_serialization_test_books_type_id__volatile;
}

static inline gpointer
gom_serialization_test_book_store_get_instance_private (GomSerializationTestBookStore* self)
{
	return G_STRUCT_MEMBER_P (self, GomSerializationTestBookStore_private_offset);
}

gchar*
gom_serialization_test_book_store_to_string (GomSerializationTestBookStore* self)
{
	gchar* result = NULL;
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_;
	gchar* s = NULL;
	gchar* _tmp1_;
	GError* _inner_error0_ = NULL;
#line 461 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 462 "GomSerializationTest.vala"
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
#line 462 "GomSerializationTest.vala"
	parser = _tmp0_;
#line 463 "GomSerializationTest.vala"
	_tmp1_ = g_strdup ("");
#line 463 "GomSerializationTest.vala"
	s = _tmp1_;
#line 20416 "GomSerializationTest.c"
	{
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_;
		gchar* _tmp4_;
#line 465 "GomSerializationTest.vala"
		_tmp3_ = gxml_parser_write_string ((GXmlParser*) parser, &_inner_error0_);
#line 465 "GomSerializationTest.vala"
		_tmp2_ = _tmp3_;
#line 465 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 20427 "GomSerializationTest.c"
			goto __catch212_g_error;
		}
#line 465 "GomSerializationTest.vala"
		_tmp4_ = _tmp2_;
#line 465 "GomSerializationTest.vala"
		_tmp2_ = NULL;
#line 465 "GomSerializationTest.vala"
		_g_free0 (s);
#line 465 "GomSerializationTest.vala"
		s = _tmp4_;
#line 464 "GomSerializationTest.vala"
		_g_free0 (_tmp2_);
#line 20440 "GomSerializationTest.c"
	}
	goto __finally212;
	__catch212_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
#line 464 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 464 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 467 "GomSerializationTest.vala"
		_tmp5_ = e->message;
#line 467 "GomSerializationTest.vala"
		_tmp6_ = g_strconcat ("Error: ", _tmp5_, NULL);
#line 467 "GomSerializationTest.vala"
		_tmp7_ = _tmp6_;
#line 467 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:467: %s", _tmp7_);
#line 467 "GomSerializationTest.vala"
		_g_free0 (_tmp7_);
#line 468 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 464 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 20467 "GomSerializationTest.c"
	}
	__finally212:
#line 464 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 464 "GomSerializationTest.vala"
		_g_free0 (s);
#line 464 "GomSerializationTest.vala"
		_g_object_unref0 (parser);
#line 464 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 464 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 464 "GomSerializationTest.vala"
		return NULL;
#line 20482 "GomSerializationTest.c"
	}
#line 470 "GomSerializationTest.vala"
	result = s;
#line 470 "GomSerializationTest.vala"
	_g_object_unref0 (parser);
#line 470 "GomSerializationTest.vala"
	return result;
#line 20490 "GomSerializationTest.c"
}

GomSerializationTestBookStore*
gom_serialization_test_book_store_construct (GType object_type)
{
	GomSerializationTestBookStore * self = NULL;
#line 454 "GomSerializationTest.vala"
	self = (GomSerializationTestBookStore*) gxml_gom_element_construct (object_type);
#line 454 "GomSerializationTest.vala"
	return self;
#line 20501 "GomSerializationTest.c"
}

GomSerializationTestBookStore*
gom_serialization_test_book_store_new (void)
{
#line 454 "GomSerializationTest.vala"
	return gom_serialization_test_book_store_construct (GOM_SERIALIZATION_TEST_TYPE_BOOK_STORE);
#line 20509 "GomSerializationTest.c"
}

const gchar*
gom_serialization_test_book_store_get_name (GomSerializationTestBookStore* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 456 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 456 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_name;
#line 456 "GomSerializationTest.vala"
	result = _tmp0_;
#line 456 "GomSerializationTest.vala"
	return result;
#line 20525 "GomSerializationTest.c"
}

void
gom_serialization_test_book_store_set_name (GomSerializationTestBookStore* self,
                                            const gchar* value)
{
#line 456 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 456 "GomSerializationTest.vala"
	if (g_strcmp0 (value, gom_serialization_test_book_store_get_name (self)) != 0) {
#line 20536 "GomSerializationTest.c"
		gchar* _tmp0_;
#line 456 "GomSerializationTest.vala"
		_tmp0_ = g_strdup (value);
#line 456 "GomSerializationTest.vala"
		_g_free0 (self->priv->_name);
#line 456 "GomSerializationTest.vala"
		self->priv->_name = _tmp0_;
#line 456 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_book_store_properties[GOM_SERIALIZATION_TEST_BOOK_STORE_NAME_PROPERTY]);
#line 20546 "GomSerializationTest.c"
	}
}

GomSerializationTestBooks*
gom_serialization_test_book_store_get_books (GomSerializationTestBookStore* self)
{
	GomSerializationTestBooks* result;
	GomSerializationTestBooks* _tmp0_;
#line 457 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 457 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_books;
#line 457 "GomSerializationTest.vala"
	result = _tmp0_;
#line 457 "GomSerializationTest.vala"
	return result;
#line 20563 "GomSerializationTest.c"
}

void
gom_serialization_test_book_store_set_books (GomSerializationTestBookStore* self,
                                             GomSerializationTestBooks* value)
{
#line 457 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 457 "GomSerializationTest.vala"
	if (gom_serialization_test_book_store_get_books (self) != value) {
#line 20574 "GomSerializationTest.c"
		GomSerializationTestBooks* _tmp0_;
#line 457 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 457 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_books);
#line 457 "GomSerializationTest.vala"
		self->priv->_books = _tmp0_;
#line 457 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_book_store_properties[GOM_SERIALIZATION_TEST_BOOK_STORE_BOOKS_PROPERTY]);
#line 20584 "GomSerializationTest.c"
	}
}

static GObject *
gom_serialization_test_book_store_constructor (GType type,
                                               guint n_construct_properties,
                                               GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestBookStore * self;
	GError* _inner_error0_ = NULL;
#line 458 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_book_store_parent_class);
#line 458 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 458 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_BOOK_STORE, GomSerializationTestBookStore);
#line 20603 "GomSerializationTest.c"
	{
#line 459 "GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "BookStore");
#line 20607 "GomSerializationTest.c"
	}
	goto __finally213;
	__catch213_g_error:
	{
#line 459 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 459 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 459 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 20618 "GomSerializationTest.c"
	}
	__finally213:
#line 459 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 459 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 459 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 20627 "GomSerializationTest.c"
	}
#line 458 "GomSerializationTest.vala"
	return obj;
#line 20631 "GomSerializationTest.c"
}

static void
gom_serialization_test_book_store_class_init (GomSerializationTestBookStoreClass * klass,
                                              gpointer klass_data)
{
#line 454 "GomSerializationTest.vala"
	gom_serialization_test_book_store_parent_class = g_type_class_peek_parent (klass);
#line 454 "GomSerializationTest.vala"
	g_type_class_adjust_private_offset (klass, &GomSerializationTestBookStore_private_offset);
#line 454 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_serialization_test_book_store_get_property;
#line 454 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_serialization_test_book_store_set_property;
#line 454 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_book_store_constructor;
#line 454 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_serialization_test_book_store_finalize;
#line 454 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STORE_NAME_PROPERTY, gom_serialization_test_book_store_properties[GOM_SERIALIZATION_TEST_BOOK_STORE_NAME_PROPERTY] = g_param_spec_string ("name", "::Name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 454 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STORE_BOOKS_PROPERTY, gom_serialization_test_book_store_properties[GOM_SERIALIZATION_TEST_BOOK_STORE_BOOKS_PROPERTY] = g_param_spec_object ("books", "books", "books", GOM_SERIALIZATION_TEST_TYPE_BOOKS, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 20654 "GomSerializationTest.c"
}

static void
gom_serialization_test_book_store_instance_init (GomSerializationTestBookStore * self,
                                                 gpointer klass)
{
#line 454 "GomSerializationTest.vala"
	self->priv = gom_serialization_test_book_store_get_instance_private (self);
#line 20663 "GomSerializationTest.c"
}

static void
gom_serialization_test_book_store_finalize (GObject * obj)
{
	GomSerializationTestBookStore * self;
#line 454 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_BOOK_STORE, GomSerializationTestBookStore);
#line 456 "GomSerializationTest.vala"
	_g_free0 (self->priv->_name);
#line 457 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_books);
#line 454 "GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_serialization_test_book_store_parent_class)->finalize (obj);
#line 20678 "GomSerializationTest.c"
}

GType
gom_serialization_test_book_store_get_type (void)
{
	static volatile gsize gom_serialization_test_book_store_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_book_store_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestBookStoreClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_book_store_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestBookStore), 0, (GInstanceInitFunc) gom_serialization_test_book_store_instance_init, NULL };
		GType gom_serialization_test_book_store_type_id;
		gom_serialization_test_book_store_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomSerializationTestBookStore", &g_define_type_info, 0);
		GomSerializationTestBookStore_private_offset = g_type_add_instance_private (gom_serialization_test_book_store_type_id, sizeof (GomSerializationTestBookStorePrivate));
		g_once_init_leave (&gom_serialization_test_book_store_type_id__volatile, gom_serialization_test_book_store_type_id);
	}
	return gom_serialization_test_book_store_type_id__volatile;
}

static void
_vala_gom_serialization_test_book_store_get_property (GObject * object,
                                                      guint property_id,
                                                      GValue * value,
                                                      GParamSpec * pspec)
{
	GomSerializationTestBookStore * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_BOOK_STORE, GomSerializationTestBookStore);
#line 454 "GomSerializationTest.vala"
	switch (property_id) {
#line 454 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STORE_NAME_PROPERTY:
#line 454 "GomSerializationTest.vala"
		g_value_set_string (value, gom_serialization_test_book_store_get_name (self));
#line 454 "GomSerializationTest.vala"
		break;
#line 454 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STORE_BOOKS_PROPERTY:
#line 454 "GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_book_store_get_books (self));
#line 454 "GomSerializationTest.vala"
		break;
#line 20717 "GomSerializationTest.c"
		default:
#line 454 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 454 "GomSerializationTest.vala"
		break;
#line 20723 "GomSerializationTest.c"
	}
}

static void
_vala_gom_serialization_test_book_store_set_property (GObject * object,
                                                      guint property_id,
                                                      const GValue * value,
                                                      GParamSpec * pspec)
{
	GomSerializationTestBookStore * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_BOOK_STORE, GomSerializationTestBookStore);
#line 454 "GomSerializationTest.vala"
	switch (property_id) {
#line 454 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STORE_NAME_PROPERTY:
#line 454 "GomSerializationTest.vala"
		gom_serialization_test_book_store_set_name (self, g_value_get_string (value));
#line 454 "GomSerializationTest.vala"
		break;
#line 454 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STORE_BOOKS_PROPERTY:
#line 454 "GomSerializationTest.vala"
		gom_serialization_test_book_store_set_books (self, g_value_get_object (value));
#line 454 "GomSerializationTest.vala"
		break;
#line 20749 "GomSerializationTest.c"
		default:
#line 454 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 454 "GomSerializationTest.vala"
		break;
#line 20755 "GomSerializationTest.c"
	}
}

static inline gpointer
gom_serialization_test_motor_get_instance_private (GomSerializationTestMotor* self)
{
	return G_STRUCT_MEMBER_P (self, GomSerializationTestMotor_private_offset);
}

GType
gom_serialization_test_motor_tension_type_enum_get_type (void)
{
	static volatile gsize gom_serialization_test_motor_tension_type_enum_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_motor_tension_type_enum_type_id__volatile)) {
		static const GEnumValue values[] = {{GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_ENUM_AC, "GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_ENUM_AC", "ac"}, {GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_ENUM_DC, "GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_ENUM_DC", "dc"}, {0, NULL, NULL}};
		GType gom_serialization_test_motor_tension_type_enum_type_id;
		gom_serialization_test_motor_tension_type_enum_type_id = g_enum_register_static ("GomSerializationTestMotorTensionTypeEnum", values);
		g_once_init_leave (&gom_serialization_test_motor_tension_type_enum_type_id__volatile, gom_serialization_test_motor_tension_type_enum_type_id);
	}
	return gom_serialization_test_motor_tension_type_enum_type_id__volatile;
}

gchar*
gom_serialization_test_motor_to_string (GomSerializationTestMotor* self)
{
	gchar* result = NULL;
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_;
	gchar* s = NULL;
	gchar* _tmp1_;
	GError* _inner_error0_ = NULL;
#line 487 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 488 "GomSerializationTest.vala"
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
#line 488 "GomSerializationTest.vala"
	parser = _tmp0_;
#line 489 "GomSerializationTest.vala"
	_tmp1_ = g_strdup ("");
#line 489 "GomSerializationTest.vala"
	s = _tmp1_;
#line 20797 "GomSerializationTest.c"
	{
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_;
		gchar* _tmp4_;
#line 491 "GomSerializationTest.vala"
		_tmp3_ = gxml_parser_write_string ((GXmlParser*) parser, &_inner_error0_);
#line 491 "GomSerializationTest.vala"
		_tmp2_ = _tmp3_;
#line 491 "GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 20808 "GomSerializationTest.c"
			goto __catch214_g_error;
		}
#line 491 "GomSerializationTest.vala"
		_tmp4_ = _tmp2_;
#line 491 "GomSerializationTest.vala"
		_tmp2_ = NULL;
#line 491 "GomSerializationTest.vala"
		_g_free0 (s);
#line 491 "GomSerializationTest.vala"
		s = _tmp4_;
#line 490 "GomSerializationTest.vala"
		_g_free0 (_tmp2_);
#line 20821 "GomSerializationTest.c"
	}
	goto __finally214;
	__catch214_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
#line 490 "GomSerializationTest.vala"
		e = _inner_error0_;
#line 490 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 493 "GomSerializationTest.vala"
		_tmp5_ = e->message;
#line 493 "GomSerializationTest.vala"
		_tmp6_ = g_strconcat ("Error: ", _tmp5_, NULL);
#line 493 "GomSerializationTest.vala"
		_tmp7_ = _tmp6_;
#line 493 "GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:493: %s", _tmp7_);
#line 493 "GomSerializationTest.vala"
		_g_free0 (_tmp7_);
#line 494 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 490 "GomSerializationTest.vala"
		_g_error_free0 (e);
#line 20848 "GomSerializationTest.c"
	}
	__finally214:
#line 490 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 490 "GomSerializationTest.vala"
		_g_free0 (s);
#line 490 "GomSerializationTest.vala"
		_g_object_unref0 (parser);
#line 490 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 490 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 490 "GomSerializationTest.vala"
		return NULL;
#line 20863 "GomSerializationTest.c"
	}
#line 496 "GomSerializationTest.vala"
	result = s;
#line 496 "GomSerializationTest.vala"
	_g_object_unref0 (parser);
#line 496 "GomSerializationTest.vala"
	return result;
#line 20871 "GomSerializationTest.c"
}

GomSerializationTestMotor*
gom_serialization_test_motor_construct (GType object_type)
{
	GomSerializationTestMotor * self = NULL;
#line 473 "GomSerializationTest.vala"
	self = (GomSerializationTestMotor*) gxml_gom_element_construct (object_type);
#line 473 "GomSerializationTest.vala"
	return self;
#line 20882 "GomSerializationTest.c"
}

GomSerializationTestMotor*
gom_serialization_test_motor_new (void)
{
#line 473 "GomSerializationTest.vala"
	return gom_serialization_test_motor_construct (GOM_SERIALIZATION_TEST_TYPE_MOTOR);
#line 20890 "GomSerializationTest.c"
}

GomSerializationTestMotorOn*
gom_serialization_test_motor_get_is_on (GomSerializationTestMotor* self)
{
	GomSerializationTestMotorOn* result;
	GomSerializationTestMotorOn* _tmp0_;
#line 475 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 475 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_is_on;
#line 475 "GomSerializationTest.vala"
	result = _tmp0_;
#line 475 "GomSerializationTest.vala"
	return result;
#line 20906 "GomSerializationTest.c"
}

void
gom_serialization_test_motor_set_is_on (GomSerializationTestMotor* self,
                                        GomSerializationTestMotorOn* value)
{
#line 475 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 475 "GomSerializationTest.vala"
	if (gom_serialization_test_motor_get_is_on (self) != value) {
#line 20917 "GomSerializationTest.c"
		GomSerializationTestMotorOn* _tmp0_;
#line 475 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 475 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_is_on);
#line 475 "GomSerializationTest.vala"
		self->priv->_is_on = _tmp0_;
#line 475 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_motor_properties[GOM_SERIALIZATION_TEST_MOTOR_IS_ON_PROPERTY]);
#line 20927 "GomSerializationTest.c"
	}
}

GomSerializationTestMotorTorque*
gom_serialization_test_motor_get_torque (GomSerializationTestMotor* self)
{
	GomSerializationTestMotorTorque* result;
	GomSerializationTestMotorTorque* _tmp0_;
#line 477 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 477 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_torque;
#line 477 "GomSerializationTest.vala"
	result = _tmp0_;
#line 477 "GomSerializationTest.vala"
	return result;
#line 20944 "GomSerializationTest.c"
}

void
gom_serialization_test_motor_set_torque (GomSerializationTestMotor* self,
                                         GomSerializationTestMotorTorque* value)
{
#line 477 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 477 "GomSerializationTest.vala"
	if (gom_serialization_test_motor_get_torque (self) != value) {
#line 20955 "GomSerializationTest.c"
		GomSerializationTestMotorTorque* _tmp0_;
#line 477 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 477 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_torque);
#line 477 "GomSerializationTest.vala"
		self->priv->_torque = _tmp0_;
#line 477 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_motor_properties[GOM_SERIALIZATION_TEST_MOTOR_TORQUE_PROPERTY]);
#line 20965 "GomSerializationTest.c"
	}
}

GomSerializationTestMotorSpeed*
gom_serialization_test_motor_get_speed (GomSerializationTestMotor* self)
{
	GomSerializationTestMotorSpeed* result;
	GomSerializationTestMotorSpeed* _tmp0_;
#line 479 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 479 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_speed;
#line 479 "GomSerializationTest.vala"
	result = _tmp0_;
#line 479 "GomSerializationTest.vala"
	return result;
#line 20982 "GomSerializationTest.c"
}

void
gom_serialization_test_motor_set_speed (GomSerializationTestMotor* self,
                                        GomSerializationTestMotorSpeed* value)
{
#line 479 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 479 "GomSerializationTest.vala"
	if (gom_serialization_test_motor_get_speed (self) != value) {
#line 20993 "GomSerializationTest.c"
		GomSerializationTestMotorSpeed* _tmp0_;
#line 479 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 479 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_speed);
#line 479 "GomSerializationTest.vala"
		self->priv->_speed = _tmp0_;
#line 479 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_motor_properties[GOM_SERIALIZATION_TEST_MOTOR_SPEED_PROPERTY]);
#line 21003 "GomSerializationTest.c"
	}
}

GomSerializationTestMotorTensionType*
gom_serialization_test_motor_get_tension_type (GomSerializationTestMotor* self)
{
	GomSerializationTestMotorTensionType* result;
	GomSerializationTestMotorTensionType* _tmp0_;
#line 481 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 481 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_tension_type;
#line 481 "GomSerializationTest.vala"
	result = _tmp0_;
#line 481 "GomSerializationTest.vala"
	return result;
#line 21020 "GomSerializationTest.c"
}

void
gom_serialization_test_motor_set_tension_type (GomSerializationTestMotor* self,
                                               GomSerializationTestMotorTensionType* value)
{
#line 481 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 481 "GomSerializationTest.vala"
	if (gom_serialization_test_motor_get_tension_type (self) != value) {
#line 21031 "GomSerializationTest.c"
		GomSerializationTestMotorTensionType* _tmp0_;
#line 481 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 481 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_tension_type);
#line 481 "GomSerializationTest.vala"
		self->priv->_tension_type = _tmp0_;
#line 481 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_motor_properties[GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_PROPERTY]);
#line 21041 "GomSerializationTest.c"
	}
}

GomSerializationTestMotorTension*
gom_serialization_test_motor_get_tension (GomSerializationTestMotor* self)
{
	GomSerializationTestMotorTension* result;
	GomSerializationTestMotorTension* _tmp0_;
#line 483 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 483 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_tension;
#line 483 "GomSerializationTest.vala"
	result = _tmp0_;
#line 483 "GomSerializationTest.vala"
	return result;
#line 21058 "GomSerializationTest.c"
}

void
gom_serialization_test_motor_set_tension (GomSerializationTestMotor* self,
                                          GomSerializationTestMotorTension* value)
{
#line 483 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 483 "GomSerializationTest.vala"
	if (gom_serialization_test_motor_get_tension (self) != value) {
#line 21069 "GomSerializationTest.c"
		GomSerializationTestMotorTension* _tmp0_;
#line 483 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 483 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_tension);
#line 483 "GomSerializationTest.vala"
		self->priv->_tension = _tmp0_;
#line 483 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_motor_properties[GOM_SERIALIZATION_TEST_MOTOR_TENSION_PROPERTY]);
#line 21079 "GomSerializationTest.c"
	}
}

GomSerializationTestMotorModel*
gom_serialization_test_motor_get_model (GomSerializationTestMotor* self)
{
	GomSerializationTestMotorModel* result;
	GomSerializationTestMotorModel* _tmp0_;
#line 485 "GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 485 "GomSerializationTest.vala"
	_tmp0_ = self->priv->_model;
#line 485 "GomSerializationTest.vala"
	result = _tmp0_;
#line 485 "GomSerializationTest.vala"
	return result;
#line 21096 "GomSerializationTest.c"
}

void
gom_serialization_test_motor_set_model (GomSerializationTestMotor* self,
                                        GomSerializationTestMotorModel* value)
{
#line 485 "GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 485 "GomSerializationTest.vala"
	if (gom_serialization_test_motor_get_model (self) != value) {
#line 21107 "GomSerializationTest.c"
		GomSerializationTestMotorModel* _tmp0_;
#line 485 "GomSerializationTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 485 "GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_model);
#line 485 "GomSerializationTest.vala"
		self->priv->_model = _tmp0_;
#line 485 "GomSerializationTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_serialization_test_motor_properties[GOM_SERIALIZATION_TEST_MOTOR_MODEL_PROPERTY]);
#line 21117 "GomSerializationTest.c"
	}
}

static GObject *
gom_serialization_test_motor_constructor (GType type,
                                          guint n_construct_properties,
                                          GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestMotor * self;
	GError* _inner_error0_ = NULL;
#line 486 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_motor_parent_class);
#line 486 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 486 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_MOTOR, GomSerializationTestMotor);
#line 21136 "GomSerializationTest.c"
	{
#line 486 "GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Motor");
#line 21140 "GomSerializationTest.c"
	}
	goto __finally215;
	__catch215_g_error:
	{
#line 486 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 486 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 486 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 21151 "GomSerializationTest.c"
	}
	__finally215:
#line 486 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 486 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 486 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 21160 "GomSerializationTest.c"
	}
#line 486 "GomSerializationTest.vala"
	return obj;
#line 21164 "GomSerializationTest.c"
}

GomSerializationTestMotorOn*
gom_serialization_test_motor_on_construct (GType object_type)
{
	GomSerializationTestMotorOn * self = NULL;
#line 502 "GomSerializationTest.vala"
	self = (GomSerializationTestMotorOn*) gxml_gom_boolean_construct (object_type);
#line 502 "GomSerializationTest.vala"
	return self;
#line 21175 "GomSerializationTest.c"
}

GomSerializationTestMotorOn*
gom_serialization_test_motor_on_new (void)
{
#line 502 "GomSerializationTest.vala"
	return gom_serialization_test_motor_on_construct (GOM_SERIALIZATION_TEST_MOTOR_TYPE_ON);
#line 21183 "GomSerializationTest.c"
}

static void
gom_serialization_test_motor_on_class_init (GomSerializationTestMotorOnClass * klass,
                                            gpointer klass_data)
{
#line 502 "GomSerializationTest.vala"
	gom_serialization_test_motor_on_parent_class = g_type_class_peek_parent (klass);
#line 21192 "GomSerializationTest.c"
}

static void
gom_serialization_test_motor_on_instance_init (GomSerializationTestMotorOn * self,
                                               gpointer klass)
{
}

GType
gom_serialization_test_motor_on_get_type (void)
{
	static volatile gsize gom_serialization_test_motor_on_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_motor_on_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestMotorOnClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_motor_on_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestMotorOn), 0, (GInstanceInitFunc) gom_serialization_test_motor_on_instance_init, NULL };
		GType gom_serialization_test_motor_on_type_id;
		gom_serialization_test_motor_on_type_id = g_type_register_static (GXML_TYPE_GOM_BOOLEAN, "GomSerializationTestMotorOn", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_motor_on_type_id__volatile, gom_serialization_test_motor_on_type_id);
	}
	return gom_serialization_test_motor_on_type_id__volatile;
}

GomSerializationTestMotorTorque*
gom_serialization_test_motor_torque_construct (GType object_type)
{
	GomSerializationTestMotorTorque * self = NULL;
#line 503 "GomSerializationTest.vala"
	self = (GomSerializationTestMotorTorque*) gxml_gom_double_construct (object_type);
#line 503 "GomSerializationTest.vala"
	return self;
#line 21222 "GomSerializationTest.c"
}

GomSerializationTestMotorTorque*
gom_serialization_test_motor_torque_new (void)
{
#line 503 "GomSerializationTest.vala"
	return gom_serialization_test_motor_torque_construct (GOM_SERIALIZATION_TEST_MOTOR_TYPE_TORQUE);
#line 21230 "GomSerializationTest.c"
}

static void
gom_serialization_test_motor_torque_class_init (GomSerializationTestMotorTorqueClass * klass,
                                                gpointer klass_data)
{
#line 503 "GomSerializationTest.vala"
	gom_serialization_test_motor_torque_parent_class = g_type_class_peek_parent (klass);
#line 21239 "GomSerializationTest.c"
}

static void
gom_serialization_test_motor_torque_instance_init (GomSerializationTestMotorTorque * self,
                                                   gpointer klass)
{
}

GType
gom_serialization_test_motor_torque_get_type (void)
{
	static volatile gsize gom_serialization_test_motor_torque_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_motor_torque_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestMotorTorqueClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_motor_torque_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestMotorTorque), 0, (GInstanceInitFunc) gom_serialization_test_motor_torque_instance_init, NULL };
		GType gom_serialization_test_motor_torque_type_id;
		gom_serialization_test_motor_torque_type_id = g_type_register_static (GXML_TYPE_GOM_DOUBLE, "GomSerializationTestMotorTorque", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_motor_torque_type_id__volatile, gom_serialization_test_motor_torque_type_id);
	}
	return gom_serialization_test_motor_torque_type_id__volatile;
}

GomSerializationTestMotorSpeed*
gom_serialization_test_motor_speed_construct (GType object_type)
{
	GomSerializationTestMotorSpeed * self = NULL;
#line 504 "GomSerializationTest.vala"
	self = (GomSerializationTestMotorSpeed*) gxml_gom_float_construct (object_type);
#line 504 "GomSerializationTest.vala"
	return self;
#line 21269 "GomSerializationTest.c"
}

GomSerializationTestMotorSpeed*
gom_serialization_test_motor_speed_new (void)
{
#line 504 "GomSerializationTest.vala"
	return gom_serialization_test_motor_speed_construct (GOM_SERIALIZATION_TEST_MOTOR_TYPE_SPEED);
#line 21277 "GomSerializationTest.c"
}

static void
gom_serialization_test_motor_speed_class_init (GomSerializationTestMotorSpeedClass * klass,
                                               gpointer klass_data)
{
#line 504 "GomSerializationTest.vala"
	gom_serialization_test_motor_speed_parent_class = g_type_class_peek_parent (klass);
#line 21286 "GomSerializationTest.c"
}

static void
gom_serialization_test_motor_speed_instance_init (GomSerializationTestMotorSpeed * self,
                                                  gpointer klass)
{
}

GType
gom_serialization_test_motor_speed_get_type (void)
{
	static volatile gsize gom_serialization_test_motor_speed_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_motor_speed_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestMotorSpeedClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_motor_speed_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestMotorSpeed), 0, (GInstanceInitFunc) gom_serialization_test_motor_speed_instance_init, NULL };
		GType gom_serialization_test_motor_speed_type_id;
		gom_serialization_test_motor_speed_type_id = g_type_register_static (GXML_TYPE_GOM_FLOAT, "GomSerializationTestMotorSpeed", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_motor_speed_type_id__volatile, gom_serialization_test_motor_speed_type_id);
	}
	return gom_serialization_test_motor_speed_type_id__volatile;
}

GomSerializationTestMotorTensionType*
gom_serialization_test_motor_tension_type_construct (GType object_type)
{
	GomSerializationTestMotorTensionType * self = NULL;
#line 505 "GomSerializationTest.vala"
	self = (GomSerializationTestMotorTensionType*) gxml_gom_enum_construct (object_type);
#line 505 "GomSerializationTest.vala"
	return self;
#line 21316 "GomSerializationTest.c"
}

GomSerializationTestMotorTensionType*
gom_serialization_test_motor_tension_type_new (void)
{
#line 505 "GomSerializationTest.vala"
	return gom_serialization_test_motor_tension_type_construct (GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION_TYPE);
#line 21324 "GomSerializationTest.c"
}

static GObject *
gom_serialization_test_motor_tension_type_constructor (GType type,
                                                       guint n_construct_properties,
                                                       GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestMotorTensionType * self;
	GError* _inner_error0_ = NULL;
#line 506 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_motor_tension_type_parent_class);
#line 506 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 506 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION_TYPE, GomSerializationTestMotorTensionType);
#line 21342 "GomSerializationTest.c"
	{
#line 507 "GomSerializationTest.vala"
		gxml_gom_enum_initialize_enum ((GXmlGomEnum*) self, GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION_TYPE_ENUM);
#line 21346 "GomSerializationTest.c"
	}
	goto __finally216;
	__catch216_g_error:
	{
#line 507 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 507 "GomSerializationTest.vala"
		_inner_error0_ = NULL;
#line 508 "GomSerializationTest.vala"
		g_assert_not_reached ();
#line 21357 "GomSerializationTest.c"
	}
	__finally216:
#line 507 "GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 507 "GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 507 "GomSerializationTest.vala"
		g_clear_error (&_inner_error0_);
#line 21366 "GomSerializationTest.c"
	}
#line 506 "GomSerializationTest.vala"
	return obj;
#line 21370 "GomSerializationTest.c"
}

static void
gom_serialization_test_motor_tension_type_class_init (GomSerializationTestMotorTensionTypeClass * klass,
                                                      gpointer klass_data)
{
#line 505 "GomSerializationTest.vala"
	gom_serialization_test_motor_tension_type_parent_class = g_type_class_peek_parent (klass);
#line 505 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_motor_tension_type_constructor;
#line 21381 "GomSerializationTest.c"
}

static void
gom_serialization_test_motor_tension_type_instance_init (GomSerializationTestMotorTensionType * self,
                                                         gpointer klass)
{
}

GType
gom_serialization_test_motor_tension_type_get_type (void)
{
	static volatile gsize gom_serialization_test_motor_tension_type_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_motor_tension_type_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestMotorTensionTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_motor_tension_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestMotorTensionType), 0, (GInstanceInitFunc) gom_serialization_test_motor_tension_type_instance_init, NULL };
		GType gom_serialization_test_motor_tension_type_type_id;
		gom_serialization_test_motor_tension_type_type_id = g_type_register_static (GXML_TYPE_GOM_ENUM, "GomSerializationTestMotorTensionType", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_motor_tension_type_type_id__volatile, gom_serialization_test_motor_tension_type_type_id);
	}
	return gom_serialization_test_motor_tension_type_type_id__volatile;
}

GomSerializationTestMotorTension*
gom_serialization_test_motor_tension_construct (GType object_type)
{
	GomSerializationTestMotorTension * self = NULL;
#line 511 "GomSerializationTest.vala"
	self = (GomSerializationTestMotorTension*) gxml_gom_int_construct (object_type);
#line 511 "GomSerializationTest.vala"
	return self;
#line 21411 "GomSerializationTest.c"
}

GomSerializationTestMotorTension*
gom_serialization_test_motor_tension_new (void)
{
#line 511 "GomSerializationTest.vala"
	return gom_serialization_test_motor_tension_construct (GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION);
#line 21419 "GomSerializationTest.c"
}

static void
gom_serialization_test_motor_tension_class_init (GomSerializationTestMotorTensionClass * klass,
                                                 gpointer klass_data)
{
#line 511 "GomSerializationTest.vala"
	gom_serialization_test_motor_tension_parent_class = g_type_class_peek_parent (klass);
#line 21428 "GomSerializationTest.c"
}

static void
gom_serialization_test_motor_tension_instance_init (GomSerializationTestMotorTension * self,
                                                    gpointer klass)
{
}

GType
gom_serialization_test_motor_tension_get_type (void)
{
	static volatile gsize gom_serialization_test_motor_tension_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_motor_tension_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestMotorTensionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_motor_tension_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestMotorTension), 0, (GInstanceInitFunc) gom_serialization_test_motor_tension_instance_init, NULL };
		GType gom_serialization_test_motor_tension_type_id;
		gom_serialization_test_motor_tension_type_id = g_type_register_static (GXML_TYPE_GOM_INT, "GomSerializationTestMotorTension", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_motor_tension_type_id__volatile, gom_serialization_test_motor_tension_type_id);
	}
	return gom_serialization_test_motor_tension_type_id__volatile;
}

GomSerializationTestMotorModel*
gom_serialization_test_motor_model_construct (GType object_type)
{
	GomSerializationTestMotorModel * self = NULL;
#line 512 "GomSerializationTest.vala"
	self = (GomSerializationTestMotorModel*) gxml_gom_array_string_construct (object_type);
#line 512 "GomSerializationTest.vala"
	return self;
#line 21458 "GomSerializationTest.c"
}

GomSerializationTestMotorModel*
gom_serialization_test_motor_model_new (void)
{
#line 512 "GomSerializationTest.vala"
	return gom_serialization_test_motor_model_construct (GOM_SERIALIZATION_TEST_MOTOR_TYPE_MODEL);
#line 21466 "GomSerializationTest.c"
}

static GObject *
gom_serialization_test_motor_model_constructor (GType type,
                                                guint n_construct_properties,
                                                GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestMotorModel * self;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar** _tmp2_;
#line 513 "GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_motor_model_parent_class);
#line 513 "GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 513 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_MOTOR_TYPE_MODEL, GomSerializationTestMotorModel);
#line 514 "GomSerializationTest.vala"
	_tmp0_ = g_strdup ("MODEL1");
#line 514 "GomSerializationTest.vala"
	_tmp1_ = g_strdup ("MODEL2");
#line 514 "GomSerializationTest.vala"
	_tmp2_ = g_new0 (gchar*, 2 + 1);
#line 514 "GomSerializationTest.vala"
	_tmp2_[0] = _tmp0_;
#line 514 "GomSerializationTest.vala"
	_tmp2_[1] = _tmp1_;
#line 514 "GomSerializationTest.vala"
	gxml_gom_array_string_initialize_strings ((GXmlGomArrayString*) self, _tmp2_, (gint) 2);
#line 513 "GomSerializationTest.vala"
	return obj;
#line 21500 "GomSerializationTest.c"
}

static void
gom_serialization_test_motor_model_class_init (GomSerializationTestMotorModelClass * klass,
                                               gpointer klass_data)
{
#line 512 "GomSerializationTest.vala"
	gom_serialization_test_motor_model_parent_class = g_type_class_peek_parent (klass);
#line 512 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_motor_model_constructor;
#line 21511 "GomSerializationTest.c"
}

static void
gom_serialization_test_motor_model_instance_init (GomSerializationTestMotorModel * self,
                                                  gpointer klass)
{
}

GType
gom_serialization_test_motor_model_get_type (void)
{
	static volatile gsize gom_serialization_test_motor_model_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_motor_model_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestMotorModelClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_motor_model_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestMotorModel), 0, (GInstanceInitFunc) gom_serialization_test_motor_model_instance_init, NULL };
		GType gom_serialization_test_motor_model_type_id;
		gom_serialization_test_motor_model_type_id = g_type_register_static (GXML_TYPE_GOM_ARRAY_STRING, "GomSerializationTestMotorModel", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_motor_model_type_id__volatile, gom_serialization_test_motor_model_type_id);
	}
	return gom_serialization_test_motor_model_type_id__volatile;
}

static void
gom_serialization_test_motor_class_init (GomSerializationTestMotorClass * klass,
                                         gpointer klass_data)
{
#line 473 "GomSerializationTest.vala"
	gom_serialization_test_motor_parent_class = g_type_class_peek_parent (klass);
#line 473 "GomSerializationTest.vala"
	g_type_class_adjust_private_offset (klass, &GomSerializationTestMotor_private_offset);
#line 473 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_serialization_test_motor_get_property;
#line 473 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_serialization_test_motor_set_property;
#line 473 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_motor_constructor;
#line 473 "GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_serialization_test_motor_finalize;
#line 473 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_MOTOR_IS_ON_PROPERTY, gom_serialization_test_motor_properties[GOM_SERIALIZATION_TEST_MOTOR_IS_ON_PROPERTY] = g_param_spec_object ("is-on", "::On", "is-on", GOM_SERIALIZATION_TEST_MOTOR_TYPE_ON, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 473 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_MOTOR_TORQUE_PROPERTY, gom_serialization_test_motor_properties[GOM_SERIALIZATION_TEST_MOTOR_TORQUE_PROPERTY] = g_param_spec_object ("torque", "::Torque", "torque", GOM_SERIALIZATION_TEST_MOTOR_TYPE_TORQUE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 473 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_MOTOR_SPEED_PROPERTY, gom_serialization_test_motor_properties[GOM_SERIALIZATION_TEST_MOTOR_SPEED_PROPERTY] = g_param_spec_object ("speed", "::Speed", "speed", GOM_SERIALIZATION_TEST_MOTOR_TYPE_SPEED, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 473 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_PROPERTY, gom_serialization_test_motor_properties[GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_PROPERTY] = g_param_spec_object ("tension-type", "::TensionType", "tension-type", GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION_TYPE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 473 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_MOTOR_TENSION_PROPERTY, gom_serialization_test_motor_properties[GOM_SERIALIZATION_TEST_MOTOR_TENSION_PROPERTY] = g_param_spec_object ("tension", "::Tension", "tension", GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 473 "GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_MOTOR_MODEL_PROPERTY, gom_serialization_test_motor_properties[GOM_SERIALIZATION_TEST_MOTOR_MODEL_PROPERTY] = g_param_spec_object ("model", "::Model", "model", GOM_SERIALIZATION_TEST_MOTOR_TYPE_MODEL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 21561 "GomSerializationTest.c"
}

static void
gom_serialization_test_motor_instance_init (GomSerializationTestMotor * self,
                                            gpointer klass)
{
#line 473 "GomSerializationTest.vala"
	self->priv = gom_serialization_test_motor_get_instance_private (self);
#line 21570 "GomSerializationTest.c"
}

static void
gom_serialization_test_motor_finalize (GObject * obj)
{
	GomSerializationTestMotor * self;
#line 473 "GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_MOTOR, GomSerializationTestMotor);
#line 475 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_is_on);
#line 477 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_torque);
#line 479 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_speed);
#line 481 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_tension_type);
#line 483 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_tension);
#line 485 "GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_model);
#line 473 "GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_serialization_test_motor_parent_class)->finalize (obj);
#line 21593 "GomSerializationTest.c"
}

GType
gom_serialization_test_motor_get_type (void)
{
	static volatile gsize gom_serialization_test_motor_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_motor_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestMotorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_motor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestMotor), 0, (GInstanceInitFunc) gom_serialization_test_motor_instance_init, NULL };
		GType gom_serialization_test_motor_type_id;
		gom_serialization_test_motor_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomSerializationTestMotor", &g_define_type_info, 0);
		GomSerializationTestMotor_private_offset = g_type_add_instance_private (gom_serialization_test_motor_type_id, sizeof (GomSerializationTestMotorPrivate));
		g_once_init_leave (&gom_serialization_test_motor_type_id__volatile, gom_serialization_test_motor_type_id);
	}
	return gom_serialization_test_motor_type_id__volatile;
}

static void
_vala_gom_serialization_test_motor_get_property (GObject * object,
                                                 guint property_id,
                                                 GValue * value,
                                                 GParamSpec * pspec)
{
	GomSerializationTestMotor * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_MOTOR, GomSerializationTestMotor);
#line 473 "GomSerializationTest.vala"
	switch (property_id) {
#line 473 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_IS_ON_PROPERTY:
#line 473 "GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_motor_get_is_on (self));
#line 473 "GomSerializationTest.vala"
		break;
#line 473 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_TORQUE_PROPERTY:
#line 473 "GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_motor_get_torque (self));
#line 473 "GomSerializationTest.vala"
		break;
#line 473 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_SPEED_PROPERTY:
#line 473 "GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_motor_get_speed (self));
#line 473 "GomSerializationTest.vala"
		break;
#line 473 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_PROPERTY:
#line 473 "GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_motor_get_tension_type (self));
#line 473 "GomSerializationTest.vala"
		break;
#line 473 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_TENSION_PROPERTY:
#line 473 "GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_motor_get_tension (self));
#line 473 "GomSerializationTest.vala"
		break;
#line 473 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_MODEL_PROPERTY:
#line 473 "GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_motor_get_model (self));
#line 473 "GomSerializationTest.vala"
		break;
#line 21656 "GomSerializationTest.c"
		default:
#line 473 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 473 "GomSerializationTest.vala"
		break;
#line 21662 "GomSerializationTest.c"
	}
}

static void
_vala_gom_serialization_test_motor_set_property (GObject * object,
                                                 guint property_id,
                                                 const GValue * value,
                                                 GParamSpec * pspec)
{
	GomSerializationTestMotor * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_MOTOR, GomSerializationTestMotor);
#line 473 "GomSerializationTest.vala"
	switch (property_id) {
#line 473 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_IS_ON_PROPERTY:
#line 473 "GomSerializationTest.vala"
		gom_serialization_test_motor_set_is_on (self, g_value_get_object (value));
#line 473 "GomSerializationTest.vala"
		break;
#line 473 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_TORQUE_PROPERTY:
#line 473 "GomSerializationTest.vala"
		gom_serialization_test_motor_set_torque (self, g_value_get_object (value));
#line 473 "GomSerializationTest.vala"
		break;
#line 473 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_SPEED_PROPERTY:
#line 473 "GomSerializationTest.vala"
		gom_serialization_test_motor_set_speed (self, g_value_get_object (value));
#line 473 "GomSerializationTest.vala"
		break;
#line 473 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_PROPERTY:
#line 473 "GomSerializationTest.vala"
		gom_serialization_test_motor_set_tension_type (self, g_value_get_object (value));
#line 473 "GomSerializationTest.vala"
		break;
#line 473 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_TENSION_PROPERTY:
#line 473 "GomSerializationTest.vala"
		gom_serialization_test_motor_set_tension (self, g_value_get_object (value));
#line 473 "GomSerializationTest.vala"
		break;
#line 473 "GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_MODEL_PROPERTY:
#line 473 "GomSerializationTest.vala"
		gom_serialization_test_motor_set_model (self, g_value_get_object (value));
#line 473 "GomSerializationTest.vala"
		break;
#line 21712 "GomSerializationTest.c"
		default:
#line 473 "GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 473 "GomSerializationTest.vala"
		break;
#line 21718 "GomSerializationTest.c"
	}
}

static void
gom_serialization_test_class_init (GomSerializationTestClass * klass,
                                   gpointer klass_data)
{
#line 218 "GomSerializationTest.vala"
	gom_serialization_test_parent_class = g_type_class_peek_parent (klass);
#line 21728 "GomSerializationTest.c"
}

static void
gom_serialization_test_instance_init (GomSerializationTest * self,
                                      gpointer klass)
{
}

GType
gom_serialization_test_get_type (void)
{
	static volatile gsize gom_serialization_test_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTest), 0, (GInstanceInitFunc) gom_serialization_test_instance_init, NULL };
		GType gom_serialization_test_type_id;
		gom_serialization_test_type_id = g_type_register_static (TYPE_GXML_TEST, "GomSerializationTest", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_type_id__volatile, gom_serialization_test_type_id);
	}
	return gom_serialization_test_type_id__volatile;
}

