/* CssSelectorTest.c generated by valac 0.44.3, the Vala compiler
 * generated from CssSelectorTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* Notation.vala
 *
 * Copyright (C) 2017  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib-object.h>
#include <glib.h>
#include <gxml/gxml.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_CSS_SELECTOR_TEST (css_selector_test_get_type ())
#define CSS_SELECTOR_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CSS_SELECTOR_TEST, CssSelectorTest))
#define CSS_SELECTOR_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CSS_SELECTOR_TEST, CssSelectorTestClass))
#define IS_CSS_SELECTOR_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CSS_SELECTOR_TEST))
#define IS_CSS_SELECTOR_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CSS_SELECTOR_TEST))
#define CSS_SELECTOR_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CSS_SELECTOR_TEST, CssSelectorTestClass))

typedef struct _CssSelectorTest CssSelectorTest;
typedef struct _CssSelectorTestClass CssSelectorTestClass;
typedef struct _CssSelectorTestPrivate CssSelectorTestPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _CssSelectorTest {
	GXmlTest parent_instance;
	CssSelectorTestPrivate * priv;
};

struct _CssSelectorTestClass {
	GXmlTestClass parent_class;
};

static gpointer css_selector_test_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType css_selector_test_get_type (void) G_GNUC_CONST;
void css_selector_test_add_tests (void);
static void __lambda145_ (void);
static void ___lambda145__gtest_func (void);
static void __lambda146_ (void);
static void ___lambda146__gtest_func (void);
static void __lambda147_ (void);
static void ___lambda147__gtest_func (void);
static void __lambda148_ (void);
static void ___lambda148__gtest_func (void);
static void __lambda149_ (void);
static void ___lambda149__gtest_func (void);
static void __lambda150_ (void);
static void ___lambda150__gtest_func (void);
static void __lambda151_ (void);
static void ___lambda151__gtest_func (void);
static void __lambda152_ (void);
static void ___lambda152__gtest_func (void);
static void __lambda153_ (void);
static void ___lambda153__gtest_func (void);
static void __lambda154_ (void);
static void ___lambda154__gtest_func (void);
static void __lambda155_ (void);
static void ___lambda155__gtest_func (void);
static void __lambda156_ (void);
static void ___lambda156__gtest_func (void);
static void __lambda157_ (void);
static void ___lambda157__gtest_func (void);
static void __lambda158_ (void);
static void ___lambda158__gtest_func (void);
static void __lambda159_ (void);
static void ___lambda159__gtest_func (void);
static void __lambda160_ (void);
static void ___lambda160__gtest_func (void);
static void __lambda161_ (void);
static void ___lambda161__gtest_func (void);
static void __lambda162_ (void);
static void ___lambda162__gtest_func (void);
static void __lambda163_ (void);
static void ___lambda163__gtest_func (void);
CssSelectorTest* css_selector_test_new (void);
CssSelectorTest* css_selector_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);

static void
__lambda145_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelector* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelector* _tmp11_;
		GXmlCssSelector* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp15_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlGomDocument* _tmp18_;
		GXmlDomElement* _tmp19_;
		GXmlDomNode* _tmp20_;
		GXmlDomNode* _tmp21_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp22_;
		GXmlDomElement* _tmp23_;
		GXmlDomElement* _tmp24_;
		GXmlDomElement* _tmp25_;
		GXmlDomNode* _tmp26_;
		GXmlDomNode* _tmp27_;
		gboolean _tmp28_ = FALSE;
		GXmlCssSelectorParser* _tmp29_;
		GXmlDomElement* _tmp30_;
		gboolean _tmp31_ = FALSE;
		GXmlCssSelectorParser* _tmp32_;
		GXmlDomElement* _tmp33_;
#line 29 "CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 29 "CssSelectorTest.vala"
		cp = _tmp0_;
#line 30 "CssSelectorTest.vala"
		_tmp1_ = cp;
#line 30 "CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "*", &_inner_error0_);
#line 30 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 30 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 199 "CssSelectorTest.c"
			goto __catch0_g_error;
		}
#line 31 "CssSelectorTest.vala"
		_tmp2_ = cp;
#line 31 "CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 31 "CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 31 "CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 31 "CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 31 "CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 1, "cp.selectors.size == 1");
#line 32 "CssSelectorTest.vala"
		_tmp7_ = cp;
#line 32 "CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 32 "CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 32 "CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 32 "CssSelectorTest.vala"
		s = (GXmlCssSelector*) _tmp10_;
#line 33 "CssSelectorTest.vala"
		_tmp11_ = s;
#line 33 "CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 34 "CssSelectorTest.vala"
		_tmp12_ = s;
#line 34 "CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_get_selector_type (_tmp12_);
#line 34 "CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 34 "CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ALL, "s.selector_type == CssSelectorType.ALL");
#line 35 "CssSelectorTest.vala"
		_tmp15_ = gxml_gom_document_new ();
#line 35 "CssSelectorTest.vala"
		d = _tmp15_;
#line 36 "CssSelectorTest.vala"
		_tmp16_ = d;
#line 36 "CssSelectorTest.vala"
		_tmp17_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp16_, "root", &_inner_error0_);
#line 36 "CssSelectorTest.vala"
		r = _tmp17_;
#line 36 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 36 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 36 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 36 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 254 "CssSelectorTest.c"
			goto __catch0_g_error;
		}
#line 37 "CssSelectorTest.vala"
		_tmp18_ = d;
#line 37 "CssSelectorTest.vala"
		_tmp19_ = r;
#line 37 "CssSelectorTest.vala"
		_tmp20_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp18_, (GXmlDomNode*) _tmp19_, &_inner_error0_);
#line 37 "CssSelectorTest.vala"
		_tmp21_ = _tmp20_;
#line 37 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp21_);
#line 37 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 37 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 37 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 37 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 37 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 277 "CssSelectorTest.c"
			goto __catch0_g_error;
		}
#line 38 "CssSelectorTest.vala"
		_tmp22_ = d;
#line 38 "CssSelectorTest.vala"
		_tmp23_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp22_, "child", &_inner_error0_);
#line 38 "CssSelectorTest.vala"
		c1 = _tmp23_;
#line 38 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 38 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 38 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 38 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 38 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 296 "CssSelectorTest.c"
			goto __catch0_g_error;
		}
#line 39 "CssSelectorTest.vala"
		_tmp24_ = r;
#line 39 "CssSelectorTest.vala"
		_tmp25_ = c1;
#line 39 "CssSelectorTest.vala"
		_tmp26_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp24_, (GXmlDomNode*) _tmp25_, &_inner_error0_);
#line 39 "CssSelectorTest.vala"
		_tmp27_ = _tmp26_;
#line 39 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp27_);
#line 39 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 39 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 39 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 39 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 39 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 39 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 321 "CssSelectorTest.c"
			goto __catch0_g_error;
		}
#line 40 "CssSelectorTest.vala"
		_tmp29_ = cp;
#line 40 "CssSelectorTest.vala"
		_tmp30_ = r;
#line 40 "CssSelectorTest.vala"
		_tmp28_ = gxml_css_selector_parser_match (_tmp29_, _tmp30_, &_inner_error0_);
#line 40 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 40 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 40 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 40 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 40 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 40 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 342 "CssSelectorTest.c"
			goto __catch0_g_error;
		}
#line 40 "CssSelectorTest.vala"
		_vala_assert (_tmp28_, "cp.match (r)");
#line 41 "CssSelectorTest.vala"
		_tmp32_ = cp;
#line 41 "CssSelectorTest.vala"
		_tmp33_ = c1;
#line 41 "CssSelectorTest.vala"
		_tmp31_ = gxml_css_selector_parser_match (_tmp32_, _tmp33_, &_inner_error0_);
#line 41 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 41 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 41 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 41 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 41 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 41 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 365 "CssSelectorTest.c"
			goto __catch0_g_error;
		}
#line 41 "CssSelectorTest.vala"
		_vala_assert (_tmp31_, "cp.match (c1)");
#line 28 "CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 28 "CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 28 "CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 28 "CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 28 "CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 380 "CssSelectorTest.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp34_;
		const gchar* _tmp35_;
		gchar* _tmp36_;
		gchar* _tmp37_;
#line 28 "CssSelectorTest.vala"
		e = _inner_error0_;
#line 28 "CssSelectorTest.vala"
		_inner_error0_ = NULL;
#line 43 "CssSelectorTest.vala"
		_tmp34_ = e;
#line 43 "CssSelectorTest.vala"
		_tmp35_ = _tmp34_->message;
#line 43 "CssSelectorTest.vala"
		_tmp36_ = g_strconcat ("ERROR: ", _tmp35_, NULL);
#line 43 "CssSelectorTest.vala"
		_tmp37_ = _tmp36_;
#line 43 "CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:43: %s", _tmp37_);
#line 43 "CssSelectorTest.vala"
		_g_free0 (_tmp37_);
#line 28 "CssSelectorTest.vala"
		_g_error_free0 (e);
#line 408 "CssSelectorTest.c"
	}
	__finally0:
#line 28 "CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 28 "CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 28 "CssSelectorTest.vala"
		g_clear_error (&_inner_error0_);
#line 28 "CssSelectorTest.vala"
		return;
#line 419 "CssSelectorTest.c"
	}
}

static void
___lambda145__gtest_func (void)
{
#line 27 "CssSelectorTest.vala"
	__lambda145_ ();
#line 428 "CssSelectorTest.c"
}

static void
__lambda146_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelector* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelector* _tmp11_;
		GXmlCssSelector* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp15_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlGomDocument* _tmp18_;
		GXmlDomElement* _tmp19_;
		GXmlDomNode* _tmp20_;
		GXmlDomNode* _tmp21_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp22_;
		GXmlDomElement* _tmp23_;
		GXmlDomElement* _tmp24_;
		GXmlDomElement* _tmp25_;
		GXmlDomNode* _tmp26_;
		GXmlDomNode* _tmp27_;
		gboolean _tmp28_ = FALSE;
		GXmlCssSelectorParser* _tmp29_;
		GXmlDomElement* _tmp30_;
		gboolean _tmp31_ = FALSE;
		GXmlCssSelectorParser* _tmp32_;
		GXmlDomElement* _tmp33_;
#line 48 "CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 48 "CssSelectorTest.vala"
		cp = _tmp0_;
#line 49 "CssSelectorTest.vala"
		_tmp1_ = cp;
#line 49 "CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "child", &_inner_error0_);
#line 49 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 49 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 487 "CssSelectorTest.c"
			goto __catch1_g_error;
		}
#line 50 "CssSelectorTest.vala"
		_tmp2_ = cp;
#line 50 "CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 50 "CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 50 "CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 50 "CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 50 "CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 1, "cp.selectors.size == 1");
#line 51 "CssSelectorTest.vala"
		_tmp7_ = cp;
#line 51 "CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 51 "CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 51 "CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 51 "CssSelectorTest.vala"
		s = (GXmlCssSelector*) _tmp10_;
#line 52 "CssSelectorTest.vala"
		_tmp11_ = s;
#line 52 "CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 53 "CssSelectorTest.vala"
		_tmp12_ = s;
#line 53 "CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_get_selector_type (_tmp12_);
#line 53 "CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 53 "CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 54 "CssSelectorTest.vala"
		_tmp15_ = gxml_gom_document_new ();
#line 54 "CssSelectorTest.vala"
		d = _tmp15_;
#line 55 "CssSelectorTest.vala"
		_tmp16_ = d;
#line 55 "CssSelectorTest.vala"
		_tmp17_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp16_, "root", &_inner_error0_);
#line 55 "CssSelectorTest.vala"
		r = _tmp17_;
#line 55 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 55 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 55 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 55 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 542 "CssSelectorTest.c"
			goto __catch1_g_error;
		}
#line 56 "CssSelectorTest.vala"
		_tmp18_ = d;
#line 56 "CssSelectorTest.vala"
		_tmp19_ = r;
#line 56 "CssSelectorTest.vala"
		_tmp20_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp18_, (GXmlDomNode*) _tmp19_, &_inner_error0_);
#line 56 "CssSelectorTest.vala"
		_tmp21_ = _tmp20_;
#line 56 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp21_);
#line 56 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 56 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 56 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 56 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 56 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 565 "CssSelectorTest.c"
			goto __catch1_g_error;
		}
#line 57 "CssSelectorTest.vala"
		_tmp22_ = d;
#line 57 "CssSelectorTest.vala"
		_tmp23_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp22_, "child", &_inner_error0_);
#line 57 "CssSelectorTest.vala"
		c1 = _tmp23_;
#line 57 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 57 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 57 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 57 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 57 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 584 "CssSelectorTest.c"
			goto __catch1_g_error;
		}
#line 58 "CssSelectorTest.vala"
		_tmp24_ = r;
#line 58 "CssSelectorTest.vala"
		_tmp25_ = c1;
#line 58 "CssSelectorTest.vala"
		_tmp26_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp24_, (GXmlDomNode*) _tmp25_, &_inner_error0_);
#line 58 "CssSelectorTest.vala"
		_tmp27_ = _tmp26_;
#line 58 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp27_);
#line 58 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 58 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 58 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 58 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 58 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 58 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 609 "CssSelectorTest.c"
			goto __catch1_g_error;
		}
#line 59 "CssSelectorTest.vala"
		_tmp29_ = cp;
#line 59 "CssSelectorTest.vala"
		_tmp30_ = r;
#line 59 "CssSelectorTest.vala"
		_tmp28_ = gxml_css_selector_parser_match (_tmp29_, _tmp30_, &_inner_error0_);
#line 59 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 59 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 59 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 59 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 59 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 59 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 630 "CssSelectorTest.c"
			goto __catch1_g_error;
		}
#line 59 "CssSelectorTest.vala"
		_vala_assert (!_tmp28_, "!cp.match (r)");
#line 60 "CssSelectorTest.vala"
		_tmp32_ = cp;
#line 60 "CssSelectorTest.vala"
		_tmp33_ = c1;
#line 60 "CssSelectorTest.vala"
		_tmp31_ = gxml_css_selector_parser_match (_tmp32_, _tmp33_, &_inner_error0_);
#line 60 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 60 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 60 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 60 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 60 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 60 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 653 "CssSelectorTest.c"
			goto __catch1_g_error;
		}
#line 60 "CssSelectorTest.vala"
		_vala_assert (_tmp31_, "cp.match (c1)");
#line 47 "CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 47 "CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 47 "CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 47 "CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 47 "CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 668 "CssSelectorTest.c"
	}
	goto __finally1;
	__catch1_g_error:
	{
		GError* e = NULL;
		GError* _tmp34_;
		const gchar* _tmp35_;
		gchar* _tmp36_;
		gchar* _tmp37_;
#line 47 "CssSelectorTest.vala"
		e = _inner_error0_;
#line 47 "CssSelectorTest.vala"
		_inner_error0_ = NULL;
#line 62 "CssSelectorTest.vala"
		_tmp34_ = e;
#line 62 "CssSelectorTest.vala"
		_tmp35_ = _tmp34_->message;
#line 62 "CssSelectorTest.vala"
		_tmp36_ = g_strconcat ("ERROR: ", _tmp35_, NULL);
#line 62 "CssSelectorTest.vala"
		_tmp37_ = _tmp36_;
#line 62 "CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:62: %s", _tmp37_);
#line 62 "CssSelectorTest.vala"
		_g_free0 (_tmp37_);
#line 47 "CssSelectorTest.vala"
		_g_error_free0 (e);
#line 696 "CssSelectorTest.c"
	}
	__finally1:
#line 47 "CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 47 "CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 47 "CssSelectorTest.vala"
		g_clear_error (&_inner_error0_);
#line 47 "CssSelectorTest.vala"
		return;
#line 707 "CssSelectorTest.c"
	}
}

static void
___lambda146__gtest_func (void)
{
#line 46 "CssSelectorTest.vala"
	__lambda146_ ();
#line 716 "CssSelectorTest.c"
}

static void
__lambda147_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelector* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelector* _tmp11_;
		GXmlCssSelector* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelector* _tmp15_;
		GXmlCssCombiner _tmp16_;
		GXmlCssCombiner _tmp17_;
		GXmlCssSelector* sa = NULL;
		GXmlCssSelectorParser* _tmp18_;
		GeeList* _tmp19_;
		GeeList* _tmp20_;
		gpointer _tmp21_;
		GXmlCssSelector* _tmp22_;
		GXmlCssSelector* _tmp23_;
		GXmlCssSelectorType _tmp24_;
		GXmlCssSelectorType _tmp25_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp26_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp27_;
		GXmlDomElement* _tmp28_;
		GXmlGomDocument* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomNode* _tmp31_;
		GXmlDomNode* _tmp32_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp33_;
		GXmlDomElement* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomNode* _tmp38_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomElement* _tmp42_;
		GXmlDomElement* _tmp43_;
		GXmlDomNode* _tmp44_;
		GXmlDomNode* _tmp45_;
		gboolean _tmp46_ = FALSE;
		GXmlCssSelectorParser* _tmp47_;
		GXmlDomElement* _tmp48_;
		gboolean _tmp49_ = FALSE;
		GXmlCssSelectorParser* _tmp50_;
		GXmlDomElement* _tmp51_;
		gboolean _tmp52_ = FALSE;
		GXmlCssSelectorParser* _tmp53_;
		GXmlDomElement* _tmp54_;
#line 67 "CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 67 "CssSelectorTest.vala"
		cp = _tmp0_;
#line 68 "CssSelectorTest.vala"
		_tmp1_ = cp;
#line 68 "CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "child[prop-name]", &_inner_error0_);
#line 68 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 68 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 798 "CssSelectorTest.c"
			goto __catch2_g_error;
		}
#line 69 "CssSelectorTest.vala"
		_tmp2_ = cp;
#line 69 "CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 69 "CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 69 "CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 69 "CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 69 "CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 2, "cp.selectors.size == 2");
#line 70 "CssSelectorTest.vala"
		_tmp7_ = cp;
#line 70 "CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 70 "CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 70 "CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 70 "CssSelectorTest.vala"
		s = (GXmlCssSelector*) _tmp10_;
#line 71 "CssSelectorTest.vala"
		_tmp11_ = s;
#line 71 "CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 72 "CssSelectorTest.vala"
		_tmp12_ = s;
#line 72 "CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_get_selector_type (_tmp12_);
#line 72 "CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 72 "CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 73 "CssSelectorTest.vala"
		_tmp15_ = s;
#line 73 "CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_get_combiner (_tmp15_);
#line 73 "CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 73 "CssSelectorTest.vala"
		_vala_assert (_tmp17_ == GXML_CSS_COMBINER_NONE, "s.combiner == CssCombiner.NONE");
#line 74 "CssSelectorTest.vala"
		_tmp18_ = cp;
#line 74 "CssSelectorTest.vala"
		_tmp19_ = gxml_css_selector_parser_get_selectors (_tmp18_);
#line 74 "CssSelectorTest.vala"
		_tmp20_ = _tmp19_;
#line 74 "CssSelectorTest.vala"
		_tmp21_ = gee_list_get (_tmp20_, 1);
#line 74 "CssSelectorTest.vala"
		sa = (GXmlCssSelector*) _tmp21_;
#line 75 "CssSelectorTest.vala"
		_tmp22_ = sa;
#line 75 "CssSelectorTest.vala"
		_vala_assert (_tmp22_ != NULL, "sa != null");
#line 76 "CssSelectorTest.vala"
		_tmp23_ = sa;
#line 76 "CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_get_selector_type (_tmp23_);
#line 76 "CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 76 "CssSelectorTest.vala"
		_vala_assert (_tmp25_ == GXML_CSS_SELECTOR_TYPE_ATTRIBUTE, "sa.selector_type == CssSelectorType.ATTRIBUTE");
#line 77 "CssSelectorTest.vala"
		_tmp26_ = gxml_gom_document_new ();
#line 77 "CssSelectorTest.vala"
		d = _tmp26_;
#line 78 "CssSelectorTest.vala"
		_tmp27_ = d;
#line 78 "CssSelectorTest.vala"
		_tmp28_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp27_, "root", &_inner_error0_);
#line 78 "CssSelectorTest.vala"
		r = _tmp28_;
#line 78 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 78 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 78 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 78 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 78 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 885 "CssSelectorTest.c"
			goto __catch2_g_error;
		}
#line 79 "CssSelectorTest.vala"
		_tmp29_ = d;
#line 79 "CssSelectorTest.vala"
		_tmp30_ = r;
#line 79 "CssSelectorTest.vala"
		_tmp31_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp29_, (GXmlDomNode*) _tmp30_, &_inner_error0_);
#line 79 "CssSelectorTest.vala"
		_tmp32_ = _tmp31_;
#line 79 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp32_);
#line 79 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 79 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 79 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 79 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 79 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 79 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 910 "CssSelectorTest.c"
			goto __catch2_g_error;
		}
#line 80 "CssSelectorTest.vala"
		_tmp33_ = d;
#line 80 "CssSelectorTest.vala"
		_tmp34_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp33_, "child", &_inner_error0_);
#line 80 "CssSelectorTest.vala"
		c1 = _tmp34_;
#line 80 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 80 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 80 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 80 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 80 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 80 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 931 "CssSelectorTest.c"
			goto __catch2_g_error;
		}
#line 81 "CssSelectorTest.vala"
		_tmp35_ = r;
#line 81 "CssSelectorTest.vala"
		_tmp36_ = c1;
#line 81 "CssSelectorTest.vala"
		_tmp37_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp35_, (GXmlDomNode*) _tmp36_, &_inner_error0_);
#line 81 "CssSelectorTest.vala"
		_tmp38_ = _tmp37_;
#line 81 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp38_);
#line 81 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 81 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 81 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 81 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 81 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 81 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 81 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 958 "CssSelectorTest.c"
			goto __catch2_g_error;
		}
#line 82 "CssSelectorTest.vala"
		_tmp39_ = d;
#line 82 "CssSelectorTest.vala"
		_tmp40_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp39_, "child", &_inner_error0_);
#line 82 "CssSelectorTest.vala"
		c2 = _tmp40_;
#line 82 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 82 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 82 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 82 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 82 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 82 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 82 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 981 "CssSelectorTest.c"
			goto __catch2_g_error;
		}
#line 83 "CssSelectorTest.vala"
		_tmp41_ = c2;
#line 83 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp41_, "prop-name", "val", &_inner_error0_);
#line 83 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 83 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 83 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 83 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 83 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 83 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 83 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 83 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1004 "CssSelectorTest.c"
			goto __catch2_g_error;
		}
#line 84 "CssSelectorTest.vala"
		_tmp42_ = r;
#line 84 "CssSelectorTest.vala"
		_tmp43_ = c2;
#line 84 "CssSelectorTest.vala"
		_tmp44_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp42_, (GXmlDomNode*) _tmp43_, &_inner_error0_);
#line 84 "CssSelectorTest.vala"
		_tmp45_ = _tmp44_;
#line 84 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp45_);
#line 84 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 84 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 84 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 84 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 84 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 84 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 84 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 84 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1033 "CssSelectorTest.c"
			goto __catch2_g_error;
		}
#line 85 "CssSelectorTest.vala"
		_tmp47_ = cp;
#line 85 "CssSelectorTest.vala"
		_tmp48_ = r;
#line 85 "CssSelectorTest.vala"
		_tmp46_ = gxml_css_selector_parser_match (_tmp47_, _tmp48_, &_inner_error0_);
#line 85 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 85 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 85 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 85 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 85 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 85 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 85 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 85 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1058 "CssSelectorTest.c"
			goto __catch2_g_error;
		}
#line 85 "CssSelectorTest.vala"
		_vala_assert (!_tmp46_, "!cp.match (r)");
#line 86 "CssSelectorTest.vala"
		_tmp50_ = cp;
#line 86 "CssSelectorTest.vala"
		_tmp51_ = c1;
#line 86 "CssSelectorTest.vala"
		_tmp49_ = gxml_css_selector_parser_match (_tmp50_, _tmp51_, &_inner_error0_);
#line 86 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 86 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 86 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 86 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 86 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 86 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 86 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 86 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1085 "CssSelectorTest.c"
			goto __catch2_g_error;
		}
#line 86 "CssSelectorTest.vala"
		_vala_assert (!_tmp49_, "!cp.match (c1)");
#line 87 "CssSelectorTest.vala"
		_tmp53_ = cp;
#line 87 "CssSelectorTest.vala"
		_tmp54_ = c2;
#line 87 "CssSelectorTest.vala"
		_tmp52_ = gxml_css_selector_parser_match (_tmp53_, _tmp54_, &_inner_error0_);
#line 87 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 87 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 87 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 87 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 87 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 87 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 87 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 87 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1112 "CssSelectorTest.c"
			goto __catch2_g_error;
		}
#line 87 "CssSelectorTest.vala"
		_vala_assert (_tmp52_, "cp.match (c2)");
#line 66 "CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 66 "CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 66 "CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 66 "CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 66 "CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 66 "CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 66 "CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 1131 "CssSelectorTest.c"
	}
	goto __finally2;
	__catch2_g_error:
	{
		GError* e = NULL;
		GError* _tmp55_;
		const gchar* _tmp56_;
		gchar* _tmp57_;
		gchar* _tmp58_;
#line 66 "CssSelectorTest.vala"
		e = _inner_error0_;
#line 66 "CssSelectorTest.vala"
		_inner_error0_ = NULL;
#line 89 "CssSelectorTest.vala"
		_tmp55_ = e;
#line 89 "CssSelectorTest.vala"
		_tmp56_ = _tmp55_->message;
#line 89 "CssSelectorTest.vala"
		_tmp57_ = g_strconcat ("ERROR: ", _tmp56_, NULL);
#line 89 "CssSelectorTest.vala"
		_tmp58_ = _tmp57_;
#line 89 "CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:89: %s", _tmp58_);
#line 89 "CssSelectorTest.vala"
		_g_free0 (_tmp58_);
#line 66 "CssSelectorTest.vala"
		_g_error_free0 (e);
#line 1159 "CssSelectorTest.c"
	}
	__finally2:
#line 66 "CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 66 "CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 66 "CssSelectorTest.vala"
		g_clear_error (&_inner_error0_);
#line 66 "CssSelectorTest.vala"
		return;
#line 1170 "CssSelectorTest.c"
	}
}

static void
___lambda147__gtest_func (void)
{
#line 65 "CssSelectorTest.vala"
	__lambda147_ ();
#line 1179 "CssSelectorTest.c"
}

static void
__lambda148_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelector* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelector* _tmp11_;
		GXmlCssSelector* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelector* _tmp15_;
		GXmlCssCombiner _tmp16_;
		GXmlCssCombiner _tmp17_;
		GXmlCssSelector* sa = NULL;
		GXmlCssSelectorParser* _tmp18_;
		GeeList* _tmp19_;
		GeeList* _tmp20_;
		gpointer _tmp21_;
		GXmlCssSelector* _tmp22_;
		GXmlCssSelector* _tmp23_;
		GXmlCssSelectorType _tmp24_;
		GXmlCssSelectorType _tmp25_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp26_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp27_;
		GXmlDomElement* _tmp28_;
		GXmlGomDocument* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomNode* _tmp31_;
		GXmlDomNode* _tmp32_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp33_;
		GXmlDomElement* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomNode* _tmp38_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomElement* _tmp42_;
		GXmlDomElement* _tmp43_;
		GXmlDomNode* _tmp44_;
		GXmlDomNode* _tmp45_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlDomNode* _tmp51_;
		GXmlDomNode* _tmp52_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomElement* _tmp56_;
		GXmlDomElement* _tmp57_;
		GXmlDomNode* _tmp58_;
		GXmlDomNode* _tmp59_;
		gboolean _tmp60_ = FALSE;
		GXmlCssSelectorParser* _tmp61_;
		GXmlDomElement* _tmp62_;
		gboolean _tmp63_ = FALSE;
		GXmlCssSelectorParser* _tmp64_;
		GXmlDomElement* _tmp65_;
		gboolean _tmp66_ = FALSE;
		GXmlCssSelectorParser* _tmp67_;
		GXmlDomElement* _tmp68_;
		gboolean _tmp69_ = FALSE;
		GXmlCssSelectorParser* _tmp70_;
		GXmlDomElement* _tmp71_;
		gboolean _tmp72_ = FALSE;
		GXmlCssSelectorParser* _tmp73_;
		GXmlDomElement* _tmp74_;
#line 94 "CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 94 "CssSelectorTest.vala"
		cp = _tmp0_;
#line 95 "CssSelectorTest.vala"
		_tmp1_ = cp;
#line 95 "CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "child[prop-name~=\"val\"]", &_inner_error0_);
#line 95 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 95 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1283 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 96 "CssSelectorTest.vala"
		_tmp2_ = cp;
#line 96 "CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 96 "CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 96 "CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 96 "CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 96 "CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 2, "cp.selectors.size == 2");
#line 97 "CssSelectorTest.vala"
		_tmp7_ = cp;
#line 97 "CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 97 "CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 97 "CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 97 "CssSelectorTest.vala"
		s = (GXmlCssSelector*) _tmp10_;
#line 98 "CssSelectorTest.vala"
		_tmp11_ = s;
#line 98 "CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 99 "CssSelectorTest.vala"
		_tmp12_ = s;
#line 99 "CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_get_selector_type (_tmp12_);
#line 99 "CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 99 "CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 100 "CssSelectorTest.vala"
		_tmp15_ = s;
#line 100 "CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_get_combiner (_tmp15_);
#line 100 "CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 100 "CssSelectorTest.vala"
		_vala_assert (_tmp17_ == GXML_CSS_COMBINER_NONE, "s.combiner == CssCombiner.NONE");
#line 101 "CssSelectorTest.vala"
		_tmp18_ = cp;
#line 101 "CssSelectorTest.vala"
		_tmp19_ = gxml_css_selector_parser_get_selectors (_tmp18_);
#line 101 "CssSelectorTest.vala"
		_tmp20_ = _tmp19_;
#line 101 "CssSelectorTest.vala"
		_tmp21_ = gee_list_get (_tmp20_, 1);
#line 101 "CssSelectorTest.vala"
		sa = (GXmlCssSelector*) _tmp21_;
#line 102 "CssSelectorTest.vala"
		_tmp22_ = sa;
#line 102 "CssSelectorTest.vala"
		_vala_assert (_tmp22_ != NULL, "sa != null");
#line 103 "CssSelectorTest.vala"
		_tmp23_ = sa;
#line 103 "CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_get_selector_type (_tmp23_);
#line 103 "CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 103 "CssSelectorTest.vala"
		_vala_assert (_tmp25_ == GXML_CSS_SELECTOR_TYPE_ATTRIBUTE_CONTAINS, "sa.selector_type == CssSelectorType.ATTRIBUTE_CONTAINS");
#line 104 "CssSelectorTest.vala"
		_tmp26_ = gxml_gom_document_new ();
#line 104 "CssSelectorTest.vala"
		d = _tmp26_;
#line 105 "CssSelectorTest.vala"
		_tmp27_ = d;
#line 105 "CssSelectorTest.vala"
		_tmp28_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp27_, "root", &_inner_error0_);
#line 105 "CssSelectorTest.vala"
		r = _tmp28_;
#line 105 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 105 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 105 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 105 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 105 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1370 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 106 "CssSelectorTest.vala"
		_tmp29_ = d;
#line 106 "CssSelectorTest.vala"
		_tmp30_ = r;
#line 106 "CssSelectorTest.vala"
		_tmp31_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp29_, (GXmlDomNode*) _tmp30_, &_inner_error0_);
#line 106 "CssSelectorTest.vala"
		_tmp32_ = _tmp31_;
#line 106 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp32_);
#line 106 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 106 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 106 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 106 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 106 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 106 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1395 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 107 "CssSelectorTest.vala"
		_tmp33_ = d;
#line 107 "CssSelectorTest.vala"
		_tmp34_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp33_, "child", &_inner_error0_);
#line 107 "CssSelectorTest.vala"
		c1 = _tmp34_;
#line 107 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 107 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 107 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 107 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 107 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 107 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1416 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 108 "CssSelectorTest.vala"
		_tmp35_ = r;
#line 108 "CssSelectorTest.vala"
		_tmp36_ = c1;
#line 108 "CssSelectorTest.vala"
		_tmp37_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp35_, (GXmlDomNode*) _tmp36_, &_inner_error0_);
#line 108 "CssSelectorTest.vala"
		_tmp38_ = _tmp37_;
#line 108 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp38_);
#line 108 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 108 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 108 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 108 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 108 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 108 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 108 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1443 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 109 "CssSelectorTest.vala"
		_tmp39_ = d;
#line 109 "CssSelectorTest.vala"
		_tmp40_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp39_, "child", &_inner_error0_);
#line 109 "CssSelectorTest.vala"
		c2 = _tmp40_;
#line 109 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 109 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 109 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 109 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 109 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 109 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 109 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1466 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 110 "CssSelectorTest.vala"
		_tmp41_ = c2;
#line 110 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp41_, "prop-name", "val calc soup", &_inner_error0_);
#line 110 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 110 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 110 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 110 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 110 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 110 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 110 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 110 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1489 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 111 "CssSelectorTest.vala"
		_tmp42_ = r;
#line 111 "CssSelectorTest.vala"
		_tmp43_ = c2;
#line 111 "CssSelectorTest.vala"
		_tmp44_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp42_, (GXmlDomNode*) _tmp43_, &_inner_error0_);
#line 111 "CssSelectorTest.vala"
		_tmp45_ = _tmp44_;
#line 111 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp45_);
#line 111 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 111 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 111 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 111 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 111 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 111 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 111 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 111 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1518 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 112 "CssSelectorTest.vala"
		_tmp46_ = d;
#line 112 "CssSelectorTest.vala"
		_tmp47_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp46_, "child", &_inner_error0_);
#line 112 "CssSelectorTest.vala"
		c3 = _tmp47_;
#line 112 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 112 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 112 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 112 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 112 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 112 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 112 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 112 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1543 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 113 "CssSelectorTest.vala"
		_tmp48_ = c3;
#line 113 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp48_, "prop-name", "calc val soup", &_inner_error0_);
#line 113 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 113 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 113 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 113 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 113 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 113 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 113 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 113 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 113 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1568 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 114 "CssSelectorTest.vala"
		_tmp49_ = r;
#line 114 "CssSelectorTest.vala"
		_tmp50_ = c3;
#line 114 "CssSelectorTest.vala"
		_tmp51_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp49_, (GXmlDomNode*) _tmp50_, &_inner_error0_);
#line 114 "CssSelectorTest.vala"
		_tmp52_ = _tmp51_;
#line 114 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp52_);
#line 114 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 114 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 114 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 114 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 114 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 114 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 114 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 114 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 114 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1599 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 115 "CssSelectorTest.vala"
		_tmp53_ = d;
#line 115 "CssSelectorTest.vala"
		_tmp54_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp53_, "child", &_inner_error0_);
#line 115 "CssSelectorTest.vala"
		c4 = _tmp54_;
#line 115 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 115 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 115 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 115 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 115 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 115 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 115 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 115 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 115 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1626 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 116 "CssSelectorTest.vala"
		_tmp55_ = c4;
#line 116 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp55_, "prop-name", "calc secondary soup", &_inner_error0_);
#line 116 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 116 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 116 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 116 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 116 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 116 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 116 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 116 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 116 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 116 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1653 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 117 "CssSelectorTest.vala"
		_tmp56_ = r;
#line 117 "CssSelectorTest.vala"
		_tmp57_ = c4;
#line 117 "CssSelectorTest.vala"
		_tmp58_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp56_, (GXmlDomNode*) _tmp57_, &_inner_error0_);
#line 117 "CssSelectorTest.vala"
		_tmp59_ = _tmp58_;
#line 117 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp59_);
#line 117 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 117 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 117 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 117 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 117 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 117 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 117 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 117 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 117 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 117 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1686 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 118 "CssSelectorTest.vala"
		_tmp61_ = cp;
#line 118 "CssSelectorTest.vala"
		_tmp62_ = r;
#line 118 "CssSelectorTest.vala"
		_tmp60_ = gxml_css_selector_parser_match (_tmp61_, _tmp62_, &_inner_error0_);
#line 118 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 118 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 118 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 118 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 118 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 118 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 118 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 118 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 118 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 118 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1715 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 118 "CssSelectorTest.vala"
		_vala_assert (!_tmp60_, "!cp.match (r)");
#line 119 "CssSelectorTest.vala"
		_tmp64_ = cp;
#line 119 "CssSelectorTest.vala"
		_tmp65_ = c1;
#line 119 "CssSelectorTest.vala"
		_tmp63_ = gxml_css_selector_parser_match (_tmp64_, _tmp65_, &_inner_error0_);
#line 119 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 119 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 119 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 119 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 119 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 119 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 119 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 119 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 119 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 119 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1746 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 119 "CssSelectorTest.vala"
		_vala_assert (!_tmp63_, "!cp.match (c1)");
#line 120 "CssSelectorTest.vala"
		_tmp67_ = cp;
#line 120 "CssSelectorTest.vala"
		_tmp68_ = c2;
#line 120 "CssSelectorTest.vala"
		_tmp66_ = gxml_css_selector_parser_match (_tmp67_, _tmp68_, &_inner_error0_);
#line 120 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 120 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 120 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 120 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 120 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 120 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 120 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 120 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 120 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 120 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1777 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 120 "CssSelectorTest.vala"
		_vala_assert (_tmp66_, "cp.match (c2)");
#line 121 "CssSelectorTest.vala"
		_tmp70_ = cp;
#line 121 "CssSelectorTest.vala"
		_tmp71_ = c3;
#line 121 "CssSelectorTest.vala"
		_tmp69_ = gxml_css_selector_parser_match (_tmp70_, _tmp71_, &_inner_error0_);
#line 121 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 121 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 121 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 121 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 121 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 121 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 121 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 121 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 121 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 121 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1808 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 121 "CssSelectorTest.vala"
		_vala_assert (_tmp69_, "cp.match (c3)");
#line 122 "CssSelectorTest.vala"
		_tmp73_ = cp;
#line 122 "CssSelectorTest.vala"
		_tmp74_ = c4;
#line 122 "CssSelectorTest.vala"
		_tmp72_ = gxml_css_selector_parser_match (_tmp73_, _tmp74_, &_inner_error0_);
#line 122 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 122 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 122 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 122 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 122 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 122 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 122 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 122 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 122 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 122 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 1839 "CssSelectorTest.c"
			goto __catch3_g_error;
		}
#line 122 "CssSelectorTest.vala"
		_vala_assert (!_tmp72_, "!cp.match (c4)");
#line 93 "CssSelectorTest.vala"
		_g_object_unref0 (c4);
#line 93 "CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 93 "CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 93 "CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 93 "CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 93 "CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 93 "CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 93 "CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 93 "CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 1862 "CssSelectorTest.c"
	}
	goto __finally3;
	__catch3_g_error:
	{
		GError* e = NULL;
		GError* _tmp75_;
		const gchar* _tmp76_;
		gchar* _tmp77_;
		gchar* _tmp78_;
#line 93 "CssSelectorTest.vala"
		e = _inner_error0_;
#line 93 "CssSelectorTest.vala"
		_inner_error0_ = NULL;
#line 124 "CssSelectorTest.vala"
		_tmp75_ = e;
#line 124 "CssSelectorTest.vala"
		_tmp76_ = _tmp75_->message;
#line 124 "CssSelectorTest.vala"
		_tmp77_ = g_strconcat ("ERROR: ", _tmp76_, NULL);
#line 124 "CssSelectorTest.vala"
		_tmp78_ = _tmp77_;
#line 124 "CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:124: %s", _tmp78_);
#line 124 "CssSelectorTest.vala"
		_g_free0 (_tmp78_);
#line 93 "CssSelectorTest.vala"
		_g_error_free0 (e);
#line 1890 "CssSelectorTest.c"
	}
	__finally3:
#line 93 "CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 93 "CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 93 "CssSelectorTest.vala"
		g_clear_error (&_inner_error0_);
#line 93 "CssSelectorTest.vala"
		return;
#line 1901 "CssSelectorTest.c"
	}
}

static void
___lambda148__gtest_func (void)
{
#line 92 "CssSelectorTest.vala"
	__lambda148_ ();
#line 1910 "CssSelectorTest.c"
}

static void
__lambda149_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelector* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelector* _tmp11_;
		GXmlCssSelector* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelector* _tmp15_;
		GXmlCssCombiner _tmp16_;
		GXmlCssCombiner _tmp17_;
		GXmlCssSelector* sa = NULL;
		GXmlCssSelectorParser* _tmp18_;
		GeeList* _tmp19_;
		GeeList* _tmp20_;
		gpointer _tmp21_;
		GXmlCssSelector* _tmp22_;
		GXmlCssSelector* _tmp23_;
		GXmlCssSelectorType _tmp24_;
		GXmlCssSelectorType _tmp25_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp26_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp27_;
		GXmlDomElement* _tmp28_;
		GXmlGomDocument* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomNode* _tmp31_;
		GXmlDomNode* _tmp32_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp33_;
		GXmlDomElement* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomNode* _tmp38_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomElement* _tmp42_;
		GXmlDomElement* _tmp43_;
		GXmlDomNode* _tmp44_;
		GXmlDomNode* _tmp45_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlDomNode* _tmp51_;
		GXmlDomNode* _tmp52_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomElement* _tmp56_;
		GXmlDomElement* _tmp57_;
		GXmlDomNode* _tmp58_;
		GXmlDomNode* _tmp59_;
		gboolean _tmp60_ = FALSE;
		GXmlCssSelectorParser* _tmp61_;
		GXmlDomElement* _tmp62_;
		gboolean _tmp63_ = FALSE;
		GXmlCssSelectorParser* _tmp64_;
		GXmlDomElement* _tmp65_;
		gboolean _tmp66_ = FALSE;
		GXmlCssSelectorParser* _tmp67_;
		GXmlDomElement* _tmp68_;
		gboolean _tmp69_ = FALSE;
		GXmlCssSelectorParser* _tmp70_;
		GXmlDomElement* _tmp71_;
		gboolean _tmp72_ = FALSE;
		GXmlCssSelectorParser* _tmp73_;
		GXmlDomElement* _tmp74_;
#line 129 "CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 129 "CssSelectorTest.vala"
		cp = _tmp0_;
#line 130 "CssSelectorTest.vala"
		_tmp1_ = cp;
#line 130 "CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "child[prop-name^=\"val\"]", &_inner_error0_);
#line 130 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 130 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2014 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 131 "CssSelectorTest.vala"
		_tmp2_ = cp;
#line 131 "CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 131 "CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 131 "CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 131 "CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 131 "CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 2, "cp.selectors.size == 2");
#line 132 "CssSelectorTest.vala"
		_tmp7_ = cp;
#line 132 "CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 132 "CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 132 "CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 132 "CssSelectorTest.vala"
		s = (GXmlCssSelector*) _tmp10_;
#line 133 "CssSelectorTest.vala"
		_tmp11_ = s;
#line 133 "CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 134 "CssSelectorTest.vala"
		_tmp12_ = s;
#line 134 "CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_get_selector_type (_tmp12_);
#line 134 "CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 134 "CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 135 "CssSelectorTest.vala"
		_tmp15_ = s;
#line 135 "CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_get_combiner (_tmp15_);
#line 135 "CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 135 "CssSelectorTest.vala"
		_vala_assert (_tmp17_ == GXML_CSS_COMBINER_NONE, "s.combiner == CssCombiner.NONE");
#line 136 "CssSelectorTest.vala"
		_tmp18_ = cp;
#line 136 "CssSelectorTest.vala"
		_tmp19_ = gxml_css_selector_parser_get_selectors (_tmp18_);
#line 136 "CssSelectorTest.vala"
		_tmp20_ = _tmp19_;
#line 136 "CssSelectorTest.vala"
		_tmp21_ = gee_list_get (_tmp20_, 1);
#line 136 "CssSelectorTest.vala"
		sa = (GXmlCssSelector*) _tmp21_;
#line 137 "CssSelectorTest.vala"
		_tmp22_ = sa;
#line 137 "CssSelectorTest.vala"
		_vala_assert (_tmp22_ != NULL, "sa != null");
#line 138 "CssSelectorTest.vala"
		_tmp23_ = sa;
#line 138 "CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_get_selector_type (_tmp23_);
#line 138 "CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 138 "CssSelectorTest.vala"
		_vala_assert (_tmp25_ == GXML_CSS_SELECTOR_TYPE_ATTRIBUTE_STARTS_WITH, "sa.selector_type == CssSelectorType.ATTRIBUTE_STARTS_WITH");
#line 139 "CssSelectorTest.vala"
		_tmp26_ = gxml_gom_document_new ();
#line 139 "CssSelectorTest.vala"
		d = _tmp26_;
#line 140 "CssSelectorTest.vala"
		_tmp27_ = d;
#line 140 "CssSelectorTest.vala"
		_tmp28_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp27_, "root", &_inner_error0_);
#line 140 "CssSelectorTest.vala"
		r = _tmp28_;
#line 140 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 140 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 140 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 140 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 140 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2101 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 141 "CssSelectorTest.vala"
		_tmp29_ = d;
#line 141 "CssSelectorTest.vala"
		_tmp30_ = r;
#line 141 "CssSelectorTest.vala"
		_tmp31_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp29_, (GXmlDomNode*) _tmp30_, &_inner_error0_);
#line 141 "CssSelectorTest.vala"
		_tmp32_ = _tmp31_;
#line 141 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp32_);
#line 141 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 141 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 141 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 141 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 141 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 141 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2126 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 142 "CssSelectorTest.vala"
		_tmp33_ = d;
#line 142 "CssSelectorTest.vala"
		_tmp34_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp33_, "child", &_inner_error0_);
#line 142 "CssSelectorTest.vala"
		c1 = _tmp34_;
#line 142 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 142 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 142 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 142 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 142 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 142 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2147 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 143 "CssSelectorTest.vala"
		_tmp35_ = r;
#line 143 "CssSelectorTest.vala"
		_tmp36_ = c1;
#line 143 "CssSelectorTest.vala"
		_tmp37_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp35_, (GXmlDomNode*) _tmp36_, &_inner_error0_);
#line 143 "CssSelectorTest.vala"
		_tmp38_ = _tmp37_;
#line 143 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp38_);
#line 143 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 143 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 143 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 143 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 143 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 143 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 143 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2174 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 144 "CssSelectorTest.vala"
		_tmp39_ = d;
#line 144 "CssSelectorTest.vala"
		_tmp40_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp39_, "child", &_inner_error0_);
#line 144 "CssSelectorTest.vala"
		c2 = _tmp40_;
#line 144 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 144 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 144 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 144 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 144 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 144 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 144 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2197 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 145 "CssSelectorTest.vala"
		_tmp41_ = c2;
#line 145 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp41_, "prop-name", "val", &_inner_error0_);
#line 145 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 145 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 145 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 145 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 145 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 145 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 145 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 145 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2220 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 146 "CssSelectorTest.vala"
		_tmp42_ = r;
#line 146 "CssSelectorTest.vala"
		_tmp43_ = c2;
#line 146 "CssSelectorTest.vala"
		_tmp44_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp42_, (GXmlDomNode*) _tmp43_, &_inner_error0_);
#line 146 "CssSelectorTest.vala"
		_tmp45_ = _tmp44_;
#line 146 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp45_);
#line 146 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 146 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 146 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 146 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 146 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 146 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 146 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 146 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2249 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 147 "CssSelectorTest.vala"
		_tmp46_ = d;
#line 147 "CssSelectorTest.vala"
		_tmp47_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp46_, "child", &_inner_error0_);
#line 147 "CssSelectorTest.vala"
		c3 = _tmp47_;
#line 147 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 147 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 147 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 147 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 147 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 147 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 147 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 147 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2274 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 148 "CssSelectorTest.vala"
		_tmp48_ = c3;
#line 148 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp48_, "prop-name", "value", &_inner_error0_);
#line 148 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 148 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 148 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 148 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 148 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 148 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 148 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 148 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 148 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2299 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 149 "CssSelectorTest.vala"
		_tmp49_ = r;
#line 149 "CssSelectorTest.vala"
		_tmp50_ = c3;
#line 149 "CssSelectorTest.vala"
		_tmp51_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp49_, (GXmlDomNode*) _tmp50_, &_inner_error0_);
#line 149 "CssSelectorTest.vala"
		_tmp52_ = _tmp51_;
#line 149 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp52_);
#line 149 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 149 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 149 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 149 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 149 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 149 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 149 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 149 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 149 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2330 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 150 "CssSelectorTest.vala"
		_tmp53_ = d;
#line 150 "CssSelectorTest.vala"
		_tmp54_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp53_, "child", &_inner_error0_);
#line 150 "CssSelectorTest.vala"
		c4 = _tmp54_;
#line 150 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 150 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 150 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 150 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 150 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 150 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 150 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 150 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 150 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2357 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 151 "CssSelectorTest.vala"
		_tmp55_ = c4;
#line 151 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp55_, "prop-name", "secondaryvalue", &_inner_error0_);
#line 151 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 151 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 151 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 151 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 151 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 151 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 151 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 151 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 151 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 151 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2384 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 152 "CssSelectorTest.vala"
		_tmp56_ = r;
#line 152 "CssSelectorTest.vala"
		_tmp57_ = c4;
#line 152 "CssSelectorTest.vala"
		_tmp58_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp56_, (GXmlDomNode*) _tmp57_, &_inner_error0_);
#line 152 "CssSelectorTest.vala"
		_tmp59_ = _tmp58_;
#line 152 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp59_);
#line 152 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 152 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 152 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 152 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 152 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 152 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 152 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 152 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 152 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 152 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2417 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 153 "CssSelectorTest.vala"
		_tmp61_ = cp;
#line 153 "CssSelectorTest.vala"
		_tmp62_ = r;
#line 153 "CssSelectorTest.vala"
		_tmp60_ = gxml_css_selector_parser_match (_tmp61_, _tmp62_, &_inner_error0_);
#line 153 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 153 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 153 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 153 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 153 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 153 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 153 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 153 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 153 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 153 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2446 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 153 "CssSelectorTest.vala"
		_vala_assert (!_tmp60_, "!cp.match (r)");
#line 154 "CssSelectorTest.vala"
		_tmp64_ = cp;
#line 154 "CssSelectorTest.vala"
		_tmp65_ = c1;
#line 154 "CssSelectorTest.vala"
		_tmp63_ = gxml_css_selector_parser_match (_tmp64_, _tmp65_, &_inner_error0_);
#line 154 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 154 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 154 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 154 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 154 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 154 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 154 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 154 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 154 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 154 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2477 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 154 "CssSelectorTest.vala"
		_vala_assert (!_tmp63_, "!cp.match (c1)");
#line 155 "CssSelectorTest.vala"
		_tmp67_ = cp;
#line 155 "CssSelectorTest.vala"
		_tmp68_ = c2;
#line 155 "CssSelectorTest.vala"
		_tmp66_ = gxml_css_selector_parser_match (_tmp67_, _tmp68_, &_inner_error0_);
#line 155 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 155 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 155 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 155 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 155 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 155 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 155 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 155 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 155 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 155 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2508 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 155 "CssSelectorTest.vala"
		_vala_assert (_tmp66_, "cp.match (c2)");
#line 156 "CssSelectorTest.vala"
		_tmp70_ = cp;
#line 156 "CssSelectorTest.vala"
		_tmp71_ = c3;
#line 156 "CssSelectorTest.vala"
		_tmp69_ = gxml_css_selector_parser_match (_tmp70_, _tmp71_, &_inner_error0_);
#line 156 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 156 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 156 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 156 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 156 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 156 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 156 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 156 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 156 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 156 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2539 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 156 "CssSelectorTest.vala"
		_vala_assert (_tmp69_, "cp.match (c3)");
#line 157 "CssSelectorTest.vala"
		_tmp73_ = cp;
#line 157 "CssSelectorTest.vala"
		_tmp74_ = c4;
#line 157 "CssSelectorTest.vala"
		_tmp72_ = gxml_css_selector_parser_match (_tmp73_, _tmp74_, &_inner_error0_);
#line 157 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 157 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 157 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 157 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 157 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 157 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 157 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 157 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 157 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 157 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2570 "CssSelectorTest.c"
			goto __catch4_g_error;
		}
#line 157 "CssSelectorTest.vala"
		_vala_assert (!_tmp72_, "!cp.match (c4)");
#line 128 "CssSelectorTest.vala"
		_g_object_unref0 (c4);
#line 128 "CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 128 "CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 128 "CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 128 "CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 128 "CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 128 "CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 128 "CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 128 "CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 2593 "CssSelectorTest.c"
	}
	goto __finally4;
	__catch4_g_error:
	{
		GError* e = NULL;
		GError* _tmp75_;
		const gchar* _tmp76_;
		gchar* _tmp77_;
		gchar* _tmp78_;
#line 128 "CssSelectorTest.vala"
		e = _inner_error0_;
#line 128 "CssSelectorTest.vala"
		_inner_error0_ = NULL;
#line 159 "CssSelectorTest.vala"
		_tmp75_ = e;
#line 159 "CssSelectorTest.vala"
		_tmp76_ = _tmp75_->message;
#line 159 "CssSelectorTest.vala"
		_tmp77_ = g_strconcat ("ERROR: ", _tmp76_, NULL);
#line 159 "CssSelectorTest.vala"
		_tmp78_ = _tmp77_;
#line 159 "CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:159: %s", _tmp78_);
#line 159 "CssSelectorTest.vala"
		_g_free0 (_tmp78_);
#line 128 "CssSelectorTest.vala"
		_g_error_free0 (e);
#line 2621 "CssSelectorTest.c"
	}
	__finally4:
#line 128 "CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 128 "CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 128 "CssSelectorTest.vala"
		g_clear_error (&_inner_error0_);
#line 128 "CssSelectorTest.vala"
		return;
#line 2632 "CssSelectorTest.c"
	}
}

static void
___lambda149__gtest_func (void)
{
#line 127 "CssSelectorTest.vala"
	__lambda149_ ();
#line 2641 "CssSelectorTest.c"
}

static void
__lambda150_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelector* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelector* _tmp11_;
		GXmlCssSelector* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelector* _tmp15_;
		GXmlCssCombiner _tmp16_;
		GXmlCssCombiner _tmp17_;
		GXmlCssSelector* sa = NULL;
		GXmlCssSelectorParser* _tmp18_;
		GeeList* _tmp19_;
		GeeList* _tmp20_;
		gpointer _tmp21_;
		GXmlCssSelector* _tmp22_;
		GXmlCssSelector* _tmp23_;
		GXmlCssSelectorType _tmp24_;
		GXmlCssSelectorType _tmp25_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp26_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp27_;
		GXmlDomElement* _tmp28_;
		GXmlGomDocument* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomNode* _tmp31_;
		GXmlDomNode* _tmp32_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp33_;
		GXmlDomElement* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomNode* _tmp38_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomElement* _tmp42_;
		GXmlDomElement* _tmp43_;
		GXmlDomNode* _tmp44_;
		GXmlDomNode* _tmp45_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlDomNode* _tmp51_;
		GXmlDomNode* _tmp52_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomElement* _tmp56_;
		GXmlDomElement* _tmp57_;
		GXmlDomNode* _tmp58_;
		GXmlDomNode* _tmp59_;
		gboolean _tmp60_ = FALSE;
		GXmlCssSelectorParser* _tmp61_;
		GXmlDomElement* _tmp62_;
		gboolean _tmp63_ = FALSE;
		GXmlCssSelectorParser* _tmp64_;
		GXmlDomElement* _tmp65_;
		gboolean _tmp66_ = FALSE;
		GXmlCssSelectorParser* _tmp67_;
		GXmlDomElement* _tmp68_;
		gboolean _tmp69_ = FALSE;
		GXmlCssSelectorParser* _tmp70_;
		GXmlDomElement* _tmp71_;
		gboolean _tmp72_ = FALSE;
		GXmlCssSelectorParser* _tmp73_;
		GXmlDomElement* _tmp74_;
#line 164 "CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 164 "CssSelectorTest.vala"
		cp = _tmp0_;
#line 165 "CssSelectorTest.vala"
		_tmp1_ = cp;
#line 165 "CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "child[prop-name|=\"val\"]", &_inner_error0_);
#line 165 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 165 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2745 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 166 "CssSelectorTest.vala"
		_tmp2_ = cp;
#line 166 "CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 166 "CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 166 "CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 166 "CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 166 "CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 2, "cp.selectors.size == 2");
#line 167 "CssSelectorTest.vala"
		_tmp7_ = cp;
#line 167 "CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 167 "CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 167 "CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 167 "CssSelectorTest.vala"
		s = (GXmlCssSelector*) _tmp10_;
#line 168 "CssSelectorTest.vala"
		_tmp11_ = s;
#line 168 "CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 169 "CssSelectorTest.vala"
		_tmp12_ = s;
#line 169 "CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_get_selector_type (_tmp12_);
#line 169 "CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 169 "CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 170 "CssSelectorTest.vala"
		_tmp15_ = s;
#line 170 "CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_get_combiner (_tmp15_);
#line 170 "CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 170 "CssSelectorTest.vala"
		_vala_assert (_tmp17_ == GXML_CSS_COMBINER_NONE, "s.combiner == CssCombiner.NONE");
#line 171 "CssSelectorTest.vala"
		_tmp18_ = cp;
#line 171 "CssSelectorTest.vala"
		_tmp19_ = gxml_css_selector_parser_get_selectors (_tmp18_);
#line 171 "CssSelectorTest.vala"
		_tmp20_ = _tmp19_;
#line 171 "CssSelectorTest.vala"
		_tmp21_ = gee_list_get (_tmp20_, 1);
#line 171 "CssSelectorTest.vala"
		sa = (GXmlCssSelector*) _tmp21_;
#line 172 "CssSelectorTest.vala"
		_tmp22_ = sa;
#line 172 "CssSelectorTest.vala"
		_vala_assert (_tmp22_ != NULL, "sa != null");
#line 173 "CssSelectorTest.vala"
		_tmp23_ = sa;
#line 173 "CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_get_selector_type (_tmp23_);
#line 173 "CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 173 "CssSelectorTest.vala"
		_vala_assert (_tmp25_ == GXML_CSS_SELECTOR_TYPE_ATTRIBUTE_STARTS_WITH_WORD, "sa.selector_type == CssSelectorType.ATTRIBUTE_STARTS_WITH_WORD");
#line 174 "CssSelectorTest.vala"
		_tmp26_ = gxml_gom_document_new ();
#line 174 "CssSelectorTest.vala"
		d = _tmp26_;
#line 175 "CssSelectorTest.vala"
		_tmp27_ = d;
#line 175 "CssSelectorTest.vala"
		_tmp28_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp27_, "root", &_inner_error0_);
#line 175 "CssSelectorTest.vala"
		r = _tmp28_;
#line 175 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 175 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 175 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 175 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 175 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2832 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 176 "CssSelectorTest.vala"
		_tmp29_ = d;
#line 176 "CssSelectorTest.vala"
		_tmp30_ = r;
#line 176 "CssSelectorTest.vala"
		_tmp31_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp29_, (GXmlDomNode*) _tmp30_, &_inner_error0_);
#line 176 "CssSelectorTest.vala"
		_tmp32_ = _tmp31_;
#line 176 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp32_);
#line 176 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 176 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 176 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 176 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 176 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 176 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2857 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 177 "CssSelectorTest.vala"
		_tmp33_ = d;
#line 177 "CssSelectorTest.vala"
		_tmp34_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp33_, "child", &_inner_error0_);
#line 177 "CssSelectorTest.vala"
		c1 = _tmp34_;
#line 177 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 177 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 177 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 177 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 177 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 177 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2878 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 178 "CssSelectorTest.vala"
		_tmp35_ = r;
#line 178 "CssSelectorTest.vala"
		_tmp36_ = c1;
#line 178 "CssSelectorTest.vala"
		_tmp37_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp35_, (GXmlDomNode*) _tmp36_, &_inner_error0_);
#line 178 "CssSelectorTest.vala"
		_tmp38_ = _tmp37_;
#line 178 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp38_);
#line 178 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 178 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 178 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 178 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 178 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 178 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 178 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2905 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 179 "CssSelectorTest.vala"
		_tmp39_ = d;
#line 179 "CssSelectorTest.vala"
		_tmp40_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp39_, "child", &_inner_error0_);
#line 179 "CssSelectorTest.vala"
		c2 = _tmp40_;
#line 179 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 179 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 179 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 179 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 179 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 179 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 179 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2928 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 180 "CssSelectorTest.vala"
		_tmp41_ = c2;
#line 180 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp41_, "prop-name", "val-", &_inner_error0_);
#line 180 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 180 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 180 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 180 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 180 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 180 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 180 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 180 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2951 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 181 "CssSelectorTest.vala"
		_tmp42_ = r;
#line 181 "CssSelectorTest.vala"
		_tmp43_ = c2;
#line 181 "CssSelectorTest.vala"
		_tmp44_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp42_, (GXmlDomNode*) _tmp43_, &_inner_error0_);
#line 181 "CssSelectorTest.vala"
		_tmp45_ = _tmp44_;
#line 181 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp45_);
#line 181 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 181 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 181 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 181 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 181 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 181 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 181 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 181 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 2980 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 182 "CssSelectorTest.vala"
		_tmp46_ = d;
#line 182 "CssSelectorTest.vala"
		_tmp47_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp46_, "child", &_inner_error0_);
#line 182 "CssSelectorTest.vala"
		c3 = _tmp47_;
#line 182 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 182 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 182 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 182 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 182 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 182 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 182 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 182 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3005 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 183 "CssSelectorTest.vala"
		_tmp48_ = c3;
#line 183 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp48_, "prop-name", "value", &_inner_error0_);
#line 183 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 183 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 183 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 183 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 183 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 183 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 183 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 183 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 183 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3030 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 184 "CssSelectorTest.vala"
		_tmp49_ = r;
#line 184 "CssSelectorTest.vala"
		_tmp50_ = c3;
#line 184 "CssSelectorTest.vala"
		_tmp51_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp49_, (GXmlDomNode*) _tmp50_, &_inner_error0_);
#line 184 "CssSelectorTest.vala"
		_tmp52_ = _tmp51_;
#line 184 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp52_);
#line 184 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 184 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 184 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 184 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 184 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 184 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 184 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 184 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 184 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3061 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 185 "CssSelectorTest.vala"
		_tmp53_ = d;
#line 185 "CssSelectorTest.vala"
		_tmp54_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp53_, "child", &_inner_error0_);
#line 185 "CssSelectorTest.vala"
		c4 = _tmp54_;
#line 185 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 185 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 185 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 185 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 185 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 185 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 185 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 185 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 185 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3088 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 186 "CssSelectorTest.vala"
		_tmp55_ = c4;
#line 186 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp55_, "prop-name", "secondaryvalue", &_inner_error0_);
#line 186 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 186 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 186 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 186 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 186 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 186 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 186 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 186 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 186 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 186 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3115 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 187 "CssSelectorTest.vala"
		_tmp56_ = r;
#line 187 "CssSelectorTest.vala"
		_tmp57_ = c4;
#line 187 "CssSelectorTest.vala"
		_tmp58_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp56_, (GXmlDomNode*) _tmp57_, &_inner_error0_);
#line 187 "CssSelectorTest.vala"
		_tmp59_ = _tmp58_;
#line 187 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp59_);
#line 187 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 187 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 187 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 187 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 187 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 187 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 187 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 187 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 187 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 187 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3148 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 188 "CssSelectorTest.vala"
		_tmp61_ = cp;
#line 188 "CssSelectorTest.vala"
		_tmp62_ = r;
#line 188 "CssSelectorTest.vala"
		_tmp60_ = gxml_css_selector_parser_match (_tmp61_, _tmp62_, &_inner_error0_);
#line 188 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 188 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 188 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 188 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 188 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 188 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 188 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 188 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 188 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 188 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3177 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 188 "CssSelectorTest.vala"
		_vala_assert (!_tmp60_, "!cp.match (r)");
#line 189 "CssSelectorTest.vala"
		_tmp64_ = cp;
#line 189 "CssSelectorTest.vala"
		_tmp65_ = c1;
#line 189 "CssSelectorTest.vala"
		_tmp63_ = gxml_css_selector_parser_match (_tmp64_, _tmp65_, &_inner_error0_);
#line 189 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 189 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 189 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 189 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 189 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 189 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 189 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 189 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 189 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 189 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3208 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 189 "CssSelectorTest.vala"
		_vala_assert (!_tmp63_, "!cp.match (c1)");
#line 190 "CssSelectorTest.vala"
		_tmp67_ = cp;
#line 190 "CssSelectorTest.vala"
		_tmp68_ = c2;
#line 190 "CssSelectorTest.vala"
		_tmp66_ = gxml_css_selector_parser_match (_tmp67_, _tmp68_, &_inner_error0_);
#line 190 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 190 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 190 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 190 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 190 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 190 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 190 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 190 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 190 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 190 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3239 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 190 "CssSelectorTest.vala"
		_vala_assert (_tmp66_, "cp.match (c2)");
#line 191 "CssSelectorTest.vala"
		_tmp70_ = cp;
#line 191 "CssSelectorTest.vala"
		_tmp71_ = c3;
#line 191 "CssSelectorTest.vala"
		_tmp69_ = gxml_css_selector_parser_match (_tmp70_, _tmp71_, &_inner_error0_);
#line 191 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 191 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 191 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 191 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 191 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 191 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 191 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 191 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 191 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 191 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3270 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 191 "CssSelectorTest.vala"
		_vala_assert (!_tmp69_, "!cp.match (c3)");
#line 192 "CssSelectorTest.vala"
		_tmp73_ = cp;
#line 192 "CssSelectorTest.vala"
		_tmp74_ = c4;
#line 192 "CssSelectorTest.vala"
		_tmp72_ = gxml_css_selector_parser_match (_tmp73_, _tmp74_, &_inner_error0_);
#line 192 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 192 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 192 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 192 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 192 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 192 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 192 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 192 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 192 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 192 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3301 "CssSelectorTest.c"
			goto __catch5_g_error;
		}
#line 192 "CssSelectorTest.vala"
		_vala_assert (!_tmp72_, "!cp.match (c4)");
#line 163 "CssSelectorTest.vala"
		_g_object_unref0 (c4);
#line 163 "CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 163 "CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 163 "CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 163 "CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 163 "CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 163 "CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 163 "CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 163 "CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 3324 "CssSelectorTest.c"
	}
	goto __finally5;
	__catch5_g_error:
	{
		GError* e = NULL;
		GError* _tmp75_;
		const gchar* _tmp76_;
		gchar* _tmp77_;
		gchar* _tmp78_;
#line 163 "CssSelectorTest.vala"
		e = _inner_error0_;
#line 163 "CssSelectorTest.vala"
		_inner_error0_ = NULL;
#line 194 "CssSelectorTest.vala"
		_tmp75_ = e;
#line 194 "CssSelectorTest.vala"
		_tmp76_ = _tmp75_->message;
#line 194 "CssSelectorTest.vala"
		_tmp77_ = g_strconcat ("ERROR: ", _tmp76_, NULL);
#line 194 "CssSelectorTest.vala"
		_tmp78_ = _tmp77_;
#line 194 "CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:194: %s", _tmp78_);
#line 194 "CssSelectorTest.vala"
		_g_free0 (_tmp78_);
#line 163 "CssSelectorTest.vala"
		_g_error_free0 (e);
#line 3352 "CssSelectorTest.c"
	}
	__finally5:
#line 163 "CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 163 "CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 163 "CssSelectorTest.vala"
		g_clear_error (&_inner_error0_);
#line 163 "CssSelectorTest.vala"
		return;
#line 3363 "CssSelectorTest.c"
	}
}

static void
___lambda150__gtest_func (void)
{
#line 162 "CssSelectorTest.vala"
	__lambda150_ ();
#line 3372 "CssSelectorTest.c"
}

static void
__lambda151_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelector* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelector* _tmp11_;
		GXmlCssSelector* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelector* _tmp15_;
		GXmlCssCombiner _tmp16_;
		GXmlCssCombiner _tmp17_;
		GXmlCssSelector* sa = NULL;
		GXmlCssSelectorParser* _tmp18_;
		GeeList* _tmp19_;
		GeeList* _tmp20_;
		gpointer _tmp21_;
		GXmlCssSelector* _tmp22_;
		GXmlCssSelector* _tmp23_;
		GXmlCssSelectorType _tmp24_;
		GXmlCssSelectorType _tmp25_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp26_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp27_;
		GXmlDomElement* _tmp28_;
		GXmlGomDocument* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomNode* _tmp31_;
		GXmlDomNode* _tmp32_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp33_;
		GXmlDomElement* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomNode* _tmp38_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomElement* _tmp42_;
		GXmlDomElement* _tmp43_;
		GXmlDomNode* _tmp44_;
		GXmlDomNode* _tmp45_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlDomNode* _tmp51_;
		GXmlDomNode* _tmp52_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomElement* _tmp56_;
		GXmlDomElement* _tmp57_;
		GXmlDomNode* _tmp58_;
		GXmlDomNode* _tmp59_;
		gboolean _tmp60_ = FALSE;
		GXmlCssSelectorParser* _tmp61_;
		GXmlDomElement* _tmp62_;
		gboolean _tmp63_ = FALSE;
		GXmlCssSelectorParser* _tmp64_;
		GXmlDomElement* _tmp65_;
		gboolean _tmp66_ = FALSE;
		GXmlCssSelectorParser* _tmp67_;
		GXmlDomElement* _tmp68_;
		gboolean _tmp69_ = FALSE;
		GXmlCssSelectorParser* _tmp70_;
		GXmlDomElement* _tmp71_;
		gboolean _tmp72_ = FALSE;
		GXmlCssSelectorParser* _tmp73_;
		GXmlDomElement* _tmp74_;
#line 199 "CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 199 "CssSelectorTest.vala"
		cp = _tmp0_;
#line 200 "CssSelectorTest.vala"
		_tmp1_ = cp;
#line 200 "CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "child[prop-name$=\"val\"]", &_inner_error0_);
#line 200 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 200 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3476 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 201 "CssSelectorTest.vala"
		_tmp2_ = cp;
#line 201 "CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 201 "CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 201 "CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 201 "CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 201 "CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 2, "cp.selectors.size == 2");
#line 202 "CssSelectorTest.vala"
		_tmp7_ = cp;
#line 202 "CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 202 "CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 202 "CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 202 "CssSelectorTest.vala"
		s = (GXmlCssSelector*) _tmp10_;
#line 203 "CssSelectorTest.vala"
		_tmp11_ = s;
#line 203 "CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 204 "CssSelectorTest.vala"
		_tmp12_ = s;
#line 204 "CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_get_selector_type (_tmp12_);
#line 204 "CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 204 "CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 205 "CssSelectorTest.vala"
		_tmp15_ = s;
#line 205 "CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_get_combiner (_tmp15_);
#line 205 "CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 205 "CssSelectorTest.vala"
		_vala_assert (_tmp17_ == GXML_CSS_COMBINER_NONE, "s.combiner == CssCombiner.NONE");
#line 206 "CssSelectorTest.vala"
		_tmp18_ = cp;
#line 206 "CssSelectorTest.vala"
		_tmp19_ = gxml_css_selector_parser_get_selectors (_tmp18_);
#line 206 "CssSelectorTest.vala"
		_tmp20_ = _tmp19_;
#line 206 "CssSelectorTest.vala"
		_tmp21_ = gee_list_get (_tmp20_, 1);
#line 206 "CssSelectorTest.vala"
		sa = (GXmlCssSelector*) _tmp21_;
#line 207 "CssSelectorTest.vala"
		_tmp22_ = sa;
#line 207 "CssSelectorTest.vala"
		_vala_assert (_tmp22_ != NULL, "sa != null");
#line 208 "CssSelectorTest.vala"
		_tmp23_ = sa;
#line 208 "CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_get_selector_type (_tmp23_);
#line 208 "CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 208 "CssSelectorTest.vala"
		_vala_assert (_tmp25_ == GXML_CSS_SELECTOR_TYPE_ATTRIBUTE_ENDS_WITH, "sa.selector_type == CssSelectorType.ATTRIBUTE_ENDS_WITH");
#line 209 "CssSelectorTest.vala"
		_tmp26_ = gxml_gom_document_new ();
#line 209 "CssSelectorTest.vala"
		d = _tmp26_;
#line 210 "CssSelectorTest.vala"
		_tmp27_ = d;
#line 210 "CssSelectorTest.vala"
		_tmp28_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp27_, "root", &_inner_error0_);
#line 210 "CssSelectorTest.vala"
		r = _tmp28_;
#line 210 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 210 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 210 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 210 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 210 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3563 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 211 "CssSelectorTest.vala"
		_tmp29_ = d;
#line 211 "CssSelectorTest.vala"
		_tmp30_ = r;
#line 211 "CssSelectorTest.vala"
		_tmp31_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp29_, (GXmlDomNode*) _tmp30_, &_inner_error0_);
#line 211 "CssSelectorTest.vala"
		_tmp32_ = _tmp31_;
#line 211 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp32_);
#line 211 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 211 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 211 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 211 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 211 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 211 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3588 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 212 "CssSelectorTest.vala"
		_tmp33_ = d;
#line 212 "CssSelectorTest.vala"
		_tmp34_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp33_, "child", &_inner_error0_);
#line 212 "CssSelectorTest.vala"
		c1 = _tmp34_;
#line 212 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 212 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 212 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 212 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 212 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 212 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3609 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 213 "CssSelectorTest.vala"
		_tmp35_ = r;
#line 213 "CssSelectorTest.vala"
		_tmp36_ = c1;
#line 213 "CssSelectorTest.vala"
		_tmp37_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp35_, (GXmlDomNode*) _tmp36_, &_inner_error0_);
#line 213 "CssSelectorTest.vala"
		_tmp38_ = _tmp37_;
#line 213 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp38_);
#line 213 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 213 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 213 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 213 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 213 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 213 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 213 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3636 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 214 "CssSelectorTest.vala"
		_tmp39_ = d;
#line 214 "CssSelectorTest.vala"
		_tmp40_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp39_, "child", &_inner_error0_);
#line 214 "CssSelectorTest.vala"
		c2 = _tmp40_;
#line 214 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 214 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 214 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 214 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 214 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 214 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 214 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3659 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 215 "CssSelectorTest.vala"
		_tmp41_ = c2;
#line 215 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp41_, "prop-name", "subval", &_inner_error0_);
#line 215 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 215 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 215 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 215 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 215 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 215 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 215 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 215 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3682 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 216 "CssSelectorTest.vala"
		_tmp42_ = r;
#line 216 "CssSelectorTest.vala"
		_tmp43_ = c2;
#line 216 "CssSelectorTest.vala"
		_tmp44_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp42_, (GXmlDomNode*) _tmp43_, &_inner_error0_);
#line 216 "CssSelectorTest.vala"
		_tmp45_ = _tmp44_;
#line 216 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp45_);
#line 216 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 216 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 216 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 216 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 216 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 216 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 216 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 216 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3711 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 217 "CssSelectorTest.vala"
		_tmp46_ = d;
#line 217 "CssSelectorTest.vala"
		_tmp47_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp46_, "child", &_inner_error0_);
#line 217 "CssSelectorTest.vala"
		c3 = _tmp47_;
#line 217 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 217 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 217 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 217 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 217 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 217 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 217 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 217 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3736 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 218 "CssSelectorTest.vala"
		_tmp48_ = c3;
#line 218 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp48_, "prop-name", "techval", &_inner_error0_);
#line 218 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 218 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 218 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 218 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 218 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 218 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 218 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 218 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 218 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3761 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 219 "CssSelectorTest.vala"
		_tmp49_ = r;
#line 219 "CssSelectorTest.vala"
		_tmp50_ = c3;
#line 219 "CssSelectorTest.vala"
		_tmp51_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp49_, (GXmlDomNode*) _tmp50_, &_inner_error0_);
#line 219 "CssSelectorTest.vala"
		_tmp52_ = _tmp51_;
#line 219 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp52_);
#line 219 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 219 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 219 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 219 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 219 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 219 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 219 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 219 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 219 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3792 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 220 "CssSelectorTest.vala"
		_tmp53_ = d;
#line 220 "CssSelectorTest.vala"
		_tmp54_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp53_, "child", &_inner_error0_);
#line 220 "CssSelectorTest.vala"
		c4 = _tmp54_;
#line 220 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 220 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 220 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 220 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 220 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 220 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 220 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 220 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 220 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3819 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 221 "CssSelectorTest.vala"
		_tmp55_ = c4;
#line 221 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp55_, "prop-name", "secondaryvalue", &_inner_error0_);
#line 221 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 221 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 221 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 221 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 221 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 221 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 221 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 221 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 221 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 221 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3846 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 222 "CssSelectorTest.vala"
		_tmp56_ = r;
#line 222 "CssSelectorTest.vala"
		_tmp57_ = c4;
#line 222 "CssSelectorTest.vala"
		_tmp58_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp56_, (GXmlDomNode*) _tmp57_, &_inner_error0_);
#line 222 "CssSelectorTest.vala"
		_tmp59_ = _tmp58_;
#line 222 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp59_);
#line 222 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 222 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 222 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 222 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 222 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 222 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 222 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 222 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 222 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 222 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3879 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 223 "CssSelectorTest.vala"
		_tmp61_ = cp;
#line 223 "CssSelectorTest.vala"
		_tmp62_ = r;
#line 223 "CssSelectorTest.vala"
		_tmp60_ = gxml_css_selector_parser_match (_tmp61_, _tmp62_, &_inner_error0_);
#line 223 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 223 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 223 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 223 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 223 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 223 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 223 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 223 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 223 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 223 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3908 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 223 "CssSelectorTest.vala"
		_vala_assert (!_tmp60_, "!cp.match (r)");
#line 224 "CssSelectorTest.vala"
		_tmp64_ = cp;
#line 224 "CssSelectorTest.vala"
		_tmp65_ = c1;
#line 224 "CssSelectorTest.vala"
		_tmp63_ = gxml_css_selector_parser_match (_tmp64_, _tmp65_, &_inner_error0_);
#line 224 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 224 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 224 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 224 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 224 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 224 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 224 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 224 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 224 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 224 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3939 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 224 "CssSelectorTest.vala"
		_vala_assert (!_tmp63_, "!cp.match (c1)");
#line 225 "CssSelectorTest.vala"
		_tmp67_ = cp;
#line 225 "CssSelectorTest.vala"
		_tmp68_ = c2;
#line 225 "CssSelectorTest.vala"
		_tmp66_ = gxml_css_selector_parser_match (_tmp67_, _tmp68_, &_inner_error0_);
#line 225 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 225 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 225 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 225 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 225 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 225 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 225 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 225 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 225 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 225 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 3970 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 225 "CssSelectorTest.vala"
		_vala_assert (_tmp66_, "cp.match (c2)");
#line 226 "CssSelectorTest.vala"
		_tmp70_ = cp;
#line 226 "CssSelectorTest.vala"
		_tmp71_ = c3;
#line 226 "CssSelectorTest.vala"
		_tmp69_ = gxml_css_selector_parser_match (_tmp70_, _tmp71_, &_inner_error0_);
#line 226 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 226 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 226 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 226 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 226 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 226 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 226 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 226 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 226 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 226 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4001 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 226 "CssSelectorTest.vala"
		_vala_assert (_tmp69_, "cp.match (c3)");
#line 227 "CssSelectorTest.vala"
		_tmp73_ = cp;
#line 227 "CssSelectorTest.vala"
		_tmp74_ = c4;
#line 227 "CssSelectorTest.vala"
		_tmp72_ = gxml_css_selector_parser_match (_tmp73_, _tmp74_, &_inner_error0_);
#line 227 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 227 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 227 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 227 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 227 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 227 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 227 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 227 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 227 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 227 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4032 "CssSelectorTest.c"
			goto __catch6_g_error;
		}
#line 227 "CssSelectorTest.vala"
		_vala_assert (!_tmp72_, "!cp.match (c4)");
#line 198 "CssSelectorTest.vala"
		_g_object_unref0 (c4);
#line 198 "CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 198 "CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 198 "CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 198 "CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 198 "CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 198 "CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 198 "CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 198 "CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 4055 "CssSelectorTest.c"
	}
	goto __finally6;
	__catch6_g_error:
	{
		GError* e = NULL;
		GError* _tmp75_;
		const gchar* _tmp76_;
		gchar* _tmp77_;
		gchar* _tmp78_;
#line 198 "CssSelectorTest.vala"
		e = _inner_error0_;
#line 198 "CssSelectorTest.vala"
		_inner_error0_ = NULL;
#line 229 "CssSelectorTest.vala"
		_tmp75_ = e;
#line 229 "CssSelectorTest.vala"
		_tmp76_ = _tmp75_->message;
#line 229 "CssSelectorTest.vala"
		_tmp77_ = g_strconcat ("ERROR: ", _tmp76_, NULL);
#line 229 "CssSelectorTest.vala"
		_tmp78_ = _tmp77_;
#line 229 "CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:229: %s", _tmp78_);
#line 229 "CssSelectorTest.vala"
		_g_free0 (_tmp78_);
#line 198 "CssSelectorTest.vala"
		_g_error_free0 (e);
#line 4083 "CssSelectorTest.c"
	}
	__finally6:
#line 198 "CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 198 "CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 198 "CssSelectorTest.vala"
		g_clear_error (&_inner_error0_);
#line 198 "CssSelectorTest.vala"
		return;
#line 4094 "CssSelectorTest.c"
	}
}

static void
___lambda151__gtest_func (void)
{
#line 197 "CssSelectorTest.vala"
	__lambda151_ ();
#line 4103 "CssSelectorTest.c"
}

static void
__lambda152_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelector* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelector* _tmp11_;
		GXmlCssSelector* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelector* _tmp15_;
		GXmlCssCombiner _tmp16_;
		GXmlCssCombiner _tmp17_;
		GXmlCssSelector* sa = NULL;
		GXmlCssSelectorParser* _tmp18_;
		GeeList* _tmp19_;
		GeeList* _tmp20_;
		gpointer _tmp21_;
		GXmlCssSelector* _tmp22_;
		GXmlCssSelector* _tmp23_;
		GXmlCssSelectorType _tmp24_;
		GXmlCssSelectorType _tmp25_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp26_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp27_;
		GXmlDomElement* _tmp28_;
		GXmlGomDocument* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomNode* _tmp31_;
		GXmlDomNode* _tmp32_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp33_;
		GXmlDomElement* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomNode* _tmp38_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp42_;
		GXmlDomElement* _tmp43_;
		GXmlDomElement* _tmp44_;
		GXmlDomElement* _tmp45_;
		GXmlDomElement* _tmp46_;
		GXmlDomNode* _tmp47_;
		GXmlDomNode* _tmp48_;
		gboolean _tmp49_ = FALSE;
		GXmlCssSelectorParser* _tmp50_;
		GXmlDomElement* _tmp51_;
		gboolean _tmp52_ = FALSE;
		GXmlCssSelectorParser* _tmp53_;
		GXmlDomElement* _tmp54_;
		gboolean _tmp55_ = FALSE;
		GXmlCssSelectorParser* _tmp56_;
		GXmlDomElement* _tmp57_;
		gboolean _tmp58_ = FALSE;
		GXmlCssSelectorParser* _tmp59_;
		GXmlDomElement* _tmp60_;
#line 234 "CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 234 "CssSelectorTest.vala"
		cp = _tmp0_;
#line 235 "CssSelectorTest.vala"
		_tmp1_ = cp;
#line 235 "CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "child[prop-name=va7u3_unqu§ted]", &_inner_error0_);
#line 235 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 235 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4192 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 236 "CssSelectorTest.vala"
		_tmp2_ = cp;
#line 236 "CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 236 "CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 236 "CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 236 "CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 236 "CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 2, "cp.selectors.size == 2");
#line 237 "CssSelectorTest.vala"
		_tmp7_ = cp;
#line 237 "CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 237 "CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 237 "CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 237 "CssSelectorTest.vala"
		s = (GXmlCssSelector*) _tmp10_;
#line 238 "CssSelectorTest.vala"
		_tmp11_ = s;
#line 238 "CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 239 "CssSelectorTest.vala"
		_tmp12_ = s;
#line 239 "CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_get_selector_type (_tmp12_);
#line 239 "CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 239 "CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 240 "CssSelectorTest.vala"
		_tmp15_ = s;
#line 240 "CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_get_combiner (_tmp15_);
#line 240 "CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 240 "CssSelectorTest.vala"
		_vala_assert (_tmp17_ == GXML_CSS_COMBINER_NONE, "s.combiner == CssCombiner.NONE");
#line 241 "CssSelectorTest.vala"
		_tmp18_ = cp;
#line 241 "CssSelectorTest.vala"
		_tmp19_ = gxml_css_selector_parser_get_selectors (_tmp18_);
#line 241 "CssSelectorTest.vala"
		_tmp20_ = _tmp19_;
#line 241 "CssSelectorTest.vala"
		_tmp21_ = gee_list_get (_tmp20_, 1);
#line 241 "CssSelectorTest.vala"
		sa = (GXmlCssSelector*) _tmp21_;
#line 242 "CssSelectorTest.vala"
		_tmp22_ = sa;
#line 242 "CssSelectorTest.vala"
		_vala_assert (_tmp22_ != NULL, "sa != null");
#line 243 "CssSelectorTest.vala"
		_tmp23_ = sa;
#line 243 "CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_get_selector_type (_tmp23_);
#line 243 "CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 243 "CssSelectorTest.vala"
		_vala_assert (_tmp25_ == GXML_CSS_SELECTOR_TYPE_ATTRIBUTE_EQUAL, "sa.selector_type == CssSelectorType.ATTRIBUTE_EQUAL");
#line 244 "CssSelectorTest.vala"
		_tmp26_ = gxml_gom_document_new ();
#line 244 "CssSelectorTest.vala"
		d = _tmp26_;
#line 245 "CssSelectorTest.vala"
		_tmp27_ = d;
#line 245 "CssSelectorTest.vala"
		_tmp28_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp27_, "root", &_inner_error0_);
#line 245 "CssSelectorTest.vala"
		r = _tmp28_;
#line 245 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 245 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 245 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 245 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 245 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4279 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 246 "CssSelectorTest.vala"
		_tmp29_ = d;
#line 246 "CssSelectorTest.vala"
		_tmp30_ = r;
#line 246 "CssSelectorTest.vala"
		_tmp31_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp29_, (GXmlDomNode*) _tmp30_, &_inner_error0_);
#line 246 "CssSelectorTest.vala"
		_tmp32_ = _tmp31_;
#line 246 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp32_);
#line 246 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 246 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 246 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 246 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 246 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 246 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4304 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 247 "CssSelectorTest.vala"
		_tmp33_ = d;
#line 247 "CssSelectorTest.vala"
		_tmp34_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp33_, "child", &_inner_error0_);
#line 247 "CssSelectorTest.vala"
		c1 = _tmp34_;
#line 247 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 247 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 247 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 247 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 247 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 247 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4325 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 248 "CssSelectorTest.vala"
		_tmp35_ = r;
#line 248 "CssSelectorTest.vala"
		_tmp36_ = c1;
#line 248 "CssSelectorTest.vala"
		_tmp37_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp35_, (GXmlDomNode*) _tmp36_, &_inner_error0_);
#line 248 "CssSelectorTest.vala"
		_tmp38_ = _tmp37_;
#line 248 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp38_);
#line 248 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 248 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 248 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 248 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 248 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 248 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 248 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4352 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 249 "CssSelectorTest.vala"
		_tmp39_ = d;
#line 249 "CssSelectorTest.vala"
		_tmp40_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp39_, "child", &_inner_error0_);
#line 249 "CssSelectorTest.vala"
		c2 = _tmp40_;
#line 249 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 249 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 249 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 249 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 249 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 249 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 249 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4375 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 250 "CssSelectorTest.vala"
		_tmp41_ = c2;
#line 250 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp41_, "prop-name", "t", &_inner_error0_);
#line 250 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 250 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 250 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 250 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 250 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 250 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 250 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 250 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4398 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 251 "CssSelectorTest.vala"
		_tmp42_ = d;
#line 251 "CssSelectorTest.vala"
		_tmp43_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp42_, "child", &_inner_error0_);
#line 251 "CssSelectorTest.vala"
		c3 = _tmp43_;
#line 251 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 251 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 251 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 251 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 251 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 251 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 251 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 251 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4423 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 252 "CssSelectorTest.vala"
		_tmp44_ = c3;
#line 252 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp44_, "prop-name", "va7u3_unqu§ted", &_inner_error0_);
#line 252 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 252 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 252 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 252 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 252 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 252 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 252 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 252 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 252 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4448 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 253 "CssSelectorTest.vala"
		_tmp45_ = r;
#line 253 "CssSelectorTest.vala"
		_tmp46_ = c3;
#line 253 "CssSelectorTest.vala"
		_tmp47_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp45_, (GXmlDomNode*) _tmp46_, &_inner_error0_);
#line 253 "CssSelectorTest.vala"
		_tmp48_ = _tmp47_;
#line 253 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp48_);
#line 253 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 253 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 253 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 253 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 253 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 253 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 253 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 253 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 253 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4479 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 254 "CssSelectorTest.vala"
		_tmp50_ = cp;
#line 254 "CssSelectorTest.vala"
		_tmp51_ = r;
#line 254 "CssSelectorTest.vala"
		_tmp49_ = gxml_css_selector_parser_match (_tmp50_, _tmp51_, &_inner_error0_);
#line 254 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 254 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 254 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 254 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 254 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 254 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 254 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 254 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 254 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4506 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 254 "CssSelectorTest.vala"
		_vala_assert (!_tmp49_, "!cp.match (r)");
#line 255 "CssSelectorTest.vala"
		_tmp53_ = cp;
#line 255 "CssSelectorTest.vala"
		_tmp54_ = c1;
#line 255 "CssSelectorTest.vala"
		_tmp52_ = gxml_css_selector_parser_match (_tmp53_, _tmp54_, &_inner_error0_);
#line 255 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 255 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 255 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 255 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 255 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 255 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 255 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 255 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 255 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4535 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 255 "CssSelectorTest.vala"
		_vala_assert (!_tmp52_, "!cp.match (c1)");
#line 256 "CssSelectorTest.vala"
		_tmp56_ = cp;
#line 256 "CssSelectorTest.vala"
		_tmp57_ = c2;
#line 256 "CssSelectorTest.vala"
		_tmp55_ = gxml_css_selector_parser_match (_tmp56_, _tmp57_, &_inner_error0_);
#line 256 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 256 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 256 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 256 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 256 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 256 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 256 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 256 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 256 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4564 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 256 "CssSelectorTest.vala"
		_vala_assert (!_tmp55_, "!cp.match (c2)");
#line 257 "CssSelectorTest.vala"
		_tmp59_ = cp;
#line 257 "CssSelectorTest.vala"
		_tmp60_ = c3;
#line 257 "CssSelectorTest.vala"
		_tmp58_ = gxml_css_selector_parser_match (_tmp59_, _tmp60_, &_inner_error0_);
#line 257 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 257 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 257 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 257 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 257 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 257 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 257 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 257 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 257 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4593 "CssSelectorTest.c"
			goto __catch7_g_error;
		}
#line 257 "CssSelectorTest.vala"
		_vala_assert (_tmp58_, "cp.match (c3)");
#line 233 "CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 233 "CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 233 "CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 233 "CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 233 "CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 233 "CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 233 "CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 233 "CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 4614 "CssSelectorTest.c"
	}
	goto __finally7;
	__catch7_g_error:
	{
		GError* e = NULL;
		GError* _tmp61_;
		const gchar* _tmp62_;
		gchar* _tmp63_;
		gchar* _tmp64_;
#line 233 "CssSelectorTest.vala"
		e = _inner_error0_;
#line 233 "CssSelectorTest.vala"
		_inner_error0_ = NULL;
#line 259 "CssSelectorTest.vala"
		_tmp61_ = e;
#line 259 "CssSelectorTest.vala"
		_tmp62_ = _tmp61_->message;
#line 259 "CssSelectorTest.vala"
		_tmp63_ = g_strconcat ("ERROR: ", _tmp62_, NULL);
#line 259 "CssSelectorTest.vala"
		_tmp64_ = _tmp63_;
#line 259 "CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:259: %s", _tmp64_);
#line 259 "CssSelectorTest.vala"
		_g_free0 (_tmp64_);
#line 233 "CssSelectorTest.vala"
		_g_error_free0 (e);
#line 4642 "CssSelectorTest.c"
	}
	__finally7:
#line 233 "CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 233 "CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 233 "CssSelectorTest.vala"
		g_clear_error (&_inner_error0_);
#line 233 "CssSelectorTest.vala"
		return;
#line 4653 "CssSelectorTest.c"
	}
}

static void
___lambda152__gtest_func (void)
{
#line 232 "CssSelectorTest.vala"
	__lambda152_ ();
#line 4662 "CssSelectorTest.c"
}

static void
__lambda153_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelector* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelector* _tmp11_;
		GXmlCssSelector* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelector* _tmp15_;
		GXmlCssCombiner _tmp16_;
		GXmlCssCombiner _tmp17_;
		GXmlCssSelector* sa = NULL;
		GXmlCssSelectorParser* _tmp18_;
		GeeList* _tmp19_;
		GeeList* _tmp20_;
		gpointer _tmp21_;
		GXmlCssSelector* _tmp22_;
		GXmlCssSelector* _tmp23_;
		GXmlCssSelectorType _tmp24_;
		GXmlCssSelectorType _tmp25_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp26_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp27_;
		GXmlDomElement* _tmp28_;
		GXmlGomDocument* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomNode* _tmp31_;
		GXmlDomNode* _tmp32_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp33_;
		GXmlDomElement* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomNode* _tmp38_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp42_;
		GXmlDomElement* _tmp43_;
		GXmlDomElement* _tmp44_;
		GXmlDomElement* _tmp45_;
		GXmlDomElement* _tmp46_;
		GXmlDomNode* _tmp47_;
		GXmlDomNode* _tmp48_;
		gboolean _tmp49_ = FALSE;
		GXmlCssSelectorParser* _tmp50_;
		GXmlDomElement* _tmp51_;
		gboolean _tmp52_ = FALSE;
		GXmlCssSelectorParser* _tmp53_;
		GXmlDomElement* _tmp54_;
		gboolean _tmp55_ = FALSE;
		GXmlCssSelectorParser* _tmp56_;
		GXmlDomElement* _tmp57_;
		gboolean _tmp58_ = FALSE;
		GXmlCssSelectorParser* _tmp59_;
		GXmlDomElement* _tmp60_;
#line 264 "CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 264 "CssSelectorTest.vala"
		cp = _tmp0_;
#line 265 "CssSelectorTest.vala"
		_tmp1_ = cp;
#line 265 "CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "child[prop-name=\"val\"]", &_inner_error0_);
#line 265 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 265 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4751 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 266 "CssSelectorTest.vala"
		_tmp2_ = cp;
#line 266 "CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 266 "CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 266 "CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 266 "CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 266 "CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 2, "cp.selectors.size == 2");
#line 267 "CssSelectorTest.vala"
		_tmp7_ = cp;
#line 267 "CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 267 "CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 267 "CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 267 "CssSelectorTest.vala"
		s = (GXmlCssSelector*) _tmp10_;
#line 268 "CssSelectorTest.vala"
		_tmp11_ = s;
#line 268 "CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 269 "CssSelectorTest.vala"
		_tmp12_ = s;
#line 269 "CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_get_selector_type (_tmp12_);
#line 269 "CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 269 "CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 270 "CssSelectorTest.vala"
		_tmp15_ = s;
#line 270 "CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_get_combiner (_tmp15_);
#line 270 "CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 270 "CssSelectorTest.vala"
		_vala_assert (_tmp17_ == GXML_CSS_COMBINER_NONE, "s.combiner == CssCombiner.NONE");
#line 271 "CssSelectorTest.vala"
		_tmp18_ = cp;
#line 271 "CssSelectorTest.vala"
		_tmp19_ = gxml_css_selector_parser_get_selectors (_tmp18_);
#line 271 "CssSelectorTest.vala"
		_tmp20_ = _tmp19_;
#line 271 "CssSelectorTest.vala"
		_tmp21_ = gee_list_get (_tmp20_, 1);
#line 271 "CssSelectorTest.vala"
		sa = (GXmlCssSelector*) _tmp21_;
#line 272 "CssSelectorTest.vala"
		_tmp22_ = sa;
#line 272 "CssSelectorTest.vala"
		_vala_assert (_tmp22_ != NULL, "sa != null");
#line 273 "CssSelectorTest.vala"
		_tmp23_ = sa;
#line 273 "CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_get_selector_type (_tmp23_);
#line 273 "CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 273 "CssSelectorTest.vala"
		_vala_assert (_tmp25_ == GXML_CSS_SELECTOR_TYPE_ATTRIBUTE_EQUAL, "sa.selector_type == CssSelectorType.ATTRIBUTE_EQUAL");
#line 274 "CssSelectorTest.vala"
		_tmp26_ = gxml_gom_document_new ();
#line 274 "CssSelectorTest.vala"
		d = _tmp26_;
#line 275 "CssSelectorTest.vala"
		_tmp27_ = d;
#line 275 "CssSelectorTest.vala"
		_tmp28_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp27_, "root", &_inner_error0_);
#line 275 "CssSelectorTest.vala"
		r = _tmp28_;
#line 275 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 275 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 275 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 275 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 275 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4838 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 276 "CssSelectorTest.vala"
		_tmp29_ = d;
#line 276 "CssSelectorTest.vala"
		_tmp30_ = r;
#line 276 "CssSelectorTest.vala"
		_tmp31_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp29_, (GXmlDomNode*) _tmp30_, &_inner_error0_);
#line 276 "CssSelectorTest.vala"
		_tmp32_ = _tmp31_;
#line 276 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp32_);
#line 276 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 276 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 276 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 276 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 276 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 276 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4863 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 277 "CssSelectorTest.vala"
		_tmp33_ = d;
#line 277 "CssSelectorTest.vala"
		_tmp34_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp33_, "child", &_inner_error0_);
#line 277 "CssSelectorTest.vala"
		c1 = _tmp34_;
#line 277 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 277 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 277 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 277 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 277 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 277 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4884 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 278 "CssSelectorTest.vala"
		_tmp35_ = r;
#line 278 "CssSelectorTest.vala"
		_tmp36_ = c1;
#line 278 "CssSelectorTest.vala"
		_tmp37_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp35_, (GXmlDomNode*) _tmp36_, &_inner_error0_);
#line 278 "CssSelectorTest.vala"
		_tmp38_ = _tmp37_;
#line 278 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp38_);
#line 278 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 278 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 278 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 278 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 278 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 278 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 278 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4911 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 279 "CssSelectorTest.vala"
		_tmp39_ = d;
#line 279 "CssSelectorTest.vala"
		_tmp40_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp39_, "child", &_inner_error0_);
#line 279 "CssSelectorTest.vala"
		c2 = _tmp40_;
#line 279 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 279 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 279 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 279 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 279 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 279 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 279 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4934 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 280 "CssSelectorTest.vala"
		_tmp41_ = c2;
#line 280 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp41_, "prop-name", "t", &_inner_error0_);
#line 280 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 280 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 280 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 280 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 280 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 280 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 280 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 280 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4957 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 281 "CssSelectorTest.vala"
		_tmp42_ = d;
#line 281 "CssSelectorTest.vala"
		_tmp43_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp42_, "child", &_inner_error0_);
#line 281 "CssSelectorTest.vala"
		c3 = _tmp43_;
#line 281 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 281 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 281 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 281 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 281 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 281 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 281 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 281 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 4982 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 282 "CssSelectorTest.vala"
		_tmp44_ = c3;
#line 282 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp44_, "prop-name", "val", &_inner_error0_);
#line 282 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 282 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 282 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 282 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 282 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 282 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 282 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 282 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 282 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5007 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 283 "CssSelectorTest.vala"
		_tmp45_ = r;
#line 283 "CssSelectorTest.vala"
		_tmp46_ = c3;
#line 283 "CssSelectorTest.vala"
		_tmp47_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp45_, (GXmlDomNode*) _tmp46_, &_inner_error0_);
#line 283 "CssSelectorTest.vala"
		_tmp48_ = _tmp47_;
#line 283 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp48_);
#line 283 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 283 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 283 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 283 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 283 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 283 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 283 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 283 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 283 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5038 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 284 "CssSelectorTest.vala"
		_tmp50_ = cp;
#line 284 "CssSelectorTest.vala"
		_tmp51_ = r;
#line 284 "CssSelectorTest.vala"
		_tmp49_ = gxml_css_selector_parser_match (_tmp50_, _tmp51_, &_inner_error0_);
#line 284 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 284 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 284 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 284 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 284 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 284 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 284 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 284 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 284 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5065 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 284 "CssSelectorTest.vala"
		_vala_assert (!_tmp49_, "!cp.match (r)");
#line 285 "CssSelectorTest.vala"
		_tmp53_ = cp;
#line 285 "CssSelectorTest.vala"
		_tmp54_ = c1;
#line 285 "CssSelectorTest.vala"
		_tmp52_ = gxml_css_selector_parser_match (_tmp53_, _tmp54_, &_inner_error0_);
#line 285 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 285 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 285 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 285 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 285 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 285 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 285 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 285 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 285 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5094 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 285 "CssSelectorTest.vala"
		_vala_assert (!_tmp52_, "!cp.match (c1)");
#line 286 "CssSelectorTest.vala"
		_tmp56_ = cp;
#line 286 "CssSelectorTest.vala"
		_tmp57_ = c2;
#line 286 "CssSelectorTest.vala"
		_tmp55_ = gxml_css_selector_parser_match (_tmp56_, _tmp57_, &_inner_error0_);
#line 286 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 286 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 286 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 286 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 286 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 286 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 286 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 286 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 286 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5123 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 286 "CssSelectorTest.vala"
		_vala_assert (!_tmp55_, "!cp.match (c2)");
#line 287 "CssSelectorTest.vala"
		_tmp59_ = cp;
#line 287 "CssSelectorTest.vala"
		_tmp60_ = c3;
#line 287 "CssSelectorTest.vala"
		_tmp58_ = gxml_css_selector_parser_match (_tmp59_, _tmp60_, &_inner_error0_);
#line 287 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 287 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 287 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 287 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 287 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 287 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 287 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 287 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 287 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5152 "CssSelectorTest.c"
			goto __catch8_g_error;
		}
#line 287 "CssSelectorTest.vala"
		_vala_assert (_tmp58_, "cp.match (c3)");
#line 263 "CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 263 "CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 263 "CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 263 "CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 263 "CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 263 "CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 263 "CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 263 "CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 5173 "CssSelectorTest.c"
	}
	goto __finally8;
	__catch8_g_error:
	{
		GError* e = NULL;
		GError* _tmp61_;
		const gchar* _tmp62_;
		gchar* _tmp63_;
		gchar* _tmp64_;
#line 263 "CssSelectorTest.vala"
		e = _inner_error0_;
#line 263 "CssSelectorTest.vala"
		_inner_error0_ = NULL;
#line 289 "CssSelectorTest.vala"
		_tmp61_ = e;
#line 289 "CssSelectorTest.vala"
		_tmp62_ = _tmp61_->message;
#line 289 "CssSelectorTest.vala"
		_tmp63_ = g_strconcat ("ERROR: ", _tmp62_, NULL);
#line 289 "CssSelectorTest.vala"
		_tmp64_ = _tmp63_;
#line 289 "CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:289: %s", _tmp64_);
#line 289 "CssSelectorTest.vala"
		_g_free0 (_tmp64_);
#line 263 "CssSelectorTest.vala"
		_g_error_free0 (e);
#line 5201 "CssSelectorTest.c"
	}
	__finally8:
#line 263 "CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 263 "CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 263 "CssSelectorTest.vala"
		g_clear_error (&_inner_error0_);
#line 263 "CssSelectorTest.vala"
		return;
#line 5212 "CssSelectorTest.c"
	}
}

static void
___lambda153__gtest_func (void)
{
#line 262 "CssSelectorTest.vala"
	__lambda153_ ();
#line 5221 "CssSelectorTest.c"
}

static void
__lambda154_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelector* si = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelector* _tmp11_;
		GXmlCssSelector* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp15_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlGomDocument* _tmp18_;
		GXmlDomElement* _tmp19_;
		GXmlDomNode* _tmp20_;
		GXmlDomNode* _tmp21_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp22_;
		GXmlDomElement* _tmp23_;
		GXmlDomElement* _tmp24_;
		GXmlDomElement* _tmp25_;
		GXmlDomElement* _tmp26_;
		GXmlDomNode* _tmp27_;
		GXmlDomNode* _tmp28_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomElement* _tmp31_;
		GXmlDomElement* _tmp32_;
		GXmlDomElement* _tmp33_;
		GXmlDomNode* _tmp34_;
		GXmlDomNode* _tmp35_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp36_;
		GXmlDomElement* _tmp37_;
		GXmlDomElement* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomNode* _tmp41_;
		GXmlDomNode* _tmp42_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp43_;
		GXmlDomElement* _tmp44_;
		GXmlDomElement* _tmp45_;
		GXmlDomElement* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomNode* _tmp48_;
		GXmlDomNode* _tmp49_;
		GXmlDomElement* c5 = NULL;
		GXmlGomDocument* _tmp50_;
		GXmlDomElement* _tmp51_;
		GXmlDomElement* _tmp52_;
		GXmlDomElement* _tmp53_;
		GXmlDomNode* _tmp54_;
		GXmlDomNode* _tmp55_;
		gboolean _tmp56_ = FALSE;
		GXmlCssSelectorParser* _tmp57_;
		GXmlDomElement* _tmp58_;
		gboolean _tmp59_ = FALSE;
		GXmlCssSelectorParser* _tmp60_;
		GXmlDomElement* _tmp61_;
		gboolean _tmp62_ = FALSE;
		GXmlCssSelectorParser* _tmp63_;
		GXmlDomElement* _tmp64_;
		gboolean _tmp65_ = FALSE;
		GXmlCssSelectorParser* _tmp66_;
		GXmlDomElement* _tmp67_;
		gboolean _tmp68_ = FALSE;
		GXmlCssSelectorParser* _tmp69_;
		GXmlDomElement* _tmp70_;
		gboolean _tmp71_ = FALSE;
		GXmlCssSelectorParser* _tmp72_;
		GXmlDomElement* _tmp73_;
#line 294 "CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 294 "CssSelectorTest.vala"
		cp = _tmp0_;
#line 295 "CssSelectorTest.vala"
		_tmp1_ = cp;
#line 295 "CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, ".warning", &_inner_error0_);
#line 295 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 295 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5324 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 296 "CssSelectorTest.vala"
		_tmp2_ = cp;
#line 296 "CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 296 "CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 296 "CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 296 "CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 296 "CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 1, "cp.selectors.size == 1");
#line 297 "CssSelectorTest.vala"
		_tmp7_ = cp;
#line 297 "CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 297 "CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 297 "CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 297 "CssSelectorTest.vala"
		si = (GXmlCssSelector*) _tmp10_;
#line 298 "CssSelectorTest.vala"
		_tmp11_ = si;
#line 298 "CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "si != null");
#line 299 "CssSelectorTest.vala"
		_tmp12_ = si;
#line 299 "CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_get_selector_type (_tmp12_);
#line 299 "CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 299 "CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_CLASS, "si.selector_type == CssSelectorType.CLASS");
#line 300 "CssSelectorTest.vala"
		_tmp15_ = gxml_gom_document_new ();
#line 300 "CssSelectorTest.vala"
		d = _tmp15_;
#line 301 "CssSelectorTest.vala"
		_tmp16_ = d;
#line 301 "CssSelectorTest.vala"
		_tmp17_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp16_, "root", &_inner_error0_);
#line 301 "CssSelectorTest.vala"
		r = _tmp17_;
#line 301 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 301 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 301 "CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 301 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5379 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 302 "CssSelectorTest.vala"
		_tmp18_ = d;
#line 302 "CssSelectorTest.vala"
		_tmp19_ = r;
#line 302 "CssSelectorTest.vala"
		_tmp20_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp18_, (GXmlDomNode*) _tmp19_, &_inner_error0_);
#line 302 "CssSelectorTest.vala"
		_tmp21_ = _tmp20_;
#line 302 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp21_);
#line 302 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 302 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 302 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 302 "CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 302 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5402 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 303 "CssSelectorTest.vala"
		_tmp22_ = d;
#line 303 "CssSelectorTest.vala"
		_tmp23_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp22_, "child", &_inner_error0_);
#line 303 "CssSelectorTest.vala"
		c1 = _tmp23_;
#line 303 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 303 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 303 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 303 "CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 303 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5421 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 304 "CssSelectorTest.vala"
		_tmp24_ = c1;
#line 304 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp24_, "class", "error", &_inner_error0_);
#line 304 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 304 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 304 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 304 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 304 "CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 304 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5440 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 305 "CssSelectorTest.vala"
		_tmp25_ = r;
#line 305 "CssSelectorTest.vala"
		_tmp26_ = c1;
#line 305 "CssSelectorTest.vala"
		_tmp27_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp25_, (GXmlDomNode*) _tmp26_, &_inner_error0_);
#line 305 "CssSelectorTest.vala"
		_tmp28_ = _tmp27_;
#line 305 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp28_);
#line 305 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 305 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 305 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 305 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 305 "CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 305 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5465 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 306 "CssSelectorTest.vala"
		_tmp29_ = d;
#line 306 "CssSelectorTest.vala"
		_tmp30_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp29_, "child", &_inner_error0_);
#line 306 "CssSelectorTest.vala"
		c2 = _tmp30_;
#line 306 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 306 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 306 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 306 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 306 "CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 306 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5486 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 307 "CssSelectorTest.vala"
		_tmp31_ = c2;
#line 307 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp31_, "class", "warning", &_inner_error0_);
#line 307 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 307 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 307 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 307 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 307 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 307 "CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 307 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5507 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 308 "CssSelectorTest.vala"
		_tmp32_ = r;
#line 308 "CssSelectorTest.vala"
		_tmp33_ = c2;
#line 308 "CssSelectorTest.vala"
		_tmp34_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp32_, (GXmlDomNode*) _tmp33_, &_inner_error0_);
#line 308 "CssSelectorTest.vala"
		_tmp35_ = _tmp34_;
#line 308 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp35_);
#line 308 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 308 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 308 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 308 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 308 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 308 "CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 308 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5534 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 309 "CssSelectorTest.vala"
		_tmp36_ = d;
#line 309 "CssSelectorTest.vala"
		_tmp37_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp36_, "child", &_inner_error0_);
#line 309 "CssSelectorTest.vala"
		c3 = _tmp37_;
#line 309 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 309 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 309 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 309 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 309 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 309 "CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 309 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5557 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 310 "CssSelectorTest.vala"
		_tmp38_ = c3;
#line 310 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp38_, "class", "error warning", &_inner_error0_);
#line 310 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 310 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 310 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 310 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 310 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 310 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 310 "CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 310 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5580 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 311 "CssSelectorTest.vala"
		_tmp39_ = r;
#line 311 "CssSelectorTest.vala"
		_tmp40_ = c3;
#line 311 "CssSelectorTest.vala"
		_tmp41_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp39_, (GXmlDomNode*) _tmp40_, &_inner_error0_);
#line 311 "CssSelectorTest.vala"
		_tmp42_ = _tmp41_;
#line 311 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp42_);
#line 311 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 311 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 311 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 311 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 311 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 311 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 311 "CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 311 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5609 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 312 "CssSelectorTest.vala"
		_tmp43_ = d;
#line 312 "CssSelectorTest.vala"
		_tmp44_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp43_, "child", &_inner_error0_);
#line 312 "CssSelectorTest.vala"
		c4 = _tmp44_;
#line 312 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 312 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 312 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 312 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 312 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 312 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 312 "CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 312 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5634 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 313 "CssSelectorTest.vala"
		_tmp45_ = c4;
#line 313 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp45_, "class", "error calc", &_inner_error0_);
#line 313 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 313 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 313 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 313 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 313 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 313 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 313 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 313 "CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 313 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5659 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 314 "CssSelectorTest.vala"
		_tmp46_ = r;
#line 314 "CssSelectorTest.vala"
		_tmp47_ = c4;
#line 314 "CssSelectorTest.vala"
		_tmp48_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp46_, (GXmlDomNode*) _tmp47_, &_inner_error0_);
#line 314 "CssSelectorTest.vala"
		_tmp49_ = _tmp48_;
#line 314 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp49_);
#line 314 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 314 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 314 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 314 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 314 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 314 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 314 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 314 "CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 314 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5690 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 315 "CssSelectorTest.vala"
		_tmp50_ = d;
#line 315 "CssSelectorTest.vala"
		_tmp51_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp50_, "child", &_inner_error0_);
#line 315 "CssSelectorTest.vala"
		c5 = _tmp51_;
#line 315 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 315 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 315 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 315 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 315 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 315 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 315 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 315 "CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 315 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5717 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 316 "CssSelectorTest.vala"
		_tmp52_ = r;
#line 316 "CssSelectorTest.vala"
		_tmp53_ = c5;
#line 316 "CssSelectorTest.vala"
		_tmp54_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp52_, (GXmlDomNode*) _tmp53_, &_inner_error0_);
#line 316 "CssSelectorTest.vala"
		_tmp55_ = _tmp54_;
#line 316 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp55_);
#line 316 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 316 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 316 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 316 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 316 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 316 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 316 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 316 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 316 "CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 316 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5750 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 317 "CssSelectorTest.vala"
		_tmp57_ = cp;
#line 317 "CssSelectorTest.vala"
		_tmp58_ = r;
#line 317 "CssSelectorTest.vala"
		_tmp56_ = gxml_css_selector_parser_match (_tmp57_, _tmp58_, &_inner_error0_);
#line 317 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 317 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 317 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 317 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 317 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 317 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 317 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 317 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 317 "CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 317 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5779 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 317 "CssSelectorTest.vala"
		_vala_assert (!_tmp56_, "!cp.match (r)");
#line 318 "CssSelectorTest.vala"
		_tmp60_ = cp;
#line 318 "CssSelectorTest.vala"
		_tmp61_ = c1;
#line 318 "CssSelectorTest.vala"
		_tmp59_ = gxml_css_selector_parser_match (_tmp60_, _tmp61_, &_inner_error0_);
#line 318 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 318 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 318 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 318 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 318 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 318 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 318 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 318 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 318 "CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 318 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5810 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 318 "CssSelectorTest.vala"
		_vala_assert (!_tmp59_, "!cp.match (c1)");
#line 319 "CssSelectorTest.vala"
		_tmp63_ = cp;
#line 319 "CssSelectorTest.vala"
		_tmp64_ = c2;
#line 319 "CssSelectorTest.vala"
		_tmp62_ = gxml_css_selector_parser_match (_tmp63_, _tmp64_, &_inner_error0_);
#line 319 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 319 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 319 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 319 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 319 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 319 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 319 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 319 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 319 "CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 319 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5841 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 319 "CssSelectorTest.vala"
		_vala_assert (_tmp62_, "cp.match (c2)");
#line 320 "CssSelectorTest.vala"
		_tmp66_ = cp;
#line 320 "CssSelectorTest.vala"
		_tmp67_ = c3;
#line 320 "CssSelectorTest.vala"
		_tmp65_ = gxml_css_selector_parser_match (_tmp66_, _tmp67_, &_inner_error0_);
#line 320 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 320 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 320 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 320 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 320 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 320 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 320 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 320 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 320 "CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 320 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5872 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 320 "CssSelectorTest.vala"
		_vala_assert (_tmp65_, "cp.match (c3)");
#line 321 "CssSelectorTest.vala"
		_tmp69_ = cp;
#line 321 "CssSelectorTest.vala"
		_tmp70_ = c4;
#line 321 "CssSelectorTest.vala"
		_tmp68_ = gxml_css_selector_parser_match (_tmp69_, _tmp70_, &_inner_error0_);
#line 321 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 321 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 321 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 321 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 321 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 321 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 321 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 321 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 321 "CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 321 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5903 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 321 "CssSelectorTest.vala"
		_vala_assert (!_tmp68_, "!cp.match (c4)");
#line 322 "CssSelectorTest.vala"
		_tmp72_ = cp;
#line 322 "CssSelectorTest.vala"
		_tmp73_ = c5;
#line 322 "CssSelectorTest.vala"
		_tmp71_ = gxml_css_selector_parser_match (_tmp72_, _tmp73_, &_inner_error0_);
#line 322 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 322 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 322 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 322 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 322 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 322 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 322 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 322 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 322 "CssSelectorTest.vala"
			_g_object_unref0 (si);
#line 322 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 5934 "CssSelectorTest.c"
			goto __catch9_g_error;
		}
#line 322 "CssSelectorTest.vala"
		_vala_assert (!_tmp71_, "!cp.match (c5)");
#line 293 "CssSelectorTest.vala"
		_g_object_unref0 (c5);
#line 293 "CssSelectorTest.vala"
		_g_object_unref0 (c4);
#line 293 "CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 293 "CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 293 "CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 293 "CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 293 "CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 293 "CssSelectorTest.vala"
		_g_object_unref0 (si);
#line 293 "CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 5957 "CssSelectorTest.c"
	}
	goto __finally9;
	__catch9_g_error:
	{
		GError* e = NULL;
		GError* _tmp74_;
		const gchar* _tmp75_;
		gchar* _tmp76_;
		gchar* _tmp77_;
#line 293 "CssSelectorTest.vala"
		e = _inner_error0_;
#line 293 "CssSelectorTest.vala"
		_inner_error0_ = NULL;
#line 324 "CssSelectorTest.vala"
		_tmp74_ = e;
#line 324 "CssSelectorTest.vala"
		_tmp75_ = _tmp74_->message;
#line 324 "CssSelectorTest.vala"
		_tmp76_ = g_strconcat ("ERROR: ", _tmp75_, NULL);
#line 324 "CssSelectorTest.vala"
		_tmp77_ = _tmp76_;
#line 324 "CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:324: %s", _tmp77_);
#line 324 "CssSelectorTest.vala"
		_g_free0 (_tmp77_);
#line 293 "CssSelectorTest.vala"
		_g_error_free0 (e);
#line 5985 "CssSelectorTest.c"
	}
	__finally9:
#line 293 "CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 293 "CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 293 "CssSelectorTest.vala"
		g_clear_error (&_inner_error0_);
#line 293 "CssSelectorTest.vala"
		return;
#line 5996 "CssSelectorTest.c"
	}
}

static void
___lambda154__gtest_func (void)
{
#line 292 "CssSelectorTest.vala"
	__lambda154_ ();
#line 6005 "CssSelectorTest.c"
}

static void
__lambda155_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelector* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelector* _tmp11_;
		GXmlCssSelector* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelector* _tmp15_;
		GXmlCssCombiner _tmp16_;
		GXmlCssCombiner _tmp17_;
		GXmlCssSelector* sc = NULL;
		GXmlCssSelectorParser* _tmp18_;
		GeeList* _tmp19_;
		GeeList* _tmp20_;
		gpointer _tmp21_;
		GXmlCssSelector* _tmp22_;
		GXmlCssSelector* _tmp23_;
		GXmlCssSelectorType _tmp24_;
		GXmlCssSelectorType _tmp25_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp26_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp27_;
		GXmlDomElement* _tmp28_;
		GXmlGomDocument* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomNode* _tmp31_;
		GXmlDomNode* _tmp32_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp33_;
		GXmlDomElement* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomElement* _tmp37_;
		GXmlDomNode* _tmp38_;
		GXmlDomNode* _tmp39_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomElement* _tmp42_;
		GXmlDomElement* _tmp43_;
		GXmlDomElement* _tmp44_;
		GXmlDomNode* _tmp45_;
		GXmlDomNode* _tmp46_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlDomElement* _tmp51_;
		GXmlDomNode* _tmp52_;
		GXmlDomNode* _tmp53_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomElement* _tmp56_;
		GXmlDomElement* _tmp57_;
		GXmlDomElement* _tmp58_;
		GXmlDomNode* _tmp59_;
		GXmlDomNode* _tmp60_;
		GXmlDomElement* c5 = NULL;
		GXmlGomDocument* _tmp61_;
		GXmlDomElement* _tmp62_;
		GXmlDomElement* _tmp63_;
		GXmlDomElement* _tmp64_;
		GXmlDomNode* _tmp65_;
		GXmlDomNode* _tmp66_;
		gboolean _tmp67_ = FALSE;
		GXmlCssSelectorParser* _tmp68_;
		GXmlDomElement* _tmp69_;
		gboolean _tmp70_ = FALSE;
		GXmlCssSelectorParser* _tmp71_;
		GXmlDomElement* _tmp72_;
		gboolean _tmp73_ = FALSE;
		GXmlCssSelectorParser* _tmp74_;
		GXmlDomElement* _tmp75_;
		gboolean _tmp76_ = FALSE;
		GXmlCssSelectorParser* _tmp77_;
		GXmlDomElement* _tmp78_;
		gboolean _tmp79_ = FALSE;
		GXmlCssSelectorParser* _tmp80_;
		GXmlDomElement* _tmp81_;
		gboolean _tmp82_ = FALSE;
		GXmlCssSelectorParser* _tmp83_;
		GXmlDomElement* _tmp84_;
#line 329 "CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 329 "CssSelectorTest.vala"
		cp = _tmp0_;
#line 330 "CssSelectorTest.vala"
		_tmp1_ = cp;
#line 330 "CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "child.warning", &_inner_error0_);
#line 330 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 330 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6120 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 331 "CssSelectorTest.vala"
		_tmp2_ = cp;
#line 331 "CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 331 "CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 331 "CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 331 "CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 331 "CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 2, "cp.selectors.size == 2");
#line 332 "CssSelectorTest.vala"
		_tmp7_ = cp;
#line 332 "CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 332 "CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 332 "CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 332 "CssSelectorTest.vala"
		s = (GXmlCssSelector*) _tmp10_;
#line 333 "CssSelectorTest.vala"
		_tmp11_ = s;
#line 333 "CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 334 "CssSelectorTest.vala"
		_tmp12_ = s;
#line 334 "CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_get_selector_type (_tmp12_);
#line 334 "CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 334 "CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 335 "CssSelectorTest.vala"
		_tmp15_ = s;
#line 335 "CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_get_combiner (_tmp15_);
#line 335 "CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 335 "CssSelectorTest.vala"
		_vala_assert (_tmp17_ == GXML_CSS_COMBINER_NONE, "s.combiner == CssCombiner.NONE");
#line 336 "CssSelectorTest.vala"
		_tmp18_ = cp;
#line 336 "CssSelectorTest.vala"
		_tmp19_ = gxml_css_selector_parser_get_selectors (_tmp18_);
#line 336 "CssSelectorTest.vala"
		_tmp20_ = _tmp19_;
#line 336 "CssSelectorTest.vala"
		_tmp21_ = gee_list_get (_tmp20_, 1);
#line 336 "CssSelectorTest.vala"
		sc = (GXmlCssSelector*) _tmp21_;
#line 337 "CssSelectorTest.vala"
		_tmp22_ = sc;
#line 337 "CssSelectorTest.vala"
		_vala_assert (_tmp22_ != NULL, "sc != null");
#line 338 "CssSelectorTest.vala"
		_tmp23_ = sc;
#line 338 "CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_get_selector_type (_tmp23_);
#line 338 "CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 338 "CssSelectorTest.vala"
		_vala_assert (_tmp25_ == GXML_CSS_SELECTOR_TYPE_CLASS, "sc.selector_type == CssSelectorType.CLASS");
#line 339 "CssSelectorTest.vala"
		_tmp26_ = gxml_gom_document_new ();
#line 339 "CssSelectorTest.vala"
		d = _tmp26_;
#line 340 "CssSelectorTest.vala"
		_tmp27_ = d;
#line 340 "CssSelectorTest.vala"
		_tmp28_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp27_, "root", &_inner_error0_);
#line 340 "CssSelectorTest.vala"
		r = _tmp28_;
#line 340 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 340 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 340 "CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 340 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 340 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6207 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 341 "CssSelectorTest.vala"
		_tmp29_ = d;
#line 341 "CssSelectorTest.vala"
		_tmp30_ = r;
#line 341 "CssSelectorTest.vala"
		_tmp31_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp29_, (GXmlDomNode*) _tmp30_, &_inner_error0_);
#line 341 "CssSelectorTest.vala"
		_tmp32_ = _tmp31_;
#line 341 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp32_);
#line 341 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 341 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 341 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 341 "CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 341 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 341 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6232 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 342 "CssSelectorTest.vala"
		_tmp33_ = d;
#line 342 "CssSelectorTest.vala"
		_tmp34_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp33_, "children", &_inner_error0_);
#line 342 "CssSelectorTest.vala"
		c1 = _tmp34_;
#line 342 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 342 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 342 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 342 "CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 342 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 342 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6253 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 343 "CssSelectorTest.vala"
		_tmp35_ = c1;
#line 343 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp35_, "class", "error", &_inner_error0_);
#line 343 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 343 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 343 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 343 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 343 "CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 343 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 343 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6274 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 344 "CssSelectorTest.vala"
		_tmp36_ = r;
#line 344 "CssSelectorTest.vala"
		_tmp37_ = c1;
#line 344 "CssSelectorTest.vala"
		_tmp38_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp36_, (GXmlDomNode*) _tmp37_, &_inner_error0_);
#line 344 "CssSelectorTest.vala"
		_tmp39_ = _tmp38_;
#line 344 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp39_);
#line 344 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 344 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 344 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 344 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 344 "CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 344 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 344 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6301 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 345 "CssSelectorTest.vala"
		_tmp40_ = d;
#line 345 "CssSelectorTest.vala"
		_tmp41_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp40_, "child", &_inner_error0_);
#line 345 "CssSelectorTest.vala"
		c2 = _tmp41_;
#line 345 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 345 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 345 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 345 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 345 "CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 345 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 345 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6324 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 346 "CssSelectorTest.vala"
		_tmp42_ = c2;
#line 346 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp42_, "class", "warning", &_inner_error0_);
#line 346 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 346 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 346 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 346 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 346 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 346 "CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 346 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 346 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6347 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 347 "CssSelectorTest.vala"
		_tmp43_ = r;
#line 347 "CssSelectorTest.vala"
		_tmp44_ = c2;
#line 347 "CssSelectorTest.vala"
		_tmp45_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp43_, (GXmlDomNode*) _tmp44_, &_inner_error0_);
#line 347 "CssSelectorTest.vala"
		_tmp46_ = _tmp45_;
#line 347 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp46_);
#line 347 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 347 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 347 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 347 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 347 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 347 "CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 347 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 347 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6376 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 348 "CssSelectorTest.vala"
		_tmp47_ = d;
#line 348 "CssSelectorTest.vala"
		_tmp48_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp47_, "child", &_inner_error0_);
#line 348 "CssSelectorTest.vala"
		c3 = _tmp48_;
#line 348 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 348 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 348 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 348 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 348 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 348 "CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 348 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 348 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6401 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 349 "CssSelectorTest.vala"
		_tmp49_ = c3;
#line 349 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp49_, "class", "error warning", &_inner_error0_);
#line 349 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 349 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 349 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 349 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 349 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 349 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 349 "CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 349 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 349 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6426 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 350 "CssSelectorTest.vala"
		_tmp50_ = r;
#line 350 "CssSelectorTest.vala"
		_tmp51_ = c3;
#line 350 "CssSelectorTest.vala"
		_tmp52_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp50_, (GXmlDomNode*) _tmp51_, &_inner_error0_);
#line 350 "CssSelectorTest.vala"
		_tmp53_ = _tmp52_;
#line 350 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp53_);
#line 350 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 350 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 350 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 350 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 350 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 350 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 350 "CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 350 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 350 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6457 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 351 "CssSelectorTest.vala"
		_tmp54_ = d;
#line 351 "CssSelectorTest.vala"
		_tmp55_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp54_, "child", &_inner_error0_);
#line 351 "CssSelectorTest.vala"
		c4 = _tmp55_;
#line 351 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 351 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 351 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 351 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 351 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 351 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 351 "CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 351 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 351 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6484 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 352 "CssSelectorTest.vala"
		_tmp56_ = c4;
#line 352 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp56_, "class", "error calc", &_inner_error0_);
#line 352 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 352 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 352 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 352 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 352 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 352 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 352 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 352 "CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 352 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 352 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6511 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 353 "CssSelectorTest.vala"
		_tmp57_ = r;
#line 353 "CssSelectorTest.vala"
		_tmp58_ = c4;
#line 353 "CssSelectorTest.vala"
		_tmp59_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp57_, (GXmlDomNode*) _tmp58_, &_inner_error0_);
#line 353 "CssSelectorTest.vala"
		_tmp60_ = _tmp59_;
#line 353 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp60_);
#line 353 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 353 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 353 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 353 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 353 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 353 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 353 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 353 "CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 353 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 353 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6544 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 354 "CssSelectorTest.vala"
		_tmp61_ = d;
#line 354 "CssSelectorTest.vala"
		_tmp62_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp61_, "child", &_inner_error0_);
#line 354 "CssSelectorTest.vala"
		c5 = _tmp62_;
#line 354 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 354 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 354 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 354 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 354 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 354 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 354 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 354 "CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 354 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 354 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6573 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 355 "CssSelectorTest.vala"
		_tmp63_ = r;
#line 355 "CssSelectorTest.vala"
		_tmp64_ = c5;
#line 355 "CssSelectorTest.vala"
		_tmp65_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp63_, (GXmlDomNode*) _tmp64_, &_inner_error0_);
#line 355 "CssSelectorTest.vala"
		_tmp66_ = _tmp65_;
#line 355 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp66_);
#line 355 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 355 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 355 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 355 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 355 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 355 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 355 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 355 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 355 "CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 355 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 355 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6608 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 356 "CssSelectorTest.vala"
		_tmp68_ = cp;
#line 356 "CssSelectorTest.vala"
		_tmp69_ = r;
#line 356 "CssSelectorTest.vala"
		_tmp67_ = gxml_css_selector_parser_match (_tmp68_, _tmp69_, &_inner_error0_);
#line 356 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 356 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 356 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 356 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 356 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 356 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 356 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 356 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 356 "CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 356 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 356 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6639 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 356 "CssSelectorTest.vala"
		_vala_assert (!_tmp67_, "!cp.match (r)");
#line 357 "CssSelectorTest.vala"
		_tmp71_ = cp;
#line 357 "CssSelectorTest.vala"
		_tmp72_ = c1;
#line 357 "CssSelectorTest.vala"
		_tmp70_ = gxml_css_selector_parser_match (_tmp71_, _tmp72_, &_inner_error0_);
#line 357 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 357 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 357 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 357 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 357 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 357 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 357 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 357 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 357 "CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 357 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 357 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6672 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 357 "CssSelectorTest.vala"
		_vala_assert (!_tmp70_, "!cp.match (c1)");
#line 358 "CssSelectorTest.vala"
		_tmp74_ = cp;
#line 358 "CssSelectorTest.vala"
		_tmp75_ = c2;
#line 358 "CssSelectorTest.vala"
		_tmp73_ = gxml_css_selector_parser_match (_tmp74_, _tmp75_, &_inner_error0_);
#line 358 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 358 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 358 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 358 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 358 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 358 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 358 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 358 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 358 "CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 358 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 358 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6705 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 358 "CssSelectorTest.vala"
		_vala_assert (_tmp73_, "cp.match (c2)");
#line 359 "CssSelectorTest.vala"
		_tmp77_ = cp;
#line 359 "CssSelectorTest.vala"
		_tmp78_ = c3;
#line 359 "CssSelectorTest.vala"
		_tmp76_ = gxml_css_selector_parser_match (_tmp77_, _tmp78_, &_inner_error0_);
#line 359 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 359 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 359 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 359 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 359 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 359 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 359 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 359 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 359 "CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 359 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 359 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6738 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 359 "CssSelectorTest.vala"
		_vala_assert (_tmp76_, "cp.match (c3)");
#line 360 "CssSelectorTest.vala"
		_tmp80_ = cp;
#line 360 "CssSelectorTest.vala"
		_tmp81_ = c4;
#line 360 "CssSelectorTest.vala"
		_tmp79_ = gxml_css_selector_parser_match (_tmp80_, _tmp81_, &_inner_error0_);
#line 360 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 360 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 360 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 360 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 360 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 360 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 360 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 360 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 360 "CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 360 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 360 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6771 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 360 "CssSelectorTest.vala"
		_vala_assert (!_tmp79_, "!cp.match (c4)");
#line 361 "CssSelectorTest.vala"
		_tmp83_ = cp;
#line 361 "CssSelectorTest.vala"
		_tmp84_ = c5;
#line 361 "CssSelectorTest.vala"
		_tmp82_ = gxml_css_selector_parser_match (_tmp83_, _tmp84_, &_inner_error0_);
#line 361 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 361 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 361 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 361 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 361 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 361 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 361 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 361 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 361 "CssSelectorTest.vala"
			_g_object_unref0 (sc);
#line 361 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 361 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 6804 "CssSelectorTest.c"
			goto __catch10_g_error;
		}
#line 361 "CssSelectorTest.vala"
		_vala_assert (!_tmp82_, "!cp.match (c5)");
#line 328 "CssSelectorTest.vala"
		_g_object_unref0 (c5);
#line 328 "CssSelectorTest.vala"
		_g_object_unref0 (c4);
#line 328 "CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 328 "CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 328 "CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 328 "CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 328 "CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 328 "CssSelectorTest.vala"
		_g_object_unref0 (sc);
#line 328 "CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 328 "CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 6829 "CssSelectorTest.c"
	}
	goto __finally10;
	__catch10_g_error:
	{
		GError* e = NULL;
		GError* _tmp85_;
		const gchar* _tmp86_;
		gchar* _tmp87_;
		gchar* _tmp88_;
#line 328 "CssSelectorTest.vala"
		e = _inner_error0_;
#line 328 "CssSelectorTest.vala"
		_inner_error0_ = NULL;
#line 363 "CssSelectorTest.vala"
		_tmp85_ = e;
#line 363 "CssSelectorTest.vala"
		_tmp86_ = _tmp85_->message;
#line 363 "CssSelectorTest.vala"
		_tmp87_ = g_strconcat ("ERROR: ", _tmp86_, NULL);
#line 363 "CssSelectorTest.vala"
		_tmp88_ = _tmp87_;
#line 363 "CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:363: %s", _tmp88_);
#line 363 "CssSelectorTest.vala"
		_g_free0 (_tmp88_);
#line 328 "CssSelectorTest.vala"
		_g_error_free0 (e);
#line 6857 "CssSelectorTest.c"
	}
	__finally10:
#line 328 "CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 328 "CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 328 "CssSelectorTest.vala"
		g_clear_error (&_inner_error0_);
#line 328 "CssSelectorTest.vala"
		return;
#line 6868 "CssSelectorTest.c"
	}
}

static void
___lambda155__gtest_func (void)
{
#line 327 "CssSelectorTest.vala"
	__lambda155_ ();
#line 6877 "CssSelectorTest.c"
}

static void
__lambda156_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelector* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelector* _tmp11_;
		GXmlCssSelector* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelector* _tmp15_;
		GXmlCssCombiner _tmp16_;
		GXmlCssCombiner _tmp17_;
		GXmlCssSelector* sa = NULL;
		GXmlCssSelectorParser* _tmp18_;
		GeeList* _tmp19_;
		GeeList* _tmp20_;
		gpointer _tmp21_;
		GXmlCssSelector* _tmp22_;
		GXmlCssSelector* _tmp23_;
		GXmlCssSelectorType _tmp24_;
		GXmlCssSelectorType _tmp25_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp26_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp27_;
		GXmlDomElement* _tmp28_;
		GXmlGomDocument* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomNode* _tmp31_;
		GXmlDomNode* _tmp32_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp33_;
		GXmlDomElement* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomNode* _tmp38_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomElement* _tmp42_;
		GXmlDomElement* _tmp43_;
		GXmlDomNode* _tmp44_;
		GXmlDomNode* _tmp45_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlDomNode* _tmp51_;
		GXmlDomNode* _tmp52_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomElement* _tmp56_;
		GXmlDomElement* _tmp57_;
		GXmlDomNode* _tmp58_;
		GXmlDomNode* _tmp59_;
		gboolean _tmp60_ = FALSE;
		GXmlCssSelectorParser* _tmp61_;
		GXmlDomElement* _tmp62_;
		gboolean _tmp63_ = FALSE;
		GXmlCssSelectorParser* _tmp64_;
		GXmlDomElement* _tmp65_;
		gboolean _tmp66_ = FALSE;
		GXmlCssSelectorParser* _tmp67_;
		GXmlDomElement* _tmp68_;
		gboolean _tmp69_ = FALSE;
		GXmlCssSelectorParser* _tmp70_;
		GXmlDomElement* _tmp71_;
		gboolean _tmp72_ = FALSE;
		GXmlCssSelectorParser* _tmp73_;
		GXmlDomElement* _tmp74_;
		GXmlDomDocument* d2 = NULL;
		GXmlGDocument* _tmp75_;
		GXmlDomDocument* _tmp76_;
		GXmlDomElement* r2 = NULL;
		GXmlDomDocument* _tmp77_;
		GXmlDomElement* _tmp78_;
		GXmlDomDocument* _tmp79_;
		GXmlDomElement* _tmp80_;
		GXmlDomNode* _tmp81_;
		GXmlDomNode* _tmp82_;
		GXmlDomElement* c1g = NULL;
		GXmlDomDocument* _tmp83_;
		GXmlDomElement* _tmp84_;
		GXmlDomElement* _tmp85_;
		GXmlDomElement* _tmp86_;
		GXmlDomNode* _tmp87_;
		GXmlDomNode* _tmp88_;
		GXmlDomElement* c2g = NULL;
		GXmlDomDocument* _tmp89_;
		GXmlDomElement* _tmp90_;
		GXmlDomElement* _tmp91_;
		GXmlDomElement* _tmp92_;
		GXmlDomElement* _tmp93_;
		GXmlDomNode* _tmp94_;
		GXmlDomNode* _tmp95_;
		GXmlDomElement* c3g = NULL;
		GXmlDomDocument* _tmp96_;
		GXmlDomElement* _tmp97_;
		GXmlDomElement* _tmp98_;
		GXmlDomElement* _tmp99_;
		GXmlDomElement* _tmp100_;
		GXmlDomNode* _tmp101_;
		GXmlDomNode* _tmp102_;
		GXmlDomElement* c4g = NULL;
		GXmlDomDocument* _tmp103_;
		GXmlDomElement* _tmp104_;
		GXmlDomElement* _tmp105_;
		GXmlDomElement* _tmp106_;
		GXmlDomElement* _tmp107_;
		GXmlDomNode* _tmp108_;
		GXmlDomNode* _tmp109_;
		gboolean _tmp110_ = FALSE;
		GXmlCssSelectorParser* _tmp111_;
		GXmlDomElement* _tmp112_;
		gboolean _tmp113_ = FALSE;
		GXmlCssSelectorParser* _tmp114_;
		GXmlDomElement* _tmp115_;
		gboolean _tmp116_ = FALSE;
		GXmlCssSelectorParser* _tmp117_;
		GXmlDomElement* _tmp118_;
		gboolean _tmp119_ = FALSE;
		GXmlCssSelectorParser* _tmp120_;
		GXmlDomElement* _tmp121_;
		gboolean _tmp122_ = FALSE;
		GXmlCssSelectorParser* _tmp123_;
		GXmlDomElement* _tmp124_;
#line 368 "CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 368 "CssSelectorTest.vala"
		cp = _tmp0_;
#line 369 "CssSelectorTest.vala"
		_tmp1_ = cp;
#line 369 "CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "toplevel:root", &_inner_error0_);
#line 369 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 369 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7037 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 370 "CssSelectorTest.vala"
		_tmp2_ = cp;
#line 370 "CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 370 "CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 370 "CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 370 "CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 370 "CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 2, "cp.selectors.size == 2");
#line 371 "CssSelectorTest.vala"
		_tmp7_ = cp;
#line 371 "CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 371 "CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 371 "CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 371 "CssSelectorTest.vala"
		s = (GXmlCssSelector*) _tmp10_;
#line 372 "CssSelectorTest.vala"
		_tmp11_ = s;
#line 372 "CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 373 "CssSelectorTest.vala"
		_tmp12_ = s;
#line 373 "CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_get_selector_type (_tmp12_);
#line 373 "CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 373 "CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 374 "CssSelectorTest.vala"
		_tmp15_ = s;
#line 374 "CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_get_combiner (_tmp15_);
#line 374 "CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 374 "CssSelectorTest.vala"
		_vala_assert (_tmp17_ == GXML_CSS_COMBINER_NONE, "s.combiner == CssCombiner.NONE");
#line 375 "CssSelectorTest.vala"
		_tmp18_ = cp;
#line 375 "CssSelectorTest.vala"
		_tmp19_ = gxml_css_selector_parser_get_selectors (_tmp18_);
#line 375 "CssSelectorTest.vala"
		_tmp20_ = _tmp19_;
#line 375 "CssSelectorTest.vala"
		_tmp21_ = gee_list_get (_tmp20_, 1);
#line 375 "CssSelectorTest.vala"
		sa = (GXmlCssSelector*) _tmp21_;
#line 376 "CssSelectorTest.vala"
		_tmp22_ = sa;
#line 376 "CssSelectorTest.vala"
		_vala_assert (_tmp22_ != NULL, "sa != null");
#line 377 "CssSelectorTest.vala"
		_tmp23_ = sa;
#line 377 "CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_get_selector_type (_tmp23_);
#line 377 "CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 377 "CssSelectorTest.vala"
		_vala_assert (_tmp25_ == GXML_CSS_SELECTOR_TYPE_PSEUDO_CLASS, "sa.selector_type == CssSelectorType.PSEUDO_CLASS");
#line 378 "CssSelectorTest.vala"
		_tmp26_ = gxml_gom_document_new ();
#line 378 "CssSelectorTest.vala"
		d = _tmp26_;
#line 379 "CssSelectorTest.vala"
		_tmp27_ = d;
#line 379 "CssSelectorTest.vala"
		_tmp28_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp27_, "toplevel", &_inner_error0_);
#line 379 "CssSelectorTest.vala"
		r = _tmp28_;
#line 379 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 379 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 379 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 379 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 379 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7124 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 380 "CssSelectorTest.vala"
		_tmp29_ = d;
#line 380 "CssSelectorTest.vala"
		_tmp30_ = r;
#line 380 "CssSelectorTest.vala"
		_tmp31_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp29_, (GXmlDomNode*) _tmp30_, &_inner_error0_);
#line 380 "CssSelectorTest.vala"
		_tmp32_ = _tmp31_;
#line 380 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp32_);
#line 380 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 380 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 380 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 380 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 380 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 380 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7149 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 381 "CssSelectorTest.vala"
		_tmp33_ = d;
#line 381 "CssSelectorTest.vala"
		_tmp34_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp33_, "child", &_inner_error0_);
#line 381 "CssSelectorTest.vala"
		c1 = _tmp34_;
#line 381 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 381 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 381 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 381 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 381 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 381 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7170 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 382 "CssSelectorTest.vala"
		_tmp35_ = r;
#line 382 "CssSelectorTest.vala"
		_tmp36_ = c1;
#line 382 "CssSelectorTest.vala"
		_tmp37_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp35_, (GXmlDomNode*) _tmp36_, &_inner_error0_);
#line 382 "CssSelectorTest.vala"
		_tmp38_ = _tmp37_;
#line 382 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp38_);
#line 382 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 382 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 382 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 382 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 382 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 382 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 382 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7197 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 383 "CssSelectorTest.vala"
		_tmp39_ = d;
#line 383 "CssSelectorTest.vala"
		_tmp40_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp39_, "child", &_inner_error0_);
#line 383 "CssSelectorTest.vala"
		c2 = _tmp40_;
#line 383 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 383 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 383 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 383 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 383 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 383 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 383 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7220 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 384 "CssSelectorTest.vala"
		_tmp41_ = c2;
#line 384 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp41_, "prop-name", "subval", &_inner_error0_);
#line 384 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 384 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 384 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 384 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 384 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 384 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 384 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 384 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7243 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 385 "CssSelectorTest.vala"
		_tmp42_ = r;
#line 385 "CssSelectorTest.vala"
		_tmp43_ = c2;
#line 385 "CssSelectorTest.vala"
		_tmp44_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp42_, (GXmlDomNode*) _tmp43_, &_inner_error0_);
#line 385 "CssSelectorTest.vala"
		_tmp45_ = _tmp44_;
#line 385 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp45_);
#line 385 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 385 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 385 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 385 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 385 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 385 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 385 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 385 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7272 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 386 "CssSelectorTest.vala"
		_tmp46_ = d;
#line 386 "CssSelectorTest.vala"
		_tmp47_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp46_, "child", &_inner_error0_);
#line 386 "CssSelectorTest.vala"
		c3 = _tmp47_;
#line 386 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 386 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 386 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 386 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 386 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 386 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 386 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 386 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7297 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 387 "CssSelectorTest.vala"
		_tmp48_ = c3;
#line 387 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp48_, "prop-name", "techval", &_inner_error0_);
#line 387 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 387 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 387 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 387 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 387 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 387 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 387 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 387 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 387 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7322 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 388 "CssSelectorTest.vala"
		_tmp49_ = r;
#line 388 "CssSelectorTest.vala"
		_tmp50_ = c3;
#line 388 "CssSelectorTest.vala"
		_tmp51_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp49_, (GXmlDomNode*) _tmp50_, &_inner_error0_);
#line 388 "CssSelectorTest.vala"
		_tmp52_ = _tmp51_;
#line 388 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp52_);
#line 388 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 388 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 388 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 388 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 388 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 388 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 388 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 388 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 388 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7353 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 389 "CssSelectorTest.vala"
		_tmp53_ = d;
#line 389 "CssSelectorTest.vala"
		_tmp54_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp53_, "child", &_inner_error0_);
#line 389 "CssSelectorTest.vala"
		c4 = _tmp54_;
#line 389 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 389 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 389 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 389 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 389 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 389 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 389 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 389 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 389 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7380 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 390 "CssSelectorTest.vala"
		_tmp55_ = c4;
#line 390 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp55_, "prop-name", "secondaryvalue", &_inner_error0_);
#line 390 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 390 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 390 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 390 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 390 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 390 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 390 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 390 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 390 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 390 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7407 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 391 "CssSelectorTest.vala"
		_tmp56_ = r;
#line 391 "CssSelectorTest.vala"
		_tmp57_ = c4;
#line 391 "CssSelectorTest.vala"
		_tmp58_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp56_, (GXmlDomNode*) _tmp57_, &_inner_error0_);
#line 391 "CssSelectorTest.vala"
		_tmp59_ = _tmp58_;
#line 391 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp59_);
#line 391 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 391 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 391 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 391 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 391 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 391 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 391 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 391 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 391 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 391 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7440 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 392 "CssSelectorTest.vala"
		_tmp61_ = cp;
#line 392 "CssSelectorTest.vala"
		_tmp62_ = r;
#line 392 "CssSelectorTest.vala"
		_tmp60_ = gxml_css_selector_parser_match (_tmp61_, _tmp62_, &_inner_error0_);
#line 392 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 392 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 392 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 392 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 392 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 392 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 392 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 392 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 392 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 392 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7469 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 392 "CssSelectorTest.vala"
		_vala_assert (_tmp60_, "cp.match (r)");
#line 393 "CssSelectorTest.vala"
		_tmp64_ = cp;
#line 393 "CssSelectorTest.vala"
		_tmp65_ = c1;
#line 393 "CssSelectorTest.vala"
		_tmp63_ = gxml_css_selector_parser_match (_tmp64_, _tmp65_, &_inner_error0_);
#line 393 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 393 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 393 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 393 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 393 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 393 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 393 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 393 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 393 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 393 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7500 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 393 "CssSelectorTest.vala"
		_vala_assert (!_tmp63_, "!cp.match (c1)");
#line 394 "CssSelectorTest.vala"
		_tmp67_ = cp;
#line 394 "CssSelectorTest.vala"
		_tmp68_ = c2;
#line 394 "CssSelectorTest.vala"
		_tmp66_ = gxml_css_selector_parser_match (_tmp67_, _tmp68_, &_inner_error0_);
#line 394 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 394 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 394 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 394 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 394 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 394 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 394 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 394 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 394 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 394 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7531 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 394 "CssSelectorTest.vala"
		_vala_assert (!_tmp66_, "!cp.match (c2)");
#line 395 "CssSelectorTest.vala"
		_tmp70_ = cp;
#line 395 "CssSelectorTest.vala"
		_tmp71_ = c3;
#line 395 "CssSelectorTest.vala"
		_tmp69_ = gxml_css_selector_parser_match (_tmp70_, _tmp71_, &_inner_error0_);
#line 395 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 395 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 395 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 395 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 395 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 395 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 395 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 395 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 395 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 395 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7562 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 395 "CssSelectorTest.vala"
		_vala_assert (!_tmp69_, "!cp.match (c3)");
#line 396 "CssSelectorTest.vala"
		_tmp73_ = cp;
#line 396 "CssSelectorTest.vala"
		_tmp74_ = c4;
#line 396 "CssSelectorTest.vala"
		_tmp72_ = gxml_css_selector_parser_match (_tmp73_, _tmp74_, &_inner_error0_);
#line 396 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 396 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 396 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 396 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 396 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 396 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 396 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 396 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 396 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 396 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7593 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 396 "CssSelectorTest.vala"
		_vala_assert (!_tmp72_, "!cp.match (c4)");
#line 397 "CssSelectorTest.vala"
		_tmp75_ = gxml_gdocument_new ();
#line 397 "CssSelectorTest.vala"
		_tmp76_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp75_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp75_) : NULL;
#line 397 "CssSelectorTest.vala"
		if (_tmp76_ == NULL) {
#line 397 "CssSelectorTest.vala"
			_g_object_unref0 (_tmp75_);
#line 7606 "CssSelectorTest.c"
		}
#line 397 "CssSelectorTest.vala"
		d2 = _tmp76_;
#line 398 "CssSelectorTest.vala"
		_tmp77_ = d2;
#line 398 "CssSelectorTest.vala"
		_tmp78_ = gxml_dom_document_create_element (_tmp77_, "toplevel", &_inner_error0_);
#line 398 "CssSelectorTest.vala"
		r2 = _tmp78_;
#line 398 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 398 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 398 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 398 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 398 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 398 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 398 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 398 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 398 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 398 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 398 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7638 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 399 "CssSelectorTest.vala"
		_tmp79_ = d2;
#line 399 "CssSelectorTest.vala"
		_tmp80_ = r2;
#line 399 "CssSelectorTest.vala"
		_tmp81_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp79_, (GXmlDomNode*) _tmp80_, &_inner_error0_);
#line 399 "CssSelectorTest.vala"
		_tmp82_ = _tmp81_;
#line 399 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp82_);
#line 399 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 399 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 399 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 399 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 399 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 399 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 399 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 399 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 399 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 399 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 399 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 399 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7675 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 400 "CssSelectorTest.vala"
		_tmp83_ = d2;
#line 400 "CssSelectorTest.vala"
		_tmp84_ = gxml_dom_document_create_element (_tmp83_, "child", &_inner_error0_);
#line 400 "CssSelectorTest.vala"
		c1g = _tmp84_;
#line 400 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 400 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 400 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 400 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 400 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 400 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 400 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 400 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 400 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 400 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 400 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 400 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7708 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 401 "CssSelectorTest.vala"
		_tmp85_ = r2;
#line 401 "CssSelectorTest.vala"
		_tmp86_ = c1g;
#line 401 "CssSelectorTest.vala"
		_tmp87_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp85_, (GXmlDomNode*) _tmp86_, &_inner_error0_);
#line 401 "CssSelectorTest.vala"
		_tmp88_ = _tmp87_;
#line 401 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp88_);
#line 401 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 401 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 401 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 401 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 401 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 401 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 401 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 401 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 401 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 401 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 401 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 401 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 401 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7747 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 402 "CssSelectorTest.vala"
		_tmp89_ = d2;
#line 402 "CssSelectorTest.vala"
		_tmp90_ = gxml_dom_document_create_element (_tmp89_, "child", &_inner_error0_);
#line 402 "CssSelectorTest.vala"
		c2g = _tmp90_;
#line 402 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 402 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 402 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 402 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 402 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 402 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 402 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 402 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 402 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 402 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 402 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 402 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 402 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7782 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 403 "CssSelectorTest.vala"
		_tmp91_ = c2g;
#line 403 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp91_, "prop-name", "subval", &_inner_error0_);
#line 403 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 403 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 403 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 403 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 403 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 403 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 403 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 403 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 403 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 403 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 403 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 403 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 403 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 403 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7817 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 404 "CssSelectorTest.vala"
		_tmp92_ = r2;
#line 404 "CssSelectorTest.vala"
		_tmp93_ = c2g;
#line 404 "CssSelectorTest.vala"
		_tmp94_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp92_, (GXmlDomNode*) _tmp93_, &_inner_error0_);
#line 404 "CssSelectorTest.vala"
		_tmp95_ = _tmp94_;
#line 404 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp95_);
#line 404 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 404 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 404 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 404 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 404 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 404 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 404 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 404 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 404 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 404 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 404 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 404 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 404 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 404 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7858 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 405 "CssSelectorTest.vala"
		_tmp96_ = d2;
#line 405 "CssSelectorTest.vala"
		_tmp97_ = gxml_dom_document_create_element (_tmp96_, "child", &_inner_error0_);
#line 405 "CssSelectorTest.vala"
		c3g = _tmp97_;
#line 405 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 405 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 405 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 405 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 405 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 405 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 405 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 405 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 405 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 405 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 405 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 405 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 405 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 405 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7895 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 406 "CssSelectorTest.vala"
		_tmp98_ = c3g;
#line 406 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp98_, "prop-name", "techval", &_inner_error0_);
#line 406 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 406 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 406 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 406 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 406 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 406 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 406 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 406 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 406 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 406 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 406 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 406 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 406 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 406 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 406 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7932 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 407 "CssSelectorTest.vala"
		_tmp99_ = r2;
#line 407 "CssSelectorTest.vala"
		_tmp100_ = c3g;
#line 407 "CssSelectorTest.vala"
		_tmp101_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp99_, (GXmlDomNode*) _tmp100_, &_inner_error0_);
#line 407 "CssSelectorTest.vala"
		_tmp102_ = _tmp101_;
#line 407 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp102_);
#line 407 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 407 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 407 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 407 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 407 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 407 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 407 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 407 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 407 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 407 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 407 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 407 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 407 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 407 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 407 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 7975 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 408 "CssSelectorTest.vala"
		_tmp103_ = d2;
#line 408 "CssSelectorTest.vala"
		_tmp104_ = gxml_dom_document_create_element (_tmp103_, "child", &_inner_error0_);
#line 408 "CssSelectorTest.vala"
		c4g = _tmp104_;
#line 408 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 408 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 408 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 408 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 408 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 408 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 408 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 408 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 408 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 408 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 408 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 408 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 408 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 408 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 408 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8014 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 409 "CssSelectorTest.vala"
		_tmp105_ = c4g;
#line 409 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp105_, "prop-name", "secondaryvalue", &_inner_error0_);
#line 409 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 409 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 409 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 409 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 409 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 409 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 409 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 409 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 409 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 409 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 409 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 409 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 409 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 409 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 409 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 409 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8053 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 410 "CssSelectorTest.vala"
		_tmp106_ = r2;
#line 410 "CssSelectorTest.vala"
		_tmp107_ = c4g;
#line 410 "CssSelectorTest.vala"
		_tmp108_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp106_, (GXmlDomNode*) _tmp107_, &_inner_error0_);
#line 410 "CssSelectorTest.vala"
		_tmp109_ = _tmp108_;
#line 410 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp109_);
#line 410 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 410 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 410 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 410 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 410 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 410 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 410 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 410 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 410 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 410 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 410 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 410 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 410 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 410 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 410 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 410 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8098 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 411 "CssSelectorTest.vala"
		_tmp111_ = cp;
#line 411 "CssSelectorTest.vala"
		_tmp112_ = r;
#line 411 "CssSelectorTest.vala"
		_tmp110_ = gxml_css_selector_parser_match (_tmp111_, _tmp112_, &_inner_error0_);
#line 411 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 411 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 411 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 411 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 411 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 411 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 411 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 411 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 411 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 411 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 411 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 411 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 411 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 411 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 411 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 411 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8139 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 411 "CssSelectorTest.vala"
		_vala_assert (_tmp110_, "cp.match (r)");
#line 412 "CssSelectorTest.vala"
		_tmp114_ = cp;
#line 412 "CssSelectorTest.vala"
		_tmp115_ = c1g;
#line 412 "CssSelectorTest.vala"
		_tmp113_ = gxml_css_selector_parser_match (_tmp114_, _tmp115_, &_inner_error0_);
#line 412 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 412 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 412 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 412 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 412 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 412 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 412 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 412 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 412 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 412 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 412 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 412 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 412 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 412 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 412 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 412 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8182 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 412 "CssSelectorTest.vala"
		_vala_assert (!_tmp113_, "!cp.match (c1g)");
#line 413 "CssSelectorTest.vala"
		_tmp117_ = cp;
#line 413 "CssSelectorTest.vala"
		_tmp118_ = c2g;
#line 413 "CssSelectorTest.vala"
		_tmp116_ = gxml_css_selector_parser_match (_tmp117_, _tmp118_, &_inner_error0_);
#line 413 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 413 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 413 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 413 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 413 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 413 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 413 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 413 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 413 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 413 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 413 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 413 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 413 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 413 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 413 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 413 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8225 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 413 "CssSelectorTest.vala"
		_vala_assert (!_tmp116_, "!cp.match (c2g)");
#line 414 "CssSelectorTest.vala"
		_tmp120_ = cp;
#line 414 "CssSelectorTest.vala"
		_tmp121_ = c3g;
#line 414 "CssSelectorTest.vala"
		_tmp119_ = gxml_css_selector_parser_match (_tmp120_, _tmp121_, &_inner_error0_);
#line 414 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 414 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 414 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 414 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 414 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 414 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 414 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 414 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 414 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 414 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 414 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 414 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 414 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 414 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 414 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 414 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8268 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 414 "CssSelectorTest.vala"
		_vala_assert (!_tmp119_, "!cp.match (c3g)");
#line 415 "CssSelectorTest.vala"
		_tmp123_ = cp;
#line 415 "CssSelectorTest.vala"
		_tmp124_ = c4g;
#line 415 "CssSelectorTest.vala"
		_tmp122_ = gxml_css_selector_parser_match (_tmp123_, _tmp124_, &_inner_error0_);
#line 415 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 415 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 415 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 415 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 415 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 415 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 415 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 415 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 415 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 415 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 415 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 415 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 415 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 415 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 415 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 415 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8311 "CssSelectorTest.c"
			goto __catch11_g_error;
		}
#line 415 "CssSelectorTest.vala"
		_vala_assert (!_tmp122_, "!cp.match (c4g)");
#line 367 "CssSelectorTest.vala"
		_g_object_unref0 (c4g);
#line 367 "CssSelectorTest.vala"
		_g_object_unref0 (c3g);
#line 367 "CssSelectorTest.vala"
		_g_object_unref0 (c2g);
#line 367 "CssSelectorTest.vala"
		_g_object_unref0 (c1g);
#line 367 "CssSelectorTest.vala"
		_g_object_unref0 (r2);
#line 367 "CssSelectorTest.vala"
		_g_object_unref0 (d2);
#line 367 "CssSelectorTest.vala"
		_g_object_unref0 (c4);
#line 367 "CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 367 "CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 367 "CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 367 "CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 367 "CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 367 "CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 367 "CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 367 "CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 8346 "CssSelectorTest.c"
	}
	goto __finally11;
	__catch11_g_error:
	{
		GError* e = NULL;
		GError* _tmp125_;
		const gchar* _tmp126_;
		gchar* _tmp127_;
		gchar* _tmp128_;
#line 367 "CssSelectorTest.vala"
		e = _inner_error0_;
#line 367 "CssSelectorTest.vala"
		_inner_error0_ = NULL;
#line 417 "CssSelectorTest.vala"
		_tmp125_ = e;
#line 417 "CssSelectorTest.vala"
		_tmp126_ = _tmp125_->message;
#line 417 "CssSelectorTest.vala"
		_tmp127_ = g_strconcat ("ERROR: ", _tmp126_, NULL);
#line 417 "CssSelectorTest.vala"
		_tmp128_ = _tmp127_;
#line 417 "CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:417: %s", _tmp128_);
#line 417 "CssSelectorTest.vala"
		_g_free0 (_tmp128_);
#line 367 "CssSelectorTest.vala"
		_g_error_free0 (e);
#line 8374 "CssSelectorTest.c"
	}
	__finally11:
#line 367 "CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 367 "CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 367 "CssSelectorTest.vala"
		g_clear_error (&_inner_error0_);
#line 367 "CssSelectorTest.vala"
		return;
#line 8385 "CssSelectorTest.c"
	}
}

static void
___lambda156__gtest_func (void)
{
#line 366 "CssSelectorTest.vala"
	__lambda156_ ();
#line 8394 "CssSelectorTest.c"
}

static void
__lambda157_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelector* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelector* _tmp11_;
		GXmlCssSelector* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelector* _tmp15_;
		GXmlCssCombiner _tmp16_;
		GXmlCssCombiner _tmp17_;
		GXmlCssSelector* sa = NULL;
		GXmlCssSelectorParser* _tmp18_;
		GeeList* _tmp19_;
		GeeList* _tmp20_;
		gpointer _tmp21_;
		GXmlCssSelector* _tmp22_;
		GXmlCssSelector* _tmp23_;
		GXmlCssSelectorType _tmp24_;
		GXmlCssSelectorType _tmp25_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp26_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp27_;
		GXmlDomElement* _tmp28_;
		GXmlGomDocument* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomNode* _tmp31_;
		GXmlDomNode* _tmp32_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp33_;
		GXmlDomElement* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomNode* _tmp38_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomElement* _tmp42_;
		GXmlDomElement* _tmp43_;
		GXmlDomNode* _tmp44_;
		GXmlDomNode* _tmp45_;
		gboolean _tmp46_ = FALSE;
		GXmlCssSelectorParser* _tmp47_;
		GXmlDomElement* _tmp48_;
		gboolean _tmp49_ = FALSE;
		GXmlCssSelectorParser* _tmp50_;
		GXmlDomElement* _tmp51_;
		gboolean _tmp52_ = FALSE;
		GXmlCssSelectorParser* _tmp53_;
		GXmlDomElement* _tmp54_;
#line 422 "CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 422 "CssSelectorTest.vala"
		cp = _tmp0_;
#line 423 "CssSelectorTest.vala"
		_tmp1_ = cp;
#line 423 "CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "radio[enable=\"true\"]", &_inner_error0_);
#line 423 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 423 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8476 "CssSelectorTest.c"
			goto __catch12_g_error;
		}
#line 424 "CssSelectorTest.vala"
		_tmp2_ = cp;
#line 424 "CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 424 "CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 424 "CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 424 "CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 424 "CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 2, "cp.selectors.size == 2");
#line 425 "CssSelectorTest.vala"
		_tmp7_ = cp;
#line 425 "CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 425 "CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 425 "CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 425 "CssSelectorTest.vala"
		s = (GXmlCssSelector*) _tmp10_;
#line 426 "CssSelectorTest.vala"
		_tmp11_ = s;
#line 426 "CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 427 "CssSelectorTest.vala"
		_tmp12_ = s;
#line 427 "CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_get_selector_type (_tmp12_);
#line 427 "CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 427 "CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 428 "CssSelectorTest.vala"
		_tmp15_ = s;
#line 428 "CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_get_combiner (_tmp15_);
#line 428 "CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 428 "CssSelectorTest.vala"
		_vala_assert (_tmp17_ == GXML_CSS_COMBINER_NONE, "s.combiner == CssCombiner.NONE");
#line 429 "CssSelectorTest.vala"
		_tmp18_ = cp;
#line 429 "CssSelectorTest.vala"
		_tmp19_ = gxml_css_selector_parser_get_selectors (_tmp18_);
#line 429 "CssSelectorTest.vala"
		_tmp20_ = _tmp19_;
#line 429 "CssSelectorTest.vala"
		_tmp21_ = gee_list_get (_tmp20_, 1);
#line 429 "CssSelectorTest.vala"
		sa = (GXmlCssSelector*) _tmp21_;
#line 430 "CssSelectorTest.vala"
		_tmp22_ = sa;
#line 430 "CssSelectorTest.vala"
		_vala_assert (_tmp22_ != NULL, "sa != null");
#line 431 "CssSelectorTest.vala"
		_tmp23_ = sa;
#line 431 "CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_get_selector_type (_tmp23_);
#line 431 "CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 431 "CssSelectorTest.vala"
		_vala_assert (_tmp25_ == GXML_CSS_SELECTOR_TYPE_ATTRIBUTE_EQUAL, "sa.selector_type == CssSelectorType.ATTRIBUTE_EQUAL");
#line 432 "CssSelectorTest.vala"
		_tmp26_ = gxml_gom_document_new ();
#line 432 "CssSelectorTest.vala"
		d = _tmp26_;
#line 433 "CssSelectorTest.vala"
		_tmp27_ = d;
#line 433 "CssSelectorTest.vala"
		_tmp28_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp27_, "HTML", &_inner_error0_);
#line 433 "CssSelectorTest.vala"
		r = _tmp28_;
#line 433 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 433 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 433 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 433 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 433 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8563 "CssSelectorTest.c"
			goto __catch12_g_error;
		}
#line 434 "CssSelectorTest.vala"
		_tmp29_ = d;
#line 434 "CssSelectorTest.vala"
		_tmp30_ = r;
#line 434 "CssSelectorTest.vala"
		_tmp31_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp29_, (GXmlDomNode*) _tmp30_, &_inner_error0_);
#line 434 "CssSelectorTest.vala"
		_tmp32_ = _tmp31_;
#line 434 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp32_);
#line 434 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 434 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 434 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 434 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 434 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 434 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8588 "CssSelectorTest.c"
			goto __catch12_g_error;
		}
#line 435 "CssSelectorTest.vala"
		_tmp33_ = d;
#line 435 "CssSelectorTest.vala"
		_tmp34_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp33_, "BODY", &_inner_error0_);
#line 435 "CssSelectorTest.vala"
		c1 = _tmp34_;
#line 435 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 435 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 435 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 435 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 435 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 435 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8609 "CssSelectorTest.c"
			goto __catch12_g_error;
		}
#line 436 "CssSelectorTest.vala"
		_tmp35_ = r;
#line 436 "CssSelectorTest.vala"
		_tmp36_ = c1;
#line 436 "CssSelectorTest.vala"
		_tmp37_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp35_, (GXmlDomNode*) _tmp36_, &_inner_error0_);
#line 436 "CssSelectorTest.vala"
		_tmp38_ = _tmp37_;
#line 436 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp38_);
#line 436 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 436 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 436 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 436 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 436 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 436 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 436 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8636 "CssSelectorTest.c"
			goto __catch12_g_error;
		}
#line 437 "CssSelectorTest.vala"
		_tmp39_ = d;
#line 437 "CssSelectorTest.vala"
		_tmp40_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp39_, "radio", &_inner_error0_);
#line 437 "CssSelectorTest.vala"
		c2 = _tmp40_;
#line 437 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 437 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 437 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 437 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 437 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 437 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 437 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8659 "CssSelectorTest.c"
			goto __catch12_g_error;
		}
#line 438 "CssSelectorTest.vala"
		_tmp41_ = c2;
#line 438 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp41_, "enable", "true", &_inner_error0_);
#line 438 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 438 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 438 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 438 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 438 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 438 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 438 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 438 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8682 "CssSelectorTest.c"
			goto __catch12_g_error;
		}
#line 439 "CssSelectorTest.vala"
		_tmp42_ = r;
#line 439 "CssSelectorTest.vala"
		_tmp43_ = c2;
#line 439 "CssSelectorTest.vala"
		_tmp44_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp42_, (GXmlDomNode*) _tmp43_, &_inner_error0_);
#line 439 "CssSelectorTest.vala"
		_tmp45_ = _tmp44_;
#line 439 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp45_);
#line 439 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 439 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 439 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 439 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 439 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 439 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 439 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 439 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8711 "CssSelectorTest.c"
			goto __catch12_g_error;
		}
#line 440 "CssSelectorTest.vala"
		_tmp47_ = cp;
#line 440 "CssSelectorTest.vala"
		_tmp48_ = r;
#line 440 "CssSelectorTest.vala"
		_tmp46_ = gxml_css_selector_parser_match (_tmp47_, _tmp48_, &_inner_error0_);
#line 440 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 440 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 440 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 440 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 440 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 440 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 440 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 440 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8736 "CssSelectorTest.c"
			goto __catch12_g_error;
		}
#line 440 "CssSelectorTest.vala"
		_vala_assert (!_tmp46_, "!cp.match (r)");
#line 441 "CssSelectorTest.vala"
		_tmp50_ = cp;
#line 441 "CssSelectorTest.vala"
		_tmp51_ = c1;
#line 441 "CssSelectorTest.vala"
		_tmp49_ = gxml_css_selector_parser_match (_tmp50_, _tmp51_, &_inner_error0_);
#line 441 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 441 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 441 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 441 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 441 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 441 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 441 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 441 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8763 "CssSelectorTest.c"
			goto __catch12_g_error;
		}
#line 441 "CssSelectorTest.vala"
		_vala_assert (!_tmp49_, "!cp.match (c1)");
#line 442 "CssSelectorTest.vala"
		_tmp53_ = cp;
#line 442 "CssSelectorTest.vala"
		_tmp54_ = c2;
#line 442 "CssSelectorTest.vala"
		_tmp52_ = gxml_css_selector_parser_match (_tmp53_, _tmp54_, &_inner_error0_);
#line 442 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 442 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 442 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 442 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 442 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 442 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 442 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 442 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 8790 "CssSelectorTest.c"
			goto __catch12_g_error;
		}
#line 442 "CssSelectorTest.vala"
		_vala_assert (_tmp52_, "cp.match (c2)");
#line 421 "CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 421 "CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 421 "CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 421 "CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 421 "CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 421 "CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 421 "CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 8809 "CssSelectorTest.c"
	}
	goto __finally12;
	__catch12_g_error:
	{
		GError* e = NULL;
		GError* _tmp55_;
		const gchar* _tmp56_;
		gchar* _tmp57_;
		gchar* _tmp58_;
#line 421 "CssSelectorTest.vala"
		e = _inner_error0_;
#line 421 "CssSelectorTest.vala"
		_inner_error0_ = NULL;
#line 444 "CssSelectorTest.vala"
		_tmp55_ = e;
#line 444 "CssSelectorTest.vala"
		_tmp56_ = _tmp55_->message;
#line 444 "CssSelectorTest.vala"
		_tmp57_ = g_strconcat ("ERROR: ", _tmp56_, NULL);
#line 444 "CssSelectorTest.vala"
		_tmp58_ = _tmp57_;
#line 444 "CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:444: %s", _tmp58_);
#line 444 "CssSelectorTest.vala"
		_g_free0 (_tmp58_);
#line 421 "CssSelectorTest.vala"
		_g_error_free0 (e);
#line 8837 "CssSelectorTest.c"
	}
	__finally12:
#line 421 "CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 421 "CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 421 "CssSelectorTest.vala"
		g_clear_error (&_inner_error0_);
#line 421 "CssSelectorTest.vala"
		return;
#line 8848 "CssSelectorTest.c"
	}
}

static void
___lambda157__gtest_func (void)
{
#line 420 "CssSelectorTest.vala"
	__lambda157_ ();
#line 8857 "CssSelectorTest.c"
}

static void
__lambda158_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelector* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelector* _tmp11_;
		GXmlCssSelector* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelector* _tmp15_;
		GXmlCssCombiner _tmp16_;
		GXmlCssCombiner _tmp17_;
		GXmlCssSelector* sa = NULL;
		GXmlCssSelectorParser* _tmp18_;
		GeeList* _tmp19_;
		GeeList* _tmp20_;
		gpointer _tmp21_;
		GXmlCssSelector* _tmp22_;
		GXmlCssSelector* _tmp23_;
		GXmlCssSelectorType _tmp24_;
		GXmlCssSelectorType _tmp25_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp26_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp27_;
		GXmlDomElement* _tmp28_;
		GXmlGomDocument* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomNode* _tmp31_;
		GXmlDomNode* _tmp32_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp33_;
		GXmlDomElement* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomNode* _tmp38_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomElement* _tmp42_;
		GXmlDomElement* _tmp43_;
		GXmlDomNode* _tmp44_;
		GXmlDomNode* _tmp45_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlDomNode* _tmp51_;
		GXmlDomNode* _tmp52_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomElement* _tmp56_;
		GXmlDomElement* _tmp57_;
		GXmlDomNode* _tmp58_;
		GXmlDomNode* _tmp59_;
		GXmlDomElement* c5 = NULL;
		GXmlGomDocument* _tmp60_;
		GXmlDomElement* _tmp61_;
		GXmlDomElement* _tmp62_;
		GXmlDomElement* _tmp63_;
		GXmlDomNode* _tmp64_;
		GXmlDomNode* _tmp65_;
		GXmlDomElement* _tmp66_;
		GXmlDomElement* _tmp67_;
		GXmlDomElement* _tmp68_;
		GXmlDomElement* _tmp69_;
		GXmlDomElement* _tmp70_;
		gboolean _tmp71_ = FALSE;
		GXmlCssSelectorParser* _tmp72_;
		GXmlDomElement* _tmp73_;
		gboolean _tmp74_ = FALSE;
		GXmlCssSelectorParser* _tmp75_;
		GXmlDomElement* _tmp76_;
		gboolean _tmp77_ = FALSE;
		GXmlCssSelectorParser* _tmp78_;
		GXmlDomElement* _tmp79_;
		gboolean _tmp80_ = FALSE;
		GXmlCssSelectorParser* _tmp81_;
		GXmlDomElement* _tmp82_;
		gboolean _tmp83_ = FALSE;
		GXmlCssSelectorParser* _tmp84_;
		GXmlDomElement* _tmp85_;
		gboolean _tmp86_ = FALSE;
		GXmlCssSelectorParser* _tmp87_;
		GXmlDomElement* _tmp88_;
		GXmlDomDocument* d2 = NULL;
		GXmlGDocument* _tmp89_;
		GXmlDomDocument* _tmp90_;
		GXmlDomElement* r2 = NULL;
		GXmlDomDocument* _tmp91_;
		GXmlDomElement* _tmp92_;
		GXmlDomDocument* _tmp93_;
		GXmlDomElement* _tmp94_;
		GXmlDomNode* _tmp95_;
		GXmlDomNode* _tmp96_;
		GXmlDomElement* c1g = NULL;
		GXmlDomDocument* _tmp97_;
		GXmlDomElement* _tmp98_;
		GXmlDomElement* _tmp99_;
		GXmlDomElement* _tmp100_;
		GXmlDomNode* _tmp101_;
		GXmlDomNode* _tmp102_;
		GXmlDomElement* c2g = NULL;
		GXmlDomDocument* _tmp103_;
		GXmlDomElement* _tmp104_;
		GXmlDomElement* _tmp105_;
		GXmlDomElement* _tmp106_;
		GXmlDomElement* _tmp107_;
		GXmlDomNode* _tmp108_;
		GXmlDomNode* _tmp109_;
		GXmlDomElement* c3g = NULL;
		GXmlDomDocument* _tmp110_;
		GXmlDomElement* _tmp111_;
		GXmlDomElement* _tmp112_;
		GXmlDomElement* _tmp113_;
		GXmlDomElement* _tmp114_;
		GXmlDomNode* _tmp115_;
		GXmlDomNode* _tmp116_;
		GXmlDomElement* c4g = NULL;
		GXmlDomDocument* _tmp117_;
		GXmlDomElement* _tmp118_;
		GXmlDomElement* _tmp119_;
		GXmlDomElement* _tmp120_;
		GXmlDomElement* _tmp121_;
		GXmlDomNode* _tmp122_;
		GXmlDomNode* _tmp123_;
		GXmlDomElement* c5g = NULL;
		GXmlDomDocument* _tmp124_;
		GXmlDomElement* _tmp125_;
		GXmlDomElement* _tmp126_;
		GXmlDomElement* _tmp127_;
		GXmlDomNode* _tmp128_;
		GXmlDomNode* _tmp129_;
		gboolean _tmp130_ = FALSE;
		GXmlCssSelectorParser* _tmp131_;
		GXmlDomElement* _tmp132_;
		gboolean _tmp133_ = FALSE;
		GXmlCssSelectorParser* _tmp134_;
		GXmlDomElement* _tmp135_;
		gboolean _tmp136_ = FALSE;
		GXmlCssSelectorParser* _tmp137_;
		GXmlDomElement* _tmp138_;
		gboolean _tmp139_ = FALSE;
		GXmlCssSelectorParser* _tmp140_;
		GXmlDomElement* _tmp141_;
		gboolean _tmp142_ = FALSE;
		GXmlCssSelectorParser* _tmp143_;
		GXmlDomElement* _tmp144_;
		gboolean _tmp145_ = FALSE;
		GXmlCssSelectorParser* _tmp146_;
		GXmlDomElement* _tmp147_;
#line 449 "CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 449 "CssSelectorTest.vala"
		cp = _tmp0_;
#line 450 "CssSelectorTest.vala"
		_tmp1_ = cp;
#line 450 "CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "child:empty", &_inner_error0_);
#line 450 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 450 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9042 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 451 "CssSelectorTest.vala"
		_tmp2_ = cp;
#line 451 "CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 451 "CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 451 "CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 451 "CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 451 "CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 2, "cp.selectors.size == 2");
#line 452 "CssSelectorTest.vala"
		_tmp7_ = cp;
#line 452 "CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 452 "CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 452 "CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 452 "CssSelectorTest.vala"
		s = (GXmlCssSelector*) _tmp10_;
#line 453 "CssSelectorTest.vala"
		_tmp11_ = s;
#line 453 "CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 454 "CssSelectorTest.vala"
		_tmp12_ = s;
#line 454 "CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_get_selector_type (_tmp12_);
#line 454 "CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 454 "CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 455 "CssSelectorTest.vala"
		_tmp15_ = s;
#line 455 "CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_get_combiner (_tmp15_);
#line 455 "CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 455 "CssSelectorTest.vala"
		_vala_assert (_tmp17_ == GXML_CSS_COMBINER_NONE, "s.combiner == CssCombiner.NONE");
#line 456 "CssSelectorTest.vala"
		_tmp18_ = cp;
#line 456 "CssSelectorTest.vala"
		_tmp19_ = gxml_css_selector_parser_get_selectors (_tmp18_);
#line 456 "CssSelectorTest.vala"
		_tmp20_ = _tmp19_;
#line 456 "CssSelectorTest.vala"
		_tmp21_ = gee_list_get (_tmp20_, 1);
#line 456 "CssSelectorTest.vala"
		sa = (GXmlCssSelector*) _tmp21_;
#line 457 "CssSelectorTest.vala"
		_tmp22_ = sa;
#line 457 "CssSelectorTest.vala"
		_vala_assert (_tmp22_ != NULL, "sa != null");
#line 458 "CssSelectorTest.vala"
		_tmp23_ = sa;
#line 458 "CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_get_selector_type (_tmp23_);
#line 458 "CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 458 "CssSelectorTest.vala"
		_vala_assert (_tmp25_ == GXML_CSS_SELECTOR_TYPE_PSEUDO_CLASS, "sa.selector_type == CssSelectorType.PSEUDO_CLASS");
#line 459 "CssSelectorTest.vala"
		_tmp26_ = gxml_gom_document_new ();
#line 459 "CssSelectorTest.vala"
		d = _tmp26_;
#line 460 "CssSelectorTest.vala"
		_tmp27_ = d;
#line 460 "CssSelectorTest.vala"
		_tmp28_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp27_, "toplevel", &_inner_error0_);
#line 460 "CssSelectorTest.vala"
		r = _tmp28_;
#line 460 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 460 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 460 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 460 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 460 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9129 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 461 "CssSelectorTest.vala"
		_tmp29_ = d;
#line 461 "CssSelectorTest.vala"
		_tmp30_ = r;
#line 461 "CssSelectorTest.vala"
		_tmp31_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp29_, (GXmlDomNode*) _tmp30_, &_inner_error0_);
#line 461 "CssSelectorTest.vala"
		_tmp32_ = _tmp31_;
#line 461 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp32_);
#line 461 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 461 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 461 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 461 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 461 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 461 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9154 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 462 "CssSelectorTest.vala"
		_tmp33_ = d;
#line 462 "CssSelectorTest.vala"
		_tmp34_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp33_, "child", &_inner_error0_);
#line 462 "CssSelectorTest.vala"
		c1 = _tmp34_;
#line 462 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 462 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 462 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 462 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 462 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 462 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9175 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 463 "CssSelectorTest.vala"
		_tmp35_ = r;
#line 463 "CssSelectorTest.vala"
		_tmp36_ = c1;
#line 463 "CssSelectorTest.vala"
		_tmp37_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp35_, (GXmlDomNode*) _tmp36_, &_inner_error0_);
#line 463 "CssSelectorTest.vala"
		_tmp38_ = _tmp37_;
#line 463 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp38_);
#line 463 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 463 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 463 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 463 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 463 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 463 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 463 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9202 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 464 "CssSelectorTest.vala"
		_tmp39_ = d;
#line 464 "CssSelectorTest.vala"
		_tmp40_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp39_, "child", &_inner_error0_);
#line 464 "CssSelectorTest.vala"
		c2 = _tmp40_;
#line 464 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 464 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 464 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 464 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 464 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 464 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 464 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9225 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 465 "CssSelectorTest.vala"
		_tmp41_ = c2;
#line 465 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp41_, "prop-name", "subval", &_inner_error0_);
#line 465 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 465 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 465 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 465 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 465 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 465 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 465 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 465 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9248 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 466 "CssSelectorTest.vala"
		_tmp42_ = r;
#line 466 "CssSelectorTest.vala"
		_tmp43_ = c2;
#line 466 "CssSelectorTest.vala"
		_tmp44_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp42_, (GXmlDomNode*) _tmp43_, &_inner_error0_);
#line 466 "CssSelectorTest.vala"
		_tmp45_ = _tmp44_;
#line 466 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp45_);
#line 466 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 466 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 466 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 466 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 466 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 466 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 466 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 466 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9277 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 467 "CssSelectorTest.vala"
		_tmp46_ = d;
#line 467 "CssSelectorTest.vala"
		_tmp47_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp46_, "child", &_inner_error0_);
#line 467 "CssSelectorTest.vala"
		c3 = _tmp47_;
#line 467 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 467 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 467 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 467 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 467 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 467 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 467 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 467 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9302 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 468 "CssSelectorTest.vala"
		_tmp48_ = c3;
#line 468 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp48_, "prop-name", "techval", &_inner_error0_);
#line 468 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 468 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 468 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 468 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 468 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 468 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 468 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 468 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 468 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9327 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 469 "CssSelectorTest.vala"
		_tmp49_ = r;
#line 469 "CssSelectorTest.vala"
		_tmp50_ = c3;
#line 469 "CssSelectorTest.vala"
		_tmp51_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp49_, (GXmlDomNode*) _tmp50_, &_inner_error0_);
#line 469 "CssSelectorTest.vala"
		_tmp52_ = _tmp51_;
#line 469 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp52_);
#line 469 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 469 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 469 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 469 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 469 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 469 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 469 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 469 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 469 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9358 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 470 "CssSelectorTest.vala"
		_tmp53_ = d;
#line 470 "CssSelectorTest.vala"
		_tmp54_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp53_, "child", &_inner_error0_);
#line 470 "CssSelectorTest.vala"
		c4 = _tmp54_;
#line 470 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 470 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 470 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 470 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 470 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 470 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 470 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 470 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 470 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9385 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 471 "CssSelectorTest.vala"
		_tmp55_ = c4;
#line 471 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp55_, "prop-name", "secondaryvalue", &_inner_error0_);
#line 471 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 471 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 471 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 471 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 471 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 471 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 471 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 471 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 471 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 471 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9412 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 472 "CssSelectorTest.vala"
		_tmp56_ = r;
#line 472 "CssSelectorTest.vala"
		_tmp57_ = c4;
#line 472 "CssSelectorTest.vala"
		_tmp58_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp56_, (GXmlDomNode*) _tmp57_, &_inner_error0_);
#line 472 "CssSelectorTest.vala"
		_tmp59_ = _tmp58_;
#line 472 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp59_);
#line 472 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 472 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 472 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 472 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 472 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 472 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 472 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 472 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 472 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 472 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9445 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 473 "CssSelectorTest.vala"
		_tmp60_ = d;
#line 473 "CssSelectorTest.vala"
		_tmp61_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp60_, "common", &_inner_error0_);
#line 473 "CssSelectorTest.vala"
		c5 = _tmp61_;
#line 473 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 473 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 473 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 473 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 473 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 473 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 473 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 473 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 473 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 473 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9474 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 474 "CssSelectorTest.vala"
		_tmp62_ = c4;
#line 474 "CssSelectorTest.vala"
		_tmp63_ = c5;
#line 474 "CssSelectorTest.vala"
		_tmp64_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp62_, (GXmlDomNode*) _tmp63_, &_inner_error0_);
#line 474 "CssSelectorTest.vala"
		_tmp65_ = _tmp64_;
#line 474 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp65_);
#line 474 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 474 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 474 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 474 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 474 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 474 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 474 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 474 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 474 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 474 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 474 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9509 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 475 "CssSelectorTest.vala"
		_tmp66_ = c1;
#line 475 "CssSelectorTest.vala"
		_vala_assert (!gxml_dom_node_has_child_nodes ((GXmlDomNode*) _tmp66_), "!c1.has_child_nodes ()");
#line 476 "CssSelectorTest.vala"
		_tmp67_ = c2;
#line 476 "CssSelectorTest.vala"
		_vala_assert (!gxml_dom_node_has_child_nodes ((GXmlDomNode*) _tmp67_), "!c2.has_child_nodes ()");
#line 477 "CssSelectorTest.vala"
		_tmp68_ = c3;
#line 477 "CssSelectorTest.vala"
		_vala_assert (!gxml_dom_node_has_child_nodes ((GXmlDomNode*) _tmp68_), "!c3.has_child_nodes ()");
#line 478 "CssSelectorTest.vala"
		_tmp69_ = c4;
#line 478 "CssSelectorTest.vala"
		_vala_assert (gxml_dom_node_has_child_nodes ((GXmlDomNode*) _tmp69_), "c4.has_child_nodes ()");
#line 479 "CssSelectorTest.vala"
		_tmp70_ = c5;
#line 479 "CssSelectorTest.vala"
		_vala_assert (!gxml_dom_node_has_child_nodes ((GXmlDomNode*) _tmp70_), "!c5.has_child_nodes ()");
#line 480 "CssSelectorTest.vala"
		_tmp72_ = cp;
#line 480 "CssSelectorTest.vala"
		_tmp73_ = r;
#line 480 "CssSelectorTest.vala"
		_tmp71_ = gxml_css_selector_parser_match (_tmp72_, _tmp73_, &_inner_error0_);
#line 480 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 480 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 480 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 480 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 480 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 480 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 480 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 480 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 480 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 480 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 480 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9560 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 480 "CssSelectorTest.vala"
		_vala_assert (!_tmp71_, "!cp.match (r)");
#line 481 "CssSelectorTest.vala"
		_tmp75_ = cp;
#line 481 "CssSelectorTest.vala"
		_tmp76_ = c1;
#line 481 "CssSelectorTest.vala"
		_tmp74_ = gxml_css_selector_parser_match (_tmp75_, _tmp76_, &_inner_error0_);
#line 481 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 481 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 481 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 481 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 481 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 481 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 481 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 481 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 481 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 481 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 481 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9593 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 481 "CssSelectorTest.vala"
		_vala_assert (_tmp74_, "cp.match (c1)");
#line 482 "CssSelectorTest.vala"
		_tmp78_ = cp;
#line 482 "CssSelectorTest.vala"
		_tmp79_ = c2;
#line 482 "CssSelectorTest.vala"
		_tmp77_ = gxml_css_selector_parser_match (_tmp78_, _tmp79_, &_inner_error0_);
#line 482 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 482 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 482 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 482 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 482 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 482 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 482 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 482 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 482 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 482 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 482 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9626 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 482 "CssSelectorTest.vala"
		_vala_assert (_tmp77_, "cp.match (c2)");
#line 483 "CssSelectorTest.vala"
		_tmp81_ = cp;
#line 483 "CssSelectorTest.vala"
		_tmp82_ = c3;
#line 483 "CssSelectorTest.vala"
		_tmp80_ = gxml_css_selector_parser_match (_tmp81_, _tmp82_, &_inner_error0_);
#line 483 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 483 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 483 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 483 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 483 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 483 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 483 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 483 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 483 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 483 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 483 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9659 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 483 "CssSelectorTest.vala"
		_vala_assert (_tmp80_, "cp.match (c3)");
#line 484 "CssSelectorTest.vala"
		_tmp84_ = cp;
#line 484 "CssSelectorTest.vala"
		_tmp85_ = c4;
#line 484 "CssSelectorTest.vala"
		_tmp83_ = gxml_css_selector_parser_match (_tmp84_, _tmp85_, &_inner_error0_);
#line 484 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 484 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 484 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 484 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 484 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 484 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 484 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 484 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 484 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 484 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 484 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9692 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 484 "CssSelectorTest.vala"
		_vala_assert (!_tmp83_, "!cp.match (c4)");
#line 485 "CssSelectorTest.vala"
		_tmp87_ = cp;
#line 485 "CssSelectorTest.vala"
		_tmp88_ = c5;
#line 485 "CssSelectorTest.vala"
		_tmp86_ = gxml_css_selector_parser_match (_tmp87_, _tmp88_, &_inner_error0_);
#line 485 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 485 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 485 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 485 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 485 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 485 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 485 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 485 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 485 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 485 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 485 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9725 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 485 "CssSelectorTest.vala"
		_vala_assert (!_tmp86_, "!cp.match (c5)");
#line 486 "CssSelectorTest.vala"
		_tmp89_ = gxml_gdocument_new ();
#line 486 "CssSelectorTest.vala"
		_tmp90_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp89_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp89_) : NULL;
#line 486 "CssSelectorTest.vala"
		if (_tmp90_ == NULL) {
#line 486 "CssSelectorTest.vala"
			_g_object_unref0 (_tmp89_);
#line 9738 "CssSelectorTest.c"
		}
#line 486 "CssSelectorTest.vala"
		d2 = _tmp90_;
#line 487 "CssSelectorTest.vala"
		_tmp91_ = d2;
#line 487 "CssSelectorTest.vala"
		_tmp92_ = gxml_dom_document_create_element (_tmp91_, "toplevel", &_inner_error0_);
#line 487 "CssSelectorTest.vala"
		r2 = _tmp92_;
#line 487 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 487 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 487 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 487 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 487 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 487 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 487 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 487 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 487 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 487 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 487 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 487 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9772 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 488 "CssSelectorTest.vala"
		_tmp93_ = d2;
#line 488 "CssSelectorTest.vala"
		_tmp94_ = r2;
#line 488 "CssSelectorTest.vala"
		_tmp95_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp93_, (GXmlDomNode*) _tmp94_, &_inner_error0_);
#line 488 "CssSelectorTest.vala"
		_tmp96_ = _tmp95_;
#line 488 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp96_);
#line 488 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 488 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 488 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 488 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 488 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 488 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 488 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 488 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 488 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 488 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 488 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 488 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 488 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9811 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 489 "CssSelectorTest.vala"
		_tmp97_ = d2;
#line 489 "CssSelectorTest.vala"
		_tmp98_ = gxml_dom_document_create_element (_tmp97_, "child", &_inner_error0_);
#line 489 "CssSelectorTest.vala"
		c1g = _tmp98_;
#line 489 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 489 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 489 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 489 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 489 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 489 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 489 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 489 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 489 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 489 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 489 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 489 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 489 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9846 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 490 "CssSelectorTest.vala"
		_tmp99_ = r2;
#line 490 "CssSelectorTest.vala"
		_tmp100_ = c1g;
#line 490 "CssSelectorTest.vala"
		_tmp101_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp99_, (GXmlDomNode*) _tmp100_, &_inner_error0_);
#line 490 "CssSelectorTest.vala"
		_tmp102_ = _tmp101_;
#line 490 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp102_);
#line 490 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 490 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 490 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 490 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 490 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 490 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 490 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 490 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 490 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 490 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 490 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 490 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 490 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 490 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9887 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 491 "CssSelectorTest.vala"
		_tmp103_ = d2;
#line 491 "CssSelectorTest.vala"
		_tmp104_ = gxml_dom_document_create_element (_tmp103_, "child", &_inner_error0_);
#line 491 "CssSelectorTest.vala"
		c2g = _tmp104_;
#line 491 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 491 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 491 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 491 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 491 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 491 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 491 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 491 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 491 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 491 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 491 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 491 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 491 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 491 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9924 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 492 "CssSelectorTest.vala"
		_tmp105_ = c2g;
#line 492 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp105_, "prop-name", "subval", &_inner_error0_);
#line 492 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 492 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 492 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 492 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 492 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 492 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 492 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 492 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 492 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 492 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 492 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 492 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 492 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 492 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 492 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 9961 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 493 "CssSelectorTest.vala"
		_tmp106_ = r2;
#line 493 "CssSelectorTest.vala"
		_tmp107_ = c2g;
#line 493 "CssSelectorTest.vala"
		_tmp108_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp106_, (GXmlDomNode*) _tmp107_, &_inner_error0_);
#line 493 "CssSelectorTest.vala"
		_tmp109_ = _tmp108_;
#line 493 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp109_);
#line 493 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 493 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 493 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 493 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 493 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 493 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 493 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 493 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 493 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 493 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 493 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 493 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 493 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 493 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 493 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10004 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 494 "CssSelectorTest.vala"
		_tmp110_ = d2;
#line 494 "CssSelectorTest.vala"
		_tmp111_ = gxml_dom_document_create_element (_tmp110_, "child", &_inner_error0_);
#line 494 "CssSelectorTest.vala"
		c3g = _tmp111_;
#line 494 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 494 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 494 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 494 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 494 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 494 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 494 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 494 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 494 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 494 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 494 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 494 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 494 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 494 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 494 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10043 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 495 "CssSelectorTest.vala"
		_tmp112_ = c3g;
#line 495 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp112_, "prop-name", "techval", &_inner_error0_);
#line 495 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 495 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 495 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 495 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 495 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 495 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 495 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 495 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 495 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 495 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 495 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 495 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 495 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 495 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 495 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 495 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10082 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 496 "CssSelectorTest.vala"
		_tmp113_ = r2;
#line 496 "CssSelectorTest.vala"
		_tmp114_ = c3g;
#line 496 "CssSelectorTest.vala"
		_tmp115_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp113_, (GXmlDomNode*) _tmp114_, &_inner_error0_);
#line 496 "CssSelectorTest.vala"
		_tmp116_ = _tmp115_;
#line 496 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp116_);
#line 496 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 496 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 496 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 496 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 496 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 496 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 496 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 496 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 496 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 496 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 496 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 496 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 496 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 496 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 496 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 496 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10127 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 497 "CssSelectorTest.vala"
		_tmp117_ = d2;
#line 497 "CssSelectorTest.vala"
		_tmp118_ = gxml_dom_document_create_element (_tmp117_, "child", &_inner_error0_);
#line 497 "CssSelectorTest.vala"
		c4g = _tmp118_;
#line 497 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 497 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 497 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 497 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 497 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 497 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 497 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 497 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 497 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 497 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 497 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 497 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 497 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 497 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 497 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 497 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10168 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 498 "CssSelectorTest.vala"
		_tmp119_ = c4g;
#line 498 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp119_, "prop-name", "secondaryvalue", &_inner_error0_);
#line 498 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 498 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 498 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 498 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 498 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 498 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 498 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 498 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 498 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 498 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 498 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 498 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 498 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 498 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 498 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 498 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 498 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10209 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 499 "CssSelectorTest.vala"
		_tmp120_ = r2;
#line 499 "CssSelectorTest.vala"
		_tmp121_ = c4g;
#line 499 "CssSelectorTest.vala"
		_tmp122_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp120_, (GXmlDomNode*) _tmp121_, &_inner_error0_);
#line 499 "CssSelectorTest.vala"
		_tmp123_ = _tmp122_;
#line 499 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp123_);
#line 499 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 499 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 499 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 499 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 499 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 499 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 499 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 499 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 499 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 499 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 499 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 499 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 499 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 499 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 499 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 499 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 499 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10256 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 500 "CssSelectorTest.vala"
		_tmp124_ = d2;
#line 500 "CssSelectorTest.vala"
		_tmp125_ = gxml_dom_document_create_element (_tmp124_, "common", &_inner_error0_);
#line 500 "CssSelectorTest.vala"
		c5g = _tmp125_;
#line 500 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 500 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 500 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 500 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 500 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 500 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 500 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 500 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 500 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 500 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 500 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 500 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 500 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 500 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 500 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 500 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 500 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10299 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 501 "CssSelectorTest.vala"
		_tmp126_ = c4g;
#line 501 "CssSelectorTest.vala"
		_tmp127_ = c5g;
#line 501 "CssSelectorTest.vala"
		_tmp128_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp126_, (GXmlDomNode*) _tmp127_, &_inner_error0_);
#line 501 "CssSelectorTest.vala"
		_tmp129_ = _tmp128_;
#line 501 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp129_);
#line 501 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 501 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 501 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 501 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 501 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 501 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 501 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 501 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 501 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 501 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 501 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 501 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 501 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 501 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 501 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 501 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 501 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 501 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10348 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 502 "CssSelectorTest.vala"
		_tmp131_ = cp;
#line 502 "CssSelectorTest.vala"
		_tmp132_ = r;
#line 502 "CssSelectorTest.vala"
		_tmp130_ = gxml_css_selector_parser_match (_tmp131_, _tmp132_, &_inner_error0_);
#line 502 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 502 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 502 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 502 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 502 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 502 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 502 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 502 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 502 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 502 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 502 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 502 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 502 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 502 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 502 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 502 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 502 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 502 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10393 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 502 "CssSelectorTest.vala"
		_vala_assert (!_tmp130_, "!cp.match (r)");
#line 503 "CssSelectorTest.vala"
		_tmp134_ = cp;
#line 503 "CssSelectorTest.vala"
		_tmp135_ = c1g;
#line 503 "CssSelectorTest.vala"
		_tmp133_ = gxml_css_selector_parser_match (_tmp134_, _tmp135_, &_inner_error0_);
#line 503 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 503 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 503 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 503 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 503 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 503 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 503 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 503 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 503 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 503 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 503 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 503 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 503 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 503 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 503 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 503 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 503 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 503 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10440 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 503 "CssSelectorTest.vala"
		_vala_assert (_tmp133_, "cp.match (c1g)");
#line 504 "CssSelectorTest.vala"
		_tmp137_ = cp;
#line 504 "CssSelectorTest.vala"
		_tmp138_ = c2g;
#line 504 "CssSelectorTest.vala"
		_tmp136_ = gxml_css_selector_parser_match (_tmp137_, _tmp138_, &_inner_error0_);
#line 504 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 504 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 504 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 504 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 504 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 504 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 504 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 504 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 504 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 504 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 504 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 504 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 504 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 504 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 504 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 504 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 504 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 504 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10487 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 504 "CssSelectorTest.vala"
		_vala_assert (_tmp136_, "cp.match (c2g)");
#line 505 "CssSelectorTest.vala"
		_tmp140_ = cp;
#line 505 "CssSelectorTest.vala"
		_tmp141_ = c3g;
#line 505 "CssSelectorTest.vala"
		_tmp139_ = gxml_css_selector_parser_match (_tmp140_, _tmp141_, &_inner_error0_);
#line 505 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 505 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 505 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 505 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 505 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 505 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 505 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 505 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 505 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 505 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 505 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 505 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 505 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 505 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 505 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 505 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 505 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 505 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10534 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 505 "CssSelectorTest.vala"
		_vala_assert (_tmp139_, "cp.match (c3g)");
#line 506 "CssSelectorTest.vala"
		_tmp143_ = cp;
#line 506 "CssSelectorTest.vala"
		_tmp144_ = c4g;
#line 506 "CssSelectorTest.vala"
		_tmp142_ = gxml_css_selector_parser_match (_tmp143_, _tmp144_, &_inner_error0_);
#line 506 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 506 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 506 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 506 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 506 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 506 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 506 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 506 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 506 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 506 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 506 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 506 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 506 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 506 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 506 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 506 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 506 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 506 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10581 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 506 "CssSelectorTest.vala"
		_vala_assert (!_tmp142_, "!cp.match (c4g)");
#line 507 "CssSelectorTest.vala"
		_tmp146_ = cp;
#line 507 "CssSelectorTest.vala"
		_tmp147_ = c5g;
#line 507 "CssSelectorTest.vala"
		_tmp145_ = gxml_css_selector_parser_match (_tmp146_, _tmp147_, &_inner_error0_);
#line 507 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 507 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 507 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 507 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 507 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 507 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 507 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 507 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 507 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 507 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 507 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 507 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 507 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 507 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 507 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 507 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 507 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 507 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10628 "CssSelectorTest.c"
			goto __catch13_g_error;
		}
#line 507 "CssSelectorTest.vala"
		_vala_assert (!_tmp145_, "!cp.match (c5g)");
#line 448 "CssSelectorTest.vala"
		_g_object_unref0 (c5g);
#line 448 "CssSelectorTest.vala"
		_g_object_unref0 (c4g);
#line 448 "CssSelectorTest.vala"
		_g_object_unref0 (c3g);
#line 448 "CssSelectorTest.vala"
		_g_object_unref0 (c2g);
#line 448 "CssSelectorTest.vala"
		_g_object_unref0 (c1g);
#line 448 "CssSelectorTest.vala"
		_g_object_unref0 (r2);
#line 448 "CssSelectorTest.vala"
		_g_object_unref0 (d2);
#line 448 "CssSelectorTest.vala"
		_g_object_unref0 (c5);
#line 448 "CssSelectorTest.vala"
		_g_object_unref0 (c4);
#line 448 "CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 448 "CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 448 "CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 448 "CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 448 "CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 448 "CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 448 "CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 448 "CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 10667 "CssSelectorTest.c"
	}
	goto __finally13;
	__catch13_g_error:
	{
		GError* e = NULL;
		GError* _tmp148_;
		const gchar* _tmp149_;
		gchar* _tmp150_;
		gchar* _tmp151_;
#line 448 "CssSelectorTest.vala"
		e = _inner_error0_;
#line 448 "CssSelectorTest.vala"
		_inner_error0_ = NULL;
#line 509 "CssSelectorTest.vala"
		_tmp148_ = e;
#line 509 "CssSelectorTest.vala"
		_tmp149_ = _tmp148_->message;
#line 509 "CssSelectorTest.vala"
		_tmp150_ = g_strconcat ("ERROR: ", _tmp149_, NULL);
#line 509 "CssSelectorTest.vala"
		_tmp151_ = _tmp150_;
#line 509 "CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:509: %s", _tmp151_);
#line 509 "CssSelectorTest.vala"
		_g_free0 (_tmp151_);
#line 448 "CssSelectorTest.vala"
		_g_error_free0 (e);
#line 10695 "CssSelectorTest.c"
	}
	__finally13:
#line 448 "CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 448 "CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 448 "CssSelectorTest.vala"
		g_clear_error (&_inner_error0_);
#line 448 "CssSelectorTest.vala"
		return;
#line 10706 "CssSelectorTest.c"
	}
}

static void
___lambda158__gtest_func (void)
{
#line 447 "CssSelectorTest.vala"
	__lambda158_ ();
#line 10715 "CssSelectorTest.c"
}

static void
__lambda159_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelector* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelector* _tmp11_;
		GXmlCssSelector* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelector* _tmp15_;
		GXmlCssCombiner _tmp16_;
		GXmlCssCombiner _tmp17_;
		GXmlCssSelector* sa = NULL;
		GXmlCssSelectorParser* _tmp18_;
		GeeList* _tmp19_;
		GeeList* _tmp20_;
		gpointer _tmp21_;
		GXmlCssSelector* _tmp22_;
		GXmlCssSelector* _tmp23_;
		GXmlCssSelectorType _tmp24_;
		GXmlCssSelectorType _tmp25_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp26_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp27_;
		GXmlDomElement* _tmp28_;
		GXmlGomDocument* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomNode* _tmp31_;
		GXmlDomNode* _tmp32_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp33_;
		GXmlDomElement* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomNode* _tmp38_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomElement* _tmp42_;
		GXmlDomElement* _tmp43_;
		GXmlDomNode* _tmp44_;
		GXmlDomNode* _tmp45_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlDomNode* _tmp51_;
		GXmlDomNode* _tmp52_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomElement* _tmp56_;
		GXmlDomElement* _tmp57_;
		GXmlDomNode* _tmp58_;
		GXmlDomNode* _tmp59_;
		GXmlDomElement* c5 = NULL;
		GXmlGomDocument* _tmp60_;
		GXmlDomElement* _tmp61_;
		GXmlDomElement* _tmp62_;
		GXmlDomElement* _tmp63_;
		GXmlDomNode* _tmp64_;
		GXmlDomNode* _tmp65_;
		GXmlDomElement* c6 = NULL;
		GXmlGomDocument* _tmp66_;
		GXmlDomElement* _tmp67_;
		GXmlDomElement* _tmp68_;
		GXmlDomElement* _tmp69_;
		GXmlDomNode* _tmp70_;
		GXmlDomNode* _tmp71_;
		GXmlDomElement* _tmp72_;
		GXmlDomElement* _tmp73_;
		GXmlDomNode* _tmp74_;
		GXmlDomNode* _tmp75_;
		GXmlDomParentNode* _tmp76_;
		GXmlDomParentNode* _tmp77_;
		GXmlDomElement* _tmp78_;
		GXmlDomElement* _tmp79_;
		GXmlDomElement* _tmp80_;
		GXmlDomElement* _tmp81_;
		GXmlDomElement* _tmp82_;
		GXmlDomNode* _tmp83_;
		GXmlDomNode* _tmp84_;
		GXmlDomParentNode* _tmp85_;
		GXmlDomParentNode* _tmp86_;
		GXmlDomElement* _tmp87_;
		GXmlDomElement* _tmp88_;
		GXmlDomElement* _tmp89_;
		GXmlDomElement* _tmp90_;
		GXmlDomElement* _tmp91_;
		GXmlDomNode* _tmp92_;
		GXmlDomNode* _tmp93_;
		GXmlDomParentNode* _tmp94_;
		GXmlDomParentNode* _tmp95_;
		GXmlDomElement* _tmp96_;
		GXmlDomElement* _tmp97_;
		GXmlDomElement* _tmp98_;
		GXmlDomElement* _tmp99_;
		GXmlDomElement* _tmp100_;
		GXmlDomNode* _tmp101_;
		GXmlDomNode* _tmp102_;
		GXmlDomParentNode* _tmp103_;
		GXmlDomParentNode* _tmp104_;
		GXmlDomElement* _tmp105_;
		GXmlDomElement* _tmp106_;
		GXmlDomElement* _tmp107_;
		GXmlDomElement* _tmp108_;
		GXmlDomElement* _tmp109_;
		GXmlDomNode* _tmp110_;
		GXmlDomNode* _tmp111_;
		GXmlDomParentNode* _tmp112_;
		GXmlDomParentNode* _tmp113_;
		GXmlDomElement* _tmp114_;
		GXmlDomElement* _tmp115_;
		GXmlDomElement* _tmp116_;
		GXmlDomElement* _tmp117_;
		GXmlDomElement* _tmp118_;
		GXmlDomNode* _tmp119_;
		GXmlDomNode* _tmp120_;
		GXmlDomParentNode* _tmp121_;
		GXmlDomParentNode* _tmp122_;
		GXmlDomElement* _tmp123_;
		GXmlDomElement* _tmp124_;
		GXmlDomElement* _tmp125_;
		gboolean _tmp126_ = FALSE;
		GXmlCssSelectorParser* _tmp127_;
		GXmlDomElement* _tmp128_;
		gboolean _tmp129_ = FALSE;
		GXmlCssSelectorParser* _tmp130_;
		GXmlDomElement* _tmp131_;
		gboolean _tmp132_ = FALSE;
		GXmlCssSelectorParser* _tmp133_;
		GXmlDomElement* _tmp134_;
		gboolean _tmp135_ = FALSE;
		GXmlCssSelectorParser* _tmp136_;
		GXmlDomElement* _tmp137_;
		gboolean _tmp138_ = FALSE;
		GXmlCssSelectorParser* _tmp139_;
		GXmlDomElement* _tmp140_;
		gboolean _tmp141_ = FALSE;
		GXmlCssSelectorParser* _tmp142_;
		GXmlDomElement* _tmp143_;
		gboolean _tmp144_ = FALSE;
		GXmlCssSelectorParser* _tmp145_;
		GXmlDomElement* _tmp146_;
		GXmlDomDocument* d2 = NULL;
		GXmlGDocument* _tmp147_;
		GXmlDomDocument* _tmp148_;
		GXmlDomElement* r2 = NULL;
		GXmlDomDocument* _tmp149_;
		GXmlDomElement* _tmp150_;
		GXmlDomDocument* _tmp151_;
		GXmlDomElement* _tmp152_;
		GXmlDomNode* _tmp153_;
		GXmlDomNode* _tmp154_;
		GXmlDomElement* c1g = NULL;
		GXmlDomDocument* _tmp155_;
		GXmlDomElement* _tmp156_;
		GXmlDomElement* _tmp157_;
		GXmlDomElement* _tmp158_;
		GXmlDomNode* _tmp159_;
		GXmlDomNode* _tmp160_;
		GXmlDomElement* c2g = NULL;
		GXmlDomDocument* _tmp161_;
		GXmlDomElement* _tmp162_;
		GXmlDomElement* _tmp163_;
		GXmlDomElement* _tmp164_;
		GXmlDomElement* _tmp165_;
		GXmlDomNode* _tmp166_;
		GXmlDomNode* _tmp167_;
		GXmlDomElement* c3g = NULL;
		GXmlDomDocument* _tmp168_;
		GXmlDomElement* _tmp169_;
		GXmlDomElement* _tmp170_;
		GXmlDomElement* _tmp171_;
		GXmlDomElement* _tmp172_;
		GXmlDomNode* _tmp173_;
		GXmlDomNode* _tmp174_;
		GXmlDomElement* c4g = NULL;
		GXmlDomDocument* _tmp175_;
		GXmlDomElement* _tmp176_;
		GXmlDomElement* _tmp177_;
		GXmlDomElement* _tmp178_;
		GXmlDomElement* _tmp179_;
		GXmlDomNode* _tmp180_;
		GXmlDomNode* _tmp181_;
		GXmlDomElement* c5g = NULL;
		GXmlDomDocument* _tmp182_;
		GXmlDomElement* _tmp183_;
		GXmlDomElement* _tmp184_;
		GXmlDomElement* _tmp185_;
		GXmlDomNode* _tmp186_;
		GXmlDomNode* _tmp187_;
		GXmlDomElement* c6g = NULL;
		GXmlDomDocument* _tmp188_;
		GXmlDomElement* _tmp189_;
		GXmlDomElement* _tmp190_;
		GXmlDomElement* _tmp191_;
		GXmlDomNode* _tmp192_;
		GXmlDomNode* _tmp193_;
		gboolean _tmp194_ = FALSE;
		GXmlCssSelectorParser* _tmp195_;
		GXmlDomElement* _tmp196_;
		gboolean _tmp197_ = FALSE;
		GXmlCssSelectorParser* _tmp198_;
		GXmlDomElement* _tmp199_;
		gboolean _tmp200_ = FALSE;
		GXmlCssSelectorParser* _tmp201_;
		GXmlDomElement* _tmp202_;
		gboolean _tmp203_ = FALSE;
		GXmlCssSelectorParser* _tmp204_;
		GXmlDomElement* _tmp205_;
		gboolean _tmp206_ = FALSE;
		GXmlCssSelectorParser* _tmp207_;
		GXmlDomElement* _tmp208_;
		gboolean _tmp209_ = FALSE;
		GXmlCssSelectorParser* _tmp210_;
		GXmlDomElement* _tmp211_;
		gboolean _tmp212_ = FALSE;
		GXmlCssSelectorParser* _tmp213_;
		GXmlDomElement* _tmp214_;
#line 514 "CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 514 "CssSelectorTest.vala"
		cp = _tmp0_;
#line 515 "CssSelectorTest.vala"
		_tmp1_ = cp;
#line 515 "CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "second:first-child", &_inner_error0_);
#line 515 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 515 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 10969 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 516 "CssSelectorTest.vala"
		_tmp2_ = cp;
#line 516 "CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 516 "CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 516 "CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 516 "CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 516 "CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 2, "cp.selectors.size == 2");
#line 517 "CssSelectorTest.vala"
		_tmp7_ = cp;
#line 517 "CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 517 "CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 517 "CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 517 "CssSelectorTest.vala"
		s = (GXmlCssSelector*) _tmp10_;
#line 518 "CssSelectorTest.vala"
		_tmp11_ = s;
#line 518 "CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 519 "CssSelectorTest.vala"
		_tmp12_ = s;
#line 519 "CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_get_selector_type (_tmp12_);
#line 519 "CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 519 "CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 520 "CssSelectorTest.vala"
		_tmp15_ = s;
#line 520 "CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_get_combiner (_tmp15_);
#line 520 "CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 520 "CssSelectorTest.vala"
		_vala_assert (_tmp17_ == GXML_CSS_COMBINER_NONE, "s.combiner == CssCombiner.NONE");
#line 521 "CssSelectorTest.vala"
		_tmp18_ = cp;
#line 521 "CssSelectorTest.vala"
		_tmp19_ = gxml_css_selector_parser_get_selectors (_tmp18_);
#line 521 "CssSelectorTest.vala"
		_tmp20_ = _tmp19_;
#line 521 "CssSelectorTest.vala"
		_tmp21_ = gee_list_get (_tmp20_, 1);
#line 521 "CssSelectorTest.vala"
		sa = (GXmlCssSelector*) _tmp21_;
#line 522 "CssSelectorTest.vala"
		_tmp22_ = sa;
#line 522 "CssSelectorTest.vala"
		_vala_assert (_tmp22_ != NULL, "sa != null");
#line 523 "CssSelectorTest.vala"
		_tmp23_ = sa;
#line 523 "CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_get_selector_type (_tmp23_);
#line 523 "CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 523 "CssSelectorTest.vala"
		_vala_assert (_tmp25_ == GXML_CSS_SELECTOR_TYPE_PSEUDO_CLASS, "sa.selector_type == CssSelectorType.PSEUDO_CLASS");
#line 524 "CssSelectorTest.vala"
		_tmp26_ = gxml_gom_document_new ();
#line 524 "CssSelectorTest.vala"
		d = _tmp26_;
#line 525 "CssSelectorTest.vala"
		_tmp27_ = d;
#line 525 "CssSelectorTest.vala"
		_tmp28_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp27_, "toplevel", &_inner_error0_);
#line 525 "CssSelectorTest.vala"
		r = _tmp28_;
#line 525 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 525 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 525 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 525 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 525 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11056 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 526 "CssSelectorTest.vala"
		_tmp29_ = d;
#line 526 "CssSelectorTest.vala"
		_tmp30_ = r;
#line 526 "CssSelectorTest.vala"
		_tmp31_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp29_, (GXmlDomNode*) _tmp30_, &_inner_error0_);
#line 526 "CssSelectorTest.vala"
		_tmp32_ = _tmp31_;
#line 526 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp32_);
#line 526 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 526 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 526 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 526 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 526 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 526 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11081 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 527 "CssSelectorTest.vala"
		_tmp33_ = d;
#line 527 "CssSelectorTest.vala"
		_tmp34_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp33_, "child", &_inner_error0_);
#line 527 "CssSelectorTest.vala"
		c1 = _tmp34_;
#line 527 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 527 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 527 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 527 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 527 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 527 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11102 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 528 "CssSelectorTest.vala"
		_tmp35_ = r;
#line 528 "CssSelectorTest.vala"
		_tmp36_ = c1;
#line 528 "CssSelectorTest.vala"
		_tmp37_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp35_, (GXmlDomNode*) _tmp36_, &_inner_error0_);
#line 528 "CssSelectorTest.vala"
		_tmp38_ = _tmp37_;
#line 528 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp38_);
#line 528 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 528 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 528 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 528 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 528 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 528 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 528 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11129 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 529 "CssSelectorTest.vala"
		_tmp39_ = d;
#line 529 "CssSelectorTest.vala"
		_tmp40_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp39_, "child", &_inner_error0_);
#line 529 "CssSelectorTest.vala"
		c2 = _tmp40_;
#line 529 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 529 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 529 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 529 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 529 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 529 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 529 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11152 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 530 "CssSelectorTest.vala"
		_tmp41_ = c2;
#line 530 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp41_, "prop-name", "subval", &_inner_error0_);
#line 530 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 530 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 530 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 530 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 530 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 530 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 530 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 530 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11175 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 531 "CssSelectorTest.vala"
		_tmp42_ = r;
#line 531 "CssSelectorTest.vala"
		_tmp43_ = c2;
#line 531 "CssSelectorTest.vala"
		_tmp44_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp42_, (GXmlDomNode*) _tmp43_, &_inner_error0_);
#line 531 "CssSelectorTest.vala"
		_tmp45_ = _tmp44_;
#line 531 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp45_);
#line 531 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 531 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 531 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 531 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 531 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 531 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 531 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 531 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11204 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 532 "CssSelectorTest.vala"
		_tmp46_ = d;
#line 532 "CssSelectorTest.vala"
		_tmp47_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp46_, "child", &_inner_error0_);
#line 532 "CssSelectorTest.vala"
		c3 = _tmp47_;
#line 532 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 532 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 532 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 532 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 532 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 532 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 532 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 532 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11229 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 533 "CssSelectorTest.vala"
		_tmp48_ = c3;
#line 533 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp48_, "prop-name", "techval", &_inner_error0_);
#line 533 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 533 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 533 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 533 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 533 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 533 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 533 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 533 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 533 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11254 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 534 "CssSelectorTest.vala"
		_tmp49_ = r;
#line 534 "CssSelectorTest.vala"
		_tmp50_ = c3;
#line 534 "CssSelectorTest.vala"
		_tmp51_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp49_, (GXmlDomNode*) _tmp50_, &_inner_error0_);
#line 534 "CssSelectorTest.vala"
		_tmp52_ = _tmp51_;
#line 534 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp52_);
#line 534 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 534 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 534 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 534 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 534 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 534 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 534 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 534 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 534 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11285 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 535 "CssSelectorTest.vala"
		_tmp53_ = d;
#line 535 "CssSelectorTest.vala"
		_tmp54_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp53_, "child", &_inner_error0_);
#line 535 "CssSelectorTest.vala"
		c4 = _tmp54_;
#line 535 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 535 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 535 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 535 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 535 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 535 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 535 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 535 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 535 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11312 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 536 "CssSelectorTest.vala"
		_tmp55_ = c4;
#line 536 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp55_, "prop-name", "secondaryvalue", &_inner_error0_);
#line 536 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 536 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 536 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 536 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 536 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 536 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 536 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 536 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 536 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 536 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11339 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 537 "CssSelectorTest.vala"
		_tmp56_ = r;
#line 537 "CssSelectorTest.vala"
		_tmp57_ = c4;
#line 537 "CssSelectorTest.vala"
		_tmp58_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp56_, (GXmlDomNode*) _tmp57_, &_inner_error0_);
#line 537 "CssSelectorTest.vala"
		_tmp59_ = _tmp58_;
#line 537 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp59_);
#line 537 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 537 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 537 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 537 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 537 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 537 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 537 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 537 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 537 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 537 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11372 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 538 "CssSelectorTest.vala"
		_tmp60_ = d;
#line 538 "CssSelectorTest.vala"
		_tmp61_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp60_, "second", &_inner_error0_);
#line 538 "CssSelectorTest.vala"
		c5 = _tmp61_;
#line 538 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 538 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 538 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 538 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 538 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 538 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 538 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 538 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 538 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 538 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11401 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 539 "CssSelectorTest.vala"
		_tmp62_ = c3;
#line 539 "CssSelectorTest.vala"
		_tmp63_ = c5;
#line 539 "CssSelectorTest.vala"
		_tmp64_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp62_, (GXmlDomNode*) _tmp63_, &_inner_error0_);
#line 539 "CssSelectorTest.vala"
		_tmp65_ = _tmp64_;
#line 539 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp65_);
#line 539 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 539 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 539 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 539 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 539 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 539 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 539 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 539 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 539 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 539 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 539 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11436 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 540 "CssSelectorTest.vala"
		_tmp66_ = d;
#line 540 "CssSelectorTest.vala"
		_tmp67_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp66_, "second", &_inner_error0_);
#line 540 "CssSelectorTest.vala"
		c6 = _tmp67_;
#line 540 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 540 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 540 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 540 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 540 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 540 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 540 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 540 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 540 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 540 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 540 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11467 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 541 "CssSelectorTest.vala"
		_tmp68_ = c4;
#line 541 "CssSelectorTest.vala"
		_tmp69_ = c6;
#line 541 "CssSelectorTest.vala"
		_tmp70_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp68_, (GXmlDomNode*) _tmp69_, &_inner_error0_);
#line 541 "CssSelectorTest.vala"
		_tmp71_ = _tmp70_;
#line 541 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp71_);
#line 541 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 541 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 541 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 541 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 541 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 541 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 541 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 541 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 541 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 541 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 541 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 541 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11504 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 542 "CssSelectorTest.vala"
		_tmp72_ = c1;
#line 542 "CssSelectorTest.vala"
		_tmp73_ = c1;
#line 542 "CssSelectorTest.vala"
		_tmp74_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp73_);
#line 542 "CssSelectorTest.vala"
		_tmp75_ = _tmp74_;
#line 542 "CssSelectorTest.vala"
		_tmp76_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp75_, GXML_TYPE_DOM_PARENT_NODE) ? ((GXmlDomParentNode*) _tmp75_) : NULL;
#line 542 "CssSelectorTest.vala"
		if (_tmp76_ == NULL) {
#line 542 "CssSelectorTest.vala"
			_g_object_unref0 (_tmp75_);
#line 11521 "CssSelectorTest.c"
		}
#line 542 "CssSelectorTest.vala"
		_tmp77_ = _tmp76_;
#line 542 "CssSelectorTest.vala"
		_tmp78_ = gxml_dom_parent_node_get_first_element_child (_tmp77_);
#line 542 "CssSelectorTest.vala"
		_tmp79_ = _tmp78_;
#line 542 "CssSelectorTest.vala"
		_tmp80_ = _tmp79_;
#line 542 "CssSelectorTest.vala"
		_vala_assert (_tmp72_ == _tmp80_, "c1 == (c1.parent_node as DomParentNode).first_element_child");
#line 542 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp80_);
#line 542 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp77_);
#line 543 "CssSelectorTest.vala"
		_tmp81_ = c2;
#line 543 "CssSelectorTest.vala"
		_tmp82_ = c2;
#line 543 "CssSelectorTest.vala"
		_tmp83_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp82_);
#line 543 "CssSelectorTest.vala"
		_tmp84_ = _tmp83_;
#line 543 "CssSelectorTest.vala"
		_tmp85_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp84_, GXML_TYPE_DOM_PARENT_NODE) ? ((GXmlDomParentNode*) _tmp84_) : NULL;
#line 543 "CssSelectorTest.vala"
		if (_tmp85_ == NULL) {
#line 543 "CssSelectorTest.vala"
			_g_object_unref0 (_tmp84_);
#line 11551 "CssSelectorTest.c"
		}
#line 543 "CssSelectorTest.vala"
		_tmp86_ = _tmp85_;
#line 543 "CssSelectorTest.vala"
		_tmp87_ = gxml_dom_parent_node_get_first_element_child (_tmp86_);
#line 543 "CssSelectorTest.vala"
		_tmp88_ = _tmp87_;
#line 543 "CssSelectorTest.vala"
		_tmp89_ = _tmp88_;
#line 543 "CssSelectorTest.vala"
		_vala_assert (_tmp81_ != _tmp89_, "c2 != (c2.parent_node as DomParentNode).first_element_child");
#line 543 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp89_);
#line 543 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp86_);
#line 544 "CssSelectorTest.vala"
		_tmp90_ = c3;
#line 544 "CssSelectorTest.vala"
		_tmp91_ = c3;
#line 544 "CssSelectorTest.vala"
		_tmp92_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp91_);
#line 544 "CssSelectorTest.vala"
		_tmp93_ = _tmp92_;
#line 544 "CssSelectorTest.vala"
		_tmp94_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp93_, GXML_TYPE_DOM_PARENT_NODE) ? ((GXmlDomParentNode*) _tmp93_) : NULL;
#line 544 "CssSelectorTest.vala"
		if (_tmp94_ == NULL) {
#line 544 "CssSelectorTest.vala"
			_g_object_unref0 (_tmp93_);
#line 11581 "CssSelectorTest.c"
		}
#line 544 "CssSelectorTest.vala"
		_tmp95_ = _tmp94_;
#line 544 "CssSelectorTest.vala"
		_tmp96_ = gxml_dom_parent_node_get_first_element_child (_tmp95_);
#line 544 "CssSelectorTest.vala"
		_tmp97_ = _tmp96_;
#line 544 "CssSelectorTest.vala"
		_tmp98_ = _tmp97_;
#line 544 "CssSelectorTest.vala"
		_vala_assert (_tmp90_ != _tmp98_, "c3 != (c3.parent_node as DomParentNode).first_element_child");
#line 544 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp98_);
#line 544 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp95_);
#line 545 "CssSelectorTest.vala"
		_tmp99_ = c4;
#line 545 "CssSelectorTest.vala"
		_tmp100_ = c4;
#line 545 "CssSelectorTest.vala"
		_tmp101_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp100_);
#line 545 "CssSelectorTest.vala"
		_tmp102_ = _tmp101_;
#line 545 "CssSelectorTest.vala"
		_tmp103_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp102_, GXML_TYPE_DOM_PARENT_NODE) ? ((GXmlDomParentNode*) _tmp102_) : NULL;
#line 545 "CssSelectorTest.vala"
		if (_tmp103_ == NULL) {
#line 545 "CssSelectorTest.vala"
			_g_object_unref0 (_tmp102_);
#line 11611 "CssSelectorTest.c"
		}
#line 545 "CssSelectorTest.vala"
		_tmp104_ = _tmp103_;
#line 545 "CssSelectorTest.vala"
		_tmp105_ = gxml_dom_parent_node_get_first_element_child (_tmp104_);
#line 545 "CssSelectorTest.vala"
		_tmp106_ = _tmp105_;
#line 545 "CssSelectorTest.vala"
		_tmp107_ = _tmp106_;
#line 545 "CssSelectorTest.vala"
		_vala_assert (_tmp99_ != _tmp107_, "c4 != (c4.parent_node as DomParentNode).first_element_child");
#line 545 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp107_);
#line 545 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp104_);
#line 546 "CssSelectorTest.vala"
		_tmp108_ = c5;
#line 546 "CssSelectorTest.vala"
		_tmp109_ = c5;
#line 546 "CssSelectorTest.vala"
		_tmp110_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp109_);
#line 546 "CssSelectorTest.vala"
		_tmp111_ = _tmp110_;
#line 546 "CssSelectorTest.vala"
		_tmp112_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp111_, GXML_TYPE_DOM_PARENT_NODE) ? ((GXmlDomParentNode*) _tmp111_) : NULL;
#line 546 "CssSelectorTest.vala"
		if (_tmp112_ == NULL) {
#line 546 "CssSelectorTest.vala"
			_g_object_unref0 (_tmp111_);
#line 11641 "CssSelectorTest.c"
		}
#line 546 "CssSelectorTest.vala"
		_tmp113_ = _tmp112_;
#line 546 "CssSelectorTest.vala"
		_tmp114_ = gxml_dom_parent_node_get_first_element_child (_tmp113_);
#line 546 "CssSelectorTest.vala"
		_tmp115_ = _tmp114_;
#line 546 "CssSelectorTest.vala"
		_tmp116_ = _tmp115_;
#line 546 "CssSelectorTest.vala"
		_vala_assert (_tmp108_ == _tmp116_, "c5 == (c5.parent_node as DomParentNode).first_element_child");
#line 546 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp116_);
#line 546 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp113_);
#line 547 "CssSelectorTest.vala"
		_tmp117_ = c6;
#line 547 "CssSelectorTest.vala"
		_tmp118_ = c6;
#line 547 "CssSelectorTest.vala"
		_tmp119_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp118_);
#line 547 "CssSelectorTest.vala"
		_tmp120_ = _tmp119_;
#line 547 "CssSelectorTest.vala"
		_tmp121_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp120_, GXML_TYPE_DOM_PARENT_NODE) ? ((GXmlDomParentNode*) _tmp120_) : NULL;
#line 547 "CssSelectorTest.vala"
		if (_tmp121_ == NULL) {
#line 547 "CssSelectorTest.vala"
			_g_object_unref0 (_tmp120_);
#line 11671 "CssSelectorTest.c"
		}
#line 547 "CssSelectorTest.vala"
		_tmp122_ = _tmp121_;
#line 547 "CssSelectorTest.vala"
		_tmp123_ = gxml_dom_parent_node_get_first_element_child (_tmp122_);
#line 547 "CssSelectorTest.vala"
		_tmp124_ = _tmp123_;
#line 547 "CssSelectorTest.vala"
		_tmp125_ = _tmp124_;
#line 547 "CssSelectorTest.vala"
		_vala_assert (_tmp117_ == _tmp125_, "c6 == (c6.parent_node as DomParentNode).first_element_child");
#line 547 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp125_);
#line 547 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp122_);
#line 548 "CssSelectorTest.vala"
		_tmp127_ = cp;
#line 548 "CssSelectorTest.vala"
		_tmp128_ = r;
#line 548 "CssSelectorTest.vala"
		_tmp126_ = gxml_css_selector_parser_match (_tmp127_, _tmp128_, &_inner_error0_);
#line 548 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 548 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 548 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 548 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 548 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 548 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 548 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 548 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 548 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 548 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 548 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 548 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11717 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 548 "CssSelectorTest.vala"
		_vala_assert (!_tmp126_, "!cp.match (r)");
#line 549 "CssSelectorTest.vala"
		_tmp130_ = cp;
#line 549 "CssSelectorTest.vala"
		_tmp131_ = c1;
#line 549 "CssSelectorTest.vala"
		_tmp129_ = gxml_css_selector_parser_match (_tmp130_, _tmp131_, &_inner_error0_);
#line 549 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 549 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 549 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 549 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 549 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 549 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 549 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 549 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 549 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 549 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 549 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 549 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11752 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 549 "CssSelectorTest.vala"
		_vala_assert (!_tmp129_, "!cp.match (c1)");
#line 550 "CssSelectorTest.vala"
		_tmp133_ = cp;
#line 550 "CssSelectorTest.vala"
		_tmp134_ = c2;
#line 550 "CssSelectorTest.vala"
		_tmp132_ = gxml_css_selector_parser_match (_tmp133_, _tmp134_, &_inner_error0_);
#line 550 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 550 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 550 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 550 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 550 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 550 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 550 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 550 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 550 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 550 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 550 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 550 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11787 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 550 "CssSelectorTest.vala"
		_vala_assert (!_tmp132_, "!cp.match (c2)");
#line 551 "CssSelectorTest.vala"
		_tmp136_ = cp;
#line 551 "CssSelectorTest.vala"
		_tmp137_ = c3;
#line 551 "CssSelectorTest.vala"
		_tmp135_ = gxml_css_selector_parser_match (_tmp136_, _tmp137_, &_inner_error0_);
#line 551 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 551 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 551 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 551 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 551 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 551 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 551 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 551 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 551 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 551 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 551 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 551 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11822 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 551 "CssSelectorTest.vala"
		_vala_assert (!_tmp135_, "!cp.match (c3)");
#line 552 "CssSelectorTest.vala"
		_tmp139_ = cp;
#line 552 "CssSelectorTest.vala"
		_tmp140_ = c4;
#line 552 "CssSelectorTest.vala"
		_tmp138_ = gxml_css_selector_parser_match (_tmp139_, _tmp140_, &_inner_error0_);
#line 552 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 552 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 552 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 552 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 552 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 552 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 552 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 552 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 552 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 552 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 552 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 552 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11857 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 552 "CssSelectorTest.vala"
		_vala_assert (!_tmp138_, "!cp.match (c4)");
#line 553 "CssSelectorTest.vala"
		_tmp142_ = cp;
#line 553 "CssSelectorTest.vala"
		_tmp143_ = c5;
#line 553 "CssSelectorTest.vala"
		_tmp141_ = gxml_css_selector_parser_match (_tmp142_, _tmp143_, &_inner_error0_);
#line 553 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 553 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 553 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 553 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 553 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 553 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 553 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 553 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 553 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 553 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 553 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 553 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11892 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 553 "CssSelectorTest.vala"
		_vala_assert (_tmp141_, "cp.match (c5)");
#line 554 "CssSelectorTest.vala"
		_tmp145_ = cp;
#line 554 "CssSelectorTest.vala"
		_tmp146_ = c6;
#line 554 "CssSelectorTest.vala"
		_tmp144_ = gxml_css_selector_parser_match (_tmp145_, _tmp146_, &_inner_error0_);
#line 554 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 554 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 554 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 554 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 554 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 554 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 554 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 554 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 554 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 554 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 554 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 554 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11927 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 554 "CssSelectorTest.vala"
		_vala_assert (_tmp144_, "cp.match (c6)");
#line 555 "CssSelectorTest.vala"
		_tmp147_ = gxml_gdocument_new ();
#line 555 "CssSelectorTest.vala"
		_tmp148_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp147_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp147_) : NULL;
#line 555 "CssSelectorTest.vala"
		if (_tmp148_ == NULL) {
#line 555 "CssSelectorTest.vala"
			_g_object_unref0 (_tmp147_);
#line 11940 "CssSelectorTest.c"
		}
#line 555 "CssSelectorTest.vala"
		d2 = _tmp148_;
#line 556 "CssSelectorTest.vala"
		_tmp149_ = d2;
#line 556 "CssSelectorTest.vala"
		_tmp150_ = gxml_dom_document_create_element (_tmp149_, "toplevel", &_inner_error0_);
#line 556 "CssSelectorTest.vala"
		r2 = _tmp150_;
#line 556 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 556 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 556 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 556 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 556 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 556 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 556 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 556 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 556 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 556 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 556 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 556 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 556 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 11976 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 557 "CssSelectorTest.vala"
		_tmp151_ = d2;
#line 557 "CssSelectorTest.vala"
		_tmp152_ = r2;
#line 557 "CssSelectorTest.vala"
		_tmp153_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp151_, (GXmlDomNode*) _tmp152_, &_inner_error0_);
#line 557 "CssSelectorTest.vala"
		_tmp154_ = _tmp153_;
#line 557 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp154_);
#line 557 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 557 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 557 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 557 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 557 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 557 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 557 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 557 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 557 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 557 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 557 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 557 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 557 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 557 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12017 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 558 "CssSelectorTest.vala"
		_tmp155_ = d2;
#line 558 "CssSelectorTest.vala"
		_tmp156_ = gxml_dom_document_create_element (_tmp155_, "child", &_inner_error0_);
#line 558 "CssSelectorTest.vala"
		c1g = _tmp156_;
#line 558 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 558 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 558 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 558 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 558 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 558 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 558 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 558 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 558 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 558 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 558 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 558 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 558 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 558 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12054 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 559 "CssSelectorTest.vala"
		_tmp157_ = r2;
#line 559 "CssSelectorTest.vala"
		_tmp158_ = c1g;
#line 559 "CssSelectorTest.vala"
		_tmp159_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp157_, (GXmlDomNode*) _tmp158_, &_inner_error0_);
#line 559 "CssSelectorTest.vala"
		_tmp160_ = _tmp159_;
#line 559 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp160_);
#line 559 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 559 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 559 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 559 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 559 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 559 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 559 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 559 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 559 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 559 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 559 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 559 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 559 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 559 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 559 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12097 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 560 "CssSelectorTest.vala"
		_tmp161_ = d2;
#line 560 "CssSelectorTest.vala"
		_tmp162_ = gxml_dom_document_create_element (_tmp161_, "child", &_inner_error0_);
#line 560 "CssSelectorTest.vala"
		c2g = _tmp162_;
#line 560 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 560 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 560 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 560 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 560 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 560 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 560 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 560 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 560 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 560 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 560 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 560 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 560 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 560 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 560 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12136 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 561 "CssSelectorTest.vala"
		_tmp163_ = c2g;
#line 561 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp163_, "prop-name", "subval", &_inner_error0_);
#line 561 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 561 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 561 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 561 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 561 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 561 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 561 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 561 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 561 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 561 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 561 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 561 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 561 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 561 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 561 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 561 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12175 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 562 "CssSelectorTest.vala"
		_tmp164_ = r2;
#line 562 "CssSelectorTest.vala"
		_tmp165_ = c2g;
#line 562 "CssSelectorTest.vala"
		_tmp166_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp164_, (GXmlDomNode*) _tmp165_, &_inner_error0_);
#line 562 "CssSelectorTest.vala"
		_tmp167_ = _tmp166_;
#line 562 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp167_);
#line 562 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 562 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 562 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 562 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 562 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 562 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 562 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 562 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 562 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 562 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 562 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 562 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 562 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 562 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 562 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 562 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12220 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 563 "CssSelectorTest.vala"
		_tmp168_ = d2;
#line 563 "CssSelectorTest.vala"
		_tmp169_ = gxml_dom_document_create_element (_tmp168_, "child", &_inner_error0_);
#line 563 "CssSelectorTest.vala"
		c3g = _tmp169_;
#line 563 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 563 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 563 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 563 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 563 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 563 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 563 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 563 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 563 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 563 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 563 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 563 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 563 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 563 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 563 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 563 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12261 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 564 "CssSelectorTest.vala"
		_tmp170_ = c3g;
#line 564 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp170_, "prop-name", "techval", &_inner_error0_);
#line 564 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 564 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 564 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 564 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 564 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 564 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 564 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 564 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 564 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 564 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 564 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 564 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 564 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 564 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 564 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 564 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 564 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12302 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 565 "CssSelectorTest.vala"
		_tmp171_ = r2;
#line 565 "CssSelectorTest.vala"
		_tmp172_ = c3g;
#line 565 "CssSelectorTest.vala"
		_tmp173_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp171_, (GXmlDomNode*) _tmp172_, &_inner_error0_);
#line 565 "CssSelectorTest.vala"
		_tmp174_ = _tmp173_;
#line 565 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp174_);
#line 565 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 565 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 565 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 565 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 565 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 565 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 565 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 565 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 565 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 565 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 565 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 565 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 565 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 565 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 565 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 565 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 565 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12349 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 566 "CssSelectorTest.vala"
		_tmp175_ = d2;
#line 566 "CssSelectorTest.vala"
		_tmp176_ = gxml_dom_document_create_element (_tmp175_, "child", &_inner_error0_);
#line 566 "CssSelectorTest.vala"
		c4g = _tmp176_;
#line 566 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 566 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 566 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 566 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 566 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 566 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 566 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 566 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 566 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 566 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 566 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 566 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 566 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 566 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 566 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 566 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 566 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12392 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 567 "CssSelectorTest.vala"
		_tmp177_ = c4g;
#line 567 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp177_, "prop-name", "secondaryvalue", &_inner_error0_);
#line 567 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 567 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 567 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 567 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 567 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 567 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 567 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 567 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 567 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 567 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 567 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 567 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 567 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 567 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 567 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 567 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 567 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 567 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12435 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 568 "CssSelectorTest.vala"
		_tmp178_ = r2;
#line 568 "CssSelectorTest.vala"
		_tmp179_ = c4g;
#line 568 "CssSelectorTest.vala"
		_tmp180_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp178_, (GXmlDomNode*) _tmp179_, &_inner_error0_);
#line 568 "CssSelectorTest.vala"
		_tmp181_ = _tmp180_;
#line 568 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp181_);
#line 568 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 568 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 568 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 568 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 568 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 568 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 568 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 568 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 568 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 568 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 568 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 568 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 568 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 568 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 568 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 568 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 568 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 568 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12484 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 569 "CssSelectorTest.vala"
		_tmp182_ = d2;
#line 569 "CssSelectorTest.vala"
		_tmp183_ = gxml_dom_document_create_element (_tmp182_, "second", &_inner_error0_);
#line 569 "CssSelectorTest.vala"
		c5g = _tmp183_;
#line 569 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 569 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 569 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 569 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 569 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 569 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 569 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 569 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 569 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 569 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 569 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 569 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 569 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 569 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 569 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 569 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 569 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 569 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12529 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 570 "CssSelectorTest.vala"
		_tmp184_ = c3g;
#line 570 "CssSelectorTest.vala"
		_tmp185_ = c5g;
#line 570 "CssSelectorTest.vala"
		_tmp186_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp184_, (GXmlDomNode*) _tmp185_, &_inner_error0_);
#line 570 "CssSelectorTest.vala"
		_tmp187_ = _tmp186_;
#line 570 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp187_);
#line 570 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 570 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 570 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 570 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 570 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 570 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 570 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 570 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 570 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 570 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 570 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 570 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 570 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 570 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 570 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 570 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 570 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 570 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 570 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12580 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 571 "CssSelectorTest.vala"
		_tmp188_ = d2;
#line 571 "CssSelectorTest.vala"
		_tmp189_ = gxml_dom_document_create_element (_tmp188_, "second", &_inner_error0_);
#line 571 "CssSelectorTest.vala"
		c6g = _tmp189_;
#line 571 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 571 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 571 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 571 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 571 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 571 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 571 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 571 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 571 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 571 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 571 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 571 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 571 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 571 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 571 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 571 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 571 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 571 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 571 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12627 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 572 "CssSelectorTest.vala"
		_tmp190_ = c4g;
#line 572 "CssSelectorTest.vala"
		_tmp191_ = c6g;
#line 572 "CssSelectorTest.vala"
		_tmp192_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp190_, (GXmlDomNode*) _tmp191_, &_inner_error0_);
#line 572 "CssSelectorTest.vala"
		_tmp193_ = _tmp192_;
#line 572 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp193_);
#line 572 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 572 "CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 572 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 572 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 572 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 572 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 572 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 572 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 572 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 572 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 572 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 572 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 572 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 572 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 572 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 572 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 572 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 572 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 572 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 572 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12680 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 573 "CssSelectorTest.vala"
		_tmp195_ = cp;
#line 573 "CssSelectorTest.vala"
		_tmp196_ = r;
#line 573 "CssSelectorTest.vala"
		_tmp194_ = gxml_css_selector_parser_match (_tmp195_, _tmp196_, &_inner_error0_);
#line 573 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 573 "CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 573 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 573 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 573 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 573 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 573 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 573 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 573 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 573 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 573 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 573 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 573 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 573 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 573 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 573 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 573 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 573 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 573 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 573 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12729 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 573 "CssSelectorTest.vala"
		_vala_assert (!_tmp194_, "!cp.match (r)");
#line 574 "CssSelectorTest.vala"
		_tmp198_ = cp;
#line 574 "CssSelectorTest.vala"
		_tmp199_ = c1g;
#line 574 "CssSelectorTest.vala"
		_tmp197_ = gxml_css_selector_parser_match (_tmp198_, _tmp199_, &_inner_error0_);
#line 574 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 574 "CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 574 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 574 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 574 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 574 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 574 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 574 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 574 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 574 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 574 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 574 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 574 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 574 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 574 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 574 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 574 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 574 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 574 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 574 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12780 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 574 "CssSelectorTest.vala"
		_vala_assert (!_tmp197_, "!cp.match (c1g)");
#line 575 "CssSelectorTest.vala"
		_tmp201_ = cp;
#line 575 "CssSelectorTest.vala"
		_tmp202_ = c2g;
#line 575 "CssSelectorTest.vala"
		_tmp200_ = gxml_css_selector_parser_match (_tmp201_, _tmp202_, &_inner_error0_);
#line 575 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 575 "CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 575 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 575 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 575 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 575 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 575 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 575 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 575 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 575 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 575 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 575 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 575 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 575 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 575 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 575 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 575 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 575 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 575 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 575 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12831 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 575 "CssSelectorTest.vala"
		_vala_assert (!_tmp200_, "!cp.match (c2g)");
#line 576 "CssSelectorTest.vala"
		_tmp204_ = cp;
#line 576 "CssSelectorTest.vala"
		_tmp205_ = c3g;
#line 576 "CssSelectorTest.vala"
		_tmp203_ = gxml_css_selector_parser_match (_tmp204_, _tmp205_, &_inner_error0_);
#line 576 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 576 "CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 576 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 576 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 576 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 576 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 576 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 576 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 576 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 576 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 576 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 576 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 576 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 576 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 576 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 576 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 576 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 576 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 576 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 576 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12882 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 576 "CssSelectorTest.vala"
		_vala_assert (!_tmp203_, "!cp.match (c3g)");
#line 577 "CssSelectorTest.vala"
		_tmp207_ = cp;
#line 577 "CssSelectorTest.vala"
		_tmp208_ = c4g;
#line 577 "CssSelectorTest.vala"
		_tmp206_ = gxml_css_selector_parser_match (_tmp207_, _tmp208_, &_inner_error0_);
#line 577 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 577 "CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 577 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 577 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 577 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 577 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 577 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 577 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 577 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 577 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 577 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 577 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 577 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 577 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 577 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 577 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 577 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 577 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 577 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 577 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12933 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 577 "CssSelectorTest.vala"
		_vala_assert (!_tmp206_, "!cp.match (c4g)");
#line 578 "CssSelectorTest.vala"
		_tmp210_ = cp;
#line 578 "CssSelectorTest.vala"
		_tmp211_ = c5g;
#line 578 "CssSelectorTest.vala"
		_tmp209_ = gxml_css_selector_parser_match (_tmp210_, _tmp211_, &_inner_error0_);
#line 578 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 578 "CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 578 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 578 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 578 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 578 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 578 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 578 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 578 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 578 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 578 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 578 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 578 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 578 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 578 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 578 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 578 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 578 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 578 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 578 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 12984 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 578 "CssSelectorTest.vala"
		_vala_assert (_tmp209_, "cp.match (c5g)");
#line 579 "CssSelectorTest.vala"
		_tmp213_ = cp;
#line 579 "CssSelectorTest.vala"
		_tmp214_ = c6g;
#line 579 "CssSelectorTest.vala"
		_tmp212_ = gxml_css_selector_parser_match (_tmp213_, _tmp214_, &_inner_error0_);
#line 579 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 579 "CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 579 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 579 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 579 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 579 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 579 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 579 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 579 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 579 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 579 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 579 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 579 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 579 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 579 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 579 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 579 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 579 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 579 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 579 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13035 "CssSelectorTest.c"
			goto __catch14_g_error;
		}
#line 579 "CssSelectorTest.vala"
		_vala_assert (_tmp212_, "cp.match (c6g)");
#line 513 "CssSelectorTest.vala"
		_g_object_unref0 (c6g);
#line 513 "CssSelectorTest.vala"
		_g_object_unref0 (c5g);
#line 513 "CssSelectorTest.vala"
		_g_object_unref0 (c4g);
#line 513 "CssSelectorTest.vala"
		_g_object_unref0 (c3g);
#line 513 "CssSelectorTest.vala"
		_g_object_unref0 (c2g);
#line 513 "CssSelectorTest.vala"
		_g_object_unref0 (c1g);
#line 513 "CssSelectorTest.vala"
		_g_object_unref0 (r2);
#line 513 "CssSelectorTest.vala"
		_g_object_unref0 (d2);
#line 513 "CssSelectorTest.vala"
		_g_object_unref0 (c6);
#line 513 "CssSelectorTest.vala"
		_g_object_unref0 (c5);
#line 513 "CssSelectorTest.vala"
		_g_object_unref0 (c4);
#line 513 "CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 513 "CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 513 "CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 513 "CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 513 "CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 513 "CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 513 "CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 513 "CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 13078 "CssSelectorTest.c"
	}
	goto __finally14;
	__catch14_g_error:
	{
		GError* e = NULL;
		GError* _tmp215_;
		const gchar* _tmp216_;
		gchar* _tmp217_;
		gchar* _tmp218_;
#line 513 "CssSelectorTest.vala"
		e = _inner_error0_;
#line 513 "CssSelectorTest.vala"
		_inner_error0_ = NULL;
#line 581 "CssSelectorTest.vala"
		_tmp215_ = e;
#line 581 "CssSelectorTest.vala"
		_tmp216_ = _tmp215_->message;
#line 581 "CssSelectorTest.vala"
		_tmp217_ = g_strconcat ("ERROR: ", _tmp216_, NULL);
#line 581 "CssSelectorTest.vala"
		_tmp218_ = _tmp217_;
#line 581 "CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:581: %s", _tmp218_);
#line 581 "CssSelectorTest.vala"
		_g_free0 (_tmp218_);
#line 513 "CssSelectorTest.vala"
		_g_error_free0 (e);
#line 13106 "CssSelectorTest.c"
	}
	__finally14:
#line 513 "CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 513 "CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 513 "CssSelectorTest.vala"
		g_clear_error (&_inner_error0_);
#line 513 "CssSelectorTest.vala"
		return;
#line 13117 "CssSelectorTest.c"
	}
}

static void
___lambda159__gtest_func (void)
{
#line 512 "CssSelectorTest.vala"
	__lambda159_ ();
#line 13126 "CssSelectorTest.c"
}

static void
__lambda160_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelector* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelector* _tmp11_;
		GXmlCssSelector* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlCssSelector* _tmp15_;
		GXmlCssCombiner _tmp16_;
		GXmlCssCombiner _tmp17_;
		GXmlCssSelector* sa = NULL;
		GXmlCssSelectorParser* _tmp18_;
		GeeList* _tmp19_;
		GeeList* _tmp20_;
		gpointer _tmp21_;
		GXmlCssSelector* _tmp22_;
		GXmlCssSelector* _tmp23_;
		GXmlCssSelectorType _tmp24_;
		GXmlCssSelectorType _tmp25_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp26_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp27_;
		GXmlDomElement* _tmp28_;
		GXmlGomDocument* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomNode* _tmp31_;
		GXmlDomNode* _tmp32_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp33_;
		GXmlDomElement* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomNode* _tmp37_;
		GXmlDomNode* _tmp38_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomElement* _tmp42_;
		GXmlDomElement* _tmp43_;
		GXmlDomNode* _tmp44_;
		GXmlDomNode* _tmp45_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlDomNode* _tmp51_;
		GXmlDomNode* _tmp52_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomElement* _tmp56_;
		GXmlDomElement* _tmp57_;
		GXmlDomNode* _tmp58_;
		GXmlDomNode* _tmp59_;
		GXmlDomElement* c5 = NULL;
		GXmlGomDocument* _tmp60_;
		GXmlDomElement* _tmp61_;
		GXmlDomElement* _tmp62_;
		GXmlDomElement* _tmp63_;
		GXmlDomNode* _tmp64_;
		GXmlDomNode* _tmp65_;
		GXmlDomElement* c6 = NULL;
		GXmlGomDocument* _tmp66_;
		GXmlDomElement* _tmp67_;
		GXmlDomElement* _tmp68_;
		GXmlDomElement* _tmp69_;
		GXmlDomNode* _tmp70_;
		GXmlDomNode* _tmp71_;
		GXmlDomElement* c7 = NULL;
		GXmlGomDocument* _tmp72_;
		GXmlDomElement* _tmp73_;
		GXmlDomElement* _tmp74_;
		GXmlDomElement* _tmp75_;
		GXmlDomNode* _tmp76_;
		GXmlDomNode* _tmp77_;
		gboolean _tmp78_ = FALSE;
		GXmlCssSelectorParser* _tmp79_;
		GXmlDomElement* _tmp80_;
		gboolean _tmp81_ = FALSE;
		GXmlCssSelectorParser* _tmp82_;
		GXmlDomElement* _tmp83_;
		gboolean _tmp84_ = FALSE;
		GXmlCssSelectorParser* _tmp85_;
		GXmlDomElement* _tmp86_;
		gboolean _tmp87_ = FALSE;
		GXmlCssSelectorParser* _tmp88_;
		GXmlDomElement* _tmp89_;
		gboolean _tmp90_ = FALSE;
		GXmlCssSelectorParser* _tmp91_;
		GXmlDomElement* _tmp92_;
		gboolean _tmp93_ = FALSE;
		GXmlCssSelectorParser* _tmp94_;
		GXmlDomElement* _tmp95_;
		gboolean _tmp96_ = FALSE;
		GXmlCssSelectorParser* _tmp97_;
		GXmlDomElement* _tmp98_;
		gboolean _tmp99_ = FALSE;
		GXmlCssSelectorParser* _tmp100_;
		GXmlDomElement* _tmp101_;
		GXmlDomDocument* d2 = NULL;
		GXmlGDocument* _tmp102_;
		GXmlDomDocument* _tmp103_;
		GXmlDomElement* r2 = NULL;
		GXmlDomDocument* _tmp104_;
		GXmlDomElement* _tmp105_;
		GXmlDomDocument* _tmp106_;
		GXmlDomElement* _tmp107_;
		GXmlDomNode* _tmp108_;
		GXmlDomNode* _tmp109_;
		GXmlDomElement* c1g = NULL;
		GXmlDomDocument* _tmp110_;
		GXmlDomElement* _tmp111_;
		GXmlDomElement* _tmp112_;
		GXmlDomElement* _tmp113_;
		GXmlDomNode* _tmp114_;
		GXmlDomNode* _tmp115_;
		GXmlDomElement* c2g = NULL;
		GXmlDomDocument* _tmp116_;
		GXmlDomElement* _tmp117_;
		GXmlDomElement* _tmp118_;
		GXmlDomElement* _tmp119_;
		GXmlDomElement* _tmp120_;
		GXmlDomNode* _tmp121_;
		GXmlDomNode* _tmp122_;
		GXmlDomElement* c3g = NULL;
		GXmlDomDocument* _tmp123_;
		GXmlDomElement* _tmp124_;
		GXmlDomElement* _tmp125_;
		GXmlDomElement* _tmp126_;
		GXmlDomElement* _tmp127_;
		GXmlDomNode* _tmp128_;
		GXmlDomNode* _tmp129_;
		GXmlDomElement* c4g = NULL;
		GXmlDomDocument* _tmp130_;
		GXmlDomElement* _tmp131_;
		GXmlDomElement* _tmp132_;
		GXmlDomElement* _tmp133_;
		GXmlDomElement* _tmp134_;
		GXmlDomNode* _tmp135_;
		GXmlDomNode* _tmp136_;
		GXmlDomElement* c5g = NULL;
		GXmlDomDocument* _tmp137_;
		GXmlDomElement* _tmp138_;
		GXmlDomElement* _tmp139_;
		GXmlDomElement* _tmp140_;
		GXmlDomNode* _tmp141_;
		GXmlDomNode* _tmp142_;
		GXmlDomElement* c6g = NULL;
		GXmlDomDocument* _tmp143_;
		GXmlDomElement* _tmp144_;
		GXmlDomElement* _tmp145_;
		GXmlDomElement* _tmp146_;
		GXmlDomNode* _tmp147_;
		GXmlDomNode* _tmp148_;
		GXmlDomElement* c7g = NULL;
		GXmlDomDocument* _tmp149_;
		GXmlDomElement* _tmp150_;
		GXmlDomElement* _tmp151_;
		GXmlDomElement* _tmp152_;
		GXmlDomNode* _tmp153_;
		GXmlDomNode* _tmp154_;
		gboolean _tmp155_ = FALSE;
		GXmlCssSelectorParser* _tmp156_;
		GXmlDomElement* _tmp157_;
		gboolean _tmp158_ = FALSE;
		GXmlCssSelectorParser* _tmp159_;
		GXmlDomElement* _tmp160_;
		gboolean _tmp161_ = FALSE;
		GXmlCssSelectorParser* _tmp162_;
		GXmlDomElement* _tmp163_;
		gboolean _tmp164_ = FALSE;
		GXmlCssSelectorParser* _tmp165_;
		GXmlDomElement* _tmp166_;
		gboolean _tmp167_ = FALSE;
		GXmlCssSelectorParser* _tmp168_;
		GXmlDomElement* _tmp169_;
		gboolean _tmp170_ = FALSE;
		GXmlCssSelectorParser* _tmp171_;
		GXmlDomElement* _tmp172_;
		gboolean _tmp173_ = FALSE;
		GXmlCssSelectorParser* _tmp174_;
		GXmlDomElement* _tmp175_;
		gboolean _tmp176_ = FALSE;
		GXmlCssSelectorParser* _tmp177_;
		GXmlDomElement* _tmp178_;
#line 586 "CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 586 "CssSelectorTest.vala"
		cp = _tmp0_;
#line 587 "CssSelectorTest.vala"
		_tmp1_ = cp;
#line 587 "CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "second:last-child", &_inner_error0_);
#line 587 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 587 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13346 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 588 "CssSelectorTest.vala"
		_tmp2_ = cp;
#line 588 "CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 588 "CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 588 "CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 588 "CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 588 "CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 2, "cp.selectors.size == 2");
#line 589 "CssSelectorTest.vala"
		_tmp7_ = cp;
#line 589 "CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 589 "CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 589 "CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 589 "CssSelectorTest.vala"
		s = (GXmlCssSelector*) _tmp10_;
#line 590 "CssSelectorTest.vala"
		_tmp11_ = s;
#line 590 "CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 591 "CssSelectorTest.vala"
		_tmp12_ = s;
#line 591 "CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_get_selector_type (_tmp12_);
#line 591 "CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 591 "CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 592 "CssSelectorTest.vala"
		_tmp15_ = s;
#line 592 "CssSelectorTest.vala"
		_tmp16_ = gxml_css_selector_get_combiner (_tmp15_);
#line 592 "CssSelectorTest.vala"
		_tmp17_ = _tmp16_;
#line 592 "CssSelectorTest.vala"
		_vala_assert (_tmp17_ == GXML_CSS_COMBINER_NONE, "s.combiner == CssCombiner.NONE");
#line 593 "CssSelectorTest.vala"
		_tmp18_ = cp;
#line 593 "CssSelectorTest.vala"
		_tmp19_ = gxml_css_selector_parser_get_selectors (_tmp18_);
#line 593 "CssSelectorTest.vala"
		_tmp20_ = _tmp19_;
#line 593 "CssSelectorTest.vala"
		_tmp21_ = gee_list_get (_tmp20_, 1);
#line 593 "CssSelectorTest.vala"
		sa = (GXmlCssSelector*) _tmp21_;
#line 594 "CssSelectorTest.vala"
		_tmp22_ = sa;
#line 594 "CssSelectorTest.vala"
		_vala_assert (_tmp22_ != NULL, "sa != null");
#line 595 "CssSelectorTest.vala"
		_tmp23_ = sa;
#line 595 "CssSelectorTest.vala"
		_tmp24_ = gxml_css_selector_get_selector_type (_tmp23_);
#line 595 "CssSelectorTest.vala"
		_tmp25_ = _tmp24_;
#line 595 "CssSelectorTest.vala"
		_vala_assert (_tmp25_ == GXML_CSS_SELECTOR_TYPE_PSEUDO_CLASS, "sa.selector_type == CssSelectorType.PSEUDO_CLASS");
#line 596 "CssSelectorTest.vala"
		_tmp26_ = gxml_gom_document_new ();
#line 596 "CssSelectorTest.vala"
		d = _tmp26_;
#line 597 "CssSelectorTest.vala"
		_tmp27_ = d;
#line 597 "CssSelectorTest.vala"
		_tmp28_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp27_, "toplevel", &_inner_error0_);
#line 597 "CssSelectorTest.vala"
		r = _tmp28_;
#line 597 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 597 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 597 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 597 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 597 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13433 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 598 "CssSelectorTest.vala"
		_tmp29_ = d;
#line 598 "CssSelectorTest.vala"
		_tmp30_ = r;
#line 598 "CssSelectorTest.vala"
		_tmp31_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp29_, (GXmlDomNode*) _tmp30_, &_inner_error0_);
#line 598 "CssSelectorTest.vala"
		_tmp32_ = _tmp31_;
#line 598 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp32_);
#line 598 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 598 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 598 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 598 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 598 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 598 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13458 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 599 "CssSelectorTest.vala"
		_tmp33_ = d;
#line 599 "CssSelectorTest.vala"
		_tmp34_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp33_, "child", &_inner_error0_);
#line 599 "CssSelectorTest.vala"
		c1 = _tmp34_;
#line 599 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 599 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 599 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 599 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 599 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 599 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13479 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 600 "CssSelectorTest.vala"
		_tmp35_ = r;
#line 600 "CssSelectorTest.vala"
		_tmp36_ = c1;
#line 600 "CssSelectorTest.vala"
		_tmp37_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp35_, (GXmlDomNode*) _tmp36_, &_inner_error0_);
#line 600 "CssSelectorTest.vala"
		_tmp38_ = _tmp37_;
#line 600 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp38_);
#line 600 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 600 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 600 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 600 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 600 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 600 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 600 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13506 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 601 "CssSelectorTest.vala"
		_tmp39_ = d;
#line 601 "CssSelectorTest.vala"
		_tmp40_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp39_, "child", &_inner_error0_);
#line 601 "CssSelectorTest.vala"
		c2 = _tmp40_;
#line 601 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 601 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 601 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 601 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 601 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 601 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 601 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13529 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 602 "CssSelectorTest.vala"
		_tmp41_ = c2;
#line 602 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp41_, "prop-name", "subval", &_inner_error0_);
#line 602 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 602 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 602 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 602 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 602 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 602 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 602 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 602 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13552 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 603 "CssSelectorTest.vala"
		_tmp42_ = r;
#line 603 "CssSelectorTest.vala"
		_tmp43_ = c2;
#line 603 "CssSelectorTest.vala"
		_tmp44_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp42_, (GXmlDomNode*) _tmp43_, &_inner_error0_);
#line 603 "CssSelectorTest.vala"
		_tmp45_ = _tmp44_;
#line 603 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp45_);
#line 603 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 603 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 603 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 603 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 603 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 603 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 603 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 603 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13581 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 604 "CssSelectorTest.vala"
		_tmp46_ = d;
#line 604 "CssSelectorTest.vala"
		_tmp47_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp46_, "child", &_inner_error0_);
#line 604 "CssSelectorTest.vala"
		c3 = _tmp47_;
#line 604 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 604 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 604 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 604 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 604 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 604 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 604 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 604 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13606 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 605 "CssSelectorTest.vala"
		_tmp48_ = c3;
#line 605 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp48_, "prop-name", "techval", &_inner_error0_);
#line 605 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 605 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 605 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 605 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 605 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 605 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 605 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 605 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 605 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13631 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 606 "CssSelectorTest.vala"
		_tmp49_ = r;
#line 606 "CssSelectorTest.vala"
		_tmp50_ = c3;
#line 606 "CssSelectorTest.vala"
		_tmp51_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp49_, (GXmlDomNode*) _tmp50_, &_inner_error0_);
#line 606 "CssSelectorTest.vala"
		_tmp52_ = _tmp51_;
#line 606 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp52_);
#line 606 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 606 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 606 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 606 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 606 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 606 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 606 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 606 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 606 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13662 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 607 "CssSelectorTest.vala"
		_tmp53_ = d;
#line 607 "CssSelectorTest.vala"
		_tmp54_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp53_, "child", &_inner_error0_);
#line 607 "CssSelectorTest.vala"
		c4 = _tmp54_;
#line 607 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 607 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 607 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 607 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 607 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 607 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 607 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 607 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 607 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13689 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 608 "CssSelectorTest.vala"
		_tmp55_ = c4;
#line 608 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp55_, "prop-name", "secondaryvalue", &_inner_error0_);
#line 608 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 608 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 608 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 608 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 608 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 608 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 608 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 608 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 608 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 608 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13716 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 609 "CssSelectorTest.vala"
		_tmp56_ = r;
#line 609 "CssSelectorTest.vala"
		_tmp57_ = c4;
#line 609 "CssSelectorTest.vala"
		_tmp58_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp56_, (GXmlDomNode*) _tmp57_, &_inner_error0_);
#line 609 "CssSelectorTest.vala"
		_tmp59_ = _tmp58_;
#line 609 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp59_);
#line 609 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 609 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 609 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 609 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 609 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 609 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 609 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 609 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 609 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 609 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13749 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 610 "CssSelectorTest.vala"
		_tmp60_ = d;
#line 610 "CssSelectorTest.vala"
		_tmp61_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp60_, "second", &_inner_error0_);
#line 610 "CssSelectorTest.vala"
		c5 = _tmp61_;
#line 610 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 610 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 610 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 610 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 610 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 610 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 610 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 610 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 610 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 610 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13778 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 611 "CssSelectorTest.vala"
		_tmp62_ = c3;
#line 611 "CssSelectorTest.vala"
		_tmp63_ = c5;
#line 611 "CssSelectorTest.vala"
		_tmp64_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp62_, (GXmlDomNode*) _tmp63_, &_inner_error0_);
#line 611 "CssSelectorTest.vala"
		_tmp65_ = _tmp64_;
#line 611 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp65_);
#line 611 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 611 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 611 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 611 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 611 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 611 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 611 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 611 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 611 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 611 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 611 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13813 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 612 "CssSelectorTest.vala"
		_tmp66_ = d;
#line 612 "CssSelectorTest.vala"
		_tmp67_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp66_, "second", &_inner_error0_);
#line 612 "CssSelectorTest.vala"
		c6 = _tmp67_;
#line 612 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 612 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 612 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 612 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 612 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 612 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 612 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 612 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 612 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 612 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 612 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13844 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 613 "CssSelectorTest.vala"
		_tmp68_ = c4;
#line 613 "CssSelectorTest.vala"
		_tmp69_ = c6;
#line 613 "CssSelectorTest.vala"
		_tmp70_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp68_, (GXmlDomNode*) _tmp69_, &_inner_error0_);
#line 613 "CssSelectorTest.vala"
		_tmp71_ = _tmp70_;
#line 613 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp71_);
#line 613 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 613 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 613 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 613 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 613 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 613 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 613 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 613 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 613 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 613 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 613 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 613 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13881 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 614 "CssSelectorTest.vala"
		_tmp72_ = d;
#line 614 "CssSelectorTest.vala"
		_tmp73_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp72_, "second", &_inner_error0_);
#line 614 "CssSelectorTest.vala"
		c7 = _tmp73_;
#line 614 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 614 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 614 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 614 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 614 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 614 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 614 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 614 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 614 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 614 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 614 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 614 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13914 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 615 "CssSelectorTest.vala"
		_tmp74_ = c4;
#line 615 "CssSelectorTest.vala"
		_tmp75_ = c7;
#line 615 "CssSelectorTest.vala"
		_tmp76_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp74_, (GXmlDomNode*) _tmp75_, &_inner_error0_);
#line 615 "CssSelectorTest.vala"
		_tmp77_ = _tmp76_;
#line 615 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp77_);
#line 615 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 615 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 615 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 615 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 615 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 615 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 615 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 615 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 615 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 615 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 615 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 615 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 615 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13953 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 616 "CssSelectorTest.vala"
		_tmp79_ = cp;
#line 616 "CssSelectorTest.vala"
		_tmp80_ = r;
#line 616 "CssSelectorTest.vala"
		_tmp78_ = gxml_css_selector_parser_match (_tmp79_, _tmp80_, &_inner_error0_);
#line 616 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 616 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 616 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 616 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 616 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 616 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 616 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 616 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 616 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 616 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 616 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 616 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 616 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 13988 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 616 "CssSelectorTest.vala"
		_vala_assert (!_tmp78_, "!cp.match (r)");
#line 617 "CssSelectorTest.vala"
		_tmp82_ = cp;
#line 617 "CssSelectorTest.vala"
		_tmp83_ = c1;
#line 617 "CssSelectorTest.vala"
		_tmp81_ = gxml_css_selector_parser_match (_tmp82_, _tmp83_, &_inner_error0_);
#line 617 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 617 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 617 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 617 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 617 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 617 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 617 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 617 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 617 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 617 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 617 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 617 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 617 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14025 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 617 "CssSelectorTest.vala"
		_vala_assert (!_tmp81_, "!cp.match (c1)");
#line 618 "CssSelectorTest.vala"
		_tmp85_ = cp;
#line 618 "CssSelectorTest.vala"
		_tmp86_ = c2;
#line 618 "CssSelectorTest.vala"
		_tmp84_ = gxml_css_selector_parser_match (_tmp85_, _tmp86_, &_inner_error0_);
#line 618 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 618 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 618 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 618 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 618 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 618 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 618 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 618 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 618 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 618 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 618 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 618 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 618 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14062 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 618 "CssSelectorTest.vala"
		_vala_assert (!_tmp84_, "!cp.match (c2)");
#line 619 "CssSelectorTest.vala"
		_tmp88_ = cp;
#line 619 "CssSelectorTest.vala"
		_tmp89_ = c3;
#line 619 "CssSelectorTest.vala"
		_tmp87_ = gxml_css_selector_parser_match (_tmp88_, _tmp89_, &_inner_error0_);
#line 619 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 619 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 619 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 619 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 619 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 619 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 619 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 619 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 619 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 619 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 619 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 619 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 619 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14099 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 619 "CssSelectorTest.vala"
		_vala_assert (!_tmp87_, "!cp.match (c3)");
#line 620 "CssSelectorTest.vala"
		_tmp91_ = cp;
#line 620 "CssSelectorTest.vala"
		_tmp92_ = c4;
#line 620 "CssSelectorTest.vala"
		_tmp90_ = gxml_css_selector_parser_match (_tmp91_, _tmp92_, &_inner_error0_);
#line 620 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 620 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 620 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 620 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 620 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 620 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 620 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 620 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 620 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 620 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 620 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 620 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 620 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14136 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 620 "CssSelectorTest.vala"
		_vala_assert (!_tmp90_, "!cp.match (c4)");
#line 621 "CssSelectorTest.vala"
		_tmp94_ = cp;
#line 621 "CssSelectorTest.vala"
		_tmp95_ = c5;
#line 621 "CssSelectorTest.vala"
		_tmp93_ = gxml_css_selector_parser_match (_tmp94_, _tmp95_, &_inner_error0_);
#line 621 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 621 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 621 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 621 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 621 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 621 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 621 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 621 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 621 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 621 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 621 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 621 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 621 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14173 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 621 "CssSelectorTest.vala"
		_vala_assert (_tmp93_, "cp.match (c5)");
#line 622 "CssSelectorTest.vala"
		_tmp97_ = cp;
#line 622 "CssSelectorTest.vala"
		_tmp98_ = c6;
#line 622 "CssSelectorTest.vala"
		_tmp96_ = gxml_css_selector_parser_match (_tmp97_, _tmp98_, &_inner_error0_);
#line 622 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 622 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 622 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 622 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 622 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 622 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 622 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 622 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 622 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 622 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 622 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 622 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 622 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14210 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 622 "CssSelectorTest.vala"
		_vala_assert (!_tmp96_, "!cp.match (c6)");
#line 623 "CssSelectorTest.vala"
		_tmp100_ = cp;
#line 623 "CssSelectorTest.vala"
		_tmp101_ = c7;
#line 623 "CssSelectorTest.vala"
		_tmp99_ = gxml_css_selector_parser_match (_tmp100_, _tmp101_, &_inner_error0_);
#line 623 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 623 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 623 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 623 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 623 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 623 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 623 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 623 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 623 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 623 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 623 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 623 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 623 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14247 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 623 "CssSelectorTest.vala"
		_vala_assert (_tmp99_, "cp.match (c7)");
#line 624 "CssSelectorTest.vala"
		_tmp102_ = gxml_gdocument_new ();
#line 624 "CssSelectorTest.vala"
		_tmp103_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp102_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp102_) : NULL;
#line 624 "CssSelectorTest.vala"
		if (_tmp103_ == NULL) {
#line 624 "CssSelectorTest.vala"
			_g_object_unref0 (_tmp102_);
#line 14260 "CssSelectorTest.c"
		}
#line 624 "CssSelectorTest.vala"
		d2 = _tmp103_;
#line 625 "CssSelectorTest.vala"
		_tmp104_ = d2;
#line 625 "CssSelectorTest.vala"
		_tmp105_ = gxml_dom_document_create_element (_tmp104_, "toplevel", &_inner_error0_);
#line 625 "CssSelectorTest.vala"
		r2 = _tmp105_;
#line 625 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 625 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 625 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 625 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 625 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 625 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 625 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 625 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 625 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 625 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 625 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 625 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 625 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 625 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14298 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 626 "CssSelectorTest.vala"
		_tmp106_ = d2;
#line 626 "CssSelectorTest.vala"
		_tmp107_ = r2;
#line 626 "CssSelectorTest.vala"
		_tmp108_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp106_, (GXmlDomNode*) _tmp107_, &_inner_error0_);
#line 626 "CssSelectorTest.vala"
		_tmp109_ = _tmp108_;
#line 626 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp109_);
#line 626 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 626 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 626 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 626 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 626 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 626 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 626 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 626 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 626 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 626 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 626 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 626 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 626 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 626 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 626 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14341 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 627 "CssSelectorTest.vala"
		_tmp110_ = d2;
#line 627 "CssSelectorTest.vala"
		_tmp111_ = gxml_dom_document_create_element (_tmp110_, "child", &_inner_error0_);
#line 627 "CssSelectorTest.vala"
		c1g = _tmp111_;
#line 627 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 627 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 627 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 627 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 627 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 627 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 627 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 627 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 627 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 627 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 627 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 627 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 627 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 627 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 627 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14380 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 628 "CssSelectorTest.vala"
		_tmp112_ = r2;
#line 628 "CssSelectorTest.vala"
		_tmp113_ = c1g;
#line 628 "CssSelectorTest.vala"
		_tmp114_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp112_, (GXmlDomNode*) _tmp113_, &_inner_error0_);
#line 628 "CssSelectorTest.vala"
		_tmp115_ = _tmp114_;
#line 628 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp115_);
#line 628 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 628 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 628 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 628 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 628 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 628 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 628 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 628 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 628 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 628 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 628 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 628 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 628 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 628 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 628 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 628 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14425 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 629 "CssSelectorTest.vala"
		_tmp116_ = d2;
#line 629 "CssSelectorTest.vala"
		_tmp117_ = gxml_dom_document_create_element (_tmp116_, "child", &_inner_error0_);
#line 629 "CssSelectorTest.vala"
		c2g = _tmp117_;
#line 629 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 629 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 629 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 629 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 629 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 629 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 629 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 629 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 629 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 629 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 629 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 629 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 629 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 629 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 629 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 629 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14466 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 630 "CssSelectorTest.vala"
		_tmp118_ = c2g;
#line 630 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp118_, "prop-name", "subval", &_inner_error0_);
#line 630 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 630 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 630 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 630 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 630 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 630 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 630 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 630 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 630 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 630 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 630 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 630 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 630 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 630 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 630 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 630 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 630 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14507 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 631 "CssSelectorTest.vala"
		_tmp119_ = r2;
#line 631 "CssSelectorTest.vala"
		_tmp120_ = c2g;
#line 631 "CssSelectorTest.vala"
		_tmp121_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp119_, (GXmlDomNode*) _tmp120_, &_inner_error0_);
#line 631 "CssSelectorTest.vala"
		_tmp122_ = _tmp121_;
#line 631 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp122_);
#line 631 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 631 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 631 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 631 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 631 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 631 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 631 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 631 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 631 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 631 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 631 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 631 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 631 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 631 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 631 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 631 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 631 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14554 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 632 "CssSelectorTest.vala"
		_tmp123_ = d2;
#line 632 "CssSelectorTest.vala"
		_tmp124_ = gxml_dom_document_create_element (_tmp123_, "child", &_inner_error0_);
#line 632 "CssSelectorTest.vala"
		c3g = _tmp124_;
#line 632 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 632 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 632 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 632 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 632 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 632 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 632 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 632 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 632 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 632 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 632 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 632 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 632 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 632 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 632 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 632 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 632 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14597 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 633 "CssSelectorTest.vala"
		_tmp125_ = c3g;
#line 633 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp125_, "prop-name", "techval", &_inner_error0_);
#line 633 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 633 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 633 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 633 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 633 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 633 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 633 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 633 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 633 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 633 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 633 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 633 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 633 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 633 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 633 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 633 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 633 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 633 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14640 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 634 "CssSelectorTest.vala"
		_tmp126_ = r2;
#line 634 "CssSelectorTest.vala"
		_tmp127_ = c3g;
#line 634 "CssSelectorTest.vala"
		_tmp128_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp126_, (GXmlDomNode*) _tmp127_, &_inner_error0_);
#line 634 "CssSelectorTest.vala"
		_tmp129_ = _tmp128_;
#line 634 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp129_);
#line 634 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 634 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 634 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 634 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 634 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 634 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 634 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 634 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 634 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 634 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 634 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 634 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 634 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 634 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 634 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 634 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 634 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 634 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14689 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 635 "CssSelectorTest.vala"
		_tmp130_ = d2;
#line 635 "CssSelectorTest.vala"
		_tmp131_ = gxml_dom_document_create_element (_tmp130_, "child", &_inner_error0_);
#line 635 "CssSelectorTest.vala"
		c4g = _tmp131_;
#line 635 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 635 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 635 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 635 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 635 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 635 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 635 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 635 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 635 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 635 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 635 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 635 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 635 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 635 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 635 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 635 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 635 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 635 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14734 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 636 "CssSelectorTest.vala"
		_tmp132_ = c4g;
#line 636 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp132_, "prop-name", "secondaryvalue", &_inner_error0_);
#line 636 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 636 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 636 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 636 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 636 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 636 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 636 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 636 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 636 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 636 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 636 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 636 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 636 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 636 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 636 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 636 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 636 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 636 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 636 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14779 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 637 "CssSelectorTest.vala"
		_tmp133_ = r2;
#line 637 "CssSelectorTest.vala"
		_tmp134_ = c4g;
#line 637 "CssSelectorTest.vala"
		_tmp135_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp133_, (GXmlDomNode*) _tmp134_, &_inner_error0_);
#line 637 "CssSelectorTest.vala"
		_tmp136_ = _tmp135_;
#line 637 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp136_);
#line 637 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 637 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 637 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 637 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 637 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 637 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 637 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 637 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 637 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 637 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 637 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 637 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 637 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 637 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 637 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 637 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 637 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 637 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 637 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14830 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 638 "CssSelectorTest.vala"
		_tmp137_ = d2;
#line 638 "CssSelectorTest.vala"
		_tmp138_ = gxml_dom_document_create_element (_tmp137_, "second", &_inner_error0_);
#line 638 "CssSelectorTest.vala"
		c5g = _tmp138_;
#line 638 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 638 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 638 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 638 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 638 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 638 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 638 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 638 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 638 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 638 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 638 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 638 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 638 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 638 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 638 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 638 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 638 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 638 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 638 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14877 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 639 "CssSelectorTest.vala"
		_tmp139_ = c3g;
#line 639 "CssSelectorTest.vala"
		_tmp140_ = c5g;
#line 639 "CssSelectorTest.vala"
		_tmp141_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp139_, (GXmlDomNode*) _tmp140_, &_inner_error0_);
#line 639 "CssSelectorTest.vala"
		_tmp142_ = _tmp141_;
#line 639 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp142_);
#line 639 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 639 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 639 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 639 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 639 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 639 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 639 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 639 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 639 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 639 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 639 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 639 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 639 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 639 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 639 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 639 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 639 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 639 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 639 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 639 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14930 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 640 "CssSelectorTest.vala"
		_tmp143_ = d2;
#line 640 "CssSelectorTest.vala"
		_tmp144_ = gxml_dom_document_create_element (_tmp143_, "second", &_inner_error0_);
#line 640 "CssSelectorTest.vala"
		c6g = _tmp144_;
#line 640 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 640 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 640 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 640 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 640 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 640 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 640 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 640 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 640 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 640 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 640 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 640 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 640 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 640 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 640 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 640 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 640 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 640 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 640 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 640 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 14979 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 641 "CssSelectorTest.vala"
		_tmp145_ = c4g;
#line 641 "CssSelectorTest.vala"
		_tmp146_ = c6g;
#line 641 "CssSelectorTest.vala"
		_tmp147_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp145_, (GXmlDomNode*) _tmp146_, &_inner_error0_);
#line 641 "CssSelectorTest.vala"
		_tmp148_ = _tmp147_;
#line 641 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp148_);
#line 641 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 641 "CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 641 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 641 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 641 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 641 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 641 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 641 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 641 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 641 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 641 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 641 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 641 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 641 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 641 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 641 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 641 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 641 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 641 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 641 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 641 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15034 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 642 "CssSelectorTest.vala"
		_tmp149_ = d2;
#line 642 "CssSelectorTest.vala"
		_tmp150_ = gxml_dom_document_create_element (_tmp149_, "second", &_inner_error0_);
#line 642 "CssSelectorTest.vala"
		c7g = _tmp150_;
#line 642 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 642 "CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 642 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 642 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 642 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 642 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 642 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 642 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 642 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 642 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 642 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 642 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 642 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 642 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 642 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 642 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 642 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 642 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 642 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 642 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 642 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15085 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 643 "CssSelectorTest.vala"
		_tmp151_ = c4g;
#line 643 "CssSelectorTest.vala"
		_tmp152_ = c7g;
#line 643 "CssSelectorTest.vala"
		_tmp153_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp151_, (GXmlDomNode*) _tmp152_, &_inner_error0_);
#line 643 "CssSelectorTest.vala"
		_tmp154_ = _tmp153_;
#line 643 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp154_);
#line 643 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 643 "CssSelectorTest.vala"
			_g_object_unref0 (c7g);
#line 643 "CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 643 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 643 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 643 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 643 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 643 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 643 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 643 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 643 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 643 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 643 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 643 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 643 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 643 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 643 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 643 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 643 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 643 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 643 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 643 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15142 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 644 "CssSelectorTest.vala"
		_tmp156_ = cp;
#line 644 "CssSelectorTest.vala"
		_tmp157_ = r;
#line 644 "CssSelectorTest.vala"
		_tmp155_ = gxml_css_selector_parser_match (_tmp156_, _tmp157_, &_inner_error0_);
#line 644 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 644 "CssSelectorTest.vala"
			_g_object_unref0 (c7g);
#line 644 "CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 644 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 644 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 644 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 644 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 644 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 644 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 644 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 644 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 644 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 644 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 644 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 644 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 644 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 644 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 644 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 644 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 644 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 644 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 644 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15195 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 644 "CssSelectorTest.vala"
		_vala_assert (!_tmp155_, "!cp.match (r)");
#line 645 "CssSelectorTest.vala"
		_tmp159_ = cp;
#line 645 "CssSelectorTest.vala"
		_tmp160_ = c1g;
#line 645 "CssSelectorTest.vala"
		_tmp158_ = gxml_css_selector_parser_match (_tmp159_, _tmp160_, &_inner_error0_);
#line 645 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 645 "CssSelectorTest.vala"
			_g_object_unref0 (c7g);
#line 645 "CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 645 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 645 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 645 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 645 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 645 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 645 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 645 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 645 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 645 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 645 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 645 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 645 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 645 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 645 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 645 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 645 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 645 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 645 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 645 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15250 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 645 "CssSelectorTest.vala"
		_vala_assert (!_tmp158_, "!cp.match (c1g)");
#line 646 "CssSelectorTest.vala"
		_tmp162_ = cp;
#line 646 "CssSelectorTest.vala"
		_tmp163_ = c2g;
#line 646 "CssSelectorTest.vala"
		_tmp161_ = gxml_css_selector_parser_match (_tmp162_, _tmp163_, &_inner_error0_);
#line 646 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 646 "CssSelectorTest.vala"
			_g_object_unref0 (c7g);
#line 646 "CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 646 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 646 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 646 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 646 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 646 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 646 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 646 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 646 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 646 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 646 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 646 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 646 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 646 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 646 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 646 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 646 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 646 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 646 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 646 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15305 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 646 "CssSelectorTest.vala"
		_vala_assert (!_tmp161_, "!cp.match (c2g)");
#line 647 "CssSelectorTest.vala"
		_tmp165_ = cp;
#line 647 "CssSelectorTest.vala"
		_tmp166_ = c3g;
#line 647 "CssSelectorTest.vala"
		_tmp164_ = gxml_css_selector_parser_match (_tmp165_, _tmp166_, &_inner_error0_);
#line 647 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 647 "CssSelectorTest.vala"
			_g_object_unref0 (c7g);
#line 647 "CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 647 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 647 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 647 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 647 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 647 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 647 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 647 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 647 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 647 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 647 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 647 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 647 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 647 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 647 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 647 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 647 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 647 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 647 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 647 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15360 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 647 "CssSelectorTest.vala"
		_vala_assert (!_tmp164_, "!cp.match (c3g)");
#line 648 "CssSelectorTest.vala"
		_tmp168_ = cp;
#line 648 "CssSelectorTest.vala"
		_tmp169_ = c4g;
#line 648 "CssSelectorTest.vala"
		_tmp167_ = gxml_css_selector_parser_match (_tmp168_, _tmp169_, &_inner_error0_);
#line 648 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 648 "CssSelectorTest.vala"
			_g_object_unref0 (c7g);
#line 648 "CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 648 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 648 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 648 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 648 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 648 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 648 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 648 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 648 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 648 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 648 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 648 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 648 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 648 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 648 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 648 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 648 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 648 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 648 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 648 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15415 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 648 "CssSelectorTest.vala"
		_vala_assert (!_tmp167_, "!cp.match (c4g)");
#line 649 "CssSelectorTest.vala"
		_tmp171_ = cp;
#line 649 "CssSelectorTest.vala"
		_tmp172_ = c5g;
#line 649 "CssSelectorTest.vala"
		_tmp170_ = gxml_css_selector_parser_match (_tmp171_, _tmp172_, &_inner_error0_);
#line 649 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 649 "CssSelectorTest.vala"
			_g_object_unref0 (c7g);
#line 649 "CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 649 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 649 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 649 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 649 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 649 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 649 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 649 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 649 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 649 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 649 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 649 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 649 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 649 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 649 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 649 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 649 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 649 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 649 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 649 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15470 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 649 "CssSelectorTest.vala"
		_vala_assert (_tmp170_, "cp.match (c5g)");
#line 650 "CssSelectorTest.vala"
		_tmp174_ = cp;
#line 650 "CssSelectorTest.vala"
		_tmp175_ = c6g;
#line 650 "CssSelectorTest.vala"
		_tmp173_ = gxml_css_selector_parser_match (_tmp174_, _tmp175_, &_inner_error0_);
#line 650 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 650 "CssSelectorTest.vala"
			_g_object_unref0 (c7g);
#line 650 "CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 650 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 650 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 650 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 650 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 650 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 650 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 650 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 650 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 650 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 650 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 650 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 650 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 650 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 650 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 650 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 650 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 650 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 650 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 650 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15525 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 650 "CssSelectorTest.vala"
		_vala_assert (!_tmp173_, "!cp.match (c6g)");
#line 651 "CssSelectorTest.vala"
		_tmp177_ = cp;
#line 651 "CssSelectorTest.vala"
		_tmp178_ = c7g;
#line 651 "CssSelectorTest.vala"
		_tmp176_ = gxml_css_selector_parser_match (_tmp177_, _tmp178_, &_inner_error0_);
#line 651 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 651 "CssSelectorTest.vala"
			_g_object_unref0 (c7g);
#line 651 "CssSelectorTest.vala"
			_g_object_unref0 (c6g);
#line 651 "CssSelectorTest.vala"
			_g_object_unref0 (c5g);
#line 651 "CssSelectorTest.vala"
			_g_object_unref0 (c4g);
#line 651 "CssSelectorTest.vala"
			_g_object_unref0 (c3g);
#line 651 "CssSelectorTest.vala"
			_g_object_unref0 (c2g);
#line 651 "CssSelectorTest.vala"
			_g_object_unref0 (c1g);
#line 651 "CssSelectorTest.vala"
			_g_object_unref0 (r2);
#line 651 "CssSelectorTest.vala"
			_g_object_unref0 (d2);
#line 651 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 651 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 651 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 651 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 651 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 651 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 651 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 651 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 651 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 651 "CssSelectorTest.vala"
			_g_object_unref0 (sa);
#line 651 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 651 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15580 "CssSelectorTest.c"
			goto __catch15_g_error;
		}
#line 651 "CssSelectorTest.vala"
		_vala_assert (_tmp176_, "cp.match (c7g)");
#line 585 "CssSelectorTest.vala"
		_g_object_unref0 (c7g);
#line 585 "CssSelectorTest.vala"
		_g_object_unref0 (c6g);
#line 585 "CssSelectorTest.vala"
		_g_object_unref0 (c5g);
#line 585 "CssSelectorTest.vala"
		_g_object_unref0 (c4g);
#line 585 "CssSelectorTest.vala"
		_g_object_unref0 (c3g);
#line 585 "CssSelectorTest.vala"
		_g_object_unref0 (c2g);
#line 585 "CssSelectorTest.vala"
		_g_object_unref0 (c1g);
#line 585 "CssSelectorTest.vala"
		_g_object_unref0 (r2);
#line 585 "CssSelectorTest.vala"
		_g_object_unref0 (d2);
#line 585 "CssSelectorTest.vala"
		_g_object_unref0 (c7);
#line 585 "CssSelectorTest.vala"
		_g_object_unref0 (c6);
#line 585 "CssSelectorTest.vala"
		_g_object_unref0 (c5);
#line 585 "CssSelectorTest.vala"
		_g_object_unref0 (c4);
#line 585 "CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 585 "CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 585 "CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 585 "CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 585 "CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 585 "CssSelectorTest.vala"
		_g_object_unref0 (sa);
#line 585 "CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 585 "CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 15627 "CssSelectorTest.c"
	}
	goto __finally15;
	__catch15_g_error:
	{
		GError* e = NULL;
		GError* _tmp179_;
		const gchar* _tmp180_;
		gchar* _tmp181_;
		gchar* _tmp182_;
#line 585 "CssSelectorTest.vala"
		e = _inner_error0_;
#line 585 "CssSelectorTest.vala"
		_inner_error0_ = NULL;
#line 653 "CssSelectorTest.vala"
		_tmp179_ = e;
#line 653 "CssSelectorTest.vala"
		_tmp180_ = _tmp179_->message;
#line 653 "CssSelectorTest.vala"
		_tmp181_ = g_strconcat ("ERROR: ", _tmp180_, NULL);
#line 653 "CssSelectorTest.vala"
		_tmp182_ = _tmp181_;
#line 653 "CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:653: %s", _tmp182_);
#line 653 "CssSelectorTest.vala"
		_g_free0 (_tmp182_);
#line 585 "CssSelectorTest.vala"
		_g_error_free0 (e);
#line 15655 "CssSelectorTest.c"
	}
	__finally15:
#line 585 "CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 585 "CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 585 "CssSelectorTest.vala"
		g_clear_error (&_inner_error0_);
#line 585 "CssSelectorTest.vala"
		return;
#line 15666 "CssSelectorTest.c"
	}
}

static void
___lambda160__gtest_func (void)
{
#line 584 "CssSelectorTest.vala"
	__lambda160_ ();
#line 15675 "CssSelectorTest.c"
}

static void
__lambda161_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelector* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelector* _tmp11_;
		GXmlCssSelector* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp15_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlGomDocument* _tmp18_;
		GXmlDomElement* _tmp19_;
		GXmlDomNode* _tmp20_;
		GXmlDomNode* _tmp21_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp22_;
		GXmlDomElement* _tmp23_;
		GXmlDomElement* _tmp24_;
		GXmlDomElement* _tmp25_;
		GXmlDomNode* _tmp26_;
		GXmlDomNode* _tmp27_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp28_;
		GXmlDomElement* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomElement* _tmp31_;
		GXmlDomElement* _tmp32_;
		GXmlDomNode* _tmp33_;
		GXmlDomNode* _tmp34_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomElement* _tmp37_;
		GXmlDomElement* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomNode* _tmp40_;
		GXmlDomNode* _tmp41_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp42_;
		GXmlDomElement* _tmp43_;
		GXmlDomElement* _tmp44_;
		GXmlDomElement* _tmp45_;
		GXmlDomElement* _tmp46_;
		GXmlDomNode* _tmp47_;
		GXmlDomNode* _tmp48_;
		GXmlDomElement* c5 = NULL;
		GXmlGomDocument* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlDomElement* _tmp51_;
		GXmlDomElement* _tmp52_;
		GXmlDomNode* _tmp53_;
		GXmlDomNode* _tmp54_;
		GXmlDomElement* c6 = NULL;
		GXmlGomDocument* _tmp55_;
		GXmlDomElement* _tmp56_;
		GXmlDomElement* _tmp57_;
		GXmlDomElement* _tmp58_;
		GXmlDomNode* _tmp59_;
		GXmlDomNode* _tmp60_;
		GXmlDomElement* c7 = NULL;
		GXmlGomDocument* _tmp61_;
		GXmlDomElement* _tmp62_;
		gchar* _tmp63_ = NULL;
		GXmlGomDocument* _tmp64_;
		gchar* _tmp65_;
		gboolean _tmp66_ = FALSE;
		GXmlCssSelectorParser* _tmp67_;
		GXmlDomElement* _tmp68_;
		gboolean _tmp69_ = FALSE;
		GXmlCssSelectorParser* _tmp70_;
		GXmlDomElement* _tmp71_;
		gboolean _tmp72_ = FALSE;
		GXmlCssSelectorParser* _tmp73_;
		GXmlDomElement* _tmp74_;
		gboolean _tmp75_ = FALSE;
		GXmlCssSelectorParser* _tmp76_;
		GXmlDomElement* _tmp77_;
#line 658 "CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 658 "CssSelectorTest.vala"
		cp = _tmp0_;
#line 659 "CssSelectorTest.vala"
		_tmp1_ = cp;
#line 659 "CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "namespace|second", &_inner_error0_);
#line 659 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 659 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15784 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 660 "CssSelectorTest.vala"
		_tmp2_ = cp;
#line 660 "CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 660 "CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 660 "CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 660 "CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 660 "CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 1, "cp.selectors.size == 1");
#line 661 "CssSelectorTest.vala"
		_tmp7_ = cp;
#line 661 "CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 661 "CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 661 "CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 661 "CssSelectorTest.vala"
		s = (GXmlCssSelector*) _tmp10_;
#line 662 "CssSelectorTest.vala"
		_tmp11_ = s;
#line 662 "CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 663 "CssSelectorTest.vala"
		_tmp12_ = s;
#line 663 "CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_get_selector_type (_tmp12_);
#line 663 "CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 663 "CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 664 "CssSelectorTest.vala"
		_tmp15_ = gxml_gom_document_new ();
#line 664 "CssSelectorTest.vala"
		d = _tmp15_;
#line 665 "CssSelectorTest.vala"
		_tmp16_ = d;
#line 665 "CssSelectorTest.vala"
		_tmp17_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp16_, "toplevel", &_inner_error0_);
#line 665 "CssSelectorTest.vala"
		r = _tmp17_;
#line 665 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 665 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 665 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 665 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15839 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 666 "CssSelectorTest.vala"
		_tmp18_ = d;
#line 666 "CssSelectorTest.vala"
		_tmp19_ = r;
#line 666 "CssSelectorTest.vala"
		_tmp20_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp18_, (GXmlDomNode*) _tmp19_, &_inner_error0_);
#line 666 "CssSelectorTest.vala"
		_tmp21_ = _tmp20_;
#line 666 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp21_);
#line 666 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 666 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 666 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 666 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 666 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15862 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 667 "CssSelectorTest.vala"
		_tmp22_ = d;
#line 667 "CssSelectorTest.vala"
		_tmp23_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp22_, "child", &_inner_error0_);
#line 667 "CssSelectorTest.vala"
		c1 = _tmp23_;
#line 667 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 667 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 667 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 667 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 667 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15881 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 668 "CssSelectorTest.vala"
		_tmp24_ = r;
#line 668 "CssSelectorTest.vala"
		_tmp25_ = c1;
#line 668 "CssSelectorTest.vala"
		_tmp26_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp24_, (GXmlDomNode*) _tmp25_, &_inner_error0_);
#line 668 "CssSelectorTest.vala"
		_tmp27_ = _tmp26_;
#line 668 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp27_);
#line 668 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 668 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 668 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 668 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 668 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 668 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15906 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 669 "CssSelectorTest.vala"
		_tmp28_ = d;
#line 669 "CssSelectorTest.vala"
		_tmp29_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp28_, "child", &_inner_error0_);
#line 669 "CssSelectorTest.vala"
		c2 = _tmp29_;
#line 669 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 669 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 669 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 669 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 669 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 669 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15927 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 670 "CssSelectorTest.vala"
		_tmp30_ = c2;
#line 670 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp30_, "prop-name", "subval", &_inner_error0_);
#line 670 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 670 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 670 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 670 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 670 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 670 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 670 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15948 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 671 "CssSelectorTest.vala"
		_tmp31_ = r;
#line 671 "CssSelectorTest.vala"
		_tmp32_ = c2;
#line 671 "CssSelectorTest.vala"
		_tmp33_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp31_, (GXmlDomNode*) _tmp32_, &_inner_error0_);
#line 671 "CssSelectorTest.vala"
		_tmp34_ = _tmp33_;
#line 671 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp34_);
#line 671 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 671 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 671 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 671 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 671 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 671 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 671 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15975 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 672 "CssSelectorTest.vala"
		_tmp35_ = d;
#line 672 "CssSelectorTest.vala"
		_tmp36_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp35_, "child", &_inner_error0_);
#line 672 "CssSelectorTest.vala"
		c3 = _tmp36_;
#line 672 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 672 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 672 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 672 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 672 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 672 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 672 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 15998 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 673 "CssSelectorTest.vala"
		_tmp37_ = c3;
#line 673 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp37_, "prop-name", "techval", &_inner_error0_);
#line 673 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 673 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 673 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 673 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 673 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 673 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 673 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 673 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16021 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 674 "CssSelectorTest.vala"
		_tmp38_ = r;
#line 674 "CssSelectorTest.vala"
		_tmp39_ = c3;
#line 674 "CssSelectorTest.vala"
		_tmp40_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp38_, (GXmlDomNode*) _tmp39_, &_inner_error0_);
#line 674 "CssSelectorTest.vala"
		_tmp41_ = _tmp40_;
#line 674 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp41_);
#line 674 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 674 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 674 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 674 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 674 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 674 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 674 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 674 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16050 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 675 "CssSelectorTest.vala"
		_tmp42_ = d;
#line 675 "CssSelectorTest.vala"
		_tmp43_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp42_, "child", &_inner_error0_);
#line 675 "CssSelectorTest.vala"
		c4 = _tmp43_;
#line 675 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 675 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 675 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 675 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 675 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 675 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 675 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 675 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16075 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 676 "CssSelectorTest.vala"
		_tmp44_ = c4;
#line 676 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp44_, "prop-name", "secondaryvalue", &_inner_error0_);
#line 676 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 676 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 676 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 676 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 676 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 676 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 676 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 676 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 676 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16100 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 677 "CssSelectorTest.vala"
		_tmp45_ = r;
#line 677 "CssSelectorTest.vala"
		_tmp46_ = c4;
#line 677 "CssSelectorTest.vala"
		_tmp47_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp45_, (GXmlDomNode*) _tmp46_, &_inner_error0_);
#line 677 "CssSelectorTest.vala"
		_tmp48_ = _tmp47_;
#line 677 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp48_);
#line 677 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 677 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 677 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 677 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 677 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 677 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 677 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 677 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 677 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16131 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 678 "CssSelectorTest.vala"
		_tmp49_ = d;
#line 678 "CssSelectorTest.vala"
		_tmp50_ = gxml_dom_document_create_element_ns ((GXmlDomDocument*) _tmp49_, "http://gxml.org", "namespace:second", &_inner_error0_);
#line 678 "CssSelectorTest.vala"
		c5 = _tmp50_;
#line 678 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 678 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 678 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 678 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 678 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 678 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 678 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 678 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 678 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16158 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 679 "CssSelectorTest.vala"
		_tmp51_ = c3;
#line 679 "CssSelectorTest.vala"
		_tmp52_ = c5;
#line 679 "CssSelectorTest.vala"
		_tmp53_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp51_, (GXmlDomNode*) _tmp52_, &_inner_error0_);
#line 679 "CssSelectorTest.vala"
		_tmp54_ = _tmp53_;
#line 679 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp54_);
#line 679 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 679 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 679 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 679 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 679 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 679 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 679 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 679 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 679 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 679 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16191 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 680 "CssSelectorTest.vala"
		_tmp55_ = d;
#line 680 "CssSelectorTest.vala"
		_tmp56_ = gxml_dom_document_create_element_ns ((GXmlDomDocument*) _tmp55_, "http://gxml.org", "namespace:second", &_inner_error0_);
#line 680 "CssSelectorTest.vala"
		c6 = _tmp56_;
#line 680 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 680 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 680 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 680 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 680 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 680 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 680 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 680 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 680 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 680 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16220 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 681 "CssSelectorTest.vala"
		_tmp57_ = c4;
#line 681 "CssSelectorTest.vala"
		_tmp58_ = c6;
#line 681 "CssSelectorTest.vala"
		_tmp59_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp57_, (GXmlDomNode*) _tmp58_, &_inner_error0_);
#line 681 "CssSelectorTest.vala"
		_tmp60_ = _tmp59_;
#line 681 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp60_);
#line 681 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 681 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 681 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 681 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 681 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 681 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 681 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 681 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 681 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 681 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 681 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16255 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 682 "CssSelectorTest.vala"
		_tmp61_ = d;
#line 682 "CssSelectorTest.vala"
		_tmp62_ = gxml_dom_document_create_element_ns ((GXmlDomDocument*) _tmp61_, "http://gxml.org", "namespace:second", &_inner_error0_);
#line 682 "CssSelectorTest.vala"
		c7 = _tmp62_;
#line 682 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 682 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 682 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 682 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 682 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 682 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 682 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 682 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 682 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 682 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 682 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16286 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 683 "CssSelectorTest.vala"
		_tmp64_ = d;
#line 683 "CssSelectorTest.vala"
		_tmp65_ = gxml_dom_document_write_string ((GXmlDomDocument*) _tmp64_, NULL, &_inner_error0_);
#line 683 "CssSelectorTest.vala"
		_tmp63_ = _tmp65_;
#line 683 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 683 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 683 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 683 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 683 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 683 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 683 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 683 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 683 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 683 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 683 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 683 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16319 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 683 "CssSelectorTest.vala"
		g_message ("CssSelectorTest.vala:683: %s", _tmp63_);
#line 684 "CssSelectorTest.vala"
		_tmp67_ = cp;
#line 684 "CssSelectorTest.vala"
		_tmp68_ = r;
#line 684 "CssSelectorTest.vala"
		_tmp66_ = gxml_css_selector_parser_match (_tmp67_, _tmp68_, &_inner_error0_);
#line 684 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 684 "CssSelectorTest.vala"
			_g_free0 (_tmp63_);
#line 684 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 684 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 684 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 684 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 684 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 684 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 684 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 684 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 684 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 684 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 684 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16356 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 684 "CssSelectorTest.vala"
		_vala_assert (!_tmp66_, "!cp.match (r)");
#line 685 "CssSelectorTest.vala"
		_tmp70_ = cp;
#line 685 "CssSelectorTest.vala"
		_tmp71_ = c5;
#line 685 "CssSelectorTest.vala"
		_tmp69_ = gxml_css_selector_parser_match (_tmp70_, _tmp71_, &_inner_error0_);
#line 685 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 685 "CssSelectorTest.vala"
			_g_free0 (_tmp63_);
#line 685 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 685 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 685 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 685 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 685 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 685 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 685 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 685 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 685 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 685 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 685 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16393 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 685 "CssSelectorTest.vala"
		_vala_assert (_tmp69_, "cp.match (c5)");
#line 686 "CssSelectorTest.vala"
		_tmp73_ = cp;
#line 686 "CssSelectorTest.vala"
		_tmp74_ = c6;
#line 686 "CssSelectorTest.vala"
		_tmp72_ = gxml_css_selector_parser_match (_tmp73_, _tmp74_, &_inner_error0_);
#line 686 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 686 "CssSelectorTest.vala"
			_g_free0 (_tmp63_);
#line 686 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 686 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 686 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 686 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 686 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 686 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 686 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 686 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 686 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 686 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 686 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16430 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 686 "CssSelectorTest.vala"
		_vala_assert (_tmp72_, "cp.match (c6)");
#line 687 "CssSelectorTest.vala"
		_tmp76_ = cp;
#line 687 "CssSelectorTest.vala"
		_tmp77_ = c7;
#line 687 "CssSelectorTest.vala"
		_tmp75_ = gxml_css_selector_parser_match (_tmp76_, _tmp77_, &_inner_error0_);
#line 687 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 687 "CssSelectorTest.vala"
			_g_free0 (_tmp63_);
#line 687 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 687 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 687 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 687 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 687 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 687 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 687 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 687 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 687 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 687 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 687 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16467 "CssSelectorTest.c"
			goto __catch16_g_error;
		}
#line 687 "CssSelectorTest.vala"
		_vala_assert (_tmp75_, "cp.match (c7)");
#line 657 "CssSelectorTest.vala"
		_g_free0 (_tmp63_);
#line 657 "CssSelectorTest.vala"
		_g_object_unref0 (c7);
#line 657 "CssSelectorTest.vala"
		_g_object_unref0 (c6);
#line 657 "CssSelectorTest.vala"
		_g_object_unref0 (c5);
#line 657 "CssSelectorTest.vala"
		_g_object_unref0 (c4);
#line 657 "CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 657 "CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 657 "CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 657 "CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 657 "CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 657 "CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 657 "CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 16496 "CssSelectorTest.c"
	}
	goto __finally16;
	__catch16_g_error:
	{
		GError* e = NULL;
		GError* _tmp78_;
		const gchar* _tmp79_;
		gchar* _tmp80_;
		gchar* _tmp81_;
#line 657 "CssSelectorTest.vala"
		e = _inner_error0_;
#line 657 "CssSelectorTest.vala"
		_inner_error0_ = NULL;
#line 689 "CssSelectorTest.vala"
		_tmp78_ = e;
#line 689 "CssSelectorTest.vala"
		_tmp79_ = _tmp78_->message;
#line 689 "CssSelectorTest.vala"
		_tmp80_ = g_strconcat ("ERROR: ", _tmp79_, NULL);
#line 689 "CssSelectorTest.vala"
		_tmp81_ = _tmp80_;
#line 689 "CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:689: %s", _tmp81_);
#line 689 "CssSelectorTest.vala"
		_g_free0 (_tmp81_);
#line 657 "CssSelectorTest.vala"
		_g_error_free0 (e);
#line 16524 "CssSelectorTest.c"
	}
	__finally16:
#line 657 "CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 657 "CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 657 "CssSelectorTest.vala"
		g_clear_error (&_inner_error0_);
#line 657 "CssSelectorTest.vala"
		return;
#line 16535 "CssSelectorTest.c"
	}
}

static void
___lambda161__gtest_func (void)
{
#line 656 "CssSelectorTest.vala"
	__lambda161_ ();
#line 16544 "CssSelectorTest.c"
}

static void
__lambda162_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelector* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelector* _tmp11_;
		GXmlCssSelector* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp15_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlGomDocument* _tmp18_;
		GXmlDomElement* _tmp19_;
		GXmlDomNode* _tmp20_;
		GXmlDomNode* _tmp21_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp22_;
		GXmlDomElement* _tmp23_;
		GXmlDomElement* _tmp24_;
		GXmlDomElement* _tmp25_;
		GXmlDomNode* _tmp26_;
		GXmlDomNode* _tmp27_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp28_;
		GXmlDomElement* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomElement* _tmp31_;
		GXmlDomElement* _tmp32_;
		GXmlDomNode* _tmp33_;
		GXmlDomNode* _tmp34_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomElement* _tmp37_;
		GXmlDomElement* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomNode* _tmp40_;
		GXmlDomNode* _tmp41_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp42_;
		GXmlDomElement* _tmp43_;
		GXmlDomElement* _tmp44_;
		GXmlDomElement* _tmp45_;
		GXmlDomElement* _tmp46_;
		GXmlDomNode* _tmp47_;
		GXmlDomNode* _tmp48_;
		GXmlDomElement* c5 = NULL;
		GXmlGomDocument* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlDomElement* _tmp51_;
		GXmlDomElement* _tmp52_;
		GXmlDomNode* _tmp53_;
		GXmlDomNode* _tmp54_;
		GXmlDomElement* c6 = NULL;
		GXmlGomDocument* _tmp55_;
		GXmlDomElement* _tmp56_;
		GXmlDomElement* _tmp57_;
		GXmlDomElement* _tmp58_;
		GXmlDomNode* _tmp59_;
		GXmlDomNode* _tmp60_;
		GXmlDomElement* c7 = NULL;
		GXmlGomDocument* _tmp61_;
		GXmlDomElement* _tmp62_;
		GXmlDomElement* _tmp63_;
		GXmlDomElement* _tmp64_;
		GXmlDomNode* _tmp65_;
		GXmlDomNode* _tmp66_;
		GXmlDomElement* c8 = NULL;
		GXmlGomDocument* _tmp67_;
		GXmlDomElement* _tmp68_;
		GXmlDomElement* _tmp69_;
		GXmlDomElement* _tmp70_;
		GXmlDomNode* _tmp71_;
		GXmlDomNode* _tmp72_;
		gchar* _tmp73_ = NULL;
		GXmlGomDocument* _tmp74_;
		gchar* _tmp75_;
		gboolean _tmp76_ = FALSE;
		GXmlCssSelectorParser* _tmp77_;
		GXmlDomElement* _tmp78_;
		gboolean _tmp79_ = FALSE;
		GXmlCssSelectorParser* _tmp80_;
		GXmlDomElement* _tmp81_;
		gboolean _tmp82_ = FALSE;
		GXmlCssSelectorParser* _tmp83_;
		GXmlDomElement* _tmp84_;
		gboolean _tmp85_ = FALSE;
		GXmlCssSelectorParser* _tmp86_;
		GXmlDomElement* _tmp87_;
		gboolean _tmp88_ = FALSE;
		GXmlCssSelectorParser* _tmp89_;
		GXmlDomElement* _tmp90_;
#line 694 "CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 694 "CssSelectorTest.vala"
		cp = _tmp0_;
#line 695 "CssSelectorTest.vala"
		_tmp1_ = cp;
#line 695 "CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "*|second", &_inner_error0_);
#line 695 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 695 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16667 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 696 "CssSelectorTest.vala"
		_tmp2_ = cp;
#line 696 "CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 696 "CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 696 "CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 696 "CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 696 "CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 1, "cp.selectors.size == 1");
#line 697 "CssSelectorTest.vala"
		_tmp7_ = cp;
#line 697 "CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 697 "CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 697 "CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 697 "CssSelectorTest.vala"
		s = (GXmlCssSelector*) _tmp10_;
#line 698 "CssSelectorTest.vala"
		_tmp11_ = s;
#line 698 "CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 699 "CssSelectorTest.vala"
		_tmp12_ = s;
#line 699 "CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_get_selector_type (_tmp12_);
#line 699 "CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 699 "CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 700 "CssSelectorTest.vala"
		_tmp15_ = gxml_gom_document_new ();
#line 700 "CssSelectorTest.vala"
		d = _tmp15_;
#line 701 "CssSelectorTest.vala"
		_tmp16_ = d;
#line 701 "CssSelectorTest.vala"
		_tmp17_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp16_, "toplevel", &_inner_error0_);
#line 701 "CssSelectorTest.vala"
		r = _tmp17_;
#line 701 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 701 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 701 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 701 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16722 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 702 "CssSelectorTest.vala"
		_tmp18_ = d;
#line 702 "CssSelectorTest.vala"
		_tmp19_ = r;
#line 702 "CssSelectorTest.vala"
		_tmp20_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp18_, (GXmlDomNode*) _tmp19_, &_inner_error0_);
#line 702 "CssSelectorTest.vala"
		_tmp21_ = _tmp20_;
#line 702 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp21_);
#line 702 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 702 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 702 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 702 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 702 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16745 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 703 "CssSelectorTest.vala"
		_tmp22_ = d;
#line 703 "CssSelectorTest.vala"
		_tmp23_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp22_, "child", &_inner_error0_);
#line 703 "CssSelectorTest.vala"
		c1 = _tmp23_;
#line 703 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 703 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 703 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 703 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 703 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16764 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 704 "CssSelectorTest.vala"
		_tmp24_ = r;
#line 704 "CssSelectorTest.vala"
		_tmp25_ = c1;
#line 704 "CssSelectorTest.vala"
		_tmp26_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp24_, (GXmlDomNode*) _tmp25_, &_inner_error0_);
#line 704 "CssSelectorTest.vala"
		_tmp27_ = _tmp26_;
#line 704 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp27_);
#line 704 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 704 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 704 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 704 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 704 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 704 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16789 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 705 "CssSelectorTest.vala"
		_tmp28_ = d;
#line 705 "CssSelectorTest.vala"
		_tmp29_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp28_, "child", &_inner_error0_);
#line 705 "CssSelectorTest.vala"
		c2 = _tmp29_;
#line 705 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 705 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 705 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 705 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 705 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 705 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16810 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 706 "CssSelectorTest.vala"
		_tmp30_ = c2;
#line 706 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp30_, "prop-name", "subval", &_inner_error0_);
#line 706 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 706 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 706 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 706 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 706 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 706 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 706 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16831 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 707 "CssSelectorTest.vala"
		_tmp31_ = r;
#line 707 "CssSelectorTest.vala"
		_tmp32_ = c2;
#line 707 "CssSelectorTest.vala"
		_tmp33_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp31_, (GXmlDomNode*) _tmp32_, &_inner_error0_);
#line 707 "CssSelectorTest.vala"
		_tmp34_ = _tmp33_;
#line 707 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp34_);
#line 707 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 707 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 707 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 707 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 707 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 707 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 707 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16858 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 708 "CssSelectorTest.vala"
		_tmp35_ = d;
#line 708 "CssSelectorTest.vala"
		_tmp36_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp35_, "child", &_inner_error0_);
#line 708 "CssSelectorTest.vala"
		c3 = _tmp36_;
#line 708 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 708 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 708 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 708 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 708 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 708 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 708 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16881 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 709 "CssSelectorTest.vala"
		_tmp37_ = c3;
#line 709 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp37_, "prop-name", "techval", &_inner_error0_);
#line 709 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 709 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 709 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 709 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 709 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 709 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 709 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 709 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16904 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 710 "CssSelectorTest.vala"
		_tmp38_ = r;
#line 710 "CssSelectorTest.vala"
		_tmp39_ = c3;
#line 710 "CssSelectorTest.vala"
		_tmp40_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp38_, (GXmlDomNode*) _tmp39_, &_inner_error0_);
#line 710 "CssSelectorTest.vala"
		_tmp41_ = _tmp40_;
#line 710 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp41_);
#line 710 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 710 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 710 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 710 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 710 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 710 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 710 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 710 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16933 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 711 "CssSelectorTest.vala"
		_tmp42_ = d;
#line 711 "CssSelectorTest.vala"
		_tmp43_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp42_, "child", &_inner_error0_);
#line 711 "CssSelectorTest.vala"
		c4 = _tmp43_;
#line 711 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 711 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 711 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 711 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 711 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 711 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 711 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 711 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16958 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 712 "CssSelectorTest.vala"
		_tmp44_ = c4;
#line 712 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp44_, "prop-name", "secondaryvalue", &_inner_error0_);
#line 712 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 712 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 712 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 712 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 712 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 712 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 712 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 712 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 712 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 16983 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 713 "CssSelectorTest.vala"
		_tmp45_ = r;
#line 713 "CssSelectorTest.vala"
		_tmp46_ = c4;
#line 713 "CssSelectorTest.vala"
		_tmp47_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp45_, (GXmlDomNode*) _tmp46_, &_inner_error0_);
#line 713 "CssSelectorTest.vala"
		_tmp48_ = _tmp47_;
#line 713 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp48_);
#line 713 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 713 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 713 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 713 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 713 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 713 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 713 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 713 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 713 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17014 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 714 "CssSelectorTest.vala"
		_tmp49_ = d;
#line 714 "CssSelectorTest.vala"
		_tmp50_ = gxml_dom_document_create_element_ns ((GXmlDomDocument*) _tmp49_, "http://gxml.org", "namespace:second", &_inner_error0_);
#line 714 "CssSelectorTest.vala"
		c5 = _tmp50_;
#line 714 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 714 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 714 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 714 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 714 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 714 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 714 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 714 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 714 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17041 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 715 "CssSelectorTest.vala"
		_tmp51_ = c3;
#line 715 "CssSelectorTest.vala"
		_tmp52_ = c5;
#line 715 "CssSelectorTest.vala"
		_tmp53_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp51_, (GXmlDomNode*) _tmp52_, &_inner_error0_);
#line 715 "CssSelectorTest.vala"
		_tmp54_ = _tmp53_;
#line 715 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp54_);
#line 715 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 715 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 715 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 715 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 715 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 715 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 715 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 715 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 715 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 715 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17074 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 716 "CssSelectorTest.vala"
		_tmp55_ = d;
#line 716 "CssSelectorTest.vala"
		_tmp56_ = gxml_dom_document_create_element_ns ((GXmlDomDocument*) _tmp55_, "http://gxml.org", "namespace:second", &_inner_error0_);
#line 716 "CssSelectorTest.vala"
		c6 = _tmp56_;
#line 716 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 716 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 716 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 716 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 716 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 716 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 716 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 716 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 716 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 716 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17103 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 717 "CssSelectorTest.vala"
		_tmp57_ = c4;
#line 717 "CssSelectorTest.vala"
		_tmp58_ = c6;
#line 717 "CssSelectorTest.vala"
		_tmp59_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp57_, (GXmlDomNode*) _tmp58_, &_inner_error0_);
#line 717 "CssSelectorTest.vala"
		_tmp60_ = _tmp59_;
#line 717 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp60_);
#line 717 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 717 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 717 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 717 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 717 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 717 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 717 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 717 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 717 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 717 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 717 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17138 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 718 "CssSelectorTest.vala"
		_tmp61_ = d;
#line 718 "CssSelectorTest.vala"
		_tmp62_ = gxml_dom_document_create_element_ns ((GXmlDomDocument*) _tmp61_, "http://gxml.org", "namespace:second", &_inner_error0_);
#line 718 "CssSelectorTest.vala"
		c7 = _tmp62_;
#line 718 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 718 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 718 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 718 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 718 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 718 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 718 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 718 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 718 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 718 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 718 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17169 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 719 "CssSelectorTest.vala"
		_tmp63_ = c4;
#line 719 "CssSelectorTest.vala"
		_tmp64_ = c7;
#line 719 "CssSelectorTest.vala"
		_tmp65_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp63_, (GXmlDomNode*) _tmp64_, &_inner_error0_);
#line 719 "CssSelectorTest.vala"
		_tmp66_ = _tmp65_;
#line 719 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp66_);
#line 719 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 719 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 719 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 719 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 719 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 719 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 719 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 719 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 719 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 719 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 719 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 719 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17206 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 720 "CssSelectorTest.vala"
		_tmp67_ = d;
#line 720 "CssSelectorTest.vala"
		_tmp68_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp67_, "second", &_inner_error0_);
#line 720 "CssSelectorTest.vala"
		c8 = _tmp68_;
#line 720 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 720 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 720 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 720 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 720 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 720 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 720 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 720 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 720 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 720 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 720 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 720 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17239 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 721 "CssSelectorTest.vala"
		_tmp69_ = c4;
#line 721 "CssSelectorTest.vala"
		_tmp70_ = c8;
#line 721 "CssSelectorTest.vala"
		_tmp71_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp69_, (GXmlDomNode*) _tmp70_, &_inner_error0_);
#line 721 "CssSelectorTest.vala"
		_tmp72_ = _tmp71_;
#line 721 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp72_);
#line 721 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 721 "CssSelectorTest.vala"
			_g_object_unref0 (c8);
#line 721 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 721 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 721 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 721 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 721 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 721 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 721 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 721 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 721 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 721 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 721 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17278 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 722 "CssSelectorTest.vala"
		_tmp74_ = d;
#line 722 "CssSelectorTest.vala"
		_tmp75_ = gxml_dom_document_write_string ((GXmlDomDocument*) _tmp74_, NULL, &_inner_error0_);
#line 722 "CssSelectorTest.vala"
		_tmp73_ = _tmp75_;
#line 722 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 722 "CssSelectorTest.vala"
			_g_object_unref0 (c8);
#line 722 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 722 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 722 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 722 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 722 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 722 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 722 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 722 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 722 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 722 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 722 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17313 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 722 "CssSelectorTest.vala"
		g_message ("CssSelectorTest.vala:722: %s", _tmp73_);
#line 723 "CssSelectorTest.vala"
		_tmp77_ = cp;
#line 723 "CssSelectorTest.vala"
		_tmp78_ = r;
#line 723 "CssSelectorTest.vala"
		_tmp76_ = gxml_css_selector_parser_match (_tmp77_, _tmp78_, &_inner_error0_);
#line 723 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 723 "CssSelectorTest.vala"
			_g_free0 (_tmp73_);
#line 723 "CssSelectorTest.vala"
			_g_object_unref0 (c8);
#line 723 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 723 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 723 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 723 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 723 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 723 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 723 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 723 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 723 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 723 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 723 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17352 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 723 "CssSelectorTest.vala"
		_vala_assert (!_tmp76_, "!cp.match (r)");
#line 724 "CssSelectorTest.vala"
		_tmp80_ = cp;
#line 724 "CssSelectorTest.vala"
		_tmp81_ = c5;
#line 724 "CssSelectorTest.vala"
		_tmp79_ = gxml_css_selector_parser_match (_tmp80_, _tmp81_, &_inner_error0_);
#line 724 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 724 "CssSelectorTest.vala"
			_g_free0 (_tmp73_);
#line 724 "CssSelectorTest.vala"
			_g_object_unref0 (c8);
#line 724 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 724 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 724 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 724 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 724 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 724 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 724 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 724 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 724 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 724 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 724 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17391 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 724 "CssSelectorTest.vala"
		_vala_assert (_tmp79_, "cp.match (c5)");
#line 725 "CssSelectorTest.vala"
		_tmp83_ = cp;
#line 725 "CssSelectorTest.vala"
		_tmp84_ = c6;
#line 725 "CssSelectorTest.vala"
		_tmp82_ = gxml_css_selector_parser_match (_tmp83_, _tmp84_, &_inner_error0_);
#line 725 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 725 "CssSelectorTest.vala"
			_g_free0 (_tmp73_);
#line 725 "CssSelectorTest.vala"
			_g_object_unref0 (c8);
#line 725 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 725 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 725 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 725 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 725 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 725 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 725 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 725 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 725 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 725 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 725 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17430 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 725 "CssSelectorTest.vala"
		_vala_assert (_tmp82_, "cp.match (c6)");
#line 726 "CssSelectorTest.vala"
		_tmp86_ = cp;
#line 726 "CssSelectorTest.vala"
		_tmp87_ = c7;
#line 726 "CssSelectorTest.vala"
		_tmp85_ = gxml_css_selector_parser_match (_tmp86_, _tmp87_, &_inner_error0_);
#line 726 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 726 "CssSelectorTest.vala"
			_g_free0 (_tmp73_);
#line 726 "CssSelectorTest.vala"
			_g_object_unref0 (c8);
#line 726 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 726 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 726 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 726 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 726 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 726 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 726 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 726 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 726 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 726 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 726 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17469 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 726 "CssSelectorTest.vala"
		_vala_assert (_tmp85_, "cp.match (c7)");
#line 727 "CssSelectorTest.vala"
		_tmp89_ = cp;
#line 727 "CssSelectorTest.vala"
		_tmp90_ = c8;
#line 727 "CssSelectorTest.vala"
		_tmp88_ = gxml_css_selector_parser_match (_tmp89_, _tmp90_, &_inner_error0_);
#line 727 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 727 "CssSelectorTest.vala"
			_g_free0 (_tmp73_);
#line 727 "CssSelectorTest.vala"
			_g_object_unref0 (c8);
#line 727 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 727 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 727 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 727 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 727 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 727 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 727 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 727 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 727 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 727 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 727 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17508 "CssSelectorTest.c"
			goto __catch17_g_error;
		}
#line 727 "CssSelectorTest.vala"
		_vala_assert (_tmp88_, "cp.match (c8)");
#line 693 "CssSelectorTest.vala"
		_g_free0 (_tmp73_);
#line 693 "CssSelectorTest.vala"
		_g_object_unref0 (c8);
#line 693 "CssSelectorTest.vala"
		_g_object_unref0 (c7);
#line 693 "CssSelectorTest.vala"
		_g_object_unref0 (c6);
#line 693 "CssSelectorTest.vala"
		_g_object_unref0 (c5);
#line 693 "CssSelectorTest.vala"
		_g_object_unref0 (c4);
#line 693 "CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 693 "CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 693 "CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 693 "CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 693 "CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 693 "CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 693 "CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 17539 "CssSelectorTest.c"
	}
	goto __finally17;
	__catch17_g_error:
	{
		GError* e = NULL;
		GError* _tmp91_;
		const gchar* _tmp92_;
		gchar* _tmp93_;
		gchar* _tmp94_;
#line 693 "CssSelectorTest.vala"
		e = _inner_error0_;
#line 693 "CssSelectorTest.vala"
		_inner_error0_ = NULL;
#line 729 "CssSelectorTest.vala"
		_tmp91_ = e;
#line 729 "CssSelectorTest.vala"
		_tmp92_ = _tmp91_->message;
#line 729 "CssSelectorTest.vala"
		_tmp93_ = g_strconcat ("ERROR: ", _tmp92_, NULL);
#line 729 "CssSelectorTest.vala"
		_tmp94_ = _tmp93_;
#line 729 "CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:729: %s", _tmp94_);
#line 729 "CssSelectorTest.vala"
		_g_free0 (_tmp94_);
#line 693 "CssSelectorTest.vala"
		_g_error_free0 (e);
#line 17567 "CssSelectorTest.c"
	}
	__finally17:
#line 693 "CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 693 "CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 693 "CssSelectorTest.vala"
		g_clear_error (&_inner_error0_);
#line 693 "CssSelectorTest.vala"
		return;
#line 17578 "CssSelectorTest.c"
	}
}

static void
___lambda162__gtest_func (void)
{
#line 692 "CssSelectorTest.vala"
	__lambda162_ ();
#line 17587 "CssSelectorTest.c"
}

static void
__lambda163_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlCssSelectorParser* cp = NULL;
		GXmlCssSelectorParser* _tmp0_;
		GXmlCssSelectorParser* _tmp1_;
		GXmlCssSelectorParser* _tmp2_;
		GeeList* _tmp3_;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GXmlCssSelector* s = NULL;
		GXmlCssSelectorParser* _tmp7_;
		GeeList* _tmp8_;
		GeeList* _tmp9_;
		gpointer _tmp10_;
		GXmlCssSelector* _tmp11_;
		GXmlCssSelector* _tmp12_;
		GXmlCssSelectorType _tmp13_;
		GXmlCssSelectorType _tmp14_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp15_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlGomDocument* _tmp18_;
		GXmlDomElement* _tmp19_;
		GXmlDomNode* _tmp20_;
		GXmlDomNode* _tmp21_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp22_;
		GXmlDomElement* _tmp23_;
		GXmlDomElement* _tmp24_;
		GXmlDomElement* _tmp25_;
		GXmlDomNode* _tmp26_;
		GXmlDomNode* _tmp27_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp28_;
		GXmlDomElement* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomElement* _tmp31_;
		GXmlDomElement* _tmp32_;
		GXmlDomNode* _tmp33_;
		GXmlDomNode* _tmp34_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomElement* _tmp37_;
		GXmlDomElement* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomNode* _tmp40_;
		GXmlDomNode* _tmp41_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp42_;
		GXmlDomElement* _tmp43_;
		GXmlDomElement* _tmp44_;
		GXmlDomElement* _tmp45_;
		GXmlDomElement* _tmp46_;
		GXmlDomNode* _tmp47_;
		GXmlDomNode* _tmp48_;
		GXmlDomElement* c5 = NULL;
		GXmlGomDocument* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlDomElement* _tmp51_;
		GXmlDomElement* _tmp52_;
		GXmlDomNode* _tmp53_;
		GXmlDomNode* _tmp54_;
		GXmlDomElement* c6 = NULL;
		GXmlGomDocument* _tmp55_;
		GXmlDomElement* _tmp56_;
		GXmlDomElement* _tmp57_;
		GXmlDomElement* _tmp58_;
		GXmlDomNode* _tmp59_;
		GXmlDomNode* _tmp60_;
		GXmlDomElement* c7 = NULL;
		GXmlGomDocument* _tmp61_;
		GXmlDomElement* _tmp62_;
		GXmlDomElement* _tmp63_;
		GXmlDomElement* _tmp64_;
		GXmlDomNode* _tmp65_;
		GXmlDomNode* _tmp66_;
		GXmlDomElement* c8 = NULL;
		GXmlGomDocument* _tmp67_;
		GXmlDomElement* _tmp68_;
		GXmlDomElement* _tmp69_;
		GXmlDomElement* _tmp70_;
		GXmlDomNode* _tmp71_;
		GXmlDomNode* _tmp72_;
		gchar* _tmp73_ = NULL;
		GXmlGomDocument* _tmp74_;
		gchar* _tmp75_;
		gboolean _tmp76_ = FALSE;
		GXmlCssSelectorParser* _tmp77_;
		GXmlDomElement* _tmp78_;
		gboolean _tmp79_ = FALSE;
		GXmlCssSelectorParser* _tmp80_;
		GXmlDomElement* _tmp81_;
		gboolean _tmp82_ = FALSE;
		GXmlCssSelectorParser* _tmp83_;
		GXmlDomElement* _tmp84_;
		gboolean _tmp85_ = FALSE;
		GXmlCssSelectorParser* _tmp86_;
		GXmlDomElement* _tmp87_;
		gboolean _tmp88_ = FALSE;
		GXmlCssSelectorParser* _tmp89_;
		GXmlDomElement* _tmp90_;
#line 734 "CssSelectorTest.vala"
		_tmp0_ = gxml_css_selector_parser_new ();
#line 734 "CssSelectorTest.vala"
		cp = _tmp0_;
#line 735 "CssSelectorTest.vala"
		_tmp1_ = cp;
#line 735 "CssSelectorTest.vala"
		gxml_css_selector_parser_parse (_tmp1_, "|second", &_inner_error0_);
#line 735 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 735 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17710 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 736 "CssSelectorTest.vala"
		_tmp2_ = cp;
#line 736 "CssSelectorTest.vala"
		_tmp3_ = gxml_css_selector_parser_get_selectors (_tmp2_);
#line 736 "CssSelectorTest.vala"
		_tmp4_ = _tmp3_;
#line 736 "CssSelectorTest.vala"
		_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
#line 736 "CssSelectorTest.vala"
		_tmp6_ = _tmp5_;
#line 736 "CssSelectorTest.vala"
		_vala_assert (_tmp6_ == 1, "cp.selectors.size == 1");
#line 737 "CssSelectorTest.vala"
		_tmp7_ = cp;
#line 737 "CssSelectorTest.vala"
		_tmp8_ = gxml_css_selector_parser_get_selectors (_tmp7_);
#line 737 "CssSelectorTest.vala"
		_tmp9_ = _tmp8_;
#line 737 "CssSelectorTest.vala"
		_tmp10_ = gee_list_get (_tmp9_, 0);
#line 737 "CssSelectorTest.vala"
		s = (GXmlCssSelector*) _tmp10_;
#line 738 "CssSelectorTest.vala"
		_tmp11_ = s;
#line 738 "CssSelectorTest.vala"
		_vala_assert (_tmp11_ != NULL, "s != null");
#line 739 "CssSelectorTest.vala"
		_tmp12_ = s;
#line 739 "CssSelectorTest.vala"
		_tmp13_ = gxml_css_selector_get_selector_type (_tmp12_);
#line 739 "CssSelectorTest.vala"
		_tmp14_ = _tmp13_;
#line 739 "CssSelectorTest.vala"
		_vala_assert (_tmp14_ == GXML_CSS_SELECTOR_TYPE_ELEMENT, "s.selector_type == CssSelectorType.ELEMENT");
#line 740 "CssSelectorTest.vala"
		_tmp15_ = gxml_gom_document_new ();
#line 740 "CssSelectorTest.vala"
		d = _tmp15_;
#line 741 "CssSelectorTest.vala"
		_tmp16_ = d;
#line 741 "CssSelectorTest.vala"
		_tmp17_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp16_, "toplevel", &_inner_error0_);
#line 741 "CssSelectorTest.vala"
		r = _tmp17_;
#line 741 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 741 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 741 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 741 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17765 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 742 "CssSelectorTest.vala"
		_tmp18_ = d;
#line 742 "CssSelectorTest.vala"
		_tmp19_ = r;
#line 742 "CssSelectorTest.vala"
		_tmp20_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp18_, (GXmlDomNode*) _tmp19_, &_inner_error0_);
#line 742 "CssSelectorTest.vala"
		_tmp21_ = _tmp20_;
#line 742 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp21_);
#line 742 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 742 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 742 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 742 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 742 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17788 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 743 "CssSelectorTest.vala"
		_tmp22_ = d;
#line 743 "CssSelectorTest.vala"
		_tmp23_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp22_, "child", &_inner_error0_);
#line 743 "CssSelectorTest.vala"
		c1 = _tmp23_;
#line 743 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 743 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 743 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 743 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 743 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17807 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 744 "CssSelectorTest.vala"
		_tmp24_ = r;
#line 744 "CssSelectorTest.vala"
		_tmp25_ = c1;
#line 744 "CssSelectorTest.vala"
		_tmp26_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp24_, (GXmlDomNode*) _tmp25_, &_inner_error0_);
#line 744 "CssSelectorTest.vala"
		_tmp27_ = _tmp26_;
#line 744 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp27_);
#line 744 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 744 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 744 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 744 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 744 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 744 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17832 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 745 "CssSelectorTest.vala"
		_tmp28_ = d;
#line 745 "CssSelectorTest.vala"
		_tmp29_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp28_, "child", &_inner_error0_);
#line 745 "CssSelectorTest.vala"
		c2 = _tmp29_;
#line 745 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 745 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 745 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 745 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 745 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 745 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17853 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 746 "CssSelectorTest.vala"
		_tmp30_ = c2;
#line 746 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp30_, "prop-name", "subval", &_inner_error0_);
#line 746 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 746 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 746 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 746 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 746 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 746 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 746 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17874 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 747 "CssSelectorTest.vala"
		_tmp31_ = r;
#line 747 "CssSelectorTest.vala"
		_tmp32_ = c2;
#line 747 "CssSelectorTest.vala"
		_tmp33_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp31_, (GXmlDomNode*) _tmp32_, &_inner_error0_);
#line 747 "CssSelectorTest.vala"
		_tmp34_ = _tmp33_;
#line 747 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp34_);
#line 747 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 747 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 747 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 747 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 747 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 747 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 747 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17901 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 748 "CssSelectorTest.vala"
		_tmp35_ = d;
#line 748 "CssSelectorTest.vala"
		_tmp36_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp35_, "child", &_inner_error0_);
#line 748 "CssSelectorTest.vala"
		c3 = _tmp36_;
#line 748 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 748 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 748 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 748 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 748 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 748 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 748 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17924 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 749 "CssSelectorTest.vala"
		_tmp37_ = c3;
#line 749 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp37_, "prop-name", "techval", &_inner_error0_);
#line 749 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 749 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 749 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 749 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 749 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 749 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 749 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 749 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17947 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 750 "CssSelectorTest.vala"
		_tmp38_ = r;
#line 750 "CssSelectorTest.vala"
		_tmp39_ = c3;
#line 750 "CssSelectorTest.vala"
		_tmp40_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp38_, (GXmlDomNode*) _tmp39_, &_inner_error0_);
#line 750 "CssSelectorTest.vala"
		_tmp41_ = _tmp40_;
#line 750 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp41_);
#line 750 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 750 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 750 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 750 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 750 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 750 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 750 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 750 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 17976 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 751 "CssSelectorTest.vala"
		_tmp42_ = d;
#line 751 "CssSelectorTest.vala"
		_tmp43_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp42_, "child", &_inner_error0_);
#line 751 "CssSelectorTest.vala"
		c4 = _tmp43_;
#line 751 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 751 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 751 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 751 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 751 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 751 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 751 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 751 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 18001 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 752 "CssSelectorTest.vala"
		_tmp44_ = c4;
#line 752 "CssSelectorTest.vala"
		gxml_dom_element_set_attribute (_tmp44_, "prop-name", "secondaryvalue", &_inner_error0_);
#line 752 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 752 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 752 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 752 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 752 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 752 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 752 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 752 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 752 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 18026 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 753 "CssSelectorTest.vala"
		_tmp45_ = r;
#line 753 "CssSelectorTest.vala"
		_tmp46_ = c4;
#line 753 "CssSelectorTest.vala"
		_tmp47_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp45_, (GXmlDomNode*) _tmp46_, &_inner_error0_);
#line 753 "CssSelectorTest.vala"
		_tmp48_ = _tmp47_;
#line 753 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp48_);
#line 753 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 753 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 753 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 753 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 753 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 753 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 753 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 753 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 753 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 18057 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 754 "CssSelectorTest.vala"
		_tmp49_ = d;
#line 754 "CssSelectorTest.vala"
		_tmp50_ = gxml_dom_document_create_element_ns ((GXmlDomDocument*) _tmp49_, "http://gxml.org", "namespace:second", &_inner_error0_);
#line 754 "CssSelectorTest.vala"
		c5 = _tmp50_;
#line 754 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 754 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 754 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 754 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 754 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 754 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 754 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 754 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 754 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 18084 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 755 "CssSelectorTest.vala"
		_tmp51_ = c3;
#line 755 "CssSelectorTest.vala"
		_tmp52_ = c5;
#line 755 "CssSelectorTest.vala"
		_tmp53_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp51_, (GXmlDomNode*) _tmp52_, &_inner_error0_);
#line 755 "CssSelectorTest.vala"
		_tmp54_ = _tmp53_;
#line 755 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp54_);
#line 755 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 755 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 755 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 755 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 755 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 755 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 755 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 755 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 755 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 755 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 18117 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 756 "CssSelectorTest.vala"
		_tmp55_ = d;
#line 756 "CssSelectorTest.vala"
		_tmp56_ = gxml_dom_document_create_element_ns ((GXmlDomDocument*) _tmp55_, "http://gxml.org", "namespace:second", &_inner_error0_);
#line 756 "CssSelectorTest.vala"
		c6 = _tmp56_;
#line 756 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 756 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 756 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 756 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 756 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 756 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 756 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 756 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 756 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 756 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 18146 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 757 "CssSelectorTest.vala"
		_tmp57_ = c4;
#line 757 "CssSelectorTest.vala"
		_tmp58_ = c6;
#line 757 "CssSelectorTest.vala"
		_tmp59_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp57_, (GXmlDomNode*) _tmp58_, &_inner_error0_);
#line 757 "CssSelectorTest.vala"
		_tmp60_ = _tmp59_;
#line 757 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp60_);
#line 757 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 757 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 757 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 757 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 757 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 757 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 757 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 757 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 757 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 757 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 757 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 18181 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 758 "CssSelectorTest.vala"
		_tmp61_ = d;
#line 758 "CssSelectorTest.vala"
		_tmp62_ = gxml_dom_document_create_element_ns ((GXmlDomDocument*) _tmp61_, "http://gxml.org", "namespace:second", &_inner_error0_);
#line 758 "CssSelectorTest.vala"
		c7 = _tmp62_;
#line 758 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 758 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 758 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 758 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 758 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 758 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 758 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 758 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 758 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 758 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 758 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 18212 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 759 "CssSelectorTest.vala"
		_tmp63_ = c4;
#line 759 "CssSelectorTest.vala"
		_tmp64_ = c7;
#line 759 "CssSelectorTest.vala"
		_tmp65_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp63_, (GXmlDomNode*) _tmp64_, &_inner_error0_);
#line 759 "CssSelectorTest.vala"
		_tmp66_ = _tmp65_;
#line 759 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp66_);
#line 759 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 759 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 759 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 759 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 759 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 759 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 759 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 759 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 759 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 759 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 759 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 759 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 18249 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 760 "CssSelectorTest.vala"
		_tmp67_ = d;
#line 760 "CssSelectorTest.vala"
		_tmp68_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp67_, "second", &_inner_error0_);
#line 760 "CssSelectorTest.vala"
		c8 = _tmp68_;
#line 760 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 760 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 760 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 760 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 760 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 760 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 760 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 760 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 760 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 760 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 760 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 760 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 18282 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 761 "CssSelectorTest.vala"
		_tmp69_ = c4;
#line 761 "CssSelectorTest.vala"
		_tmp70_ = c8;
#line 761 "CssSelectorTest.vala"
		_tmp71_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp69_, (GXmlDomNode*) _tmp70_, &_inner_error0_);
#line 761 "CssSelectorTest.vala"
		_tmp72_ = _tmp71_;
#line 761 "CssSelectorTest.vala"
		_g_object_unref0 (_tmp72_);
#line 761 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 761 "CssSelectorTest.vala"
			_g_object_unref0 (c8);
#line 761 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 761 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 761 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 761 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 761 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 761 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 761 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 761 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 761 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 761 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 761 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 18321 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 762 "CssSelectorTest.vala"
		_tmp74_ = d;
#line 762 "CssSelectorTest.vala"
		_tmp75_ = gxml_dom_document_write_string ((GXmlDomDocument*) _tmp74_, NULL, &_inner_error0_);
#line 762 "CssSelectorTest.vala"
		_tmp73_ = _tmp75_;
#line 762 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 762 "CssSelectorTest.vala"
			_g_object_unref0 (c8);
#line 762 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 762 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 762 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 762 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 762 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 762 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 762 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 762 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 762 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 762 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 762 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 18356 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 762 "CssSelectorTest.vala"
		g_message ("CssSelectorTest.vala:762: %s", _tmp73_);
#line 763 "CssSelectorTest.vala"
		_tmp77_ = cp;
#line 763 "CssSelectorTest.vala"
		_tmp78_ = r;
#line 763 "CssSelectorTest.vala"
		_tmp76_ = gxml_css_selector_parser_match (_tmp77_, _tmp78_, &_inner_error0_);
#line 763 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 763 "CssSelectorTest.vala"
			_g_free0 (_tmp73_);
#line 763 "CssSelectorTest.vala"
			_g_object_unref0 (c8);
#line 763 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 763 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 763 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 763 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 763 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 763 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 763 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 763 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 763 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 763 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 763 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 18395 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 763 "CssSelectorTest.vala"
		_vala_assert (!_tmp76_, "!cp.match (r)");
#line 764 "CssSelectorTest.vala"
		_tmp80_ = cp;
#line 764 "CssSelectorTest.vala"
		_tmp81_ = c5;
#line 764 "CssSelectorTest.vala"
		_tmp79_ = gxml_css_selector_parser_match (_tmp80_, _tmp81_, &_inner_error0_);
#line 764 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 764 "CssSelectorTest.vala"
			_g_free0 (_tmp73_);
#line 764 "CssSelectorTest.vala"
			_g_object_unref0 (c8);
#line 764 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 764 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 764 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 764 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 764 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 764 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 764 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 764 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 764 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 764 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 764 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 18434 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 764 "CssSelectorTest.vala"
		_vala_assert (!_tmp79_, "!cp.match (c5)");
#line 765 "CssSelectorTest.vala"
		_tmp83_ = cp;
#line 765 "CssSelectorTest.vala"
		_tmp84_ = c6;
#line 765 "CssSelectorTest.vala"
		_tmp82_ = gxml_css_selector_parser_match (_tmp83_, _tmp84_, &_inner_error0_);
#line 765 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 765 "CssSelectorTest.vala"
			_g_free0 (_tmp73_);
#line 765 "CssSelectorTest.vala"
			_g_object_unref0 (c8);
#line 765 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 765 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 765 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 765 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 765 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 765 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 765 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 765 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 765 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 765 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 765 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 18473 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 765 "CssSelectorTest.vala"
		_vala_assert (!_tmp82_, "!cp.match (c6)");
#line 766 "CssSelectorTest.vala"
		_tmp86_ = cp;
#line 766 "CssSelectorTest.vala"
		_tmp87_ = c7;
#line 766 "CssSelectorTest.vala"
		_tmp85_ = gxml_css_selector_parser_match (_tmp86_, _tmp87_, &_inner_error0_);
#line 766 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 766 "CssSelectorTest.vala"
			_g_free0 (_tmp73_);
#line 766 "CssSelectorTest.vala"
			_g_object_unref0 (c8);
#line 766 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 766 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 766 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 766 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 766 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 766 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 766 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 766 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 766 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 766 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 766 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 18512 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 766 "CssSelectorTest.vala"
		_vala_assert (!_tmp85_, "!cp.match (c7)");
#line 767 "CssSelectorTest.vala"
		_tmp89_ = cp;
#line 767 "CssSelectorTest.vala"
		_tmp90_ = c8;
#line 767 "CssSelectorTest.vala"
		_tmp88_ = gxml_css_selector_parser_match (_tmp89_, _tmp90_, &_inner_error0_);
#line 767 "CssSelectorTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 767 "CssSelectorTest.vala"
			_g_free0 (_tmp73_);
#line 767 "CssSelectorTest.vala"
			_g_object_unref0 (c8);
#line 767 "CssSelectorTest.vala"
			_g_object_unref0 (c7);
#line 767 "CssSelectorTest.vala"
			_g_object_unref0 (c6);
#line 767 "CssSelectorTest.vala"
			_g_object_unref0 (c5);
#line 767 "CssSelectorTest.vala"
			_g_object_unref0 (c4);
#line 767 "CssSelectorTest.vala"
			_g_object_unref0 (c3);
#line 767 "CssSelectorTest.vala"
			_g_object_unref0 (c2);
#line 767 "CssSelectorTest.vala"
			_g_object_unref0 (c1);
#line 767 "CssSelectorTest.vala"
			_g_object_unref0 (r);
#line 767 "CssSelectorTest.vala"
			_g_object_unref0 (d);
#line 767 "CssSelectorTest.vala"
			_g_object_unref0 (s);
#line 767 "CssSelectorTest.vala"
			_g_object_unref0 (cp);
#line 18551 "CssSelectorTest.c"
			goto __catch18_g_error;
		}
#line 767 "CssSelectorTest.vala"
		_vala_assert (_tmp88_, "cp.match (c8)");
#line 733 "CssSelectorTest.vala"
		_g_free0 (_tmp73_);
#line 733 "CssSelectorTest.vala"
		_g_object_unref0 (c8);
#line 733 "CssSelectorTest.vala"
		_g_object_unref0 (c7);
#line 733 "CssSelectorTest.vala"
		_g_object_unref0 (c6);
#line 733 "CssSelectorTest.vala"
		_g_object_unref0 (c5);
#line 733 "CssSelectorTest.vala"
		_g_object_unref0 (c4);
#line 733 "CssSelectorTest.vala"
		_g_object_unref0 (c3);
#line 733 "CssSelectorTest.vala"
		_g_object_unref0 (c2);
#line 733 "CssSelectorTest.vala"
		_g_object_unref0 (c1);
#line 733 "CssSelectorTest.vala"
		_g_object_unref0 (r);
#line 733 "CssSelectorTest.vala"
		_g_object_unref0 (d);
#line 733 "CssSelectorTest.vala"
		_g_object_unref0 (s);
#line 733 "CssSelectorTest.vala"
		_g_object_unref0 (cp);
#line 18582 "CssSelectorTest.c"
	}
	goto __finally18;
	__catch18_g_error:
	{
		GError* e = NULL;
		GError* _tmp91_;
		const gchar* _tmp92_;
		gchar* _tmp93_;
		gchar* _tmp94_;
#line 733 "CssSelectorTest.vala"
		e = _inner_error0_;
#line 733 "CssSelectorTest.vala"
		_inner_error0_ = NULL;
#line 769 "CssSelectorTest.vala"
		_tmp91_ = e;
#line 769 "CssSelectorTest.vala"
		_tmp92_ = _tmp91_->message;
#line 769 "CssSelectorTest.vala"
		_tmp93_ = g_strconcat ("ERROR: ", _tmp92_, NULL);
#line 769 "CssSelectorTest.vala"
		_tmp94_ = _tmp93_;
#line 769 "CssSelectorTest.vala"
		g_warning ("CssSelectorTest.vala:769: %s", _tmp94_);
#line 769 "CssSelectorTest.vala"
		_g_free0 (_tmp94_);
#line 733 "CssSelectorTest.vala"
		_g_error_free0 (e);
#line 18610 "CssSelectorTest.c"
	}
	__finally18:
#line 733 "CssSelectorTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 733 "CssSelectorTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 733 "CssSelectorTest.vala"
		g_clear_error (&_inner_error0_);
#line 733 "CssSelectorTest.vala"
		return;
#line 18621 "CssSelectorTest.c"
	}
}

static void
___lambda163__gtest_func (void)
{
#line 732 "CssSelectorTest.vala"
	__lambda163_ ();
#line 18630 "CssSelectorTest.c"
}

void
css_selector_test_add_tests (void)
{
#line 27 "CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/all", ___lambda145__gtest_func);
#line 46 "CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/element/node", ___lambda146__gtest_func);
#line 65 "CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/element/attribute/value", ___lambda147__gtest_func);
#line 92 "CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/element/attribute/contains", ___lambda148__gtest_func);
#line 127 "CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/element/attribute/starts_with", ___lambda149__gtest_func);
#line 162 "CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/element/attribute/starts_with_word", ___lambda150__gtest_func);
#line 197 "CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/element/attribute/ends_with", ___lambda151__gtest_func);
#line 232 "CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/element/attribute-value-unquoted", ___lambda152__gtest_func);
#line 262 "CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/element/attribute-value", ___lambda153__gtest_func);
#line 292 "CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/element/class-only", ___lambda154__gtest_func);
#line 327 "CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/element/class-element", ___lambda155__gtest_func);
#line 366 "CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/pseudo/root", ___lambda156__gtest_func);
#line 420 "CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/pseudo/non-hmtl/enable-disable-checked", ___lambda157__gtest_func);
#line 447 "CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/pseudo/empty", ___lambda158__gtest_func);
#line 512 "CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/pseudo/first-child", ___lambda159__gtest_func);
#line 584 "CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/pseudo/last-child", ___lambda160__gtest_func);
#line 656 "CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/element-namespace", ___lambda161__gtest_func);
#line 692 "CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/element-namespace/all", ___lambda162__gtest_func);
#line 732 "CssSelectorTest.vala"
	g_test_add_func ("/gxml/css-selector/element-namespace/none", ___lambda163__gtest_func);
#line 18674 "CssSelectorTest.c"
}

CssSelectorTest*
css_selector_test_construct (GType object_type)
{
	CssSelectorTest* self = NULL;
#line 25 "CssSelectorTest.vala"
	self = (CssSelectorTest*) gxml_test_construct (object_type);
#line 25 "CssSelectorTest.vala"
	return self;
#line 18685 "CssSelectorTest.c"
}

CssSelectorTest*
css_selector_test_new (void)
{
#line 25 "CssSelectorTest.vala"
	return css_selector_test_construct (TYPE_CSS_SELECTOR_TEST);
#line 18693 "CssSelectorTest.c"
}

static void
css_selector_test_class_init (CssSelectorTestClass * klass,
                              gpointer klass_data)
{
#line 25 "CssSelectorTest.vala"
	css_selector_test_parent_class = g_type_class_peek_parent (klass);
#line 18702 "CssSelectorTest.c"
}

static void
css_selector_test_instance_init (CssSelectorTest * self,
                                 gpointer klass)
{
}

GType
css_selector_test_get_type (void)
{
	static volatile gsize css_selector_test_type_id__volatile = 0;
	if (g_once_init_enter (&css_selector_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (CssSelectorTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) css_selector_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (CssSelectorTest), 0, (GInstanceInitFunc) css_selector_test_instance_init, NULL };
		GType css_selector_test_type_id;
		css_selector_test_type_id = g_type_register_static (TYPE_GXML_TEST, "CssSelectorTest", &g_define_type_info, 0);
		g_once_init_leave (&css_selector_test_type_id__volatile, css_selector_test_type_id);
	}
	return css_selector_test_type_id__volatile;
}

