/* GomDocumentTest.c generated by valac 0.44.3, the Vala compiler
 * generated from GomDocumentTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* GomDocumentTest.vala
 *
 * Copyright (C) 2016 Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib-object.h>
#include <glib.h>
#include <gxml/gxml.h>
#include <gee.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_GOM_DOCUMENT_TEST (gom_document_test_get_type ())
#define GOM_DOCUMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_DOCUMENT_TEST, GomDocumentTest))
#define GOM_DOCUMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_DOCUMENT_TEST, GomDocumentTestClass))
#define IS_GOM_DOCUMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_DOCUMENT_TEST))
#define IS_GOM_DOCUMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_DOCUMENT_TEST))
#define GOM_DOCUMENT_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_DOCUMENT_TEST, GomDocumentTestClass))

typedef struct _GomDocumentTest GomDocumentTest;
typedef struct _GomDocumentTestClass GomDocumentTestClass;
typedef struct _GomDocumentTestPrivate GomDocumentTestPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))

#define GOM_DOCUMENT_TEST_TYPE_OBJECT_DOCUMENT (gom_document_test_object_document_get_type ())
#define GOM_DOCUMENT_TEST_OBJECT_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_DOCUMENT_TEST_TYPE_OBJECT_DOCUMENT, GomDocumentTestObjectDocument))
#define GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_DOCUMENT_TEST_TYPE_OBJECT_DOCUMENT, GomDocumentTestObjectDocumentClass))
#define GOM_DOCUMENT_TEST_IS_OBJECT_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_DOCUMENT_TEST_TYPE_OBJECT_DOCUMENT))
#define GOM_DOCUMENT_TEST_IS_OBJECT_DOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_DOCUMENT_TEST_TYPE_OBJECT_DOCUMENT))
#define GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_DOCUMENT_TEST_TYPE_OBJECT_DOCUMENT, GomDocumentTestObjectDocumentClass))

typedef struct _GomDocumentTestObjectDocument GomDocumentTestObjectDocument;
typedef struct _GomDocumentTestObjectDocumentClass GomDocumentTestObjectDocumentClass;

#define GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_TYPE_OBJECT_PARENT (gom_document_test_object_document_object_parent_get_type ())
#define GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_TYPE_OBJECT_PARENT, GomDocumentTestObjectDocumentObjectParent))
#define GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_TYPE_OBJECT_PARENT, GomDocumentTestObjectDocumentObjectParentClass))
#define GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_IS_OBJECT_PARENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_TYPE_OBJECT_PARENT))
#define GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_IS_OBJECT_PARENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_TYPE_OBJECT_PARENT))
#define GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_TYPE_OBJECT_PARENT, GomDocumentTestObjectDocumentObjectParentClass))

typedef struct _GomDocumentTestObjectDocumentObjectParent GomDocumentTestObjectDocumentObjectParent;
typedef struct _GomDocumentTestObjectDocumentObjectParentClass GomDocumentTestObjectDocumentObjectParentClass;

#define GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TYPE_OBJECT_PROPERTY (gom_document_test_object_document_object_parent_object_property_get_type ())
#define GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_OBJECT_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TYPE_OBJECT_PROPERTY, GomDocumentTestObjectDocumentObjectParentObjectProperty))
#define GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_OBJECT_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TYPE_OBJECT_PROPERTY, GomDocumentTestObjectDocumentObjectParentObjectPropertyClass))
#define GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_IS_OBJECT_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TYPE_OBJECT_PROPERTY))
#define GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_IS_OBJECT_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TYPE_OBJECT_PROPERTY))
#define GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_OBJECT_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TYPE_OBJECT_PROPERTY, GomDocumentTestObjectDocumentObjectParentObjectPropertyClass))

typedef struct _GomDocumentTestObjectDocumentObjectParentObjectProperty GomDocumentTestObjectDocumentObjectParentObjectProperty;
typedef struct _GomDocumentTestObjectDocumentObjectParentObjectPropertyClass GomDocumentTestObjectDocumentObjectParentObjectPropertyClass;
typedef struct _GomDocumentTestObjectDocumentPrivate GomDocumentTestObjectDocumentPrivate;
enum  {
	GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_0_PROPERTY,
	GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_ROOT_ELEMENT_PROPERTY,
	GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_NUM_PROPERTIES
};
static GParamSpec* gom_document_test_object_document_properties[GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_NUM_PROPERTIES];
typedef struct _GomDocumentTestObjectDocumentObjectParentPrivate GomDocumentTestObjectDocumentObjectParentPrivate;

#define GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TYPE_OBJECT_CHILD (gom_document_test_object_document_object_parent_object_child_get_type ())
#define GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_OBJECT_CHILD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TYPE_OBJECT_CHILD, GomDocumentTestObjectDocumentObjectParentObjectChild))
#define GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_OBJECT_CHILD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TYPE_OBJECT_CHILD, GomDocumentTestObjectDocumentObjectParentObjectChildClass))
#define GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_IS_OBJECT_CHILD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TYPE_OBJECT_CHILD))
#define GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_IS_OBJECT_CHILD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TYPE_OBJECT_CHILD))
#define GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_OBJECT_CHILD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TYPE_OBJECT_CHILD, GomDocumentTestObjectDocumentObjectParentObjectChildClass))

typedef struct _GomDocumentTestObjectDocumentObjectParentObjectChild GomDocumentTestObjectDocumentObjectParentObjectChild;
typedef struct _GomDocumentTestObjectDocumentObjectParentObjectChildClass GomDocumentTestObjectDocumentObjectParentObjectChildClass;
enum  {
	GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_0_PROPERTY,
	GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TEXT_PROPERTY,
	GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_PROP_PROPERTY,
	GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_CHILD_PROPERTY,
	GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_NUM_PROPERTIES
};
static GParamSpec* gom_document_test_object_document_object_parent_properties[GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_NUM_PROPERTIES];
typedef struct _GomDocumentTestObjectDocumentObjectParentObjectPropertyPrivate GomDocumentTestObjectDocumentObjectParentObjectPropertyPrivate;
enum  {
	GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_OBJECT_PROPERTY_0_PROPERTY,
	GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_OBJECT_PROPERTY_VALUE_PROPERTY,
	GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_OBJECT_PROPERTY_NUM_PROPERTIES
};
static GParamSpec* gom_document_test_object_document_object_parent_object_property_properties[GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_OBJECT_PROPERTY_NUM_PROPERTIES];
typedef struct _GomDocumentTestObjectDocumentObjectParentObjectChildPrivate GomDocumentTestObjectDocumentObjectParentObjectChildPrivate;
enum  {
	GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_OBJECT_CHILD_0_PROPERTY,
	GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_OBJECT_CHILD_NUM_PROPERTIES
};
static GParamSpec* gom_document_test_object_document_object_parent_object_child_properties[GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_OBJECT_CHILD_NUM_PROPERTIES];
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _GomDocumentTest {
	GXmlTest parent_instance;
	GomDocumentTestPrivate * priv;
};

struct _GomDocumentTestClass {
	GXmlTestClass parent_class;
};

struct _GomDocumentTestObjectDocument {
	GXmlGomDocument parent_instance;
	GomDocumentTestObjectDocumentPrivate * priv;
};

struct _GomDocumentTestObjectDocumentClass {
	GXmlGomDocumentClass parent_class;
};

struct _GomDocumentTestObjectDocumentPrivate {
	GomDocumentTestObjectDocumentObjectParent* _root_element;
};

struct _GomDocumentTestObjectDocumentObjectParent {
	GXmlGomElement parent_instance;
	GomDocumentTestObjectDocumentObjectParentPrivate * priv;
};

struct _GomDocumentTestObjectDocumentObjectParentClass {
	GXmlGomElementClass parent_class;
};

struct _GomDocumentTestObjectDocumentObjectParentPrivate {
	gchar* _text;
	GomDocumentTestObjectDocumentObjectParentObjectProperty* _prop;
	GomDocumentTestObjectDocumentObjectParentObjectChild* _child;
};

struct _GomDocumentTestObjectDocumentObjectParentObjectProperty {
	GObject parent_instance;
	GomDocumentTestObjectDocumentObjectParentObjectPropertyPrivate * priv;
};

struct _GomDocumentTestObjectDocumentObjectParentObjectPropertyClass {
	GObjectClass parent_class;
};

struct _GomDocumentTestObjectDocumentObjectParentObjectPropertyPrivate {
	gchar* _value;
};

struct _GomDocumentTestObjectDocumentObjectParentObjectChild {
	GXmlGomElement parent_instance;
	GomDocumentTestObjectDocumentObjectParentObjectChildPrivate * priv;
};

struct _GomDocumentTestObjectDocumentObjectParentObjectChildClass {
	GXmlGomElementClass parent_class;
};

static gpointer gom_document_test_parent_class = NULL;
static gint GomDocumentTestObjectDocument_private_offset;
static gpointer gom_document_test_object_document_parent_class = NULL;
static gint GomDocumentTestObjectDocumentObjectParent_private_offset;
static gpointer gom_document_test_object_document_object_parent_parent_class = NULL;
static gint GomDocumentTestObjectDocumentObjectParentObjectProperty_private_offset;
static gpointer gom_document_test_object_document_object_parent_object_property_parent_class = NULL;
static GXmlGomPropertyIface * gom_document_test_object_document_object_parent_object_property_gxml_gom_property_parent_iface = NULL;
static gpointer gom_document_test_object_document_object_parent_object_child_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType gom_document_test_get_type (void) G_GNUC_CONST;
void gom_document_test_add_tests (void);
static void __lambda61_ (void);
static void ___lambda61__gtest_func (void);
static void __lambda62_ (void);
static void ___lambda62__gtest_func (void);
static void __lambda63_ (void);
static void ___lambda63__gtest_func (void);
static void __lambda64_ (void);
static void ___lambda64__gtest_func (void);
static void __lambda65_ (void);
static void ___lambda65__gtest_func (void);
static void __lambda66_ (void);
static void ___lambda66__gtest_func (void);
static void __lambda67_ (void);
static void ___lambda67__gtest_func (void);
static void __lambda68_ (void);
static void ___lambda68__gtest_func (void);
static void __lambda69_ (void);
static void ___lambda69__gtest_func (void);
static void __lambda70_ (void);
static void ___lambda70__gtest_func (void);
static void __lambda71_ (void);
static void ___lambda71__gtest_func (void);
static void __lambda72_ (void);
static void ___lambda72__gtest_func (void);
static void __lambda73_ (void);
static void ___lambda73__gtest_func (void);
static void __lambda74_ (void);
static void ___lambda74__gtest_func (void);
static void __lambda75_ (void);
static void ___lambda75__gtest_func (void);
static void __lambda76_ (void);
static void ___lambda76__gtest_func (void);
static void __lambda77_ (void);
static void ___lambda77__gtest_func (void);
static void __lambda78_ (void);
static void ___lambda78__gtest_func (void);
static void __lambda79_ (void);
static void ___lambda79__gtest_func (void);
static void __lambda80_ (void);
static void ___lambda80__gtest_func (void);
static void __lambda81_ (void);
static void ___lambda81__gtest_func (void);
static void __lambda82_ (void);
static void ___lambda82__gtest_func (void);
static void __lambda83_ (void);
static void ___lambda83__gtest_func (void);
static void __lambda84_ (void);
static void ___lambda84__gtest_func (void);
static void __lambda85_ (void);
static void ___lambda85__gtest_func (void);
static void __lambda86_ (void);
static void ___lambda86__gtest_func (void);
static void __lambda87_ (void);
static void ___lambda87__gtest_func (void);
static void __lambda88_ (void);
static void ___lambda88__gtest_func (void);
static void __lambda89_ (void);
static void ___lambda89__gtest_func (void);
static void __lambda90_ (void);
static void ___lambda90__gtest_func (void);
static void __lambda91_ (void);
static void ___lambda91__gtest_func (void);
static void __lambda92_ (void);
static void ___lambda92__gtest_func (void);
static void __lambda93_ (void);
static void ___lambda93__gtest_func (void);
static void __lambda94_ (void);
static void ___lambda94__gtest_func (void);
static void __lambda95_ (void);
static void ___lambda95__gtest_func (void);
static void __lambda96_ (void);
static GType gom_document_test_object_document_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static GomDocumentTestObjectDocument* gom_document_test_object_document_new (void);
static GomDocumentTestObjectDocument* gom_document_test_object_document_construct (GType object_type);
GType gom_document_test_object_document_object_parent_get_type (void) G_GNUC_CONST;
static GomDocumentTestObjectDocumentObjectParent* gom_document_test_object_document_get_root_element (GomDocumentTestObjectDocument* self);
static const gchar* gom_document_test_object_document_object_parent_get_text (GomDocumentTestObjectDocumentObjectParent* self);
GType gom_document_test_object_document_object_parent_object_property_get_type (void) G_GNUC_CONST;
static GomDocumentTestObjectDocumentObjectParentObjectProperty* gom_document_test_object_document_object_parent_get_prop (GomDocumentTestObjectDocumentObjectParent* self);
static void ___lambda96__gtest_func (void);
GomDocumentTest* gom_document_test_new (void);
GomDocumentTest* gom_document_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static void gom_document_test_object_document_set_root_element (GomDocumentTestObjectDocument* self,
                                                         GomDocumentTestObjectDocumentObjectParent* value);
static GObject * gom_document_test_object_document_constructor (GType type,
                                                         guint n_construct_properties,
                                                         GObjectConstructParam * construct_properties);
GType gom_document_test_object_document_object_parent_object_child_get_type (void) G_GNUC_CONST;
static GomDocumentTestObjectDocumentObjectParent* gom_document_test_object_document_object_parent_new (void);
static GomDocumentTestObjectDocumentObjectParent* gom_document_test_object_document_object_parent_construct (GType object_type);
static void gom_document_test_object_document_object_parent_set_text (GomDocumentTestObjectDocumentObjectParent* self,
                                                               const gchar* value);
static void gom_document_test_object_document_object_parent_set_prop (GomDocumentTestObjectDocumentObjectParent* self,
                                                               GomDocumentTestObjectDocumentObjectParentObjectProperty* value);
static GomDocumentTestObjectDocumentObjectParentObjectChild* gom_document_test_object_document_object_parent_get_child (GomDocumentTestObjectDocumentObjectParent* self);
static void gom_document_test_object_document_object_parent_set_child (GomDocumentTestObjectDocumentObjectParent* self,
                                                                GomDocumentTestObjectDocumentObjectParentObjectChild* value);
static GObject * gom_document_test_object_document_object_parent_constructor (GType type,
                                                                       guint n_construct_properties,
                                                                       GObjectConstructParam * construct_properties);
static gboolean gom_document_test_object_document_object_parent_object_property_real_validate_value (GXmlGomProperty* base,
                                                                                              const gchar* val);
static GomDocumentTestObjectDocumentObjectParentObjectProperty* gom_document_test_object_document_object_parent_object_property_new (void);
static GomDocumentTestObjectDocumentObjectParentObjectProperty* gom_document_test_object_document_object_parent_object_property_construct (GType object_type);
static void gom_document_test_object_document_object_parent_object_property_finalize (GObject * obj);
static void _vala_gom_document_test_object_document_object_parent_object_property_get_property (GObject * object,
                                                                                         guint property_id,
                                                                                         GValue * value,
                                                                                         GParamSpec * pspec);
static void _vala_gom_document_test_object_document_object_parent_object_property_set_property (GObject * object,
                                                                                         guint property_id,
                                                                                         const GValue * value,
                                                                                         GParamSpec * pspec);
static GomDocumentTestObjectDocumentObjectParentObjectChild* gom_document_test_object_document_object_parent_object_child_new (void);
static GomDocumentTestObjectDocumentObjectParentObjectChild* gom_document_test_object_document_object_parent_object_child_construct (GType object_type);
static GObject * gom_document_test_object_document_object_parent_object_child_constructor (GType type,
                                                                                    guint n_construct_properties,
                                                                                    GObjectConstructParam * construct_properties);
static void gom_document_test_object_document_object_parent_finalize (GObject * obj);
static void _vala_gom_document_test_object_document_object_parent_get_property (GObject * object,
                                                                         guint property_id,
                                                                         GValue * value,
                                                                         GParamSpec * pspec);
static void _vala_gom_document_test_object_document_object_parent_set_property (GObject * object,
                                                                         guint property_id,
                                                                         const GValue * value,
                                                                         GParamSpec * pspec);
static void gom_document_test_object_document_finalize (GObject * obj);
static void _vala_gom_document_test_object_document_get_property (GObject * object,
                                                           guint property_id,
                                                           GValue * value,
                                                           GParamSpec * pspec);
static void _vala_gom_document_test_object_document_set_property (GObject * object,
                                                           guint property_id,
                                                           const GValue * value,
                                                           GParamSpec * pspec);
static void _vala_array_destroy (gpointer array,
                          gint array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gint array_length,
                       GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);

static void
__lambda61_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlDomDocument* d = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlDomElement* r = NULL;
		GXmlDomElement* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		GXmlDomNodeNodeType _tmp8_;
		GXmlDomNodeNodeType _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		GXmlDomNodeList* _tmp13_;
		GXmlDomNodeList* _tmp14_;
		GXmlDomNodeList* _tmp15_;
		GXmlDomElement* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlDomElement* _tmp18_;
		GXmlDomElement* _tmp19_;
		GXmlDomElement* _tmp20_;
		GXmlDomElement* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
#line 61 "GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new ();
#line 61 "GomDocumentTest.vala"
		d = (GXmlDomDocument*) _tmp0_;
#line 62 "GomDocumentTest.vala"
		_tmp1_ = gxml_dom_document_create_element (d, "root", &_inner_error0_);
#line 62 "GomDocumentTest.vala"
		r = _tmp1_;
#line 62 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 62 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 419 "GomDocumentTest.c"
			goto __catch72_g_error;
		}
#line 63 "GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (r, GXML_TYPE_DOM_ELEMENT), "r is DomElement");
#line 64 "GomDocumentTest.vala"
		_tmp2_ = gxml_dom_element_get_local_name (r);
#line 64 "GomDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 64 "GomDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 64 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp4_, "root") == 0, "r.local_name == \"root\"");
#line 64 "GomDocumentTest.vala"
		_g_free0 (_tmp4_);
#line 65 "GomDocumentTest.vala"
		_tmp5_ = gxml_dom_element_get_tag_name (r);
#line 65 "GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 65 "GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 65 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "root") == 0, "r.tag_name == \"root\"");
#line 65 "GomDocumentTest.vala"
		_g_free0 (_tmp7_);
#line 66 "GomDocumentTest.vala"
		_tmp8_ = gxml_dom_node_get_node_type ((GXmlDomNode*) r);
#line 66 "GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 66 "GomDocumentTest.vala"
		_vala_assert (_tmp9_ == GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE, "r.node_type == DomNode.NodeType.ELEMENT_NODE");
#line 67 "GomDocumentTest.vala"
		_tmp10_ = gxml_dom_node_get_node_name ((GXmlDomNode*) r);
#line 67 "GomDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 67 "GomDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 67 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp12_, "root") == 0, "r.node_name == \"root\"");
#line 67 "GomDocumentTest.vala"
		_g_free0 (_tmp12_);
#line 68 "GomDocumentTest.vala"
		_tmp13_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) d);
#line 68 "GomDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 68 "GomDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 68 "GomDocumentTest.vala"
		gee_collection_add ((GeeCollection*) _tmp15_, (GXmlDomNode*) r);
#line 68 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 69 "GomDocumentTest.vala"
		_tmp16_ = gxml_dom_document_get_document_element (d);
#line 69 "GomDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 69 "GomDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 69 "GomDocumentTest.vala"
		_vala_assert (_tmp18_ != NULL, "d.document_element != null");
#line 69 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp18_);
#line 70 "GomDocumentTest.vala"
		_tmp19_ = gxml_dom_document_get_document_element (d);
#line 70 "GomDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 70 "GomDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 70 "GomDocumentTest.vala"
		_tmp22_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp21_);
#line 70 "GomDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 70 "GomDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 70 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp24_, "root") == 0, "d.document_element.node_name == \"root\"");
#line 70 "GomDocumentTest.vala"
		_g_free0 (_tmp24_);
#line 70 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp21_);
#line 60 "GomDocumentTest.vala"
		_g_object_unref0 (r);
#line 60 "GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 502 "GomDocumentTest.c"
	}
	goto __finally72;
	__catch72_g_error:
	{
#line 60 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 60 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 73 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 513 "GomDocumentTest.c"
	}
	__finally72:
#line 60 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 60 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 60 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 60 "GomDocumentTest.vala"
		return;
#line 524 "GomDocumentTest.c"
	}
}

static void
___lambda61__gtest_func (void)
{
#line 59 "GomDocumentTest.vala"
	__lambda61_ ();
#line 533 "GomDocumentTest.c"
}

static void
__lambda62_ (void)
{
	GXmlDomDocument* doc = NULL;
	GError* _inner_error0_ = NULL;
	{
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_;
		GXmlGomDocument* _tmp2_;
#line 78 "GomDocumentTest.vala"
		g_test_message ("invalid file...");
#line 80 "GomDocumentTest.vala"
		_tmp1_ = gxml_gom_document_new_from_path ("/tmp/asdfjlkansdlfjl", &_inner_error0_);
#line 80 "GomDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 80 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 553 "GomDocumentTest.c"
			goto __catch73_g_error;
		}
#line 80 "GomDocumentTest.vala"
		_tmp2_ = _tmp0_;
#line 80 "GomDocumentTest.vala"
		_tmp0_ = NULL;
#line 80 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 80 "GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp2_;
#line 81 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 77 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 568 "GomDocumentTest.c"
	}
	goto __finally73;
	__catch73_g_error:
	{
#line 77 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 77 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 577 "GomDocumentTest.c"
	}
	__finally73:
#line 77 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 77 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 77 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 77 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 77 "GomDocumentTest.vala"
		return;
#line 590 "GomDocumentTest.c"
	}
	{
		GXmlGomDocument* _tmp3_ = NULL;
		GXmlGomDocument* _tmp4_;
		GXmlGomDocument* _tmp5_;
#line 86 "GomDocumentTest.vala"
		_tmp4_ = gxml_gom_document_new_from_path ("/tmp/", &_inner_error0_);
#line 86 "GomDocumentTest.vala"
		_tmp3_ = _tmp4_;
#line 86 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 602 "GomDocumentTest.c"
			goto __catch74_g_error;
		}
#line 86 "GomDocumentTest.vala"
		_tmp5_ = _tmp3_;
#line 86 "GomDocumentTest.vala"
		_tmp3_ = NULL;
#line 86 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 86 "GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp5_;
#line 87 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 84 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp3_);
#line 617 "GomDocumentTest.c"
	}
	goto __finally74;
	__catch74_g_error:
	{
#line 84 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 84 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 626 "GomDocumentTest.c"
	}
	__finally74:
#line 84 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 84 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 84 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 84 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 84 "GomDocumentTest.vala"
		return;
#line 639 "GomDocumentTest.c"
	}
	{
		GXmlGomDocument* _tmp6_ = NULL;
		GXmlGomDocument* _tmp7_;
		GXmlGomDocument* _tmp8_;
#line 90 "GomDocumentTest.vala"
		_tmp7_ = gxml_gom_document_new_from_path ("test_invalid.xml", &_inner_error0_);
#line 90 "GomDocumentTest.vala"
		_tmp6_ = _tmp7_;
#line 90 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 651 "GomDocumentTest.c"
			goto __catch75_g_error;
		}
#line 90 "GomDocumentTest.vala"
		_tmp8_ = _tmp6_;
#line 90 "GomDocumentTest.vala"
		_tmp6_ = NULL;
#line 90 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 90 "GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp8_;
#line 91 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 89 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp6_);
#line 666 "GomDocumentTest.c"
	}
	goto __finally75;
	__catch75_g_error:
	{
#line 89 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 89 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 675 "GomDocumentTest.c"
	}
	__finally75:
#line 89 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 89 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 89 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 89 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 89 "GomDocumentTest.vala"
		return;
#line 688 "GomDocumentTest.c"
	}
#line 75 "GomDocumentTest.vala"
	_g_object_unref0 (doc);
#line 692 "GomDocumentTest.c"
}

static void
___lambda62__gtest_func (void)
{
#line 75 "GomDocumentTest.vala"
	__lambda62_ ();
#line 700 "GomDocumentTest.c"
}

static void
__lambda63_ (void)
{
	GFile* fin = NULL;
	GFile* _tmp0_;
	GFile* _tmp1_;
	GError* _inner_error0_ = NULL;
#line 95 "GomDocumentTest.vala"
	_tmp0_ = g_file_new_for_path (TEST_DIR "/test.xml");
#line 95 "GomDocumentTest.vala"
	fin = _tmp0_;
#line 96 "GomDocumentTest.vala"
	_tmp1_ = fin;
#line 96 "GomDocumentTest.vala"
	_vala_assert (g_file_query_exists (_tmp1_, NULL), "fin.query_exists ()");
#line 718 "GomDocumentTest.c"
	{
		GFileInputStream* instream = NULL;
		GFile* _tmp2_;
		GFileInputStream* _tmp3_;
		GXmlGomDocument* doc = NULL;
		GFileInputStream* _tmp4_;
		GXmlGomDocument* _tmp5_;
		GXmlGomDocument* _tmp6_;
#line 98 "GomDocumentTest.vala"
		_tmp2_ = fin;
#line 98 "GomDocumentTest.vala"
		_tmp3_ = g_file_read (_tmp2_, NULL, &_inner_error0_);
#line 98 "GomDocumentTest.vala"
		instream = _tmp3_;
#line 98 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 735 "GomDocumentTest.c"
			goto __catch76_g_error;
		}
#line 99 "GomDocumentTest.vala"
		_tmp4_ = instream;
#line 99 "GomDocumentTest.vala"
		_tmp5_ = gxml_gom_document_new_from_stream ((GInputStream*) _tmp4_, &_inner_error0_);
#line 99 "GomDocumentTest.vala"
		doc = _tmp5_;
#line 99 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 99 "GomDocumentTest.vala"
			_g_object_unref0 (instream);
#line 748 "GomDocumentTest.c"
			goto __catch76_g_error;
		}
#line 100 "GomDocumentTest.vala"
		_tmp6_ = doc;
#line 100 "GomDocumentTest.vala"
		_vala_assert (_tmp6_ != NULL, "doc != null");
#line 97 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 97 "GomDocumentTest.vala"
		_g_object_unref0 (instream);
#line 759 "GomDocumentTest.c"
	}
	goto __finally76;
	__catch76_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp7_;
#line 97 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 97 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 103 "GomDocumentTest.vala"
		_tmp7_ = e->message;
#line 103 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:103: %s", _tmp7_);
#line 104 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 97 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 778 "GomDocumentTest.c"
	}
	__finally76:
#line 97 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 97 "GomDocumentTest.vala"
		_g_object_unref0 (fin);
#line 97 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 97 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 97 "GomDocumentTest.vala"
		return;
#line 791 "GomDocumentTest.c"
	}
#line 94 "GomDocumentTest.vala"
	_g_object_unref0 (fin);
#line 795 "GomDocumentTest.c"
}

static void
___lambda63__gtest_func (void)
{
#line 94 "GomDocumentTest.vala"
	__lambda63_ ();
#line 803 "GomDocumentTest.c"
}

static void
__lambda64_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GFile* f = NULL;
		GFile* _tmp0_;
		GFile* _tmp1_;
		GString* s = NULL;
		GString* _tmp3_;
		GString* _tmp4_;
		GXmlGomDocument* d = NULL;
		GString* _tmp5_;
		const gchar* _tmp6_;
		GXmlGomDocument* _tmp7_;
		GXmlGomDocument* _tmp8_;
		GFile* _tmp9_;
		GFile* _tmp10_;
		GXmlGomDocument* d2 = NULL;
		GFile* _tmp11_;
		GXmlGomDocument* _tmp12_;
		GXmlGomDocument* _tmp13_;
		GXmlGomDocument* _tmp14_;
		GXmlDomElement* _tmp15_;
		GXmlDomElement* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlGomDocument* _tmp18_;
		GXmlDomElement* _tmp19_;
		GXmlDomElement* _tmp20_;
		GXmlDomElement* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
		GFile* _tmp25_;
#line 109 "GomDocumentTest.vala"
		_tmp0_ = g_file_new_for_path (TEST_SAVE_DIR "/tw-test-file.xml");
#line 109 "GomDocumentTest.vala"
		f = _tmp0_;
#line 110 "GomDocumentTest.vala"
		_tmp1_ = f;
#line 110 "GomDocumentTest.vala"
		if (g_file_query_exists (_tmp1_, NULL)) {
#line 848 "GomDocumentTest.c"
			GFile* _tmp2_;
#line 110 "GomDocumentTest.vala"
			_tmp2_ = f;
#line 110 "GomDocumentTest.vala"
			g_file_delete (_tmp2_, NULL, &_inner_error0_);
#line 110 "GomDocumentTest.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 110 "GomDocumentTest.vala"
				_g_object_unref0 (f);
#line 858 "GomDocumentTest.c"
				goto __catch77_g_error;
			}
		}
#line 111 "GomDocumentTest.vala"
		_tmp3_ = g_string_new ("");
#line 111 "GomDocumentTest.vala"
		s = _tmp3_;
#line 112 "GomDocumentTest.vala"
		_tmp4_ = s;
#line 112 "GomDocumentTest.vala"
		g_string_append (_tmp4_, "<document_element />");
#line 113 "GomDocumentTest.vala"
		_tmp5_ = s;
#line 113 "GomDocumentTest.vala"
		_tmp6_ = _tmp5_->str;
#line 113 "GomDocumentTest.vala"
		_tmp7_ = gxml_gom_document_new_from_string (_tmp6_, &_inner_error0_);
#line 113 "GomDocumentTest.vala"
		d = _tmp7_;
#line 113 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 113 "GomDocumentTest.vala"
			_g_string_free0 (s);
#line 113 "GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 884 "GomDocumentTest.c"
			goto __catch77_g_error;
		}
#line 119 "GomDocumentTest.vala"
		_tmp8_ = d;
#line 119 "GomDocumentTest.vala"
		_tmp9_ = f;
#line 119 "GomDocumentTest.vala"
		gxml_dom_document_write_file ((GXmlDomDocument*) _tmp8_, _tmp9_, NULL, &_inner_error0_);
#line 119 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 119 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 119 "GomDocumentTest.vala"
			_g_string_free0 (s);
#line 119 "GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 901 "GomDocumentTest.c"
			goto __catch77_g_error;
		}
#line 120 "GomDocumentTest.vala"
		_tmp10_ = f;
#line 120 "GomDocumentTest.vala"
		_vala_assert (g_file_query_exists (_tmp10_, NULL), "f.query_exists ()");
#line 121 "GomDocumentTest.vala"
		_tmp11_ = f;
#line 121 "GomDocumentTest.vala"
		_tmp12_ = gxml_gom_document_new_from_file (_tmp11_, &_inner_error0_);
#line 121 "GomDocumentTest.vala"
		d2 = _tmp12_;
#line 121 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 121 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 121 "GomDocumentTest.vala"
			_g_string_free0 (s);
#line 121 "GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 922 "GomDocumentTest.c"
			goto __catch77_g_error;
		}
#line 122 "GomDocumentTest.vala"
		_tmp13_ = d2;
#line 122 "GomDocumentTest.vala"
		_vala_assert (_tmp13_ != NULL, "d2 != null");
#line 123 "GomDocumentTest.vala"
		_tmp14_ = d2;
#line 123 "GomDocumentTest.vala"
		_tmp15_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp14_);
#line 123 "GomDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 123 "GomDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 123 "GomDocumentTest.vala"
		_vala_assert (_tmp17_ != NULL, "d2.document_element != null");
#line 123 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp17_);
#line 124 "GomDocumentTest.vala"
		_tmp18_ = d2;
#line 124 "GomDocumentTest.vala"
		_tmp19_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp18_);
#line 124 "GomDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 124 "GomDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 124 "GomDocumentTest.vala"
		_tmp22_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp21_);
#line 124 "GomDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 124 "GomDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 124 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp24_, "document_element") == 0, "d2.document_element.node_name == \"document_element\"");
#line 124 "GomDocumentTest.vala"
		_g_free0 (_tmp24_);
#line 124 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp21_);
#line 125 "GomDocumentTest.vala"
		_tmp25_ = f;
#line 125 "GomDocumentTest.vala"
		g_file_delete (_tmp25_, NULL, &_inner_error0_);
#line 125 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 125 "GomDocumentTest.vala"
			_g_object_unref0 (d2);
#line 125 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 125 "GomDocumentTest.vala"
			_g_string_free0 (s);
#line 125 "GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 975 "GomDocumentTest.c"
			goto __catch77_g_error;
		}
#line 108 "GomDocumentTest.vala"
		_g_object_unref0 (d2);
#line 108 "GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 108 "GomDocumentTest.vala"
		_g_string_free0 (s);
#line 108 "GomDocumentTest.vala"
		_g_object_unref0 (f);
#line 986 "GomDocumentTest.c"
	}
	goto __finally77;
	__catch77_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
#line 108 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 108 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 127 "GomDocumentTest.vala"
		_tmp26_ = e->message;
#line 127 "GomDocumentTest.vala"
		_tmp27_ = g_strconcat ("Error: ", _tmp26_, NULL);
#line 127 "GomDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 127 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:127: %s", _tmp28_);
#line 127 "GomDocumentTest.vala"
		_g_free0 (_tmp28_);
#line 128 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 108 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 1013 "GomDocumentTest.c"
	}
	__finally77:
#line 108 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 108 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 108 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 108 "GomDocumentTest.vala"
		return;
#line 1024 "GomDocumentTest.c"
	}
}

static void
___lambda64__gtest_func (void)
{
#line 107 "GomDocumentTest.vala"
	__lambda64_ ();
#line 1033 "GomDocumentTest.c"
}

static void
__lambda65_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GFile* f = NULL;
		GFile* _tmp0_;
		GFile* _tmp1_;
		GString* s = NULL;
		GString* _tmp3_;
		GString* _tmp4_;
		GXmlGomDocument* d = NULL;
		GString* _tmp5_;
		const gchar* _tmp6_;
		GXmlGomDocument* _tmp7_;
		GXmlXParser* parser = NULL;
		GXmlGomDocument* _tmp8_;
		GXmlXParser* _tmp9_;
		gchar* _tmp10_ = NULL;
		GXmlXParser* _tmp11_;
		gchar* _tmp12_;
		GFile* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		gchar* _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_;
		gchar* _tmp19_;
		GXmlGomDocument* _tmp20_;
		GFile* _tmp21_;
		GFile* _tmp22_;
		GXmlGomDocument* d2 = NULL;
		GXmlGomDocument* _tmp23_;
		GXmlGomDocument* _tmp24_;
		GXmlGomDocument* _tmp25_;
		GFile* _tmp26_;
		GXmlGomDocument* _tmp27_;
		GXmlDomElement* _tmp28_;
		GXmlDomElement* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlGomDocument* _tmp31_;
		GXmlDomElement* _tmp32_;
		GXmlDomElement* _tmp33_;
		GXmlDomElement* _tmp34_;
		gchar* _tmp35_;
		gchar* _tmp36_;
		gchar* _tmp37_;
		GFile* _tmp38_;
#line 133 "GomDocumentTest.vala"
		_tmp0_ = g_file_new_for_path (TEST_SAVE_DIR "/tw-test-file.xml");
#line 133 "GomDocumentTest.vala"
		f = _tmp0_;
#line 134 "GomDocumentTest.vala"
		_tmp1_ = f;
#line 134 "GomDocumentTest.vala"
		if (g_file_query_exists (_tmp1_, NULL)) {
#line 1092 "GomDocumentTest.c"
			GFile* _tmp2_;
#line 134 "GomDocumentTest.vala"
			_tmp2_ = f;
#line 134 "GomDocumentTest.vala"
			g_file_delete (_tmp2_, NULL, &_inner_error0_);
#line 134 "GomDocumentTest.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 134 "GomDocumentTest.vala"
				_g_object_unref0 (f);
#line 1102 "GomDocumentTest.c"
				goto __catch78_g_error;
			}
		}
#line 135 "GomDocumentTest.vala"
		_tmp3_ = g_string_new ("");
#line 135 "GomDocumentTest.vala"
		s = _tmp3_;
#line 136 "GomDocumentTest.vala"
		_tmp4_ = s;
#line 136 "GomDocumentTest.vala"
		g_string_append (_tmp4_, "<document_element />");
#line 137 "GomDocumentTest.vala"
		_tmp5_ = s;
#line 137 "GomDocumentTest.vala"
		_tmp6_ = _tmp5_->str;
#line 137 "GomDocumentTest.vala"
		_tmp7_ = gxml_gom_document_new_from_string (_tmp6_, &_inner_error0_);
#line 137 "GomDocumentTest.vala"
		d = _tmp7_;
#line 137 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 137 "GomDocumentTest.vala"
			_g_string_free0 (s);
#line 137 "GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 1128 "GomDocumentTest.c"
			goto __catch78_g_error;
		}
#line 138 "GomDocumentTest.vala"
		_tmp8_ = d;
#line 138 "GomDocumentTest.vala"
		_tmp9_ = gxml_xparser_new ((GXmlDomNode*) _tmp8_);
#line 138 "GomDocumentTest.vala"
		parser = _tmp9_;
#line 139 "GomDocumentTest.vala"
		_tmp11_ = parser;
#line 139 "GomDocumentTest.vala"
		_tmp12_ = gxml_parser_write_string ((GXmlParser*) _tmp11_, &_inner_error0_);
#line 139 "GomDocumentTest.vala"
		_tmp10_ = _tmp12_;
#line 139 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 139 "GomDocumentTest.vala"
			_g_object_unref0 (parser);
#line 139 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 139 "GomDocumentTest.vala"
			_g_string_free0 (s);
#line 139 "GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 1153 "GomDocumentTest.c"
			goto __catch78_g_error;
		}
#line 139 "GomDocumentTest.vala"
		_tmp13_ = f;
#line 139 "GomDocumentTest.vala"
		_tmp14_ = g_file_get_uri (_tmp13_);
#line 139 "GomDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 139 "GomDocumentTest.vala"
		_tmp16_ = g_strconcat ("Saving to file: ", _tmp15_, NULL);
#line 139 "GomDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 139 "GomDocumentTest.vala"
		_tmp18_ = g_strconcat (_tmp17_, _tmp10_, NULL);
#line 139 "GomDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 139 "GomDocumentTest.vala"
		g_test_message ("%s", _tmp19_);
#line 139 "GomDocumentTest.vala"
		_g_free0 (_tmp19_);
#line 139 "GomDocumentTest.vala"
		_g_free0 (_tmp17_);
#line 139 "GomDocumentTest.vala"
		_g_free0 (_tmp15_);
#line 140 "GomDocumentTest.vala"
		_tmp20_ = d;
#line 140 "GomDocumentTest.vala"
		_tmp21_ = f;
#line 140 "GomDocumentTest.vala"
		gxml_dom_document_write_file ((GXmlDomDocument*) _tmp20_, _tmp21_, NULL, &_inner_error0_);
#line 140 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 140 "GomDocumentTest.vala"
			_g_free0 (_tmp10_);
#line 140 "GomDocumentTest.vala"
			_g_object_unref0 (parser);
#line 140 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 140 "GomDocumentTest.vala"
			_g_string_free0 (s);
#line 140 "GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 1196 "GomDocumentTest.c"
			goto __catch78_g_error;
		}
#line 141 "GomDocumentTest.vala"
		_tmp22_ = f;
#line 141 "GomDocumentTest.vala"
		_vala_assert (g_file_query_exists (_tmp22_, NULL), "f.query_exists ()");
#line 142 "GomDocumentTest.vala"
		_tmp23_ = gxml_gom_document_new ();
#line 142 "GomDocumentTest.vala"
		d2 = _tmp23_;
#line 143 "GomDocumentTest.vala"
		_tmp24_ = d2;
#line 143 "GomDocumentTest.vala"
		_vala_assert (_tmp24_ != NULL, "d2 != null");
#line 144 "GomDocumentTest.vala"
		_tmp25_ = d2;
#line 144 "GomDocumentTest.vala"
		_tmp26_ = f;
#line 144 "GomDocumentTest.vala"
		gxml_dom_document_read_from_file ((GXmlDomDocument*) _tmp25_, _tmp26_, NULL, &_inner_error0_);
#line 144 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 144 "GomDocumentTest.vala"
			_g_object_unref0 (d2);
#line 144 "GomDocumentTest.vala"
			_g_free0 (_tmp10_);
#line 144 "GomDocumentTest.vala"
			_g_object_unref0 (parser);
#line 144 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 144 "GomDocumentTest.vala"
			_g_string_free0 (s);
#line 144 "GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 1231 "GomDocumentTest.c"
			goto __catch78_g_error;
		}
#line 145 "GomDocumentTest.vala"
		_tmp27_ = d2;
#line 145 "GomDocumentTest.vala"
		_tmp28_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp27_);
#line 145 "GomDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 145 "GomDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 145 "GomDocumentTest.vala"
		_vala_assert (_tmp30_ != NULL, "d2.document_element != null");
#line 145 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp30_);
#line 146 "GomDocumentTest.vala"
		_tmp31_ = d2;
#line 146 "GomDocumentTest.vala"
		_tmp32_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp31_);
#line 146 "GomDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 146 "GomDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 146 "GomDocumentTest.vala"
		_tmp35_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp34_);
#line 146 "GomDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 146 "GomDocumentTest.vala"
		_tmp37_ = _tmp36_;
#line 146 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp37_, "document_element") == 0, "d2.document_element.node_name == \"document_element\"");
#line 146 "GomDocumentTest.vala"
		_g_free0 (_tmp37_);
#line 146 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp34_);
#line 147 "GomDocumentTest.vala"
		_tmp38_ = f;
#line 147 "GomDocumentTest.vala"
		g_file_delete (_tmp38_, NULL, &_inner_error0_);
#line 147 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 147 "GomDocumentTest.vala"
			_g_object_unref0 (d2);
#line 147 "GomDocumentTest.vala"
			_g_free0 (_tmp10_);
#line 147 "GomDocumentTest.vala"
			_g_object_unref0 (parser);
#line 147 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 147 "GomDocumentTest.vala"
			_g_string_free0 (s);
#line 147 "GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 1284 "GomDocumentTest.c"
			goto __catch78_g_error;
		}
#line 132 "GomDocumentTest.vala"
		_g_object_unref0 (d2);
#line 132 "GomDocumentTest.vala"
		_g_free0 (_tmp10_);
#line 132 "GomDocumentTest.vala"
		_g_object_unref0 (parser);
#line 132 "GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 132 "GomDocumentTest.vala"
		_g_string_free0 (s);
#line 132 "GomDocumentTest.vala"
		_g_object_unref0 (f);
#line 1299 "GomDocumentTest.c"
	}
	goto __finally78;
	__catch78_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp39_;
		gchar* _tmp40_;
		gchar* _tmp41_;
#line 132 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 132 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 149 "GomDocumentTest.vala"
		_tmp39_ = e->message;
#line 149 "GomDocumentTest.vala"
		_tmp40_ = g_strconcat ("Error: ", _tmp39_, NULL);
#line 149 "GomDocumentTest.vala"
		_tmp41_ = _tmp40_;
#line 149 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:149: %s", _tmp41_);
#line 149 "GomDocumentTest.vala"
		_g_free0 (_tmp41_);
#line 150 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 132 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 1326 "GomDocumentTest.c"
	}
	__finally78:
#line 132 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 132 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 132 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 132 "GomDocumentTest.vala"
		return;
#line 1337 "GomDocumentTest.c"
	}
}

static void
___lambda65__gtest_func (void)
{
#line 131 "GomDocumentTest.vala"
	__lambda65_ ();
#line 1346 "GomDocumentTest.c"
}

static void
__lambda66_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GFile* rf = NULL;
		GFile* _tmp0_;
		GFile* _tmp1_;
		GXmlGomDocument* d = NULL;
		GFile* _tmp2_;
		GXmlGomDocument* _tmp3_;
		GXmlGomDocument* _tmp4_;
		GXmlGomDocument* _tmp5_;
		GXmlDomElement* _tmp6_;
		GXmlDomElement* _tmp7_;
		GXmlDomElement* _tmp8_;
		GXmlGomDocument* _tmp9_;
		GXmlDomElement* _tmp10_;
		GXmlDomElement* _tmp11_;
		GXmlDomElement* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		gboolean fname = FALSE;
		gboolean fshordesc = FALSE;
		gboolean fdescription = FALSE;
		gboolean fhomepage = FALSE;
		GFile* f = NULL;
		GFile* _tmp48_;
		GXmlGomDocument* _tmp49_;
		GFile* _tmp50_;
		GFile* _tmp51_;
		GFile* _tmp52_;
#line 155 "GomDocumentTest.vala"
		_tmp0_ = g_file_new_for_uri ("https://git.gnome.org/browse/gxml/plain/gxml.doap");
#line 155 "GomDocumentTest.vala"
		rf = _tmp0_;
#line 156 "GomDocumentTest.vala"
		_tmp1_ = rf;
#line 156 "GomDocumentTest.vala"
		if (!g_file_query_exists (_tmp1_, NULL)) {
#line 157 "GomDocumentTest.vala"
			g_message ("GomDocumentTest.vala:157: No remote file available. Skiping...");
#line 158 "GomDocumentTest.vala"
			_g_object_unref0 (rf);
#line 158 "GomDocumentTest.vala"
			return;
#line 1396 "GomDocumentTest.c"
		}
#line 160 "GomDocumentTest.vala"
		_tmp2_ = rf;
#line 160 "GomDocumentTest.vala"
		_tmp3_ = gxml_gom_document_new_from_file (_tmp2_, &_inner_error0_);
#line 160 "GomDocumentTest.vala"
		d = _tmp3_;
#line 160 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 160 "GomDocumentTest.vala"
			_g_object_unref0 (rf);
#line 1408 "GomDocumentTest.c"
			goto __catch79_g_error;
		}
#line 161 "GomDocumentTest.vala"
		_tmp4_ = d;
#line 161 "GomDocumentTest.vala"
		_vala_assert (_tmp4_ != NULL, "d != null");
#line 162 "GomDocumentTest.vala"
		_tmp5_ = d;
#line 162 "GomDocumentTest.vala"
		_tmp6_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp5_);
#line 162 "GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 162 "GomDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 162 "GomDocumentTest.vala"
		_vala_assert (_tmp8_ != NULL, "d.document_element != null");
#line 162 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp8_);
#line 163 "GomDocumentTest.vala"
		_tmp9_ = d;
#line 163 "GomDocumentTest.vala"
		_tmp10_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp9_);
#line 163 "GomDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 163 "GomDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 163 "GomDocumentTest.vala"
		_tmp13_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp12_);
#line 163 "GomDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 163 "GomDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 163 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp15_, "Project") == 0, "d.document_element.node_name == \"Project\"");
#line 163 "GomDocumentTest.vala"
		_g_free0 (_tmp15_);
#line 163 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp12_);
#line 165 "GomDocumentTest.vala"
		fhomepage = FALSE;
#line 165 "GomDocumentTest.vala"
		fdescription = fhomepage;
#line 165 "GomDocumentTest.vala"
		fshordesc = fdescription;
#line 165 "GomDocumentTest.vala"
		fname = fshordesc;
#line 1455 "GomDocumentTest.c"
		{
			GXmlDomNodeList* _n_list = NULL;
			GXmlGomDocument* _tmp16_;
			GXmlDomElement* _tmp17_;
			GXmlDomElement* _tmp18_;
			GXmlDomElement* _tmp19_;
			GXmlDomNodeList* _tmp20_;
			GXmlDomNodeList* _tmp21_;
			GXmlDomNodeList* _tmp22_;
			gint _n_size = 0;
			GXmlDomNodeList* _tmp23_;
			gint _tmp24_;
			gint _tmp25_;
			gint _n_index = 0;
#line 166 "GomDocumentTest.vala"
			_tmp16_ = d;
#line 166 "GomDocumentTest.vala"
			_tmp17_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp16_);
#line 166 "GomDocumentTest.vala"
			_tmp18_ = _tmp17_;
#line 166 "GomDocumentTest.vala"
			_tmp19_ = _tmp18_;
#line 166 "GomDocumentTest.vala"
			_tmp20_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp19_);
#line 166 "GomDocumentTest.vala"
			_tmp21_ = _tmp20_;
#line 166 "GomDocumentTest.vala"
			_tmp22_ = _tmp21_;
#line 166 "GomDocumentTest.vala"
			_g_object_unref0 (_tmp19_);
#line 166 "GomDocumentTest.vala"
			_n_list = _tmp22_;
#line 166 "GomDocumentTest.vala"
			_tmp23_ = _n_list;
#line 166 "GomDocumentTest.vala"
			_tmp24_ = gee_collection_get_size ((GeeCollection*) _tmp23_);
#line 166 "GomDocumentTest.vala"
			_tmp25_ = _tmp24_;
#line 166 "GomDocumentTest.vala"
			_n_size = _tmp25_;
#line 166 "GomDocumentTest.vala"
			_n_index = -1;
#line 166 "GomDocumentTest.vala"
			while (TRUE) {
#line 1500 "GomDocumentTest.c"
				GXmlDomNode* n = NULL;
				GXmlDomNodeList* _tmp26_;
				gpointer _tmp27_;
				GXmlDomNode* _tmp28_;
				gchar* _tmp29_;
				gchar* _tmp30_;
				gchar* _tmp31_;
				gboolean _tmp32_;
				GXmlDomNode* _tmp33_;
				gchar* _tmp34_;
				gchar* _tmp35_;
				gchar* _tmp36_;
				gboolean _tmp37_;
				GXmlDomNode* _tmp38_;
				gchar* _tmp39_;
				gchar* _tmp40_;
				gchar* _tmp41_;
				gboolean _tmp42_;
				GXmlDomNode* _tmp43_;
				gchar* _tmp44_;
				gchar* _tmp45_;
				gchar* _tmp46_;
				gboolean _tmp47_;
#line 166 "GomDocumentTest.vala"
				_n_index = _n_index + 1;
#line 166 "GomDocumentTest.vala"
				if (!(_n_index < _n_size)) {
#line 166 "GomDocumentTest.vala"
					break;
#line 1530 "GomDocumentTest.c"
				}
#line 166 "GomDocumentTest.vala"
				_tmp26_ = _n_list;
#line 166 "GomDocumentTest.vala"
				_tmp27_ = gee_list_get ((GeeList*) _tmp26_, _n_index);
#line 166 "GomDocumentTest.vala"
				n = (GXmlDomNode*) _tmp27_;
#line 167 "GomDocumentTest.vala"
				_tmp28_ = n;
#line 167 "GomDocumentTest.vala"
				_tmp29_ = gxml_dom_node_get_node_name (_tmp28_);
#line 167 "GomDocumentTest.vala"
				_tmp30_ = _tmp29_;
#line 167 "GomDocumentTest.vala"
				_tmp31_ = _tmp30_;
#line 167 "GomDocumentTest.vala"
				_tmp32_ = g_strcmp0 (_tmp31_, "name") == 0;
#line 167 "GomDocumentTest.vala"
				_g_free0 (_tmp31_);
#line 167 "GomDocumentTest.vala"
				if (_tmp32_) {
#line 167 "GomDocumentTest.vala"
					fname = TRUE;
#line 1554 "GomDocumentTest.c"
				}
#line 168 "GomDocumentTest.vala"
				_tmp33_ = n;
#line 168 "GomDocumentTest.vala"
				_tmp34_ = gxml_dom_node_get_node_name (_tmp33_);
#line 168 "GomDocumentTest.vala"
				_tmp35_ = _tmp34_;
#line 168 "GomDocumentTest.vala"
				_tmp36_ = _tmp35_;
#line 168 "GomDocumentTest.vala"
				_tmp37_ = g_strcmp0 (_tmp36_, "shortdesc") == 0;
#line 168 "GomDocumentTest.vala"
				_g_free0 (_tmp36_);
#line 168 "GomDocumentTest.vala"
				if (_tmp37_) {
#line 168 "GomDocumentTest.vala"
					fshordesc = TRUE;
#line 1572 "GomDocumentTest.c"
				}
#line 169 "GomDocumentTest.vala"
				_tmp38_ = n;
#line 169 "GomDocumentTest.vala"
				_tmp39_ = gxml_dom_node_get_node_name (_tmp38_);
#line 169 "GomDocumentTest.vala"
				_tmp40_ = _tmp39_;
#line 169 "GomDocumentTest.vala"
				_tmp41_ = _tmp40_;
#line 169 "GomDocumentTest.vala"
				_tmp42_ = g_strcmp0 (_tmp41_, "description") == 0;
#line 169 "GomDocumentTest.vala"
				_g_free0 (_tmp41_);
#line 169 "GomDocumentTest.vala"
				if (_tmp42_) {
#line 169 "GomDocumentTest.vala"
					fdescription = TRUE;
#line 1590 "GomDocumentTest.c"
				}
#line 170 "GomDocumentTest.vala"
				_tmp43_ = n;
#line 170 "GomDocumentTest.vala"
				_tmp44_ = gxml_dom_node_get_node_name (_tmp43_);
#line 170 "GomDocumentTest.vala"
				_tmp45_ = _tmp44_;
#line 170 "GomDocumentTest.vala"
				_tmp46_ = _tmp45_;
#line 170 "GomDocumentTest.vala"
				_tmp47_ = g_strcmp0 (_tmp46_, "homepage") == 0;
#line 170 "GomDocumentTest.vala"
				_g_free0 (_tmp46_);
#line 170 "GomDocumentTest.vala"
				if (_tmp47_) {
#line 170 "GomDocumentTest.vala"
					fhomepage = TRUE;
#line 1608 "GomDocumentTest.c"
				}
#line 166 "GomDocumentTest.vala"
				_g_object_unref0 (n);
#line 1612 "GomDocumentTest.c"
			}
#line 166 "GomDocumentTest.vala"
			_g_object_unref0 (_n_list);
#line 1616 "GomDocumentTest.c"
		}
#line 172 "GomDocumentTest.vala"
		_vala_assert (fname, "fname");
#line 173 "GomDocumentTest.vala"
		_vala_assert (fshordesc, "fshordesc");
#line 174 "GomDocumentTest.vala"
		_vala_assert (fdescription, "fdescription");
#line 175 "GomDocumentTest.vala"
		_vala_assert (fhomepage, "fhomepage");
#line 176 "GomDocumentTest.vala"
		_tmp48_ = g_file_new_for_path (TEST_SAVE_DIR "/xml.doap");
#line 176 "GomDocumentTest.vala"
		f = _tmp48_;
#line 177 "GomDocumentTest.vala"
		_tmp49_ = d;
#line 177 "GomDocumentTest.vala"
		_tmp50_ = f;
#line 177 "GomDocumentTest.vala"
		gxml_dom_document_write_file ((GXmlDomDocument*) _tmp49_, _tmp50_, NULL, &_inner_error0_);
#line 177 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 177 "GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 177 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 177 "GomDocumentTest.vala"
			_g_object_unref0 (rf);
#line 1644 "GomDocumentTest.c"
			goto __catch79_g_error;
		}
#line 178 "GomDocumentTest.vala"
		_tmp51_ = f;
#line 178 "GomDocumentTest.vala"
		_vala_assert (g_file_query_exists (_tmp51_, NULL), "f.query_exists ()");
#line 179 "GomDocumentTest.vala"
		_tmp52_ = f;
#line 179 "GomDocumentTest.vala"
		g_file_delete (_tmp52_, NULL, &_inner_error0_);
#line 179 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 179 "GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 179 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 179 "GomDocumentTest.vala"
			_g_object_unref0 (rf);
#line 1663 "GomDocumentTest.c"
			goto __catch79_g_error;
		}
#line 154 "GomDocumentTest.vala"
		_g_object_unref0 (f);
#line 154 "GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 154 "GomDocumentTest.vala"
		_g_object_unref0 (rf);
#line 1672 "GomDocumentTest.c"
	}
	goto __finally79;
	__catch79_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp53_;
		gchar* _tmp54_;
		gchar* _tmp55_;
#line 154 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 154 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 181 "GomDocumentTest.vala"
		_tmp53_ = e->message;
#line 181 "GomDocumentTest.vala"
		_tmp54_ = g_strconcat ("Error: ", _tmp53_, NULL);
#line 181 "GomDocumentTest.vala"
		_tmp55_ = _tmp54_;
#line 181 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:181: %s", _tmp55_);
#line 181 "GomDocumentTest.vala"
		_g_free0 (_tmp55_);
#line 182 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 154 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 1699 "GomDocumentTest.c"
	}
	__finally79:
#line 154 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 154 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 154 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 154 "GomDocumentTest.vala"
		return;
#line 1710 "GomDocumentTest.c"
	}
}

static void
___lambda66__gtest_func (void)
{
#line 153 "GomDocumentTest.vala"
	__lambda66_ ();
#line 1719 "GomDocumentTest.c"
}

static gboolean
string_contains (const gchar* self,
                 const gchar* needle)
{
	gboolean result = FALSE;
	gchar* _tmp0_;
#line 1476 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1476 "glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1477 "glib-2.0.vapi"
	_tmp0_ = strstr ((gchar*) self, (gchar*) needle);
#line 1477 "glib-2.0.vapi"
	result = _tmp0_ != NULL;
#line 1477 "glib-2.0.vapi"
	return result;
#line 1738 "GomDocumentTest.c"
}

static void
__lambda67_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GFile* rf = NULL;
		GFile* _tmp0_;
		GFile* _tmp1_;
		GXmlGomDocument* d = NULL;
		GFile* _tmp2_;
		GXmlGomDocument* _tmp3_;
		GXmlGomDocument* _tmp4_;
		GXmlGomDocument* _tmp5_;
		GXmlDomElement* _tmp6_;
		GXmlDomElement* _tmp7_;
		GXmlDomElement* _tmp8_;
		GXmlXParser* parser = NULL;
		GXmlGomDocument* _tmp9_;
		GXmlXParser* _tmp10_;
		gchar* s = NULL;
		GXmlXParser* _tmp11_;
		gchar* _tmp12_;
		const gchar* _tmp13_;
		const gchar* _tmp14_;
		const gchar* _tmp15_;
		const gchar* _tmp16_;
		const gchar* _tmp17_;
#line 187 "GomDocumentTest.vala"
		_tmp0_ = g_file_new_for_uri ("https://git.gnome.org/browse/gxml/plain/gxml.doap");
#line 187 "GomDocumentTest.vala"
		rf = _tmp0_;
#line 188 "GomDocumentTest.vala"
		_tmp1_ = rf;
#line 188 "GomDocumentTest.vala"
		if (!g_file_query_exists (_tmp1_, NULL)) {
#line 189 "GomDocumentTest.vala"
			g_message ("GomDocumentTest.vala:189: No remote file available. Skiping...");
#line 190 "GomDocumentTest.vala"
			_g_object_unref0 (rf);
#line 190 "GomDocumentTest.vala"
			return;
#line 1782 "GomDocumentTest.c"
		}
#line 192 "GomDocumentTest.vala"
		_tmp2_ = rf;
#line 192 "GomDocumentTest.vala"
		_tmp3_ = gxml_gom_document_new_from_file (_tmp2_, &_inner_error0_);
#line 192 "GomDocumentTest.vala"
		d = _tmp3_;
#line 192 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 192 "GomDocumentTest.vala"
			_g_object_unref0 (rf);
#line 1794 "GomDocumentTest.c"
			goto __catch80_g_error;
		}
#line 193 "GomDocumentTest.vala"
		_tmp4_ = d;
#line 193 "GomDocumentTest.vala"
		_vala_assert (_tmp4_ != NULL, "d != null");
#line 194 "GomDocumentTest.vala"
		_tmp5_ = d;
#line 194 "GomDocumentTest.vala"
		_tmp6_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp5_);
#line 194 "GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 194 "GomDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 194 "GomDocumentTest.vala"
		_vala_assert (_tmp8_ != NULL, "d.document_element != null");
#line 194 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp8_);
#line 195 "GomDocumentTest.vala"
		_tmp9_ = d;
#line 195 "GomDocumentTest.vala"
		_tmp10_ = gxml_xparser_new ((GXmlDomNode*) _tmp9_);
#line 195 "GomDocumentTest.vala"
		parser = _tmp10_;
#line 196 "GomDocumentTest.vala"
		_tmp11_ = parser;
#line 196 "GomDocumentTest.vala"
		_tmp12_ = gxml_parser_write_string ((GXmlParser*) _tmp11_, &_inner_error0_);
#line 196 "GomDocumentTest.vala"
		s = _tmp12_;
#line 196 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 196 "GomDocumentTest.vala"
			_g_object_unref0 (parser);
#line 196 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 196 "GomDocumentTest.vala"
			_g_object_unref0 (rf);
#line 1833 "GomDocumentTest.c"
			goto __catch80_g_error;
		}
#line 200 "GomDocumentTest.vala"
		_tmp13_ = s;
#line 200 "GomDocumentTest.vala"
		_vala_assert (string_contains (_tmp13_, "<name xml:lang=\"en\">GXml</name>"), "\"<name xml:lang=\\\"en\\\">GXml</name>\" in s");
#line 201 "GomDocumentTest.vala"
		_tmp14_ = s;
#line 201 "GomDocumentTest.vala"
		_vala_assert (string_contains (_tmp14_, "<shortdesc xml:lang=\"en\">GObject XML and Serialization API</shortdes" \
"c>"), "\"<shortdesc xml:lang=\\\"en\\\">GObject XML and Serialization API</shortdesc>\" \t\t\t\t\t\t\t\tin s");
#line 203 "GomDocumentTest.vala"
		_tmp15_ = s;
#line 203 "GomDocumentTest.vala"
		_vala_assert (string_contains (_tmp15_, "<homepage rdf:resource=\"https://wiki.gnome.org/GXml\"/>"), "\"<homepage rdf:resource=\\\"https://wiki.gnome.org/GXml\\\"/>\" in s");
#line 204 "GomDocumentTest.vala"
		_tmp16_ = s;
#line 204 "GomDocumentTest.vala"
		_vala_assert (string_contains (_tmp16_, "<foaf:Person>"), "\"<foaf:Person>\" in s");
#line 205 "GomDocumentTest.vala"
		_tmp17_ = s;
#line 205 "GomDocumentTest.vala"
		_vala_assert (string_contains (_tmp17_, "<foaf:name>Daniel Espinosa</foaf:name>"), "\"<foaf:name>Daniel Espinosa</foaf:name>\" in s");
#line 186 "GomDocumentTest.vala"
		_g_free0 (s);
#line 186 "GomDocumentTest.vala"
		_g_object_unref0 (parser);
#line 186 "GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 186 "GomDocumentTest.vala"
		_g_object_unref0 (rf);
#line 1864 "GomDocumentTest.c"
	}
	goto __finally80;
	__catch80_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
#line 186 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 186 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 207 "GomDocumentTest.vala"
		_tmp18_ = e->message;
#line 207 "GomDocumentTest.vala"
		_tmp19_ = g_strconcat ("Error: ", _tmp18_, NULL);
#line 207 "GomDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 207 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:207: %s", _tmp20_);
#line 207 "GomDocumentTest.vala"
		_g_free0 (_tmp20_);
#line 208 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 186 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 1891 "GomDocumentTest.c"
	}
	__finally80:
#line 186 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 186 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 186 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 186 "GomDocumentTest.vala"
		return;
#line 1902 "GomDocumentTest.c"
	}
}

static void
___lambda67__gtest_func (void)
{
#line 185 "GomDocumentTest.vala"
	__lambda67_ ();
#line 1911 "GomDocumentTest.c"
}

static void
__lambda68_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp1_;
		GXmlDomElement* _tmp2_;
		GXmlGomDocument* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlDomNode* _tmp5_;
		GXmlDomNode* _tmp6_;
		GXmlDomElement* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		GXmlDomElement* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
		GXmlXParser* parser = NULL;
		GXmlGomDocument* _tmp15_;
		GXmlXParser* _tmp16_;
		gchar* s = NULL;
		GXmlXParser* _tmp17_;
		gchar* _tmp18_;
		const gchar* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		const gchar* _tmp22_;
		GXmlGomDocument* _tmp23_;
		GXmlDomElement* _tmp24_;
		GXmlDomElement* _tmp25_;
		GXmlDomElement* _tmp26_;
#line 213 "GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new ();
#line 213 "GomDocumentTest.vala"
		doc = _tmp0_;
#line 214 "GomDocumentTest.vala"
		_tmp1_ = doc;
#line 214 "GomDocumentTest.vala"
		_tmp2_ = gxml_dom_document_create_element_ns ((GXmlDomDocument*) _tmp1_, "http://live.gnome.org/GXml", "root", &_inner_error0_);
#line 214 "GomDocumentTest.vala"
		r = _tmp2_;
#line 214 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 214 "GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 1964 "GomDocumentTest.c"
			goto __catch81_g_error;
		}
#line 215 "GomDocumentTest.vala"
		_tmp3_ = doc;
#line 215 "GomDocumentTest.vala"
		_tmp4_ = r;
#line 215 "GomDocumentTest.vala"
		_tmp5_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp3_, (GXmlDomNode*) _tmp4_, &_inner_error0_);
#line 215 "GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 215 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp6_);
#line 215 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 215 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 215 "GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 1983 "GomDocumentTest.c"
			goto __catch81_g_error;
		}
#line 216 "GomDocumentTest.vala"
		_tmp7_ = r;
#line 216 "GomDocumentTest.vala"
		_tmp8_ = gxml_dom_element_get_prefix (_tmp7_);
#line 216 "GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 216 "GomDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 216 "GomDocumentTest.vala"
		_vala_assert (_tmp10_ == NULL, "r.prefix == null");
#line 216 "GomDocumentTest.vala"
		_g_free0 (_tmp10_);
#line 217 "GomDocumentTest.vala"
		_tmp11_ = r;
#line 217 "GomDocumentTest.vala"
		_tmp12_ = gxml_dom_element_get_namespace_uri (_tmp11_);
#line 217 "GomDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 217 "GomDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 217 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp14_, "http://live.gnome.org/GXml") == 0, "r.namespace_uri == \"http://live.gnome.org/GXml\"");
#line 217 "GomDocumentTest.vala"
		_g_free0 (_tmp14_);
#line 218 "GomDocumentTest.vala"
		_tmp15_ = doc;
#line 218 "GomDocumentTest.vala"
		_tmp16_ = gxml_xparser_new ((GXmlDomNode*) _tmp15_);
#line 218 "GomDocumentTest.vala"
		parser = _tmp16_;
#line 219 "GomDocumentTest.vala"
		_tmp17_ = parser;
#line 219 "GomDocumentTest.vala"
		_tmp18_ = gxml_parser_write_string ((GXmlParser*) _tmp17_, &_inner_error0_);
#line 219 "GomDocumentTest.vala"
		s = _tmp18_;
#line 219 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 219 "GomDocumentTest.vala"
			_g_object_unref0 (parser);
#line 219 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 219 "GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 2030 "GomDocumentTest.c"
			goto __catch81_g_error;
		}
#line 220 "GomDocumentTest.vala"
		_tmp19_ = s;
#line 220 "GomDocumentTest.vala"
		_tmp20_ = g_strconcat ("DOC: ", _tmp19_, NULL);
#line 220 "GomDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 220 "GomDocumentTest.vala"
		g_test_message ("%s", _tmp21_);
#line 220 "GomDocumentTest.vala"
		_g_free0 (_tmp21_);
#line 221 "GomDocumentTest.vala"
		_tmp22_ = s;
#line 221 "GomDocumentTest.vala"
		_vala_assert (string_contains (_tmp22_, "<root xmlns=\"http://live.gnome.org/GXml\"/>"), "\"<root xmlns=\\\"http://live.gnome.org/GXml\\\"/>\" in s");
#line 222 "GomDocumentTest.vala"
		_tmp23_ = doc;
#line 222 "GomDocumentTest.vala"
		_tmp24_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp23_);
#line 222 "GomDocumentTest.vala"
		_tmp25_ = _tmp24_;
#line 222 "GomDocumentTest.vala"
		_tmp26_ = _tmp25_;
#line 222 "GomDocumentTest.vala"
		gxml_dom_element_set_attribute_ns (_tmp26_, "http://www.w3.org/2000/xmlns/", "xmlns", "http://live.gnome.org/GXml", &_inner_error0_);
#line 222 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp26_);
#line 222 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 222 "GomDocumentTest.vala"
			_g_free0 (s);
#line 222 "GomDocumentTest.vala"
			_g_object_unref0 (parser);
#line 222 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 222 "GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 2069 "GomDocumentTest.c"
			goto __catch81_g_error;
		}
#line 212 "GomDocumentTest.vala"
		_g_free0 (s);
#line 212 "GomDocumentTest.vala"
		_g_object_unref0 (parser);
#line 212 "GomDocumentTest.vala"
		_g_object_unref0 (r);
#line 212 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 2080 "GomDocumentTest.c"
	}
	goto __finally81;
	__catch81_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
#line 212 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 212 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 226 "GomDocumentTest.vala"
		_tmp27_ = e->message;
#line 226 "GomDocumentTest.vala"
		_tmp28_ = g_strconcat ("Error: ", _tmp27_, NULL);
#line 226 "GomDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 226 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:226: %s", _tmp29_);
#line 226 "GomDocumentTest.vala"
		_g_free0 (_tmp29_);
#line 227 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 212 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 2107 "GomDocumentTest.c"
	}
	__finally81:
#line 212 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 212 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 212 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 212 "GomDocumentTest.vala"
		return;
#line 2118 "GomDocumentTest.c"
	}
}

static void
___lambda68__gtest_func (void)
{
#line 211 "GomDocumentTest.vala"
	__lambda68_ ();
#line 2127 "GomDocumentTest.c"
}

static void
__lambda69_ (void)
{
	GFile* fin = NULL;
	GFileIOStream* iostream = NULL;
	GXmlDomDocument* doc = NULL;
	GError* _inner_error0_ = NULL;
	{
		GFile* _tmp0_ = NULL;
		GFileIOStream* _tmp1_ = NULL;
		GFile* _tmp2_;
		GFile* _tmp3_;
		GXmlGomDocument* _tmp4_ = NULL;
		GFileIOStream* _tmp5_;
		GInputStream* _tmp6_;
		GInputStream* _tmp7_;
		GXmlGomDocument* _tmp8_;
		GXmlGomDocument* _tmp9_;
#line 236 "GomDocumentTest.vala"
		_tmp2_ = g_file_new_tmp ("gxml.XXXXXX", &_tmp1_, &_inner_error0_);
#line 236 "GomDocumentTest.vala"
		_g_object_unref0 (iostream);
#line 236 "GomDocumentTest.vala"
		iostream = _tmp1_;
#line 236 "GomDocumentTest.vala"
		_tmp0_ = _tmp2_;
#line 236 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2158 "GomDocumentTest.c"
			goto __catch82_g_error;
		}
#line 236 "GomDocumentTest.vala"
		_tmp3_ = _tmp0_;
#line 236 "GomDocumentTest.vala"
		_tmp0_ = NULL;
#line 236 "GomDocumentTest.vala"
		_g_object_unref0 (fin);
#line 236 "GomDocumentTest.vala"
		fin = _tmp3_;
#line 237 "GomDocumentTest.vala"
		_tmp5_ = iostream;
#line 237 "GomDocumentTest.vala"
		_tmp6_ = g_io_stream_get_input_stream ((GIOStream*) _tmp5_);
#line 237 "GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 237 "GomDocumentTest.vala"
		_tmp8_ = gxml_gom_document_new_from_stream (_tmp7_, &_inner_error0_);
#line 237 "GomDocumentTest.vala"
		_tmp4_ = _tmp8_;
#line 237 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 237 "GomDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 2183 "GomDocumentTest.c"
			goto __catch82_g_error;
		}
#line 237 "GomDocumentTest.vala"
		_tmp9_ = _tmp4_;
#line 237 "GomDocumentTest.vala"
		_tmp4_ = NULL;
#line 237 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 237 "GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp9_;
#line 238 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:238: Passed parse error stream");
#line 239 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 235 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp4_);
#line 235 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 2202 "GomDocumentTest.c"
	}
	goto __finally82;
	__catch82_g_error:
	{
#line 235 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 235 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 2211 "GomDocumentTest.c"
	}
	__finally82:
#line 235 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 235 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 235 "GomDocumentTest.vala"
		_g_object_unref0 (iostream);
#line 235 "GomDocumentTest.vala"
		_g_object_unref0 (fin);
#line 235 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 235 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 235 "GomDocumentTest.vala"
		return;
#line 2228 "GomDocumentTest.c"
	}
#line 230 "GomDocumentTest.vala"
	_g_object_unref0 (doc);
#line 230 "GomDocumentTest.vala"
	_g_object_unref0 (iostream);
#line 230 "GomDocumentTest.vala"
	_g_object_unref0 (fin);
#line 2236 "GomDocumentTest.c"
}

static void
___lambda69__gtest_func (void)
{
#line 230 "GomDocumentTest.vala"
	__lambda69_ ();
#line 2244 "GomDocumentTest.c"
}

static void
__lambda70_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		gchar* xml = NULL;
		GXmlDomDocument* doc = NULL;
		GXmlDomNode* document_element = NULL;
		gchar* _tmp0_;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_;
		GXmlGomDocument* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlDomElement* _tmp5_;
		GXmlDomElement* _tmp6_;
		GXmlDomElement* _tmp7_;
		GXmlDomElement* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		GXmlDomNodeList* _tmp12_;
		GXmlDomNodeList* _tmp13_;
		GXmlDomNodeList* _tmp14_;
		gint _tmp15_;
		gint _tmp16_;
		GXmlDomNode* n1 = NULL;
		GXmlDomNodeList* _tmp17_;
		GXmlDomNodeList* _tmp18_;
		GXmlDomNodeList* _tmp19_;
		gpointer _tmp20_;
		GXmlDomNode* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
#line 248 "GomDocumentTest.vala"
		_tmp0_ = g_strdup ("<Fruits><Apple></Apple><Orange></Orange></Fruits>");
#line 248 "GomDocumentTest.vala"
		_g_free0 (xml);
#line 248 "GomDocumentTest.vala"
		xml = _tmp0_;
#line 249 "GomDocumentTest.vala"
		_tmp2_ = gxml_gom_document_new_from_string (xml, &_inner_error0_);
#line 249 "GomDocumentTest.vala"
		_tmp1_ = _tmp2_;
#line 249 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 249 "GomDocumentTest.vala"
			_g_object_unref0 (document_element);
#line 249 "GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 249 "GomDocumentTest.vala"
			_g_free0 (xml);
#line 2299 "GomDocumentTest.c"
			goto __catch83_g_error;
		}
#line 249 "GomDocumentTest.vala"
		_tmp3_ = _tmp1_;
#line 249 "GomDocumentTest.vala"
		_tmp1_ = NULL;
#line 249 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 249 "GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp3_;
#line 250 "GomDocumentTest.vala"
		_tmp4_ = gxml_dom_document_get_document_element (doc);
#line 250 "GomDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 250 "GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 250 "GomDocumentTest.vala"
		_vala_assert (_tmp6_ != NULL, "doc.document_element != null");
#line 250 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp6_);
#line 251 "GomDocumentTest.vala"
		_tmp7_ = gxml_dom_document_get_document_element (doc);
#line 251 "GomDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 251 "GomDocumentTest.vala"
		_g_object_unref0 (document_element);
#line 251 "GomDocumentTest.vala"
		document_element = (GXmlDomNode*) _tmp8_;
#line 252 "GomDocumentTest.vala"
		_tmp9_ = gxml_dom_node_get_node_name (document_element);
#line 252 "GomDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 252 "GomDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 252 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp11_, "Fruits") == 0, "document_element.node_name == \"Fruits\"");
#line 252 "GomDocumentTest.vala"
		_g_free0 (_tmp11_);
#line 253 "GomDocumentTest.vala"
		_tmp12_ = gxml_dom_node_get_child_nodes (document_element);
#line 253 "GomDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 253 "GomDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 253 "GomDocumentTest.vala"
		_tmp15_ = gee_collection_get_size ((GeeCollection*) _tmp14_);
#line 253 "GomDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 253 "GomDocumentTest.vala"
		_vala_assert (_tmp16_ == 2, "document_element.child_nodes.size == 2");
#line 253 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp14_);
#line 254 "GomDocumentTest.vala"
		_tmp17_ = gxml_dom_node_get_child_nodes (document_element);
#line 254 "GomDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 254 "GomDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 254 "GomDocumentTest.vala"
		_tmp20_ = gee_list_get ((GeeList*) _tmp19_, 0);
#line 254 "GomDocumentTest.vala"
		_tmp21_ = (GXmlDomNode*) _tmp20_;
#line 254 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp19_);
#line 254 "GomDocumentTest.vala"
		n1 = _tmp21_;
#line 255 "GomDocumentTest.vala"
		_vala_assert (n1 != NULL, "n1 != null");
#line 256 "GomDocumentTest.vala"
		_tmp22_ = gxml_dom_node_get_node_name (n1);
#line 256 "GomDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 256 "GomDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 256 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp24_, "Apple") == 0, "n1.node_name == \"Apple\"");
#line 256 "GomDocumentTest.vala"
		_g_free0 (_tmp24_);
#line 243 "GomDocumentTest.vala"
		_g_object_unref0 (n1);
#line 243 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 243 "GomDocumentTest.vala"
		_g_object_unref0 (document_element);
#line 243 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 243 "GomDocumentTest.vala"
		_g_free0 (xml);
#line 2388 "GomDocumentTest.c"
	}
	goto __finally83;
	__catch83_g_error:
	{
#line 243 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 243 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 257 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 2399 "GomDocumentTest.c"
	}
	__finally83:
#line 243 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 243 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 243 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 243 "GomDocumentTest.vala"
		return;
#line 2410 "GomDocumentTest.c"
	}
}

static void
___lambda70__gtest_func (void)
{
#line 242 "GomDocumentTest.vala"
	__lambda70_ ();
#line 2419 "GomDocumentTest.c"
}

static void
__lambda71_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		gchar* xml = NULL;
		GXmlGomDocument* doc = NULL;
		GXmlDomNode* document_element = NULL;
		gchar* _tmp0_;
		GXmlGomDocument* _tmp1_;
		GXmlDomElement* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlDomElement* _tmp5_;
		GXmlDomElement* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		GXmlDomNodeList* _tmp10_;
		GXmlDomNodeList* _tmp11_;
		GXmlDomNodeList* _tmp12_;
		gint _tmp13_;
		gint _tmp14_;
		GXmlDomNode* n1 = NULL;
		GXmlDomNodeList* _tmp15_;
		GXmlDomNodeList* _tmp16_;
		GXmlDomNodeList* _tmp17_;
		gpointer _tmp18_;
		GXmlDomNode* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
#line 265 "GomDocumentTest.vala"
		_tmp0_ = g_strdup ("<Fruits><Apple></Apple><Orange></Orange></Fruits>");
#line 265 "GomDocumentTest.vala"
		_g_free0 (xml);
#line 265 "GomDocumentTest.vala"
		xml = _tmp0_;
#line 266 "GomDocumentTest.vala"
		_tmp1_ = gxml_gom_document_new ();
#line 266 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 266 "GomDocumentTest.vala"
		doc = _tmp1_;
#line 267 "GomDocumentTest.vala"
		gxml_dom_document_read_from_string ((GXmlDomDocument*) doc, xml, NULL, &_inner_error0_);
#line 267 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 267 "GomDocumentTest.vala"
			_g_object_unref0 (document_element);
#line 267 "GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 267 "GomDocumentTest.vala"
			_g_free0 (xml);
#line 2476 "GomDocumentTest.c"
			goto __catch84_g_error;
		}
#line 268 "GomDocumentTest.vala"
		_tmp2_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 268 "GomDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 268 "GomDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 268 "GomDocumentTest.vala"
		_vala_assert (_tmp4_ != NULL, "doc.document_element != null");
#line 268 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp4_);
#line 269 "GomDocumentTest.vala"
		_tmp5_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 269 "GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 269 "GomDocumentTest.vala"
		_g_object_unref0 (document_element);
#line 269 "GomDocumentTest.vala"
		document_element = (GXmlDomNode*) _tmp6_;
#line 270 "GomDocumentTest.vala"
		_tmp7_ = gxml_dom_node_get_node_name (document_element);
#line 270 "GomDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 270 "GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 270 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp9_, "Fruits") == 0, "document_element.node_name == \"Fruits\"");
#line 270 "GomDocumentTest.vala"
		_g_free0 (_tmp9_);
#line 271 "GomDocumentTest.vala"
		_tmp10_ = gxml_dom_node_get_child_nodes (document_element);
#line 271 "GomDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 271 "GomDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 271 "GomDocumentTest.vala"
		_tmp13_ = gee_collection_get_size ((GeeCollection*) _tmp12_);
#line 271 "GomDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 271 "GomDocumentTest.vala"
		_vala_assert (_tmp14_ == 2, "document_element.child_nodes.size == 2");
#line 271 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp12_);
#line 272 "GomDocumentTest.vala"
		_tmp15_ = gxml_dom_node_get_child_nodes (document_element);
#line 272 "GomDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 272 "GomDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 272 "GomDocumentTest.vala"
		_tmp18_ = gee_list_get ((GeeList*) _tmp17_, 0);
#line 272 "GomDocumentTest.vala"
		_tmp19_ = (GXmlDomNode*) _tmp18_;
#line 272 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp17_);
#line 272 "GomDocumentTest.vala"
		n1 = _tmp19_;
#line 273 "GomDocumentTest.vala"
		_vala_assert (n1 != NULL, "n1 != null");
#line 274 "GomDocumentTest.vala"
		_tmp20_ = gxml_dom_node_get_node_name (n1);
#line 274 "GomDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 274 "GomDocumentTest.vala"
		_tmp22_ = _tmp21_;
#line 274 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp22_, "Apple") == 0, "n1.node_name == \"Apple\"");
#line 274 "GomDocumentTest.vala"
		_g_free0 (_tmp22_);
#line 260 "GomDocumentTest.vala"
		_g_object_unref0 (n1);
#line 260 "GomDocumentTest.vala"
		_g_object_unref0 (document_element);
#line 260 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 260 "GomDocumentTest.vala"
		_g_free0 (xml);
#line 2555 "GomDocumentTest.c"
	}
	goto __finally84;
	__catch84_g_error:
	{
#line 260 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 260 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 275 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 2566 "GomDocumentTest.c"
	}
	__finally84:
#line 260 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 260 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 260 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 260 "GomDocumentTest.vala"
		return;
#line 2577 "GomDocumentTest.c"
	}
}

static void
___lambda71__gtest_func (void)
{
#line 259 "GomDocumentTest.vala"
	__lambda71_ ();
#line 2586 "GomDocumentTest.c"
}

static void
__lambda72_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		gchar* xml = NULL;
		GXmlDomDocument* doc = NULL;
		gchar* _tmp0_;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_;
		GXmlGomDocument* _tmp3_;
#line 282 "GomDocumentTest.vala"
		_tmp0_ = g_strdup ("<?xml version=\"1.0\"?>");
#line 282 "GomDocumentTest.vala"
		_g_free0 (xml);
#line 282 "GomDocumentTest.vala"
		xml = _tmp0_;
#line 283 "GomDocumentTest.vala"
		_tmp2_ = gxml_gom_document_new_from_string (xml, &_inner_error0_);
#line 283 "GomDocumentTest.vala"
		_tmp1_ = _tmp2_;
#line 283 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 283 "GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 283 "GomDocumentTest.vala"
			_g_free0 (xml);
#line 2616 "GomDocumentTest.c"
			goto __catch85_g_error;
		}
#line 283 "GomDocumentTest.vala"
		_tmp3_ = _tmp1_;
#line 283 "GomDocumentTest.vala"
		_tmp1_ = NULL;
#line 283 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 283 "GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp3_;
#line 284 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 278 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 278 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 278 "GomDocumentTest.vala"
		_g_free0 (xml);
#line 2635 "GomDocumentTest.c"
	}
	goto __finally85;
	__catch85_g_error:
	{
#line 278 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 278 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 2644 "GomDocumentTest.c"
	}
	__finally85:
#line 278 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 278 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 278 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 278 "GomDocumentTest.vala"
		return;
#line 2655 "GomDocumentTest.c"
	}
}

static void
___lambda72__gtest_func (void)
{
#line 277 "GomDocumentTest.vala"
	__lambda72_ ();
#line 2664 "GomDocumentTest.c"
}

static void
__lambda73_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		gchar* xml = NULL;
		GXmlDomDocument* doc = NULL;
		gchar* _tmp0_;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_;
		GXmlGomDocument* _tmp3_;
#line 292 "GomDocumentTest.vala"
		_tmp0_ = g_strdup ("");
#line 292 "GomDocumentTest.vala"
		_g_free0 (xml);
#line 292 "GomDocumentTest.vala"
		xml = _tmp0_;
#line 293 "GomDocumentTest.vala"
		_tmp2_ = gxml_gom_document_new_from_string (xml, &_inner_error0_);
#line 293 "GomDocumentTest.vala"
		_tmp1_ = _tmp2_;
#line 293 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 293 "GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 293 "GomDocumentTest.vala"
			_g_free0 (xml);
#line 2694 "GomDocumentTest.c"
			goto __catch86_g_error;
		}
#line 293 "GomDocumentTest.vala"
		_tmp3_ = _tmp1_;
#line 293 "GomDocumentTest.vala"
		_tmp1_ = NULL;
#line 293 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 293 "GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp3_;
#line 294 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 288 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 288 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 288 "GomDocumentTest.vala"
		_g_free0 (xml);
#line 2713 "GomDocumentTest.c"
	}
	goto __finally86;
	__catch86_g_error:
	{
#line 288 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 288 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 2722 "GomDocumentTest.c"
	}
	__finally86:
#line 288 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 288 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 288 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 288 "GomDocumentTest.vala"
		return;
#line 2733 "GomDocumentTest.c"
	}
}

static void
___lambda73__gtest_func (void)
{
#line 287 "GomDocumentTest.vala"
	__lambda73_ ();
#line 2742 "GomDocumentTest.c"
}

static void
__lambda74_ (void)
{
	GXmlDomDocument* doc = NULL;
	GError* _inner_error0_ = NULL;
	{
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_;
		GXmlGomDocument* _tmp2_;
		GFile* f = NULL;
		GFile* _tmp3_;
		GXmlDomDocument* _tmp4_;
		GFile* _tmp5_;
		GFile* _tmp6_;
		GFile* _tmp7_;
#line 301 "GomDocumentTest.vala"
		_tmp1_ = gxml_gom_document_new_from_string ("<document_element />", &_inner_error0_);
#line 301 "GomDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 301 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2766 "GomDocumentTest.c"
			goto __catch87_g_error;
		}
#line 301 "GomDocumentTest.vala"
		_tmp2_ = _tmp0_;
#line 301 "GomDocumentTest.vala"
		_tmp0_ = NULL;
#line 301 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 301 "GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp2_;
#line 302 "GomDocumentTest.vala"
		_tmp3_ = g_file_new_for_path (TEST_SAVE_DIR "/test_out_path.xml");
#line 302 "GomDocumentTest.vala"
		f = _tmp3_;
#line 303 "GomDocumentTest.vala"
		_tmp4_ = doc;
#line 303 "GomDocumentTest.vala"
		_tmp5_ = f;
#line 303 "GomDocumentTest.vala"
		gxml_dom_document_write_file ((GXmlDomDocument*) (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GXML_TYPE_GOM_DOCUMENT) ? ((GXmlGomDocument*) _tmp4_) : NULL), _tmp5_, NULL, &_inner_error0_);
#line 303 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 303 "GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 303 "GomDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 2793 "GomDocumentTest.c"
			goto __catch87_g_error;
		}
#line 304 "GomDocumentTest.vala"
		_tmp6_ = f;
#line 304 "GomDocumentTest.vala"
		_vala_assert (g_file_query_exists (_tmp6_, NULL), "f.query_exists ()");
#line 305 "GomDocumentTest.vala"
		_tmp7_ = f;
#line 305 "GomDocumentTest.vala"
		g_file_delete (_tmp7_, NULL, &_inner_error0_);
#line 305 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 305 "GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 305 "GomDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 2810 "GomDocumentTest.c"
			goto __catch87_g_error;
		}
#line 300 "GomDocumentTest.vala"
		_g_object_unref0 (f);
#line 300 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 2817 "GomDocumentTest.c"
	}
	goto __finally87;
	__catch87_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp8_;
#line 300 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 300 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 307 "GomDocumentTest.vala"
		_tmp8_ = e->message;
#line 307 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:307: %s", _tmp8_);
#line 308 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 300 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 2836 "GomDocumentTest.c"
	}
	__finally87:
#line 300 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 300 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 300 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 300 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 300 "GomDocumentTest.vala"
		return;
#line 2849 "GomDocumentTest.c"
	}
#line 297 "GomDocumentTest.vala"
	_g_object_unref0 (doc);
#line 2853 "GomDocumentTest.c"
}

static void
___lambda74__gtest_func (void)
{
#line 297 "GomDocumentTest.vala"
	__lambda74_ ();
#line 2861 "GomDocumentTest.c"
}

static void
__lambda75_ (void)
{
	GXmlDomDocument* doc = NULL;
	GError* _inner_error0_ = NULL;
	{
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_;
		GXmlGomDocument* _tmp2_;
		GXmlDomDocument* _tmp3_;
		GFile* _tmp4_;
		GFile* _tmp5_;
#line 315 "GomDocumentTest.vala"
		_tmp1_ = gxml_gom_document_new_from_string ("<document_element />", &_inner_error0_);
#line 315 "GomDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 315 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2882 "GomDocumentTest.c"
			goto __catch88_g_error;
		}
#line 315 "GomDocumentTest.vala"
		_tmp2_ = _tmp0_;
#line 315 "GomDocumentTest.vala"
		_tmp0_ = NULL;
#line 315 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 315 "GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp2_;
#line 316 "GomDocumentTest.vala"
		_tmp3_ = doc;
#line 316 "GomDocumentTest.vala"
		_tmp4_ = g_file_new_for_path ("/tmp/a/b/c/d/e/f/g/h/i");
#line 316 "GomDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 316 "GomDocumentTest.vala"
		gxml_dom_document_write_file ((GXmlDomDocument*) (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_GOM_DOCUMENT) ? ((GXmlGomDocument*) _tmp3_) : NULL), _tmp5_, NULL, &_inner_error0_);
#line 316 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp5_);
#line 316 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 316 "GomDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 2907 "GomDocumentTest.c"
			goto __catch88_g_error;
		}
#line 317 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 314 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 2914 "GomDocumentTest.c"
	}
	goto __finally88;
	__catch88_g_error:
	{
#line 314 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 314 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 2923 "GomDocumentTest.c"
	}
	__finally88:
#line 314 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 314 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 314 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 314 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 314 "GomDocumentTest.vala"
		return;
#line 2936 "GomDocumentTest.c"
	}
#line 311 "GomDocumentTest.vala"
	_g_object_unref0 (doc);
#line 2940 "GomDocumentTest.c"
}

static void
___lambda75__gtest_func (void)
{
#line 311 "GomDocumentTest.vala"
	__lambda75_ ();
#line 2948 "GomDocumentTest.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 325 "GomDocumentTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 2956 "GomDocumentTest.c"
}

static void
__lambda76_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlDomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlDomElement* elem = NULL;
		GXmlDomElement* _tmp1_ = NULL;
		GXmlDomDocument* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlDomElement* _tmp5_;
		GXmlDomElement* _tmp6_;
		GXmlDomElement* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		GXmlDomElement* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
		GXmlDomElement* _tmp15_ = NULL;
		GXmlDomDocument* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlDomElement* _tmp18_;
#line 323 "GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<document_element />", &_inner_error0_);
#line 323 "GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp0_;
#line 323 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2991 "GomDocumentTest.c"
			goto __catch89_g_error;
		}
#line 324 "GomDocumentTest.vala"
		elem = NULL;
#line 325 "GomDocumentTest.vala"
		_tmp2_ = doc;
#line 325 "GomDocumentTest.vala"
		_tmp3_ = gxml_dom_document_create_element (_tmp2_, "Banana", &_inner_error0_);
#line 325 "GomDocumentTest.vala"
		_tmp1_ = _tmp3_;
#line 325 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 325 "GomDocumentTest.vala"
			_g_object_unref0 (elem);
#line 325 "GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 3008 "GomDocumentTest.c"
			goto __catch89_g_error;
		}
#line 325 "GomDocumentTest.vala"
		_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement));
#line 325 "GomDocumentTest.vala"
		_g_object_unref0 (elem);
#line 325 "GomDocumentTest.vala"
		elem = _tmp4_;
#line 326 "GomDocumentTest.vala"
		_tmp5_ = elem;
#line 326 "GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GXML_TYPE_DOM_ELEMENT), "elem is DomElement");
#line 327 "GomDocumentTest.vala"
		_tmp6_ = elem;
#line 327 "GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, GXML_TYPE_GOM_ELEMENT), "elem is GomElement");
#line 328 "GomDocumentTest.vala"
		_tmp7_ = elem;
#line 328 "GomDocumentTest.vala"
		_tmp8_ = gxml_dom_element_get_tag_name (_tmp7_);
#line 328 "GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 328 "GomDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 328 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp10_, "Banana") == 0, "elem.tag_name == \"Banana\"");
#line 328 "GomDocumentTest.vala"
		_g_free0 (_tmp10_);
#line 329 "GomDocumentTest.vala"
		_tmp11_ = elem;
#line 329 "GomDocumentTest.vala"
		_tmp12_ = gxml_dom_element_get_tag_name (_tmp11_);
#line 329 "GomDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 329 "GomDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 329 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp14_, "banana") != 0, "elem.tag_name != \"banana\"");
#line 329 "GomDocumentTest.vala"
		_g_free0 (_tmp14_);
#line 331 "GomDocumentTest.vala"
		_tmp16_ = doc;
#line 331 "GomDocumentTest.vala"
		_tmp17_ = gxml_dom_document_create_element (_tmp16_, "ØÏØÏØ¯ÏØÏ  ²øœ³¤ïØ£", &_inner_error0_);
#line 331 "GomDocumentTest.vala"
		_tmp15_ = _tmp17_;
#line 331 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 331 "GomDocumentTest.vala"
			_g_object_unref0 (_tmp1_);
#line 331 "GomDocumentTest.vala"
			_g_object_unref0 (elem);
#line 331 "GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 3063 "GomDocumentTest.c"
			goto __catch89_g_error;
		}
#line 331 "GomDocumentTest.vala"
		_tmp18_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement));
#line 331 "GomDocumentTest.vala"
		_g_object_unref0 (elem);
#line 331 "GomDocumentTest.vala"
		elem = _tmp18_;
#line 322 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 322 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 322 "GomDocumentTest.vala"
		_g_object_unref0 (elem);
#line 322 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 3080 "GomDocumentTest.c"
	}
	goto __finally89;
	__catch89_g_error:
	{
#line 322 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 322 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 332 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 3091 "GomDocumentTest.c"
	}
	__finally89:
#line 322 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 322 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 322 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 322 "GomDocumentTest.vala"
		return;
#line 3102 "GomDocumentTest.c"
	}
}

static void
___lambda76__gtest_func (void)
{
#line 321 "GomDocumentTest.vala"
	__lambda76_ ();
#line 3111 "GomDocumentTest.c"
}

static void
__lambda77_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlDomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlDomText* _tmp1_ = NULL;
		GXmlDomDocument* _tmp2_;
		GXmlDomText* _tmp3_;
		GXmlDomText* text = NULL;
		GXmlDomText* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
#line 336 "GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<document_element />", &_inner_error0_);
#line 336 "GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp0_;
#line 336 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 3138 "GomDocumentTest.c"
			goto __catch90_g_error;
		}
#line 337 "GomDocumentTest.vala"
		_tmp2_ = doc;
#line 337 "GomDocumentTest.vala"
		_tmp3_ = gxml_dom_document_create_text_node (_tmp2_, "Star of my dreams", &_inner_error0_);
#line 337 "GomDocumentTest.vala"
		_tmp1_ = _tmp3_;
#line 337 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 337 "GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 3151 "GomDocumentTest.c"
			goto __catch90_g_error;
		}
#line 337 "GomDocumentTest.vala"
		_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_DOM_TEXT, GXmlDomText));
#line 337 "GomDocumentTest.vala"
		text = _tmp4_;
#line 338 "GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (text, GXML_TYPE_GOM_TEXT), "text is GomText");
#line 339 "GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (text, GXML_TYPE_DOM_TEXT), "text is DomText");
#line 341 "GomDocumentTest.vala"
		_tmp5_ = gxml_dom_node_get_node_name ((GXmlDomNode*) text);
#line 341 "GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 341 "GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 341 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "#text") == 0, "text.node_name == \"#text\"");
#line 341 "GomDocumentTest.vala"
		_g_free0 (_tmp7_);
#line 342 "GomDocumentTest.vala"
		_tmp8_ = gxml_dom_node_get_node_value ((GXmlDomNode*) text);
#line 342 "GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 342 "GomDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 342 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp10_, "Star of my dreams") == 0, "text.node_value == \"Star of my dreams\"");
#line 342 "GomDocumentTest.vala"
		_g_free0 (_tmp10_);
#line 335 "GomDocumentTest.vala"
		_g_object_unref0 (text);
#line 335 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 335 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 3188 "GomDocumentTest.c"
	}
	goto __finally90;
	__catch90_g_error:
	{
#line 335 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 335 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 343 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 3199 "GomDocumentTest.c"
	}
	__finally90:
#line 335 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 335 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 335 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 335 "GomDocumentTest.vala"
		return;
#line 3210 "GomDocumentTest.c"
	}
}

static void
___lambda77__gtest_func (void)
{
#line 334 "GomDocumentTest.vala"
	__lambda77_ ();
#line 3219 "GomDocumentTest.c"
}

static void
__lambda78_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlDomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlDomElement* r = NULL;
		GXmlDomElement* _tmp1_;
		GXmlDomElement* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		GXmlDomNodeList* _tmp6_;
		GXmlDomNodeList* _tmp7_;
		GXmlDomNodeList* _tmp8_;
		gint _tmp9_;
		gint _tmp10_;
		GXmlDomNodeList* _tmp11_;
		GXmlDomNodeList* _tmp12_;
		GXmlDomNodeList* _tmp13_;
		GXmlDomNode* _tmp14_;
		GXmlDomNode* _tmp15_;
		GXmlDomNodeList* _tmp16_;
		GXmlDomNodeList* _tmp17_;
		GXmlDomNodeList* _tmp18_;
		GXmlDomNode* _tmp19_;
		GXmlDomNode* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
#line 347 "GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<document_element />", &_inner_error0_);
#line 347 "GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp0_;
#line 347 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 3259 "GomDocumentTest.c"
			goto __catch91_g_error;
		}
#line 348 "GomDocumentTest.vala"
		_tmp1_ = gxml_dom_document_get_document_element (doc);
#line 348 "GomDocumentTest.vala"
		_tmp2_ = _tmp1_;
#line 348 "GomDocumentTest.vala"
		r = _tmp2_;
#line 349 "GomDocumentTest.vala"
		_vala_assert (r != NULL, "r != null");
#line 350 "GomDocumentTest.vala"
		_tmp3_ = gxml_dom_node_get_text_content ((GXmlDomNode*) r);
#line 350 "GomDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 350 "GomDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 350 "GomDocumentTest.vala"
		_vala_assert (_tmp5_ == NULL, "r.text_content == null");
#line 350 "GomDocumentTest.vala"
		_g_free0 (_tmp5_);
#line 351 "GomDocumentTest.vala"
		gxml_dom_node_set_text_content ((GXmlDomNode*) r, "Starting");
#line 352 "GomDocumentTest.vala"
		_tmp6_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) r);
#line 352 "GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 352 "GomDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 352 "GomDocumentTest.vala"
		_tmp9_ = gxml_dom_node_list_get_length (_tmp8_);
#line 352 "GomDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 352 "GomDocumentTest.vala"
		_vala_assert (_tmp10_ == 1, "r.child_nodes.length == 1");
#line 352 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp8_);
#line 353 "GomDocumentTest.vala"
		_tmp11_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) r);
#line 353 "GomDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 353 "GomDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 353 "GomDocumentTest.vala"
		_tmp14_ = gxml_dom_node_list_item (_tmp13_, 0);
#line 353 "GomDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 353 "GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GXML_TYPE_DOM_TEXT), "r.child_nodes.item (0) is DomText");
#line 353 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 353 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp13_);
#line 354 "GomDocumentTest.vala"
		_tmp16_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) r);
#line 354 "GomDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 354 "GomDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 354 "GomDocumentTest.vala"
		_tmp19_ = gxml_dom_node_list_item (_tmp18_, 0);
#line 354 "GomDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 354 "GomDocumentTest.vala"
		_tmp21_ = gxml_dom_node_get_node_value (_tmp20_);
#line 354 "GomDocumentTest.vala"
		_tmp22_ = _tmp21_;
#line 354 "GomDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 354 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp23_, "Starting") == 0, "r.child_nodes.item (0).node_value == \"Starting\"");
#line 354 "GomDocumentTest.vala"
		_g_free0 (_tmp23_);
#line 354 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp20_);
#line 354 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp18_);
#line 346 "GomDocumentTest.vala"
		_g_object_unref0 (r);
#line 346 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 3340 "GomDocumentTest.c"
	}
	goto __finally91;
	__catch91_g_error:
	{
#line 346 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 346 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 355 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 3351 "GomDocumentTest.c"
	}
	__finally91:
#line 346 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 346 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 346 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 346 "GomDocumentTest.vala"
		return;
#line 3362 "GomDocumentTest.c"
	}
}

static void
___lambda78__gtest_func (void)
{
#line 345 "GomDocumentTest.vala"
	__lambda78_ ();
#line 3371 "GomDocumentTest.c"
}

static void
__lambda79_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlDomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlDomComment* _tmp1_ = NULL;
		GXmlDomDocument* _tmp2_;
		GXmlDomComment* _tmp3_;
		GXmlDomComment* comment = NULL;
		GXmlDomComment* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
#line 359 "GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<document_element />", &_inner_error0_);
#line 359 "GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp0_;
#line 359 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 3398 "GomDocumentTest.c"
			goto __catch92_g_error;
		}
#line 360 "GomDocumentTest.vala"
		_tmp2_ = doc;
#line 360 "GomDocumentTest.vala"
		_tmp3_ = gxml_dom_document_create_comment (_tmp2_, "Ever since the day we promised.", &_inner_error0_);
#line 360 "GomDocumentTest.vala"
		_tmp1_ = _tmp3_;
#line 360 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 360 "GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 3411 "GomDocumentTest.c"
			goto __catch92_g_error;
		}
#line 360 "GomDocumentTest.vala"
		_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_DOM_COMMENT, GXmlDomComment));
#line 360 "GomDocumentTest.vala"
		comment = _tmp4_;
#line 362 "GomDocumentTest.vala"
		_tmp5_ = gxml_dom_node_get_node_name ((GXmlDomNode*) comment);
#line 362 "GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 362 "GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 362 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "#comment") == 0, "comment.node_name == \"#comment\"");
#line 362 "GomDocumentTest.vala"
		_g_free0 (_tmp7_);
#line 363 "GomDocumentTest.vala"
		_tmp8_ = gxml_dom_character_data_get_data ((GXmlDomCharacterData*) comment);
#line 363 "GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 363 "GomDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 363 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp10_, "Ever since the day we promised.") == 0, "comment.data == \"Ever since the day we promised.\"");
#line 363 "GomDocumentTest.vala"
		_g_free0 (_tmp10_);
#line 358 "GomDocumentTest.vala"
		_g_object_unref0 (comment);
#line 358 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 358 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 3444 "GomDocumentTest.c"
	}
	goto __finally92;
	__catch92_g_error:
	{
#line 358 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 358 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 364 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 3455 "GomDocumentTest.c"
	}
	__finally92:
#line 358 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 358 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 358 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 358 "GomDocumentTest.vala"
		return;
#line 3466 "GomDocumentTest.c"
	}
}

static void
___lambda79__gtest_func (void)
{
#line 357 "GomDocumentTest.vala"
	__lambda79_ ();
#line 3475 "GomDocumentTest.c"
}

static void
__lambda80_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlDomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlDomProcessingInstruction* instruction = NULL;
		GXmlDomDocument* _tmp1_;
		GXmlDomProcessingInstruction* _tmp2_;
		GXmlDomProcessingInstruction* _tmp3_;
		GXmlDomProcessingInstruction* _tmp4_;
		GXmlDomProcessingInstruction* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		GXmlDomProcessingInstruction* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		GXmlDomProcessingInstruction* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		gchar* _tmp16_;
		GXmlDomProcessingInstruction* _tmp17_;
		gchar* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		GXmlDomProcessingInstruction* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
#line 368 "GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<document_element />", &_inner_error0_);
#line 368 "GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp0_;
#line 368 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 3516 "GomDocumentTest.c"
			goto __catch93_g_error;
		}
#line 369 "GomDocumentTest.vala"
		_tmp1_ = doc;
#line 369 "GomDocumentTest.vala"
		_tmp2_ = gxml_dom_document_create_processing_instruction (_tmp1_, "target", "data", &_inner_error0_);
#line 369 "GomDocumentTest.vala"
		instruction = _tmp2_;
#line 369 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 369 "GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 3529 "GomDocumentTest.c"
			goto __catch93_g_error;
		}
#line 370 "GomDocumentTest.vala"
		_tmp3_ = instruction;
#line 370 "GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_GOM_PROCESSING_INSTRUCTION), "instruction is GomProcessingInstruction");
#line 371 "GomDocumentTest.vala"
		_tmp4_ = instruction;
#line 371 "GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GXML_TYPE_DOM_PROCESSING_INSTRUCTION), "instruction is DomProcessingInstruction");
#line 372 "GomDocumentTest.vala"
		_tmp5_ = instruction;
#line 372 "GomDocumentTest.vala"
		_tmp6_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp5_);
#line 372 "GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 372 "GomDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 372 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp8_, "target") == 0, "instruction.node_name == \"target\"");
#line 372 "GomDocumentTest.vala"
		_g_free0 (_tmp8_);
#line 373 "GomDocumentTest.vala"
		_tmp9_ = instruction;
#line 373 "GomDocumentTest.vala"
		_tmp10_ = gxml_dom_node_get_node_value ((GXmlDomNode*) _tmp9_);
#line 373 "GomDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 373 "GomDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 373 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp12_, "data") == 0, "instruction.node_value == \"data\"");
#line 373 "GomDocumentTest.vala"
		_g_free0 (_tmp12_);
#line 378 "GomDocumentTest.vala"
		_tmp13_ = instruction;
#line 378 "GomDocumentTest.vala"
		_tmp14_ = gxml_dom_character_data_get_data ((GXmlDomCharacterData*) _tmp13_);
#line 378 "GomDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 378 "GomDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 378 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp16_, "data") == 0, "instruction.data == \"data\"");
#line 378 "GomDocumentTest.vala"
		_g_free0 (_tmp16_);
#line 379 "GomDocumentTest.vala"
		_tmp17_ = instruction;
#line 379 "GomDocumentTest.vala"
		_tmp18_ = gxml_dom_processing_instruction_get_target (_tmp17_);
#line 379 "GomDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 379 "GomDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 379 "GomDocumentTest.vala"
		_vala_assert (_tmp20_ != NULL, "instruction.target != null");
#line 379 "GomDocumentTest.vala"
		_g_free0 (_tmp20_);
#line 380 "GomDocumentTest.vala"
		_tmp21_ = instruction;
#line 380 "GomDocumentTest.vala"
		_tmp22_ = gxml_dom_processing_instruction_get_target (_tmp21_);
#line 380 "GomDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 380 "GomDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 380 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp24_, "target") == 0, "instruction.target == \"target\"");
#line 380 "GomDocumentTest.vala"
		_g_free0 (_tmp24_);
#line 367 "GomDocumentTest.vala"
		_g_object_unref0 (instruction);
#line 367 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 3604 "GomDocumentTest.c"
	}
	goto __finally93;
	__catch93_g_error:
	{
#line 367 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 367 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 381 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 3615 "GomDocumentTest.c"
	}
	__finally93:
#line 367 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 367 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 367 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 367 "GomDocumentTest.vala"
		return;
#line 3626 "GomDocumentTest.c"
	}
}

static void
___lambda80__gtest_func (void)
{
#line 366 "GomDocumentTest.vala"
	__lambda80_ ();
#line 3635 "GomDocumentTest.c"
}

static void
__lambda81_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlDomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlDomDocument* _tmp1_;
		GXmlDomElement* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlDomDocument* _tmp5_;
		GXmlDomElement* _tmp6_;
		GXmlDomElement* _tmp7_;
		GXmlDomElement* _tmp8_;
		GXmlDomDocument* _tmp9_;
		GXmlDomElement* _tmp10_;
		GXmlDomElement* _tmp11_;
		GXmlDomElement* _tmp12_;
		GXmlDomNamedNodeMap* _tmp13_;
		GXmlDomNamedNodeMap* _tmp14_;
		GXmlDomNamedNodeMap* _tmp15_;
		gint _tmp16_;
		gint _tmp17_;
		gchar* attr = NULL;
		GXmlDomDocument* _tmp18_;
		GXmlDomElement* _tmp19_;
		GXmlDomElement* _tmp20_;
		GXmlDomElement* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
#line 385 "GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<document_element />", &_inner_error0_);
#line 385 "GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp0_;
#line 385 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 3675 "GomDocumentTest.c"
			goto __catch94_g_error;
		}
#line 386 "GomDocumentTest.vala"
		_tmp1_ = doc;
#line 386 "GomDocumentTest.vala"
		_tmp2_ = gxml_dom_document_get_document_element (_tmp1_);
#line 386 "GomDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 386 "GomDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 386 "GomDocumentTest.vala"
		_vala_assert (_tmp4_ != NULL, "doc.document_element != null");
#line 386 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp4_);
#line 387 "GomDocumentTest.vala"
		_tmp5_ = doc;
#line 387 "GomDocumentTest.vala"
		_tmp6_ = gxml_dom_document_get_document_element (_tmp5_);
#line 387 "GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 387 "GomDocumentTest.vala"
		_tmp8_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement);
#line 387 "GomDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp8_, "attrname", "attrvalue", &_inner_error0_);
#line 387 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp8_);
#line 387 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 387 "GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 3706 "GomDocumentTest.c"
			goto __catch94_g_error;
		}
#line 388 "GomDocumentTest.vala"
		_tmp9_ = doc;
#line 388 "GomDocumentTest.vala"
		_tmp10_ = gxml_dom_document_get_document_element (_tmp9_);
#line 388 "GomDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 388 "GomDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 388 "GomDocumentTest.vala"
		_tmp13_ = gxml_dom_element_get_attributes (_tmp12_);
#line 388 "GomDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 388 "GomDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 388 "GomDocumentTest.vala"
		_tmp16_ = gee_map_get_size ((GeeMap*) _tmp15_);
#line 388 "GomDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 388 "GomDocumentTest.vala"
		_vala_assert (_tmp17_ == 1, "doc.document_element.attributes.size == 1");
#line 388 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 388 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp12_);
#line 389 "GomDocumentTest.vala"
		_tmp18_ = doc;
#line 389 "GomDocumentTest.vala"
		_tmp19_ = gxml_dom_document_get_document_element (_tmp18_);
#line 389 "GomDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 389 "GomDocumentTest.vala"
		_tmp21_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement);
#line 389 "GomDocumentTest.vala"
		_tmp22_ = gxml_dom_element_get_attribute (_tmp21_, "attrname");
#line 389 "GomDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 389 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp21_);
#line 389 "GomDocumentTest.vala"
		attr = _tmp23_;
#line 393 "GomDocumentTest.vala"
		_vala_assert (attr != NULL, "attr != null");
#line 394 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (attr, "attrvalue") == 0, "attr == \"attrvalue\"");
#line 384 "GomDocumentTest.vala"
		_g_free0 (attr);
#line 384 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 3757 "GomDocumentTest.c"
	}
	goto __finally94;
	__catch94_g_error:
	{
#line 384 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 384 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 397 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 3768 "GomDocumentTest.c"
	}
	__finally94:
#line 384 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 384 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 384 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 384 "GomDocumentTest.vala"
		return;
#line 3779 "GomDocumentTest.c"
	}
}

static void
___lambda81__gtest_func (void)
{
#line 383 "GomDocumentTest.vala"
	__lambda81_ ();
#line 3788 "GomDocumentTest.c"
}

static void
__lambda82_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlDomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlXParser* parser = NULL;
		GXmlDomDocument* _tmp1_;
		GXmlXParser* _tmp2_;
		gchar* s1 = NULL;
		GXmlXParser* _tmp3_;
		gchar* _tmp4_;
		const gchar* _tmp5_;
		gchar** cs1 = NULL;
		const gchar* _tmp6_;
		gchar** _tmp7_;
		gchar** _tmp8_;
		gint cs1_length1;
		gint _cs1_size_;
		const gchar* _tmp9_;
		const gchar* _tmp10_;
#line 401 "GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<?xml version=\"1.0\"?>\n" \
"<Sentences><Sentence lang=\"en\">I like the colour blue.</Sentence><Se" \
"ntence lang=\"de\">Ich liebe die T&#xFC;r.</Sentence><Authors><Author>" \
"<Name>Fred</Name><Email>fweasley@hogwarts.co.uk</Email></Author><Autho" \
"r><Name>George</Name><Email>gweasley@hogwarts.co.uk</Email></Author></" \
"Authors></Sentences>", &_inner_error0_);
#line 401 "GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp0_;
#line 401 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 3819 "GomDocumentTest.c"
			goto __catch95_g_error;
		}
#line 404 "GomDocumentTest.vala"
		_tmp1_ = doc;
#line 404 "GomDocumentTest.vala"
		_tmp2_ = gxml_xparser_new ((GXmlDomNode*) _tmp1_);
#line 404 "GomDocumentTest.vala"
		parser = _tmp2_;
#line 405 "GomDocumentTest.vala"
		_tmp3_ = parser;
#line 405 "GomDocumentTest.vala"
		_tmp4_ = gxml_parser_write_string ((GXmlParser*) _tmp3_, &_inner_error0_);
#line 405 "GomDocumentTest.vala"
		s1 = _tmp4_;
#line 405 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 405 "GomDocumentTest.vala"
			_g_object_unref0 (parser);
#line 405 "GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 3840 "GomDocumentTest.c"
			goto __catch95_g_error;
		}
#line 406 "GomDocumentTest.vala"
		_tmp5_ = s1;
#line 406 "GomDocumentTest.vala"
		_vala_assert (_tmp5_ != NULL, "s1 != null");
#line 410 "GomDocumentTest.vala"
		_tmp6_ = s1;
#line 410 "GomDocumentTest.vala"
		_tmp8_ = _tmp7_ = g_strsplit (_tmp6_, "\n", 0);
#line 410 "GomDocumentTest.vala"
		cs1 = _tmp8_;
#line 410 "GomDocumentTest.vala"
		cs1_length1 = _vala_array_length (_tmp7_);
#line 410 "GomDocumentTest.vala"
		_cs1_size_ = cs1_length1;
#line 414 "GomDocumentTest.vala"
		_tmp9_ = cs1[0];
#line 414 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp9_, "<?xml version=\"1.0\"?>") == 0, "cs1[0] == \"<?xml version=\\\"1.0\\\"?>\"");
#line 415 "GomDocumentTest.vala"
		_tmp10_ = cs1[1];
#line 415 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp10_, "<Sentences><Sentence lang=\"en\">I like the colour blue.</Sentence><Se" \
"ntence lang=\"de\">Ich liebe die T&#xFC;r.</Sentence><Authors><Author>" \
"<Name>Fred</Name><Email>fweasley@hogwarts.co.uk</Email></Author><Autho" \
"r><Name>George</Name><Email>gweasley@hogwarts.co.uk</Email></Author></" \
"Authors></Sentences>") == 0, "cs1[1] == \"<Sentences><Sentence lang=\\\"en\\\">I like the colour blue.</Sentence><Sentence lang=\\\"de\\\">Ich liebe die T&#xFC;r.</Sentence><Authors><Author><Name>Fred</Name><Email>fweasley@hogwarts.co.uk</Email></Author><Author><Name>George</Name><Email>gweasley@hogwarts.co.uk</Email></Author></Authors></Sentences>\"");
#line 400 "GomDocumentTest.vala"
		cs1 = (_vala_array_free (cs1, cs1_length1, (GDestroyNotify) g_free), NULL);
#line 400 "GomDocumentTest.vala"
		_g_free0 (s1);
#line 400 "GomDocumentTest.vala"
		_g_object_unref0 (parser);
#line 400 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 3873 "GomDocumentTest.c"
	}
	goto __finally95;
	__catch95_g_error:
	{
#line 400 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 400 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 416 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 3884 "GomDocumentTest.c"
	}
	__finally95:
#line 400 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 400 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 400 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 400 "GomDocumentTest.vala"
		return;
#line 3895 "GomDocumentTest.c"
	}
}

static void
___lambda82__gtest_func (void)
{
#line 399 "GomDocumentTest.vala"
	__lambda82_ ();
#line 3904 "GomDocumentTest.c"
}

static void
__lambda83_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlDomElement* _tmp1_;
		GXmlDomElement* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlDomElement* _tmp5_;
		GXmlDomElement* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		GXmlDomElement* _tmp10_;
		GXmlDomElement* _tmp11_;
		GXmlDomElement* _tmp12_;
		GXmlDomNodeList* _tmp13_;
		GXmlDomNodeList* _tmp14_;
		GXmlDomNodeList* _tmp15_;
		gpointer _tmp16_;
		GXmlDomNode* _tmp17_;
		GXmlDomElement* _tmp18_;
		GXmlDomElement* _tmp19_;
		GXmlDomElement* _tmp20_;
		GXmlDomNodeList* _tmp21_;
		GXmlDomNodeList* _tmp22_;
		GXmlDomNodeList* _tmp23_;
		gpointer _tmp24_;
		GXmlDomNode* _tmp25_;
		GXmlDomElement* _tmp26_;
		GXmlDomElement* _tmp27_;
		GXmlDomElement* _tmp28_;
		GXmlDomNodeList* _tmp29_;
		GXmlDomNodeList* _tmp30_;
		GXmlDomNodeList* _tmp31_;
		gpointer _tmp32_;
		GXmlDomNode* _tmp33_;
		GXmlDomElement* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomNodeList* _tmp37_;
		GXmlDomNodeList* _tmp38_;
		GXmlDomNodeList* _tmp39_;
		gpointer _tmp40_;
		GXmlDomNode* _tmp41_;
		gchar* _tmp42_;
		gchar* _tmp43_;
		gchar* _tmp44_;
		GXmlDomElement* _tmp45_;
		GXmlDomElement* _tmp46_;
		GXmlDomElement* _tmp47_;
		GXmlDomNodeList* _tmp48_;
		GXmlDomNodeList* _tmp49_;
		GXmlDomNodeList* _tmp50_;
		gint _tmp51_;
		gint _tmp52_;
		GXmlDomElement* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomNodeList* _tmp56_;
		GXmlDomNodeList* _tmp57_;
		GXmlDomNodeList* _tmp58_;
		gpointer _tmp59_;
		GXmlDomNode* _tmp60_;
		gchar* _tmp61_;
		gchar* _tmp62_;
		gchar* _tmp63_;
		GXmlDomElement* _tmp64_;
		GXmlDomElement* _tmp65_;
		GXmlDomElement* _tmp66_;
		GXmlDomNodeList* _tmp67_;
		GXmlDomNodeList* _tmp68_;
		GXmlDomNodeList* _tmp69_;
		gpointer _tmp70_;
		GXmlDomNode* _tmp71_;
		GXmlDomNodeList* _tmp72_;
		GXmlDomNodeList* _tmp73_;
		GXmlDomNodeList* _tmp74_;
		gint _tmp75_;
		gint _tmp76_;
		GXmlDomElement* _tmp77_;
		GXmlDomElement* _tmp78_;
		GXmlDomElement* _tmp79_;
		GXmlDomNodeList* _tmp80_;
		GXmlDomNodeList* _tmp81_;
		GXmlDomNodeList* _tmp82_;
		gpointer _tmp83_;
		GXmlDomNode* _tmp84_;
		GXmlDomNodeList* _tmp85_;
		GXmlDomNodeList* _tmp86_;
		GXmlDomNodeList* _tmp87_;
		gpointer _tmp88_;
		GXmlDomNode* _tmp89_;
		gchar* _tmp90_;
		gchar* _tmp91_;
		gchar* _tmp92_;
		GXmlDomElement* _tmp93_;
		GXmlDomElement* _tmp94_;
		GXmlDomElement* _tmp95_;
		GXmlDomNodeList* _tmp96_;
		GXmlDomNodeList* _tmp97_;
		GXmlDomNodeList* _tmp98_;
		gpointer _tmp99_;
		GXmlDomNode* _tmp100_;
		GXmlDomNodeList* _tmp101_;
		GXmlDomNodeList* _tmp102_;
		GXmlDomNodeList* _tmp103_;
		gpointer _tmp104_;
		GXmlDomNode* _tmp105_;
		GXmlDomNodeList* _tmp106_;
		GXmlDomNodeList* _tmp107_;
		GXmlDomNodeList* _tmp108_;
		gint _tmp109_;
		gint _tmp110_;
		GXmlDomElement* _tmp111_;
		GXmlDomElement* _tmp112_;
		GXmlDomElement* _tmp113_;
		GXmlDomNodeList* _tmp114_;
		GXmlDomNodeList* _tmp115_;
		GXmlDomNodeList* _tmp116_;
		gpointer _tmp117_;
		GXmlDomNode* _tmp118_;
		GXmlDomNodeList* _tmp119_;
		GXmlDomNodeList* _tmp120_;
		GXmlDomNodeList* _tmp121_;
		gpointer _tmp122_;
		GXmlDomNode* _tmp123_;
		GXmlDomNodeList* _tmp124_;
		GXmlDomNodeList* _tmp125_;
		GXmlDomNodeList* _tmp126_;
		gpointer _tmp127_;
		GXmlDomNode* _tmp128_;
		gchar* _tmp129_;
		gchar* _tmp130_;
		gchar* _tmp131_;
		GXmlDomElement* _tmp132_;
		GXmlDomElement* _tmp133_;
		GXmlDomElement* _tmp134_;
		GXmlDomNodeList* _tmp135_;
		GXmlDomNodeList* _tmp136_;
		GXmlDomNodeList* _tmp137_;
		gpointer _tmp138_;
		GXmlDomNode* _tmp139_;
		GXmlDomNodeList* _tmp140_;
		GXmlDomNodeList* _tmp141_;
		GXmlDomNodeList* _tmp142_;
		gpointer _tmp143_;
		GXmlDomNode* _tmp144_;
		GXmlDomNodeList* _tmp145_;
		GXmlDomNodeList* _tmp146_;
		GXmlDomNodeList* _tmp147_;
		gpointer _tmp148_;
		GXmlDomNode* _tmp149_;
		GXmlDomNodeList* _tmp150_;
		GXmlDomNodeList* _tmp151_;
		GXmlDomNodeList* _tmp152_;
		gint _tmp153_;
		gint _tmp154_;
		GXmlDomElement* _tmp155_;
		GXmlDomElement* _tmp156_;
		GXmlDomElement* _tmp157_;
		GXmlDomNodeList* _tmp158_;
		GXmlDomNodeList* _tmp159_;
		GXmlDomNodeList* _tmp160_;
		gpointer _tmp161_;
		GXmlDomNode* _tmp162_;
		GXmlDomNodeList* _tmp163_;
		GXmlDomNodeList* _tmp164_;
		GXmlDomNodeList* _tmp165_;
		gpointer _tmp166_;
		GXmlDomNode* _tmp167_;
		GXmlDomNodeList* _tmp168_;
		GXmlDomNodeList* _tmp169_;
		GXmlDomNodeList* _tmp170_;
		gpointer _tmp171_;
		GXmlDomNode* _tmp172_;
		GXmlDomNodeList* _tmp173_;
		GXmlDomNodeList* _tmp174_;
		GXmlDomNodeList* _tmp175_;
		gpointer _tmp176_;
		GXmlDomNode* _tmp177_;
		GXmlDomElement* _tmp178_;
		GXmlDomElement* _tmp179_;
		GXmlDomElement* _tmp180_;
		GXmlDomNodeList* _tmp181_;
		GXmlDomNodeList* _tmp182_;
		GXmlDomNodeList* _tmp183_;
		gpointer _tmp184_;
		GXmlDomNode* _tmp185_;
		GXmlDomNodeList* _tmp186_;
		GXmlDomNodeList* _tmp187_;
		GXmlDomNodeList* _tmp188_;
		gpointer _tmp189_;
		GXmlDomNode* _tmp190_;
		GXmlDomNodeList* _tmp191_;
		GXmlDomNodeList* _tmp192_;
		GXmlDomNodeList* _tmp193_;
		gpointer _tmp194_;
		GXmlDomNode* _tmp195_;
		GXmlDomNodeList* _tmp196_;
		GXmlDomNodeList* _tmp197_;
		GXmlDomNodeList* _tmp198_;
		gpointer _tmp199_;
		GXmlDomNode* _tmp200_;
		gchar* _tmp201_;
		gchar* _tmp202_;
		gchar* _tmp203_;
#line 420 "GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_path (TEST_DIR "/gdocument-read.xml", &_inner_error0_);
#line 420 "GomDocumentTest.vala"
		d = _tmp0_;
#line 420 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 4123 "GomDocumentTest.c"
			goto __catch96_g_error;
		}
#line 425 "GomDocumentTest.vala"
		_tmp1_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 425 "GomDocumentTest.vala"
		_tmp2_ = _tmp1_;
#line 425 "GomDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 425 "GomDocumentTest.vala"
		_vala_assert (_tmp3_ != NULL, "d.document_element != null");
#line 425 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp3_);
#line 426 "GomDocumentTest.vala"
		_tmp4_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 426 "GomDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 426 "GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 426 "GomDocumentTest.vala"
		_tmp7_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp6_);
#line 426 "GomDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 426 "GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 426 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp9_, "DataTypeTemplates") == 0, "d.document_element.node_name == \"DataTypeTemplates\"");
#line 426 "GomDocumentTest.vala"
		_g_free0 (_tmp9_);
#line 426 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp6_);
#line 430 "GomDocumentTest.vala"
		_tmp10_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 430 "GomDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 430 "GomDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 430 "GomDocumentTest.vala"
		_tmp13_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp12_);
#line 430 "GomDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 430 "GomDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 430 "GomDocumentTest.vala"
		_tmp16_ = gee_list_get ((GeeList*) _tmp15_, 0);
#line 430 "GomDocumentTest.vala"
		_tmp17_ = (GXmlDomNode*) _tmp16_;
#line 430 "GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp17_, GXML_TYPE_DOM_TEXT), "d.document_element.child_nodes[0] is GXml.DomText");
#line 430 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp17_);
#line 430 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 430 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp12_);
#line 431 "GomDocumentTest.vala"
		_tmp18_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 431 "GomDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 431 "GomDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 431 "GomDocumentTest.vala"
		_tmp21_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp20_);
#line 431 "GomDocumentTest.vala"
		_tmp22_ = _tmp21_;
#line 431 "GomDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 431 "GomDocumentTest.vala"
		_tmp24_ = gee_list_get ((GeeList*) _tmp23_, 1);
#line 431 "GomDocumentTest.vala"
		_tmp25_ = (GXmlDomNode*) _tmp24_;
#line 431 "GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp25_, GXML_TYPE_DOM_ELEMENT), "d.document_element.child_nodes[1] is GXml.DomElement");
#line 431 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp25_);
#line 431 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp23_);
#line 431 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp20_);
#line 432 "GomDocumentTest.vala"
		_tmp26_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 432 "GomDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 432 "GomDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 432 "GomDocumentTest.vala"
		_tmp29_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp28_);
#line 432 "GomDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 432 "GomDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 432 "GomDocumentTest.vala"
		_tmp32_ = gee_list_get ((GeeList*) _tmp31_, 2);
#line 432 "GomDocumentTest.vala"
		_tmp33_ = (GXmlDomNode*) _tmp32_;
#line 432 "GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp33_, GXML_TYPE_DOM_TEXT), "d.document_element.child_nodes[2] is GXml.DomText");
#line 432 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp33_);
#line 432 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp31_);
#line 432 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp28_);
#line 433 "GomDocumentTest.vala"
		_tmp34_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 433 "GomDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 433 "GomDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 433 "GomDocumentTest.vala"
		_tmp37_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp36_);
#line 433 "GomDocumentTest.vala"
		_tmp38_ = _tmp37_;
#line 433 "GomDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 433 "GomDocumentTest.vala"
		_tmp40_ = gee_list_get ((GeeList*) _tmp39_, 2);
#line 433 "GomDocumentTest.vala"
		_tmp41_ = (GXmlDomNode*) _tmp40_;
#line 433 "GomDocumentTest.vala"
		_tmp42_ = gxml_dom_node_get_node_value (_tmp41_);
#line 433 "GomDocumentTest.vala"
		_tmp43_ = _tmp42_;
#line 433 "GomDocumentTest.vala"
		_tmp44_ = _tmp43_;
#line 433 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp44_, "\n") == 0, "d.document_element.child_nodes[2].node_value == \"\\n\"");
#line 433 "GomDocumentTest.vala"
		_g_free0 (_tmp44_);
#line 433 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp41_);
#line 433 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp39_);
#line 433 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp36_);
#line 434 "GomDocumentTest.vala"
		_tmp45_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 434 "GomDocumentTest.vala"
		_tmp46_ = _tmp45_;
#line 434 "GomDocumentTest.vala"
		_tmp47_ = _tmp46_;
#line 434 "GomDocumentTest.vala"
		_tmp48_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp47_);
#line 434 "GomDocumentTest.vala"
		_tmp49_ = _tmp48_;
#line 434 "GomDocumentTest.vala"
		_tmp50_ = _tmp49_;
#line 434 "GomDocumentTest.vala"
		_tmp51_ = gee_collection_get_size ((GeeCollection*) _tmp50_);
#line 434 "GomDocumentTest.vala"
		_tmp52_ = _tmp51_;
#line 434 "GomDocumentTest.vala"
		_vala_assert (_tmp52_ == 3, "d.document_element.child_nodes.size == 3");
#line 434 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp50_);
#line 434 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp47_);
#line 435 "GomDocumentTest.vala"
		_tmp53_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 435 "GomDocumentTest.vala"
		_tmp54_ = _tmp53_;
#line 435 "GomDocumentTest.vala"
		_tmp55_ = _tmp54_;
#line 435 "GomDocumentTest.vala"
		_tmp56_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp55_);
#line 435 "GomDocumentTest.vala"
		_tmp57_ = _tmp56_;
#line 435 "GomDocumentTest.vala"
		_tmp58_ = _tmp57_;
#line 435 "GomDocumentTest.vala"
		_tmp59_ = gee_list_get ((GeeList*) _tmp58_, 1);
#line 435 "GomDocumentTest.vala"
		_tmp60_ = (GXmlDomNode*) _tmp59_;
#line 435 "GomDocumentTest.vala"
		_tmp61_ = gxml_dom_node_get_node_name (_tmp60_);
#line 435 "GomDocumentTest.vala"
		_tmp62_ = _tmp61_;
#line 435 "GomDocumentTest.vala"
		_tmp63_ = _tmp62_;
#line 435 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp63_, "DAType") == 0, "d.document_element.child_nodes[1].node_name == \"DAType\"");
#line 435 "GomDocumentTest.vala"
		_g_free0 (_tmp63_);
#line 435 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp60_);
#line 435 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp58_);
#line 435 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp55_);
#line 436 "GomDocumentTest.vala"
		_tmp64_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 436 "GomDocumentTest.vala"
		_tmp65_ = _tmp64_;
#line 436 "GomDocumentTest.vala"
		_tmp66_ = _tmp65_;
#line 436 "GomDocumentTest.vala"
		_tmp67_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp66_);
#line 436 "GomDocumentTest.vala"
		_tmp68_ = _tmp67_;
#line 436 "GomDocumentTest.vala"
		_tmp69_ = _tmp68_;
#line 436 "GomDocumentTest.vala"
		_tmp70_ = gee_list_get ((GeeList*) _tmp69_, 1);
#line 436 "GomDocumentTest.vala"
		_tmp71_ = (GXmlDomNode*) _tmp70_;
#line 436 "GomDocumentTest.vala"
		_tmp72_ = gxml_dom_node_get_child_nodes (_tmp71_);
#line 436 "GomDocumentTest.vala"
		_tmp73_ = _tmp72_;
#line 436 "GomDocumentTest.vala"
		_tmp74_ = _tmp73_;
#line 436 "GomDocumentTest.vala"
		_tmp75_ = gee_collection_get_size ((GeeCollection*) _tmp74_);
#line 436 "GomDocumentTest.vala"
		_tmp76_ = _tmp75_;
#line 436 "GomDocumentTest.vala"
		_vala_assert (_tmp76_ == 3, "d.document_element.child_nodes[1].child_nodes.size == 3");
#line 436 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp74_);
#line 436 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp71_);
#line 436 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp69_);
#line 436 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp66_);
#line 437 "GomDocumentTest.vala"
		_tmp77_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 437 "GomDocumentTest.vala"
		_tmp78_ = _tmp77_;
#line 437 "GomDocumentTest.vala"
		_tmp79_ = _tmp78_;
#line 437 "GomDocumentTest.vala"
		_tmp80_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp79_);
#line 437 "GomDocumentTest.vala"
		_tmp81_ = _tmp80_;
#line 437 "GomDocumentTest.vala"
		_tmp82_ = _tmp81_;
#line 437 "GomDocumentTest.vala"
		_tmp83_ = gee_list_get ((GeeList*) _tmp82_, 1);
#line 437 "GomDocumentTest.vala"
		_tmp84_ = (GXmlDomNode*) _tmp83_;
#line 437 "GomDocumentTest.vala"
		_tmp85_ = gxml_dom_node_get_child_nodes (_tmp84_);
#line 437 "GomDocumentTest.vala"
		_tmp86_ = _tmp85_;
#line 437 "GomDocumentTest.vala"
		_tmp87_ = _tmp86_;
#line 437 "GomDocumentTest.vala"
		_tmp88_ = gee_list_get ((GeeList*) _tmp87_, 1);
#line 437 "GomDocumentTest.vala"
		_tmp89_ = (GXmlDomNode*) _tmp88_;
#line 437 "GomDocumentTest.vala"
		_tmp90_ = gxml_dom_node_get_node_name (_tmp89_);
#line 437 "GomDocumentTest.vala"
		_tmp91_ = _tmp90_;
#line 437 "GomDocumentTest.vala"
		_tmp92_ = _tmp91_;
#line 437 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp92_, "BDA") == 0, "d.document_element.child_nodes[1].child_nodes[1].node_name == \"BDA\"");
#line 437 "GomDocumentTest.vala"
		_g_free0 (_tmp92_);
#line 437 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp89_);
#line 437 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp87_);
#line 437 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp84_);
#line 437 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp82_);
#line 437 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp79_);
#line 438 "GomDocumentTest.vala"
		_tmp93_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 438 "GomDocumentTest.vala"
		_tmp94_ = _tmp93_;
#line 438 "GomDocumentTest.vala"
		_tmp95_ = _tmp94_;
#line 438 "GomDocumentTest.vala"
		_tmp96_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp95_);
#line 438 "GomDocumentTest.vala"
		_tmp97_ = _tmp96_;
#line 438 "GomDocumentTest.vala"
		_tmp98_ = _tmp97_;
#line 438 "GomDocumentTest.vala"
		_tmp99_ = gee_list_get ((GeeList*) _tmp98_, 1);
#line 438 "GomDocumentTest.vala"
		_tmp100_ = (GXmlDomNode*) _tmp99_;
#line 438 "GomDocumentTest.vala"
		_tmp101_ = gxml_dom_node_get_child_nodes (_tmp100_);
#line 438 "GomDocumentTest.vala"
		_tmp102_ = _tmp101_;
#line 438 "GomDocumentTest.vala"
		_tmp103_ = _tmp102_;
#line 438 "GomDocumentTest.vala"
		_tmp104_ = gee_list_get ((GeeList*) _tmp103_, 1);
#line 438 "GomDocumentTest.vala"
		_tmp105_ = (GXmlDomNode*) _tmp104_;
#line 438 "GomDocumentTest.vala"
		_tmp106_ = gxml_dom_node_get_child_nodes (_tmp105_);
#line 438 "GomDocumentTest.vala"
		_tmp107_ = _tmp106_;
#line 438 "GomDocumentTest.vala"
		_tmp108_ = _tmp107_;
#line 438 "GomDocumentTest.vala"
		_tmp109_ = gee_collection_get_size ((GeeCollection*) _tmp108_);
#line 438 "GomDocumentTest.vala"
		_tmp110_ = _tmp109_;
#line 438 "GomDocumentTest.vala"
		_vala_assert (_tmp110_ == 3, "d.document_element.child_nodes[1].child_nodes[1].child_nodes.size == 3");
#line 438 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp108_);
#line 438 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp105_);
#line 438 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp103_);
#line 438 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp100_);
#line 438 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp98_);
#line 438 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp95_);
#line 439 "GomDocumentTest.vala"
		_tmp111_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 439 "GomDocumentTest.vala"
		_tmp112_ = _tmp111_;
#line 439 "GomDocumentTest.vala"
		_tmp113_ = _tmp112_;
#line 439 "GomDocumentTest.vala"
		_tmp114_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp113_);
#line 439 "GomDocumentTest.vala"
		_tmp115_ = _tmp114_;
#line 439 "GomDocumentTest.vala"
		_tmp116_ = _tmp115_;
#line 439 "GomDocumentTest.vala"
		_tmp117_ = gee_list_get ((GeeList*) _tmp116_, 1);
#line 439 "GomDocumentTest.vala"
		_tmp118_ = (GXmlDomNode*) _tmp117_;
#line 439 "GomDocumentTest.vala"
		_tmp119_ = gxml_dom_node_get_child_nodes (_tmp118_);
#line 439 "GomDocumentTest.vala"
		_tmp120_ = _tmp119_;
#line 439 "GomDocumentTest.vala"
		_tmp121_ = _tmp120_;
#line 439 "GomDocumentTest.vala"
		_tmp122_ = gee_list_get ((GeeList*) _tmp121_, 1);
#line 439 "GomDocumentTest.vala"
		_tmp123_ = (GXmlDomNode*) _tmp122_;
#line 439 "GomDocumentTest.vala"
		_tmp124_ = gxml_dom_node_get_child_nodes (_tmp123_);
#line 439 "GomDocumentTest.vala"
		_tmp125_ = _tmp124_;
#line 439 "GomDocumentTest.vala"
		_tmp126_ = _tmp125_;
#line 439 "GomDocumentTest.vala"
		_tmp127_ = gee_list_get ((GeeList*) _tmp126_, 1);
#line 439 "GomDocumentTest.vala"
		_tmp128_ = (GXmlDomNode*) _tmp127_;
#line 439 "GomDocumentTest.vala"
		_tmp129_ = gxml_dom_node_get_node_name (_tmp128_);
#line 439 "GomDocumentTest.vala"
		_tmp130_ = _tmp129_;
#line 439 "GomDocumentTest.vala"
		_tmp131_ = _tmp130_;
#line 439 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp131_, "Val") == 0, "d.document_element.child_nodes[1].child_nodes[1].child_nodes[1].node_name == \"Val\"");
#line 439 "GomDocumentTest.vala"
		_g_free0 (_tmp131_);
#line 439 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp128_);
#line 439 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp126_);
#line 439 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp123_);
#line 439 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp121_);
#line 439 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp118_);
#line 439 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp116_);
#line 439 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp113_);
#line 440 "GomDocumentTest.vala"
		_tmp132_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 440 "GomDocumentTest.vala"
		_tmp133_ = _tmp132_;
#line 440 "GomDocumentTest.vala"
		_tmp134_ = _tmp133_;
#line 440 "GomDocumentTest.vala"
		_tmp135_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp134_);
#line 440 "GomDocumentTest.vala"
		_tmp136_ = _tmp135_;
#line 440 "GomDocumentTest.vala"
		_tmp137_ = _tmp136_;
#line 440 "GomDocumentTest.vala"
		_tmp138_ = gee_list_get ((GeeList*) _tmp137_, 1);
#line 440 "GomDocumentTest.vala"
		_tmp139_ = (GXmlDomNode*) _tmp138_;
#line 440 "GomDocumentTest.vala"
		_tmp140_ = gxml_dom_node_get_child_nodes (_tmp139_);
#line 440 "GomDocumentTest.vala"
		_tmp141_ = _tmp140_;
#line 440 "GomDocumentTest.vala"
		_tmp142_ = _tmp141_;
#line 440 "GomDocumentTest.vala"
		_tmp143_ = gee_list_get ((GeeList*) _tmp142_, 1);
#line 440 "GomDocumentTest.vala"
		_tmp144_ = (GXmlDomNode*) _tmp143_;
#line 440 "GomDocumentTest.vala"
		_tmp145_ = gxml_dom_node_get_child_nodes (_tmp144_);
#line 440 "GomDocumentTest.vala"
		_tmp146_ = _tmp145_;
#line 440 "GomDocumentTest.vala"
		_tmp147_ = _tmp146_;
#line 440 "GomDocumentTest.vala"
		_tmp148_ = gee_list_get ((GeeList*) _tmp147_, 1);
#line 440 "GomDocumentTest.vala"
		_tmp149_ = (GXmlDomNode*) _tmp148_;
#line 440 "GomDocumentTest.vala"
		_tmp150_ = gxml_dom_node_get_child_nodes (_tmp149_);
#line 440 "GomDocumentTest.vala"
		_tmp151_ = _tmp150_;
#line 440 "GomDocumentTest.vala"
		_tmp152_ = _tmp151_;
#line 440 "GomDocumentTest.vala"
		_tmp153_ = gee_collection_get_size ((GeeCollection*) _tmp152_);
#line 440 "GomDocumentTest.vala"
		_tmp154_ = _tmp153_;
#line 440 "GomDocumentTest.vala"
		_vala_assert (_tmp154_ == 1, "d.document_element.child_nodes[1].child_nodes[1].child_nodes[1].child_nodes.size == 1");
#line 440 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp152_);
#line 440 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp149_);
#line 440 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp147_);
#line 440 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp144_);
#line 440 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp142_);
#line 440 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp139_);
#line 440 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp137_);
#line 440 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp134_);
#line 441 "GomDocumentTest.vala"
		_tmp155_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 441 "GomDocumentTest.vala"
		_tmp156_ = _tmp155_;
#line 441 "GomDocumentTest.vala"
		_tmp157_ = _tmp156_;
#line 441 "GomDocumentTest.vala"
		_tmp158_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp157_);
#line 441 "GomDocumentTest.vala"
		_tmp159_ = _tmp158_;
#line 441 "GomDocumentTest.vala"
		_tmp160_ = _tmp159_;
#line 441 "GomDocumentTest.vala"
		_tmp161_ = gee_list_get ((GeeList*) _tmp160_, 1);
#line 441 "GomDocumentTest.vala"
		_tmp162_ = (GXmlDomNode*) _tmp161_;
#line 441 "GomDocumentTest.vala"
		_tmp163_ = gxml_dom_node_get_child_nodes (_tmp162_);
#line 441 "GomDocumentTest.vala"
		_tmp164_ = _tmp163_;
#line 441 "GomDocumentTest.vala"
		_tmp165_ = _tmp164_;
#line 441 "GomDocumentTest.vala"
		_tmp166_ = gee_list_get ((GeeList*) _tmp165_, 1);
#line 441 "GomDocumentTest.vala"
		_tmp167_ = (GXmlDomNode*) _tmp166_;
#line 441 "GomDocumentTest.vala"
		_tmp168_ = gxml_dom_node_get_child_nodes (_tmp167_);
#line 441 "GomDocumentTest.vala"
		_tmp169_ = _tmp168_;
#line 441 "GomDocumentTest.vala"
		_tmp170_ = _tmp169_;
#line 441 "GomDocumentTest.vala"
		_tmp171_ = gee_list_get ((GeeList*) _tmp170_, 1);
#line 441 "GomDocumentTest.vala"
		_tmp172_ = (GXmlDomNode*) _tmp171_;
#line 441 "GomDocumentTest.vala"
		_tmp173_ = gxml_dom_node_get_child_nodes (_tmp172_);
#line 441 "GomDocumentTest.vala"
		_tmp174_ = _tmp173_;
#line 441 "GomDocumentTest.vala"
		_tmp175_ = _tmp174_;
#line 441 "GomDocumentTest.vala"
		_tmp176_ = gee_list_get ((GeeList*) _tmp175_, 0);
#line 441 "GomDocumentTest.vala"
		_tmp177_ = (GXmlDomNode*) _tmp176_;
#line 441 "GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp177_, GXML_TYPE_DOM_TEXT), "d.document_element.child_nodes[1].child_nodes[1].child_nodes[1].child_nodes[0] is GXml.DomText");
#line 441 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp177_);
#line 441 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp175_);
#line 441 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp172_);
#line 441 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp170_);
#line 441 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp167_);
#line 441 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp165_);
#line 441 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp162_);
#line 441 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp160_);
#line 441 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp157_);
#line 442 "GomDocumentTest.vala"
		_tmp178_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 442 "GomDocumentTest.vala"
		_tmp179_ = _tmp178_;
#line 442 "GomDocumentTest.vala"
		_tmp180_ = _tmp179_;
#line 442 "GomDocumentTest.vala"
		_tmp181_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp180_);
#line 442 "GomDocumentTest.vala"
		_tmp182_ = _tmp181_;
#line 442 "GomDocumentTest.vala"
		_tmp183_ = _tmp182_;
#line 442 "GomDocumentTest.vala"
		_tmp184_ = gee_list_get ((GeeList*) _tmp183_, 1);
#line 442 "GomDocumentTest.vala"
		_tmp185_ = (GXmlDomNode*) _tmp184_;
#line 442 "GomDocumentTest.vala"
		_tmp186_ = gxml_dom_node_get_child_nodes (_tmp185_);
#line 442 "GomDocumentTest.vala"
		_tmp187_ = _tmp186_;
#line 442 "GomDocumentTest.vala"
		_tmp188_ = _tmp187_;
#line 442 "GomDocumentTest.vala"
		_tmp189_ = gee_list_get ((GeeList*) _tmp188_, 1);
#line 442 "GomDocumentTest.vala"
		_tmp190_ = (GXmlDomNode*) _tmp189_;
#line 442 "GomDocumentTest.vala"
		_tmp191_ = gxml_dom_node_get_child_nodes (_tmp190_);
#line 442 "GomDocumentTest.vala"
		_tmp192_ = _tmp191_;
#line 442 "GomDocumentTest.vala"
		_tmp193_ = _tmp192_;
#line 442 "GomDocumentTest.vala"
		_tmp194_ = gee_list_get ((GeeList*) _tmp193_, 1);
#line 442 "GomDocumentTest.vala"
		_tmp195_ = (GXmlDomNode*) _tmp194_;
#line 442 "GomDocumentTest.vala"
		_tmp196_ = gxml_dom_node_get_child_nodes (_tmp195_);
#line 442 "GomDocumentTest.vala"
		_tmp197_ = _tmp196_;
#line 442 "GomDocumentTest.vala"
		_tmp198_ = _tmp197_;
#line 442 "GomDocumentTest.vala"
		_tmp199_ = gee_list_get ((GeeList*) _tmp198_, 0);
#line 442 "GomDocumentTest.vala"
		_tmp200_ = (GXmlDomNode*) _tmp199_;
#line 442 "GomDocumentTest.vala"
		_tmp201_ = gxml_dom_node_get_node_value (_tmp200_);
#line 442 "GomDocumentTest.vala"
		_tmp202_ = _tmp201_;
#line 442 "GomDocumentTest.vala"
		_tmp203_ = _tmp202_;
#line 442 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp203_, "status_only") == 0, "d.document_element.child_nodes[1].child_nodes[1].child_nodes[1].child_nodes[0].node_value == \"status_only\"");
#line 442 "GomDocumentTest.vala"
		_g_free0 (_tmp203_);
#line 442 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp200_);
#line 442 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp198_);
#line 442 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp195_);
#line 442 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp193_);
#line 442 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp190_);
#line 442 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp188_);
#line 442 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp185_);
#line 442 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp183_);
#line 442 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp180_);
#line 419 "GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 4710 "GomDocumentTest.c"
	}
	goto __finally96;
	__catch96_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp204_;
		gchar* _tmp205_;
		gchar* _tmp206_;
#line 419 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 419 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 443 "GomDocumentTest.vala"
		_tmp204_ = e->message;
#line 443 "GomDocumentTest.vala"
		_tmp205_ = g_strconcat ("ERROR: ", _tmp204_, NULL);
#line 443 "GomDocumentTest.vala"
		_tmp206_ = _tmp205_;
#line 443 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:443: %s", _tmp206_);
#line 443 "GomDocumentTest.vala"
		_g_free0 (_tmp206_);
#line 443 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 419 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 4737 "GomDocumentTest.c"
	}
	__finally96:
#line 419 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 419 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 419 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 419 "GomDocumentTest.vala"
		return;
#line 4748 "GomDocumentTest.c"
	}
}

static void
___lambda83__gtest_func (void)
{
#line 418 "GomDocumentTest.vala"
	__lambda83_ ();
#line 4757 "GomDocumentTest.c"
}

static void
__lambda84_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlDomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlDomDocument* _tmp1_;
		GXmlDomElement* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlDomDocument* _tmp5_;
		GXmlDomElement* _tmp6_;
		GXmlDomElement* _tmp7_;
		GXmlDomElement* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		GXmlDomDocument* _tmp12_;
		GXmlDomElement* _tmp13_;
		GXmlDomElement* _tmp14_;
		GXmlDomElement* _tmp15_;
		gchar* _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_;
		GXmlDomDocument* _tmp19_;
		GXmlDomElement* _tmp20_;
		GXmlDomElement* _tmp21_;
		GXmlDomElement* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
		GXmlDomDocument* _tmp25_;
		GXmlDomElement* _tmp26_;
		GXmlDomElement* _tmp27_;
		GXmlDomElement* _tmp28_;
		GXmlDomDocument* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomElement* _tmp31_;
		GXmlDomElement* _tmp32_;
		GXmlDomDocument* _tmp33_;
		GXmlDomElement* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomElement* _tmp36_;
		gchar* _tmp37_;
		gchar* _tmp38_;
		gchar* _tmp39_;
		GXmlDomDocument* _tmp40_;
		GXmlDomElement* _tmp41_;
		GXmlDomElement* _tmp42_;
		GXmlDomElement* _tmp43_;
		gchar* _tmp44_;
		gchar* _tmp45_;
		gchar* _tmp46_;
		GXmlDomDocument* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		gchar* _tmp51_;
		gchar* _tmp52_;
		GXmlDomDocument* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomElement* _tmp56_;
		GXmlDomNodeList* _tmp57_;
		GXmlDomNodeList* _tmp58_;
		GXmlDomNodeList* _tmp59_;
		GXmlDomDocument* _tmp60_;
		GXmlDomElement* _tmp61_;
		GXmlDomElement* _tmp62_;
		GXmlDomElement* _tmp63_;
		GXmlDomNodeList* _tmp64_;
		GXmlDomNodeList* _tmp65_;
		GXmlDomNodeList* _tmp66_;
		gint _tmp67_;
		gint _tmp68_;
		GXmlDomElement* c = NULL;
		GXmlDomDocument* _tmp69_;
		GXmlDomElement* _tmp70_;
		GXmlDomElement* _tmp71_;
		GXmlDomElement* _tmp72_;
		GXmlDomNodeList* _tmp73_;
		GXmlDomNodeList* _tmp74_;
		GXmlDomNodeList* _tmp75_;
		gpointer _tmp76_;
		GXmlDomNode* _tmp77_;
		GXmlDomElement* _tmp78_;
		GXmlDomElement* _tmp79_;
		GXmlDomElement* _tmp80_;
		GXmlDomElement* _tmp81_;
		GXmlDomElement* _tmp82_;
		gchar* _tmp83_;
		gchar* _tmp84_;
		gchar* _tmp85_;
		GXmlDomElement* _tmp86_;
		gchar* _tmp87_;
		gchar* _tmp88_;
		gchar* _tmp89_;
		GXmlDomElement* _tmp90_;
		gchar* p = NULL;
		GXmlDomElement* _tmp91_;
		gchar* _tmp92_;
		const gchar* _tmp93_;
		const gchar* _tmp94_;
		gchar* _tmp95_ = NULL;
		GXmlDomDocument* _tmp96_;
		gchar* _tmp97_;
		GXmlDomDocument* _tmp98_;
		GXmlDomElement* _tmp99_;
		GXmlDomElement* _tmp100_;
		GXmlDomElement* _tmp101_;
		gchar* _tmp102_;
		gchar* _tmp103_;
		GXmlDomElement* _tmp104_;
		gchar* _tmp105_;
		gchar* _tmp106_;
		gchar* _tmp107_;
		GXmlDomElement* _tmp108_;
		gchar* _tmp109_;
		gchar* _tmp110_;
		gchar* _tmp111_;
		GXmlDomElement* _tmp112_;
		gchar* _tmp113_;
		gchar* _tmp114_;
		GXmlDomElement* _tmp115_;
		gchar* _tmp116_;
		gchar* _tmp117_;
		GXmlDomElement* _tmp118_;
		gchar* _tmp119_;
		gchar* _tmp120_;
		GXmlDomElement* _tmp121_;
		gchar* _tmp122_;
		gchar* _tmp123_;
		GXmlDomElement* c2 = NULL;
		GXmlDomDocument* _tmp124_;
		GXmlDomElement* _tmp125_;
		GXmlDomElement* _tmp126_;
		gchar* _tmp127_;
		gchar* _tmp128_;
		gchar* _tmp129_;
		GXmlDomElement* _tmp130_;
		gchar* _tmp131_;
		gchar* _tmp132_;
		gchar* _tmp133_;
		GXmlDomElement* _tmp134_;
		GXmlDomNamedNodeMap* _tmp135_;
		GXmlDomNamedNodeMap* _tmp136_;
		GXmlDomNamedNodeMap* _tmp137_;
		gint _tmp138_;
		gint _tmp139_;
		GXmlDomDocument* _tmp140_;
		GXmlDomElement* _tmp141_;
		GXmlDomElement* _tmp142_;
		GXmlDomElement* _tmp143_;
		GXmlDomElement* _tmp144_;
		GXmlDomNode* _tmp145_;
		GXmlDomNode* _tmp146_;
		GXmlDomElement* _tmp147_;
		gchar* _tmp148_;
		gchar* _tmp149_;
		gchar* _tmp150_;
		GXmlDomElement* _tmp151_;
		gchar* _tmp152_;
		gchar* _tmp153_;
		gchar* _tmp154_;
		GXmlDomElement* _tmp155_;
		gchar* _tmp156_;
		gchar* _tmp157_;
#line 447 "GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<document_element><child/></document_element>", &_inner_error0_);
#line 447 "GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp0_;
#line 447 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 4933 "GomDocumentTest.c"
			goto __catch97_g_error;
		}
#line 449 "GomDocumentTest.vala"
		_tmp1_ = doc;
#line 449 "GomDocumentTest.vala"
		_tmp2_ = gxml_dom_document_get_document_element (_tmp1_);
#line 449 "GomDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 449 "GomDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 449 "GomDocumentTest.vala"
		_vala_assert (_tmp4_ != NULL, "doc.document_element != null");
#line 449 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp4_);
#line 450 "GomDocumentTest.vala"
		_tmp5_ = doc;
#line 450 "GomDocumentTest.vala"
		_tmp6_ = gxml_dom_document_get_document_element (_tmp5_);
#line 450 "GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 450 "GomDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 450 "GomDocumentTest.vala"
		_tmp9_ = gxml_dom_element_get_namespace_uri (_tmp8_);
#line 450 "GomDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 450 "GomDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 450 "GomDocumentTest.vala"
		_vala_assert (_tmp11_ == NULL, "doc.document_element.namespace_uri == null");
#line 450 "GomDocumentTest.vala"
		_g_free0 (_tmp11_);
#line 450 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp8_);
#line 451 "GomDocumentTest.vala"
		_tmp12_ = doc;
#line 451 "GomDocumentTest.vala"
		_tmp13_ = gxml_dom_document_get_document_element (_tmp12_);
#line 451 "GomDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 451 "GomDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 451 "GomDocumentTest.vala"
		_tmp16_ = gxml_dom_element_get_prefix (_tmp15_);
#line 451 "GomDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 451 "GomDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 451 "GomDocumentTest.vala"
		_vala_assert (_tmp18_ == NULL, "doc.document_element.prefix == null");
#line 451 "GomDocumentTest.vala"
		_g_free0 (_tmp18_);
#line 451 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 452 "GomDocumentTest.vala"
		_tmp19_ = doc;
#line 452 "GomDocumentTest.vala"
		_tmp20_ = gxml_dom_document_get_document_element (_tmp19_);
#line 452 "GomDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 452 "GomDocumentTest.vala"
		_tmp22_ = _tmp21_;
#line 452 "GomDocumentTest.vala"
		_tmp23_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp22_, NULL);
#line 452 "GomDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 452 "GomDocumentTest.vala"
		_vala_assert (_tmp24_ == NULL, "doc.document_element.lookup_namespace_uri (null) == null");
#line 452 "GomDocumentTest.vala"
		_g_free0 (_tmp24_);
#line 452 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp22_);
#line 453 "GomDocumentTest.vala"
		_tmp25_ = doc;
#line 453 "GomDocumentTest.vala"
		_tmp26_ = gxml_dom_document_get_document_element (_tmp25_);
#line 453 "GomDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 453 "GomDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 453 "GomDocumentTest.vala"
		gxml_dom_element_set_attribute_ns (_tmp28_, "http://www.w3.org/2000/xmlns/", "xmlns", "http://www.gnome.org/GXml", &_inner_error0_);
#line 453 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp28_);
#line 453 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 453 "GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 5022 "GomDocumentTest.c"
			goto __catch97_g_error;
		}
#line 455 "GomDocumentTest.vala"
		_tmp29_ = doc;
#line 455 "GomDocumentTest.vala"
		_tmp30_ = gxml_dom_document_get_document_element (_tmp29_);
#line 455 "GomDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 455 "GomDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 455 "GomDocumentTest.vala"
		_vala_assert (_tmp32_ != NULL, "doc.document_element != null");
#line 455 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp32_);
#line 456 "GomDocumentTest.vala"
		_tmp33_ = doc;
#line 456 "GomDocumentTest.vala"
		_tmp34_ = gxml_dom_document_get_document_element (_tmp33_);
#line 456 "GomDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 456 "GomDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 456 "GomDocumentTest.vala"
		_tmp37_ = gxml_dom_element_get_namespace_uri (_tmp36_);
#line 456 "GomDocumentTest.vala"
		_tmp38_ = _tmp37_;
#line 456 "GomDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 456 "GomDocumentTest.vala"
		_vala_assert (_tmp39_ == NULL, "doc.document_element.namespace_uri == null");
#line 456 "GomDocumentTest.vala"
		_g_free0 (_tmp39_);
#line 456 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp36_);
#line 457 "GomDocumentTest.vala"
		_tmp40_ = doc;
#line 457 "GomDocumentTest.vala"
		_tmp41_ = gxml_dom_document_get_document_element (_tmp40_);
#line 457 "GomDocumentTest.vala"
		_tmp42_ = _tmp41_;
#line 457 "GomDocumentTest.vala"
		_tmp43_ = _tmp42_;
#line 457 "GomDocumentTest.vala"
		_tmp44_ = gxml_dom_element_get_prefix (_tmp43_);
#line 457 "GomDocumentTest.vala"
		_tmp45_ = _tmp44_;
#line 457 "GomDocumentTest.vala"
		_tmp46_ = _tmp45_;
#line 457 "GomDocumentTest.vala"
		_vala_assert (_tmp46_ == NULL, "doc.document_element.prefix == null");
#line 457 "GomDocumentTest.vala"
		_g_free0 (_tmp46_);
#line 457 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp43_);
#line 458 "GomDocumentTest.vala"
		_tmp47_ = doc;
#line 458 "GomDocumentTest.vala"
		_tmp48_ = gxml_dom_document_get_document_element (_tmp47_);
#line 458 "GomDocumentTest.vala"
		_tmp49_ = _tmp48_;
#line 458 "GomDocumentTest.vala"
		_tmp50_ = _tmp49_;
#line 458 "GomDocumentTest.vala"
		_tmp51_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp50_, NULL);
#line 458 "GomDocumentTest.vala"
		_tmp52_ = _tmp51_;
#line 458 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp52_, "http://www.gnome.org/GXml") == 0, "doc.document_element.lookup_namespace_uri (null) == \"http://www.gnome.org/GXml\"");
#line 458 "GomDocumentTest.vala"
		_g_free0 (_tmp52_);
#line 458 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp50_);
#line 459 "GomDocumentTest.vala"
		_tmp53_ = doc;
#line 459 "GomDocumentTest.vala"
		_tmp54_ = gxml_dom_document_get_document_element (_tmp53_);
#line 459 "GomDocumentTest.vala"
		_tmp55_ = _tmp54_;
#line 459 "GomDocumentTest.vala"
		_tmp56_ = _tmp55_;
#line 459 "GomDocumentTest.vala"
		_tmp57_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp56_);
#line 459 "GomDocumentTest.vala"
		_tmp58_ = _tmp57_;
#line 459 "GomDocumentTest.vala"
		_tmp59_ = _tmp58_;
#line 459 "GomDocumentTest.vala"
		_vala_assert (_tmp59_ != NULL, "doc.document_element.child_nodes != null");
#line 459 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp59_);
#line 459 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp56_);
#line 460 "GomDocumentTest.vala"
		_tmp60_ = doc;
#line 460 "GomDocumentTest.vala"
		_tmp61_ = gxml_dom_document_get_document_element (_tmp60_);
#line 460 "GomDocumentTest.vala"
		_tmp62_ = _tmp61_;
#line 460 "GomDocumentTest.vala"
		_tmp63_ = _tmp62_;
#line 460 "GomDocumentTest.vala"
		_tmp64_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp63_);
#line 460 "GomDocumentTest.vala"
		_tmp65_ = _tmp64_;
#line 460 "GomDocumentTest.vala"
		_tmp66_ = _tmp65_;
#line 460 "GomDocumentTest.vala"
		_tmp67_ = gee_collection_get_size ((GeeCollection*) _tmp66_);
#line 460 "GomDocumentTest.vala"
		_tmp68_ = _tmp67_;
#line 460 "GomDocumentTest.vala"
		_vala_assert (_tmp68_ == 1, "doc.document_element.child_nodes.size == 1");
#line 460 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp66_);
#line 460 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp63_);
#line 461 "GomDocumentTest.vala"
		_tmp69_ = doc;
#line 461 "GomDocumentTest.vala"
		_tmp70_ = gxml_dom_document_get_document_element (_tmp69_);
#line 461 "GomDocumentTest.vala"
		_tmp71_ = _tmp70_;
#line 461 "GomDocumentTest.vala"
		_tmp72_ = _tmp71_;
#line 461 "GomDocumentTest.vala"
		_tmp73_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp72_);
#line 461 "GomDocumentTest.vala"
		_tmp74_ = _tmp73_;
#line 461 "GomDocumentTest.vala"
		_tmp75_ = _tmp74_;
#line 461 "GomDocumentTest.vala"
		_tmp76_ = gee_list_get ((GeeList*) _tmp75_, 0);
#line 461 "GomDocumentTest.vala"
		_tmp77_ = (GXmlDomNode*) _tmp76_;
#line 461 "GomDocumentTest.vala"
		_tmp78_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp77_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp77_) : NULL;
#line 461 "GomDocumentTest.vala"
		if (_tmp78_ == NULL) {
#line 461 "GomDocumentTest.vala"
			_g_object_unref0 (_tmp77_);
#line 5163 "GomDocumentTest.c"
		}
#line 461 "GomDocumentTest.vala"
		_tmp79_ = _tmp78_;
#line 461 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp75_);
#line 461 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp72_);
#line 461 "GomDocumentTest.vala"
		c = _tmp79_;
#line 462 "GomDocumentTest.vala"
		_tmp80_ = c;
#line 462 "GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp80_, GXML_TYPE_DOM_ELEMENT), "c is DomElement");
#line 463 "GomDocumentTest.vala"
		_tmp81_ = c;
#line 463 "GomDocumentTest.vala"
		gxml_dom_element_set_attribute_ns (_tmp81_, "http://www.w3.org/2000/xmlns/", "xmlns:gxml2", "http://www.gnome.org/GXml2", &_inner_error0_);
#line 463 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 463 "GomDocumentTest.vala"
			_g_object_unref0 (c);
#line 463 "GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 5187 "GomDocumentTest.c"
			goto __catch97_g_error;
		}
#line 465 "GomDocumentTest.vala"
		_tmp82_ = c;
#line 465 "GomDocumentTest.vala"
		_tmp83_ = gxml_dom_element_get_prefix (_tmp82_);
#line 465 "GomDocumentTest.vala"
		_tmp84_ = _tmp83_;
#line 465 "GomDocumentTest.vala"
		_tmp85_ = _tmp84_;
#line 465 "GomDocumentTest.vala"
		_vala_assert (_tmp85_ == NULL, "c.prefix == null");
#line 465 "GomDocumentTest.vala"
		_g_free0 (_tmp85_);
#line 466 "GomDocumentTest.vala"
		_tmp86_ = c;
#line 466 "GomDocumentTest.vala"
		_tmp87_ = gxml_dom_element_get_namespace_uri (_tmp86_);
#line 466 "GomDocumentTest.vala"
		_tmp88_ = _tmp87_;
#line 466 "GomDocumentTest.vala"
		_tmp89_ = _tmp88_;
#line 466 "GomDocumentTest.vala"
		_vala_assert (_tmp89_ == NULL, "c.namespace_uri == null");
#line 466 "GomDocumentTest.vala"
		_g_free0 (_tmp89_);
#line 467 "GomDocumentTest.vala"
		_tmp90_ = c;
#line 467 "GomDocumentTest.vala"
		gxml_dom_element_set_attribute_ns (_tmp90_, "http://www.gnome.org/GXml2", "gxml2:prop", "val", &_inner_error0_);
#line 467 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 467 "GomDocumentTest.vala"
			_g_object_unref0 (c);
#line 467 "GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 5224 "GomDocumentTest.c"
			goto __catch97_g_error;
		}
#line 468 "GomDocumentTest.vala"
		_tmp91_ = c;
#line 468 "GomDocumentTest.vala"
		_tmp92_ = gxml_dom_element_get_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (_tmp91_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp91_) : NULL, "http://www.gnome.org/GXml2", "prop");
#line 468 "GomDocumentTest.vala"
		p = _tmp92_;
#line 470 "GomDocumentTest.vala"
		_tmp93_ = p;
#line 470 "GomDocumentTest.vala"
		_vala_assert (_tmp93_ != NULL, "p != null");
#line 471 "GomDocumentTest.vala"
		_tmp94_ = p;
#line 471 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp94_, "val") == 0, "p == \"val\"");
#line 472 "GomDocumentTest.vala"
		_tmp96_ = doc;
#line 472 "GomDocumentTest.vala"
		_tmp97_ = gxml_dom_document_write_string ((GXmlDomDocument*) (G_TYPE_CHECK_INSTANCE_TYPE (_tmp96_, GXML_TYPE_GOM_DOCUMENT) ? ((GXmlGomDocument*) _tmp96_) : NULL), NULL, &_inner_error0_);
#line 472 "GomDocumentTest.vala"
		_tmp95_ = _tmp97_;
#line 472 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 472 "GomDocumentTest.vala"
			_g_free0 (p);
#line 472 "GomDocumentTest.vala"
			_g_object_unref0 (c);
#line 472 "GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 5255 "GomDocumentTest.c"
			goto __catch97_g_error;
		}
#line 472 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:472: %s", _tmp95_);
#line 473 "GomDocumentTest.vala"
		_tmp98_ = doc;
#line 473 "GomDocumentTest.vala"
		_tmp99_ = gxml_dom_document_get_document_element (_tmp98_);
#line 473 "GomDocumentTest.vala"
		_tmp100_ = _tmp99_;
#line 473 "GomDocumentTest.vala"
		_tmp101_ = _tmp100_;
#line 473 "GomDocumentTest.vala"
		_tmp102_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp101_, NULL);
#line 473 "GomDocumentTest.vala"
		_tmp103_ = _tmp102_;
#line 473 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp103_, "http://www.gnome.org/GXml") == 0, "doc.document_element.lookup_namespace_uri (null) == \"http://www.gnome.org/GXml\"");
#line 473 "GomDocumentTest.vala"
		_g_free0 (_tmp103_);
#line 473 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp101_);
#line 474 "GomDocumentTest.vala"
		_tmp104_ = c;
#line 474 "GomDocumentTest.vala"
		_tmp105_ = gxml_dom_element_get_prefix (_tmp104_);
#line 474 "GomDocumentTest.vala"
		_tmp106_ = _tmp105_;
#line 474 "GomDocumentTest.vala"
		_tmp107_ = _tmp106_;
#line 474 "GomDocumentTest.vala"
		_vala_assert (_tmp107_ == NULL, "c.prefix == null");
#line 474 "GomDocumentTest.vala"
		_g_free0 (_tmp107_);
#line 475 "GomDocumentTest.vala"
		_tmp108_ = c;
#line 475 "GomDocumentTest.vala"
		_tmp109_ = gxml_dom_element_get_namespace_uri (_tmp108_);
#line 475 "GomDocumentTest.vala"
		_tmp110_ = _tmp109_;
#line 475 "GomDocumentTest.vala"
		_tmp111_ = _tmp110_;
#line 475 "GomDocumentTest.vala"
		_vala_assert (_tmp111_ == NULL, "c.namespace_uri == null");
#line 475 "GomDocumentTest.vala"
		_g_free0 (_tmp111_);
#line 476 "GomDocumentTest.vala"
		_tmp112_ = c;
#line 476 "GomDocumentTest.vala"
		_tmp113_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp112_, NULL);
#line 476 "GomDocumentTest.vala"
		_tmp114_ = _tmp113_;
#line 476 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp114_, "http://www.gnome.org/GXml") == 0, "c.lookup_namespace_uri (null) == \"http://www.gnome.org/GXml\"");
#line 476 "GomDocumentTest.vala"
		_g_free0 (_tmp114_);
#line 477 "GomDocumentTest.vala"
		_tmp115_ = c;
#line 477 "GomDocumentTest.vala"
		_tmp116_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp115_, "gxml2");
#line 477 "GomDocumentTest.vala"
		_tmp117_ = _tmp116_;
#line 477 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp117_, "http://www.gnome.org/GXml2") == 0, "c.lookup_namespace_uri (\"gxml2\") == \"http://www.gnome.org/GXml2\"");
#line 477 "GomDocumentTest.vala"
		_g_free0 (_tmp117_);
#line 478 "GomDocumentTest.vala"
		_tmp118_ = c;
#line 478 "GomDocumentTest.vala"
		_tmp119_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) _tmp118_, "http://www.gnome.org/GXml3");
#line 478 "GomDocumentTest.vala"
		_tmp120_ = _tmp119_;
#line 478 "GomDocumentTest.vala"
		_vala_assert (_tmp120_ == NULL, "c.lookup_prefix (\"http://www.gnome.org/GXml3\") == null");
#line 478 "GomDocumentTest.vala"
		_g_free0 (_tmp120_);
#line 479 "GomDocumentTest.vala"
		_tmp121_ = c;
#line 479 "GomDocumentTest.vala"
		_tmp122_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) _tmp121_, "http://www.gnome.org/GXml2");
#line 479 "GomDocumentTest.vala"
		_tmp123_ = _tmp122_;
#line 479 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp123_, "gxml2") == 0, "c.lookup_prefix (\"http://www.gnome.org/GXml2\") == \"gxml2\"");
#line 479 "GomDocumentTest.vala"
		_g_free0 (_tmp123_);
#line 480 "GomDocumentTest.vala"
		_tmp124_ = doc;
#line 480 "GomDocumentTest.vala"
		_tmp125_ = gxml_dom_document_create_element_ns (_tmp124_, "http://www.gnome.org/GXml/testing", "t:child2", &_inner_error0_);
#line 480 "GomDocumentTest.vala"
		c2 = _tmp125_;
#line 480 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 480 "GomDocumentTest.vala"
			_g_free0 (_tmp95_);
#line 480 "GomDocumentTest.vala"
			_g_free0 (p);
#line 480 "GomDocumentTest.vala"
			_g_object_unref0 (c);
#line 480 "GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 5358 "GomDocumentTest.c"
			goto __catch97_g_error;
		}
#line 482 "GomDocumentTest.vala"
		_tmp126_ = c2;
#line 482 "GomDocumentTest.vala"
		_tmp127_ = gxml_dom_element_get_prefix (_tmp126_);
#line 482 "GomDocumentTest.vala"
		_tmp128_ = _tmp127_;
#line 482 "GomDocumentTest.vala"
		_tmp129_ = _tmp128_;
#line 482 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp129_, "t") == 0, "c2.prefix == \"t\"");
#line 482 "GomDocumentTest.vala"
		_g_free0 (_tmp129_);
#line 483 "GomDocumentTest.vala"
		_tmp130_ = c2;
#line 483 "GomDocumentTest.vala"
		_tmp131_ = gxml_dom_element_get_namespace_uri (_tmp130_);
#line 483 "GomDocumentTest.vala"
		_tmp132_ = _tmp131_;
#line 483 "GomDocumentTest.vala"
		_tmp133_ = _tmp132_;
#line 483 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp133_, "http://www.gnome.org/GXml/testing") == 0, "c2.namespace_uri == \"http://www.gnome.org/GXml/testing\"");
#line 483 "GomDocumentTest.vala"
		_g_free0 (_tmp133_);
#line 484 "GomDocumentTest.vala"
		_tmp134_ = c2;
#line 484 "GomDocumentTest.vala"
		_tmp135_ = gxml_dom_element_get_attributes (_tmp134_);
#line 484 "GomDocumentTest.vala"
		_tmp136_ = _tmp135_;
#line 484 "GomDocumentTest.vala"
		_tmp137_ = _tmp136_;
#line 484 "GomDocumentTest.vala"
		_tmp138_ = gee_map_get_size ((GeeMap*) _tmp137_);
#line 484 "GomDocumentTest.vala"
		_tmp139_ = _tmp138_;
#line 484 "GomDocumentTest.vala"
		_vala_assert (_tmp139_ == 0, "c2.attributes.size == 0");
#line 484 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp137_);
#line 485 "GomDocumentTest.vala"
		_tmp140_ = doc;
#line 485 "GomDocumentTest.vala"
		_tmp141_ = gxml_dom_document_get_document_element (_tmp140_);
#line 485 "GomDocumentTest.vala"
		_tmp142_ = _tmp141_;
#line 485 "GomDocumentTest.vala"
		_tmp143_ = _tmp142_;
#line 485 "GomDocumentTest.vala"
		_tmp144_ = c2;
#line 485 "GomDocumentTest.vala"
		_tmp145_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp143_, (GXmlDomNode*) _tmp144_, &_inner_error0_);
#line 485 "GomDocumentTest.vala"
		_tmp146_ = _tmp145_;
#line 485 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp146_);
#line 485 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp143_);
#line 485 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 485 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 485 "GomDocumentTest.vala"
			_g_free0 (_tmp95_);
#line 485 "GomDocumentTest.vala"
			_g_free0 (p);
#line 485 "GomDocumentTest.vala"
			_g_object_unref0 (c);
#line 485 "GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 5431 "GomDocumentTest.c"
			goto __catch97_g_error;
		}
#line 486 "GomDocumentTest.vala"
		_tmp147_ = c2;
#line 486 "GomDocumentTest.vala"
		_tmp148_ = gxml_dom_element_get_prefix (_tmp147_);
#line 486 "GomDocumentTest.vala"
		_tmp149_ = _tmp148_;
#line 486 "GomDocumentTest.vala"
		_tmp150_ = _tmp149_;
#line 486 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp150_, "t") == 0, "c2.prefix == \"t\"");
#line 486 "GomDocumentTest.vala"
		_g_free0 (_tmp150_);
#line 487 "GomDocumentTest.vala"
		_tmp151_ = c2;
#line 487 "GomDocumentTest.vala"
		_tmp152_ = gxml_dom_element_get_namespace_uri (_tmp151_);
#line 487 "GomDocumentTest.vala"
		_tmp153_ = _tmp152_;
#line 487 "GomDocumentTest.vala"
		_tmp154_ = _tmp153_;
#line 487 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp154_, "http://www.gnome.org/GXml/testing") == 0, "c2.namespace_uri == \"http://www.gnome.org/GXml/testing\"");
#line 487 "GomDocumentTest.vala"
		_g_free0 (_tmp154_);
#line 488 "GomDocumentTest.vala"
		_tmp155_ = c2;
#line 488 "GomDocumentTest.vala"
		_tmp156_ = gxml_dom_element_get_attribute_ns (_tmp155_, "http://www.w3.org/2000/xmlns/", "t");
#line 488 "GomDocumentTest.vala"
		_tmp157_ = _tmp156_;
#line 488 "GomDocumentTest.vala"
		_vala_assert (_tmp157_ == NULL, "c2.get_attribute_ns (\"http://www.w3.org/2000/xmlns/\", \t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t \"t\") == null");
#line 488 "GomDocumentTest.vala"
		_g_free0 (_tmp157_);
#line 446 "GomDocumentTest.vala"
		_g_object_unref0 (c2);
#line 446 "GomDocumentTest.vala"
		_g_free0 (_tmp95_);
#line 446 "GomDocumentTest.vala"
		_g_free0 (p);
#line 446 "GomDocumentTest.vala"
		_g_object_unref0 (c);
#line 446 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 5478 "GomDocumentTest.c"
	}
	goto __finally97;
	__catch97_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp158_;
		gchar* _tmp159_;
		gchar* _tmp160_;
#line 446 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 446 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 491 "GomDocumentTest.vala"
		_tmp158_ = e->message;
#line 491 "GomDocumentTest.vala"
		_tmp159_ = g_strconcat ("ERROR: ", _tmp158_, NULL);
#line 491 "GomDocumentTest.vala"
		_tmp160_ = _tmp159_;
#line 491 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:491: %s", _tmp160_);
#line 491 "GomDocumentTest.vala"
		_g_free0 (_tmp160_);
#line 492 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 446 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 5505 "GomDocumentTest.c"
	}
	__finally97:
#line 446 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 446 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 446 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 446 "GomDocumentTest.vala"
		return;
#line 5516 "GomDocumentTest.c"
	}
}

static void
___lambda84__gtest_func (void)
{
#line 445 "GomDocumentTest.vala"
	__lambda84_ ();
#line 5525 "GomDocumentTest.c"
}

static void
__lambda85_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlDomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlDomElement* _tmp1_;
		GXmlDomElement* _tmp2_;
		GXmlDomElement* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
#line 497 "GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("\n" \
"\t\t\t\t<Project xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-n" \
"s#\"\n" \
"         xmlns:rdfs=\"http://www.w3.org/2000/01/rdf-schema#\"\n" \
"         xmlns:foaf=\"http://xmlns.com/foaf/0.1/\"\n" \
"         xmlns:gnome=\"http://api.gnome.org/doap-extensions#\"\n" \
"         xmlns=\"http://usefulinc.com/ns/doap#\"><child/></Project>", &_inner_error0_);
#line 497 "GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp0_;
#line 497 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 5547 "GomDocumentTest.c"
			goto __catch98_g_error;
		}
#line 503 "GomDocumentTest.vala"
		_tmp1_ = gxml_dom_document_get_document_element (doc);
#line 503 "GomDocumentTest.vala"
		_tmp2_ = _tmp1_;
#line 503 "GomDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 503 "GomDocumentTest.vala"
		_tmp4_ = gxml_dom_element_get_prefix (_tmp3_);
#line 503 "GomDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 503 "GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 503 "GomDocumentTest.vala"
		_vala_assert (_tmp6_ == NULL, "doc.document_element.prefix == null");
#line 503 "GomDocumentTest.vala"
		_g_free0 (_tmp6_);
#line 503 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp3_);
#line 496 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 5570 "GomDocumentTest.c"
	}
	goto __finally98;
	__catch98_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
#line 496 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 496 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 510 "GomDocumentTest.vala"
		_tmp7_ = e->message;
#line 510 "GomDocumentTest.vala"
		_tmp8_ = g_strconcat ("ERROR: ", _tmp7_, NULL);
#line 510 "GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 510 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:510: %s", _tmp9_);
#line 510 "GomDocumentTest.vala"
		_g_free0 (_tmp9_);
#line 511 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 496 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 5597 "GomDocumentTest.c"
	}
	__finally98:
#line 496 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 496 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 496 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 496 "GomDocumentTest.vala"
		return;
#line 5608 "GomDocumentTest.c"
	}
}

static void
___lambda85__gtest_func (void)
{
#line 495 "GomDocumentTest.vala"
	__lambda85_ ();
#line 5617 "GomDocumentTest.c"
}

static void
__lambda86_ (void)
{
	GXmlDomDocument* doc = NULL;
	GXmlDomDocument* _tmp11_;
	GXmlDomElement* _tmp12_;
	GXmlDomElement* _tmp13_;
	GXmlDomElement* _tmp14_;
	GXmlDomDocument* _tmp15_;
	GXmlDomElement* _tmp16_;
	GXmlDomElement* _tmp17_;
	GXmlDomElement* _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	gchar* _tmp21_;
	GXmlDomDocument* _tmp22_;
	GXmlDomElement* _tmp23_;
	GXmlDomElement* _tmp24_;
	GXmlDomElement* _tmp25_;
	gchar* _tmp26_;
	gchar* _tmp27_;
	gchar* _tmp28_;
	GXmlDomDocument* _tmp29_;
	GXmlDomElement* _tmp30_;
	GXmlDomElement* _tmp31_;
	GXmlDomElement* _tmp32_;
	GXmlDomNodeList* _tmp33_;
	GXmlDomNodeList* _tmp34_;
	GXmlDomNodeList* _tmp35_;
	GXmlDomDocument* _tmp40_;
	GXmlDomElement* _tmp41_;
	GXmlDomElement* _tmp42_;
	GXmlDomElement* _tmp43_;
	GXmlDomNodeList* _tmp44_;
	GXmlDomNodeList* _tmp45_;
	GXmlDomNodeList* _tmp46_;
	gint _tmp47_;
	gint _tmp48_;
	GXmlDomElement* c = NULL;
	GXmlDomDocument* _tmp49_;
	GXmlDomElement* _tmp50_;
	GXmlDomElement* _tmp51_;
	GXmlDomElement* _tmp52_;
	GXmlDomNodeList* _tmp53_;
	GXmlDomNodeList* _tmp54_;
	GXmlDomNodeList* _tmp55_;
	gpointer _tmp56_;
	GXmlDomNode* _tmp57_;
	GXmlDomElement* _tmp58_;
	GXmlDomElement* _tmp59_;
	GXmlDomNamedNodeMap* _tmp63_;
	GXmlDomNamedNodeMap* _tmp64_;
	GXmlDomNamedNodeMap* _tmp65_;
	gint _tmp66_;
	gint _tmp67_;
	gchar* _tmp68_;
	gchar* _tmp69_;
	gchar* _tmp70_;
	gchar* _tmp71_;
	gchar* _tmp72_;
	gchar* _tmp73_;
	GXmlDomNamedNodeMap* _tmp74_;
	GXmlDomNamedNodeMap* _tmp75_;
	GXmlDomNamedNodeMap* _tmp76_;
	gint _tmp77_;
	gint _tmp78_;
	gchar* _tmp79_;
	gchar* _tmp80_;
	gchar* _tmp81_;
	gchar* _tmp82_;
	gchar* _tmp83_;
	gchar* _tmp84_;
	gchar* p = NULL;
	gchar* _tmp85_;
	GError* _inner_error0_ = NULL;
#line 515 "GomDocumentTest.vala"
	doc = NULL;
#line 5697 "GomDocumentTest.c"
	{
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_;
		GXmlGomDocument* _tmp2_;
#line 516 "GomDocumentTest.vala"
		_tmp1_ = gxml_gom_document_new_from_string ("<document_element><child/></document_element>", &_inner_error0_);
#line 516 "GomDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 516 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 5708 "GomDocumentTest.c"
			goto __catch99_g_error;
		}
#line 516 "GomDocumentTest.vala"
		_tmp2_ = _tmp0_;
#line 516 "GomDocumentTest.vala"
		_tmp0_ = NULL;
#line 516 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 516 "GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp2_;
#line 516 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 5721 "GomDocumentTest.c"
	}
	goto __finally99;
	__catch99_g_error:
	{
		GError* e = NULL;
		GError* _tmp3_;
		const gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
#line 516 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 516 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 517 "GomDocumentTest.vala"
		_tmp3_ = e;
#line 517 "GomDocumentTest.vala"
		_tmp4_ = _tmp3_->message;
#line 517 "GomDocumentTest.vala"
		_tmp5_ = g_strconcat ("ERROR: ", _tmp4_, NULL);
#line 517 "GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 517 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:517: %s", _tmp6_);
#line 517 "GomDocumentTest.vala"
		_g_free0 (_tmp6_);
#line 516 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 5749 "GomDocumentTest.c"
	}
	__finally99:
#line 516 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 516 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 516 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 516 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 516 "GomDocumentTest.vala"
		return;
#line 5762 "GomDocumentTest.c"
	}
	{
		GXmlDomDocument* _tmp7_;
		GXmlDomElement* _tmp8_;
		GXmlDomElement* _tmp9_;
		GXmlDomElement* _tmp10_;
#line 519 "GomDocumentTest.vala"
		_tmp7_ = doc;
#line 519 "GomDocumentTest.vala"
		_tmp8_ = gxml_dom_document_get_document_element (_tmp7_);
#line 519 "GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 519 "GomDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 519 "GomDocumentTest.vala"
		gxml_dom_element_set_attribute_ns (_tmp10_, "http://local", "xmlns:", "http://www.gnome.org/GXml", &_inner_error0_);
#line 519 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp10_);
#line 519 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 5783 "GomDocumentTest.c"
			goto __catch100_g_error;
		}
#line 521 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 5788 "GomDocumentTest.c"
	}
	goto __finally100;
	__catch100_g_error:
	{
#line 518 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 518 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 5797 "GomDocumentTest.c"
	}
	__finally100:
#line 518 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 518 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 518 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 518 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 518 "GomDocumentTest.vala"
		return;
#line 5810 "GomDocumentTest.c"
	}
#line 523 "GomDocumentTest.vala"
	_tmp11_ = doc;
#line 523 "GomDocumentTest.vala"
	_tmp12_ = gxml_dom_document_get_document_element (_tmp11_);
#line 523 "GomDocumentTest.vala"
	_tmp13_ = _tmp12_;
#line 523 "GomDocumentTest.vala"
	_tmp14_ = _tmp13_;
#line 523 "GomDocumentTest.vala"
	_vala_assert (_tmp14_ != NULL, "doc.document_element != null");
#line 523 "GomDocumentTest.vala"
	_g_object_unref0 (_tmp14_);
#line 524 "GomDocumentTest.vala"
	_tmp15_ = doc;
#line 524 "GomDocumentTest.vala"
	_tmp16_ = gxml_dom_document_get_document_element (_tmp15_);
#line 524 "GomDocumentTest.vala"
	_tmp17_ = _tmp16_;
#line 524 "GomDocumentTest.vala"
	_tmp18_ = _tmp17_;
#line 524 "GomDocumentTest.vala"
	_tmp19_ = gxml_dom_element_get_namespace_uri (_tmp18_);
#line 524 "GomDocumentTest.vala"
	_tmp20_ = _tmp19_;
#line 524 "GomDocumentTest.vala"
	_tmp21_ = _tmp20_;
#line 524 "GomDocumentTest.vala"
	_vala_assert (_tmp21_ == NULL, "doc.document_element.namespace_uri == null");
#line 524 "GomDocumentTest.vala"
	_g_free0 (_tmp21_);
#line 524 "GomDocumentTest.vala"
	_g_object_unref0 (_tmp18_);
#line 525 "GomDocumentTest.vala"
	_tmp22_ = doc;
#line 525 "GomDocumentTest.vala"
	_tmp23_ = gxml_dom_document_get_document_element (_tmp22_);
#line 525 "GomDocumentTest.vala"
	_tmp24_ = _tmp23_;
#line 525 "GomDocumentTest.vala"
	_tmp25_ = _tmp24_;
#line 525 "GomDocumentTest.vala"
	_tmp26_ = gxml_dom_element_get_prefix (_tmp25_);
#line 525 "GomDocumentTest.vala"
	_tmp27_ = _tmp26_;
#line 525 "GomDocumentTest.vala"
	_tmp28_ = _tmp27_;
#line 525 "GomDocumentTest.vala"
	_vala_assert (_tmp28_ == NULL, "doc.document_element.prefix == null");
#line 525 "GomDocumentTest.vala"
	_g_free0 (_tmp28_);
#line 525 "GomDocumentTest.vala"
	_g_object_unref0 (_tmp25_);
#line 526 "GomDocumentTest.vala"
	_tmp29_ = doc;
#line 526 "GomDocumentTest.vala"
	_tmp30_ = gxml_dom_document_get_document_element (_tmp29_);
#line 526 "GomDocumentTest.vala"
	_tmp31_ = _tmp30_;
#line 526 "GomDocumentTest.vala"
	_tmp32_ = _tmp31_;
#line 526 "GomDocumentTest.vala"
	_tmp33_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp32_);
#line 526 "GomDocumentTest.vala"
	_tmp34_ = _tmp33_;
#line 526 "GomDocumentTest.vala"
	_tmp35_ = _tmp34_;
#line 526 "GomDocumentTest.vala"
	_vala_assert (_tmp35_ != NULL, "doc.document_element.child_nodes != null");
#line 526 "GomDocumentTest.vala"
	_g_object_unref0 (_tmp35_);
#line 526 "GomDocumentTest.vala"
	_g_object_unref0 (_tmp32_);
#line 5884 "GomDocumentTest.c"
	{
		GXmlDomDocument* _tmp36_;
		GXmlDomElement* _tmp37_;
		GXmlDomElement* _tmp38_;
		GXmlDomElement* _tmp39_;
#line 528 "GomDocumentTest.vala"
		_tmp36_ = doc;
#line 528 "GomDocumentTest.vala"
		_tmp37_ = gxml_dom_document_get_document_element (_tmp36_);
#line 528 "GomDocumentTest.vala"
		_tmp38_ = _tmp37_;
#line 528 "GomDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 528 "GomDocumentTest.vala"
		gxml_dom_element_set_attribute_ns (_tmp39_, "http://www.gnome.org/GXml", "xmlns", "http://www.gnome.org/GXml", &_inner_error0_);
#line 528 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp39_);
#line 528 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 5904 "GomDocumentTest.c"
			goto __catch101_g_error;
		}
#line 530 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 5909 "GomDocumentTest.c"
	}
	goto __finally101;
	__catch101_g_error:
	{
#line 527 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 527 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 5918 "GomDocumentTest.c"
	}
	__finally101:
#line 527 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 527 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 527 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 527 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 527 "GomDocumentTest.vala"
		return;
#line 5931 "GomDocumentTest.c"
	}
#line 532 "GomDocumentTest.vala"
	_tmp40_ = doc;
#line 532 "GomDocumentTest.vala"
	_tmp41_ = gxml_dom_document_get_document_element (_tmp40_);
#line 532 "GomDocumentTest.vala"
	_tmp42_ = _tmp41_;
#line 532 "GomDocumentTest.vala"
	_tmp43_ = _tmp42_;
#line 532 "GomDocumentTest.vala"
	_tmp44_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp43_);
#line 532 "GomDocumentTest.vala"
	_tmp45_ = _tmp44_;
#line 532 "GomDocumentTest.vala"
	_tmp46_ = _tmp45_;
#line 532 "GomDocumentTest.vala"
	_tmp47_ = gee_collection_get_size ((GeeCollection*) _tmp46_);
#line 532 "GomDocumentTest.vala"
	_tmp48_ = _tmp47_;
#line 532 "GomDocumentTest.vala"
	_vala_assert (_tmp48_ == 1, "doc.document_element.child_nodes.size == 1");
#line 532 "GomDocumentTest.vala"
	_g_object_unref0 (_tmp46_);
#line 532 "GomDocumentTest.vala"
	_g_object_unref0 (_tmp43_);
#line 533 "GomDocumentTest.vala"
	_tmp49_ = doc;
#line 533 "GomDocumentTest.vala"
	_tmp50_ = gxml_dom_document_get_document_element (_tmp49_);
#line 533 "GomDocumentTest.vala"
	_tmp51_ = _tmp50_;
#line 533 "GomDocumentTest.vala"
	_tmp52_ = _tmp51_;
#line 533 "GomDocumentTest.vala"
	_tmp53_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp52_);
#line 533 "GomDocumentTest.vala"
	_tmp54_ = _tmp53_;
#line 533 "GomDocumentTest.vala"
	_tmp55_ = _tmp54_;
#line 533 "GomDocumentTest.vala"
	_tmp56_ = gee_list_get ((GeeList*) _tmp55_, 0);
#line 533 "GomDocumentTest.vala"
	_tmp57_ = (GXmlDomNode*) _tmp56_;
#line 533 "GomDocumentTest.vala"
	_tmp58_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp57_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp57_) : NULL;
#line 533 "GomDocumentTest.vala"
	if (_tmp58_ == NULL) {
#line 533 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp57_);
#line 5981 "GomDocumentTest.c"
	}
#line 533 "GomDocumentTest.vala"
	_tmp59_ = _tmp58_;
#line 533 "GomDocumentTest.vala"
	_g_object_unref0 (_tmp55_);
#line 533 "GomDocumentTest.vala"
	_g_object_unref0 (_tmp52_);
#line 533 "GomDocumentTest.vala"
	c = _tmp59_;
#line 534 "GomDocumentTest.vala"
	_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (c, GXML_TYPE_DOM_ELEMENT), "c is DomElement");
#line 5993 "GomDocumentTest.c"
	{
#line 536 "GomDocumentTest.vala"
		gxml_dom_element_set_attribute_ns (c, "http://www.w3.org/2000/xmlns/", "xmlns:gxml2", "http://www.gnome.org/GXml2", &_inner_error0_);
#line 536 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 5999 "GomDocumentTest.c"
			goto __catch102_g_error;
		}
	}
	goto __finally102;
	__catch102_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp60_;
		gchar* _tmp61_;
		gchar* _tmp62_;
#line 535 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 535 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 539 "GomDocumentTest.vala"
		_tmp60_ = e->message;
#line 539 "GomDocumentTest.vala"
		_tmp61_ = g_strconcat ("ERROR: ", _tmp60_, NULL);
#line 539 "GomDocumentTest.vala"
		_tmp62_ = _tmp61_;
#line 539 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:539: %s", _tmp62_);
#line 539 "GomDocumentTest.vala"
		_g_free0 (_tmp62_);
#line 540 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 535 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 6028 "GomDocumentTest.c"
	}
	__finally102:
#line 535 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 535 "GomDocumentTest.vala"
		_g_object_unref0 (c);
#line 535 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 535 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 535 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 535 "GomDocumentTest.vala"
		return;
#line 6043 "GomDocumentTest.c"
	}
#line 542 "GomDocumentTest.vala"
	_tmp63_ = gxml_dom_element_get_attributes (c);
#line 542 "GomDocumentTest.vala"
	_tmp64_ = _tmp63_;
#line 542 "GomDocumentTest.vala"
	_tmp65_ = _tmp64_;
#line 542 "GomDocumentTest.vala"
	_tmp66_ = gee_map_get_size ((GeeMap*) _tmp65_);
#line 542 "GomDocumentTest.vala"
	_tmp67_ = _tmp66_;
#line 542 "GomDocumentTest.vala"
	_vala_assert (_tmp67_ == 1, "c.attributes.size == 1");
#line 542 "GomDocumentTest.vala"
	_g_object_unref0 (_tmp65_);
#line 543 "GomDocumentTest.vala"
	_tmp68_ = gxml_dom_element_get_prefix (c);
#line 543 "GomDocumentTest.vala"
	_tmp69_ = _tmp68_;
#line 543 "GomDocumentTest.vala"
	_tmp70_ = _tmp69_;
#line 543 "GomDocumentTest.vala"
	_vala_assert (_tmp70_ == NULL, "c.prefix == null");
#line 543 "GomDocumentTest.vala"
	_g_free0 (_tmp70_);
#line 544 "GomDocumentTest.vala"
	_tmp71_ = gxml_dom_element_get_namespace_uri (c);
#line 544 "GomDocumentTest.vala"
	_tmp72_ = _tmp71_;
#line 544 "GomDocumentTest.vala"
	_tmp73_ = _tmp72_;
#line 544 "GomDocumentTest.vala"
	_vala_assert (_tmp73_ == NULL, "c.namespace_uri == null");
#line 544 "GomDocumentTest.vala"
	_g_free0 (_tmp73_);
#line 6079 "GomDocumentTest.c"
	{
#line 545 "GomDocumentTest.vala"
		gxml_dom_element_set_attribute_ns (c, "http://www.w3.org/2000/xmlns/", "xmlns:gxml2", "http://www.gnome.org/GXml3", &_inner_error0_);
#line 545 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 6085 "GomDocumentTest.c"
			goto __catch103_g_error;
		}
	}
	goto __finally103;
	__catch103_g_error:
	{
#line 545 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 545 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 6096 "GomDocumentTest.c"
	}
	__finally103:
#line 545 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 545 "GomDocumentTest.vala"
		_g_object_unref0 (c);
#line 545 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 545 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 545 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 545 "GomDocumentTest.vala"
		return;
#line 6111 "GomDocumentTest.c"
	}
#line 548 "GomDocumentTest.vala"
	_tmp74_ = gxml_dom_element_get_attributes (c);
#line 548 "GomDocumentTest.vala"
	_tmp75_ = _tmp74_;
#line 548 "GomDocumentTest.vala"
	_tmp76_ = _tmp75_;
#line 548 "GomDocumentTest.vala"
	_tmp77_ = gee_map_get_size ((GeeMap*) _tmp76_);
#line 548 "GomDocumentTest.vala"
	_tmp78_ = _tmp77_;
#line 548 "GomDocumentTest.vala"
	_vala_assert (_tmp78_ == 1, "c.attributes.size == 1");
#line 548 "GomDocumentTest.vala"
	_g_object_unref0 (_tmp76_);
#line 549 "GomDocumentTest.vala"
	_tmp79_ = gxml_dom_element_get_prefix (c);
#line 549 "GomDocumentTest.vala"
	_tmp80_ = _tmp79_;
#line 549 "GomDocumentTest.vala"
	_tmp81_ = _tmp80_;
#line 549 "GomDocumentTest.vala"
	_vala_assert (_tmp81_ == NULL, "c.prefix == null");
#line 549 "GomDocumentTest.vala"
	_g_free0 (_tmp81_);
#line 550 "GomDocumentTest.vala"
	_tmp82_ = gxml_dom_element_get_namespace_uri (c);
#line 550 "GomDocumentTest.vala"
	_tmp83_ = _tmp82_;
#line 550 "GomDocumentTest.vala"
	_tmp84_ = _tmp83_;
#line 550 "GomDocumentTest.vala"
	_vala_assert (_tmp84_ == NULL, "c.namespace_uri == null");
#line 550 "GomDocumentTest.vala"
	_g_free0 (_tmp84_);
#line 6147 "GomDocumentTest.c"
	{
#line 552 "GomDocumentTest.vala"
		gxml_dom_element_set_attribute_ns (c, "http://www.gnome.org/GXml2", "gxml3:prop", "val", &_inner_error0_);
#line 552 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 6153 "GomDocumentTest.c"
			goto __catch104_g_error;
		}
#line 553 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 6158 "GomDocumentTest.c"
	}
	goto __finally104;
	__catch104_g_error:
	{
#line 551 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 551 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 6167 "GomDocumentTest.c"
	}
	__finally104:
#line 551 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 551 "GomDocumentTest.vala"
		_g_object_unref0 (c);
#line 551 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 551 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 551 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 551 "GomDocumentTest.vala"
		return;
#line 6182 "GomDocumentTest.c"
	}
	{
#line 556 "GomDocumentTest.vala"
		gxml_dom_element_set_attribute_ns (c, "http://www.gnome.org/GXml3", "gxml2:prop", "val", &_inner_error0_);
#line 556 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 6189 "GomDocumentTest.c"
			goto __catch105_g_error;
		}
	}
	goto __finally105;
	__catch105_g_error:
	{
#line 555 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 555 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 6200 "GomDocumentTest.c"
	}
	__finally105:
#line 555 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 555 "GomDocumentTest.vala"
		_g_object_unref0 (c);
#line 555 "GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 555 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 555 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 555 "GomDocumentTest.vala"
		return;
#line 6215 "GomDocumentTest.c"
	}
#line 558 "GomDocumentTest.vala"
	_tmp85_ = gxml_dom_element_get_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (c, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) c) : NULL, "http://www.gnome.org/GXml4", "prop");
#line 558 "GomDocumentTest.vala"
	p = _tmp85_;
#line 559 "GomDocumentTest.vala"
	_vala_assert (p == NULL, "p == null");
#line 514 "GomDocumentTest.vala"
	_g_free0 (p);
#line 514 "GomDocumentTest.vala"
	_g_object_unref0 (c);
#line 514 "GomDocumentTest.vala"
	_g_object_unref0 (doc);
#line 6229 "GomDocumentTest.c"
}

static void
___lambda86__gtest_func (void)
{
#line 514 "GomDocumentTest.vala"
	__lambda86_ ();
#line 6237 "GomDocumentTest.c"
}

static void
__lambda87_ (void)
{
	GXmlGomDocument* doc = NULL;
	GXmlGomDocument* _tmp0_;
	GXmlDomNode* _tmp1_;
	GXmlDomNode* _tmp2_;
	GXmlDomNode* _tmp3_;
#line 562 "GomDocumentTest.vala"
	_tmp0_ = gxml_gom_document_new ();
#line 562 "GomDocumentTest.vala"
	doc = _tmp0_;
#line 563 "GomDocumentTest.vala"
	_tmp1_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) doc);
#line 563 "GomDocumentTest.vala"
	_tmp2_ = _tmp1_;
#line 563 "GomDocumentTest.vala"
	_tmp3_ = _tmp2_;
#line 563 "GomDocumentTest.vala"
	_vala_assert (_tmp3_ == NULL, "doc.parent_node == null");
#line 563 "GomDocumentTest.vala"
	_g_object_unref0 (_tmp3_);
#line 561 "GomDocumentTest.vala"
	_g_object_unref0 (doc);
#line 6264 "GomDocumentTest.c"
}

static void
___lambda87__gtest_func (void)
{
#line 561 "GomDocumentTest.vala"
	__lambda87_ ();
#line 6272 "GomDocumentTest.c"
}

static void
__lambda88_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlDomElement* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlGomElement* n = NULL;
		GXmlGomElement* _tmp4_;
		GXmlGomDocument* _tmp5_;
		GXmlGomElement* _tmp6_;
		GXmlDomNode* _tmp7_;
		GXmlDomNode* _tmp8_;
		GXmlGomElement* _tmp9_;
		GXmlDomElement* _tmp10_ = NULL;
		GXmlGomDocument* _tmp11_;
		GXmlDomElement* _tmp12_;
		GXmlGomElement* n2 = NULL;
		GXmlGomElement* _tmp13_;
		GXmlGomElement* _tmp14_;
		GXmlGomElement* _tmp15_;
		GXmlDomNode* _tmp16_;
		GXmlDomNode* _tmp17_;
		gchar* _tmp18_ = NULL;
		GXmlGomDocument* _tmp19_;
		gchar* _tmp20_;
		gchar* str = NULL;
		GXmlGomDocument* _tmp21_;
		gchar* _tmp22_;
		const gchar* _tmp23_;
		const gchar* _tmp24_;
		const gchar* _tmp25_;
#line 567 "GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new ();
#line 567 "GomDocumentTest.vala"
		d = _tmp0_;
#line 568 "GomDocumentTest.vala"
		_tmp2_ = d;
#line 568 "GomDocumentTest.vala"
		_tmp3_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp2_, "Node", &_inner_error0_);
#line 568 "GomDocumentTest.vala"
		_tmp1_ = _tmp3_;
#line 568 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 568 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6324 "GomDocumentTest.c"
			goto __catch106_g_error;
		}
#line 568 "GomDocumentTest.vala"
		_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GXML_TYPE_GOM_ELEMENT) ? ((GXmlGomElement*) _tmp1_) : NULL);
#line 568 "GomDocumentTest.vala"
		n = _tmp4_;
#line 569 "GomDocumentTest.vala"
		_tmp5_ = d;
#line 569 "GomDocumentTest.vala"
		_tmp6_ = n;
#line 569 "GomDocumentTest.vala"
		_tmp7_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp5_, (GXmlDomNode*) _tmp6_, &_inner_error0_);
#line 569 "GomDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 569 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp8_);
#line 569 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 569 "GomDocumentTest.vala"
			_g_object_unref0 (n);
#line 569 "GomDocumentTest.vala"
			_g_object_unref0 (_tmp1_);
#line 569 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6349 "GomDocumentTest.c"
			goto __catch106_g_error;
		}
#line 570 "GomDocumentTest.vala"
		_tmp9_ = n;
#line 570 "GomDocumentTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp9_, "name", "value", &_inner_error0_);
#line 570 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 570 "GomDocumentTest.vala"
			_g_object_unref0 (n);
#line 570 "GomDocumentTest.vala"
			_g_object_unref0 (_tmp1_);
#line 570 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6364 "GomDocumentTest.c"
			goto __catch106_g_error;
		}
#line 571 "GomDocumentTest.vala"
		_tmp11_ = d;
#line 571 "GomDocumentTest.vala"
		_tmp12_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp11_, "Node2", &_inner_error0_);
#line 571 "GomDocumentTest.vala"
		_tmp10_ = _tmp12_;
#line 571 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 571 "GomDocumentTest.vala"
			_g_object_unref0 (n);
#line 571 "GomDocumentTest.vala"
			_g_object_unref0 (_tmp1_);
#line 571 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6381 "GomDocumentTest.c"
			goto __catch106_g_error;
		}
#line 571 "GomDocumentTest.vala"
		_tmp13_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, GXML_TYPE_GOM_ELEMENT) ? ((GXmlGomElement*) _tmp10_) : NULL);
#line 571 "GomDocumentTest.vala"
		n2 = _tmp13_;
#line 572 "GomDocumentTest.vala"
		_tmp14_ = n;
#line 572 "GomDocumentTest.vala"
		_tmp15_ = n2;
#line 572 "GomDocumentTest.vala"
		_tmp16_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp14_, (GXmlDomNode*) _tmp15_, &_inner_error0_);
#line 572 "GomDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 572 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp17_);
#line 572 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 572 "GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 572 "GomDocumentTest.vala"
			_g_object_unref0 (_tmp10_);
#line 572 "GomDocumentTest.vala"
			_g_object_unref0 (n);
#line 572 "GomDocumentTest.vala"
			_g_object_unref0 (_tmp1_);
#line 572 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6410 "GomDocumentTest.c"
			goto __catch106_g_error;
		}
#line 573 "GomDocumentTest.vala"
		_tmp19_ = d;
#line 573 "GomDocumentTest.vala"
		_tmp20_ = gxml_dom_document_write_string ((GXmlDomDocument*) _tmp19_, NULL, &_inner_error0_);
#line 573 "GomDocumentTest.vala"
		_tmp18_ = _tmp20_;
#line 573 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 573 "GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 573 "GomDocumentTest.vala"
			_g_object_unref0 (_tmp10_);
#line 573 "GomDocumentTest.vala"
			_g_object_unref0 (n);
#line 573 "GomDocumentTest.vala"
			_g_object_unref0 (_tmp1_);
#line 573 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6431 "GomDocumentTest.c"
			goto __catch106_g_error;
		}
#line 573 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:573: %s", _tmp18_);
#line 574 "GomDocumentTest.vala"
		_tmp21_ = d;
#line 574 "GomDocumentTest.vala"
		_tmp22_ = gxml_dom_document_write_string ((GXmlDomDocument*) _tmp21_, NULL, &_inner_error0_);
#line 574 "GomDocumentTest.vala"
		str = _tmp22_;
#line 574 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 574 "GomDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 574 "GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 574 "GomDocumentTest.vala"
			_g_object_unref0 (_tmp10_);
#line 574 "GomDocumentTest.vala"
			_g_object_unref0 (n);
#line 574 "GomDocumentTest.vala"
			_g_object_unref0 (_tmp1_);
#line 574 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6456 "GomDocumentTest.c"
			goto __catch106_g_error;
		}
#line 575 "GomDocumentTest.vala"
		_tmp23_ = str;
#line 575 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:575: Output document: %s", _tmp23_);
#line 576 "GomDocumentTest.vala"
		_tmp24_ = str;
#line 576 "GomDocumentTest.vala"
		_vala_assert (string_contains (_tmp24_, "<Node"), "\"<Node\" in str");
#line 577 "GomDocumentTest.vala"
		_tmp25_ = str;
#line 577 "GomDocumentTest.vala"
		_vala_assert (string_contains (_tmp25_, "<Node name=\"value\"><Node2/></Node>"), "\"<Node name=\\\"value\\\"><Node2/></Node>\" in str");
#line 566 "GomDocumentTest.vala"
		_g_free0 (str);
#line 566 "GomDocumentTest.vala"
		_g_free0 (_tmp18_);
#line 566 "GomDocumentTest.vala"
		_g_object_unref0 (n2);
#line 566 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp10_);
#line 566 "GomDocumentTest.vala"
		_g_object_unref0 (n);
#line 566 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 566 "GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 6485 "GomDocumentTest.c"
	}
	goto __finally106;
	__catch106_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
#line 566 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 566 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 579 "GomDocumentTest.vala"
		_tmp26_ = e->message;
#line 579 "GomDocumentTest.vala"
		_tmp27_ = g_strconcat ("Error: ", _tmp26_, NULL);
#line 579 "GomDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 579 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:579: %s", _tmp28_);
#line 579 "GomDocumentTest.vala"
		_g_free0 (_tmp28_);
#line 580 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 566 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 6512 "GomDocumentTest.c"
	}
	__finally106:
#line 566 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 566 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 566 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 566 "GomDocumentTest.vala"
		return;
#line 6523 "GomDocumentTest.c"
	}
}

static void
___lambda88__gtest_func (void)
{
#line 565 "GomDocumentTest.vala"
	__lambda88_ ();
#line 6532 "GomDocumentTest.c"
}

static void
__lambda89_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp1_;
		GXmlDomElement* _tmp2_;
		GXmlGomDocument* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlDomNode* _tmp5_;
		GXmlDomNode* _tmp6_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp7_;
		GXmlDomElement* _tmp8_;
		GXmlDomElement* _tmp9_;
		GXmlDomElement* _tmp10_;
		GXmlDomElement* _tmp11_;
		GXmlDomNode* _tmp12_;
		GXmlDomNode* _tmp13_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp14_;
		GXmlDomElement* _tmp15_;
		GXmlDomElement* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlDomElement* _tmp18_;
		GXmlDomNode* _tmp19_;
		GXmlDomNode* _tmp20_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp21_;
		GXmlDomElement* _tmp22_;
		GXmlDomElement* _tmp23_;
		GXmlDomElement* _tmp24_;
		GXmlDomElement* _tmp25_;
		GXmlDomNode* _tmp26_;
		GXmlDomNode* _tmp27_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp28_;
		GXmlDomElement* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomElement* _tmp31_;
		GXmlDomElement* _tmp32_;
		GXmlDomNode* _tmp33_;
		GXmlDomNode* _tmp34_;
		GXmlDomElement* c5 = NULL;
		GXmlGomDocument* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomElement* _tmp37_;
		GXmlDomElement* _tmp38_;
		GXmlDomNode* _tmp39_;
		GXmlDomNode* _tmp40_;
		GXmlDomElement* c51 = NULL;
		GXmlGomDocument* _tmp41_;
		GXmlDomElement* _tmp42_;
		GXmlDomElement* _tmp43_;
		GXmlDomElement* _tmp44_;
		GXmlDomNode* _tmp45_;
		GXmlDomNode* _tmp46_;
		GXmlDomElement* n1 = NULL;
		GXmlGomDocument* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		gchar* _tmp51_;
		gchar* _tmp52_;
		GXmlDomElement* n2 = NULL;
		GXmlGomDocument* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomElement* _tmp56_;
		gchar* _tmp57_;
		gchar* _tmp58_;
		GXmlDomElement* n3 = NULL;
		GXmlGomDocument* _tmp59_;
		GXmlDomElement* _tmp60_;
		GXmlDomElement* _tmp61_;
		GXmlDomElement* _tmp62_;
		gchar* _tmp63_;
		gchar* _tmp64_;
		GXmlDomElement* n4 = NULL;
		GXmlGomDocument* _tmp65_;
		GXmlDomElement* _tmp66_;
		GXmlDomElement* _tmp67_;
		GXmlDomElement* _tmp68_;
		gchar* _tmp69_;
		gchar* _tmp70_;
		GXmlDomNodeList* l1 = NULL;
		GXmlGomDocument* _tmp71_;
		GXmlDomNodeList* _tmp72_;
		GXmlDomNodeList* _tmp73_;
		GXmlDomNodeList* _tmp74_;
		gint _tmp75_;
		gint _tmp76_;
		gchar* _tmp77_;
		gchar* _tmp78_;
		GXmlDomNodeList* _tmp79_;
		gint _tmp80_;
		gint _tmp81_;
		GXmlDomNodeList* _tmp82_;
		GXmlDomNode* _tmp83_;
		GXmlDomNode* _tmp84_;
		gchar* _tmp85_;
		gchar* _tmp86_;
		gchar* _tmp87_;
		GXmlDomNodeList* l2 = NULL;
		GXmlGomDocument* _tmp88_;
		GXmlDomNodeList* _tmp89_;
		GXmlDomNodeList* _tmp90_;
		GXmlDomNodeList* _tmp91_;
		gint _tmp92_;
		gint _tmp93_;
		GXmlDomNodeList* _tmp94_;
		GXmlDomNode* _tmp95_;
		GXmlDomNode* _tmp96_;
		gchar* _tmp97_;
		gchar* _tmp98_;
		gchar* _tmp99_;
		GXmlDomNodeList* l3 = NULL;
		GXmlGomDocument* _tmp100_;
		GXmlDomNodeList* _tmp101_;
		GXmlDomNodeList* _tmp102_;
		GXmlDomNodeList* _tmp103_;
		gint _tmp104_;
		gint _tmp105_;
		GXmlDomNodeList* _tmp106_;
		GXmlDomNode* _tmp107_;
		GXmlDomNode* _tmp108_;
		gchar* _tmp109_;
		gchar* _tmp110_;
		gchar* _tmp111_;
		GXmlDomElement* c6 = NULL;
		GXmlGomDocument* _tmp112_;
		GXmlDomElement* _tmp113_;
		GXmlDomElement* _tmp114_;
		GXmlDomElement* _tmp115_;
		GXmlDomElement* _tmp116_;
		GXmlDomNode* _tmp117_;
		GXmlDomNode* _tmp118_;
		GXmlDomElement* c7 = NULL;
		GXmlGomDocument* _tmp119_;
		GXmlDomElement* _tmp120_;
		GXmlDomElement* _tmp121_;
		GXmlDomElement* _tmp122_;
		GXmlDomElement* _tmp123_;
		GXmlDomNode* _tmp124_;
		GXmlDomNode* _tmp125_;
		GXmlDomNodeList* l4 = NULL;
		GXmlGomDocument* _tmp126_;
		GXmlDomNodeList* _tmp127_;
		GXmlDomNodeList* _tmp128_;
		GXmlDomNodeList* _tmp129_;
		gint _tmp130_;
		gint _tmp131_;
		GXmlDomNodeList* _tmp132_;
		GXmlDomNode* _tmp133_;
		GXmlDomNode* _tmp134_;
		gchar* _tmp135_;
		gchar* _tmp136_;
		gchar* _tmp137_;
#line 585 "GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new ();
#line 585 "GomDocumentTest.vala"
		d = _tmp0_;
#line 586 "GomDocumentTest.vala"
		_tmp1_ = d;
#line 586 "GomDocumentTest.vala"
		_tmp2_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp1_, "root", &_inner_error0_);
#line 586 "GomDocumentTest.vala"
		r = _tmp2_;
#line 586 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 586 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6710 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 587 "GomDocumentTest.vala"
		_tmp3_ = d;
#line 587 "GomDocumentTest.vala"
		_tmp4_ = r;
#line 587 "GomDocumentTest.vala"
		_tmp5_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp3_, (GXmlDomNode*) _tmp4_, &_inner_error0_);
#line 587 "GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 587 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp6_);
#line 587 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 587 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 587 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6729 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 588 "GomDocumentTest.vala"
		_tmp7_ = d;
#line 588 "GomDocumentTest.vala"
		_tmp8_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp7_, "child", &_inner_error0_);
#line 588 "GomDocumentTest.vala"
		c1 = _tmp8_;
#line 588 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 588 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 588 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6744 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 589 "GomDocumentTest.vala"
		_tmp9_ = c1;
#line 589 "GomDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp9_, "class", "error", &_inner_error0_);
#line 589 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 589 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 589 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 589 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6759 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 590 "GomDocumentTest.vala"
		_tmp10_ = r;
#line 590 "GomDocumentTest.vala"
		_tmp11_ = c1;
#line 590 "GomDocumentTest.vala"
		_tmp12_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp10_, (GXmlDomNode*) _tmp11_, &_inner_error0_);
#line 590 "GomDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 590 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp13_);
#line 590 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 590 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 590 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 590 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6780 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 591 "GomDocumentTest.vala"
		_tmp14_ = d;
#line 591 "GomDocumentTest.vala"
		_tmp15_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp14_, "child", &_inner_error0_);
#line 591 "GomDocumentTest.vala"
		c2 = _tmp15_;
#line 591 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 591 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 591 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 591 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6797 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 592 "GomDocumentTest.vala"
		_tmp16_ = c2;
#line 592 "GomDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp16_, "class", "warning", &_inner_error0_);
#line 592 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 592 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 592 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 592 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 592 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6814 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 593 "GomDocumentTest.vala"
		_tmp17_ = r;
#line 593 "GomDocumentTest.vala"
		_tmp18_ = c2;
#line 593 "GomDocumentTest.vala"
		_tmp19_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp17_, (GXmlDomNode*) _tmp18_, &_inner_error0_);
#line 593 "GomDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 593 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp20_);
#line 593 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 593 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 593 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 593 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 593 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6837 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 594 "GomDocumentTest.vala"
		_tmp21_ = d;
#line 594 "GomDocumentTest.vala"
		_tmp22_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp21_, "child", &_inner_error0_);
#line 594 "GomDocumentTest.vala"
		c3 = _tmp22_;
#line 594 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 594 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 594 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 594 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 594 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6856 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 595 "GomDocumentTest.vala"
		_tmp23_ = c3;
#line 595 "GomDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp23_, "class", "error warning", &_inner_error0_);
#line 595 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 595 "GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 595 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 595 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 595 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 595 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6875 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 596 "GomDocumentTest.vala"
		_tmp24_ = r;
#line 596 "GomDocumentTest.vala"
		_tmp25_ = c3;
#line 596 "GomDocumentTest.vala"
		_tmp26_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp24_, (GXmlDomNode*) _tmp25_, &_inner_error0_);
#line 596 "GomDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 596 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp27_);
#line 596 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 596 "GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 596 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 596 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 596 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 596 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6900 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 597 "GomDocumentTest.vala"
		_tmp28_ = d;
#line 597 "GomDocumentTest.vala"
		_tmp29_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp28_, "child", &_inner_error0_);
#line 597 "GomDocumentTest.vala"
		c4 = _tmp29_;
#line 597 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 597 "GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 597 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 597 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 597 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 597 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6921 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 598 "GomDocumentTest.vala"
		_tmp30_ = c4;
#line 598 "GomDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp30_, "class", "error calc", &_inner_error0_);
#line 598 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 598 "GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 598 "GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 598 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 598 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 598 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 598 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6942 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 599 "GomDocumentTest.vala"
		_tmp31_ = r;
#line 599 "GomDocumentTest.vala"
		_tmp32_ = c4;
#line 599 "GomDocumentTest.vala"
		_tmp33_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp31_, (GXmlDomNode*) _tmp32_, &_inner_error0_);
#line 599 "GomDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 599 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp34_);
#line 599 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 599 "GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 599 "GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 599 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 599 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 599 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 599 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6969 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 600 "GomDocumentTest.vala"
		_tmp35_ = d;
#line 600 "GomDocumentTest.vala"
		_tmp36_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp35_, "child", &_inner_error0_);
#line 600 "GomDocumentTest.vala"
		c5 = _tmp36_;
#line 600 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 600 "GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 600 "GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 600 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 600 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 600 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 600 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6992 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 601 "GomDocumentTest.vala"
		_tmp37_ = r;
#line 601 "GomDocumentTest.vala"
		_tmp38_ = c5;
#line 601 "GomDocumentTest.vala"
		_tmp39_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp37_, (GXmlDomNode*) _tmp38_, &_inner_error0_);
#line 601 "GomDocumentTest.vala"
		_tmp40_ = _tmp39_;
#line 601 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp40_);
#line 601 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 601 "GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 601 "GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 601 "GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 601 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 601 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 601 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 601 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7021 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 602 "GomDocumentTest.vala"
		_tmp41_ = d;
#line 602 "GomDocumentTest.vala"
		_tmp42_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp41_, "child", &_inner_error0_);
#line 602 "GomDocumentTest.vala"
		c51 = _tmp42_;
#line 602 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 602 "GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 602 "GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 602 "GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 602 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 602 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 602 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 602 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7046 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 603 "GomDocumentTest.vala"
		_tmp43_ = c5;
#line 603 "GomDocumentTest.vala"
		_tmp44_ = c51;
#line 603 "GomDocumentTest.vala"
		_tmp45_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp43_, (GXmlDomNode*) _tmp44_, &_inner_error0_);
#line 603 "GomDocumentTest.vala"
		_tmp46_ = _tmp45_;
#line 603 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp46_);
#line 603 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 603 "GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 603 "GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 603 "GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 603 "GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 603 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 603 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 603 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 603 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7077 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 604 "GomDocumentTest.vala"
		_tmp47_ = d;
#line 604 "GomDocumentTest.vala"
		_tmp48_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp47_, "child", &_inner_error0_);
#line 604 "GomDocumentTest.vala"
		n1 = _tmp48_;
#line 604 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 604 "GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 604 "GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 604 "GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 604 "GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 604 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 604 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 604 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 604 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7104 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 605 "GomDocumentTest.vala"
		_tmp49_ = n1;
#line 605 "GomDocumentTest.vala"
		_vala_assert (_tmp49_ != NULL, "n1 != null");
#line 606 "GomDocumentTest.vala"
		_tmp50_ = n1;
#line 606 "GomDocumentTest.vala"
		_tmp51_ = gxml_dom_element_get_attribute (_tmp50_, "class");
#line 606 "GomDocumentTest.vala"
		_tmp52_ = _tmp51_;
#line 606 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp52_, "error") == 0, "n1.get_attribute (\"class\") == \"error\"");
#line 606 "GomDocumentTest.vala"
		_g_free0 (_tmp52_);
#line 607 "GomDocumentTest.vala"
		_tmp53_ = d;
#line 607 "GomDocumentTest.vala"
		_tmp54_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp53_, "child.warning", &_inner_error0_);
#line 607 "GomDocumentTest.vala"
		n2 = _tmp54_;
#line 607 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 607 "GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 607 "GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 607 "GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 607 "GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 607 "GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 607 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 607 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 607 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 607 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7147 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 608 "GomDocumentTest.vala"
		_tmp55_ = n2;
#line 608 "GomDocumentTest.vala"
		_vala_assert (_tmp55_ != NULL, "n2 != null");
#line 609 "GomDocumentTest.vala"
		_tmp56_ = n2;
#line 609 "GomDocumentTest.vala"
		_tmp57_ = gxml_dom_element_get_attribute (_tmp56_, "class");
#line 609 "GomDocumentTest.vala"
		_tmp58_ = _tmp57_;
#line 609 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp58_, "warning") == 0, "n2.get_attribute (\"class\") == \"warning\"");
#line 609 "GomDocumentTest.vala"
		_g_free0 (_tmp58_);
#line 610 "GomDocumentTest.vala"
		_tmp59_ = d;
#line 610 "GomDocumentTest.vala"
		_tmp60_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp59_, "child[class]", &_inner_error0_);
#line 610 "GomDocumentTest.vala"
		n3 = _tmp60_;
#line 610 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 610 "GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 610 "GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 610 "GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 610 "GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 610 "GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 610 "GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 610 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 610 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 610 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 610 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7192 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 611 "GomDocumentTest.vala"
		_tmp61_ = n3;
#line 611 "GomDocumentTest.vala"
		_vala_assert (_tmp61_ != NULL, "n3 != null");
#line 612 "GomDocumentTest.vala"
		_tmp62_ = n3;
#line 612 "GomDocumentTest.vala"
		_tmp63_ = gxml_dom_element_get_attribute (_tmp62_, "class");
#line 612 "GomDocumentTest.vala"
		_tmp64_ = _tmp63_;
#line 612 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp64_, "error") == 0, "n3.get_attribute (\"class\") == \"error\"");
#line 612 "GomDocumentTest.vala"
		_g_free0 (_tmp64_);
#line 613 "GomDocumentTest.vala"
		_tmp65_ = d;
#line 613 "GomDocumentTest.vala"
		_tmp66_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp65_, "child[class=\"error calc\"]", &_inner_error0_);
#line 613 "GomDocumentTest.vala"
		n4 = _tmp66_;
#line 613 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 613 "GomDocumentTest.vala"
			_g_object_unref0 (n3);
#line 613 "GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 613 "GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 613 "GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 613 "GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 613 "GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 613 "GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 613 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 613 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 613 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 613 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7239 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 614 "GomDocumentTest.vala"
		_tmp67_ = n4;
#line 614 "GomDocumentTest.vala"
		_vala_assert (_tmp67_ != NULL, "n4 != null");
#line 615 "GomDocumentTest.vala"
		_tmp68_ = n4;
#line 615 "GomDocumentTest.vala"
		_tmp69_ = gxml_dom_element_get_attribute (_tmp68_, "class");
#line 615 "GomDocumentTest.vala"
		_tmp70_ = _tmp69_;
#line 615 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp70_, "error calc") == 0, "n4.get_attribute (\"class\") == \"error calc\"");
#line 615 "GomDocumentTest.vala"
		_g_free0 (_tmp70_);
#line 616 "GomDocumentTest.vala"
		_tmp71_ = d;
#line 616 "GomDocumentTest.vala"
		_tmp72_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp71_, "child", &_inner_error0_);
#line 616 "GomDocumentTest.vala"
		l1 = _tmp72_;
#line 616 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 616 "GomDocumentTest.vala"
			_g_object_unref0 (n4);
#line 616 "GomDocumentTest.vala"
			_g_object_unref0 (n3);
#line 616 "GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 616 "GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 616 "GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 616 "GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 616 "GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 616 "GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 616 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 616 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 616 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 616 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7288 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 617 "GomDocumentTest.vala"
		_tmp73_ = l1;
#line 617 "GomDocumentTest.vala"
		_vala_assert (_tmp73_ != NULL, "l1 != null");
#line 618 "GomDocumentTest.vala"
		_tmp74_ = l1;
#line 618 "GomDocumentTest.vala"
		_tmp75_ = gxml_dom_node_list_get_length (_tmp74_);
#line 618 "GomDocumentTest.vala"
		_tmp76_ = _tmp75_;
#line 618 "GomDocumentTest.vala"
		_tmp77_ = g_strdup_printf ("%i", _tmp76_);
#line 618 "GomDocumentTest.vala"
		_tmp78_ = _tmp77_;
#line 618 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:618: %s", _tmp78_);
#line 618 "GomDocumentTest.vala"
		_g_free0 (_tmp78_);
#line 619 "GomDocumentTest.vala"
		_tmp79_ = l1;
#line 619 "GomDocumentTest.vala"
		_tmp80_ = gxml_dom_node_list_get_length (_tmp79_);
#line 619 "GomDocumentTest.vala"
		_tmp81_ = _tmp80_;
#line 619 "GomDocumentTest.vala"
		_vala_assert (_tmp81_ == 6, "l1.length == 6");
#line 620 "GomDocumentTest.vala"
		_tmp82_ = l1;
#line 620 "GomDocumentTest.vala"
		_tmp83_ = gxml_dom_node_list_item (_tmp82_, 4);
#line 620 "GomDocumentTest.vala"
		_tmp84_ = _tmp83_;
#line 620 "GomDocumentTest.vala"
		_tmp85_ = gxml_dom_node_get_node_name (_tmp84_);
#line 620 "GomDocumentTest.vala"
		_tmp86_ = _tmp85_;
#line 620 "GomDocumentTest.vala"
		_tmp87_ = _tmp86_;
#line 620 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp87_, "child") == 0, "l1.item (4).node_name == \"child\"");
#line 620 "GomDocumentTest.vala"
		_g_free0 (_tmp87_);
#line 620 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp84_);
#line 621 "GomDocumentTest.vala"
		_tmp88_ = d;
#line 621 "GomDocumentTest.vala"
		_tmp89_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp88_, "child[class]", &_inner_error0_);
#line 621 "GomDocumentTest.vala"
		l2 = _tmp89_;
#line 621 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 621 "GomDocumentTest.vala"
			_g_object_unref0 (l1);
#line 621 "GomDocumentTest.vala"
			_g_object_unref0 (n4);
#line 621 "GomDocumentTest.vala"
			_g_object_unref0 (n3);
#line 621 "GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 621 "GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 621 "GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 621 "GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 621 "GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 621 "GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 621 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 621 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 621 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 621 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7369 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 622 "GomDocumentTest.vala"
		_tmp90_ = l2;
#line 622 "GomDocumentTest.vala"
		_vala_assert (_tmp90_ != NULL, "l2 != null");
#line 623 "GomDocumentTest.vala"
		_tmp91_ = l2;
#line 623 "GomDocumentTest.vala"
		_tmp92_ = gxml_dom_node_list_get_length (_tmp91_);
#line 623 "GomDocumentTest.vala"
		_tmp93_ = _tmp92_;
#line 623 "GomDocumentTest.vala"
		_vala_assert (_tmp93_ == 4, "l2.length == 4");
#line 624 "GomDocumentTest.vala"
		_tmp94_ = l2;
#line 624 "GomDocumentTest.vala"
		_tmp95_ = gxml_dom_node_list_item (_tmp94_, 3);
#line 624 "GomDocumentTest.vala"
		_tmp96_ = _tmp95_;
#line 624 "GomDocumentTest.vala"
		_tmp97_ = gxml_dom_node_get_node_name (_tmp96_);
#line 624 "GomDocumentTest.vala"
		_tmp98_ = _tmp97_;
#line 624 "GomDocumentTest.vala"
		_tmp99_ = _tmp98_;
#line 624 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp99_, "child") == 0, "l2.item (3).node_name == \"child\"");
#line 624 "GomDocumentTest.vala"
		_g_free0 (_tmp99_);
#line 624 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp96_);
#line 625 "GomDocumentTest.vala"
		_tmp100_ = d;
#line 625 "GomDocumentTest.vala"
		_tmp101_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp100_, "child[class=\"error\"]", &_inner_error0_);
#line 625 "GomDocumentTest.vala"
		l3 = _tmp101_;
#line 625 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 625 "GomDocumentTest.vala"
			_g_object_unref0 (l2);
#line 625 "GomDocumentTest.vala"
			_g_object_unref0 (l1);
#line 625 "GomDocumentTest.vala"
			_g_object_unref0 (n4);
#line 625 "GomDocumentTest.vala"
			_g_object_unref0 (n3);
#line 625 "GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 625 "GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 625 "GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 625 "GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 625 "GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 625 "GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 625 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 625 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 625 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 625 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7438 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 626 "GomDocumentTest.vala"
		_tmp102_ = l3;
#line 626 "GomDocumentTest.vala"
		_vala_assert (_tmp102_ != NULL, "l3 != null");
#line 627 "GomDocumentTest.vala"
		_tmp103_ = l3;
#line 627 "GomDocumentTest.vala"
		_tmp104_ = gxml_dom_node_list_get_length (_tmp103_);
#line 627 "GomDocumentTest.vala"
		_tmp105_ = _tmp104_;
#line 627 "GomDocumentTest.vala"
		_vala_assert (_tmp105_ == 1, "l3.length == 1");
#line 628 "GomDocumentTest.vala"
		_tmp106_ = l3;
#line 628 "GomDocumentTest.vala"
		_tmp107_ = gxml_dom_node_list_item (_tmp106_, 0);
#line 628 "GomDocumentTest.vala"
		_tmp108_ = _tmp107_;
#line 628 "GomDocumentTest.vala"
		_tmp109_ = gxml_dom_node_get_node_name (_tmp108_);
#line 628 "GomDocumentTest.vala"
		_tmp110_ = _tmp109_;
#line 628 "GomDocumentTest.vala"
		_tmp111_ = _tmp110_;
#line 628 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp111_, "child") == 0, "l3.item (0).node_name == \"child\"");
#line 628 "GomDocumentTest.vala"
		_g_free0 (_tmp111_);
#line 628 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp108_);
#line 629 "GomDocumentTest.vala"
		_tmp112_ = d;
#line 629 "GomDocumentTest.vala"
		_tmp113_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp112_, "child", &_inner_error0_);
#line 629 "GomDocumentTest.vala"
		c6 = _tmp113_;
#line 629 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 629 "GomDocumentTest.vala"
			_g_object_unref0 (l3);
#line 629 "GomDocumentTest.vala"
			_g_object_unref0 (l2);
#line 629 "GomDocumentTest.vala"
			_g_object_unref0 (l1);
#line 629 "GomDocumentTest.vala"
			_g_object_unref0 (n4);
#line 629 "GomDocumentTest.vala"
			_g_object_unref0 (n3);
#line 629 "GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 629 "GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 629 "GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 629 "GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 629 "GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 629 "GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 629 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 629 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 629 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 629 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7509 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 630 "GomDocumentTest.vala"
		_tmp114_ = c6;
#line 630 "GomDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp114_, "prop", "val1", &_inner_error0_);
#line 630 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 630 "GomDocumentTest.vala"
			_g_object_unref0 (c6);
#line 630 "GomDocumentTest.vala"
			_g_object_unref0 (l3);
#line 630 "GomDocumentTest.vala"
			_g_object_unref0 (l2);
#line 630 "GomDocumentTest.vala"
			_g_object_unref0 (l1);
#line 630 "GomDocumentTest.vala"
			_g_object_unref0 (n4);
#line 630 "GomDocumentTest.vala"
			_g_object_unref0 (n3);
#line 630 "GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 630 "GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 630 "GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 630 "GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 630 "GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 630 "GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 630 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 630 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 630 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 630 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7550 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 631 "GomDocumentTest.vala"
		_tmp115_ = r;
#line 631 "GomDocumentTest.vala"
		_tmp116_ = c6;
#line 631 "GomDocumentTest.vala"
		_tmp117_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp115_, (GXmlDomNode*) _tmp116_, &_inner_error0_);
#line 631 "GomDocumentTest.vala"
		_tmp118_ = _tmp117_;
#line 631 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp118_);
#line 631 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 631 "GomDocumentTest.vala"
			_g_object_unref0 (c6);
#line 631 "GomDocumentTest.vala"
			_g_object_unref0 (l3);
#line 631 "GomDocumentTest.vala"
			_g_object_unref0 (l2);
#line 631 "GomDocumentTest.vala"
			_g_object_unref0 (l1);
#line 631 "GomDocumentTest.vala"
			_g_object_unref0 (n4);
#line 631 "GomDocumentTest.vala"
			_g_object_unref0 (n3);
#line 631 "GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 631 "GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 631 "GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 631 "GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 631 "GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 631 "GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 631 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 631 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 631 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 631 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7597 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 632 "GomDocumentTest.vala"
		_tmp119_ = d;
#line 632 "GomDocumentTest.vala"
		_tmp120_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp119_, "child", &_inner_error0_);
#line 632 "GomDocumentTest.vala"
		c7 = _tmp120_;
#line 632 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 632 "GomDocumentTest.vala"
			_g_object_unref0 (c6);
#line 632 "GomDocumentTest.vala"
			_g_object_unref0 (l3);
#line 632 "GomDocumentTest.vala"
			_g_object_unref0 (l2);
#line 632 "GomDocumentTest.vala"
			_g_object_unref0 (l1);
#line 632 "GomDocumentTest.vala"
			_g_object_unref0 (n4);
#line 632 "GomDocumentTest.vala"
			_g_object_unref0 (n3);
#line 632 "GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 632 "GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 632 "GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 632 "GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 632 "GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 632 "GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 632 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 632 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 632 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 632 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7640 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 633 "GomDocumentTest.vala"
		_tmp121_ = c7;
#line 633 "GomDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp121_, "prop", "val1", &_inner_error0_);
#line 633 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 633 "GomDocumentTest.vala"
			_g_object_unref0 (c7);
#line 633 "GomDocumentTest.vala"
			_g_object_unref0 (c6);
#line 633 "GomDocumentTest.vala"
			_g_object_unref0 (l3);
#line 633 "GomDocumentTest.vala"
			_g_object_unref0 (l2);
#line 633 "GomDocumentTest.vala"
			_g_object_unref0 (l1);
#line 633 "GomDocumentTest.vala"
			_g_object_unref0 (n4);
#line 633 "GomDocumentTest.vala"
			_g_object_unref0 (n3);
#line 633 "GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 633 "GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 633 "GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 633 "GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 633 "GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 633 "GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 633 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 633 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 633 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 633 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7683 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 634 "GomDocumentTest.vala"
		_tmp122_ = r;
#line 634 "GomDocumentTest.vala"
		_tmp123_ = c7;
#line 634 "GomDocumentTest.vala"
		_tmp124_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp122_, (GXmlDomNode*) _tmp123_, &_inner_error0_);
#line 634 "GomDocumentTest.vala"
		_tmp125_ = _tmp124_;
#line 634 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp125_);
#line 634 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 634 "GomDocumentTest.vala"
			_g_object_unref0 (c7);
#line 634 "GomDocumentTest.vala"
			_g_object_unref0 (c6);
#line 634 "GomDocumentTest.vala"
			_g_object_unref0 (l3);
#line 634 "GomDocumentTest.vala"
			_g_object_unref0 (l2);
#line 634 "GomDocumentTest.vala"
			_g_object_unref0 (l1);
#line 634 "GomDocumentTest.vala"
			_g_object_unref0 (n4);
#line 634 "GomDocumentTest.vala"
			_g_object_unref0 (n3);
#line 634 "GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 634 "GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 634 "GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 634 "GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 634 "GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 634 "GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 634 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 634 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 634 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 634 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7732 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 635 "GomDocumentTest.vala"
		_tmp126_ = d;
#line 635 "GomDocumentTest.vala"
		_tmp127_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp126_, "child[prop=\"val1\"]", &_inner_error0_);
#line 635 "GomDocumentTest.vala"
		l4 = _tmp127_;
#line 635 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 635 "GomDocumentTest.vala"
			_g_object_unref0 (c7);
#line 635 "GomDocumentTest.vala"
			_g_object_unref0 (c6);
#line 635 "GomDocumentTest.vala"
			_g_object_unref0 (l3);
#line 635 "GomDocumentTest.vala"
			_g_object_unref0 (l2);
#line 635 "GomDocumentTest.vala"
			_g_object_unref0 (l1);
#line 635 "GomDocumentTest.vala"
			_g_object_unref0 (n4);
#line 635 "GomDocumentTest.vala"
			_g_object_unref0 (n3);
#line 635 "GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 635 "GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 635 "GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 635 "GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 635 "GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 635 "GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 635 "GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 635 "GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 635 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 635 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7777 "GomDocumentTest.c"
			goto __catch107_g_error;
		}
#line 636 "GomDocumentTest.vala"
		_tmp128_ = l4;
#line 636 "GomDocumentTest.vala"
		_vala_assert (_tmp128_ != NULL, "l4 != null");
#line 637 "GomDocumentTest.vala"
		_tmp129_ = l4;
#line 637 "GomDocumentTest.vala"
		_tmp130_ = gxml_dom_node_list_get_length (_tmp129_);
#line 637 "GomDocumentTest.vala"
		_tmp131_ = _tmp130_;
#line 637 "GomDocumentTest.vala"
		_vala_assert (_tmp131_ == 2, "l4.length == 2");
#line 638 "GomDocumentTest.vala"
		_tmp132_ = l4;
#line 638 "GomDocumentTest.vala"
		_tmp133_ = gxml_dom_node_list_item (_tmp132_, 0);
#line 638 "GomDocumentTest.vala"
		_tmp134_ = _tmp133_;
#line 638 "GomDocumentTest.vala"
		_tmp135_ = gxml_dom_node_get_node_name (_tmp134_);
#line 638 "GomDocumentTest.vala"
		_tmp136_ = _tmp135_;
#line 638 "GomDocumentTest.vala"
		_tmp137_ = _tmp136_;
#line 638 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp137_, "child") == 0, "l4.item (0).node_name == \"child\"");
#line 638 "GomDocumentTest.vala"
		_g_free0 (_tmp137_);
#line 638 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp134_);
#line 584 "GomDocumentTest.vala"
		_g_object_unref0 (l4);
#line 584 "GomDocumentTest.vala"
		_g_object_unref0 (c7);
#line 584 "GomDocumentTest.vala"
		_g_object_unref0 (c6);
#line 584 "GomDocumentTest.vala"
		_g_object_unref0 (l3);
#line 584 "GomDocumentTest.vala"
		_g_object_unref0 (l2);
#line 584 "GomDocumentTest.vala"
		_g_object_unref0 (l1);
#line 584 "GomDocumentTest.vala"
		_g_object_unref0 (n4);
#line 584 "GomDocumentTest.vala"
		_g_object_unref0 (n3);
#line 584 "GomDocumentTest.vala"
		_g_object_unref0 (n2);
#line 584 "GomDocumentTest.vala"
		_g_object_unref0 (n1);
#line 584 "GomDocumentTest.vala"
		_g_object_unref0 (c51);
#line 584 "GomDocumentTest.vala"
		_g_object_unref0 (c5);
#line 584 "GomDocumentTest.vala"
		_g_object_unref0 (c4);
#line 584 "GomDocumentTest.vala"
		_g_object_unref0 (c3);
#line 584 "GomDocumentTest.vala"
		_g_object_unref0 (c2);
#line 584 "GomDocumentTest.vala"
		_g_object_unref0 (c1);
#line 584 "GomDocumentTest.vala"
		_g_object_unref0 (r);
#line 584 "GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 7846 "GomDocumentTest.c"
	}
	goto __finally107;
	__catch107_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp138_;
		gchar* _tmp139_;
		gchar* _tmp140_;
#line 584 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 584 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 640 "GomDocumentTest.vala"
		_tmp138_ = e->message;
#line 640 "GomDocumentTest.vala"
		_tmp139_ = g_strconcat ("Error: ", _tmp138_, NULL);
#line 640 "GomDocumentTest.vala"
		_tmp140_ = _tmp139_;
#line 640 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:640: %s", _tmp140_);
#line 640 "GomDocumentTest.vala"
		_g_free0 (_tmp140_);
#line 641 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 584 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 7873 "GomDocumentTest.c"
	}
	__finally107:
#line 584 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 584 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 584 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 584 "GomDocumentTest.vala"
		return;
#line 7884 "GomDocumentTest.c"
	}
}

static void
___lambda89__gtest_func (void)
{
#line 583 "GomDocumentTest.vala"
	__lambda89_ ();
#line 7893 "GomDocumentTest.c"
}

static void
__lambda90_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlGomDocumentType* dt1 = NULL;
		GXmlGomDocument* _tmp1_;
		GXmlGomDocumentType* _tmp2_;
		GXmlGomDocumentType* _tmp3_;
		GXmlGomDocumentType* _tmp4_;
		GXmlDomNodeNodeType _tmp5_;
		GXmlDomNodeNodeType _tmp6_;
		GXmlGomDocumentType* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		GXmlGomDocumentType* _tmp11_;
		const gchar* _tmp12_;
		const gchar* _tmp13_;
		GXmlGomDocumentType* _tmp14_;
		const gchar* _tmp15_;
		const gchar* _tmp16_;
		GXmlGomDocumentType* _tmp17_;
		const gchar* _tmp18_;
		const gchar* _tmp19_;
		GXmlGomDocument* _tmp20_;
		GXmlGomDocumentType* _tmp21_;
		GXmlDomNode* _tmp22_;
		GXmlDomNode* _tmp23_;
		GXmlGomDocument* _tmp24_;
		GXmlDomNodeList* _tmp25_;
		GXmlDomNodeList* _tmp26_;
		GXmlDomNodeList* _tmp27_;
		gint _tmp28_;
		gint _tmp29_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp30_;
		GXmlDomElement* _tmp31_;
		GXmlGomDocument* _tmp32_;
		GXmlDomElement* _tmp33_;
		GXmlDomNode* _tmp34_;
		GXmlDomNode* _tmp35_;
		GXmlGomDocument* _tmp36_;
		GXmlDomNodeList* _tmp37_;
		GXmlDomNodeList* _tmp38_;
		GXmlDomNodeList* _tmp39_;
		gint _tmp40_;
		gint _tmp41_;
		gchar* _tmp42_ = NULL;
		GXmlGomDocument* _tmp43_;
		gchar* _tmp44_;
		gchar* _tmp45_ = NULL;
		GXmlGomDocument* _tmp46_;
		gchar* _tmp47_;
#line 646 "GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new ();
#line 646 "GomDocumentTest.vala"
		d = _tmp0_;
#line 647 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:647: Creating a DocumentType");
#line 648 "GomDocumentTest.vala"
		_tmp1_ = d;
#line 648 "GomDocumentTest.vala"
		_tmp2_ = gxml_gom_document_type_new ((GXmlDomDocument*) _tmp1_, "svg", "-//W3C//DTD SVG 1.1//EN", "http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd");
#line 648 "GomDocumentTest.vala"
		dt1 = _tmp2_;
#line 649 "GomDocumentTest.vala"
		_tmp3_ = dt1;
#line 649 "GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_DOM_DOCUMENT_TYPE), "dt1 is DomDocumentType");
#line 650 "GomDocumentTest.vala"
		_tmp4_ = dt1;
#line 650 "GomDocumentTest.vala"
		_tmp5_ = gxml_dom_node_get_node_type ((GXmlDomNode*) _tmp4_);
#line 650 "GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 650 "GomDocumentTest.vala"
		_vala_assert (_tmp6_ == GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE, "dt1.node_type == DomNode.NodeType.DOCUMENT_TYPE_NODE");
#line 651 "GomDocumentTest.vala"
		_tmp7_ = dt1;
#line 651 "GomDocumentTest.vala"
		_tmp8_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp7_);
#line 651 "GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 651 "GomDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 651 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp10_, "!DOCTYPE") == 0, "dt1.node_name == \"!DOCTYPE\"");
#line 651 "GomDocumentTest.vala"
		_g_free0 (_tmp10_);
#line 652 "GomDocumentTest.vala"
		_tmp11_ = dt1;
#line 652 "GomDocumentTest.vala"
		_tmp12_ = gxml_dom_document_type_get_name ((GXmlDomDocumentType*) _tmp11_);
#line 652 "GomDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 652 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp13_, "svg") == 0, "dt1.name == \"svg\"");
#line 653 "GomDocumentTest.vala"
		_tmp14_ = dt1;
#line 653 "GomDocumentTest.vala"
		_tmp15_ = gxml_dom_document_type_get_public_id ((GXmlDomDocumentType*) _tmp14_);
#line 653 "GomDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 653 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp16_, "-//W3C//DTD SVG 1.1//EN") == 0, "dt1.public_id == \"-//W3C//DTD SVG 1.1//EN\"");
#line 654 "GomDocumentTest.vala"
		_tmp17_ = dt1;
#line 654 "GomDocumentTest.vala"
		_tmp18_ = gxml_dom_document_type_get_system_id ((GXmlDomDocumentType*) _tmp17_);
#line 654 "GomDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 654 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp19_, "http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd") == 0, "dt1.system_id == \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\"");
#line 655 "GomDocumentTest.vala"
		_tmp20_ = d;
#line 655 "GomDocumentTest.vala"
		_tmp21_ = dt1;
#line 655 "GomDocumentTest.vala"
		_tmp22_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp20_, (GXmlDomNode*) _tmp21_, &_inner_error0_);
#line 655 "GomDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 655 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp23_);
#line 655 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 655 "GomDocumentTest.vala"
			_g_object_unref0 (dt1);
#line 655 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 8028 "GomDocumentTest.c"
			goto __catch108_g_error;
		}
#line 656 "GomDocumentTest.vala"
		_tmp24_ = d;
#line 656 "GomDocumentTest.vala"
		_tmp25_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp24_);
#line 656 "GomDocumentTest.vala"
		_tmp26_ = _tmp25_;
#line 656 "GomDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 656 "GomDocumentTest.vala"
		_tmp28_ = gxml_dom_node_list_get_length (_tmp27_);
#line 656 "GomDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 656 "GomDocumentTest.vala"
		_vala_assert (_tmp29_ == 1, "d.child_nodes.length == 1");
#line 656 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp27_);
#line 657 "GomDocumentTest.vala"
		_tmp30_ = d;
#line 657 "GomDocumentTest.vala"
		_tmp31_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp30_, "svg", &_inner_error0_);
#line 657 "GomDocumentTest.vala"
		r = _tmp31_;
#line 657 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 657 "GomDocumentTest.vala"
			_g_object_unref0 (dt1);
#line 657 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 8059 "GomDocumentTest.c"
			goto __catch108_g_error;
		}
#line 658 "GomDocumentTest.vala"
		_tmp32_ = d;
#line 658 "GomDocumentTest.vala"
		_tmp33_ = r;
#line 658 "GomDocumentTest.vala"
		_tmp34_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp32_, (GXmlDomNode*) _tmp33_, &_inner_error0_);
#line 658 "GomDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 658 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp35_);
#line 658 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 658 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 658 "GomDocumentTest.vala"
			_g_object_unref0 (dt1);
#line 658 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 8080 "GomDocumentTest.c"
			goto __catch108_g_error;
		}
#line 659 "GomDocumentTest.vala"
		_tmp36_ = d;
#line 659 "GomDocumentTest.vala"
		_tmp37_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp36_);
#line 659 "GomDocumentTest.vala"
		_tmp38_ = _tmp37_;
#line 659 "GomDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 659 "GomDocumentTest.vala"
		_tmp40_ = gxml_dom_node_list_get_length (_tmp39_);
#line 659 "GomDocumentTest.vala"
		_tmp41_ = _tmp40_;
#line 659 "GomDocumentTest.vala"
		_vala_assert (_tmp41_ == 2, "d.child_nodes.length == 2");
#line 659 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp39_);
#line 660 "GomDocumentTest.vala"
		_tmp43_ = d;
#line 660 "GomDocumentTest.vala"
		_tmp44_ = gxml_dom_document_write_string ((GXmlDomDocument*) _tmp43_, NULL, &_inner_error0_);
#line 660 "GomDocumentTest.vala"
		_tmp42_ = _tmp44_;
#line 660 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 660 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 660 "GomDocumentTest.vala"
			_g_object_unref0 (dt1);
#line 660 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 8113 "GomDocumentTest.c"
			goto __catch108_g_error;
		}
#line 660 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:660: %s", _tmp42_);
#line 661 "GomDocumentTest.vala"
		_tmp46_ = d;
#line 661 "GomDocumentTest.vala"
		_tmp47_ = gxml_dom_document_write_string ((GXmlDomDocument*) _tmp46_, NULL, &_inner_error0_);
#line 661 "GomDocumentTest.vala"
		_tmp45_ = _tmp47_;
#line 661 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 661 "GomDocumentTest.vala"
			_g_free0 (_tmp42_);
#line 661 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 661 "GomDocumentTest.vala"
			_g_object_unref0 (dt1);
#line 661 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 8134 "GomDocumentTest.c"
			goto __catch108_g_error;
		}
#line 661 "GomDocumentTest.vala"
		_vala_assert (string_contains (_tmp45_, "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\" \"http://www.w3.org/G" \
"raphics/SVG/1.1/DTD/svg11.dtd\">"), "\"<!DOCTYPE svg PUBLIC \\\"-//W3C//DTD SVG 1.1//EN\\\" \\\"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\\\">\" in d.write_string ()");
#line 645 "GomDocumentTest.vala"
		_g_free0 (_tmp45_);
#line 645 "GomDocumentTest.vala"
		_g_free0 (_tmp42_);
#line 645 "GomDocumentTest.vala"
		_g_object_unref0 (r);
#line 645 "GomDocumentTest.vala"
		_g_object_unref0 (dt1);
#line 645 "GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 8149 "GomDocumentTest.c"
	}
	goto __finally108;
	__catch108_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp48_;
		gchar* _tmp49_;
		gchar* _tmp50_;
#line 645 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 645 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 663 "GomDocumentTest.vala"
		_tmp48_ = e->message;
#line 663 "GomDocumentTest.vala"
		_tmp49_ = g_strconcat ("Error: ", _tmp48_, NULL);
#line 663 "GomDocumentTest.vala"
		_tmp50_ = _tmp49_;
#line 663 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:663: %s", _tmp50_);
#line 663 "GomDocumentTest.vala"
		_g_free0 (_tmp50_);
#line 664 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 645 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 8176 "GomDocumentTest.c"
	}
	__finally108:
#line 645 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 645 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 645 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 645 "GomDocumentTest.vala"
		return;
#line 8187 "GomDocumentTest.c"
	}
}

static void
___lambda90__gtest_func (void)
{
#line 644 "GomDocumentTest.vala"
	__lambda90_ ();
#line 8196 "GomDocumentTest.c"
}

static void
__lambda91_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlGomDocumentType* dt1 = NULL;
		GXmlGomDocument* _tmp1_;
		GXmlGomDocumentType* _tmp2_;
		GXmlGomDocumentType* _tmp3_;
		GXmlGomDocumentType* _tmp4_;
		GXmlDomNodeNodeType _tmp5_;
		GXmlDomNodeNodeType _tmp6_;
		GXmlGomDocumentType* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		GXmlGomDocumentType* _tmp11_;
		const gchar* _tmp12_;
		const gchar* _tmp13_;
		GXmlGomDocumentType* _tmp14_;
		const gchar* _tmp15_;
		const gchar* _tmp16_;
		GXmlGomDocumentType* _tmp17_;
		const gchar* _tmp18_;
		const gchar* _tmp19_;
		GXmlGomDocument* _tmp20_;
		GXmlGomDocumentType* _tmp21_;
		GXmlDomNode* _tmp22_;
		GXmlDomNode* _tmp23_;
		GXmlGomDocument* _tmp24_;
		GXmlDomNodeList* _tmp25_;
		GXmlDomNodeList* _tmp26_;
		GXmlDomNodeList* _tmp27_;
		gint _tmp28_;
		gint _tmp29_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp30_;
		GXmlDomElement* _tmp31_;
		GXmlGomDocument* _tmp32_;
		GXmlDomElement* _tmp33_;
		GXmlDomNode* _tmp34_;
		GXmlDomNode* _tmp35_;
		GXmlGomDocument* _tmp36_;
		GXmlDomNodeList* _tmp37_;
		GXmlDomNodeList* _tmp38_;
		GXmlDomNodeList* _tmp39_;
		gint _tmp40_;
		gint _tmp41_;
		gchar* _tmp42_ = NULL;
		GXmlGomDocument* _tmp43_;
		gchar* _tmp44_;
		gchar* _tmp45_ = NULL;
		GXmlGomDocument* _tmp46_;
		gchar* _tmp47_;
#line 669 "GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new ();
#line 669 "GomDocumentTest.vala"
		d = _tmp0_;
#line 670 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:670: Creating a DocumentType");
#line 671 "GomDocumentTest.vala"
		_tmp1_ = d;
#line 671 "GomDocumentTest.vala"
		_tmp2_ = gxml_gom_document_type_new ((GXmlDomDocument*) _tmp1_, "svg", NULL, NULL);
#line 671 "GomDocumentTest.vala"
		dt1 = _tmp2_;
#line 672 "GomDocumentTest.vala"
		_tmp3_ = dt1;
#line 672 "GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_DOM_DOCUMENT_TYPE), "dt1 is DomDocumentType");
#line 673 "GomDocumentTest.vala"
		_tmp4_ = dt1;
#line 673 "GomDocumentTest.vala"
		_tmp5_ = gxml_dom_node_get_node_type ((GXmlDomNode*) _tmp4_);
#line 673 "GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 673 "GomDocumentTest.vala"
		_vala_assert (_tmp6_ == GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE, "dt1.node_type == DomNode.NodeType.DOCUMENT_TYPE_NODE");
#line 674 "GomDocumentTest.vala"
		_tmp7_ = dt1;
#line 674 "GomDocumentTest.vala"
		_tmp8_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp7_);
#line 674 "GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 674 "GomDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 674 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp10_, "!DOCTYPE") == 0, "dt1.node_name == \"!DOCTYPE\"");
#line 674 "GomDocumentTest.vala"
		_g_free0 (_tmp10_);
#line 675 "GomDocumentTest.vala"
		_tmp11_ = dt1;
#line 675 "GomDocumentTest.vala"
		_tmp12_ = gxml_dom_document_type_get_name ((GXmlDomDocumentType*) _tmp11_);
#line 675 "GomDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 675 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp13_, "svg") == 0, "dt1.name == \"svg\"");
#line 676 "GomDocumentTest.vala"
		_tmp14_ = dt1;
#line 676 "GomDocumentTest.vala"
		_tmp15_ = gxml_dom_document_type_get_public_id ((GXmlDomDocumentType*) _tmp14_);
#line 676 "GomDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 676 "GomDocumentTest.vala"
		_vala_assert (_tmp16_ == NULL, "dt1.public_id == null");
#line 677 "GomDocumentTest.vala"
		_tmp17_ = dt1;
#line 677 "GomDocumentTest.vala"
		_tmp18_ = gxml_dom_document_type_get_system_id ((GXmlDomDocumentType*) _tmp17_);
#line 677 "GomDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 677 "GomDocumentTest.vala"
		_vala_assert (_tmp19_ == NULL, "dt1.system_id == null");
#line 678 "GomDocumentTest.vala"
		_tmp20_ = d;
#line 678 "GomDocumentTest.vala"
		_tmp21_ = dt1;
#line 678 "GomDocumentTest.vala"
		_tmp22_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp20_, (GXmlDomNode*) _tmp21_, &_inner_error0_);
#line 678 "GomDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 678 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp23_);
#line 678 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 678 "GomDocumentTest.vala"
			_g_object_unref0 (dt1);
#line 678 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 8331 "GomDocumentTest.c"
			goto __catch109_g_error;
		}
#line 679 "GomDocumentTest.vala"
		_tmp24_ = d;
#line 679 "GomDocumentTest.vala"
		_tmp25_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp24_);
#line 679 "GomDocumentTest.vala"
		_tmp26_ = _tmp25_;
#line 679 "GomDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 679 "GomDocumentTest.vala"
		_tmp28_ = gxml_dom_node_list_get_length (_tmp27_);
#line 679 "GomDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 679 "GomDocumentTest.vala"
		_vala_assert (_tmp29_ == 1, "d.child_nodes.length == 1");
#line 679 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp27_);
#line 680 "GomDocumentTest.vala"
		_tmp30_ = d;
#line 680 "GomDocumentTest.vala"
		_tmp31_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp30_, "svg", &_inner_error0_);
#line 680 "GomDocumentTest.vala"
		r = _tmp31_;
#line 680 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 680 "GomDocumentTest.vala"
			_g_object_unref0 (dt1);
#line 680 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 8362 "GomDocumentTest.c"
			goto __catch109_g_error;
		}
#line 681 "GomDocumentTest.vala"
		_tmp32_ = d;
#line 681 "GomDocumentTest.vala"
		_tmp33_ = r;
#line 681 "GomDocumentTest.vala"
		_tmp34_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp32_, (GXmlDomNode*) _tmp33_, &_inner_error0_);
#line 681 "GomDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 681 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp35_);
#line 681 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 681 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 681 "GomDocumentTest.vala"
			_g_object_unref0 (dt1);
#line 681 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 8383 "GomDocumentTest.c"
			goto __catch109_g_error;
		}
#line 682 "GomDocumentTest.vala"
		_tmp36_ = d;
#line 682 "GomDocumentTest.vala"
		_tmp37_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp36_);
#line 682 "GomDocumentTest.vala"
		_tmp38_ = _tmp37_;
#line 682 "GomDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 682 "GomDocumentTest.vala"
		_tmp40_ = gxml_dom_node_list_get_length (_tmp39_);
#line 682 "GomDocumentTest.vala"
		_tmp41_ = _tmp40_;
#line 682 "GomDocumentTest.vala"
		_vala_assert (_tmp41_ == 2, "d.child_nodes.length == 2");
#line 682 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp39_);
#line 683 "GomDocumentTest.vala"
		_tmp43_ = d;
#line 683 "GomDocumentTest.vala"
		_tmp44_ = gxml_dom_document_write_string ((GXmlDomDocument*) _tmp43_, NULL, &_inner_error0_);
#line 683 "GomDocumentTest.vala"
		_tmp42_ = _tmp44_;
#line 683 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 683 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 683 "GomDocumentTest.vala"
			_g_object_unref0 (dt1);
#line 683 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 8416 "GomDocumentTest.c"
			goto __catch109_g_error;
		}
#line 683 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:683: %s", _tmp42_);
#line 684 "GomDocumentTest.vala"
		_tmp46_ = d;
#line 684 "GomDocumentTest.vala"
		_tmp47_ = gxml_dom_document_write_string ((GXmlDomDocument*) _tmp46_, NULL, &_inner_error0_);
#line 684 "GomDocumentTest.vala"
		_tmp45_ = _tmp47_;
#line 684 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 684 "GomDocumentTest.vala"
			_g_free0 (_tmp42_);
#line 684 "GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 684 "GomDocumentTest.vala"
			_g_object_unref0 (dt1);
#line 684 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 8437 "GomDocumentTest.c"
			goto __catch109_g_error;
		}
#line 684 "GomDocumentTest.vala"
		_vala_assert (string_contains (_tmp45_, "<!DOCTYPE svg>"), "\"<!DOCTYPE svg>\" in d.write_string ()");
#line 668 "GomDocumentTest.vala"
		_g_free0 (_tmp45_);
#line 668 "GomDocumentTest.vala"
		_g_free0 (_tmp42_);
#line 668 "GomDocumentTest.vala"
		_g_object_unref0 (r);
#line 668 "GomDocumentTest.vala"
		_g_object_unref0 (dt1);
#line 668 "GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 8452 "GomDocumentTest.c"
	}
	goto __finally109;
	__catch109_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp48_;
		gchar* _tmp49_;
		gchar* _tmp50_;
#line 668 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 668 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 686 "GomDocumentTest.vala"
		_tmp48_ = e->message;
#line 686 "GomDocumentTest.vala"
		_tmp49_ = g_strconcat ("Error: ", _tmp48_, NULL);
#line 686 "GomDocumentTest.vala"
		_tmp50_ = _tmp49_;
#line 686 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:686: %s", _tmp50_);
#line 686 "GomDocumentTest.vala"
		_g_free0 (_tmp50_);
#line 687 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 668 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 8479 "GomDocumentTest.c"
	}
	__finally109:
#line 668 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 668 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 668 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 668 "GomDocumentTest.vala"
		return;
#line 8490 "GomDocumentTest.c"
	}
}

static void
___lambda91__gtest_func (void)
{
#line 667 "GomDocumentTest.vala"
	__lambda91_ ();
#line 8499 "GomDocumentTest.c"
}

static void
__lambda92_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp0_;
		gchar* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_;
		gchar* _tmp3_;
		GXmlGomDocument* _tmp4_;
		GXmlDomNodeList* _tmp5_;
		GXmlDomNodeList* _tmp6_;
		GXmlDomNodeList* _tmp7_;
		gint _tmp8_;
		gint _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		GXmlGomDocument* _tmp12_;
		GXmlDomNodeList* _tmp13_;
		GXmlDomNodeList* _tmp14_;
		GXmlDomNodeList* _tmp15_;
		gint _tmp16_;
		gint _tmp17_;
		GXmlDomDocumentType* dt1 = NULL;
		GXmlGomDocument* _tmp18_;
		GXmlDomNodeList* _tmp19_;
		GXmlDomNodeList* _tmp20_;
		GXmlDomNodeList* _tmp21_;
		gpointer _tmp22_;
		GXmlDomNode* _tmp23_;
		GXmlDomDocumentType* _tmp24_;
		GXmlDomDocumentType* _tmp25_;
		GXmlDomNodeNodeType _tmp26_;
		GXmlDomNodeNodeType _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
		gchar* _tmp30_;
		const gchar* _tmp31_;
		const gchar* _tmp32_;
		const gchar* _tmp33_;
		const gchar* _tmp34_;
		const gchar* _tmp35_;
		const gchar* _tmp36_;
#line 692 "GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<?xml version=\"1.0\"?>\n" \
"<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\" \"http://www.w3.org/G" \
"raphics/SVG/1.1/DTD/svg11.dtd\"><svg/>", &_inner_error0_);
#line 692 "GomDocumentTest.vala"
		d = _tmp0_;
#line 692 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 8552 "GomDocumentTest.c"
			goto __catch110_g_error;
		}
#line 693 "GomDocumentTest.vala"
		_tmp2_ = d;
#line 693 "GomDocumentTest.vala"
		_tmp3_ = gxml_dom_document_write_string ((GXmlDomDocument*) _tmp2_, NULL, &_inner_error0_);
#line 693 "GomDocumentTest.vala"
		_tmp1_ = _tmp3_;
#line 693 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 693 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 8565 "GomDocumentTest.c"
			goto __catch110_g_error;
		}
#line 693 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:693: %s", _tmp1_);
#line 694 "GomDocumentTest.vala"
		_tmp4_ = d;
#line 694 "GomDocumentTest.vala"
		_tmp5_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp4_);
#line 694 "GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 694 "GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 694 "GomDocumentTest.vala"
		_tmp8_ = gxml_dom_node_list_get_length (_tmp7_);
#line 694 "GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 694 "GomDocumentTest.vala"
		_tmp10_ = g_strdup_printf ("%i", _tmp9_);
#line 694 "GomDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 694 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:694: %s", _tmp11_);
#line 694 "GomDocumentTest.vala"
		_g_free0 (_tmp11_);
#line 694 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp7_);
#line 695 "GomDocumentTest.vala"
		_tmp12_ = d;
#line 695 "GomDocumentTest.vala"
		_tmp13_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp12_);
#line 695 "GomDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 695 "GomDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 695 "GomDocumentTest.vala"
		_tmp16_ = gxml_dom_node_list_get_length (_tmp15_);
#line 695 "GomDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 695 "GomDocumentTest.vala"
		_vala_assert (_tmp17_ == 2, "d.child_nodes.length == 2");
#line 695 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 696 "GomDocumentTest.vala"
		_tmp18_ = d;
#line 696 "GomDocumentTest.vala"
		_tmp19_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp18_);
#line 696 "GomDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 696 "GomDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 696 "GomDocumentTest.vala"
		_tmp22_ = gee_list_get ((GeeList*) _tmp21_, 0);
#line 696 "GomDocumentTest.vala"
		_tmp23_ = (GXmlDomNode*) _tmp22_;
#line 696 "GomDocumentTest.vala"
		_tmp24_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, GXML_TYPE_DOM_DOCUMENT_TYPE) ? ((GXmlDomDocumentType*) _tmp23_) : NULL;
#line 696 "GomDocumentTest.vala"
		if (_tmp24_ == NULL) {
#line 696 "GomDocumentTest.vala"
			_g_object_unref0 (_tmp23_);
#line 8626 "GomDocumentTest.c"
		}
#line 696 "GomDocumentTest.vala"
		_tmp25_ = _tmp24_;
#line 696 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp21_);
#line 696 "GomDocumentTest.vala"
		dt1 = _tmp25_;
#line 697 "GomDocumentTest.vala"
		_vala_assert (dt1 != NULL, "dt1 != null");
#line 698 "GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (dt1, GXML_TYPE_DOM_DOCUMENT_TYPE), "dt1 is DomDocumentType");
#line 699 "GomDocumentTest.vala"
		_tmp26_ = gxml_dom_node_get_node_type ((GXmlDomNode*) dt1);
#line 699 "GomDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 699 "GomDocumentTest.vala"
		_vala_assert (_tmp27_ == GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE, "dt1.node_type == DomNode.NodeType.DOCUMENT_TYPE_NODE");
#line 700 "GomDocumentTest.vala"
		_tmp28_ = gxml_dom_node_get_node_name ((GXmlDomNode*) dt1);
#line 700 "GomDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 700 "GomDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 700 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp30_, "!DOCTYPE") == 0, "dt1.node_name == \"!DOCTYPE\"");
#line 700 "GomDocumentTest.vala"
		_g_free0 (_tmp30_);
#line 701 "GomDocumentTest.vala"
		_tmp31_ = gxml_dom_document_type_get_name (dt1);
#line 701 "GomDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 701 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp32_, "svg") == 0, "dt1.name == \"svg\"");
#line 702 "GomDocumentTest.vala"
		_tmp33_ = gxml_dom_document_type_get_public_id (dt1);
#line 702 "GomDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 702 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "-//W3C//DTD SVG 1.1//EN") == 0, "dt1.public_id == \"-//W3C//DTD SVG 1.1//EN\"");
#line 703 "GomDocumentTest.vala"
		_tmp35_ = gxml_dom_document_type_get_system_id (dt1);
#line 703 "GomDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 703 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp36_, "http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd") == 0, "dt1.system_id == \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\"");
#line 691 "GomDocumentTest.vala"
		_g_object_unref0 (dt1);
#line 691 "GomDocumentTest.vala"
		_g_free0 (_tmp1_);
#line 691 "GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 8678 "GomDocumentTest.c"
	}
	goto __finally110;
	__catch110_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp37_;
		gchar* _tmp38_;
		gchar* _tmp39_;
#line 691 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 691 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 705 "GomDocumentTest.vala"
		_tmp37_ = e->message;
#line 705 "GomDocumentTest.vala"
		_tmp38_ = g_strconcat ("Error: ", _tmp37_, NULL);
#line 705 "GomDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 705 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:705: %s", _tmp39_);
#line 705 "GomDocumentTest.vala"
		_g_free0 (_tmp39_);
#line 706 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 691 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 8705 "GomDocumentTest.c"
	}
	__finally110:
#line 691 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 691 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 691 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 691 "GomDocumentTest.vala"
		return;
#line 8716 "GomDocumentTest.c"
	}
}

static void
___lambda92__gtest_func (void)
{
#line 690 "GomDocumentTest.vala"
	__lambda92_ ();
#line 8725 "GomDocumentTest.c"
}

static void
__lambda93_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp0_;
		gchar* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_;
		gchar* _tmp3_;
		GXmlGomDocument* _tmp4_;
		GXmlDomNodeList* _tmp5_;
		GXmlDomNodeList* _tmp6_;
		GXmlDomNodeList* _tmp7_;
		gint _tmp8_;
		gint _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		GXmlGomDocument* _tmp12_;
		GXmlDomNodeList* _tmp13_;
		GXmlDomNodeList* _tmp14_;
		GXmlDomNodeList* _tmp15_;
		gint _tmp16_;
		gint _tmp17_;
		GXmlDomDocumentType* dt1 = NULL;
		GXmlGomDocument* _tmp18_;
		GXmlDomNodeList* _tmp19_;
		GXmlDomNodeList* _tmp20_;
		GXmlDomNodeList* _tmp21_;
		gpointer _tmp22_;
		GXmlDomNode* _tmp23_;
		GXmlDomDocumentType* _tmp24_;
		GXmlDomDocumentType* _tmp25_;
		GXmlDomNodeNodeType _tmp26_;
		GXmlDomNodeNodeType _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
		gchar* _tmp30_;
		const gchar* _tmp31_;
		const gchar* _tmp32_;
		const gchar* _tmp33_;
		const gchar* _tmp34_;
		const gchar* _tmp35_;
		const gchar* _tmp36_;
#line 711 "GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<?xml version=\"1.0\"?>\n" \
"<!DOCTYPE     svg     PUBLIC     \"-//W3C//DTD SVG 1.1//EN\"     \"htt" \
"p://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\"    ><svg/>", &_inner_error0_);
#line 711 "GomDocumentTest.vala"
		d = _tmp0_;
#line 711 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 8778 "GomDocumentTest.c"
			goto __catch111_g_error;
		}
#line 712 "GomDocumentTest.vala"
		_tmp2_ = d;
#line 712 "GomDocumentTest.vala"
		_tmp3_ = gxml_dom_document_write_string ((GXmlDomDocument*) _tmp2_, NULL, &_inner_error0_);
#line 712 "GomDocumentTest.vala"
		_tmp1_ = _tmp3_;
#line 712 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 712 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 8791 "GomDocumentTest.c"
			goto __catch111_g_error;
		}
#line 712 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:712: %s", _tmp1_);
#line 713 "GomDocumentTest.vala"
		_tmp4_ = d;
#line 713 "GomDocumentTest.vala"
		_tmp5_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp4_);
#line 713 "GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 713 "GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 713 "GomDocumentTest.vala"
		_tmp8_ = gxml_dom_node_list_get_length (_tmp7_);
#line 713 "GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 713 "GomDocumentTest.vala"
		_tmp10_ = g_strdup_printf ("%i", _tmp9_);
#line 713 "GomDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 713 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:713: %s", _tmp11_);
#line 713 "GomDocumentTest.vala"
		_g_free0 (_tmp11_);
#line 713 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp7_);
#line 714 "GomDocumentTest.vala"
		_tmp12_ = d;
#line 714 "GomDocumentTest.vala"
		_tmp13_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp12_);
#line 714 "GomDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 714 "GomDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 714 "GomDocumentTest.vala"
		_tmp16_ = gxml_dom_node_list_get_length (_tmp15_);
#line 714 "GomDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 714 "GomDocumentTest.vala"
		_vala_assert (_tmp17_ == 2, "d.child_nodes.length == 2");
#line 714 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 715 "GomDocumentTest.vala"
		_tmp18_ = d;
#line 715 "GomDocumentTest.vala"
		_tmp19_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp18_);
#line 715 "GomDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 715 "GomDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 715 "GomDocumentTest.vala"
		_tmp22_ = gee_list_get ((GeeList*) _tmp21_, 0);
#line 715 "GomDocumentTest.vala"
		_tmp23_ = (GXmlDomNode*) _tmp22_;
#line 715 "GomDocumentTest.vala"
		_tmp24_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, GXML_TYPE_DOM_DOCUMENT_TYPE) ? ((GXmlDomDocumentType*) _tmp23_) : NULL;
#line 715 "GomDocumentTest.vala"
		if (_tmp24_ == NULL) {
#line 715 "GomDocumentTest.vala"
			_g_object_unref0 (_tmp23_);
#line 8852 "GomDocumentTest.c"
		}
#line 715 "GomDocumentTest.vala"
		_tmp25_ = _tmp24_;
#line 715 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp21_);
#line 715 "GomDocumentTest.vala"
		dt1 = _tmp25_;
#line 716 "GomDocumentTest.vala"
		_vala_assert (dt1 != NULL, "dt1 != null");
#line 717 "GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (dt1, GXML_TYPE_DOM_DOCUMENT_TYPE), "dt1 is DomDocumentType");
#line 718 "GomDocumentTest.vala"
		_tmp26_ = gxml_dom_node_get_node_type ((GXmlDomNode*) dt1);
#line 718 "GomDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 718 "GomDocumentTest.vala"
		_vala_assert (_tmp27_ == GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE, "dt1.node_type == DomNode.NodeType.DOCUMENT_TYPE_NODE");
#line 719 "GomDocumentTest.vala"
		_tmp28_ = gxml_dom_node_get_node_name ((GXmlDomNode*) dt1);
#line 719 "GomDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 719 "GomDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 719 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp30_, "!DOCTYPE") == 0, "dt1.node_name == \"!DOCTYPE\"");
#line 719 "GomDocumentTest.vala"
		_g_free0 (_tmp30_);
#line 720 "GomDocumentTest.vala"
		_tmp31_ = gxml_dom_document_type_get_name (dt1);
#line 720 "GomDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 720 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp32_, "svg") == 0, "dt1.name == \"svg\"");
#line 721 "GomDocumentTest.vala"
		_tmp33_ = gxml_dom_document_type_get_public_id (dt1);
#line 721 "GomDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 721 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "-//W3C//DTD SVG 1.1//EN") == 0, "dt1.public_id == \"-//W3C//DTD SVG 1.1//EN\"");
#line 722 "GomDocumentTest.vala"
		_tmp35_ = gxml_dom_document_type_get_system_id (dt1);
#line 722 "GomDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 722 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp36_, "http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd") == 0, "dt1.system_id == \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\"");
#line 710 "GomDocumentTest.vala"
		_g_object_unref0 (dt1);
#line 710 "GomDocumentTest.vala"
		_g_free0 (_tmp1_);
#line 710 "GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 8904 "GomDocumentTest.c"
	}
	goto __finally111;
	__catch111_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp37_;
		gchar* _tmp38_;
		gchar* _tmp39_;
#line 710 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 710 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 724 "GomDocumentTest.vala"
		_tmp37_ = e->message;
#line 724 "GomDocumentTest.vala"
		_tmp38_ = g_strconcat ("Error: ", _tmp37_, NULL);
#line 724 "GomDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 724 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:724: %s", _tmp39_);
#line 724 "GomDocumentTest.vala"
		_g_free0 (_tmp39_);
#line 725 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 710 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 8931 "GomDocumentTest.c"
	}
	__finally111:
#line 710 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 710 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 710 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 710 "GomDocumentTest.vala"
		return;
#line 8942 "GomDocumentTest.c"
	}
}

static void
___lambda93__gtest_func (void)
{
#line 709 "GomDocumentTest.vala"
	__lambda93_ ();
#line 8951 "GomDocumentTest.c"
}

static void
__lambda94_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp0_;
		gchar* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_;
		gchar* _tmp3_;
		GXmlGomDocument* _tmp4_;
		GXmlDomNodeList* _tmp5_;
		GXmlDomNodeList* _tmp6_;
		GXmlDomNodeList* _tmp7_;
		gint _tmp8_;
		gint _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		GXmlGomDocument* _tmp12_;
		GXmlDomNodeList* _tmp13_;
		GXmlDomNodeList* _tmp14_;
		GXmlDomNodeList* _tmp15_;
		gint _tmp16_;
		gint _tmp17_;
		GXmlDomDocumentType* dt1 = NULL;
		GXmlGomDocument* _tmp18_;
		GXmlDomNodeList* _tmp19_;
		GXmlDomNodeList* _tmp20_;
		GXmlDomNodeList* _tmp21_;
		gpointer _tmp22_;
		GXmlDomNode* _tmp23_;
		GXmlDomDocumentType* _tmp24_;
		GXmlDomDocumentType* _tmp25_;
		GXmlDomNodeNodeType _tmp26_;
		GXmlDomNodeNodeType _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
		gchar* _tmp30_;
		const gchar* _tmp31_;
		const gchar* _tmp32_;
		const gchar* _tmp33_;
		const gchar* _tmp34_;
		const gchar* _tmp35_;
		const gchar* _tmp36_;
#line 730 "GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<?xml version=\"1.0\"?>\n<!DOCTYPE     svg     ><svg/>", &_inner_error0_);
#line 730 "GomDocumentTest.vala"
		d = _tmp0_;
#line 730 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 9004 "GomDocumentTest.c"
			goto __catch112_g_error;
		}
#line 731 "GomDocumentTest.vala"
		_tmp2_ = d;
#line 731 "GomDocumentTest.vala"
		_tmp3_ = gxml_dom_document_write_string ((GXmlDomDocument*) _tmp2_, NULL, &_inner_error0_);
#line 731 "GomDocumentTest.vala"
		_tmp1_ = _tmp3_;
#line 731 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 731 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 9017 "GomDocumentTest.c"
			goto __catch112_g_error;
		}
#line 731 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:731: %s", _tmp1_);
#line 732 "GomDocumentTest.vala"
		_tmp4_ = d;
#line 732 "GomDocumentTest.vala"
		_tmp5_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp4_);
#line 732 "GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 732 "GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 732 "GomDocumentTest.vala"
		_tmp8_ = gxml_dom_node_list_get_length (_tmp7_);
#line 732 "GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 732 "GomDocumentTest.vala"
		_tmp10_ = g_strdup_printf ("%i", _tmp9_);
#line 732 "GomDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 732 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:732: %s", _tmp11_);
#line 732 "GomDocumentTest.vala"
		_g_free0 (_tmp11_);
#line 732 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp7_);
#line 733 "GomDocumentTest.vala"
		_tmp12_ = d;
#line 733 "GomDocumentTest.vala"
		_tmp13_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp12_);
#line 733 "GomDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 733 "GomDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 733 "GomDocumentTest.vala"
		_tmp16_ = gxml_dom_node_list_get_length (_tmp15_);
#line 733 "GomDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 733 "GomDocumentTest.vala"
		_vala_assert (_tmp17_ == 2, "d.child_nodes.length == 2");
#line 733 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 734 "GomDocumentTest.vala"
		_tmp18_ = d;
#line 734 "GomDocumentTest.vala"
		_tmp19_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp18_);
#line 734 "GomDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 734 "GomDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 734 "GomDocumentTest.vala"
		_tmp22_ = gee_list_get ((GeeList*) _tmp21_, 0);
#line 734 "GomDocumentTest.vala"
		_tmp23_ = (GXmlDomNode*) _tmp22_;
#line 734 "GomDocumentTest.vala"
		_tmp24_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, GXML_TYPE_DOM_DOCUMENT_TYPE) ? ((GXmlDomDocumentType*) _tmp23_) : NULL;
#line 734 "GomDocumentTest.vala"
		if (_tmp24_ == NULL) {
#line 734 "GomDocumentTest.vala"
			_g_object_unref0 (_tmp23_);
#line 9078 "GomDocumentTest.c"
		}
#line 734 "GomDocumentTest.vala"
		_tmp25_ = _tmp24_;
#line 734 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp21_);
#line 734 "GomDocumentTest.vala"
		dt1 = _tmp25_;
#line 735 "GomDocumentTest.vala"
		_vala_assert (dt1 != NULL, "dt1 != null");
#line 736 "GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (dt1, GXML_TYPE_DOM_DOCUMENT_TYPE), "dt1 is DomDocumentType");
#line 737 "GomDocumentTest.vala"
		_tmp26_ = gxml_dom_node_get_node_type ((GXmlDomNode*) dt1);
#line 737 "GomDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 737 "GomDocumentTest.vala"
		_vala_assert (_tmp27_ == GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE, "dt1.node_type == DomNode.NodeType.DOCUMENT_TYPE_NODE");
#line 738 "GomDocumentTest.vala"
		_tmp28_ = gxml_dom_node_get_node_name ((GXmlDomNode*) dt1);
#line 738 "GomDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 738 "GomDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 738 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp30_, "!DOCTYPE") == 0, "dt1.node_name == \"!DOCTYPE\"");
#line 738 "GomDocumentTest.vala"
		_g_free0 (_tmp30_);
#line 739 "GomDocumentTest.vala"
		_tmp31_ = gxml_dom_document_type_get_name (dt1);
#line 739 "GomDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 739 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp32_, "svg") == 0, "dt1.name == \"svg\"");
#line 740 "GomDocumentTest.vala"
		_tmp33_ = gxml_dom_document_type_get_public_id (dt1);
#line 740 "GomDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 740 "GomDocumentTest.vala"
		_vala_assert (_tmp34_ == NULL, "dt1.public_id == null");
#line 741 "GomDocumentTest.vala"
		_tmp35_ = gxml_dom_document_type_get_system_id (dt1);
#line 741 "GomDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 741 "GomDocumentTest.vala"
		_vala_assert (_tmp36_ == NULL, "dt1.system_id == null");
#line 729 "GomDocumentTest.vala"
		_g_object_unref0 (dt1);
#line 729 "GomDocumentTest.vala"
		_g_free0 (_tmp1_);
#line 729 "GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 9130 "GomDocumentTest.c"
	}
	goto __finally112;
	__catch112_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp37_;
		gchar* _tmp38_;
		gchar* _tmp39_;
#line 729 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 729 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 743 "GomDocumentTest.vala"
		_tmp37_ = e->message;
#line 743 "GomDocumentTest.vala"
		_tmp38_ = g_strconcat ("Error: ", _tmp37_, NULL);
#line 743 "GomDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 743 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:743: %s", _tmp39_);
#line 743 "GomDocumentTest.vala"
		_g_free0 (_tmp39_);
#line 744 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 729 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 9157 "GomDocumentTest.c"
	}
	__finally112:
#line 729 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 729 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 729 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 729 "GomDocumentTest.vala"
		return;
#line 9168 "GomDocumentTest.c"
	}
}

static void
___lambda94__gtest_func (void)
{
#line 728 "GomDocumentTest.vala"
	__lambda94_ ();
#line 9177 "GomDocumentTest.c"
}

static void
__lambda95_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_;
		GXmlDomDocument* d = NULL;
		GXmlDomDocument* _tmp2_;
		gchar* _tmp3_ = NULL;
		GXmlDomDocument* _tmp4_;
		gchar* _tmp5_;
		GXmlDomElement* e = NULL;
		GXmlDomDocument* _tmp6_;
		GXmlDomElement* _tmp7_;
		GXmlDomElement* _tmp8_;
#line 749 "GomDocumentTest.vala"
		_tmp1_ = gxml_gom_document_new_from_string ("<root><child id=\"id1\"/><child id=\"id2\"/></root>", &_inner_error0_);
#line 749 "GomDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 749 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 9202 "GomDocumentTest.c"
			goto __catch113_g_error;
		}
#line 749 "GomDocumentTest.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL);
#line 749 "GomDocumentTest.vala"
		d = _tmp2_;
#line 750 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:750: Serialize Document");
#line 751 "GomDocumentTest.vala"
		_tmp4_ = d;
#line 751 "GomDocumentTest.vala"
		_tmp5_ = gxml_dom_document_write_string ((GXmlDomDocument*) (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GXML_TYPE_GOM_DOCUMENT) ? ((GXmlGomDocument*) _tmp4_) : NULL), NULL, &_inner_error0_);
#line 751 "GomDocumentTest.vala"
		_tmp3_ = _tmp5_;
#line 751 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 751 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 751 "GomDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 9223 "GomDocumentTest.c"
			goto __catch113_g_error;
		}
#line 751 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:751: %s", _tmp3_);
#line 752 "GomDocumentTest.vala"
		_tmp6_ = d;
#line 752 "GomDocumentTest.vala"
		_tmp7_ = gxml_dom_non_element_parent_node_get_element_by_id ((GXmlDomNonElementParentNode*) _tmp6_, "id1", &_inner_error0_);
#line 752 "GomDocumentTest.vala"
		e = _tmp7_;
#line 752 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 752 "GomDocumentTest.vala"
			_g_free0 (_tmp3_);
#line 752 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 752 "GomDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 9242 "GomDocumentTest.c"
			goto __catch113_g_error;
		}
#line 753 "GomDocumentTest.vala"
		_tmp8_ = e;
#line 753 "GomDocumentTest.vala"
		_vala_assert (_tmp8_ != NULL, "e != null");
#line 748 "GomDocumentTest.vala"
		_g_object_unref0 (e);
#line 748 "GomDocumentTest.vala"
		_g_free0 (_tmp3_);
#line 748 "GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 748 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 9257 "GomDocumentTest.c"
	}
	goto __finally113;
	__catch113_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
#line 748 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 748 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 755 "GomDocumentTest.vala"
		_tmp9_ = e->message;
#line 755 "GomDocumentTest.vala"
		_tmp10_ = g_strconcat ("Error: ", _tmp9_, NULL);
#line 755 "GomDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 755 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:755: %s", _tmp11_);
#line 755 "GomDocumentTest.vala"
		_g_free0 (_tmp11_);
#line 756 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 748 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 9284 "GomDocumentTest.c"
	}
	__finally113:
#line 748 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 748 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 748 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 748 "GomDocumentTest.vala"
		return;
#line 9295 "GomDocumentTest.c"
	}
}

static void
___lambda95__gtest_func (void)
{
#line 747 "GomDocumentTest.vala"
	__lambda95_ ();
#line 9304 "GomDocumentTest.c"
}

static void
__lambda96_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GomDocumentTestObjectDocument* d = NULL;
		GomDocumentTestObjectDocument* _tmp0_;
		GomDocumentTestObjectDocument* _tmp1_;
		GomDocumentTestObjectDocumentObjectParent* _tmp2_;
		GomDocumentTestObjectDocumentObjectParent* _tmp3_;
		GomDocumentTestObjectDocument* _tmp4_;
		gchar* _tmp5_ = NULL;
		GomDocumentTestObjectDocument* _tmp6_;
		gchar* _tmp7_;
		GomDocumentTestObjectDocument* _tmp8_;
		GomDocumentTestObjectDocumentObjectParent* _tmp9_;
		GomDocumentTestObjectDocumentObjectParent* _tmp10_;
		GomDocumentTestObjectDocument* _tmp11_;
		GomDocumentTestObjectDocumentObjectParent* _tmp12_;
		GomDocumentTestObjectDocumentObjectParent* _tmp13_;
		const gchar* _tmp14_;
		const gchar* _tmp15_;
		GomDocumentTestObjectDocument* _tmp16_;
		GomDocumentTestObjectDocumentObjectParent* _tmp17_;
		GomDocumentTestObjectDocumentObjectParent* _tmp18_;
		const gchar* _tmp19_;
		const gchar* _tmp20_;
		GomDocumentTestObjectDocument* _tmp21_;
		GomDocumentTestObjectDocumentObjectParent* _tmp22_;
		GomDocumentTestObjectDocumentObjectParent* _tmp23_;
		GomDocumentTestObjectDocumentObjectParentObjectProperty* _tmp24_;
		GomDocumentTestObjectDocumentObjectParentObjectProperty* _tmp25_;
		GomDocumentTestObjectDocument* _tmp26_;
		GomDocumentTestObjectDocumentObjectParent* _tmp27_;
		GomDocumentTestObjectDocumentObjectParent* _tmp28_;
		GomDocumentTestObjectDocumentObjectParentObjectProperty* _tmp29_;
		GomDocumentTestObjectDocumentObjectParentObjectProperty* _tmp30_;
		gchar* _tmp31_;
		gchar* _tmp32_;
		gchar* _tmp33_;
#line 761 "GomDocumentTest.vala"
		_tmp0_ = gom_document_test_object_document_new ();
#line 761 "GomDocumentTest.vala"
		d = _tmp0_;
#line 762 "GomDocumentTest.vala"
		_tmp1_ = d;
#line 762 "GomDocumentTest.vala"
		_tmp2_ = gom_document_test_object_document_get_root_element (_tmp1_);
#line 762 "GomDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 762 "GomDocumentTest.vala"
		_vala_assert (_tmp3_ == NULL, "d.root_element == null");
#line 763 "GomDocumentTest.vala"
		_tmp4_ = d;
#line 763 "GomDocumentTest.vala"
		gxml_dom_document_read_from_string ((GXmlDomDocument*) _tmp4_, "<root text=\"val2\" prop=\"yat\"><child id=\"id1\"/><child id=\"id2\"/" \
"></root>", NULL, &_inner_error0_);
#line 763 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 763 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 9367 "GomDocumentTest.c"
			goto __catch114_g_error;
		}
#line 764 "GomDocumentTest.vala"
		_tmp6_ = d;
#line 764 "GomDocumentTest.vala"
		_tmp7_ = gxml_dom_document_write_string ((GXmlDomDocument*) _tmp6_, NULL, &_inner_error0_);
#line 764 "GomDocumentTest.vala"
		_tmp5_ = _tmp7_;
#line 764 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 764 "GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 9380 "GomDocumentTest.c"
			goto __catch114_g_error;
		}
#line 764 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:764: %s", _tmp5_);
#line 765 "GomDocumentTest.vala"
		_tmp8_ = d;
#line 765 "GomDocumentTest.vala"
		_tmp9_ = gom_document_test_object_document_get_root_element (_tmp8_);
#line 765 "GomDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 765 "GomDocumentTest.vala"
		_vala_assert (_tmp10_ != NULL, "d.root_element != null");
#line 766 "GomDocumentTest.vala"
		_tmp11_ = d;
#line 766 "GomDocumentTest.vala"
		_tmp12_ = gom_document_test_object_document_get_root_element (_tmp11_);
#line 766 "GomDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 766 "GomDocumentTest.vala"
		_tmp14_ = gom_document_test_object_document_object_parent_get_text (_tmp13_);
#line 766 "GomDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 766 "GomDocumentTest.vala"
		_vala_assert (_tmp15_ != NULL, "d.root_element.text != null");
#line 767 "GomDocumentTest.vala"
		_tmp16_ = d;
#line 767 "GomDocumentTest.vala"
		_tmp17_ = gom_document_test_object_document_get_root_element (_tmp16_);
#line 767 "GomDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 767 "GomDocumentTest.vala"
		_tmp19_ = gom_document_test_object_document_object_parent_get_text (_tmp18_);
#line 767 "GomDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 767 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp20_, "val2") == 0, "d.root_element.text == \"val2\"");
#line 768 "GomDocumentTest.vala"
		_tmp21_ = d;
#line 768 "GomDocumentTest.vala"
		_tmp22_ = gom_document_test_object_document_get_root_element (_tmp21_);
#line 768 "GomDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 768 "GomDocumentTest.vala"
		_tmp24_ = gom_document_test_object_document_object_parent_get_prop (_tmp23_);
#line 768 "GomDocumentTest.vala"
		_tmp25_ = _tmp24_;
#line 768 "GomDocumentTest.vala"
		_vala_assert (_tmp25_ != NULL, "d.root_element.prop != null");
#line 769 "GomDocumentTest.vala"
		_tmp26_ = d;
#line 769 "GomDocumentTest.vala"
		_tmp27_ = gom_document_test_object_document_get_root_element (_tmp26_);
#line 769 "GomDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 769 "GomDocumentTest.vala"
		_tmp29_ = gom_document_test_object_document_object_parent_get_prop (_tmp28_);
#line 769 "GomDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 769 "GomDocumentTest.vala"
		_tmp31_ = gxml_gom_property_get_value ((GXmlGomProperty*) _tmp30_);
#line 769 "GomDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 769 "GomDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 769 "GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp33_, "yat") == 0, "d.root_element.prop.value == \"yat\"");
#line 769 "GomDocumentTest.vala"
		_g_free0 (_tmp33_);
#line 760 "GomDocumentTest.vala"
		_g_free0 (_tmp5_);
#line 760 "GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 9453 "GomDocumentTest.c"
	}
	goto __finally114;
	__catch114_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp34_;
		gchar* _tmp35_;
		gchar* _tmp36_;
#line 760 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 760 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 771 "GomDocumentTest.vala"
		_tmp34_ = e->message;
#line 771 "GomDocumentTest.vala"
		_tmp35_ = g_strconcat ("Error: ", _tmp34_, NULL);
#line 771 "GomDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 771 "GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:771: %s", _tmp36_);
#line 771 "GomDocumentTest.vala"
		_g_free0 (_tmp36_);
#line 772 "GomDocumentTest.vala"
		g_assert_not_reached ();
#line 760 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 9480 "GomDocumentTest.c"
	}
	__finally114:
#line 760 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 760 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 760 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 760 "GomDocumentTest.vala"
		return;
#line 9491 "GomDocumentTest.c"
	}
}

static void
___lambda96__gtest_func (void)
{
#line 759 "GomDocumentTest.vala"
	__lambda96_ ();
#line 9500 "GomDocumentTest.c"
}

void
gom_document_test_add_tests (void)
{
#line 59 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/construct_api", ___lambda61__gtest_func);
#line 75 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/construct_from_path_error", ___lambda62__gtest_func);
#line 94 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/construct_from_stream", ___lambda63__gtest_func);
#line 107 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/gfile/local", ___lambda64__gtest_func);
#line 131 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/read-gfile/local", ___lambda65__gtest_func);
#line 153 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/gfile/remote/read", ___lambda66__gtest_func);
#line 185 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/gfile/remote/write", ___lambda67__gtest_func);
#line 211 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/namespace/write", ___lambda68__gtest_func);
#line 230 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/construct_from_stream_error", ___lambda69__gtest_func);
#line 242 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/construct_from_string", ___lambda70__gtest_func);
#line 259 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/read_from_string", ___lambda71__gtest_func);
#line 277 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/construct_from_string_no_document_element", ___lambda72__gtest_func);
#line 287 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/construct_from_string_invalid", ___lambda73__gtest_func);
#line 297 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/save", ___lambda74__gtest_func);
#line 311 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/save_error", ___lambda75__gtest_func);
#line 321 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/create_element", ___lambda76__gtest_func);
#line 334 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/create_text_node", ___lambda77__gtest_func);
#line 345 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/node_text_content", ___lambda78__gtest_func);
#line 357 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/create_comment", ___lambda79__gtest_func);
#line 366 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/create_processing_instruction", ___lambda80__gtest_func);
#line 383 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/create_attribute", ___lambda81__gtest_func);
#line 399 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/to_string/basic", ___lambda82__gtest_func);
#line 418 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/to_string/extended", ___lambda83__gtest_func);
#line 445 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/namespace/create", ___lambda84__gtest_func);
#line 495 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/namespace/read", ___lambda85__gtest_func);
#line 514 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/namespace/invalid", ___lambda86__gtest_func);
#line 561 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/parent", ___lambda87__gtest_func);
#line 565 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/write/string", ___lambda88__gtest_func);
#line 583 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/css-selector", ___lambda89__gtest_func);
#line 644 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/doc-type/write/full", ___lambda90__gtest_func);
#line 667 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/doc-type/write/no-ids", ___lambda91__gtest_func);
#line 690 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/doc-type/read/full", ___lambda92__gtest_func);
#line 709 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/doc-type/read/spaces", ___lambda93__gtest_func);
#line 728 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/doc-type/read/no-ids", ___lambda94__gtest_func);
#line 747 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/element-id", ___lambda95__gtest_func);
#line 759 "GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/parse-root-element", ___lambda96__gtest_func);
#line 9578 "GomDocumentTest.c"
}

GomDocumentTest*
gom_document_test_construct (GType object_type)
{
	GomDocumentTest* self = NULL;
#line 25 "GomDocumentTest.vala"
	self = (GomDocumentTest*) gxml_test_construct (object_type);
#line 25 "GomDocumentTest.vala"
	return self;
#line 9589 "GomDocumentTest.c"
}

GomDocumentTest*
gom_document_test_new (void)
{
#line 25 "GomDocumentTest.vala"
	return gom_document_test_construct (TYPE_GOM_DOCUMENT_TEST);
#line 9597 "GomDocumentTest.c"
}

static inline gpointer
gom_document_test_object_document_get_instance_private (GomDocumentTestObjectDocument* self)
{
	return G_STRUCT_MEMBER_P (self, GomDocumentTestObjectDocument_private_offset);
}

static GomDocumentTestObjectDocument*
gom_document_test_object_document_construct (GType object_type)
{
	GomDocumentTestObjectDocument * self = NULL;
#line 26 "GomDocumentTest.vala"
	self = (GomDocumentTestObjectDocument*) gxml_gom_document_construct (object_type);
#line 26 "GomDocumentTest.vala"
	return self;
#line 9614 "GomDocumentTest.c"
}

static GomDocumentTestObjectDocument*
gom_document_test_object_document_new (void)
{
#line 26 "GomDocumentTest.vala"
	return gom_document_test_object_document_construct (GOM_DOCUMENT_TEST_TYPE_OBJECT_DOCUMENT);
#line 9622 "GomDocumentTest.c"
}

static GomDocumentTestObjectDocumentObjectParent*
gom_document_test_object_document_get_root_element (GomDocumentTestObjectDocument* self)
{
	GomDocumentTestObjectDocumentObjectParent* result;
	GomDocumentTestObjectDocumentObjectParent* _tmp0_;
#line 28 "GomDocumentTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 28 "GomDocumentTest.vala"
	_tmp0_ = self->priv->_root_element;
#line 28 "GomDocumentTest.vala"
	result = _tmp0_;
#line 28 "GomDocumentTest.vala"
	return result;
#line 9638 "GomDocumentTest.c"
}

static void
gom_document_test_object_document_set_root_element (GomDocumentTestObjectDocument* self,
                                                    GomDocumentTestObjectDocumentObjectParent* value)
{
#line 28 "GomDocumentTest.vala"
	g_return_if_fail (self != NULL);
#line 28 "GomDocumentTest.vala"
	if (gom_document_test_object_document_get_root_element (self) != value) {
#line 9649 "GomDocumentTest.c"
		GomDocumentTestObjectDocumentObjectParent* _tmp0_;
#line 28 "GomDocumentTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 28 "GomDocumentTest.vala"
		_g_object_unref0 (self->priv->_root_element);
#line 28 "GomDocumentTest.vala"
		self->priv->_root_element = _tmp0_;
#line 28 "GomDocumentTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_document_test_object_document_properties[GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_ROOT_ELEMENT_PROPERTY]);
#line 9659 "GomDocumentTest.c"
	}
}

static GObject *
gom_document_test_object_document_constructor (GType type,
                                               guint n_construct_properties,
                                               GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomDocumentTestObjectDocument * self;
	GXmlGomDocumentType* dt = NULL;
	GXmlGomDocumentType* _tmp0_;
	GError* _inner_error0_ = NULL;
#line 29 "GomDocumentTest.vala"
	parent_class = G_OBJECT_CLASS (gom_document_test_object_document_parent_class);
#line 29 "GomDocumentTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 29 "GomDocumentTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_DOCUMENT_TEST_TYPE_OBJECT_DOCUMENT, GomDocumentTestObjectDocument);
#line 30 "GomDocumentTest.vala"
	_tmp0_ = gxml_gom_document_type_new ((GXmlDomDocument*) self, "svg", "-//W3C//DTD SVG 1.1//EN", "http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd");
#line 30 "GomDocumentTest.vala"
	dt = _tmp0_;
#line 9684 "GomDocumentTest.c"
	{
		GXmlGomDocumentType* _tmp1_;
		GXmlDomNode* _tmp2_;
		GXmlDomNode* _tmp3_;
#line 32 "GomDocumentTest.vala"
		_tmp1_ = dt;
#line 32 "GomDocumentTest.vala"
		_tmp2_ = gxml_dom_node_append_child ((GXmlDomNode*) self, (GXmlDomNode*) _tmp1_, &_inner_error0_);
#line 32 "GomDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 32 "GomDocumentTest.vala"
		_g_object_unref0 (_tmp3_);
#line 32 "GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 9699 "GomDocumentTest.c"
			goto __catch115_g_error;
		}
	}
	goto __finally115;
	__catch115_g_error:
	{
		GError* e = NULL;
		GError* _tmp4_;
		const gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
#line 32 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 32 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 32 "GomDocumentTest.vala"
		_tmp4_ = e;
#line 32 "GomDocumentTest.vala"
		_tmp5_ = _tmp4_->message;
#line 32 "GomDocumentTest.vala"
		_tmp6_ = g_strconcat ("Error: ", _tmp5_, NULL);
#line 32 "GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 32 "GomDocumentTest.vala"
		g_warning ("GomDocumentTest.vala:32: %s", _tmp7_);
#line 32 "GomDocumentTest.vala"
		_g_free0 (_tmp7_);
#line 32 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 9729 "GomDocumentTest.c"
	}
	__finally115:
#line 32 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 32 "GomDocumentTest.vala"
		_g_object_unref0 (dt);
#line 32 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 32 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 9740 "GomDocumentTest.c"
	}
#line 29 "GomDocumentTest.vala"
	_g_object_unref0 (dt);
#line 29 "GomDocumentTest.vala"
	return obj;
#line 9746 "GomDocumentTest.c"
}

static inline gpointer
gom_document_test_object_document_object_parent_get_instance_private (GomDocumentTestObjectDocumentObjectParent* self)
{
	return G_STRUCT_MEMBER_P (self, GomDocumentTestObjectDocumentObjectParent_private_offset);
}

static GomDocumentTestObjectDocumentObjectParent*
gom_document_test_object_document_object_parent_construct (GType object_type)
{
	GomDocumentTestObjectDocumentObjectParent * self = NULL;
#line 34 "GomDocumentTest.vala"
	self = (GomDocumentTestObjectDocumentObjectParent*) gxml_gom_element_construct (object_type);
#line 34 "GomDocumentTest.vala"
	return self;
#line 9763 "GomDocumentTest.c"
}

static GomDocumentTestObjectDocumentObjectParent*
gom_document_test_object_document_object_parent_new (void)
{
#line 34 "GomDocumentTest.vala"
	return gom_document_test_object_document_object_parent_construct (GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_TYPE_OBJECT_PARENT);
#line 9771 "GomDocumentTest.c"
}

static const gchar*
gom_document_test_object_document_object_parent_get_text (GomDocumentTestObjectDocumentObjectParent* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 40 "GomDocumentTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 40 "GomDocumentTest.vala"
	_tmp0_ = self->priv->_text;
#line 40 "GomDocumentTest.vala"
	result = _tmp0_;
#line 40 "GomDocumentTest.vala"
	return result;
#line 9787 "GomDocumentTest.c"
}

static void
gom_document_test_object_document_object_parent_set_text (GomDocumentTestObjectDocumentObjectParent* self,
                                                          const gchar* value)
{
#line 40 "GomDocumentTest.vala"
	g_return_if_fail (self != NULL);
#line 40 "GomDocumentTest.vala"
	if (g_strcmp0 (value, gom_document_test_object_document_object_parent_get_text (self)) != 0) {
#line 9798 "GomDocumentTest.c"
		gchar* _tmp0_;
#line 40 "GomDocumentTest.vala"
		_tmp0_ = g_strdup (value);
#line 40 "GomDocumentTest.vala"
		_g_free0 (self->priv->_text);
#line 40 "GomDocumentTest.vala"
		self->priv->_text = _tmp0_;
#line 40 "GomDocumentTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_document_test_object_document_object_parent_properties[GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TEXT_PROPERTY]);
#line 9808 "GomDocumentTest.c"
	}
}

static GomDocumentTestObjectDocumentObjectParentObjectProperty*
gom_document_test_object_document_object_parent_get_prop (GomDocumentTestObjectDocumentObjectParent* self)
{
	GomDocumentTestObjectDocumentObjectParentObjectProperty* result;
	GomDocumentTestObjectDocumentObjectParentObjectProperty* _tmp0_;
#line 42 "GomDocumentTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 42 "GomDocumentTest.vala"
	_tmp0_ = self->priv->_prop;
#line 42 "GomDocumentTest.vala"
	result = _tmp0_;
#line 42 "GomDocumentTest.vala"
	return result;
#line 9825 "GomDocumentTest.c"
}

static void
gom_document_test_object_document_object_parent_set_prop (GomDocumentTestObjectDocumentObjectParent* self,
                                                          GomDocumentTestObjectDocumentObjectParentObjectProperty* value)
{
#line 42 "GomDocumentTest.vala"
	g_return_if_fail (self != NULL);
#line 42 "GomDocumentTest.vala"
	if (gom_document_test_object_document_object_parent_get_prop (self) != value) {
#line 9836 "GomDocumentTest.c"
		GomDocumentTestObjectDocumentObjectParentObjectProperty* _tmp0_;
#line 42 "GomDocumentTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 42 "GomDocumentTest.vala"
		_g_object_unref0 (self->priv->_prop);
#line 42 "GomDocumentTest.vala"
		self->priv->_prop = _tmp0_;
#line 42 "GomDocumentTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_document_test_object_document_object_parent_properties[GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_PROP_PROPERTY]);
#line 9846 "GomDocumentTest.c"
	}
}

static GomDocumentTestObjectDocumentObjectParentObjectChild*
gom_document_test_object_document_object_parent_get_child (GomDocumentTestObjectDocumentObjectParent* self)
{
	GomDocumentTestObjectDocumentObjectParentObjectChild* result;
	GomDocumentTestObjectDocumentObjectParentObjectChild* _tmp0_;
#line 49 "GomDocumentTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 49 "GomDocumentTest.vala"
	_tmp0_ = self->priv->_child;
#line 49 "GomDocumentTest.vala"
	result = _tmp0_;
#line 49 "GomDocumentTest.vala"
	return result;
#line 9863 "GomDocumentTest.c"
}

static void
gom_document_test_object_document_object_parent_set_child (GomDocumentTestObjectDocumentObjectParent* self,
                                                           GomDocumentTestObjectDocumentObjectParentObjectChild* value)
{
#line 49 "GomDocumentTest.vala"
	g_return_if_fail (self != NULL);
#line 49 "GomDocumentTest.vala"
	if (gom_document_test_object_document_object_parent_get_child (self) != value) {
#line 9874 "GomDocumentTest.c"
		GomDocumentTestObjectDocumentObjectParentObjectChild* _tmp0_;
#line 49 "GomDocumentTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 49 "GomDocumentTest.vala"
		_g_object_unref0 (self->priv->_child);
#line 49 "GomDocumentTest.vala"
		self->priv->_child = _tmp0_;
#line 49 "GomDocumentTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_document_test_object_document_object_parent_properties[GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_CHILD_PROPERTY]);
#line 9884 "GomDocumentTest.c"
	}
}

static GObject *
gom_document_test_object_document_object_parent_constructor (GType type,
                                                             guint n_construct_properties,
                                                             GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomDocumentTestObjectDocumentObjectParent * self;
	GError* _inner_error0_ = NULL;
#line 35 "GomDocumentTest.vala"
	parent_class = G_OBJECT_CLASS (gom_document_test_object_document_object_parent_parent_class);
#line 35 "GomDocumentTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 35 "GomDocumentTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_TYPE_OBJECT_PARENT, GomDocumentTestObjectDocumentObjectParent);
#line 9903 "GomDocumentTest.c"
	{
#line 36 "GomDocumentTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "root");
#line 9907 "GomDocumentTest.c"
	}
	goto __finally116;
	__catch116_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 36 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 36 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 37 "GomDocumentTest.vala"
		_tmp0_ = e;
#line 37 "GomDocumentTest.vala"
		_tmp1_ = _tmp0_->message;
#line 37 "GomDocumentTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 37 "GomDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 37 "GomDocumentTest.vala"
		g_warning ("GomDocumentTest.vala:37: %s", _tmp3_);
#line 37 "GomDocumentTest.vala"
		_g_free0 (_tmp3_);
#line 36 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 9935 "GomDocumentTest.c"
	}
	__finally116:
#line 36 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 36 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 36 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 9944 "GomDocumentTest.c"
	}
#line 35 "GomDocumentTest.vala"
	return obj;
#line 9948 "GomDocumentTest.c"
}

static inline gpointer
gom_document_test_object_document_object_parent_object_property_get_instance_private (GomDocumentTestObjectDocumentObjectParentObjectProperty* self)
{
	return G_STRUCT_MEMBER_P (self, GomDocumentTestObjectDocumentObjectParentObjectProperty_private_offset);
}

static gboolean
gom_document_test_object_document_object_parent_object_property_real_validate_value (GXmlGomProperty* base,
                                                                                     const gchar* val)
{
	GomDocumentTestObjectDocumentObjectParentObjectProperty * self;
	gboolean result = FALSE;
#line 45 "GomDocumentTest.vala"
	self = (GomDocumentTestObjectDocumentObjectParentObjectProperty*) base;
#line 46 "GomDocumentTest.vala"
	result = TRUE;
#line 46 "GomDocumentTest.vala"
	return result;
#line 9969 "GomDocumentTest.c"
}

static GomDocumentTestObjectDocumentObjectParentObjectProperty*
gom_document_test_object_document_object_parent_object_property_construct (GType object_type)
{
	GomDocumentTestObjectDocumentObjectParentObjectProperty * self = NULL;
#line 43 "GomDocumentTest.vala"
	self = (GomDocumentTestObjectDocumentObjectParentObjectProperty*) g_object_new (object_type, NULL);
#line 43 "GomDocumentTest.vala"
	return self;
#line 9980 "GomDocumentTest.c"
}

static GomDocumentTestObjectDocumentObjectParentObjectProperty*
gom_document_test_object_document_object_parent_object_property_new (void)
{
#line 43 "GomDocumentTest.vala"
	return gom_document_test_object_document_object_parent_object_property_construct (GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TYPE_OBJECT_PROPERTY);
#line 9988 "GomDocumentTest.c"
}

static gchar*
gom_document_test_object_document_object_parent_object_property_real_get_value (GXmlGomProperty* base)
{
	gchar* result;
	GomDocumentTestObjectDocumentObjectParentObjectProperty* self;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 44 "GomDocumentTest.vala"
	self = (GomDocumentTestObjectDocumentObjectParentObjectProperty*) base;
#line 44 "GomDocumentTest.vala"
	_tmp0_ = self->priv->_value;
#line 44 "GomDocumentTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 44 "GomDocumentTest.vala"
	result = _tmp1_;
#line 44 "GomDocumentTest.vala"
	return result;
#line 10008 "GomDocumentTest.c"
}

static void
gom_document_test_object_document_object_parent_object_property_real_set_value (GXmlGomProperty* base,
                                                                                const gchar* value)
{
	GomDocumentTestObjectDocumentObjectParentObjectProperty* self;
#line 44 "GomDocumentTest.vala"
	self = (GomDocumentTestObjectDocumentObjectParentObjectProperty*) base;
#line 44 "GomDocumentTest.vala"
	if (g_strcmp0 (value, gom_document_test_object_document_object_parent_object_property_real_get_value (base)) != 0) {
#line 10020 "GomDocumentTest.c"
		gchar* _tmp0_;
#line 44 "GomDocumentTest.vala"
		_tmp0_ = g_strdup (value);
#line 44 "GomDocumentTest.vala"
		_g_free0 (self->priv->_value);
#line 44 "GomDocumentTest.vala"
		self->priv->_value = _tmp0_;
#line 44 "GomDocumentTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_document_test_object_document_object_parent_object_property_properties[GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_OBJECT_PROPERTY_VALUE_PROPERTY]);
#line 10030 "GomDocumentTest.c"
	}
}

static void
gom_document_test_object_document_object_parent_object_property_class_init (GomDocumentTestObjectDocumentObjectParentObjectPropertyClass * klass,
                                                                            gpointer klass_data)
{
#line 43 "GomDocumentTest.vala"
	gom_document_test_object_document_object_parent_object_property_parent_class = g_type_class_peek_parent (klass);
#line 43 "GomDocumentTest.vala"
	g_type_class_adjust_private_offset (klass, &GomDocumentTestObjectDocumentObjectParentObjectProperty_private_offset);
#line 43 "GomDocumentTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_document_test_object_document_object_parent_object_property_get_property;
#line 43 "GomDocumentTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_document_test_object_document_object_parent_object_property_set_property;
#line 43 "GomDocumentTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_document_test_object_document_object_parent_object_property_finalize;
#line 43 "GomDocumentTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_OBJECT_PROPERTY_VALUE_PROPERTY, gom_document_test_object_document_object_parent_object_property_properties[GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_OBJECT_PROPERTY_VALUE_PROPERTY] = g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 10050 "GomDocumentTest.c"
}

static void
gom_document_test_object_document_object_parent_object_property_gxml_gom_property_interface_init (GXmlGomPropertyIface * iface,
                                                                                                  gpointer iface_data)
{
#line 43 "GomDocumentTest.vala"
	gom_document_test_object_document_object_parent_object_property_gxml_gom_property_parent_iface = g_type_interface_peek_parent (iface);
#line 43 "GomDocumentTest.vala"
	iface->validate_value = (gboolean (*) (GXmlGomProperty*, const gchar*)) gom_document_test_object_document_object_parent_object_property_real_validate_value;
#line 43 "GomDocumentTest.vala"
	iface->get_value = gom_document_test_object_document_object_parent_object_property_real_get_value;
#line 43 "GomDocumentTest.vala"
	iface->set_value = gom_document_test_object_document_object_parent_object_property_real_set_value;
#line 10065 "GomDocumentTest.c"
}

static void
gom_document_test_object_document_object_parent_object_property_instance_init (GomDocumentTestObjectDocumentObjectParentObjectProperty * self,
                                                                               gpointer klass)
{
#line 43 "GomDocumentTest.vala"
	self->priv = gom_document_test_object_document_object_parent_object_property_get_instance_private (self);
#line 10074 "GomDocumentTest.c"
}

static void
gom_document_test_object_document_object_parent_object_property_finalize (GObject * obj)
{
	GomDocumentTestObjectDocumentObjectParentObjectProperty * self;
#line 43 "GomDocumentTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TYPE_OBJECT_PROPERTY, GomDocumentTestObjectDocumentObjectParentObjectProperty);
#line 44 "GomDocumentTest.vala"
	_g_free0 (self->priv->_value);
#line 43 "GomDocumentTest.vala"
	G_OBJECT_CLASS (gom_document_test_object_document_object_parent_object_property_parent_class)->finalize (obj);
#line 10087 "GomDocumentTest.c"
}

GType
gom_document_test_object_document_object_parent_object_property_get_type (void)
{
	static volatile gsize gom_document_test_object_document_object_parent_object_property_type_id__volatile = 0;
	if (g_once_init_enter (&gom_document_test_object_document_object_parent_object_property_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomDocumentTestObjectDocumentObjectParentObjectPropertyClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_document_test_object_document_object_parent_object_property_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomDocumentTestObjectDocumentObjectParentObjectProperty), 0, (GInstanceInitFunc) gom_document_test_object_document_object_parent_object_property_instance_init, NULL };
		static const GInterfaceInfo gxml_gom_property_info = { (GInterfaceInitFunc) gom_document_test_object_document_object_parent_object_property_gxml_gom_property_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gom_document_test_object_document_object_parent_object_property_type_id;
		gom_document_test_object_document_object_parent_object_property_type_id = g_type_register_static (G_TYPE_OBJECT, "GomDocumentTestObjectDocumentObjectParentObjectProperty", &g_define_type_info, 0);
		g_type_add_interface_static (gom_document_test_object_document_object_parent_object_property_type_id, GXML_TYPE_GOM_PROPERTY, &gxml_gom_property_info);
		GomDocumentTestObjectDocumentObjectParentObjectProperty_private_offset = g_type_add_instance_private (gom_document_test_object_document_object_parent_object_property_type_id, sizeof (GomDocumentTestObjectDocumentObjectParentObjectPropertyPrivate));
		g_once_init_leave (&gom_document_test_object_document_object_parent_object_property_type_id__volatile, gom_document_test_object_document_object_parent_object_property_type_id);
	}
	return gom_document_test_object_document_object_parent_object_property_type_id__volatile;
}

static void
_vala_gom_document_test_object_document_object_parent_object_property_get_property (GObject * object,
                                                                                    guint property_id,
                                                                                    GValue * value,
                                                                                    GParamSpec * pspec)
{
	GomDocumentTestObjectDocumentObjectParentObjectProperty * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TYPE_OBJECT_PROPERTY, GomDocumentTestObjectDocumentObjectParentObjectProperty);
#line 43 "GomDocumentTest.vala"
	switch (property_id) {
#line 43 "GomDocumentTest.vala"
		case GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_OBJECT_PROPERTY_VALUE_PROPERTY:
#line 43 "GomDocumentTest.vala"
		g_value_take_string (value, gxml_gom_property_get_value ((GXmlGomProperty*) self));
#line 43 "GomDocumentTest.vala"
		break;
#line 10122 "GomDocumentTest.c"
		default:
#line 43 "GomDocumentTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 43 "GomDocumentTest.vala"
		break;
#line 10128 "GomDocumentTest.c"
	}
}

static void
_vala_gom_document_test_object_document_object_parent_object_property_set_property (GObject * object,
                                                                                    guint property_id,
                                                                                    const GValue * value,
                                                                                    GParamSpec * pspec)
{
	GomDocumentTestObjectDocumentObjectParentObjectProperty * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TYPE_OBJECT_PROPERTY, GomDocumentTestObjectDocumentObjectParentObjectProperty);
#line 43 "GomDocumentTest.vala"
	switch (property_id) {
#line 43 "GomDocumentTest.vala"
		case GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_OBJECT_PROPERTY_VALUE_PROPERTY:
#line 43 "GomDocumentTest.vala"
		gxml_gom_property_set_value ((GXmlGomProperty*) self, g_value_get_string (value));
#line 43 "GomDocumentTest.vala"
		break;
#line 10148 "GomDocumentTest.c"
		default:
#line 43 "GomDocumentTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 43 "GomDocumentTest.vala"
		break;
#line 10154 "GomDocumentTest.c"
	}
}

static GomDocumentTestObjectDocumentObjectParentObjectChild*
gom_document_test_object_document_object_parent_object_child_construct (GType object_type)
{
	GomDocumentTestObjectDocumentObjectParentObjectChild * self = NULL;
#line 50 "GomDocumentTest.vala"
	self = (GomDocumentTestObjectDocumentObjectParentObjectChild*) gxml_gom_element_construct (object_type);
#line 50 "GomDocumentTest.vala"
	return self;
#line 10166 "GomDocumentTest.c"
}

static GomDocumentTestObjectDocumentObjectParentObjectChild*
gom_document_test_object_document_object_parent_object_child_new (void)
{
#line 50 "GomDocumentTest.vala"
	return gom_document_test_object_document_object_parent_object_child_construct (GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TYPE_OBJECT_CHILD);
#line 10174 "GomDocumentTest.c"
}

static GObject *
gom_document_test_object_document_object_parent_object_child_constructor (GType type,
                                                                          guint n_construct_properties,
                                                                          GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomDocumentTestObjectDocumentObjectParentObjectChild * self;
	GError* _inner_error0_ = NULL;
#line 51 "GomDocumentTest.vala"
	parent_class = G_OBJECT_CLASS (gom_document_test_object_document_object_parent_object_child_parent_class);
#line 51 "GomDocumentTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 51 "GomDocumentTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TYPE_OBJECT_CHILD, GomDocumentTestObjectDocumentObjectParentObjectChild);
#line 10192 "GomDocumentTest.c"
	{
#line 52 "GomDocumentTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "child");
#line 10196 "GomDocumentTest.c"
	}
	goto __finally117;
	__catch117_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 52 "GomDocumentTest.vala"
		e = _inner_error0_;
#line 52 "GomDocumentTest.vala"
		_inner_error0_ = NULL;
#line 53 "GomDocumentTest.vala"
		_tmp0_ = e;
#line 53 "GomDocumentTest.vala"
		_tmp1_ = _tmp0_->message;
#line 53 "GomDocumentTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 53 "GomDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 53 "GomDocumentTest.vala"
		g_warning ("GomDocumentTest.vala:53: %s", _tmp3_);
#line 53 "GomDocumentTest.vala"
		_g_free0 (_tmp3_);
#line 52 "GomDocumentTest.vala"
		_g_error_free0 (e);
#line 10224 "GomDocumentTest.c"
	}
	__finally117:
#line 52 "GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 52 "GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 52 "GomDocumentTest.vala"
		g_clear_error (&_inner_error0_);
#line 10233 "GomDocumentTest.c"
	}
#line 51 "GomDocumentTest.vala"
	return obj;
#line 10237 "GomDocumentTest.c"
}

static void
gom_document_test_object_document_object_parent_object_child_class_init (GomDocumentTestObjectDocumentObjectParentObjectChildClass * klass,
                                                                         gpointer klass_data)
{
#line 50 "GomDocumentTest.vala"
	gom_document_test_object_document_object_parent_object_child_parent_class = g_type_class_peek_parent (klass);
#line 50 "GomDocumentTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_document_test_object_document_object_parent_object_child_constructor;
#line 10248 "GomDocumentTest.c"
}

static void
gom_document_test_object_document_object_parent_object_child_instance_init (GomDocumentTestObjectDocumentObjectParentObjectChild * self,
                                                                            gpointer klass)
{
}

GType
gom_document_test_object_document_object_parent_object_child_get_type (void)
{
	static volatile gsize gom_document_test_object_document_object_parent_object_child_type_id__volatile = 0;
	if (g_once_init_enter (&gom_document_test_object_document_object_parent_object_child_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomDocumentTestObjectDocumentObjectParentObjectChildClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_document_test_object_document_object_parent_object_child_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomDocumentTestObjectDocumentObjectParentObjectChild), 0, (GInstanceInitFunc) gom_document_test_object_document_object_parent_object_child_instance_init, NULL };
		GType gom_document_test_object_document_object_parent_object_child_type_id;
		gom_document_test_object_document_object_parent_object_child_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomDocumentTestObjectDocumentObjectParentObjectChild", &g_define_type_info, 0);
		g_once_init_leave (&gom_document_test_object_document_object_parent_object_child_type_id__volatile, gom_document_test_object_document_object_parent_object_child_type_id);
	}
	return gom_document_test_object_document_object_parent_object_child_type_id__volatile;
}

static void
gom_document_test_object_document_object_parent_class_init (GomDocumentTestObjectDocumentObjectParentClass * klass,
                                                            gpointer klass_data)
{
#line 34 "GomDocumentTest.vala"
	gom_document_test_object_document_object_parent_parent_class = g_type_class_peek_parent (klass);
#line 34 "GomDocumentTest.vala"
	g_type_class_adjust_private_offset (klass, &GomDocumentTestObjectDocumentObjectParent_private_offset);
#line 34 "GomDocumentTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_document_test_object_document_object_parent_get_property;
#line 34 "GomDocumentTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_document_test_object_document_object_parent_set_property;
#line 34 "GomDocumentTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_document_test_object_document_object_parent_constructor;
#line 34 "GomDocumentTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_document_test_object_document_object_parent_finalize;
#line 34 "GomDocumentTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TEXT_PROPERTY, gom_document_test_object_document_object_parent_properties[GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TEXT_PROPERTY] = g_param_spec_string ("text", "::text", "text", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 34 "GomDocumentTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_PROP_PROPERTY, gom_document_test_object_document_object_parent_properties[GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_PROP_PROPERTY] = g_param_spec_object ("prop", "::prop", "prop", GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TYPE_OBJECT_PROPERTY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 34 "GomDocumentTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_CHILD_PROPERTY, gom_document_test_object_document_object_parent_properties[GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_CHILD_PROPERTY] = g_param_spec_object ("child", "child", "child", GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TYPE_OBJECT_CHILD, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 10292 "GomDocumentTest.c"
}

static void
gom_document_test_object_document_object_parent_instance_init (GomDocumentTestObjectDocumentObjectParent * self,
                                                               gpointer klass)
{
#line 34 "GomDocumentTest.vala"
	self->priv = gom_document_test_object_document_object_parent_get_instance_private (self);
#line 10301 "GomDocumentTest.c"
}

static void
gom_document_test_object_document_object_parent_finalize (GObject * obj)
{
	GomDocumentTestObjectDocumentObjectParent * self;
#line 34 "GomDocumentTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_TYPE_OBJECT_PARENT, GomDocumentTestObjectDocumentObjectParent);
#line 40 "GomDocumentTest.vala"
	_g_free0 (self->priv->_text);
#line 42 "GomDocumentTest.vala"
	_g_object_unref0 (self->priv->_prop);
#line 49 "GomDocumentTest.vala"
	_g_object_unref0 (self->priv->_child);
#line 34 "GomDocumentTest.vala"
	G_OBJECT_CLASS (gom_document_test_object_document_object_parent_parent_class)->finalize (obj);
#line 10318 "GomDocumentTest.c"
}

GType
gom_document_test_object_document_object_parent_get_type (void)
{
	static volatile gsize gom_document_test_object_document_object_parent_type_id__volatile = 0;
	if (g_once_init_enter (&gom_document_test_object_document_object_parent_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomDocumentTestObjectDocumentObjectParentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_document_test_object_document_object_parent_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomDocumentTestObjectDocumentObjectParent), 0, (GInstanceInitFunc) gom_document_test_object_document_object_parent_instance_init, NULL };
		GType gom_document_test_object_document_object_parent_type_id;
		gom_document_test_object_document_object_parent_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomDocumentTestObjectDocumentObjectParent", &g_define_type_info, 0);
		GomDocumentTestObjectDocumentObjectParent_private_offset = g_type_add_instance_private (gom_document_test_object_document_object_parent_type_id, sizeof (GomDocumentTestObjectDocumentObjectParentPrivate));
		g_once_init_leave (&gom_document_test_object_document_object_parent_type_id__volatile, gom_document_test_object_document_object_parent_type_id);
	}
	return gom_document_test_object_document_object_parent_type_id__volatile;
}

static void
_vala_gom_document_test_object_document_object_parent_get_property (GObject * object,
                                                                    guint property_id,
                                                                    GValue * value,
                                                                    GParamSpec * pspec)
{
	GomDocumentTestObjectDocumentObjectParent * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_TYPE_OBJECT_PARENT, GomDocumentTestObjectDocumentObjectParent);
#line 34 "GomDocumentTest.vala"
	switch (property_id) {
#line 34 "GomDocumentTest.vala"
		case GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TEXT_PROPERTY:
#line 34 "GomDocumentTest.vala"
		g_value_set_string (value, gom_document_test_object_document_object_parent_get_text (self));
#line 34 "GomDocumentTest.vala"
		break;
#line 34 "GomDocumentTest.vala"
		case GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_PROP_PROPERTY:
#line 34 "GomDocumentTest.vala"
		g_value_set_object (value, gom_document_test_object_document_object_parent_get_prop (self));
#line 34 "GomDocumentTest.vala"
		break;
#line 34 "GomDocumentTest.vala"
		case GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_CHILD_PROPERTY:
#line 34 "GomDocumentTest.vala"
		g_value_set_object (value, gom_document_test_object_document_object_parent_get_child (self));
#line 34 "GomDocumentTest.vala"
		break;
#line 10363 "GomDocumentTest.c"
		default:
#line 34 "GomDocumentTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 34 "GomDocumentTest.vala"
		break;
#line 10369 "GomDocumentTest.c"
	}
}

static void
_vala_gom_document_test_object_document_object_parent_set_property (GObject * object,
                                                                    guint property_id,
                                                                    const GValue * value,
                                                                    GParamSpec * pspec)
{
	GomDocumentTestObjectDocumentObjectParent * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_TYPE_OBJECT_PARENT, GomDocumentTestObjectDocumentObjectParent);
#line 34 "GomDocumentTest.vala"
	switch (property_id) {
#line 34 "GomDocumentTest.vala"
		case GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_TEXT_PROPERTY:
#line 34 "GomDocumentTest.vala"
		gom_document_test_object_document_object_parent_set_text (self, g_value_get_string (value));
#line 34 "GomDocumentTest.vala"
		break;
#line 34 "GomDocumentTest.vala"
		case GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_PROP_PROPERTY:
#line 34 "GomDocumentTest.vala"
		gom_document_test_object_document_object_parent_set_prop (self, g_value_get_object (value));
#line 34 "GomDocumentTest.vala"
		break;
#line 34 "GomDocumentTest.vala"
		case GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_OBJECT_PARENT_CHILD_PROPERTY:
#line 34 "GomDocumentTest.vala"
		gom_document_test_object_document_object_parent_set_child (self, g_value_get_object (value));
#line 34 "GomDocumentTest.vala"
		break;
#line 10401 "GomDocumentTest.c"
		default:
#line 34 "GomDocumentTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 34 "GomDocumentTest.vala"
		break;
#line 10407 "GomDocumentTest.c"
	}
}

static void
gom_document_test_object_document_class_init (GomDocumentTestObjectDocumentClass * klass,
                                              gpointer klass_data)
{
#line 26 "GomDocumentTest.vala"
	gom_document_test_object_document_parent_class = g_type_class_peek_parent (klass);
#line 26 "GomDocumentTest.vala"
	g_type_class_adjust_private_offset (klass, &GomDocumentTestObjectDocument_private_offset);
#line 26 "GomDocumentTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_document_test_object_document_get_property;
#line 26 "GomDocumentTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_document_test_object_document_set_property;
#line 26 "GomDocumentTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_document_test_object_document_constructor;
#line 26 "GomDocumentTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_document_test_object_document_finalize;
#line 26 "GomDocumentTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_ROOT_ELEMENT_PROPERTY, gom_document_test_object_document_properties[GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_ROOT_ELEMENT_PROPERTY] = g_param_spec_object ("root-element", "::ROOT", "root-element", GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_TYPE_OBJECT_PARENT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 10429 "GomDocumentTest.c"
}

static void
gom_document_test_object_document_instance_init (GomDocumentTestObjectDocument * self,
                                                 gpointer klass)
{
#line 26 "GomDocumentTest.vala"
	self->priv = gom_document_test_object_document_get_instance_private (self);
#line 10438 "GomDocumentTest.c"
}

static void
gom_document_test_object_document_finalize (GObject * obj)
{
	GomDocumentTestObjectDocument * self;
#line 26 "GomDocumentTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_DOCUMENT_TEST_TYPE_OBJECT_DOCUMENT, GomDocumentTestObjectDocument);
#line 28 "GomDocumentTest.vala"
	_g_object_unref0 (self->priv->_root_element);
#line 26 "GomDocumentTest.vala"
	G_OBJECT_CLASS (gom_document_test_object_document_parent_class)->finalize (obj);
#line 10451 "GomDocumentTest.c"
}

static GType
gom_document_test_object_document_get_type (void)
{
	static volatile gsize gom_document_test_object_document_type_id__volatile = 0;
	if (g_once_init_enter (&gom_document_test_object_document_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomDocumentTestObjectDocumentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_document_test_object_document_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomDocumentTestObjectDocument), 0, (GInstanceInitFunc) gom_document_test_object_document_instance_init, NULL };
		GType gom_document_test_object_document_type_id;
		gom_document_test_object_document_type_id = g_type_register_static (GXML_TYPE_GOM_DOCUMENT, "GomDocumentTestObjectDocument", &g_define_type_info, 0);
		GomDocumentTestObjectDocument_private_offset = g_type_add_instance_private (gom_document_test_object_document_type_id, sizeof (GomDocumentTestObjectDocumentPrivate));
		g_once_init_leave (&gom_document_test_object_document_type_id__volatile, gom_document_test_object_document_type_id);
	}
	return gom_document_test_object_document_type_id__volatile;
}

static void
_vala_gom_document_test_object_document_get_property (GObject * object,
                                                      guint property_id,
                                                      GValue * value,
                                                      GParamSpec * pspec)
{
	GomDocumentTestObjectDocument * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_DOCUMENT_TEST_TYPE_OBJECT_DOCUMENT, GomDocumentTestObjectDocument);
#line 26 "GomDocumentTest.vala"
	switch (property_id) {
#line 26 "GomDocumentTest.vala"
		case GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_ROOT_ELEMENT_PROPERTY:
#line 26 "GomDocumentTest.vala"
		g_value_set_object (value, gom_document_test_object_document_get_root_element (self));
#line 26 "GomDocumentTest.vala"
		break;
#line 10484 "GomDocumentTest.c"
		default:
#line 26 "GomDocumentTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 26 "GomDocumentTest.vala"
		break;
#line 10490 "GomDocumentTest.c"
	}
}

static void
_vala_gom_document_test_object_document_set_property (GObject * object,
                                                      guint property_id,
                                                      const GValue * value,
                                                      GParamSpec * pspec)
{
	GomDocumentTestObjectDocument * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_DOCUMENT_TEST_TYPE_OBJECT_DOCUMENT, GomDocumentTestObjectDocument);
#line 26 "GomDocumentTest.vala"
	switch (property_id) {
#line 26 "GomDocumentTest.vala"
		case GOM_DOCUMENT_TEST_OBJECT_DOCUMENT_ROOT_ELEMENT_PROPERTY:
#line 26 "GomDocumentTest.vala"
		gom_document_test_object_document_set_root_element (self, g_value_get_object (value));
#line 26 "GomDocumentTest.vala"
		break;
#line 10510 "GomDocumentTest.c"
		default:
#line 26 "GomDocumentTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 26 "GomDocumentTest.vala"
		break;
#line 10516 "GomDocumentTest.c"
	}
}

static void
gom_document_test_class_init (GomDocumentTestClass * klass,
                              gpointer klass_data)
{
#line 25 "GomDocumentTest.vala"
	gom_document_test_parent_class = g_type_class_peek_parent (klass);
#line 10526 "GomDocumentTest.c"
}

static void
gom_document_test_instance_init (GomDocumentTest * self,
                                 gpointer klass)
{
}

GType
gom_document_test_get_type (void)
{
	static volatile gsize gom_document_test_type_id__volatile = 0;
	if (g_once_init_enter (&gom_document_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomDocumentTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_document_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomDocumentTest), 0, (GInstanceInitFunc) gom_document_test_instance_init, NULL };
		GType gom_document_test_type_id;
		gom_document_test_type_id = g_type_register_static (TYPE_GXML_TEST, "GomDocumentTest", &g_define_type_info, 0);
		g_once_init_leave (&gom_document_test_type_id__volatile, gom_document_test_type_id);
	}
	return gom_document_test_type_id__volatile;
}

static void
_vala_array_destroy (gpointer array,
                     gint array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gint array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

static gint
_vala_array_length (gpointer array)
{
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}

