/* SerializableGeeArrayListTest.c generated by valac 0.44.3, the Vala compiler
 * generated from SerializableGeeArrayListTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */

#include <gxml/gxml.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gee.h>
#include <stdio.h>

#define TYPE_AELEMENT (aelement_get_type ())
#define AELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_AELEMENT, AElement))
#define AELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_AELEMENT, AElementClass))
#define IS_AELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_AELEMENT))
#define IS_AELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_AELEMENT))
#define AELEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_AELEMENT, AElementClass))

typedef struct _AElement AElement;
typedef struct _AElementClass AElementClass;
typedef struct _AElementPrivate AElementPrivate;
enum  {
	AELEMENT_0_PROPERTY,
	AELEMENT_NAME_PROPERTY,
	AELEMENT_NUM_PROPERTIES
};
static GParamSpec* aelement_properties[AELEMENT_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))

#define AELEMENT_TYPE_ARRAY (aelement_array_get_type ())
#define AELEMENT_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), AELEMENT_TYPE_ARRAY, AElementArray))
#define AELEMENT_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), AELEMENT_TYPE_ARRAY, AElementArrayClass))
#define AELEMENT_IS_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), AELEMENT_TYPE_ARRAY))
#define AELEMENT_IS_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), AELEMENT_TYPE_ARRAY))
#define AELEMENT_ARRAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), AELEMENT_TYPE_ARRAY, AElementArrayClass))

typedef struct _AElementArray AElementArray;
typedef struct _AElementArrayClass AElementArrayClass;
typedef struct _AElementArrayPrivate AElementArrayPrivate;
enum  {
	AELEMENT_ARRAY_0_PROPERTY,
	AELEMENT_ARRAY_ENABLE_DESERIALIZE_PROPERTY,
	AELEMENT_ARRAY_NUM_PROPERTIES
};
static GParamSpec* aelement_array_properties[AELEMENT_ARRAY_NUM_PROPERTIES];

#define TYPE_CELEMENT (celement_get_type ())
#define CELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CELEMENT, CElement))
#define CELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CELEMENT, CElementClass))
#define IS_CELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CELEMENT))
#define IS_CELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CELEMENT))
#define CELEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CELEMENT, CElementClass))

typedef struct _CElement CElement;
typedef struct _CElementClass CElementClass;
typedef struct _CElementPrivate CElementPrivate;
enum  {
	CELEMENT_0_PROPERTY,
	CELEMENT_ELEMENTS_PROPERTY,
	CELEMENT_NUM_PROPERTIES
};
static GParamSpec* celement_properties[CELEMENT_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_SERIALIZABLE_GEE_ARRAY_LIST_TEST (serializable_gee_array_list_test_get_type ())
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_GEE_ARRAY_LIST_TEST, SerializableGeeArrayListTest))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_GEE_ARRAY_LIST_TEST, SerializableGeeArrayListTestClass))
#define IS_SERIALIZABLE_GEE_ARRAY_LIST_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_GEE_ARRAY_LIST_TEST))
#define IS_SERIALIZABLE_GEE_ARRAY_LIST_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_GEE_ARRAY_LIST_TEST))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_GEE_ARRAY_LIST_TEST, SerializableGeeArrayListTestClass))

typedef struct _SerializableGeeArrayListTest SerializableGeeArrayListTest;
typedef struct _SerializableGeeArrayListTestClass SerializableGeeArrayListTestClass;
typedef struct _SerializableGeeArrayListTestPrivate SerializableGeeArrayListTestPrivate;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define TYPE_BOOK_STORE (book_store_get_type ())
#define BOOK_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BOOK_STORE, BookStore))
#define BOOK_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BOOK_STORE, BookStoreClass))
#define IS_BOOK_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BOOK_STORE))
#define IS_BOOK_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BOOK_STORE))
#define BOOK_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BOOK_STORE, BookStoreClass))

typedef struct _BookStore BookStore;
typedef struct _BookStoreClass BookStoreClass;

#define BOOK_TYPE_ARRAY (book_array_get_type ())
#define BOOK_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOOK_TYPE_ARRAY, BookArray))
#define BOOK_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOOK_TYPE_ARRAY, BookArrayClass))
#define BOOK_IS_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOOK_TYPE_ARRAY))
#define BOOK_IS_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOOK_TYPE_ARRAY))
#define BOOK_ARRAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOOK_TYPE_ARRAY, BookArrayClass))

typedef struct _BookArray BookArray;
typedef struct _BookArrayClass BookArrayClass;

#define TYPE_BOOK (book_get_type ())
#define BOOK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BOOK, Book))
#define BOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BOOK, BookClass))
#define IS_BOOK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BOOK))
#define IS_BOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BOOK))
#define BOOK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BOOK, BookClass))

typedef struct _Book Book;
typedef struct _BookClass BookClass;

#define TYPE_NAME (name_get_type ())
#define NAME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_NAME, Name))
#define NAME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_NAME, NameClass))
#define IS_NAME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_NAME))
#define IS_NAME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_NAME))
#define NAME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_NAME, NameClass))

typedef struct _Name Name;
typedef struct _NameClass NameClass;

#define TYPE_AUTHORS (authors_get_type ())
#define AUTHORS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_AUTHORS, Authors))
#define AUTHORS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_AUTHORS, AuthorsClass))
#define IS_AUTHORS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_AUTHORS))
#define IS_AUTHORS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_AUTHORS))
#define AUTHORS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_AUTHORS, AuthorsClass))

typedef struct _Authors Authors;
typedef struct _AuthorsClass AuthorsClass;

#define AUTHOR_TYPE_ARRAY (author_array_get_type ())
#define AUTHOR_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), AUTHOR_TYPE_ARRAY, AuthorArray))
#define AUTHOR_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), AUTHOR_TYPE_ARRAY, AuthorArrayClass))
#define AUTHOR_IS_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), AUTHOR_TYPE_ARRAY))
#define AUTHOR_IS_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), AUTHOR_TYPE_ARRAY))
#define AUTHOR_ARRAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), AUTHOR_TYPE_ARRAY, AuthorArrayClass))

typedef struct _AuthorArray AuthorArray;
typedef struct _AuthorArrayClass AuthorArrayClass;

#define TYPE_AUTHOR (author_get_type ())
#define AUTHOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_AUTHOR, Author))
#define AUTHOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_AUTHOR, AuthorClass))
#define IS_AUTHOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_AUTHOR))
#define IS_AUTHOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_AUTHOR))
#define AUTHOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_AUTHOR, AuthorClass))

typedef struct _Author Author;
typedef struct _AuthorClass AuthorClass;

#define TYPE_EMAIL (email_get_type ())
#define EMAIL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EMAIL, Email))
#define EMAIL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EMAIL, EmailClass))
#define IS_EMAIL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EMAIL))
#define IS_EMAIL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EMAIL))
#define EMAIL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EMAIL, EmailClass))

typedef struct _Email Email;
typedef struct _EmailClass EmailClass;

#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BIG_BAG (serializable_gee_array_list_test_big_bag_get_type ())
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_BIG_BAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BIG_BAG, SerializableGeeArrayListTestBigBag))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_BIG_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BIG_BAG, SerializableGeeArrayListTestBigBagClass))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_IS_BIG_BAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BIG_BAG))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_IS_BIG_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BIG_BAG))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_BIG_BAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BIG_BAG, SerializableGeeArrayListTestBigBagClass))

typedef struct _SerializableGeeArrayListTestBigBag SerializableGeeArrayListTestBigBag;
typedef struct _SerializableGeeArrayListTestBigBagClass SerializableGeeArrayListTestBigBagClass;

#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_TYPE_ARRAY (serializable_gee_array_list_test_small_bag_array_get_type ())
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_TYPE_ARRAY, SerializableGeeArrayListTestSmallBagArray))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_TYPE_ARRAY, SerializableGeeArrayListTestSmallBagArrayClass))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_IS_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_TYPE_ARRAY))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_IS_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_TYPE_ARRAY))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_ARRAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_TYPE_ARRAY, SerializableGeeArrayListTestSmallBagArrayClass))

typedef struct _SerializableGeeArrayListTestSmallBagArray SerializableGeeArrayListTestSmallBagArray;
typedef struct _SerializableGeeArrayListTestSmallBagArrayClass SerializableGeeArrayListTestSmallBagArrayClass;

#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_SMALL_BAG (serializable_gee_array_list_test_small_bag_get_type ())
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_SMALL_BAG, SerializableGeeArrayListTestSmallBag))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_SMALL_BAG, SerializableGeeArrayListTestSmallBagClass))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_IS_SMALL_BAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_SMALL_BAG))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_IS_SMALL_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_SMALL_BAG))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_SMALL_BAG, SerializableGeeArrayListTestSmallBagClass))

typedef struct _SerializableGeeArrayListTestSmallBag SerializableGeeArrayListTestSmallBag;
typedef struct _SerializableGeeArrayListTestSmallBagClass SerializableGeeArrayListTestSmallBagClass;

#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_TYPE_ARRAY (serializable_gee_array_list_test_ball_array_get_type ())
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_TYPE_ARRAY, SerializableGeeArrayListTestBallArray))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_TYPE_ARRAY, SerializableGeeArrayListTestBallArrayClass))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_IS_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_TYPE_ARRAY))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_IS_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_TYPE_ARRAY))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_ARRAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_TYPE_ARRAY, SerializableGeeArrayListTestBallArrayClass))

typedef struct _SerializableGeeArrayListTestBallArray SerializableGeeArrayListTestBallArray;
typedef struct _SerializableGeeArrayListTestBallArrayClass SerializableGeeArrayListTestBallArrayClass;

#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BALL (serializable_gee_array_list_test_ball_get_type ())
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BALL, SerializableGeeArrayListTestBall))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BALL, SerializableGeeArrayListTestBallClass))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_IS_BALL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BALL))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_IS_BALL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BALL))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BALL, SerializableGeeArrayListTestBallClass))

typedef struct _SerializableGeeArrayListTestBall SerializableGeeArrayListTestBall;
typedef struct _SerializableGeeArrayListTestBallClass SerializableGeeArrayListTestBallClass;

#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BALL_FILL (serializable_gee_array_list_test_ball_fill_get_type ())
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_FILL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BALL_FILL, SerializableGeeArrayListTestBallFill))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_FILL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BALL_FILL, SerializableGeeArrayListTestBallFillClass))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_IS_BALL_FILL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BALL_FILL))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_IS_BALL_FILL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BALL_FILL))
#define SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_FILL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BALL_FILL, SerializableGeeArrayListTestBallFillClass))

typedef struct _SerializableGeeArrayListTestBallFill SerializableGeeArrayListTestBallFill;
typedef struct _SerializableGeeArrayListTestBallFillClass SerializableGeeArrayListTestBallFillClass;
typedef struct _SerializableGeeArrayListTestBallFillPrivate SerializableGeeArrayListTestBallFillPrivate;
enum  {
	SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_FILL_0_PROPERTY,
	SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_FILL_NAME_PROPERTY,
	SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_FILL_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_array_list_test_ball_fill_properties[SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_FILL_NUM_PROPERTIES];
typedef struct _SerializableGeeArrayListTestBallPrivate SerializableGeeArrayListTestBallPrivate;
enum  {
	SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_0_PROPERTY,
	SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_NAME_PROPERTY,
	SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_BALLFILL_PROPERTY,
	SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_array_list_test_ball_properties[SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_NUM_PROPERTIES];
typedef struct _SerializableGeeArrayListTestBallArrayPrivate SerializableGeeArrayListTestBallArrayPrivate;
enum  {
	SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_ARRAY_0_PROPERTY,
	SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_ARRAY_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_array_list_test_ball_array_properties[SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_ARRAY_NUM_PROPERTIES];
typedef struct _SerializableGeeArrayListTestSmallBagPrivate SerializableGeeArrayListTestSmallBagPrivate;
enum  {
	SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_0_PROPERTY,
	SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_NAME_PROPERTY,
	SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_BALLS_PROPERTY,
	SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_array_list_test_small_bag_properties[SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_NUM_PROPERTIES];
typedef struct _SerializableGeeArrayListTestSmallBagArrayPrivate SerializableGeeArrayListTestSmallBagArrayPrivate;
enum  {
	SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_ARRAY_0_PROPERTY,
	SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_ARRAY_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_array_list_test_small_bag_array_properties[SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_ARRAY_NUM_PROPERTIES];
typedef struct _SerializableGeeArrayListTestBigBagPrivate SerializableGeeArrayListTestBigBagPrivate;
enum  {
	SERIALIZABLE_GEE_ARRAY_LIST_TEST_BIG_BAG_0_PROPERTY,
	SERIALIZABLE_GEE_ARRAY_LIST_TEST_BIG_BAG_NAME_PROPERTY,
	SERIALIZABLE_GEE_ARRAY_LIST_TEST_BIG_BAG_BAGS_PROPERTY,
	SERIALIZABLE_GEE_ARRAY_LIST_TEST_BIG_BAG_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_array_list_test_big_bag_properties[SERIALIZABLE_GEE_ARRAY_LIST_TEST_BIG_BAG_NUM_PROPERTIES];
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _AElement {
	GXmlSerializableObjectModel parent_instance;
	AElementPrivate * priv;
};

struct _AElementClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _AElementPrivate {
	gchar* _name;
};

struct _AElementArray {
	GXmlSerializableArrayList parent_instance;
	AElementArrayPrivate * priv;
};

struct _AElementArrayClass {
	GXmlSerializableArrayListClass parent_class;
};

struct _AElementArrayPrivate {
	gboolean _enable_deserialize;
};

struct _CElement {
	GXmlSerializableObjectModel parent_instance;
	CElementPrivate * priv;
};

struct _CElementClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _CElementPrivate {
	AElementArray* _elements;
};

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _SerializableGeeArrayListTest {
	GXmlTest parent_instance;
	SerializableGeeArrayListTestPrivate * priv;
};

struct _SerializableGeeArrayListTestClass {
	GXmlTestClass parent_class;
};

struct _SerializableGeeArrayListTestBallFill {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeArrayListTestBallFillPrivate * priv;
};

struct _SerializableGeeArrayListTestBallFillClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeArrayListTestBallFillPrivate {
	gchar* _name;
};

struct _SerializableGeeArrayListTestBall {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeArrayListTestBallPrivate * priv;
};

struct _SerializableGeeArrayListTestBallClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeArrayListTestBallPrivate {
	gchar* _name;
	SerializableGeeArrayListTestBallFill* _ballfill;
};

struct _SerializableGeeArrayListTestBallArray {
	GXmlSerializableArrayList parent_instance;
	SerializableGeeArrayListTestBallArrayPrivate * priv;
};

struct _SerializableGeeArrayListTestBallArrayClass {
	GXmlSerializableArrayListClass parent_class;
};

struct _SerializableGeeArrayListTestSmallBag {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeArrayListTestSmallBagPrivate * priv;
};

struct _SerializableGeeArrayListTestSmallBagClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeArrayListTestSmallBagPrivate {
	gchar* _name;
	SerializableGeeArrayListTestBallArray* _balls;
};

struct _SerializableGeeArrayListTestSmallBagArray {
	GXmlSerializableArrayList parent_instance;
	SerializableGeeArrayListTestSmallBagArrayPrivate * priv;
};

struct _SerializableGeeArrayListTestSmallBagArrayClass {
	GXmlSerializableArrayListClass parent_class;
};

struct _SerializableGeeArrayListTestBigBag {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeArrayListTestBigBagPrivate * priv;
};

struct _SerializableGeeArrayListTestBigBagClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeArrayListTestBigBagPrivate {
	gchar* _name;
	SerializableGeeArrayListTestSmallBagArray* _bags;
};

static gint AElement_private_offset;
static gpointer aelement_parent_class = NULL;
static gint AElementArray_private_offset;
static gpointer aelement_array_parent_class = NULL;
static gint CElement_private_offset;
static gpointer celement_parent_class = NULL;
static gpointer serializable_gee_array_list_test_parent_class = NULL;
static gint SerializableGeeArrayListTestBallFill_private_offset;
static gpointer serializable_gee_array_list_test_ball_fill_parent_class = NULL;
static gint SerializableGeeArrayListTestBall_private_offset;
static gpointer serializable_gee_array_list_test_ball_parent_class = NULL;
static gpointer serializable_gee_array_list_test_ball_array_parent_class = NULL;
static gint SerializableGeeArrayListTestSmallBag_private_offset;
static gpointer serializable_gee_array_list_test_small_bag_parent_class = NULL;
static gpointer serializable_gee_array_list_test_small_bag_array_parent_class = NULL;
static gint SerializableGeeArrayListTestBigBag_private_offset;
static gpointer serializable_gee_array_list_test_big_bag_parent_class = NULL;

GType aelement_get_type (void) G_GNUC_CONST;
AElement* aelement_new_named (const gchar* name);
AElement* aelement_construct_named (GType object_type,
                                    const gchar* name);
void aelement_set_name (AElement* self,
                        const gchar* value);
static gchar* aelement_real_to_string (GXmlSerializableObjectModel* base);
const gchar* aelement_get_name (AElement* self);
AElement* aelement_new (void);
AElement* aelement_construct (GType object_type);
GType aelement_array_get_type (void) G_GNUC_CONST;
static gboolean aelement_array_real_deserialize_proceed (GXmlSerializableArrayList* base);
gboolean aelement_array_get_enable_deserialize (AElementArray* self);
AElementArray* aelement_array_new (void);
AElementArray* aelement_array_construct (GType object_type);
void aelement_array_set_enable_deserialize (AElementArray* self,
                                            gboolean value);
static void aelement_array_finalize (GObject * obj);
static void _vala_aelement_array_get_property (GObject * object,
                                        guint property_id,
                                        GValue * value,
                                        GParamSpec * pspec);
static void _vala_aelement_array_set_property (GObject * object,
                                        guint property_id,
                                        const GValue * value,
                                        GParamSpec * pspec);
static void aelement_finalize (GObject * obj);
static void _vala_aelement_get_property (GObject * object,
                                  guint property_id,
                                  GValue * value,
                                  GParamSpec * pspec);
static void _vala_aelement_set_property (GObject * object,
                                  guint property_id,
                                  const GValue * value,
                                  GParamSpec * pspec);
GType celement_get_type (void) G_GNUC_CONST;
static gchar* celement_real_node_name (GXmlSerializableObjectModel* base);
static gchar* celement_real_to_string (GXmlSerializableObjectModel* base);
CElement* celement_new (void);
CElement* celement_construct (GType object_type);
AElementArray* celement_get_elements (CElement* self);
void celement_set_elements (CElement* self,
                            AElementArray* value);
static void celement_finalize (GObject * obj);
static void _vala_celement_get_property (GObject * object,
                                  guint property_id,
                                  GValue * value,
                                  GParamSpec * pspec);
static void _vala_celement_set_property (GObject * object,
                                  guint property_id,
                                  const GValue * value,
                                  GParamSpec * pspec);
gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType serializable_gee_array_list_test_get_type (void) G_GNUC_CONST;
void serializable_gee_array_list_test_add_tests (void);
static void __lambda305_ (void);
static void ___lambda305__gtest_func (void);
static void __lambda306_ (void);
static void ___lambda306__gtest_func (void);
static void __lambda307_ (void);
static void ___lambda307__gtest_func (void);
static void __lambda308_ (void);
static void ___lambda308__gtest_func (void);
static void __lambda309_ (void);
GType book_store_get_type (void) G_GNUC_CONST;
BookStore* book_store_new (void);
BookStore* book_store_construct (GType object_type);
const gchar* book_store_get_name (BookStore* self);
GType book_array_get_type (void) G_GNUC_CONST;
BookArray* book_store_get_books (BookStore* self);
GType book_get_type (void) G_GNUC_CONST;
GType name_get_type (void) G_GNUC_CONST;
Name* book_get_name (Book* self);
gchar* name_get_name (Name* self);
const gchar* book_get_year (Book* self);
GType authors_get_type (void) G_GNUC_CONST;
Authors* book_get_authors (Book* self);
GType author_array_get_type (void) G_GNUC_CONST;
AuthorArray* authors_get_array (Authors* self);
GType author_get_type (void) G_GNUC_CONST;
Name* author_get_name (Author* self);
GType email_get_type (void) G_GNUC_CONST;
Email* author_get_email (Author* self);
gchar* email_get_mail (Email* self);
static void ___lambda309__gtest_func (void);
static void __lambda310_ (void);
static GType serializable_gee_array_list_test_big_bag_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeArrayListTestBigBag* serializable_gee_array_list_test_big_bag_new (void);
static SerializableGeeArrayListTestBigBag* serializable_gee_array_list_test_big_bag_construct (GType object_type);
GType serializable_gee_array_list_test_small_bag_array_get_type (void) G_GNUC_CONST;
static SerializableGeeArrayListTestSmallBagArray* serializable_gee_array_list_test_big_bag_get_bags (SerializableGeeArrayListTestBigBag* self);
static GType serializable_gee_array_list_test_small_bag_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeArrayListTestSmallBag* serializable_gee_array_list_test_small_bag_new (void);
static SerializableGeeArrayListTestSmallBag* serializable_gee_array_list_test_small_bag_construct (GType object_type);
GType serializable_gee_array_list_test_ball_array_get_type (void) G_GNUC_CONST;
static SerializableGeeArrayListTestBallArray* serializable_gee_array_list_test_small_bag_get_balls (SerializableGeeArrayListTestSmallBag* self);
static GType serializable_gee_array_list_test_ball_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeArrayListTestBall* serializable_gee_array_list_test_ball_new (void);
static SerializableGeeArrayListTestBall* serializable_gee_array_list_test_ball_construct (GType object_type);
static SerializableGeeArrayListTestBallFill* serializable_gee_array_list_test_ball_fill_new (void);
static SerializableGeeArrayListTestBallFill* serializable_gee_array_list_test_ball_fill_construct (GType object_type);
static GType serializable_gee_array_list_test_ball_fill_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static void serializable_gee_array_list_test_ball_set_ballfill (SerializableGeeArrayListTestBall* self,
                                                         SerializableGeeArrayListTestBallFill* value);
static SerializableGeeArrayListTestBallFill* serializable_gee_array_list_test_ball_get_ballfill (SerializableGeeArrayListTestBall* self);
static void serializable_gee_array_list_test_ball_fill_set_text (SerializableGeeArrayListTestBallFill* self,
                                                          const gchar* txt);
static const gchar* serializable_gee_array_list_test_ball_get_name (SerializableGeeArrayListTestBall* self);
static void ___lambda310__gtest_func (void);
SerializableGeeArrayListTest* serializable_gee_array_list_test_new (void);
SerializableGeeArrayListTest* serializable_gee_array_list_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static gchar* serializable_gee_array_list_test_ball_fill_real_to_string (GXmlSerializableObjectModel* base);
static const gchar* serializable_gee_array_list_test_ball_fill_get_name (SerializableGeeArrayListTestBallFill* self);
static gchar* serializable_gee_array_list_test_ball_fill_real_node_name (GXmlSerializableObjectModel* base);
static gboolean serializable_gee_array_list_test_ball_fill_real_serialize_use_xml_node_value (GXmlSerializableObjectModel* base);
static void serializable_gee_array_list_test_ball_fill_set_name (SerializableGeeArrayListTestBallFill* self,
                                                          const gchar* value);
static void serializable_gee_array_list_test_ball_fill_finalize (GObject * obj);
static void _vala_serializable_gee_array_list_test_ball_fill_get_property (GObject * object,
                                                                    guint property_id,
                                                                    GValue * value,
                                                                    GParamSpec * pspec);
static void _vala_serializable_gee_array_list_test_ball_fill_set_property (GObject * object,
                                                                    guint property_id,
                                                                    const GValue * value,
                                                                    GParamSpec * pspec);
static gchar* serializable_gee_array_list_test_ball_real_to_string (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_array_list_test_ball_real_node_name (GXmlSerializableObjectModel* base);
static void serializable_gee_array_list_test_ball_set_name (SerializableGeeArrayListTestBall* self,
                                                     const gchar* value);
static gboolean serializable_gee_array_list_test_ball_array_real_deserialize_proceed (GXmlSerializableArrayList* base);
static SerializableGeeArrayListTestBallArray* serializable_gee_array_list_test_ball_array_new (void);
static SerializableGeeArrayListTestBallArray* serializable_gee_array_list_test_ball_array_construct (GType object_type);
static void serializable_gee_array_list_test_ball_finalize (GObject * obj);
static void _vala_serializable_gee_array_list_test_ball_get_property (GObject * object,
                                                               guint property_id,
                                                               GValue * value,
                                                               GParamSpec * pspec);
static void _vala_serializable_gee_array_list_test_ball_set_property (GObject * object,
                                                               guint property_id,
                                                               const GValue * value,
                                                               GParamSpec * pspec);
static gchar* serializable_gee_array_list_test_small_bag_real_to_string (GXmlSerializableObjectModel* base);
static const gchar* serializable_gee_array_list_test_small_bag_get_name (SerializableGeeArrayListTestSmallBag* self);
static gchar* serializable_gee_array_list_test_small_bag_real_node_name (GXmlSerializableObjectModel* base);
static void serializable_gee_array_list_test_small_bag_set_name (SerializableGeeArrayListTestSmallBag* self,
                                                          const gchar* value);
static void serializable_gee_array_list_test_small_bag_set_balls (SerializableGeeArrayListTestSmallBag* self,
                                                           SerializableGeeArrayListTestBallArray* value);
static gboolean serializable_gee_array_list_test_small_bag_array_real_deserialize_proceed (GXmlSerializableArrayList* base);
static SerializableGeeArrayListTestSmallBagArray* serializable_gee_array_list_test_small_bag_array_new (void);
static SerializableGeeArrayListTestSmallBagArray* serializable_gee_array_list_test_small_bag_array_construct (GType object_type);
static void serializable_gee_array_list_test_small_bag_finalize (GObject * obj);
static void _vala_serializable_gee_array_list_test_small_bag_get_property (GObject * object,
                                                                    guint property_id,
                                                                    GValue * value,
                                                                    GParamSpec * pspec);
static void _vala_serializable_gee_array_list_test_small_bag_set_property (GObject * object,
                                                                    guint property_id,
                                                                    const GValue * value,
                                                                    GParamSpec * pspec);
static gchar* serializable_gee_array_list_test_big_bag_real_to_string (GXmlSerializableObjectModel* base);
static const gchar* serializable_gee_array_list_test_big_bag_get_name (SerializableGeeArrayListTestBigBag* self);
static gchar* serializable_gee_array_list_test_big_bag_real_node_name (GXmlSerializableObjectModel* base);
static void serializable_gee_array_list_test_big_bag_set_name (SerializableGeeArrayListTestBigBag* self,
                                                        const gchar* value);
static void serializable_gee_array_list_test_big_bag_set_bags (SerializableGeeArrayListTestBigBag* self,
                                                        SerializableGeeArrayListTestSmallBagArray* value);
static void serializable_gee_array_list_test_big_bag_finalize (GObject * obj);
static void _vala_serializable_gee_array_list_test_big_bag_get_property (GObject * object,
                                                                  guint property_id,
                                                                  GValue * value,
                                                                  GParamSpec * pspec);
static void _vala_serializable_gee_array_list_test_big_bag_set_property (GObject * object,
                                                                  guint property_id,
                                                                  const GValue * value,
                                                                  GParamSpec * pspec);
static void _vala_array_destroy (gpointer array,
                          gint array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gint array_length,
                       GDestroyNotify destroy_func);

static inline gpointer
aelement_get_instance_private (AElement* self)
{
	return G_STRUCT_MEMBER_P (self, AElement_private_offset);
}

AElement*
aelement_construct_named (GType object_type,
                          const gchar* name)
{
	AElement * self = NULL;
#line 32 "SerializableGeeArrayListTest.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 32 "SerializableGeeArrayListTest.vala"
	self = (AElement*) gxml_serializable_object_model_construct (object_type);
#line 32 "SerializableGeeArrayListTest.vala"
	aelement_set_name (self, name);
#line 32 "SerializableGeeArrayListTest.vala"
	return self;
#line 645 "SerializableGeeArrayListTest.c"
}

AElement*
aelement_new_named (const gchar* name)
{
#line 32 "SerializableGeeArrayListTest.vala"
	return aelement_construct_named (TYPE_AELEMENT, name);
#line 653 "SerializableGeeArrayListTest.c"
}

static gchar*
aelement_real_to_string (GXmlSerializableObjectModel* base)
{
	AElement * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 33 "SerializableGeeArrayListTest.vala"
	self = (AElement*) base;
#line 33 "SerializableGeeArrayListTest.vala"
	_tmp0_ = self->priv->_name;
#line 33 "SerializableGeeArrayListTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 33 "SerializableGeeArrayListTest.vala"
	result = _tmp1_;
#line 33 "SerializableGeeArrayListTest.vala"
	return result;
#line 673 "SerializableGeeArrayListTest.c"
}

AElement*
aelement_construct (GType object_type)
{
	AElement * self = NULL;
#line 29 "SerializableGeeArrayListTest.vala"
	self = (AElement*) gxml_serializable_object_model_construct (object_type);
#line 29 "SerializableGeeArrayListTest.vala"
	return self;
#line 684 "SerializableGeeArrayListTest.c"
}

AElement*
aelement_new (void)
{
#line 29 "SerializableGeeArrayListTest.vala"
	return aelement_construct (TYPE_AELEMENT);
#line 692 "SerializableGeeArrayListTest.c"
}

const gchar*
aelement_get_name (AElement* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 31 "SerializableGeeArrayListTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 31 "SerializableGeeArrayListTest.vala"
	_tmp0_ = self->priv->_name;
#line 31 "SerializableGeeArrayListTest.vala"
	result = _tmp0_;
#line 31 "SerializableGeeArrayListTest.vala"
	return result;
#line 708 "SerializableGeeArrayListTest.c"
}

void
aelement_set_name (AElement* self,
                   const gchar* value)
{
#line 31 "SerializableGeeArrayListTest.vala"
	g_return_if_fail (self != NULL);
#line 31 "SerializableGeeArrayListTest.vala"
	if (g_strcmp0 (value, aelement_get_name (self)) != 0) {
#line 719 "SerializableGeeArrayListTest.c"
		gchar* _tmp0_;
#line 31 "SerializableGeeArrayListTest.vala"
		_tmp0_ = g_strdup (value);
#line 31 "SerializableGeeArrayListTest.vala"
		_g_free0 (self->priv->_name);
#line 31 "SerializableGeeArrayListTest.vala"
		self->priv->_name = _tmp0_;
#line 31 "SerializableGeeArrayListTest.vala"
		g_object_notify_by_pspec ((GObject *) self, aelement_properties[AELEMENT_NAME_PROPERTY]);
#line 729 "SerializableGeeArrayListTest.c"
	}
}

static inline gpointer
aelement_array_get_instance_private (AElementArray* self)
{
	return G_STRUCT_MEMBER_P (self, AElementArray_private_offset);
}

static gboolean
aelement_array_real_deserialize_proceed (GXmlSerializableArrayList* base)
{
	AElementArray * self;
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 36 "SerializableGeeArrayListTest.vala"
	self = (AElementArray*) base;
#line 36 "SerializableGeeArrayListTest.vala"
	_tmp0_ = self->priv->_enable_deserialize;
#line 36 "SerializableGeeArrayListTest.vala"
	result = _tmp0_;
#line 36 "SerializableGeeArrayListTest.vala"
	return result;
#line 753 "SerializableGeeArrayListTest.c"
}

AElementArray*
aelement_array_construct (GType object_type)
{
	AElementArray * self = NULL;
#line 34 "SerializableGeeArrayListTest.vala"
	self = (AElementArray*) gxml_serializable_array_list_construct (object_type, TYPE_AELEMENT, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 34 "SerializableGeeArrayListTest.vala"
	return self;
#line 764 "SerializableGeeArrayListTest.c"
}

AElementArray*
aelement_array_new (void)
{
#line 34 "SerializableGeeArrayListTest.vala"
	return aelement_array_construct (AELEMENT_TYPE_ARRAY);
#line 772 "SerializableGeeArrayListTest.c"
}

gboolean
aelement_array_get_enable_deserialize (AElementArray* self)
{
	gboolean result;
#line 35 "SerializableGeeArrayListTest.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 35 "SerializableGeeArrayListTest.vala"
	result = self->priv->_enable_deserialize;
#line 35 "SerializableGeeArrayListTest.vala"
	return result;
#line 785 "SerializableGeeArrayListTest.c"
}

void
aelement_array_set_enable_deserialize (AElementArray* self,
                                       gboolean value)
{
#line 35 "SerializableGeeArrayListTest.vala"
	g_return_if_fail (self != NULL);
#line 35 "SerializableGeeArrayListTest.vala"
	if (aelement_array_get_enable_deserialize (self) != value) {
#line 35 "SerializableGeeArrayListTest.vala"
		self->priv->_enable_deserialize = value;
#line 35 "SerializableGeeArrayListTest.vala"
		g_object_notify_by_pspec ((GObject *) self, aelement_array_properties[AELEMENT_ARRAY_ENABLE_DESERIALIZE_PROPERTY]);
#line 800 "SerializableGeeArrayListTest.c"
	}
}

static void
aelement_array_class_init (AElementArrayClass * klass,
                           gpointer klass_data)
{
#line 34 "SerializableGeeArrayListTest.vala"
	aelement_array_parent_class = g_type_class_peek_parent (klass);
#line 34 "SerializableGeeArrayListTest.vala"
	g_type_class_adjust_private_offset (klass, &AElementArray_private_offset);
#line 34 "SerializableGeeArrayListTest.vala"
	((GXmlSerializableArrayListClass *) klass)->deserialize_proceed = (gboolean (*) (GXmlSerializableArrayList*)) aelement_array_real_deserialize_proceed;
#line 34 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_aelement_array_get_property;
#line 34 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_aelement_array_set_property;
#line 34 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (klass)->finalize = aelement_array_finalize;
#line 34 "SerializableGeeArrayListTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), AELEMENT_ARRAY_ENABLE_DESERIALIZE_PROPERTY, aelement_array_properties[AELEMENT_ARRAY_ENABLE_DESERIALIZE_PROPERTY] = g_param_spec_boolean ("enable-deserialize", "enable-deserialize", "enable-deserialize", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 822 "SerializableGeeArrayListTest.c"
}

static void
aelement_array_instance_init (AElementArray * self,
                              gpointer klass)
{
#line 34 "SerializableGeeArrayListTest.vala"
	self->priv = aelement_array_get_instance_private (self);
#line 35 "SerializableGeeArrayListTest.vala"
	self->priv->_enable_deserialize = FALSE;
#line 833 "SerializableGeeArrayListTest.c"
}

static void
aelement_array_finalize (GObject * obj)
{
	AElementArray * self;
#line 34 "SerializableGeeArrayListTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, AELEMENT_TYPE_ARRAY, AElementArray);
#line 34 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (aelement_array_parent_class)->finalize (obj);
#line 844 "SerializableGeeArrayListTest.c"
}

GType
aelement_array_get_type (void)
{
	static volatile gsize aelement_array_type_id__volatile = 0;
	if (g_once_init_enter (&aelement_array_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AElementArrayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) aelement_array_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AElementArray), 0, (GInstanceInitFunc) aelement_array_instance_init, NULL };
		GType aelement_array_type_id;
		aelement_array_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_ARRAY_LIST, "AElementArray", &g_define_type_info, 0);
		AElementArray_private_offset = g_type_add_instance_private (aelement_array_type_id, sizeof (AElementArrayPrivate));
		g_once_init_leave (&aelement_array_type_id__volatile, aelement_array_type_id);
	}
	return aelement_array_type_id__volatile;
}

static void
_vala_aelement_array_get_property (GObject * object,
                                   guint property_id,
                                   GValue * value,
                                   GParamSpec * pspec)
{
	AElementArray * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, AELEMENT_TYPE_ARRAY, AElementArray);
#line 34 "SerializableGeeArrayListTest.vala"
	switch (property_id) {
#line 34 "SerializableGeeArrayListTest.vala"
		case AELEMENT_ARRAY_ENABLE_DESERIALIZE_PROPERTY:
#line 34 "SerializableGeeArrayListTest.vala"
		g_value_set_boolean (value, aelement_array_get_enable_deserialize (self));
#line 34 "SerializableGeeArrayListTest.vala"
		break;
#line 877 "SerializableGeeArrayListTest.c"
		default:
#line 34 "SerializableGeeArrayListTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 34 "SerializableGeeArrayListTest.vala"
		break;
#line 883 "SerializableGeeArrayListTest.c"
	}
}

static void
_vala_aelement_array_set_property (GObject * object,
                                   guint property_id,
                                   const GValue * value,
                                   GParamSpec * pspec)
{
	AElementArray * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, AELEMENT_TYPE_ARRAY, AElementArray);
#line 34 "SerializableGeeArrayListTest.vala"
	switch (property_id) {
#line 34 "SerializableGeeArrayListTest.vala"
		case AELEMENT_ARRAY_ENABLE_DESERIALIZE_PROPERTY:
#line 34 "SerializableGeeArrayListTest.vala"
		aelement_array_set_enable_deserialize (self, g_value_get_boolean (value));
#line 34 "SerializableGeeArrayListTest.vala"
		break;
#line 903 "SerializableGeeArrayListTest.c"
		default:
#line 34 "SerializableGeeArrayListTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 34 "SerializableGeeArrayListTest.vala"
		break;
#line 909 "SerializableGeeArrayListTest.c"
	}
}

static void
aelement_class_init (AElementClass * klass,
                     gpointer klass_data)
{
#line 29 "SerializableGeeArrayListTest.vala"
	aelement_parent_class = g_type_class_peek_parent (klass);
#line 29 "SerializableGeeArrayListTest.vala"
	g_type_class_adjust_private_offset (klass, &AElement_private_offset);
#line 29 "SerializableGeeArrayListTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) aelement_real_to_string;
#line 29 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_aelement_get_property;
#line 29 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_aelement_set_property;
#line 29 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (klass)->finalize = aelement_finalize;
#line 29 "SerializableGeeArrayListTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), AELEMENT_NAME_PROPERTY, aelement_properties[AELEMENT_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 931 "SerializableGeeArrayListTest.c"
}

static void
aelement_instance_init (AElement * self,
                        gpointer klass)
{
#line 29 "SerializableGeeArrayListTest.vala"
	self->priv = aelement_get_instance_private (self);
#line 940 "SerializableGeeArrayListTest.c"
}

static void
aelement_finalize (GObject * obj)
{
	AElement * self;
#line 29 "SerializableGeeArrayListTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_AELEMENT, AElement);
#line 31 "SerializableGeeArrayListTest.vala"
	_g_free0 (self->priv->_name);
#line 29 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (aelement_parent_class)->finalize (obj);
#line 953 "SerializableGeeArrayListTest.c"
}

/**
 *
 *  GXml.Serializable.BasicTypeTest
 *
 *  Authors:
 *
 *       Daniel Espinosa <esodan@gmail.com>
 *
 *
 *  Copyright (c) 2013-2015 Daniel Espinosa
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
GType
aelement_get_type (void)
{
	static volatile gsize aelement_type_id__volatile = 0;
	if (g_once_init_enter (&aelement_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AElementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) aelement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AElement), 0, (GInstanceInitFunc) aelement_instance_init, NULL };
		GType aelement_type_id;
		aelement_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "AElement", &g_define_type_info, 0);
		AElement_private_offset = g_type_add_instance_private (aelement_type_id, sizeof (AElementPrivate));
		g_once_init_leave (&aelement_type_id__volatile, aelement_type_id);
	}
	return aelement_type_id__volatile;
}

static void
_vala_aelement_get_property (GObject * object,
                             guint property_id,
                             GValue * value,
                             GParamSpec * pspec)
{
	AElement * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_AELEMENT, AElement);
#line 29 "SerializableGeeArrayListTest.vala"
	switch (property_id) {
#line 29 "SerializableGeeArrayListTest.vala"
		case AELEMENT_NAME_PROPERTY:
#line 29 "SerializableGeeArrayListTest.vala"
		g_value_set_string (value, aelement_get_name (self));
#line 29 "SerializableGeeArrayListTest.vala"
		break;
#line 1010 "SerializableGeeArrayListTest.c"
		default:
#line 29 "SerializableGeeArrayListTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 29 "SerializableGeeArrayListTest.vala"
		break;
#line 1016 "SerializableGeeArrayListTest.c"
	}
}

static void
_vala_aelement_set_property (GObject * object,
                             guint property_id,
                             const GValue * value,
                             GParamSpec * pspec)
{
	AElement * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_AELEMENT, AElement);
#line 29 "SerializableGeeArrayListTest.vala"
	switch (property_id) {
#line 29 "SerializableGeeArrayListTest.vala"
		case AELEMENT_NAME_PROPERTY:
#line 29 "SerializableGeeArrayListTest.vala"
		aelement_set_name (self, g_value_get_string (value));
#line 29 "SerializableGeeArrayListTest.vala"
		break;
#line 1036 "SerializableGeeArrayListTest.c"
		default:
#line 29 "SerializableGeeArrayListTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 29 "SerializableGeeArrayListTest.vala"
		break;
#line 1042 "SerializableGeeArrayListTest.c"
	}
}

static inline gpointer
celement_get_instance_private (CElement* self)
{
	return G_STRUCT_MEMBER_P (self, CElement_private_offset);
}

static gchar*
celement_real_node_name (GXmlSerializableObjectModel* base)
{
	CElement * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 42 "SerializableGeeArrayListTest.vala"
	self = (CElement*) base;
#line 42 "SerializableGeeArrayListTest.vala"
	_tmp0_ = g_strdup ("CElement");
#line 42 "SerializableGeeArrayListTest.vala"
	result = _tmp0_;
#line 42 "SerializableGeeArrayListTest.vala"
	return result;
#line 1066 "SerializableGeeArrayListTest.c"
}

static gchar*
celement_real_to_string (GXmlSerializableObjectModel* base)
{
	CElement * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 43 "SerializableGeeArrayListTest.vala"
	self = (CElement*) base;
#line 43 "SerializableGeeArrayListTest.vala"
	_tmp0_ = g_strdup ("CElement");
#line 43 "SerializableGeeArrayListTest.vala"
	result = _tmp0_;
#line 43 "SerializableGeeArrayListTest.vala"
	return result;
#line 1083 "SerializableGeeArrayListTest.c"
}

CElement*
celement_construct (GType object_type)
{
	CElement * self = NULL;
#line 40 "SerializableGeeArrayListTest.vala"
	self = (CElement*) gxml_serializable_object_model_construct (object_type);
#line 40 "SerializableGeeArrayListTest.vala"
	return self;
#line 1094 "SerializableGeeArrayListTest.c"
}

CElement*
celement_new (void)
{
#line 40 "SerializableGeeArrayListTest.vala"
	return celement_construct (TYPE_CELEMENT);
#line 1102 "SerializableGeeArrayListTest.c"
}

AElementArray*
celement_get_elements (CElement* self)
{
	AElementArray* result;
	AElementArray* _tmp0_;
#line 41 "SerializableGeeArrayListTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 41 "SerializableGeeArrayListTest.vala"
	_tmp0_ = self->priv->_elements;
#line 41 "SerializableGeeArrayListTest.vala"
	result = _tmp0_;
#line 41 "SerializableGeeArrayListTest.vala"
	return result;
#line 1118 "SerializableGeeArrayListTest.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 41 "SerializableGeeArrayListTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 1126 "SerializableGeeArrayListTest.c"
}

void
celement_set_elements (CElement* self,
                       AElementArray* value)
{
#line 41 "SerializableGeeArrayListTest.vala"
	g_return_if_fail (self != NULL);
#line 41 "SerializableGeeArrayListTest.vala"
	if (celement_get_elements (self) != value) {
#line 1137 "SerializableGeeArrayListTest.c"
		AElementArray* _tmp0_;
#line 41 "SerializableGeeArrayListTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 41 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (self->priv->_elements);
#line 41 "SerializableGeeArrayListTest.vala"
		self->priv->_elements = _tmp0_;
#line 41 "SerializableGeeArrayListTest.vala"
		g_object_notify_by_pspec ((GObject *) self, celement_properties[CELEMENT_ELEMENTS_PROPERTY]);
#line 1147 "SerializableGeeArrayListTest.c"
	}
}

static void
celement_class_init (CElementClass * klass,
                     gpointer klass_data)
{
#line 40 "SerializableGeeArrayListTest.vala"
	celement_parent_class = g_type_class_peek_parent (klass);
#line 40 "SerializableGeeArrayListTest.vala"
	g_type_class_adjust_private_offset (klass, &CElement_private_offset);
#line 40 "SerializableGeeArrayListTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) celement_real_node_name;
#line 40 "SerializableGeeArrayListTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) celement_real_to_string;
#line 40 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_celement_get_property;
#line 40 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_celement_set_property;
#line 40 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (klass)->finalize = celement_finalize;
#line 40 "SerializableGeeArrayListTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), CELEMENT_ELEMENTS_PROPERTY, celement_properties[CELEMENT_ELEMENTS_PROPERTY] = g_param_spec_object ("elements", "elements", "elements", AELEMENT_TYPE_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1171 "SerializableGeeArrayListTest.c"
}

static void
celement_instance_init (CElement * self,
                        gpointer klass)
{
	AElementArray* _tmp0_;
#line 40 "SerializableGeeArrayListTest.vala"
	self->priv = celement_get_instance_private (self);
#line 41 "SerializableGeeArrayListTest.vala"
	_tmp0_ = aelement_array_new ();
#line 41 "SerializableGeeArrayListTest.vala"
	self->priv->_elements = _tmp0_;
#line 1185 "SerializableGeeArrayListTest.c"
}

static void
celement_finalize (GObject * obj)
{
	CElement * self;
#line 40 "SerializableGeeArrayListTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_CELEMENT, CElement);
#line 41 "SerializableGeeArrayListTest.vala"
	_g_object_unref0 (self->priv->_elements);
#line 40 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (celement_parent_class)->finalize (obj);
#line 1198 "SerializableGeeArrayListTest.c"
}

GType
celement_get_type (void)
{
	static volatile gsize celement_type_id__volatile = 0;
	if (g_once_init_enter (&celement_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (CElementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) celement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (CElement), 0, (GInstanceInitFunc) celement_instance_init, NULL };
		GType celement_type_id;
		celement_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "CElement", &g_define_type_info, 0);
		CElement_private_offset = g_type_add_instance_private (celement_type_id, sizeof (CElementPrivate));
		g_once_init_leave (&celement_type_id__volatile, celement_type_id);
	}
	return celement_type_id__volatile;
}

static void
_vala_celement_get_property (GObject * object,
                             guint property_id,
                             GValue * value,
                             GParamSpec * pspec)
{
	CElement * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_CELEMENT, CElement);
#line 40 "SerializableGeeArrayListTest.vala"
	switch (property_id) {
#line 40 "SerializableGeeArrayListTest.vala"
		case CELEMENT_ELEMENTS_PROPERTY:
#line 40 "SerializableGeeArrayListTest.vala"
		g_value_set_object (value, celement_get_elements (self));
#line 40 "SerializableGeeArrayListTest.vala"
		break;
#line 1231 "SerializableGeeArrayListTest.c"
		default:
#line 40 "SerializableGeeArrayListTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 40 "SerializableGeeArrayListTest.vala"
		break;
#line 1237 "SerializableGeeArrayListTest.c"
	}
}

static void
_vala_celement_set_property (GObject * object,
                             guint property_id,
                             const GValue * value,
                             GParamSpec * pspec)
{
	CElement * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_CELEMENT, CElement);
#line 40 "SerializableGeeArrayListTest.vala"
	switch (property_id) {
#line 40 "SerializableGeeArrayListTest.vala"
		case CELEMENT_ELEMENTS_PROPERTY:
#line 40 "SerializableGeeArrayListTest.vala"
		celement_set_elements (self, g_value_get_object (value));
#line 40 "SerializableGeeArrayListTest.vala"
		break;
#line 1257 "SerializableGeeArrayListTest.c"
		default:
#line 40 "SerializableGeeArrayListTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 40 "SerializableGeeArrayListTest.vala"
		break;
#line 1263 "SerializableGeeArrayListTest.c"
	}
}

static void
__lambda305_ (void)
{
	GXmlSerializableArrayList* c = NULL;
	GXmlSerializableArrayList* _tmp0_;
	AElement* o1 = NULL;
	AElement* _tmp1_;
	AElement* o2 = NULL;
	AElement* _tmp2_;
	GXmlSerializableArrayList* _tmp3_;
	AElement* _tmp4_;
	GXmlSerializableArrayList* _tmp5_;
	AElement* _tmp6_;
	gboolean found1 = FALSE;
	gboolean found2 = FALSE;
#line 91 "SerializableGeeArrayListTest.vala"
	_tmp0_ = gxml_serializable_array_list_new (TYPE_AELEMENT, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 91 "SerializableGeeArrayListTest.vala"
	c = _tmp0_;
#line 92 "SerializableGeeArrayListTest.vala"
	_tmp1_ = aelement_new_named ("Big");
#line 92 "SerializableGeeArrayListTest.vala"
	o1 = _tmp1_;
#line 93 "SerializableGeeArrayListTest.vala"
	_tmp2_ = aelement_new_named ("Small");
#line 93 "SerializableGeeArrayListTest.vala"
	o2 = _tmp2_;
#line 94 "SerializableGeeArrayListTest.vala"
	_tmp3_ = c;
#line 94 "SerializableGeeArrayListTest.vala"
	_tmp4_ = o1;
#line 94 "SerializableGeeArrayListTest.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp3_, _tmp4_);
#line 95 "SerializableGeeArrayListTest.vala"
	_tmp5_ = c;
#line 95 "SerializableGeeArrayListTest.vala"
	_tmp6_ = o2;
#line 95 "SerializableGeeArrayListTest.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp5_, _tmp6_);
#line 96 "SerializableGeeArrayListTest.vala"
	found1 = FALSE;
#line 97 "SerializableGeeArrayListTest.vala"
	found2 = FALSE;
#line 1310 "SerializableGeeArrayListTest.c"
	{
		GXmlSerializableArrayList* _o_list = NULL;
		GXmlSerializableArrayList* _tmp7_;
		GXmlSerializableArrayList* _tmp8_;
		gint _o_size = 0;
		GXmlSerializableArrayList* _tmp9_;
		gint _tmp10_;
		gint _tmp11_;
		gint _o_index = 0;
#line 98 "SerializableGeeArrayListTest.vala"
		_tmp7_ = c;
#line 98 "SerializableGeeArrayListTest.vala"
		_tmp8_ = _g_object_ref0 (_tmp7_);
#line 98 "SerializableGeeArrayListTest.vala"
		_o_list = _tmp8_;
#line 98 "SerializableGeeArrayListTest.vala"
		_tmp9_ = _o_list;
#line 98 "SerializableGeeArrayListTest.vala"
		_tmp10_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp9_);
#line 98 "SerializableGeeArrayListTest.vala"
		_tmp11_ = _tmp10_;
#line 98 "SerializableGeeArrayListTest.vala"
		_o_size = _tmp11_;
#line 98 "SerializableGeeArrayListTest.vala"
		_o_index = -1;
#line 98 "SerializableGeeArrayListTest.vala"
		while (TRUE) {
#line 1338 "SerializableGeeArrayListTest.c"
			AElement* o = NULL;
			GXmlSerializableArrayList* _tmp12_;
			gpointer _tmp13_;
			AElement* _tmp14_;
			const gchar* _tmp15_;
			const gchar* _tmp16_;
			AElement* _tmp17_;
			const gchar* _tmp18_;
			const gchar* _tmp19_;
#line 98 "SerializableGeeArrayListTest.vala"
			_o_index = _o_index + 1;
#line 98 "SerializableGeeArrayListTest.vala"
			if (!(_o_index < _o_size)) {
#line 98 "SerializableGeeArrayListTest.vala"
				break;
#line 1354 "SerializableGeeArrayListTest.c"
			}
#line 98 "SerializableGeeArrayListTest.vala"
			_tmp12_ = _o_list;
#line 98 "SerializableGeeArrayListTest.vala"
			_tmp13_ = gee_abstract_list_get ((GeeAbstractList*) _tmp12_, _o_index);
#line 98 "SerializableGeeArrayListTest.vala"
			o = (AElement*) _tmp13_;
#line 99 "SerializableGeeArrayListTest.vala"
			_tmp14_ = o;
#line 99 "SerializableGeeArrayListTest.vala"
			_tmp15_ = aelement_get_name (_tmp14_);
#line 99 "SerializableGeeArrayListTest.vala"
			_tmp16_ = _tmp15_;
#line 99 "SerializableGeeArrayListTest.vala"
			if (g_strcmp0 (_tmp16_, "Big") == 0) {
#line 99 "SerializableGeeArrayListTest.vala"
				found1 = TRUE;
#line 1372 "SerializableGeeArrayListTest.c"
			}
#line 100 "SerializableGeeArrayListTest.vala"
			_tmp17_ = o;
#line 100 "SerializableGeeArrayListTest.vala"
			_tmp18_ = aelement_get_name (_tmp17_);
#line 100 "SerializableGeeArrayListTest.vala"
			_tmp19_ = _tmp18_;
#line 100 "SerializableGeeArrayListTest.vala"
			if (g_strcmp0 (_tmp19_, "Small") == 0) {
#line 100 "SerializableGeeArrayListTest.vala"
				found2 = TRUE;
#line 1384 "SerializableGeeArrayListTest.c"
			}
#line 98 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (o);
#line 1388 "SerializableGeeArrayListTest.c"
		}
#line 98 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_o_list);
#line 1392 "SerializableGeeArrayListTest.c"
	}
#line 102 "SerializableGeeArrayListTest.vala"
	if (!found1) {
#line 1396 "SerializableGeeArrayListTest.c"
		FILE* _tmp20_;
#line 103 "SerializableGeeArrayListTest.vala"
		_tmp20_ = stdout;
#line 103 "SerializableGeeArrayListTest.vala"
		fprintf (_tmp20_, "%s", "Big is not found\n");
#line 104 "SerializableGeeArrayListTest.vala"
		g_assert_not_reached ();
#line 1404 "SerializableGeeArrayListTest.c"
	}
#line 106 "SerializableGeeArrayListTest.vala"
	if (!found2) {
#line 1408 "SerializableGeeArrayListTest.c"
		FILE* _tmp21_;
#line 107 "SerializableGeeArrayListTest.vala"
		_tmp21_ = stdout;
#line 107 "SerializableGeeArrayListTest.vala"
		fprintf (_tmp21_, "%s", "Small is not found\n");
#line 108 "SerializableGeeArrayListTest.vala"
		g_assert_not_reached ();
#line 1416 "SerializableGeeArrayListTest.c"
	}
#line 90 "SerializableGeeArrayListTest.vala"
	_g_object_unref0 (o2);
#line 90 "SerializableGeeArrayListTest.vala"
	_g_object_unref0 (o1);
#line 90 "SerializableGeeArrayListTest.vala"
	_g_object_unref0 (c);
#line 1424 "SerializableGeeArrayListTest.c"
}

static void
___lambda305__gtest_func (void)
{
#line 89 "SerializableGeeArrayListTest.vala"
	__lambda305_ ();
#line 1432 "SerializableGeeArrayListTest.c"
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result = NULL;
#line 1516 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1517 "glib-2.0.vapi"
	result = self;
#line 1517 "glib-2.0.vapi"
	return result;
#line 1445 "SerializableGeeArrayListTest.c"
}

static void
__lambda306_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlSerializableArrayList* c = NULL;
		GXmlSerializableArrayList* _tmp0_;
		AElement* o1 = NULL;
		AElement* _tmp1_;
		AElement* o2 = NULL;
		AElement* _tmp2_;
		GXmlSerializableArrayList* _tmp3_;
		AElement* _tmp4_;
		GXmlSerializableArrayList* _tmp5_;
		AElement* _tmp6_;
		GXmlTDocument* doc = NULL;
		GXmlTDocument* _tmp7_;
		GXmlNode* root = NULL;
		GXmlTDocument* _tmp8_;
		GXmlNode* _tmp9_;
		GXmlTDocument* _tmp10_;
		GeeBidirList* _tmp11_;
		GeeBidirList* _tmp12_;
		GeeBidirList* _tmp13_;
		GXmlNode* _tmp14_;
		GXmlSerializableArrayList* _tmp15_;
		GXmlNode* _tmp16_;
		GXmlNode* _tmp17_;
		GXmlNode* _tmp18_;
		GXmlNode* _tmp19_;
		GeeBidirList* _tmp20_;
		GeeBidirList* _tmp21_;
		GeeBidirList* _tmp22_;
		gint _tmp23_;
		gint _tmp24_;
		gboolean found1 = FALSE;
		gboolean found2 = FALSE;
#line 114 "SerializableGeeArrayListTest.vala"
		_tmp0_ = gxml_serializable_array_list_new (TYPE_AELEMENT, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 114 "SerializableGeeArrayListTest.vala"
		c = _tmp0_;
#line 115 "SerializableGeeArrayListTest.vala"
		_tmp1_ = aelement_new_named ("Big");
#line 115 "SerializableGeeArrayListTest.vala"
		o1 = _tmp1_;
#line 116 "SerializableGeeArrayListTest.vala"
		_tmp2_ = aelement_new_named ("Small");
#line 116 "SerializableGeeArrayListTest.vala"
		o2 = _tmp2_;
#line 117 "SerializableGeeArrayListTest.vala"
		_tmp3_ = c;
#line 117 "SerializableGeeArrayListTest.vala"
		_tmp4_ = o1;
#line 117 "SerializableGeeArrayListTest.vala"
		gee_abstract_collection_add ((GeeAbstractCollection*) _tmp3_, _tmp4_);
#line 118 "SerializableGeeArrayListTest.vala"
		_tmp5_ = c;
#line 118 "SerializableGeeArrayListTest.vala"
		_tmp6_ = o2;
#line 118 "SerializableGeeArrayListTest.vala"
		gee_abstract_collection_add ((GeeAbstractCollection*) _tmp5_, _tmp6_);
#line 119 "SerializableGeeArrayListTest.vala"
		_tmp7_ = gxml_tdocument_new ();
#line 119 "SerializableGeeArrayListTest.vala"
		doc = _tmp7_;
#line 120 "SerializableGeeArrayListTest.vala"
		_tmp8_ = doc;
#line 120 "SerializableGeeArrayListTest.vala"
		_tmp9_ = gxml_document_create_element ((GXmlDocument*) _tmp8_, "root", &_inner_error0_);
#line 120 "SerializableGeeArrayListTest.vala"
		root = _tmp9_;
#line 120 "SerializableGeeArrayListTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 120 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (doc);
#line 120 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (o2);
#line 120 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (o1);
#line 120 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (c);
#line 1529 "SerializableGeeArrayListTest.c"
			goto __catch357_g_error;
		}
#line 121 "SerializableGeeArrayListTest.vala"
		_tmp10_ = doc;
#line 121 "SerializableGeeArrayListTest.vala"
		_tmp11_ = gxml_tnode_get_children_nodes ((GXmlTNode*) _tmp10_);
#line 121 "SerializableGeeArrayListTest.vala"
		_tmp12_ = _tmp11_;
#line 121 "SerializableGeeArrayListTest.vala"
		_tmp13_ = _tmp12_;
#line 121 "SerializableGeeArrayListTest.vala"
		_tmp14_ = root;
#line 121 "SerializableGeeArrayListTest.vala"
		gee_collection_add ((GeeCollection*) _tmp13_, _tmp14_);
#line 121 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp13_);
#line 122 "SerializableGeeArrayListTest.vala"
		_tmp15_ = c;
#line 122 "SerializableGeeArrayListTest.vala"
		_tmp16_ = root;
#line 122 "SerializableGeeArrayListTest.vala"
		_tmp17_ = gxml_serializable_array_list_serialize (_tmp15_, _tmp16_, &_inner_error0_);
#line 122 "SerializableGeeArrayListTest.vala"
		_tmp18_ = _tmp17_;
#line 122 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp18_);
#line 122 "SerializableGeeArrayListTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 122 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (root);
#line 122 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (doc);
#line 122 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (o2);
#line 122 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (o1);
#line 122 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (c);
#line 1568 "SerializableGeeArrayListTest.c"
			goto __catch357_g_error;
		}
#line 123 "SerializableGeeArrayListTest.vala"
		_tmp19_ = root;
#line 123 "SerializableGeeArrayListTest.vala"
		_tmp20_ = gxml_node_get_children_nodes (_tmp19_);
#line 123 "SerializableGeeArrayListTest.vala"
		_tmp21_ = _tmp20_;
#line 123 "SerializableGeeArrayListTest.vala"
		_tmp22_ = _tmp21_;
#line 123 "SerializableGeeArrayListTest.vala"
		_tmp23_ = gee_collection_get_size ((GeeCollection*) _tmp22_);
#line 123 "SerializableGeeArrayListTest.vala"
		_tmp24_ = _tmp23_;
#line 123 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp24_ == 2, "root.children_nodes.size == 2");
#line 123 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp22_);
#line 124 "SerializableGeeArrayListTest.vala"
		found1 = FALSE;
#line 125 "SerializableGeeArrayListTest.vala"
		found2 = FALSE;
#line 1591 "SerializableGeeArrayListTest.c"
		{
			GeeBidirList* _n_list = NULL;
			GXmlNode* _tmp25_;
			GeeBidirList* _tmp26_;
			GeeBidirList* _tmp27_;
			gint _n_size = 0;
			GeeBidirList* _tmp28_;
			gint _tmp29_;
			gint _tmp30_;
			gint _n_index = 0;
#line 126 "SerializableGeeArrayListTest.vala"
			_tmp25_ = root;
#line 126 "SerializableGeeArrayListTest.vala"
			_tmp26_ = gxml_node_get_children_nodes (_tmp25_);
#line 126 "SerializableGeeArrayListTest.vala"
			_tmp27_ = _tmp26_;
#line 126 "SerializableGeeArrayListTest.vala"
			_n_list = _tmp27_;
#line 126 "SerializableGeeArrayListTest.vala"
			_tmp28_ = _n_list;
#line 126 "SerializableGeeArrayListTest.vala"
			_tmp29_ = gee_collection_get_size ((GeeCollection*) _tmp28_);
#line 126 "SerializableGeeArrayListTest.vala"
			_tmp30_ = _tmp29_;
#line 126 "SerializableGeeArrayListTest.vala"
			_n_size = _tmp30_;
#line 126 "SerializableGeeArrayListTest.vala"
			_n_index = -1;
#line 126 "SerializableGeeArrayListTest.vala"
			while (TRUE) {
#line 1622 "SerializableGeeArrayListTest.c"
				GXmlNode* n = NULL;
				GeeBidirList* _tmp31_;
				gpointer _tmp32_;
				gboolean _tmp33_ = FALSE;
				GXmlNode* _tmp34_;
#line 126 "SerializableGeeArrayListTest.vala"
				_n_index = _n_index + 1;
#line 126 "SerializableGeeArrayListTest.vala"
				if (!(_n_index < _n_size)) {
#line 126 "SerializableGeeArrayListTest.vala"
					break;
#line 1634 "SerializableGeeArrayListTest.c"
				}
#line 126 "SerializableGeeArrayListTest.vala"
				_tmp31_ = _n_list;
#line 126 "SerializableGeeArrayListTest.vala"
				_tmp32_ = gee_list_get ((GeeList*) _tmp31_, _n_index);
#line 126 "SerializableGeeArrayListTest.vala"
				n = (GXmlNode*) _tmp32_;
#line 127 "SerializableGeeArrayListTest.vala"
				_tmp34_ = n;
#line 127 "SerializableGeeArrayListTest.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp34_, GXML_TYPE_ELEMENT)) {
#line 1646 "SerializableGeeArrayListTest.c"
					GXmlNode* _tmp35_;
					gchar* _tmp36_;
					gchar* _tmp37_;
					gchar* _tmp38_;
#line 127 "SerializableGeeArrayListTest.vala"
					_tmp35_ = n;
#line 127 "SerializableGeeArrayListTest.vala"
					_tmp36_ = gxml_node_get_name (_tmp35_);
#line 127 "SerializableGeeArrayListTest.vala"
					_tmp37_ = _tmp36_;
#line 127 "SerializableGeeArrayListTest.vala"
					_tmp38_ = _tmp37_;
#line 127 "SerializableGeeArrayListTest.vala"
					_tmp33_ = g_strcmp0 (_tmp38_, "aelement") == 0;
#line 127 "SerializableGeeArrayListTest.vala"
					_g_free0 (_tmp38_);
#line 1663 "SerializableGeeArrayListTest.c"
				} else {
#line 127 "SerializableGeeArrayListTest.vala"
					_tmp33_ = FALSE;
#line 1667 "SerializableGeeArrayListTest.c"
				}
#line 127 "SerializableGeeArrayListTest.vala"
				if (_tmp33_) {
#line 1671 "SerializableGeeArrayListTest.c"
					GXmlNode* name = NULL;
					GXmlNode* _tmp39_;
					GeeMap* _tmp40_;
					GeeMap* _tmp41_;
					GeeMap* _tmp42_;
					gpointer _tmp43_;
					GXmlNode* _tmp44_;
					GXmlNode* _tmp45_;
#line 128 "SerializableGeeArrayListTest.vala"
					_tmp39_ = n;
#line 128 "SerializableGeeArrayListTest.vala"
					_tmp40_ = gxml_node_get_attrs (_tmp39_);
#line 128 "SerializableGeeArrayListTest.vala"
					_tmp41_ = _tmp40_;
#line 128 "SerializableGeeArrayListTest.vala"
					_tmp42_ = _tmp41_;
#line 128 "SerializableGeeArrayListTest.vala"
					_tmp43_ = gee_map_get (_tmp42_, "name");
#line 128 "SerializableGeeArrayListTest.vala"
					_tmp44_ = (GXmlNode*) _tmp43_;
#line 128 "SerializableGeeArrayListTest.vala"
					_g_object_unref0 (_tmp42_);
#line 128 "SerializableGeeArrayListTest.vala"
					name = _tmp44_;
#line 129 "SerializableGeeArrayListTest.vala"
					_tmp45_ = name;
#line 129 "SerializableGeeArrayListTest.vala"
					if (_tmp45_ != NULL) {
#line 1700 "SerializableGeeArrayListTest.c"
						GXmlNode* _tmp46_;
						gchar* _tmp47_;
						gchar* _tmp48_;
						gchar* _tmp49_;
						gboolean _tmp50_;
						GXmlNode* _tmp51_;
						gchar* _tmp52_;
						gchar* _tmp53_;
						gchar* _tmp54_;
						gboolean _tmp55_;
#line 130 "SerializableGeeArrayListTest.vala"
						_tmp46_ = name;
#line 130 "SerializableGeeArrayListTest.vala"
						_tmp47_ = gxml_node_get_value (_tmp46_);
#line 130 "SerializableGeeArrayListTest.vala"
						_tmp48_ = _tmp47_;
#line 130 "SerializableGeeArrayListTest.vala"
						_tmp49_ = _tmp48_;
#line 130 "SerializableGeeArrayListTest.vala"
						_tmp50_ = g_strcmp0 (_tmp49_, "Big") == 0;
#line 130 "SerializableGeeArrayListTest.vala"
						_g_free0 (_tmp49_);
#line 130 "SerializableGeeArrayListTest.vala"
						if (_tmp50_) {
#line 130 "SerializableGeeArrayListTest.vala"
							found1 = TRUE;
#line 1727 "SerializableGeeArrayListTest.c"
						}
#line 131 "SerializableGeeArrayListTest.vala"
						_tmp51_ = name;
#line 131 "SerializableGeeArrayListTest.vala"
						_tmp52_ = gxml_node_get_value (_tmp51_);
#line 131 "SerializableGeeArrayListTest.vala"
						_tmp53_ = _tmp52_;
#line 131 "SerializableGeeArrayListTest.vala"
						_tmp54_ = _tmp53_;
#line 131 "SerializableGeeArrayListTest.vala"
						_tmp55_ = g_strcmp0 (_tmp54_, "Small") == 0;
#line 131 "SerializableGeeArrayListTest.vala"
						_g_free0 (_tmp54_);
#line 131 "SerializableGeeArrayListTest.vala"
						if (_tmp55_) {
#line 131 "SerializableGeeArrayListTest.vala"
							found2 = TRUE;
#line 1745 "SerializableGeeArrayListTest.c"
						}
					}
#line 127 "SerializableGeeArrayListTest.vala"
					_g_object_unref0 (name);
#line 1750 "SerializableGeeArrayListTest.c"
				}
#line 126 "SerializableGeeArrayListTest.vala"
				_g_object_unref0 (n);
#line 1754 "SerializableGeeArrayListTest.c"
			}
#line 126 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (_n_list);
#line 1758 "SerializableGeeArrayListTest.c"
		}
#line 135 "SerializableGeeArrayListTest.vala"
		if (!found1) {
#line 1762 "SerializableGeeArrayListTest.c"
			FILE* _tmp56_;
#line 136 "SerializableGeeArrayListTest.vala"
			_tmp56_ = stdout;
#line 136 "SerializableGeeArrayListTest.vala"
			fprintf (_tmp56_, "%s", "ERROR: Big space node was not found\n");
#line 137 "SerializableGeeArrayListTest.vala"
			g_assert_not_reached ();
#line 1770 "SerializableGeeArrayListTest.c"
		}
#line 139 "SerializableGeeArrayListTest.vala"
		if (!found2) {
#line 1774 "SerializableGeeArrayListTest.c"
			FILE* _tmp57_;
#line 140 "SerializableGeeArrayListTest.vala"
			_tmp57_ = stdout;
#line 140 "SerializableGeeArrayListTest.vala"
			fprintf (_tmp57_, "%s", "ERROR: Small space node was not found\n");
#line 141 "SerializableGeeArrayListTest.vala"
			g_assert_not_reached ();
#line 1782 "SerializableGeeArrayListTest.c"
		}
#line 113 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (root);
#line 113 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (doc);
#line 113 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (o2);
#line 113 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (o1);
#line 113 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (c);
#line 1794 "SerializableGeeArrayListTest.c"
	}
	goto __finally357;
	__catch357_g_error:
	{
		GError* e = NULL;
		FILE* _tmp58_;
		const gchar* _tmp59_;
		const gchar* _tmp60_;
		gchar* _tmp61_;
		gchar* _tmp62_;
#line 113 "SerializableGeeArrayListTest.vala"
		e = _inner_error0_;
#line 113 "SerializableGeeArrayListTest.vala"
		_inner_error0_ = NULL;
#line 145 "SerializableGeeArrayListTest.vala"
		_tmp58_ = stdout;
#line 145 "SerializableGeeArrayListTest.vala"
		_tmp59_ = e->message;
#line 145 "SerializableGeeArrayListTest.vala"
		_tmp60_ = string_to_string (_tmp59_);
#line 145 "SerializableGeeArrayListTest.vala"
		_tmp61_ = g_strconcat ("ERROR: ", _tmp60_, NULL);
#line 145 "SerializableGeeArrayListTest.vala"
		_tmp62_ = _tmp61_;
#line 145 "SerializableGeeArrayListTest.vala"
		fprintf (_tmp58_, "%s", _tmp62_);
#line 145 "SerializableGeeArrayListTest.vala"
		_g_free0 (_tmp62_);
#line 146 "SerializableGeeArrayListTest.vala"
		g_assert_not_reached ();
#line 113 "SerializableGeeArrayListTest.vala"
		_g_error_free0 (e);
#line 1827 "SerializableGeeArrayListTest.c"
	}
	__finally357:
#line 113 "SerializableGeeArrayListTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 113 "SerializableGeeArrayListTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 113 "SerializableGeeArrayListTest.vala"
		g_clear_error (&_inner_error0_);
#line 113 "SerializableGeeArrayListTest.vala"
		return;
#line 1838 "SerializableGeeArrayListTest.c"
	}
}

static void
___lambda306__gtest_func (void)
{
#line 111 "SerializableGeeArrayListTest.vala"
	__lambda306_ ();
#line 1847 "SerializableGeeArrayListTest.c"
}

static void
__lambda307_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlSerializableArrayList* c = NULL;
		GXmlSerializableArrayList* _tmp1_;
		GXmlSerializableArrayList* _tmp2_;
		GXmlGDocument* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		GXmlSerializableArrayList* _tmp7_;
		gint _tmp8_;
		gint _tmp9_;
		gboolean found1 = FALSE;
		gboolean found2 = FALSE;
#line 152 "SerializableGeeArrayListTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"  <root><aelement name=\"Big\"/><aelement name=\"Small\"/></root>", 0, &_inner_error0_);
#line 152 "SerializableGeeArrayListTest.vala"
		doc = _tmp0_;
#line 152 "SerializableGeeArrayListTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1875 "SerializableGeeArrayListTest.c"
			goto __catch358_g_error;
		}
#line 154 "SerializableGeeArrayListTest.vala"
		_tmp1_ = gxml_serializable_array_list_new (TYPE_AELEMENT, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 154 "SerializableGeeArrayListTest.vala"
		c = _tmp1_;
#line 155 "SerializableGeeArrayListTest.vala"
		_tmp2_ = c;
#line 155 "SerializableGeeArrayListTest.vala"
		_tmp3_ = doc;
#line 155 "SerializableGeeArrayListTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) _tmp3_);
#line 155 "SerializableGeeArrayListTest.vala"
		_tmp5_ = _tmp4_;
#line 155 "SerializableGeeArrayListTest.vala"
		_tmp6_ = _tmp5_;
#line 155 "SerializableGeeArrayListTest.vala"
		gxml_serializable_array_list_deserialize (_tmp2_, _tmp6_, &_inner_error0_);
#line 155 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp6_);
#line 155 "SerializableGeeArrayListTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 155 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (c);
#line 155 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (doc);
#line 1902 "SerializableGeeArrayListTest.c"
			goto __catch358_g_error;
		}
#line 156 "SerializableGeeArrayListTest.vala"
		_tmp7_ = c;
#line 156 "SerializableGeeArrayListTest.vala"
		_tmp8_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp7_);
#line 156 "SerializableGeeArrayListTest.vala"
		_tmp9_ = _tmp8_;
#line 156 "SerializableGeeArrayListTest.vala"
		if (_tmp9_ != 2) {
#line 1913 "SerializableGeeArrayListTest.c"
			FILE* _tmp10_;
			GXmlSerializableArrayList* _tmp11_;
			gint _tmp12_;
			gint _tmp13_;
			gchar* _tmp14_;
			gchar* _tmp15_;
			gchar* _tmp16_;
			gchar* _tmp17_;
#line 157 "SerializableGeeArrayListTest.vala"
			_tmp10_ = stdout;
#line 157 "SerializableGeeArrayListTest.vala"
			_tmp11_ = c;
#line 157 "SerializableGeeArrayListTest.vala"
			_tmp12_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp11_);
#line 157 "SerializableGeeArrayListTest.vala"
			_tmp13_ = _tmp12_;
#line 157 "SerializableGeeArrayListTest.vala"
			_tmp14_ = g_strdup_printf ("%i", _tmp13_);
#line 157 "SerializableGeeArrayListTest.vala"
			_tmp15_ = _tmp14_;
#line 157 "SerializableGeeArrayListTest.vala"
			_tmp16_ = g_strconcat ("ERROR: incorrect size must be 2 got: ", _tmp15_, "\n", NULL);
#line 157 "SerializableGeeArrayListTest.vala"
			_tmp17_ = _tmp16_;
#line 157 "SerializableGeeArrayListTest.vala"
			fprintf (_tmp10_, "%s", _tmp17_);
#line 157 "SerializableGeeArrayListTest.vala"
			_g_free0 (_tmp17_);
#line 157 "SerializableGeeArrayListTest.vala"
			_g_free0 (_tmp15_);
#line 158 "SerializableGeeArrayListTest.vala"
			g_assert_not_reached ();
#line 1946 "SerializableGeeArrayListTest.c"
		}
#line 160 "SerializableGeeArrayListTest.vala"
		found1 = FALSE;
#line 161 "SerializableGeeArrayListTest.vala"
		found2 = FALSE;
#line 1952 "SerializableGeeArrayListTest.c"
		{
			GXmlSerializableArrayList* _o_list = NULL;
			GXmlSerializableArrayList* _tmp18_;
			GXmlSerializableArrayList* _tmp19_;
			gint _o_size = 0;
			GXmlSerializableArrayList* _tmp20_;
			gint _tmp21_;
			gint _tmp22_;
			gint _o_index = 0;
#line 162 "SerializableGeeArrayListTest.vala"
			_tmp18_ = c;
#line 162 "SerializableGeeArrayListTest.vala"
			_tmp19_ = _g_object_ref0 (_tmp18_);
#line 162 "SerializableGeeArrayListTest.vala"
			_o_list = _tmp19_;
#line 162 "SerializableGeeArrayListTest.vala"
			_tmp20_ = _o_list;
#line 162 "SerializableGeeArrayListTest.vala"
			_tmp21_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp20_);
#line 162 "SerializableGeeArrayListTest.vala"
			_tmp22_ = _tmp21_;
#line 162 "SerializableGeeArrayListTest.vala"
			_o_size = _tmp22_;
#line 162 "SerializableGeeArrayListTest.vala"
			_o_index = -1;
#line 162 "SerializableGeeArrayListTest.vala"
			while (TRUE) {
#line 1980 "SerializableGeeArrayListTest.c"
				AElement* o = NULL;
				GXmlSerializableArrayList* _tmp23_;
				gpointer _tmp24_;
				AElement* _tmp25_;
				const gchar* _tmp26_;
				const gchar* _tmp27_;
				AElement* _tmp28_;
				const gchar* _tmp29_;
				const gchar* _tmp30_;
#line 162 "SerializableGeeArrayListTest.vala"
				_o_index = _o_index + 1;
#line 162 "SerializableGeeArrayListTest.vala"
				if (!(_o_index < _o_size)) {
#line 162 "SerializableGeeArrayListTest.vala"
					break;
#line 1996 "SerializableGeeArrayListTest.c"
				}
#line 162 "SerializableGeeArrayListTest.vala"
				_tmp23_ = _o_list;
#line 162 "SerializableGeeArrayListTest.vala"
				_tmp24_ = gee_abstract_list_get ((GeeAbstractList*) _tmp23_, _o_index);
#line 162 "SerializableGeeArrayListTest.vala"
				o = (AElement*) _tmp24_;
#line 163 "SerializableGeeArrayListTest.vala"
				_tmp25_ = o;
#line 163 "SerializableGeeArrayListTest.vala"
				_tmp26_ = aelement_get_name (_tmp25_);
#line 163 "SerializableGeeArrayListTest.vala"
				_tmp27_ = _tmp26_;
#line 163 "SerializableGeeArrayListTest.vala"
				if (g_strcmp0 (_tmp27_, "Big") == 0) {
#line 163 "SerializableGeeArrayListTest.vala"
					found1 = TRUE;
#line 2014 "SerializableGeeArrayListTest.c"
				}
#line 164 "SerializableGeeArrayListTest.vala"
				_tmp28_ = o;
#line 164 "SerializableGeeArrayListTest.vala"
				_tmp29_ = aelement_get_name (_tmp28_);
#line 164 "SerializableGeeArrayListTest.vala"
				_tmp30_ = _tmp29_;
#line 164 "SerializableGeeArrayListTest.vala"
				if (g_strcmp0 (_tmp30_, "Small") == 0) {
#line 164 "SerializableGeeArrayListTest.vala"
					found2 = TRUE;
#line 2026 "SerializableGeeArrayListTest.c"
				}
#line 162 "SerializableGeeArrayListTest.vala"
				_g_object_unref0 (o);
#line 2030 "SerializableGeeArrayListTest.c"
			}
#line 162 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (_o_list);
#line 2034 "SerializableGeeArrayListTest.c"
		}
#line 166 "SerializableGeeArrayListTest.vala"
		if (!found1) {
#line 2038 "SerializableGeeArrayListTest.c"
			FILE* _tmp31_;
#line 167 "SerializableGeeArrayListTest.vala"
			_tmp31_ = stdout;
#line 167 "SerializableGeeArrayListTest.vala"
			fprintf (_tmp31_, "%s", "ERROR: Big key value is not found\n");
#line 168 "SerializableGeeArrayListTest.vala"
			g_assert_not_reached ();
#line 2046 "SerializableGeeArrayListTest.c"
		}
#line 170 "SerializableGeeArrayListTest.vala"
		if (!found2) {
#line 2050 "SerializableGeeArrayListTest.c"
			FILE* _tmp32_;
#line 171 "SerializableGeeArrayListTest.vala"
			_tmp32_ = stdout;
#line 171 "SerializableGeeArrayListTest.vala"
			fprintf (_tmp32_, "%s", "ERROR: Small key value is not found\n");
#line 172 "SerializableGeeArrayListTest.vala"
			g_assert_not_reached ();
#line 2058 "SerializableGeeArrayListTest.c"
		}
#line 151 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (c);
#line 151 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (doc);
#line 2064 "SerializableGeeArrayListTest.c"
	}
	goto __finally358;
	__catch358_g_error:
	{
		GError* e = NULL;
		FILE* _tmp33_;
		const gchar* _tmp34_;
		const gchar* _tmp35_;
		gchar* _tmp36_;
		gchar* _tmp37_;
#line 151 "SerializableGeeArrayListTest.vala"
		e = _inner_error0_;
#line 151 "SerializableGeeArrayListTest.vala"
		_inner_error0_ = NULL;
#line 176 "SerializableGeeArrayListTest.vala"
		_tmp33_ = stdout;
#line 176 "SerializableGeeArrayListTest.vala"
		_tmp34_ = e->message;
#line 176 "SerializableGeeArrayListTest.vala"
		_tmp35_ = string_to_string (_tmp34_);
#line 176 "SerializableGeeArrayListTest.vala"
		_tmp36_ = g_strconcat ("ERROR: ", _tmp35_, NULL);
#line 176 "SerializableGeeArrayListTest.vala"
		_tmp37_ = _tmp36_;
#line 176 "SerializableGeeArrayListTest.vala"
		fprintf (_tmp33_, "%s", _tmp37_);
#line 176 "SerializableGeeArrayListTest.vala"
		_g_free0 (_tmp37_);
#line 177 "SerializableGeeArrayListTest.vala"
		g_assert_not_reached ();
#line 151 "SerializableGeeArrayListTest.vala"
		_g_error_free0 (e);
#line 2097 "SerializableGeeArrayListTest.c"
	}
	__finally358:
#line 151 "SerializableGeeArrayListTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 151 "SerializableGeeArrayListTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 151 "SerializableGeeArrayListTest.vala"
		g_clear_error (&_inner_error0_);
#line 151 "SerializableGeeArrayListTest.vala"
		return;
#line 2108 "SerializableGeeArrayListTest.c"
	}
}

static void
___lambda307__gtest_func (void)
{
#line 149 "SerializableGeeArrayListTest.vala"
	__lambda307_ ();
#line 2117 "SerializableGeeArrayListTest.c"
}

static void
__lambda308_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* idoc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlNode* iroot = NULL;
		GXmlGDocument* _tmp1_;
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlSerializableArrayList* ic = NULL;
		GXmlSerializableArrayList* _tmp4_;
		GXmlSerializableArrayList* _tmp5_;
		GXmlNode* _tmp6_;
		GXmlTDocument* doc = NULL;
		GXmlTDocument* _tmp7_;
		GXmlNode* root = NULL;
		GXmlTDocument* _tmp8_;
		GXmlNode* _tmp9_;
		GXmlTDocument* _tmp10_;
		GeeBidirList* _tmp11_;
		GeeBidirList* _tmp12_;
		GeeBidirList* _tmp13_;
		GXmlNode* _tmp14_;
		GXmlSerializableArrayList* _tmp15_;
		GXmlNode* _tmp16_;
		GXmlNode* _tmp17_;
		GXmlNode* _tmp18_;
		GXmlSerializableArrayList* c = NULL;
		GXmlSerializableArrayList* _tmp19_;
		GXmlSerializableArrayList* _tmp20_;
		GXmlNode* _tmp21_;
		GXmlSerializableArrayList* _tmp22_;
		gint _tmp23_;
		gint _tmp24_;
		gint count_elements = 0;
		gchar** s = NULL;
		gchar* _tmp34_;
		gchar* _tmp35_;
		gchar* _tmp36_;
		gchar** _tmp37_;
		gint s_length1;
		gint _s_size_;
#line 183 "SerializableGeeArrayListTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"    <root>\n" \
"      <aelement name=\"Big\"/>\n" \
"      <aelement name=\"Small\"/>\n" \
"      <aelement name=\"Wall\">FAKE1</aelement>\n" \
"    </root>", 0, &_inner_error0_);
#line 183 "SerializableGeeArrayListTest.vala"
		idoc = _tmp0_;
#line 183 "SerializableGeeArrayListTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2170 "SerializableGeeArrayListTest.c"
			goto __catch359_g_error;
		}
#line 189 "SerializableGeeArrayListTest.vala"
		_tmp1_ = idoc;
#line 189 "SerializableGeeArrayListTest.vala"
		_tmp2_ = gxml_document_get_root ((GXmlDocument*) _tmp1_);
#line 189 "SerializableGeeArrayListTest.vala"
		_tmp3_ = _tmp2_;
#line 189 "SerializableGeeArrayListTest.vala"
		iroot = _tmp3_;
#line 190 "SerializableGeeArrayListTest.vala"
		_tmp4_ = gxml_serializable_array_list_new (TYPE_AELEMENT, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 190 "SerializableGeeArrayListTest.vala"
		ic = _tmp4_;
#line 191 "SerializableGeeArrayListTest.vala"
		_tmp5_ = ic;
#line 191 "SerializableGeeArrayListTest.vala"
		_tmp6_ = iroot;
#line 191 "SerializableGeeArrayListTest.vala"
		gxml_serializable_array_list_deserialize (_tmp5_, _tmp6_, &_inner_error0_);
#line 191 "SerializableGeeArrayListTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 191 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (ic);
#line 191 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (iroot);
#line 191 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (idoc);
#line 2199 "SerializableGeeArrayListTest.c"
			goto __catch359_g_error;
		}
#line 192 "SerializableGeeArrayListTest.vala"
		_tmp7_ = gxml_tdocument_new ();
#line 192 "SerializableGeeArrayListTest.vala"
		doc = _tmp7_;
#line 193 "SerializableGeeArrayListTest.vala"
		_tmp8_ = doc;
#line 193 "SerializableGeeArrayListTest.vala"
		_tmp9_ = gxml_document_create_element ((GXmlDocument*) _tmp8_, "root", &_inner_error0_);
#line 193 "SerializableGeeArrayListTest.vala"
		root = _tmp9_;
#line 193 "SerializableGeeArrayListTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 193 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (doc);
#line 193 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (ic);
#line 193 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (iroot);
#line 193 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (idoc);
#line 2222 "SerializableGeeArrayListTest.c"
			goto __catch359_g_error;
		}
#line 194 "SerializableGeeArrayListTest.vala"
		_tmp10_ = doc;
#line 194 "SerializableGeeArrayListTest.vala"
		_tmp11_ = gxml_tnode_get_children_nodes ((GXmlTNode*) _tmp10_);
#line 194 "SerializableGeeArrayListTest.vala"
		_tmp12_ = _tmp11_;
#line 194 "SerializableGeeArrayListTest.vala"
		_tmp13_ = _tmp12_;
#line 194 "SerializableGeeArrayListTest.vala"
		_tmp14_ = root;
#line 194 "SerializableGeeArrayListTest.vala"
		gee_collection_add ((GeeCollection*) _tmp13_, _tmp14_);
#line 194 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp13_);
#line 195 "SerializableGeeArrayListTest.vala"
		_tmp15_ = ic;
#line 195 "SerializableGeeArrayListTest.vala"
		_tmp16_ = root;
#line 195 "SerializableGeeArrayListTest.vala"
		_tmp17_ = gxml_serializable_array_list_serialize (_tmp15_, _tmp16_, &_inner_error0_);
#line 195 "SerializableGeeArrayListTest.vala"
		_tmp18_ = _tmp17_;
#line 195 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp18_);
#line 195 "SerializableGeeArrayListTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 195 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (root);
#line 195 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (doc);
#line 195 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (ic);
#line 195 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (iroot);
#line 195 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (idoc);
#line 2261 "SerializableGeeArrayListTest.c"
			goto __catch359_g_error;
		}
#line 196 "SerializableGeeArrayListTest.vala"
		_tmp19_ = gxml_serializable_array_list_new (TYPE_AELEMENT, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 196 "SerializableGeeArrayListTest.vala"
		c = _tmp19_;
#line 197 "SerializableGeeArrayListTest.vala"
		_tmp20_ = c;
#line 197 "SerializableGeeArrayListTest.vala"
		_tmp21_ = root;
#line 197 "SerializableGeeArrayListTest.vala"
		gxml_serializable_array_list_deserialize (_tmp20_, _tmp21_, &_inner_error0_);
#line 197 "SerializableGeeArrayListTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 197 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (c);
#line 197 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (root);
#line 197 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (doc);
#line 197 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (ic);
#line 197 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (iroot);
#line 197 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (idoc);
#line 2288 "SerializableGeeArrayListTest.c"
			goto __catch359_g_error;
		}
#line 198 "SerializableGeeArrayListTest.vala"
		_tmp22_ = c;
#line 198 "SerializableGeeArrayListTest.vala"
		_tmp23_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp22_);
#line 198 "SerializableGeeArrayListTest.vala"
		_tmp24_ = _tmp23_;
#line 198 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp24_ == 3, "c.size == 3");
#line 199 "SerializableGeeArrayListTest.vala"
		count_elements = 0;
#line 2301 "SerializableGeeArrayListTest.c"
		{
			GXmlSerializableArrayList* _e_list = NULL;
			GXmlSerializableArrayList* _tmp25_;
			GXmlSerializableArrayList* _tmp26_;
			gint _e_size = 0;
			GXmlSerializableArrayList* _tmp27_;
			gint _tmp28_;
			gint _tmp29_;
			gint _e_index = 0;
#line 200 "SerializableGeeArrayListTest.vala"
			_tmp25_ = c;
#line 200 "SerializableGeeArrayListTest.vala"
			_tmp26_ = _g_object_ref0 (_tmp25_);
#line 200 "SerializableGeeArrayListTest.vala"
			_e_list = _tmp26_;
#line 200 "SerializableGeeArrayListTest.vala"
			_tmp27_ = _e_list;
#line 200 "SerializableGeeArrayListTest.vala"
			_tmp28_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp27_);
#line 200 "SerializableGeeArrayListTest.vala"
			_tmp29_ = _tmp28_;
#line 200 "SerializableGeeArrayListTest.vala"
			_e_size = _tmp29_;
#line 200 "SerializableGeeArrayListTest.vala"
			_e_index = -1;
#line 200 "SerializableGeeArrayListTest.vala"
			while (TRUE) {
#line 2329 "SerializableGeeArrayListTest.c"
				AElement* e = NULL;
				GXmlSerializableArrayList* _tmp30_;
				gpointer _tmp31_;
				AElement* _tmp32_;
				gint _tmp33_;
#line 200 "SerializableGeeArrayListTest.vala"
				_e_index = _e_index + 1;
#line 200 "SerializableGeeArrayListTest.vala"
				if (!(_e_index < _e_size)) {
#line 200 "SerializableGeeArrayListTest.vala"
					break;
#line 2341 "SerializableGeeArrayListTest.c"
				}
#line 200 "SerializableGeeArrayListTest.vala"
				_tmp30_ = _e_list;
#line 200 "SerializableGeeArrayListTest.vala"
				_tmp31_ = gee_abstract_list_get ((GeeAbstractList*) _tmp30_, _e_index);
#line 200 "SerializableGeeArrayListTest.vala"
				e = (AElement*) _tmp31_;
#line 201 "SerializableGeeArrayListTest.vala"
				_tmp32_ = e;
#line 201 "SerializableGeeArrayListTest.vala"
				_vala_assert (_tmp32_ != NULL, "e != null");
#line 202 "SerializableGeeArrayListTest.vala"
				_tmp33_ = count_elements;
#line 202 "SerializableGeeArrayListTest.vala"
				count_elements = _tmp33_ + 1;
#line 200 "SerializableGeeArrayListTest.vala"
				_g_object_unref0 (e);
#line 2359 "SerializableGeeArrayListTest.c"
			}
#line 200 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (_e_list);
#line 2363 "SerializableGeeArrayListTest.c"
		}
#line 204 "SerializableGeeArrayListTest.vala"
		_vala_assert (count_elements == 3, "count_elements == 3");
#line 205 "SerializableGeeArrayListTest.vala"
		_tmp34_ = g_strdup ("Big");
#line 205 "SerializableGeeArrayListTest.vala"
		_tmp35_ = g_strdup ("Small");
#line 205 "SerializableGeeArrayListTest.vala"
		_tmp36_ = g_strdup ("Wall");
#line 205 "SerializableGeeArrayListTest.vala"
		_tmp37_ = g_new0 (gchar*, 3 + 1);
#line 205 "SerializableGeeArrayListTest.vala"
		_tmp37_[0] = _tmp34_;
#line 205 "SerializableGeeArrayListTest.vala"
		_tmp37_[1] = _tmp35_;
#line 205 "SerializableGeeArrayListTest.vala"
		_tmp37_[2] = _tmp36_;
#line 205 "SerializableGeeArrayListTest.vala"
		s = _tmp37_;
#line 205 "SerializableGeeArrayListTest.vala"
		s_length1 = 3;
#line 205 "SerializableGeeArrayListTest.vala"
		_s_size_ = s_length1;
#line 2387 "SerializableGeeArrayListTest.c"
		{
			gint j = 0;
#line 214 "SerializableGeeArrayListTest.vala"
			j = 0;
#line 2392 "SerializableGeeArrayListTest.c"
			{
				gboolean _tmp38_ = FALSE;
#line 214 "SerializableGeeArrayListTest.vala"
				_tmp38_ = TRUE;
#line 214 "SerializableGeeArrayListTest.vala"
				while (TRUE) {
#line 2399 "SerializableGeeArrayListTest.c"
					GXmlSerializableArrayList* _tmp40_;
					gint _tmp41_;
					gint _tmp42_;
					gchar** _tmp43_;
					gint _tmp43__length1;
					const gchar* _tmp44_;
					GXmlSerializableArrayList* _tmp45_;
					gpointer _tmp46_;
					AElement* _tmp47_;
					const gchar* _tmp48_;
					const gchar* _tmp49_;
#line 214 "SerializableGeeArrayListTest.vala"
					if (!_tmp38_) {
#line 2413 "SerializableGeeArrayListTest.c"
						gint _tmp39_;
#line 214 "SerializableGeeArrayListTest.vala"
						_tmp39_ = j;
#line 214 "SerializableGeeArrayListTest.vala"
						j = _tmp39_ + 1;
#line 2419 "SerializableGeeArrayListTest.c"
					}
#line 214 "SerializableGeeArrayListTest.vala"
					_tmp38_ = FALSE;
#line 214 "SerializableGeeArrayListTest.vala"
					_tmp40_ = c;
#line 214 "SerializableGeeArrayListTest.vala"
					_tmp41_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp40_);
#line 214 "SerializableGeeArrayListTest.vala"
					_tmp42_ = _tmp41_;
#line 214 "SerializableGeeArrayListTest.vala"
					if (!(j < _tmp42_)) {
#line 214 "SerializableGeeArrayListTest.vala"
						break;
#line 2433 "SerializableGeeArrayListTest.c"
					}
#line 215 "SerializableGeeArrayListTest.vala"
					_tmp43_ = s;
#line 215 "SerializableGeeArrayListTest.vala"
					_tmp43__length1 = s_length1;
#line 215 "SerializableGeeArrayListTest.vala"
					_tmp44_ = _tmp43_[j];
#line 215 "SerializableGeeArrayListTest.vala"
					_tmp45_ = c;
#line 215 "SerializableGeeArrayListTest.vala"
					_tmp46_ = gee_abstract_list_get ((GeeAbstractList*) _tmp45_, j);
#line 215 "SerializableGeeArrayListTest.vala"
					_tmp47_ = (AElement*) _tmp46_;
#line 215 "SerializableGeeArrayListTest.vala"
					_tmp48_ = aelement_get_name (_tmp47_);
#line 215 "SerializableGeeArrayListTest.vala"
					_tmp49_ = _tmp48_;
#line 215 "SerializableGeeArrayListTest.vala"
					_vala_assert (g_strcmp0 (_tmp44_, _tmp49_) == 0, "s[j] == c.get (j).name");
#line 215 "SerializableGeeArrayListTest.vala"
					_g_object_unref0 (_tmp47_);
#line 2455 "SerializableGeeArrayListTest.c"
				}
			}
		}
#line 182 "SerializableGeeArrayListTest.vala"
		s = (_vala_array_free (s, s_length1, (GDestroyNotify) g_free), NULL);
#line 182 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (c);
#line 182 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (root);
#line 182 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (doc);
#line 182 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (ic);
#line 182 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (iroot);
#line 182 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (idoc);
#line 2473 "SerializableGeeArrayListTest.c"
	}
	goto __finally359;
	__catch359_g_error:
	{
		GError* e = NULL;
		FILE* _tmp50_;
		const gchar* _tmp51_;
		const gchar* _tmp52_;
		gchar* _tmp53_;
		gchar* _tmp54_;
#line 182 "SerializableGeeArrayListTest.vala"
		e = _inner_error0_;
#line 182 "SerializableGeeArrayListTest.vala"
		_inner_error0_ = NULL;
#line 219 "SerializableGeeArrayListTest.vala"
		_tmp50_ = stdout;
#line 219 "SerializableGeeArrayListTest.vala"
		_tmp51_ = e->message;
#line 219 "SerializableGeeArrayListTest.vala"
		_tmp52_ = string_to_string (_tmp51_);
#line 219 "SerializableGeeArrayListTest.vala"
		_tmp53_ = g_strconcat ("ERROR: ", _tmp52_, NULL);
#line 219 "SerializableGeeArrayListTest.vala"
		_tmp54_ = _tmp53_;
#line 219 "SerializableGeeArrayListTest.vala"
		fprintf (_tmp50_, "%s", _tmp54_);
#line 219 "SerializableGeeArrayListTest.vala"
		_g_free0 (_tmp54_);
#line 220 "SerializableGeeArrayListTest.vala"
		g_assert_not_reached ();
#line 182 "SerializableGeeArrayListTest.vala"
		_g_error_free0 (e);
#line 2506 "SerializableGeeArrayListTest.c"
	}
	__finally359:
#line 182 "SerializableGeeArrayListTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 182 "SerializableGeeArrayListTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 182 "SerializableGeeArrayListTest.vala"
		g_clear_error (&_inner_error0_);
#line 182 "SerializableGeeArrayListTest.vala"
		return;
#line 2517 "SerializableGeeArrayListTest.c"
	}
}

static void
___lambda308__gtest_func (void)
{
#line 180 "SerializableGeeArrayListTest.vala"
	__lambda308_ ();
#line 2526 "SerializableGeeArrayListTest.c"
}

static void
__lambda309_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* d = NULL;
		GXmlGDocument* _tmp0_;
		BookStore* bs = NULL;
		BookStore* _tmp1_;
		BookStore* _tmp2_;
		GXmlGDocument* _tmp3_;
		BookStore* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		BookStore* _tmp7_;
		BookArray* _tmp8_;
		BookArray* _tmp9_;
		gint _tmp10_;
		gint _tmp11_;
		Book* b = NULL;
		BookStore* _tmp12_;
		BookArray* _tmp13_;
		BookArray* _tmp14_;
		gpointer _tmp15_;
		Name* _tmp16_;
		Name* _tmp17_;
		Name* _tmp18_;
		Name* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		const gchar* _tmp22_;
		const gchar* _tmp23_;
		Authors* _tmp24_;
		Authors* _tmp25_;
		Authors* _tmp26_;
		Authors* _tmp27_;
		AuthorArray* _tmp28_;
		AuthorArray* _tmp29_;
		Authors* _tmp30_;
		Authors* _tmp31_;
		AuthorArray* _tmp32_;
		AuthorArray* _tmp33_;
		gint _tmp34_;
		gint _tmp35_;
		Author* a = NULL;
		Authors* _tmp36_;
		Authors* _tmp37_;
		AuthorArray* _tmp38_;
		AuthorArray* _tmp39_;
		gpointer _tmp40_;
		Name* _tmp41_;
		Name* _tmp42_;
		Name* _tmp43_;
		Name* _tmp44_;
		gchar* _tmp45_;
		gchar* _tmp46_;
		Email* _tmp47_;
		Email* _tmp48_;
		Email* _tmp49_;
		Email* _tmp50_;
		gchar* _tmp51_;
		gchar* _tmp52_;
#line 226 "SerializableGeeArrayListTest.vala"
		_tmp0_ = gxml_gdocument_new_from_path (TEST_DIR "/test-collection.xml", 0, &_inner_error0_);
#line 226 "SerializableGeeArrayListTest.vala"
		d = _tmp0_;
#line 226 "SerializableGeeArrayListTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2597 "SerializableGeeArrayListTest.c"
			goto __catch360_g_error;
		}
#line 227 "SerializableGeeArrayListTest.vala"
		_tmp1_ = book_store_new ();
#line 227 "SerializableGeeArrayListTest.vala"
		bs = _tmp1_;
#line 228 "SerializableGeeArrayListTest.vala"
		_tmp2_ = bs;
#line 228 "SerializableGeeArrayListTest.vala"
		_tmp3_ = d;
#line 228 "SerializableGeeArrayListTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 228 "SerializableGeeArrayListTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 228 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (bs);
#line 228 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (d);
#line 2616 "SerializableGeeArrayListTest.c"
			goto __catch360_g_error;
		}
#line 229 "SerializableGeeArrayListTest.vala"
		_tmp4_ = bs;
#line 229 "SerializableGeeArrayListTest.vala"
		_tmp5_ = book_store_get_name (_tmp4_);
#line 229 "SerializableGeeArrayListTest.vala"
		_tmp6_ = _tmp5_;
#line 229 "SerializableGeeArrayListTest.vala"
		_vala_assert (g_strcmp0 (_tmp6_, "The Great Book") == 0, "bs.name == \"The Great Book\"");
#line 230 "SerializableGeeArrayListTest.vala"
		_tmp7_ = bs;
#line 230 "SerializableGeeArrayListTest.vala"
		_tmp8_ = book_store_get_books (_tmp7_);
#line 230 "SerializableGeeArrayListTest.vala"
		_tmp9_ = _tmp8_;
#line 230 "SerializableGeeArrayListTest.vala"
		_tmp10_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp9_);
#line 230 "SerializableGeeArrayListTest.vala"
		_tmp11_ = _tmp10_;
#line 230 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp11_ == 3, "bs.books.size == 3");
#line 231 "SerializableGeeArrayListTest.vala"
		_tmp12_ = bs;
#line 231 "SerializableGeeArrayListTest.vala"
		_tmp13_ = book_store_get_books (_tmp12_);
#line 231 "SerializableGeeArrayListTest.vala"
		_tmp14_ = _tmp13_;
#line 231 "SerializableGeeArrayListTest.vala"
		_tmp15_ = gee_list_first ((GeeList*) _tmp14_);
#line 231 "SerializableGeeArrayListTest.vala"
		b = (Book*) _tmp15_;
#line 232 "SerializableGeeArrayListTest.vala"
		_vala_assert (b != NULL, "b != null");
#line 233 "SerializableGeeArrayListTest.vala"
		_tmp16_ = book_get_name (b);
#line 233 "SerializableGeeArrayListTest.vala"
		_tmp17_ = _tmp16_;
#line 233 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp17_ != NULL, "b.name != null");
#line 234 "SerializableGeeArrayListTest.vala"
		_tmp18_ = book_get_name (b);
#line 234 "SerializableGeeArrayListTest.vala"
		_tmp19_ = _tmp18_;
#line 234 "SerializableGeeArrayListTest.vala"
		_tmp20_ = name_get_name (_tmp19_);
#line 234 "SerializableGeeArrayListTest.vala"
		_tmp21_ = _tmp20_;
#line 234 "SerializableGeeArrayListTest.vala"
		_vala_assert (g_strcmp0 (_tmp21_, "Book1") == 0, "b.name.get_name () == \"Book1\"");
#line 234 "SerializableGeeArrayListTest.vala"
		_g_free0 (_tmp21_);
#line 235 "SerializableGeeArrayListTest.vala"
		_tmp22_ = book_get_year (b);
#line 235 "SerializableGeeArrayListTest.vala"
		_tmp23_ = _tmp22_;
#line 235 "SerializableGeeArrayListTest.vala"
		_vala_assert (g_strcmp0 (_tmp23_, "2015") == 0, "b.year == \"2015\"");
#line 236 "SerializableGeeArrayListTest.vala"
		_tmp24_ = book_get_authors (b);
#line 236 "SerializableGeeArrayListTest.vala"
		_tmp25_ = _tmp24_;
#line 236 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp25_ != NULL, "b.authors != null");
#line 237 "SerializableGeeArrayListTest.vala"
		_tmp26_ = book_get_authors (b);
#line 237 "SerializableGeeArrayListTest.vala"
		_tmp27_ = _tmp26_;
#line 237 "SerializableGeeArrayListTest.vala"
		_tmp28_ = authors_get_array (_tmp27_);
#line 237 "SerializableGeeArrayListTest.vala"
		_tmp29_ = _tmp28_;
#line 237 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp29_ != NULL, "b.authors.array != null");
#line 238 "SerializableGeeArrayListTest.vala"
		_tmp30_ = book_get_authors (b);
#line 238 "SerializableGeeArrayListTest.vala"
		_tmp31_ = _tmp30_;
#line 238 "SerializableGeeArrayListTest.vala"
		_tmp32_ = authors_get_array (_tmp31_);
#line 238 "SerializableGeeArrayListTest.vala"
		_tmp33_ = _tmp32_;
#line 238 "SerializableGeeArrayListTest.vala"
		_tmp34_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp33_);
#line 238 "SerializableGeeArrayListTest.vala"
		_tmp35_ = _tmp34_;
#line 238 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp35_ == 2, "b.authors.array.size == 2");
#line 239 "SerializableGeeArrayListTest.vala"
		_tmp36_ = book_get_authors (b);
#line 239 "SerializableGeeArrayListTest.vala"
		_tmp37_ = _tmp36_;
#line 239 "SerializableGeeArrayListTest.vala"
		_tmp38_ = authors_get_array (_tmp37_);
#line 239 "SerializableGeeArrayListTest.vala"
		_tmp39_ = _tmp38_;
#line 239 "SerializableGeeArrayListTest.vala"
		_tmp40_ = gee_list_first ((GeeList*) _tmp39_);
#line 239 "SerializableGeeArrayListTest.vala"
		a = (Author*) _tmp40_;
#line 240 "SerializableGeeArrayListTest.vala"
		_vala_assert (a != NULL, "a != null");
#line 241 "SerializableGeeArrayListTest.vala"
		_tmp41_ = author_get_name (a);
#line 241 "SerializableGeeArrayListTest.vala"
		_tmp42_ = _tmp41_;
#line 241 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp42_ != NULL, "a.name != null");
#line 242 "SerializableGeeArrayListTest.vala"
		_tmp43_ = author_get_name (a);
#line 242 "SerializableGeeArrayListTest.vala"
		_tmp44_ = _tmp43_;
#line 242 "SerializableGeeArrayListTest.vala"
		_tmp45_ = name_get_name (_tmp44_);
#line 242 "SerializableGeeArrayListTest.vala"
		_tmp46_ = _tmp45_;
#line 242 "SerializableGeeArrayListTest.vala"
		_vala_assert (g_strcmp0 (_tmp46_, "Fred") == 0, "a.name.get_name () == \"Fred\"");
#line 242 "SerializableGeeArrayListTest.vala"
		_g_free0 (_tmp46_);
#line 243 "SerializableGeeArrayListTest.vala"
		_tmp47_ = author_get_email (a);
#line 243 "SerializableGeeArrayListTest.vala"
		_tmp48_ = _tmp47_;
#line 243 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp48_ != NULL, "a.email != null");
#line 244 "SerializableGeeArrayListTest.vala"
		_tmp49_ = author_get_email (a);
#line 244 "SerializableGeeArrayListTest.vala"
		_tmp50_ = _tmp49_;
#line 244 "SerializableGeeArrayListTest.vala"
		_tmp51_ = email_get_mail (_tmp50_);
#line 244 "SerializableGeeArrayListTest.vala"
		_tmp52_ = _tmp51_;
#line 244 "SerializableGeeArrayListTest.vala"
		_vala_assert (g_strcmp0 (_tmp52_, "fweasley@hogwarts.co.uk") == 0, "a.email.get_mail () == \"fweasley@hogwarts.co.uk\"");
#line 244 "SerializableGeeArrayListTest.vala"
		_g_free0 (_tmp52_);
#line 225 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (a);
#line 225 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (b);
#line 225 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (bs);
#line 225 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (d);
#line 2763 "SerializableGeeArrayListTest.c"
	}
	goto __finally360;
	__catch360_g_error:
	{
		GError* e = NULL;
#line 225 "SerializableGeeArrayListTest.vala"
		e = _inner_error0_;
#line 225 "SerializableGeeArrayListTest.vala"
		_inner_error0_ = NULL;
#line 249 "SerializableGeeArrayListTest.vala"
		g_assert_not_reached ();
#line 225 "SerializableGeeArrayListTest.vala"
		_g_error_free0 (e);
#line 2777 "SerializableGeeArrayListTest.c"
	}
	__finally360:
#line 225 "SerializableGeeArrayListTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 225 "SerializableGeeArrayListTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 225 "SerializableGeeArrayListTest.vala"
		g_clear_error (&_inner_error0_);
#line 225 "SerializableGeeArrayListTest.vala"
		return;
#line 2788 "SerializableGeeArrayListTest.c"
	}
}

static void
___lambda309__gtest_func (void)
{
#line 223 "SerializableGeeArrayListTest.vala"
	__lambda309_ ();
#line 2797 "SerializableGeeArrayListTest.c"
}

static void
__lambda310_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		SerializableGeeArrayListTestBigBag* bag = NULL;
		SerializableGeeArrayListTestBigBag* _tmp0_;
		SerializableGeeArrayListTestBigBag* _tmp1_;
		SerializableGeeArrayListTestSmallBagArray* _tmp2_;
		SerializableGeeArrayListTestSmallBagArray* _tmp3_;
		SerializableGeeArrayListTestBigBag* _tmp32_;
		SerializableGeeArrayListTestSmallBagArray* _tmp33_;
		SerializableGeeArrayListTestSmallBagArray* _tmp34_;
		gint _tmp35_;
		gint _tmp36_;
		GXmlGDocument* d = NULL;
		GXmlGDocument* _tmp37_;
		SerializableGeeArrayListTestBigBag* _tmp38_;
		GXmlGDocument* _tmp39_;
		GXmlNode* _tmp40_;
		GXmlNode* _tmp41_;
		GXmlGDocument* _tmp42_;
		GXmlNode* _tmp43_;
		GXmlNode* _tmp44_;
		GXmlNode* _tmp45_;
		GXmlGDocument* _tmp46_;
		GXmlNode* _tmp47_;
		GXmlNode* _tmp48_;
		GXmlNode* _tmp49_;
		gchar* _tmp50_;
		gchar* _tmp51_;
		gchar* _tmp52_;
		GXmlGDocument* _tmp53_;
		GXmlNode* _tmp54_;
		GXmlNode* _tmp55_;
		GXmlNode* _tmp56_;
		GeeBidirList* _tmp57_;
		GeeBidirList* _tmp58_;
		GeeBidirList* _tmp59_;
		gint _tmp60_;
		gint _tmp61_;
		GXmlGDocument* _tmp62_;
		GXmlNode* _tmp63_;
		GXmlNode* _tmp64_;
		GXmlNode* _tmp65_;
		GeeBidirList* _tmp66_;
		GeeBidirList* _tmp67_;
		GeeBidirList* _tmp68_;
		gpointer _tmp69_;
		GXmlNode* _tmp70_;
		gchar* _tmp71_;
		gchar* _tmp72_;
		gchar* _tmp73_;
		GXmlGDocument* _tmp74_;
		GXmlNode* _tmp75_;
		GXmlNode* _tmp76_;
		GXmlNode* _tmp77_;
		GeeBidirList* _tmp78_;
		GeeBidirList* _tmp79_;
		GeeBidirList* _tmp80_;
		gpointer _tmp81_;
		GXmlNode* _tmp82_;
		GeeBidirList* _tmp83_;
		GeeBidirList* _tmp84_;
		GeeBidirList* _tmp85_;
		gint _tmp86_;
		gint _tmp87_;
		GXmlGDocument* _tmp88_;
		GXmlNode* _tmp89_;
		GXmlNode* _tmp90_;
		GXmlNode* _tmp91_;
		GeeBidirList* _tmp92_;
		GeeBidirList* _tmp93_;
		GeeBidirList* _tmp94_;
		gpointer _tmp95_;
		GXmlNode* _tmp96_;
		GeeBidirList* _tmp97_;
		GeeBidirList* _tmp98_;
		GeeBidirList* _tmp99_;
		gpointer _tmp100_;
		GXmlNode* _tmp101_;
		gchar* _tmp102_;
		gchar* _tmp103_;
		gchar* _tmp104_;
		GXmlGDocument* _tmp105_;
		GXmlNode* _tmp106_;
		GXmlNode* _tmp107_;
		GXmlNode* _tmp108_;
		GeeBidirList* _tmp109_;
		GeeBidirList* _tmp110_;
		GeeBidirList* _tmp111_;
		gpointer _tmp112_;
		GXmlNode* _tmp113_;
		GeeBidirList* _tmp114_;
		GeeBidirList* _tmp115_;
		GeeBidirList* _tmp116_;
		gpointer _tmp117_;
		GXmlNode* _tmp118_;
		GeeBidirList* _tmp119_;
		GeeBidirList* _tmp120_;
		GeeBidirList* _tmp121_;
		gint _tmp122_;
		gint _tmp123_;
		GXmlGDocument* _tmp124_;
		GXmlNode* _tmp125_;
		GXmlNode* _tmp126_;
		GXmlNode* _tmp127_;
		GeeBidirList* _tmp128_;
		GeeBidirList* _tmp129_;
		GeeBidirList* _tmp130_;
		gpointer _tmp131_;
		GXmlNode* _tmp132_;
		GeeBidirList* _tmp133_;
		GeeBidirList* _tmp134_;
		GeeBidirList* _tmp135_;
		gpointer _tmp136_;
		GXmlNode* _tmp137_;
		GeeBidirList* _tmp138_;
		GeeBidirList* _tmp139_;
		GeeBidirList* _tmp140_;
		gpointer _tmp141_;
		GXmlNode* _tmp142_;
		gchar* _tmp143_;
		gchar* _tmp144_;
		gchar* _tmp145_;
		GXmlGDocument* _tmp146_;
		GXmlNode* _tmp147_;
		GXmlNode* _tmp148_;
		GXmlNode* _tmp149_;
		GeeBidirList* _tmp150_;
		GeeBidirList* _tmp151_;
		GeeBidirList* _tmp152_;
		gpointer _tmp153_;
		GXmlNode* _tmp154_;
		GeeBidirList* _tmp155_;
		GeeBidirList* _tmp156_;
		GeeBidirList* _tmp157_;
		gpointer _tmp158_;
		GXmlNode* _tmp159_;
		GeeBidirList* _tmp160_;
		GeeBidirList* _tmp161_;
		GeeBidirList* _tmp162_;
		gpointer _tmp163_;
		GXmlNode* _tmp164_;
		GeeBidirList* _tmp165_;
		GeeBidirList* _tmp166_;
		GeeBidirList* _tmp167_;
		gint _tmp168_;
		gint _tmp169_;
		GXmlGDocument* _tmp170_;
		GXmlNode* _tmp171_;
		GXmlNode* _tmp172_;
		GXmlNode* _tmp173_;
		GeeBidirList* _tmp174_;
		GeeBidirList* _tmp175_;
		GeeBidirList* _tmp176_;
		gpointer _tmp177_;
		GXmlNode* _tmp178_;
		GeeBidirList* _tmp179_;
		GeeBidirList* _tmp180_;
		GeeBidirList* _tmp181_;
		gpointer _tmp182_;
		GXmlNode* _tmp183_;
		GeeBidirList* _tmp184_;
		GeeBidirList* _tmp185_;
		GeeBidirList* _tmp186_;
		gpointer _tmp187_;
		GXmlNode* _tmp188_;
		GeeBidirList* _tmp189_;
		GeeBidirList* _tmp190_;
		GeeBidirList* _tmp191_;
		gpointer _tmp192_;
		GXmlNode* _tmp193_;
		GXmlGDocument* _tmp194_;
		GXmlNode* _tmp195_;
		GXmlNode* _tmp196_;
		GXmlNode* _tmp197_;
		GeeBidirList* _tmp198_;
		GeeBidirList* _tmp199_;
		GeeBidirList* _tmp200_;
		gpointer _tmp201_;
		GXmlNode* _tmp202_;
		GeeBidirList* _tmp203_;
		GeeBidirList* _tmp204_;
		GeeBidirList* _tmp205_;
		gpointer _tmp206_;
		GXmlNode* _tmp207_;
		GeeBidirList* _tmp208_;
		GeeBidirList* _tmp209_;
		GeeBidirList* _tmp210_;
		gpointer _tmp211_;
		GXmlNode* _tmp212_;
		GeeBidirList* _tmp213_;
		GeeBidirList* _tmp214_;
		GeeBidirList* _tmp215_;
		gpointer _tmp216_;
		GXmlNode* _tmp217_;
		gchar* _tmp218_;
		gchar* _tmp219_;
		gchar* _tmp220_;
		SerializableGeeArrayListTestBigBag* bagt = NULL;
		SerializableGeeArrayListTestBigBag* _tmp221_;
		SerializableGeeArrayListTestBigBag* _tmp222_;
		GXmlGDocument* _tmp223_;
		gboolean _tmp224_ = FALSE;
		SerializableGeeArrayListTestBigBag* _tmp225_;
		SerializableGeeArrayListTestSmallBagArray* _tmp226_;
		SerializableGeeArrayListTestSmallBagArray* _tmp227_;
		SerializableGeeArrayListTestBigBag* _tmp228_;
		SerializableGeeArrayListTestSmallBagArray* _tmp229_;
		SerializableGeeArrayListTestSmallBagArray* _tmp230_;
		gint _tmp231_;
		gint _tmp232_;
		gboolean _tmp233_ = FALSE;
		SerializableGeeArrayListTestBigBag* _tmp234_;
		SerializableGeeArrayListTestSmallBagArray* _tmp235_;
		SerializableGeeArrayListTestSmallBagArray* _tmp236_;
		gpointer _tmp237_;
		SerializableGeeArrayListTestSmallBag* _tmp238_;
		SerializableGeeArrayListTestBallArray* _tmp239_;
		SerializableGeeArrayListTestBallArray* _tmp240_;
		gboolean _tmp241_;
		SerializableGeeArrayListTestBigBag* _tmp242_;
		SerializableGeeArrayListTestSmallBagArray* _tmp243_;
		SerializableGeeArrayListTestSmallBagArray* _tmp244_;
		gpointer _tmp245_;
		SerializableGeeArrayListTestSmallBag* _tmp246_;
		SerializableGeeArrayListTestBallArray* _tmp247_;
		SerializableGeeArrayListTestBallArray* _tmp248_;
		gint _tmp249_;
		gint _tmp250_;
		SerializableGeeArrayListTestBigBag* _tmp251_;
		SerializableGeeArrayListTestSmallBagArray* _tmp252_;
		SerializableGeeArrayListTestSmallBagArray* _tmp253_;
		gpointer _tmp254_;
		SerializableGeeArrayListTestSmallBag* _tmp255_;
		SerializableGeeArrayListTestBallArray* _tmp256_;
		SerializableGeeArrayListTestBallArray* _tmp257_;
		gpointer _tmp258_;
		SerializableGeeArrayListTestBall* _tmp259_;
		const gchar* _tmp260_;
		const gchar* _tmp261_;
		SerializableGeeArrayListTestBigBag* _tmp262_;
		SerializableGeeArrayListTestSmallBagArray* _tmp263_;
		SerializableGeeArrayListTestSmallBagArray* _tmp264_;
		gpointer _tmp265_;
		SerializableGeeArrayListTestSmallBag* _tmp266_;
		SerializableGeeArrayListTestBallArray* _tmp267_;
		SerializableGeeArrayListTestBallArray* _tmp268_;
		gpointer _tmp269_;
		SerializableGeeArrayListTestBall* _tmp270_;
		SerializableGeeArrayListTestBallFill* _tmp271_;
		SerializableGeeArrayListTestBallFill* _tmp272_;
		SerializableGeeArrayListTestBigBag* _tmp273_;
		SerializableGeeArrayListTestSmallBagArray* _tmp274_;
		SerializableGeeArrayListTestSmallBagArray* _tmp275_;
		gpointer _tmp276_;
		SerializableGeeArrayListTestSmallBag* _tmp277_;
		SerializableGeeArrayListTestBallArray* _tmp278_;
		SerializableGeeArrayListTestBallArray* _tmp279_;
		gpointer _tmp280_;
		SerializableGeeArrayListTestBall* _tmp281_;
		SerializableGeeArrayListTestBallFill* _tmp282_;
		SerializableGeeArrayListTestBallFill* _tmp283_;
		gchar* _tmp284_;
		gchar* _tmp285_;
		gchar* _tmp286_;
		SerializableGeeArrayListTestBigBag* _tmp287_;
		SerializableGeeArrayListTestSmallBagArray* _tmp288_;
		SerializableGeeArrayListTestSmallBagArray* _tmp289_;
		gpointer _tmp290_;
		SerializableGeeArrayListTestSmallBag* _tmp291_;
		SerializableGeeArrayListTestBallArray* _tmp292_;
		SerializableGeeArrayListTestBallArray* _tmp293_;
		gpointer _tmp294_;
		SerializableGeeArrayListTestBall* _tmp295_;
		SerializableGeeArrayListTestBallFill* _tmp296_;
		SerializableGeeArrayListTestBallFill* _tmp297_;
		gchar* _tmp298_;
		gchar* _tmp299_;
		gchar* _tmp300_;
		SerializableGeeArrayListTestBigBag* bag2 = NULL;
		SerializableGeeArrayListTestBigBag* _tmp301_;
		SerializableGeeArrayListTestBigBag* _tmp302_;
		GXmlGDocument* _tmp303_;
		SerializableGeeArrayListTestBigBag* _tmp304_;
		SerializableGeeArrayListTestSmallBagArray* _tmp305_;
		SerializableGeeArrayListTestSmallBagArray* _tmp306_;
		gint _tmp307_;
		gint _tmp308_;
		GXmlGDocument* d2 = NULL;
		GXmlGDocument* _tmp309_;
		SerializableGeeArrayListTestBigBag* _tmp310_;
		GXmlGDocument* _tmp311_;
		GXmlNode* _tmp312_;
		GXmlNode* _tmp313_;
		GXmlGDocument* _tmp314_;
		GXmlNode* _tmp315_;
		GXmlNode* _tmp316_;
		GXmlNode* _tmp317_;
		GXmlGDocument* _tmp318_;
		GXmlNode* _tmp319_;
		GXmlNode* _tmp320_;
		GXmlNode* _tmp321_;
		gchar* _tmp322_;
		gchar* _tmp323_;
		gchar* _tmp324_;
		GXmlGDocument* _tmp325_;
		GXmlNode* _tmp326_;
		GXmlNode* _tmp327_;
		GXmlNode* _tmp328_;
		GeeBidirList* _tmp329_;
		GeeBidirList* _tmp330_;
		GeeBidirList* _tmp331_;
		gint _tmp332_;
		gint _tmp333_;
		GXmlGDocument* _tmp334_;
		GXmlNode* _tmp335_;
		GXmlNode* _tmp336_;
		GXmlNode* _tmp337_;
		GeeBidirList* _tmp338_;
		GeeBidirList* _tmp339_;
		GeeBidirList* _tmp340_;
		gpointer _tmp341_;
		GXmlNode* _tmp342_;
		gchar* _tmp343_;
		gchar* _tmp344_;
		gchar* _tmp345_;
		GXmlGDocument* _tmp346_;
		GXmlNode* _tmp347_;
		GXmlNode* _tmp348_;
		GXmlNode* _tmp349_;
		GeeBidirList* _tmp350_;
		GeeBidirList* _tmp351_;
		GeeBidirList* _tmp352_;
		gpointer _tmp353_;
		GXmlNode* _tmp354_;
		GeeBidirList* _tmp355_;
		GeeBidirList* _tmp356_;
		GeeBidirList* _tmp357_;
		gint _tmp358_;
		gint _tmp359_;
		GXmlGDocument* _tmp360_;
		GXmlNode* _tmp361_;
		GXmlNode* _tmp362_;
		GXmlNode* _tmp363_;
		GeeBidirList* _tmp364_;
		GeeBidirList* _tmp365_;
		GeeBidirList* _tmp366_;
		gpointer _tmp367_;
		GXmlNode* _tmp368_;
		GeeBidirList* _tmp369_;
		GeeBidirList* _tmp370_;
		GeeBidirList* _tmp371_;
		gpointer _tmp372_;
		GXmlNode* _tmp373_;
		gchar* _tmp374_;
		gchar* _tmp375_;
		gchar* _tmp376_;
		GXmlGDocument* _tmp377_;
		GXmlNode* _tmp378_;
		GXmlNode* _tmp379_;
		GXmlNode* _tmp380_;
		GeeBidirList* _tmp381_;
		GeeBidirList* _tmp382_;
		GeeBidirList* _tmp383_;
		gpointer _tmp384_;
		GXmlNode* _tmp385_;
		GeeBidirList* _tmp386_;
		GeeBidirList* _tmp387_;
		GeeBidirList* _tmp388_;
		gpointer _tmp389_;
		GXmlNode* _tmp390_;
		GeeBidirList* _tmp391_;
		GeeBidirList* _tmp392_;
		GeeBidirList* _tmp393_;
		gint _tmp394_;
		gint _tmp395_;
		GXmlGDocument* _tmp396_;
		GXmlNode* _tmp397_;
		GXmlNode* _tmp398_;
		GXmlNode* _tmp399_;
		GeeBidirList* _tmp400_;
		GeeBidirList* _tmp401_;
		GeeBidirList* _tmp402_;
		gpointer _tmp403_;
		GXmlNode* _tmp404_;
		GeeBidirList* _tmp405_;
		GeeBidirList* _tmp406_;
		GeeBidirList* _tmp407_;
		gpointer _tmp408_;
		GXmlNode* _tmp409_;
		GeeBidirList* _tmp410_;
		GeeBidirList* _tmp411_;
		GeeBidirList* _tmp412_;
		gpointer _tmp413_;
		GXmlNode* _tmp414_;
		gchar* _tmp415_;
		gchar* _tmp416_;
		gchar* _tmp417_;
		GXmlGDocument* _tmp418_;
		GXmlNode* _tmp419_;
		GXmlNode* _tmp420_;
		GXmlNode* _tmp421_;
		GeeBidirList* _tmp422_;
		GeeBidirList* _tmp423_;
		GeeBidirList* _tmp424_;
		gpointer _tmp425_;
		GXmlNode* _tmp426_;
		GeeBidirList* _tmp427_;
		GeeBidirList* _tmp428_;
		GeeBidirList* _tmp429_;
		gpointer _tmp430_;
		GXmlNode* _tmp431_;
		GeeBidirList* _tmp432_;
		GeeBidirList* _tmp433_;
		GeeBidirList* _tmp434_;
		gpointer _tmp435_;
		GXmlNode* _tmp436_;
		GeeBidirList* _tmp437_;
		GeeBidirList* _tmp438_;
		GeeBidirList* _tmp439_;
		gint _tmp440_;
		gint _tmp441_;
		GXmlGDocument* _tmp442_;
		GXmlNode* _tmp443_;
		GXmlNode* _tmp444_;
		GXmlNode* _tmp445_;
		GeeBidirList* _tmp446_;
		GeeBidirList* _tmp447_;
		GeeBidirList* _tmp448_;
		gpointer _tmp449_;
		GXmlNode* _tmp450_;
		GeeBidirList* _tmp451_;
		GeeBidirList* _tmp452_;
		GeeBidirList* _tmp453_;
		gpointer _tmp454_;
		GXmlNode* _tmp455_;
		GeeBidirList* _tmp456_;
		GeeBidirList* _tmp457_;
		GeeBidirList* _tmp458_;
		gpointer _tmp459_;
		GXmlNode* _tmp460_;
		GeeBidirList* _tmp461_;
		GeeBidirList* _tmp462_;
		GeeBidirList* _tmp463_;
		gpointer _tmp464_;
		GXmlNode* _tmp465_;
		GXmlGDocument* _tmp466_;
		GXmlNode* _tmp467_;
		GXmlNode* _tmp468_;
		GXmlNode* _tmp469_;
		GeeBidirList* _tmp470_;
		GeeBidirList* _tmp471_;
		GeeBidirList* _tmp472_;
		gpointer _tmp473_;
		GXmlNode* _tmp474_;
		GeeBidirList* _tmp475_;
		GeeBidirList* _tmp476_;
		GeeBidirList* _tmp477_;
		gpointer _tmp478_;
		GXmlNode* _tmp479_;
		GeeBidirList* _tmp480_;
		GeeBidirList* _tmp481_;
		GeeBidirList* _tmp482_;
		gpointer _tmp483_;
		GXmlNode* _tmp484_;
		GeeBidirList* _tmp485_;
		GeeBidirList* _tmp486_;
		GeeBidirList* _tmp487_;
		gpointer _tmp488_;
		GXmlNode* _tmp489_;
		gchar* _tmp490_;
		gchar* _tmp491_;
		gchar* _tmp492_;
#line 256 "SerializableGeeArrayListTest.vala"
		_tmp0_ = serializable_gee_array_list_test_big_bag_new ();
#line 256 "SerializableGeeArrayListTest.vala"
		bag = _tmp0_;
#line 257 "SerializableGeeArrayListTest.vala"
		_tmp1_ = bag;
#line 257 "SerializableGeeArrayListTest.vala"
		_tmp2_ = serializable_gee_array_list_test_big_bag_get_bags (_tmp1_);
#line 257 "SerializableGeeArrayListTest.vala"
		_tmp3_ = _tmp2_;
#line 257 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp3_ != NULL, "bag.bags != null");
#line 3287 "SerializableGeeArrayListTest.c"
		{
			gint i = 0;
#line 258 "SerializableGeeArrayListTest.vala"
			i = 0;
#line 3292 "SerializableGeeArrayListTest.c"
			{
				gboolean _tmp4_ = FALSE;
#line 258 "SerializableGeeArrayListTest.vala"
				_tmp4_ = TRUE;
#line 258 "SerializableGeeArrayListTest.vala"
				while (TRUE) {
#line 3299 "SerializableGeeArrayListTest.c"
					SerializableGeeArrayListTestSmallBag* sbag = NULL;
					SerializableGeeArrayListTestSmallBag* _tmp6_;
					SerializableGeeArrayListTestSmallBag* _tmp7_;
					SerializableGeeArrayListTestBallArray* _tmp8_;
					SerializableGeeArrayListTestBallArray* _tmp9_;
					SerializableGeeArrayListTestSmallBag* _tmp23_;
					SerializableGeeArrayListTestBallArray* _tmp24_;
					SerializableGeeArrayListTestBallArray* _tmp25_;
					gint _tmp26_;
					gint _tmp27_;
					SerializableGeeArrayListTestBigBag* _tmp28_;
					SerializableGeeArrayListTestSmallBagArray* _tmp29_;
					SerializableGeeArrayListTestSmallBagArray* _tmp30_;
					SerializableGeeArrayListTestSmallBag* _tmp31_;
#line 258 "SerializableGeeArrayListTest.vala"
					if (!_tmp4_) {
#line 3316 "SerializableGeeArrayListTest.c"
						gint _tmp5_;
#line 258 "SerializableGeeArrayListTest.vala"
						_tmp5_ = i;
#line 258 "SerializableGeeArrayListTest.vala"
						i = _tmp5_ + 1;
#line 3322 "SerializableGeeArrayListTest.c"
					}
#line 258 "SerializableGeeArrayListTest.vala"
					_tmp4_ = FALSE;
#line 258 "SerializableGeeArrayListTest.vala"
					if (!(i < 2)) {
#line 258 "SerializableGeeArrayListTest.vala"
						break;
#line 3330 "SerializableGeeArrayListTest.c"
					}
#line 259 "SerializableGeeArrayListTest.vala"
					_tmp6_ = serializable_gee_array_list_test_small_bag_new ();
#line 259 "SerializableGeeArrayListTest.vala"
					sbag = _tmp6_;
#line 260 "SerializableGeeArrayListTest.vala"
					_tmp7_ = sbag;
#line 260 "SerializableGeeArrayListTest.vala"
					_tmp8_ = serializable_gee_array_list_test_small_bag_get_balls (_tmp7_);
#line 260 "SerializableGeeArrayListTest.vala"
					_tmp9_ = _tmp8_;
#line 260 "SerializableGeeArrayListTest.vala"
					_vala_assert (_tmp9_ != NULL, "sbag.balls != null");
#line 3344 "SerializableGeeArrayListTest.c"
					{
						gint j = 0;
#line 261 "SerializableGeeArrayListTest.vala"
						j = 0;
#line 3349 "SerializableGeeArrayListTest.c"
						{
							gboolean _tmp10_ = FALSE;
#line 261 "SerializableGeeArrayListTest.vala"
							_tmp10_ = TRUE;
#line 261 "SerializableGeeArrayListTest.vala"
							while (TRUE) {
#line 3356 "SerializableGeeArrayListTest.c"
								SerializableGeeArrayListTestBall* b = NULL;
								SerializableGeeArrayListTestBall* _tmp12_;
								SerializableGeeArrayListTestBall* _tmp13_;
								SerializableGeeArrayListTestBallFill* _tmp14_;
								SerializableGeeArrayListTestBallFill* _tmp15_;
								SerializableGeeArrayListTestBall* _tmp16_;
								SerializableGeeArrayListTestBallFill* _tmp17_;
								SerializableGeeArrayListTestBallFill* _tmp18_;
								SerializableGeeArrayListTestSmallBag* _tmp19_;
								SerializableGeeArrayListTestBallArray* _tmp20_;
								SerializableGeeArrayListTestBallArray* _tmp21_;
								SerializableGeeArrayListTestBall* _tmp22_;
#line 261 "SerializableGeeArrayListTest.vala"
								if (!_tmp10_) {
#line 3371 "SerializableGeeArrayListTest.c"
									gint _tmp11_;
#line 261 "SerializableGeeArrayListTest.vala"
									_tmp11_ = j;
#line 261 "SerializableGeeArrayListTest.vala"
									j = _tmp11_ + 1;
#line 3377 "SerializableGeeArrayListTest.c"
								}
#line 261 "SerializableGeeArrayListTest.vala"
								_tmp10_ = FALSE;
#line 261 "SerializableGeeArrayListTest.vala"
								if (!(j < 2)) {
#line 261 "SerializableGeeArrayListTest.vala"
									break;
#line 3385 "SerializableGeeArrayListTest.c"
								}
#line 262 "SerializableGeeArrayListTest.vala"
								_tmp12_ = serializable_gee_array_list_test_ball_new ();
#line 262 "SerializableGeeArrayListTest.vala"
								b = _tmp12_;
#line 263 "SerializableGeeArrayListTest.vala"
								_tmp13_ = b;
#line 263 "SerializableGeeArrayListTest.vala"
								_tmp14_ = serializable_gee_array_list_test_ball_fill_new ();
#line 263 "SerializableGeeArrayListTest.vala"
								_tmp15_ = _tmp14_;
#line 263 "SerializableGeeArrayListTest.vala"
								serializable_gee_array_list_test_ball_set_ballfill (_tmp13_, _tmp15_);
#line 263 "SerializableGeeArrayListTest.vala"
								_g_object_unref0 (_tmp15_);
#line 264 "SerializableGeeArrayListTest.vala"
								_tmp16_ = b;
#line 264 "SerializableGeeArrayListTest.vala"
								_tmp17_ = serializable_gee_array_list_test_ball_get_ballfill (_tmp16_);
#line 264 "SerializableGeeArrayListTest.vala"
								_tmp18_ = _tmp17_;
#line 264 "SerializableGeeArrayListTest.vala"
								serializable_gee_array_list_test_ball_fill_set_text (_tmp18_, "golden dust");
#line 265 "SerializableGeeArrayListTest.vala"
								_tmp19_ = sbag;
#line 265 "SerializableGeeArrayListTest.vala"
								_tmp20_ = serializable_gee_array_list_test_small_bag_get_balls (_tmp19_);
#line 265 "SerializableGeeArrayListTest.vala"
								_tmp21_ = _tmp20_;
#line 265 "SerializableGeeArrayListTest.vala"
								_tmp22_ = b;
#line 265 "SerializableGeeArrayListTest.vala"
								gee_abstract_collection_add ((GeeAbstractCollection*) _tmp21_, _tmp22_);
#line 261 "SerializableGeeArrayListTest.vala"
								_g_object_unref0 (b);
#line 3421 "SerializableGeeArrayListTest.c"
							}
						}
					}
#line 267 "SerializableGeeArrayListTest.vala"
					_tmp23_ = sbag;
#line 267 "SerializableGeeArrayListTest.vala"
					_tmp24_ = serializable_gee_array_list_test_small_bag_get_balls (_tmp23_);
#line 267 "SerializableGeeArrayListTest.vala"
					_tmp25_ = _tmp24_;
#line 267 "SerializableGeeArrayListTest.vala"
					_tmp26_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp25_);
#line 267 "SerializableGeeArrayListTest.vala"
					_tmp27_ = _tmp26_;
#line 267 "SerializableGeeArrayListTest.vala"
					_vala_assert (_tmp27_ == 2, "sbag.balls.size == 2");
#line 268 "SerializableGeeArrayListTest.vala"
					_tmp28_ = bag;
#line 268 "SerializableGeeArrayListTest.vala"
					_tmp29_ = serializable_gee_array_list_test_big_bag_get_bags (_tmp28_);
#line 268 "SerializableGeeArrayListTest.vala"
					_tmp30_ = _tmp29_;
#line 268 "SerializableGeeArrayListTest.vala"
					_tmp31_ = sbag;
#line 268 "SerializableGeeArrayListTest.vala"
					gee_abstract_collection_add ((GeeAbstractCollection*) _tmp30_, _tmp31_);
#line 258 "SerializableGeeArrayListTest.vala"
					_g_object_unref0 (sbag);
#line 3449 "SerializableGeeArrayListTest.c"
				}
			}
		}
#line 270 "SerializableGeeArrayListTest.vala"
		_tmp32_ = bag;
#line 270 "SerializableGeeArrayListTest.vala"
		_tmp33_ = serializable_gee_array_list_test_big_bag_get_bags (_tmp32_);
#line 270 "SerializableGeeArrayListTest.vala"
		_tmp34_ = _tmp33_;
#line 270 "SerializableGeeArrayListTest.vala"
		_tmp35_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp34_);
#line 270 "SerializableGeeArrayListTest.vala"
		_tmp36_ = _tmp35_;
#line 270 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp36_ == 2, "bag.bags.size == 2");
#line 272 "SerializableGeeArrayListTest.vala"
		_tmp37_ = gxml_gdocument_new ();
#line 272 "SerializableGeeArrayListTest.vala"
		d = _tmp37_;
#line 273 "SerializableGeeArrayListTest.vala"
		_tmp38_ = bag;
#line 273 "SerializableGeeArrayListTest.vala"
		_tmp39_ = d;
#line 273 "SerializableGeeArrayListTest.vala"
		_tmp40_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp38_, (GXmlNode*) _tmp39_, &_inner_error0_);
#line 273 "SerializableGeeArrayListTest.vala"
		_tmp41_ = _tmp40_;
#line 273 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp41_);
#line 273 "SerializableGeeArrayListTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 273 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (d);
#line 273 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (bag);
#line 3485 "SerializableGeeArrayListTest.c"
			goto __catch361_g_error;
		}
#line 274 "SerializableGeeArrayListTest.vala"
		_tmp42_ = d;
#line 274 "SerializableGeeArrayListTest.vala"
		_tmp43_ = gxml_document_get_root ((GXmlDocument*) _tmp42_);
#line 274 "SerializableGeeArrayListTest.vala"
		_tmp44_ = _tmp43_;
#line 274 "SerializableGeeArrayListTest.vala"
		_tmp45_ = _tmp44_;
#line 274 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp45_ != NULL, "d.root != null");
#line 274 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp45_);
#line 275 "SerializableGeeArrayListTest.vala"
		_tmp46_ = d;
#line 275 "SerializableGeeArrayListTest.vala"
		_tmp47_ = gxml_document_get_root ((GXmlDocument*) _tmp46_);
#line 275 "SerializableGeeArrayListTest.vala"
		_tmp48_ = _tmp47_;
#line 275 "SerializableGeeArrayListTest.vala"
		_tmp49_ = _tmp48_;
#line 275 "SerializableGeeArrayListTest.vala"
		_tmp50_ = gxml_node_get_name (_tmp49_);
#line 275 "SerializableGeeArrayListTest.vala"
		_tmp51_ = _tmp50_;
#line 275 "SerializableGeeArrayListTest.vala"
		_tmp52_ = _tmp51_;
#line 275 "SerializableGeeArrayListTest.vala"
		_vala_assert (g_strcmp0 (_tmp52_, "BigBag") == 0, "d.root.name == \"BigBag\"");
#line 275 "SerializableGeeArrayListTest.vala"
		_g_free0 (_tmp52_);
#line 275 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp49_);
#line 276 "SerializableGeeArrayListTest.vala"
		_tmp53_ = d;
#line 276 "SerializableGeeArrayListTest.vala"
		_tmp54_ = gxml_document_get_root ((GXmlDocument*) _tmp53_);
#line 276 "SerializableGeeArrayListTest.vala"
		_tmp55_ = _tmp54_;
#line 276 "SerializableGeeArrayListTest.vala"
		_tmp56_ = _tmp55_;
#line 276 "SerializableGeeArrayListTest.vala"
		_tmp57_ = gxml_node_get_children_nodes (_tmp56_);
#line 276 "SerializableGeeArrayListTest.vala"
		_tmp58_ = _tmp57_;
#line 276 "SerializableGeeArrayListTest.vala"
		_tmp59_ = _tmp58_;
#line 276 "SerializableGeeArrayListTest.vala"
		_tmp60_ = gee_collection_get_size ((GeeCollection*) _tmp59_);
#line 276 "SerializableGeeArrayListTest.vala"
		_tmp61_ = _tmp60_;
#line 276 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp61_ == 2, "d.root.children_nodes.size == 2");
#line 276 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp59_);
#line 276 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp56_);
#line 277 "SerializableGeeArrayListTest.vala"
		_tmp62_ = d;
#line 277 "SerializableGeeArrayListTest.vala"
		_tmp63_ = gxml_document_get_root ((GXmlDocument*) _tmp62_);
#line 277 "SerializableGeeArrayListTest.vala"
		_tmp64_ = _tmp63_;
#line 277 "SerializableGeeArrayListTest.vala"
		_tmp65_ = _tmp64_;
#line 277 "SerializableGeeArrayListTest.vala"
		_tmp66_ = gxml_node_get_children_nodes (_tmp65_);
#line 277 "SerializableGeeArrayListTest.vala"
		_tmp67_ = _tmp66_;
#line 277 "SerializableGeeArrayListTest.vala"
		_tmp68_ = _tmp67_;
#line 277 "SerializableGeeArrayListTest.vala"
		_tmp69_ = gee_list_get ((GeeList*) _tmp68_, 0);
#line 277 "SerializableGeeArrayListTest.vala"
		_tmp70_ = (GXmlNode*) _tmp69_;
#line 277 "SerializableGeeArrayListTest.vala"
		_tmp71_ = gxml_node_get_name (_tmp70_);
#line 277 "SerializableGeeArrayListTest.vala"
		_tmp72_ = _tmp71_;
#line 277 "SerializableGeeArrayListTest.vala"
		_tmp73_ = _tmp72_;
#line 277 "SerializableGeeArrayListTest.vala"
		_vala_assert (g_strcmp0 (_tmp73_, "SmallBag") == 0, "d.root.children_nodes[0].name == \"SmallBag\"");
#line 277 "SerializableGeeArrayListTest.vala"
		_g_free0 (_tmp73_);
#line 277 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp70_);
#line 277 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp68_);
#line 277 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp65_);
#line 278 "SerializableGeeArrayListTest.vala"
		_tmp74_ = d;
#line 278 "SerializableGeeArrayListTest.vala"
		_tmp75_ = gxml_document_get_root ((GXmlDocument*) _tmp74_);
#line 278 "SerializableGeeArrayListTest.vala"
		_tmp76_ = _tmp75_;
#line 278 "SerializableGeeArrayListTest.vala"
		_tmp77_ = _tmp76_;
#line 278 "SerializableGeeArrayListTest.vala"
		_tmp78_ = gxml_node_get_children_nodes (_tmp77_);
#line 278 "SerializableGeeArrayListTest.vala"
		_tmp79_ = _tmp78_;
#line 278 "SerializableGeeArrayListTest.vala"
		_tmp80_ = _tmp79_;
#line 278 "SerializableGeeArrayListTest.vala"
		_tmp81_ = gee_list_get ((GeeList*) _tmp80_, 0);
#line 278 "SerializableGeeArrayListTest.vala"
		_tmp82_ = (GXmlNode*) _tmp81_;
#line 278 "SerializableGeeArrayListTest.vala"
		_tmp83_ = gxml_node_get_children_nodes (_tmp82_);
#line 278 "SerializableGeeArrayListTest.vala"
		_tmp84_ = _tmp83_;
#line 278 "SerializableGeeArrayListTest.vala"
		_tmp85_ = _tmp84_;
#line 278 "SerializableGeeArrayListTest.vala"
		_tmp86_ = gee_collection_get_size ((GeeCollection*) _tmp85_);
#line 278 "SerializableGeeArrayListTest.vala"
		_tmp87_ = _tmp86_;
#line 278 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp87_ == 2, "d.root.children_nodes[0].children_nodes.size == 2");
#line 278 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp85_);
#line 278 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp82_);
#line 278 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp80_);
#line 278 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp77_);
#line 279 "SerializableGeeArrayListTest.vala"
		_tmp88_ = d;
#line 279 "SerializableGeeArrayListTest.vala"
		_tmp89_ = gxml_document_get_root ((GXmlDocument*) _tmp88_);
#line 279 "SerializableGeeArrayListTest.vala"
		_tmp90_ = _tmp89_;
#line 279 "SerializableGeeArrayListTest.vala"
		_tmp91_ = _tmp90_;
#line 279 "SerializableGeeArrayListTest.vala"
		_tmp92_ = gxml_node_get_children_nodes (_tmp91_);
#line 279 "SerializableGeeArrayListTest.vala"
		_tmp93_ = _tmp92_;
#line 279 "SerializableGeeArrayListTest.vala"
		_tmp94_ = _tmp93_;
#line 279 "SerializableGeeArrayListTest.vala"
		_tmp95_ = gee_list_get ((GeeList*) _tmp94_, 0);
#line 279 "SerializableGeeArrayListTest.vala"
		_tmp96_ = (GXmlNode*) _tmp95_;
#line 279 "SerializableGeeArrayListTest.vala"
		_tmp97_ = gxml_node_get_children_nodes (_tmp96_);
#line 279 "SerializableGeeArrayListTest.vala"
		_tmp98_ = _tmp97_;
#line 279 "SerializableGeeArrayListTest.vala"
		_tmp99_ = _tmp98_;
#line 279 "SerializableGeeArrayListTest.vala"
		_tmp100_ = gee_list_get ((GeeList*) _tmp99_, 0);
#line 279 "SerializableGeeArrayListTest.vala"
		_tmp101_ = (GXmlNode*) _tmp100_;
#line 279 "SerializableGeeArrayListTest.vala"
		_tmp102_ = gxml_node_get_name (_tmp101_);
#line 279 "SerializableGeeArrayListTest.vala"
		_tmp103_ = _tmp102_;
#line 279 "SerializableGeeArrayListTest.vala"
		_tmp104_ = _tmp103_;
#line 279 "SerializableGeeArrayListTest.vala"
		_vala_assert (g_strcmp0 (_tmp104_, "Ball") == 0, "d.root.children_nodes[0].children_nodes[0].name == \"Ball\"");
#line 279 "SerializableGeeArrayListTest.vala"
		_g_free0 (_tmp104_);
#line 279 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp101_);
#line 279 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp99_);
#line 279 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp96_);
#line 279 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp94_);
#line 279 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp91_);
#line 280 "SerializableGeeArrayListTest.vala"
		_tmp105_ = d;
#line 280 "SerializableGeeArrayListTest.vala"
		_tmp106_ = gxml_document_get_root ((GXmlDocument*) _tmp105_);
#line 280 "SerializableGeeArrayListTest.vala"
		_tmp107_ = _tmp106_;
#line 280 "SerializableGeeArrayListTest.vala"
		_tmp108_ = _tmp107_;
#line 280 "SerializableGeeArrayListTest.vala"
		_tmp109_ = gxml_node_get_children_nodes (_tmp108_);
#line 280 "SerializableGeeArrayListTest.vala"
		_tmp110_ = _tmp109_;
#line 280 "SerializableGeeArrayListTest.vala"
		_tmp111_ = _tmp110_;
#line 280 "SerializableGeeArrayListTest.vala"
		_tmp112_ = gee_list_get ((GeeList*) _tmp111_, 0);
#line 280 "SerializableGeeArrayListTest.vala"
		_tmp113_ = (GXmlNode*) _tmp112_;
#line 280 "SerializableGeeArrayListTest.vala"
		_tmp114_ = gxml_node_get_children_nodes (_tmp113_);
#line 280 "SerializableGeeArrayListTest.vala"
		_tmp115_ = _tmp114_;
#line 280 "SerializableGeeArrayListTest.vala"
		_tmp116_ = _tmp115_;
#line 280 "SerializableGeeArrayListTest.vala"
		_tmp117_ = gee_list_get ((GeeList*) _tmp116_, 0);
#line 280 "SerializableGeeArrayListTest.vala"
		_tmp118_ = (GXmlNode*) _tmp117_;
#line 280 "SerializableGeeArrayListTest.vala"
		_tmp119_ = gxml_node_get_children_nodes (_tmp118_);
#line 280 "SerializableGeeArrayListTest.vala"
		_tmp120_ = _tmp119_;
#line 280 "SerializableGeeArrayListTest.vala"
		_tmp121_ = _tmp120_;
#line 280 "SerializableGeeArrayListTest.vala"
		_tmp122_ = gee_collection_get_size ((GeeCollection*) _tmp121_);
#line 280 "SerializableGeeArrayListTest.vala"
		_tmp123_ = _tmp122_;
#line 280 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp123_ == 1, "d.root.children_nodes[0].children_nodes[0].children_nodes.size == 1");
#line 280 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp121_);
#line 280 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp118_);
#line 280 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp116_);
#line 280 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp113_);
#line 280 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp111_);
#line 280 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp108_);
#line 281 "SerializableGeeArrayListTest.vala"
		_tmp124_ = d;
#line 281 "SerializableGeeArrayListTest.vala"
		_tmp125_ = gxml_document_get_root ((GXmlDocument*) _tmp124_);
#line 281 "SerializableGeeArrayListTest.vala"
		_tmp126_ = _tmp125_;
#line 281 "SerializableGeeArrayListTest.vala"
		_tmp127_ = _tmp126_;
#line 281 "SerializableGeeArrayListTest.vala"
		_tmp128_ = gxml_node_get_children_nodes (_tmp127_);
#line 281 "SerializableGeeArrayListTest.vala"
		_tmp129_ = _tmp128_;
#line 281 "SerializableGeeArrayListTest.vala"
		_tmp130_ = _tmp129_;
#line 281 "SerializableGeeArrayListTest.vala"
		_tmp131_ = gee_list_get ((GeeList*) _tmp130_, 0);
#line 281 "SerializableGeeArrayListTest.vala"
		_tmp132_ = (GXmlNode*) _tmp131_;
#line 281 "SerializableGeeArrayListTest.vala"
		_tmp133_ = gxml_node_get_children_nodes (_tmp132_);
#line 281 "SerializableGeeArrayListTest.vala"
		_tmp134_ = _tmp133_;
#line 281 "SerializableGeeArrayListTest.vala"
		_tmp135_ = _tmp134_;
#line 281 "SerializableGeeArrayListTest.vala"
		_tmp136_ = gee_list_get ((GeeList*) _tmp135_, 0);
#line 281 "SerializableGeeArrayListTest.vala"
		_tmp137_ = (GXmlNode*) _tmp136_;
#line 281 "SerializableGeeArrayListTest.vala"
		_tmp138_ = gxml_node_get_children_nodes (_tmp137_);
#line 281 "SerializableGeeArrayListTest.vala"
		_tmp139_ = _tmp138_;
#line 281 "SerializableGeeArrayListTest.vala"
		_tmp140_ = _tmp139_;
#line 281 "SerializableGeeArrayListTest.vala"
		_tmp141_ = gee_list_get ((GeeList*) _tmp140_, 0);
#line 281 "SerializableGeeArrayListTest.vala"
		_tmp142_ = (GXmlNode*) _tmp141_;
#line 281 "SerializableGeeArrayListTest.vala"
		_tmp143_ = gxml_node_get_name (_tmp142_);
#line 281 "SerializableGeeArrayListTest.vala"
		_tmp144_ = _tmp143_;
#line 281 "SerializableGeeArrayListTest.vala"
		_tmp145_ = _tmp144_;
#line 281 "SerializableGeeArrayListTest.vala"
		_vala_assert (g_strcmp0 (_tmp145_, "BallFill") == 0, "d.root.children_nodes[0].children_nodes[0].children_nodes[0].name == \"BallFill\"");
#line 281 "SerializableGeeArrayListTest.vala"
		_g_free0 (_tmp145_);
#line 281 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp142_);
#line 281 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp140_);
#line 281 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp137_);
#line 281 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp135_);
#line 281 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp132_);
#line 281 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp130_);
#line 281 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp127_);
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp146_ = d;
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp147_ = gxml_document_get_root ((GXmlDocument*) _tmp146_);
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp148_ = _tmp147_;
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp149_ = _tmp148_;
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp150_ = gxml_node_get_children_nodes (_tmp149_);
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp151_ = _tmp150_;
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp152_ = _tmp151_;
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp153_ = gee_list_get ((GeeList*) _tmp152_, 0);
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp154_ = (GXmlNode*) _tmp153_;
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp155_ = gxml_node_get_children_nodes (_tmp154_);
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp156_ = _tmp155_;
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp157_ = _tmp156_;
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp158_ = gee_list_get ((GeeList*) _tmp157_, 0);
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp159_ = (GXmlNode*) _tmp158_;
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp160_ = gxml_node_get_children_nodes (_tmp159_);
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp161_ = _tmp160_;
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp162_ = _tmp161_;
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp163_ = gee_list_get ((GeeList*) _tmp162_, 0);
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp164_ = (GXmlNode*) _tmp163_;
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp165_ = gxml_node_get_children_nodes (_tmp164_);
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp166_ = _tmp165_;
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp167_ = _tmp166_;
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp168_ = gee_collection_get_size ((GeeCollection*) _tmp167_);
#line 282 "SerializableGeeArrayListTest.vala"
		_tmp169_ = _tmp168_;
#line 282 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp169_ == 1, "d.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes.size == 1");
#line 282 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp167_);
#line 282 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp164_);
#line 282 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp162_);
#line 282 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp159_);
#line 282 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp157_);
#line 282 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp154_);
#line 282 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp152_);
#line 282 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp149_);
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp170_ = d;
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp171_ = gxml_document_get_root ((GXmlDocument*) _tmp170_);
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp172_ = _tmp171_;
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp173_ = _tmp172_;
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp174_ = gxml_node_get_children_nodes (_tmp173_);
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp175_ = _tmp174_;
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp176_ = _tmp175_;
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp177_ = gee_list_get ((GeeList*) _tmp176_, 0);
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp178_ = (GXmlNode*) _tmp177_;
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp179_ = gxml_node_get_children_nodes (_tmp178_);
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp180_ = _tmp179_;
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp181_ = _tmp180_;
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp182_ = gee_list_get ((GeeList*) _tmp181_, 0);
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp183_ = (GXmlNode*) _tmp182_;
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp184_ = gxml_node_get_children_nodes (_tmp183_);
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp185_ = _tmp184_;
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp186_ = _tmp185_;
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp187_ = gee_list_get ((GeeList*) _tmp186_, 0);
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp188_ = (GXmlNode*) _tmp187_;
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp189_ = gxml_node_get_children_nodes (_tmp188_);
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp190_ = _tmp189_;
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp191_ = _tmp190_;
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp192_ = gee_list_get ((GeeList*) _tmp191_, 0);
#line 283 "SerializableGeeArrayListTest.vala"
		_tmp193_ = (GXmlNode*) _tmp192_;
#line 283 "SerializableGeeArrayListTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp193_, GXML_TYPE_TEXT), "d.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes[0] is Text");
#line 283 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp193_);
#line 283 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp191_);
#line 283 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp188_);
#line 283 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp186_);
#line 283 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp183_);
#line 283 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp181_);
#line 283 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp178_);
#line 283 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp176_);
#line 283 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp173_);
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp194_ = d;
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp195_ = gxml_document_get_root ((GXmlDocument*) _tmp194_);
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp196_ = _tmp195_;
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp197_ = _tmp196_;
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp198_ = gxml_node_get_children_nodes (_tmp197_);
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp199_ = _tmp198_;
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp200_ = _tmp199_;
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp201_ = gee_list_get ((GeeList*) _tmp200_, 0);
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp202_ = (GXmlNode*) _tmp201_;
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp203_ = gxml_node_get_children_nodes (_tmp202_);
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp204_ = _tmp203_;
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp205_ = _tmp204_;
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp206_ = gee_list_get ((GeeList*) _tmp205_, 0);
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp207_ = (GXmlNode*) _tmp206_;
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp208_ = gxml_node_get_children_nodes (_tmp207_);
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp209_ = _tmp208_;
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp210_ = _tmp209_;
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp211_ = gee_list_get ((GeeList*) _tmp210_, 0);
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp212_ = (GXmlNode*) _tmp211_;
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp213_ = gxml_node_get_children_nodes (_tmp212_);
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp214_ = _tmp213_;
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp215_ = _tmp214_;
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp216_ = gee_list_get ((GeeList*) _tmp215_, 0);
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp217_ = (GXmlNode*) _tmp216_;
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp218_ = gxml_node_get_value (_tmp217_);
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp219_ = _tmp218_;
#line 284 "SerializableGeeArrayListTest.vala"
		_tmp220_ = _tmp219_;
#line 284 "SerializableGeeArrayListTest.vala"
		_vala_assert (g_strcmp0 (_tmp220_, "golden dust") == 0, "d.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes[0].value == \"golden dust\"");
#line 284 "SerializableGeeArrayListTest.vala"
		_g_free0 (_tmp220_);
#line 284 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp217_);
#line 284 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp215_);
#line 284 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp212_);
#line 284 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp210_);
#line 284 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp207_);
#line 284 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp205_);
#line 284 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp202_);
#line 284 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp200_);
#line 284 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp197_);
#line 287 "SerializableGeeArrayListTest.vala"
		_tmp221_ = serializable_gee_array_list_test_big_bag_new ();
#line 287 "SerializableGeeArrayListTest.vala"
		bagt = _tmp221_;
#line 288 "SerializableGeeArrayListTest.vala"
		_tmp222_ = bagt;
#line 288 "SerializableGeeArrayListTest.vala"
		_tmp223_ = d;
#line 288 "SerializableGeeArrayListTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp222_, (GXmlNode*) _tmp223_, &_inner_error0_);
#line 288 "SerializableGeeArrayListTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 288 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (bagt);
#line 288 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (d);
#line 288 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (bag);
#line 4006 "SerializableGeeArrayListTest.c"
			goto __catch361_g_error;
		}
#line 289 "SerializableGeeArrayListTest.vala"
		_tmp225_ = bagt;
#line 289 "SerializableGeeArrayListTest.vala"
		_tmp226_ = serializable_gee_array_list_test_big_bag_get_bags (_tmp225_);
#line 289 "SerializableGeeArrayListTest.vala"
		_tmp227_ = _tmp226_;
#line 289 "SerializableGeeArrayListTest.vala"
		_tmp224_ = gxml_serializable_array_list_deserialize_children ((GXmlSerializableArrayList*) _tmp227_, &_inner_error0_);
#line 289 "SerializableGeeArrayListTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 289 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (bagt);
#line 289 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (d);
#line 289 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (bag);
#line 4025 "SerializableGeeArrayListTest.c"
			goto __catch361_g_error;
		}
#line 289 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp224_, "bagt.bags.deserialize_children ()");
#line 290 "SerializableGeeArrayListTest.vala"
		_tmp228_ = bagt;
#line 290 "SerializableGeeArrayListTest.vala"
		_tmp229_ = serializable_gee_array_list_test_big_bag_get_bags (_tmp228_);
#line 290 "SerializableGeeArrayListTest.vala"
		_tmp230_ = _tmp229_;
#line 290 "SerializableGeeArrayListTest.vala"
		_tmp231_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp230_);
#line 290 "SerializableGeeArrayListTest.vala"
		_tmp232_ = _tmp231_;
#line 290 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp232_ == 2, "bagt.bags.size == 2");
#line 291 "SerializableGeeArrayListTest.vala"
		_tmp234_ = bagt;
#line 291 "SerializableGeeArrayListTest.vala"
		_tmp235_ = serializable_gee_array_list_test_big_bag_get_bags (_tmp234_);
#line 291 "SerializableGeeArrayListTest.vala"
		_tmp236_ = _tmp235_;
#line 291 "SerializableGeeArrayListTest.vala"
		_tmp237_ = gee_abstract_list_get ((GeeAbstractList*) _tmp236_, 0);
#line 291 "SerializableGeeArrayListTest.vala"
		_tmp238_ = (SerializableGeeArrayListTestSmallBag*) _tmp237_;
#line 291 "SerializableGeeArrayListTest.vala"
		_tmp239_ = serializable_gee_array_list_test_small_bag_get_balls (_tmp238_);
#line 291 "SerializableGeeArrayListTest.vala"
		_tmp240_ = _tmp239_;
#line 291 "SerializableGeeArrayListTest.vala"
		_tmp241_ = gxml_serializable_array_list_deserialize_children ((GXmlSerializableArrayList*) _tmp240_, &_inner_error0_);
#line 291 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp238_);
#line 291 "SerializableGeeArrayListTest.vala"
		_tmp233_ = _tmp241_;
#line 291 "SerializableGeeArrayListTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 291 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (bagt);
#line 291 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (d);
#line 291 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (bag);
#line 4070 "SerializableGeeArrayListTest.c"
			goto __catch361_g_error;
		}
#line 291 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp233_, "bagt.bags[0].balls.deserialize_children ()");
#line 292 "SerializableGeeArrayListTest.vala"
		_tmp242_ = bagt;
#line 292 "SerializableGeeArrayListTest.vala"
		_tmp243_ = serializable_gee_array_list_test_big_bag_get_bags (_tmp242_);
#line 292 "SerializableGeeArrayListTest.vala"
		_tmp244_ = _tmp243_;
#line 292 "SerializableGeeArrayListTest.vala"
		_tmp245_ = gee_abstract_list_get ((GeeAbstractList*) _tmp244_, 0);
#line 292 "SerializableGeeArrayListTest.vala"
		_tmp246_ = (SerializableGeeArrayListTestSmallBag*) _tmp245_;
#line 292 "SerializableGeeArrayListTest.vala"
		_tmp247_ = serializable_gee_array_list_test_small_bag_get_balls (_tmp246_);
#line 292 "SerializableGeeArrayListTest.vala"
		_tmp248_ = _tmp247_;
#line 292 "SerializableGeeArrayListTest.vala"
		_tmp249_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp248_);
#line 292 "SerializableGeeArrayListTest.vala"
		_tmp250_ = _tmp249_;
#line 292 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp250_ == 2, "bagt.bags[0].balls.size == 2");
#line 292 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp246_);
#line 293 "SerializableGeeArrayListTest.vala"
		_tmp251_ = bagt;
#line 293 "SerializableGeeArrayListTest.vala"
		_tmp252_ = serializable_gee_array_list_test_big_bag_get_bags (_tmp251_);
#line 293 "SerializableGeeArrayListTest.vala"
		_tmp253_ = _tmp252_;
#line 293 "SerializableGeeArrayListTest.vala"
		_tmp254_ = gee_abstract_list_get ((GeeAbstractList*) _tmp253_, 0);
#line 293 "SerializableGeeArrayListTest.vala"
		_tmp255_ = (SerializableGeeArrayListTestSmallBag*) _tmp254_;
#line 293 "SerializableGeeArrayListTest.vala"
		_tmp256_ = serializable_gee_array_list_test_small_bag_get_balls (_tmp255_);
#line 293 "SerializableGeeArrayListTest.vala"
		_tmp257_ = _tmp256_;
#line 293 "SerializableGeeArrayListTest.vala"
		_tmp258_ = gee_abstract_list_get ((GeeAbstractList*) _tmp257_, 0);
#line 293 "SerializableGeeArrayListTest.vala"
		_tmp259_ = (SerializableGeeArrayListTestBall*) _tmp258_;
#line 293 "SerializableGeeArrayListTest.vala"
		_tmp260_ = serializable_gee_array_list_test_ball_get_name (_tmp259_);
#line 293 "SerializableGeeArrayListTest.vala"
		_tmp261_ = _tmp260_;
#line 293 "SerializableGeeArrayListTest.vala"
		_vala_assert (g_strcmp0 (_tmp261_, "Ball") == 0, "bagt.bags[0].balls[0].name == \"Ball\"");
#line 293 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp259_);
#line 293 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp255_);
#line 294 "SerializableGeeArrayListTest.vala"
		_tmp262_ = bagt;
#line 294 "SerializableGeeArrayListTest.vala"
		_tmp263_ = serializable_gee_array_list_test_big_bag_get_bags (_tmp262_);
#line 294 "SerializableGeeArrayListTest.vala"
		_tmp264_ = _tmp263_;
#line 294 "SerializableGeeArrayListTest.vala"
		_tmp265_ = gee_abstract_list_get ((GeeAbstractList*) _tmp264_, 0);
#line 294 "SerializableGeeArrayListTest.vala"
		_tmp266_ = (SerializableGeeArrayListTestSmallBag*) _tmp265_;
#line 294 "SerializableGeeArrayListTest.vala"
		_tmp267_ = serializable_gee_array_list_test_small_bag_get_balls (_tmp266_);
#line 294 "SerializableGeeArrayListTest.vala"
		_tmp268_ = _tmp267_;
#line 294 "SerializableGeeArrayListTest.vala"
		_tmp269_ = gee_abstract_list_get ((GeeAbstractList*) _tmp268_, 0);
#line 294 "SerializableGeeArrayListTest.vala"
		_tmp270_ = (SerializableGeeArrayListTestBall*) _tmp269_;
#line 294 "SerializableGeeArrayListTest.vala"
		_tmp271_ = serializable_gee_array_list_test_ball_get_ballfill (_tmp270_);
#line 294 "SerializableGeeArrayListTest.vala"
		_tmp272_ = _tmp271_;
#line 294 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp272_ != NULL, "bagt.bags[0].balls[0].ballfill !=null");
#line 294 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp270_);
#line 294 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp266_);
#line 295 "SerializableGeeArrayListTest.vala"
		_tmp273_ = bagt;
#line 295 "SerializableGeeArrayListTest.vala"
		_tmp274_ = serializable_gee_array_list_test_big_bag_get_bags (_tmp273_);
#line 295 "SerializableGeeArrayListTest.vala"
		_tmp275_ = _tmp274_;
#line 295 "SerializableGeeArrayListTest.vala"
		_tmp276_ = gee_abstract_list_get ((GeeAbstractList*) _tmp275_, 0);
#line 295 "SerializableGeeArrayListTest.vala"
		_tmp277_ = (SerializableGeeArrayListTestSmallBag*) _tmp276_;
#line 295 "SerializableGeeArrayListTest.vala"
		_tmp278_ = serializable_gee_array_list_test_small_bag_get_balls (_tmp277_);
#line 295 "SerializableGeeArrayListTest.vala"
		_tmp279_ = _tmp278_;
#line 295 "SerializableGeeArrayListTest.vala"
		_tmp280_ = gee_abstract_list_get ((GeeAbstractList*) _tmp279_, 0);
#line 295 "SerializableGeeArrayListTest.vala"
		_tmp281_ = (SerializableGeeArrayListTestBall*) _tmp280_;
#line 295 "SerializableGeeArrayListTest.vala"
		_tmp282_ = serializable_gee_array_list_test_ball_get_ballfill (_tmp281_);
#line 295 "SerializableGeeArrayListTest.vala"
		_tmp283_ = _tmp282_;
#line 295 "SerializableGeeArrayListTest.vala"
		_tmp284_ = gxml_serializable_get_serialized_xml_node_value ((GXmlSerializable*) _tmp283_);
#line 295 "SerializableGeeArrayListTest.vala"
		_tmp285_ = _tmp284_;
#line 295 "SerializableGeeArrayListTest.vala"
		_tmp286_ = _tmp285_;
#line 295 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp286_ != NULL, "bagt.bags[0].balls[0].ballfill.serialized_xml_node_value !=null");
#line 295 "SerializableGeeArrayListTest.vala"
		_g_free0 (_tmp286_);
#line 295 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp281_);
#line 295 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp277_);
#line 296 "SerializableGeeArrayListTest.vala"
		_tmp287_ = bagt;
#line 296 "SerializableGeeArrayListTest.vala"
		_tmp288_ = serializable_gee_array_list_test_big_bag_get_bags (_tmp287_);
#line 296 "SerializableGeeArrayListTest.vala"
		_tmp289_ = _tmp288_;
#line 296 "SerializableGeeArrayListTest.vala"
		_tmp290_ = gee_abstract_list_get ((GeeAbstractList*) _tmp289_, 0);
#line 296 "SerializableGeeArrayListTest.vala"
		_tmp291_ = (SerializableGeeArrayListTestSmallBag*) _tmp290_;
#line 296 "SerializableGeeArrayListTest.vala"
		_tmp292_ = serializable_gee_array_list_test_small_bag_get_balls (_tmp291_);
#line 296 "SerializableGeeArrayListTest.vala"
		_tmp293_ = _tmp292_;
#line 296 "SerializableGeeArrayListTest.vala"
		_tmp294_ = gee_abstract_list_get ((GeeAbstractList*) _tmp293_, 0);
#line 296 "SerializableGeeArrayListTest.vala"
		_tmp295_ = (SerializableGeeArrayListTestBall*) _tmp294_;
#line 296 "SerializableGeeArrayListTest.vala"
		_tmp296_ = serializable_gee_array_list_test_ball_get_ballfill (_tmp295_);
#line 296 "SerializableGeeArrayListTest.vala"
		_tmp297_ = _tmp296_;
#line 296 "SerializableGeeArrayListTest.vala"
		_tmp298_ = gxml_serializable_get_serialized_xml_node_value ((GXmlSerializable*) _tmp297_);
#line 296 "SerializableGeeArrayListTest.vala"
		_tmp299_ = _tmp298_;
#line 296 "SerializableGeeArrayListTest.vala"
		_tmp300_ = _tmp299_;
#line 296 "SerializableGeeArrayListTest.vala"
		_vala_assert (g_strcmp0 (_tmp300_, "golden dust") == 0, "bagt.bags[0].balls[0].ballfill.serialized_xml_node_value ==\"golden dust\"");
#line 296 "SerializableGeeArrayListTest.vala"
		_g_free0 (_tmp300_);
#line 296 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp295_);
#line 296 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp291_);
#line 297 "SerializableGeeArrayListTest.vala"
		_tmp301_ = serializable_gee_array_list_test_big_bag_new ();
#line 297 "SerializableGeeArrayListTest.vala"
		bag2 = _tmp301_;
#line 298 "SerializableGeeArrayListTest.vala"
		_tmp302_ = bag2;
#line 298 "SerializableGeeArrayListTest.vala"
		_tmp303_ = d;
#line 298 "SerializableGeeArrayListTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp302_, (GXmlNode*) _tmp303_, &_inner_error0_);
#line 298 "SerializableGeeArrayListTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 298 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (bag2);
#line 298 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (bagt);
#line 298 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (d);
#line 298 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (bag);
#line 4245 "SerializableGeeArrayListTest.c"
			goto __catch361_g_error;
		}
#line 299 "SerializableGeeArrayListTest.vala"
		_tmp304_ = bag2;
#line 299 "SerializableGeeArrayListTest.vala"
		_tmp305_ = serializable_gee_array_list_test_big_bag_get_bags (_tmp304_);
#line 299 "SerializableGeeArrayListTest.vala"
		_tmp306_ = _tmp305_;
#line 299 "SerializableGeeArrayListTest.vala"
		_tmp307_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp306_);
#line 299 "SerializableGeeArrayListTest.vala"
		_tmp308_ = _tmp307_;
#line 299 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp308_ == 0, "bag2.bags.size == 0");
#line 301 "SerializableGeeArrayListTest.vala"
		_tmp309_ = gxml_gdocument_new ();
#line 301 "SerializableGeeArrayListTest.vala"
		d2 = _tmp309_;
#line 302 "SerializableGeeArrayListTest.vala"
		_tmp310_ = bag2;
#line 302 "SerializableGeeArrayListTest.vala"
		_tmp311_ = d2;
#line 302 "SerializableGeeArrayListTest.vala"
		_tmp312_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp310_, (GXmlNode*) _tmp311_, &_inner_error0_);
#line 302 "SerializableGeeArrayListTest.vala"
		_tmp313_ = _tmp312_;
#line 302 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp313_);
#line 302 "SerializableGeeArrayListTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 302 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (d2);
#line 302 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (bag2);
#line 302 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (bagt);
#line 302 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (d);
#line 302 "SerializableGeeArrayListTest.vala"
			_g_object_unref0 (bag);
#line 4286 "SerializableGeeArrayListTest.c"
			goto __catch361_g_error;
		}
#line 304 "SerializableGeeArrayListTest.vala"
		_tmp314_ = d2;
#line 304 "SerializableGeeArrayListTest.vala"
		_tmp315_ = gxml_document_get_root ((GXmlDocument*) _tmp314_);
#line 304 "SerializableGeeArrayListTest.vala"
		_tmp316_ = _tmp315_;
#line 304 "SerializableGeeArrayListTest.vala"
		_tmp317_ = _tmp316_;
#line 304 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp317_ != NULL, "d2.root != null");
#line 304 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp317_);
#line 305 "SerializableGeeArrayListTest.vala"
		_tmp318_ = d2;
#line 305 "SerializableGeeArrayListTest.vala"
		_tmp319_ = gxml_document_get_root ((GXmlDocument*) _tmp318_);
#line 305 "SerializableGeeArrayListTest.vala"
		_tmp320_ = _tmp319_;
#line 305 "SerializableGeeArrayListTest.vala"
		_tmp321_ = _tmp320_;
#line 305 "SerializableGeeArrayListTest.vala"
		_tmp322_ = gxml_node_get_name (_tmp321_);
#line 305 "SerializableGeeArrayListTest.vala"
		_tmp323_ = _tmp322_;
#line 305 "SerializableGeeArrayListTest.vala"
		_tmp324_ = _tmp323_;
#line 305 "SerializableGeeArrayListTest.vala"
		_vala_assert (g_strcmp0 (_tmp324_, "BigBag") == 0, "d2.root.name == \"BigBag\"");
#line 305 "SerializableGeeArrayListTest.vala"
		_g_free0 (_tmp324_);
#line 305 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp321_);
#line 306 "SerializableGeeArrayListTest.vala"
		_tmp325_ = d2;
#line 306 "SerializableGeeArrayListTest.vala"
		_tmp326_ = gxml_document_get_root ((GXmlDocument*) _tmp325_);
#line 306 "SerializableGeeArrayListTest.vala"
		_tmp327_ = _tmp326_;
#line 306 "SerializableGeeArrayListTest.vala"
		_tmp328_ = _tmp327_;
#line 306 "SerializableGeeArrayListTest.vala"
		_tmp329_ = gxml_node_get_children_nodes (_tmp328_);
#line 306 "SerializableGeeArrayListTest.vala"
		_tmp330_ = _tmp329_;
#line 306 "SerializableGeeArrayListTest.vala"
		_tmp331_ = _tmp330_;
#line 306 "SerializableGeeArrayListTest.vala"
		_tmp332_ = gee_collection_get_size ((GeeCollection*) _tmp331_);
#line 306 "SerializableGeeArrayListTest.vala"
		_tmp333_ = _tmp332_;
#line 306 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp333_ == 2, "d2.root.children_nodes.size == 2");
#line 306 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp331_);
#line 306 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp328_);
#line 307 "SerializableGeeArrayListTest.vala"
		_tmp334_ = d2;
#line 307 "SerializableGeeArrayListTest.vala"
		_tmp335_ = gxml_document_get_root ((GXmlDocument*) _tmp334_);
#line 307 "SerializableGeeArrayListTest.vala"
		_tmp336_ = _tmp335_;
#line 307 "SerializableGeeArrayListTest.vala"
		_tmp337_ = _tmp336_;
#line 307 "SerializableGeeArrayListTest.vala"
		_tmp338_ = gxml_node_get_children_nodes (_tmp337_);
#line 307 "SerializableGeeArrayListTest.vala"
		_tmp339_ = _tmp338_;
#line 307 "SerializableGeeArrayListTest.vala"
		_tmp340_ = _tmp339_;
#line 307 "SerializableGeeArrayListTest.vala"
		_tmp341_ = gee_list_get ((GeeList*) _tmp340_, 0);
#line 307 "SerializableGeeArrayListTest.vala"
		_tmp342_ = (GXmlNode*) _tmp341_;
#line 307 "SerializableGeeArrayListTest.vala"
		_tmp343_ = gxml_node_get_name (_tmp342_);
#line 307 "SerializableGeeArrayListTest.vala"
		_tmp344_ = _tmp343_;
#line 307 "SerializableGeeArrayListTest.vala"
		_tmp345_ = _tmp344_;
#line 307 "SerializableGeeArrayListTest.vala"
		_vala_assert (g_strcmp0 (_tmp345_, "SmallBag") == 0, "d2.root.children_nodes[0].name == \"SmallBag\"");
#line 307 "SerializableGeeArrayListTest.vala"
		_g_free0 (_tmp345_);
#line 307 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp342_);
#line 307 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp340_);
#line 307 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp337_);
#line 308 "SerializableGeeArrayListTest.vala"
		_tmp346_ = d2;
#line 308 "SerializableGeeArrayListTest.vala"
		_tmp347_ = gxml_document_get_root ((GXmlDocument*) _tmp346_);
#line 308 "SerializableGeeArrayListTest.vala"
		_tmp348_ = _tmp347_;
#line 308 "SerializableGeeArrayListTest.vala"
		_tmp349_ = _tmp348_;
#line 308 "SerializableGeeArrayListTest.vala"
		_tmp350_ = gxml_node_get_children_nodes (_tmp349_);
#line 308 "SerializableGeeArrayListTest.vala"
		_tmp351_ = _tmp350_;
#line 308 "SerializableGeeArrayListTest.vala"
		_tmp352_ = _tmp351_;
#line 308 "SerializableGeeArrayListTest.vala"
		_tmp353_ = gee_list_get ((GeeList*) _tmp352_, 0);
#line 308 "SerializableGeeArrayListTest.vala"
		_tmp354_ = (GXmlNode*) _tmp353_;
#line 308 "SerializableGeeArrayListTest.vala"
		_tmp355_ = gxml_node_get_children_nodes (_tmp354_);
#line 308 "SerializableGeeArrayListTest.vala"
		_tmp356_ = _tmp355_;
#line 308 "SerializableGeeArrayListTest.vala"
		_tmp357_ = _tmp356_;
#line 308 "SerializableGeeArrayListTest.vala"
		_tmp358_ = gee_collection_get_size ((GeeCollection*) _tmp357_);
#line 308 "SerializableGeeArrayListTest.vala"
		_tmp359_ = _tmp358_;
#line 308 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp359_ == 2, "d2.root.children_nodes[0].children_nodes.size == 2");
#line 308 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp357_);
#line 308 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp354_);
#line 308 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp352_);
#line 308 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp349_);
#line 309 "SerializableGeeArrayListTest.vala"
		_tmp360_ = d2;
#line 309 "SerializableGeeArrayListTest.vala"
		_tmp361_ = gxml_document_get_root ((GXmlDocument*) _tmp360_);
#line 309 "SerializableGeeArrayListTest.vala"
		_tmp362_ = _tmp361_;
#line 309 "SerializableGeeArrayListTest.vala"
		_tmp363_ = _tmp362_;
#line 309 "SerializableGeeArrayListTest.vala"
		_tmp364_ = gxml_node_get_children_nodes (_tmp363_);
#line 309 "SerializableGeeArrayListTest.vala"
		_tmp365_ = _tmp364_;
#line 309 "SerializableGeeArrayListTest.vala"
		_tmp366_ = _tmp365_;
#line 309 "SerializableGeeArrayListTest.vala"
		_tmp367_ = gee_list_get ((GeeList*) _tmp366_, 0);
#line 309 "SerializableGeeArrayListTest.vala"
		_tmp368_ = (GXmlNode*) _tmp367_;
#line 309 "SerializableGeeArrayListTest.vala"
		_tmp369_ = gxml_node_get_children_nodes (_tmp368_);
#line 309 "SerializableGeeArrayListTest.vala"
		_tmp370_ = _tmp369_;
#line 309 "SerializableGeeArrayListTest.vala"
		_tmp371_ = _tmp370_;
#line 309 "SerializableGeeArrayListTest.vala"
		_tmp372_ = gee_list_get ((GeeList*) _tmp371_, 0);
#line 309 "SerializableGeeArrayListTest.vala"
		_tmp373_ = (GXmlNode*) _tmp372_;
#line 309 "SerializableGeeArrayListTest.vala"
		_tmp374_ = gxml_node_get_name (_tmp373_);
#line 309 "SerializableGeeArrayListTest.vala"
		_tmp375_ = _tmp374_;
#line 309 "SerializableGeeArrayListTest.vala"
		_tmp376_ = _tmp375_;
#line 309 "SerializableGeeArrayListTest.vala"
		_vala_assert (g_strcmp0 (_tmp376_, "Ball") == 0, "d2.root.children_nodes[0].children_nodes[0].name == \"Ball\"");
#line 309 "SerializableGeeArrayListTest.vala"
		_g_free0 (_tmp376_);
#line 309 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp373_);
#line 309 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp371_);
#line 309 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp368_);
#line 309 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp366_);
#line 309 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp363_);
#line 310 "SerializableGeeArrayListTest.vala"
		_tmp377_ = d2;
#line 310 "SerializableGeeArrayListTest.vala"
		_tmp378_ = gxml_document_get_root ((GXmlDocument*) _tmp377_);
#line 310 "SerializableGeeArrayListTest.vala"
		_tmp379_ = _tmp378_;
#line 310 "SerializableGeeArrayListTest.vala"
		_tmp380_ = _tmp379_;
#line 310 "SerializableGeeArrayListTest.vala"
		_tmp381_ = gxml_node_get_children_nodes (_tmp380_);
#line 310 "SerializableGeeArrayListTest.vala"
		_tmp382_ = _tmp381_;
#line 310 "SerializableGeeArrayListTest.vala"
		_tmp383_ = _tmp382_;
#line 310 "SerializableGeeArrayListTest.vala"
		_tmp384_ = gee_list_get ((GeeList*) _tmp383_, 0);
#line 310 "SerializableGeeArrayListTest.vala"
		_tmp385_ = (GXmlNode*) _tmp384_;
#line 310 "SerializableGeeArrayListTest.vala"
		_tmp386_ = gxml_node_get_children_nodes (_tmp385_);
#line 310 "SerializableGeeArrayListTest.vala"
		_tmp387_ = _tmp386_;
#line 310 "SerializableGeeArrayListTest.vala"
		_tmp388_ = _tmp387_;
#line 310 "SerializableGeeArrayListTest.vala"
		_tmp389_ = gee_list_get ((GeeList*) _tmp388_, 0);
#line 310 "SerializableGeeArrayListTest.vala"
		_tmp390_ = (GXmlNode*) _tmp389_;
#line 310 "SerializableGeeArrayListTest.vala"
		_tmp391_ = gxml_node_get_children_nodes (_tmp390_);
#line 310 "SerializableGeeArrayListTest.vala"
		_tmp392_ = _tmp391_;
#line 310 "SerializableGeeArrayListTest.vala"
		_tmp393_ = _tmp392_;
#line 310 "SerializableGeeArrayListTest.vala"
		_tmp394_ = gee_collection_get_size ((GeeCollection*) _tmp393_);
#line 310 "SerializableGeeArrayListTest.vala"
		_tmp395_ = _tmp394_;
#line 310 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp395_ == 1, "d2.root.children_nodes[0].children_nodes[0].children_nodes.size == 1");
#line 310 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp393_);
#line 310 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp390_);
#line 310 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp388_);
#line 310 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp385_);
#line 310 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp383_);
#line 310 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp380_);
#line 311 "SerializableGeeArrayListTest.vala"
		_tmp396_ = d2;
#line 311 "SerializableGeeArrayListTest.vala"
		_tmp397_ = gxml_document_get_root ((GXmlDocument*) _tmp396_);
#line 311 "SerializableGeeArrayListTest.vala"
		_tmp398_ = _tmp397_;
#line 311 "SerializableGeeArrayListTest.vala"
		_tmp399_ = _tmp398_;
#line 311 "SerializableGeeArrayListTest.vala"
		_tmp400_ = gxml_node_get_children_nodes (_tmp399_);
#line 311 "SerializableGeeArrayListTest.vala"
		_tmp401_ = _tmp400_;
#line 311 "SerializableGeeArrayListTest.vala"
		_tmp402_ = _tmp401_;
#line 311 "SerializableGeeArrayListTest.vala"
		_tmp403_ = gee_list_get ((GeeList*) _tmp402_, 0);
#line 311 "SerializableGeeArrayListTest.vala"
		_tmp404_ = (GXmlNode*) _tmp403_;
#line 311 "SerializableGeeArrayListTest.vala"
		_tmp405_ = gxml_node_get_children_nodes (_tmp404_);
#line 311 "SerializableGeeArrayListTest.vala"
		_tmp406_ = _tmp405_;
#line 311 "SerializableGeeArrayListTest.vala"
		_tmp407_ = _tmp406_;
#line 311 "SerializableGeeArrayListTest.vala"
		_tmp408_ = gee_list_get ((GeeList*) _tmp407_, 0);
#line 311 "SerializableGeeArrayListTest.vala"
		_tmp409_ = (GXmlNode*) _tmp408_;
#line 311 "SerializableGeeArrayListTest.vala"
		_tmp410_ = gxml_node_get_children_nodes (_tmp409_);
#line 311 "SerializableGeeArrayListTest.vala"
		_tmp411_ = _tmp410_;
#line 311 "SerializableGeeArrayListTest.vala"
		_tmp412_ = _tmp411_;
#line 311 "SerializableGeeArrayListTest.vala"
		_tmp413_ = gee_list_get ((GeeList*) _tmp412_, 0);
#line 311 "SerializableGeeArrayListTest.vala"
		_tmp414_ = (GXmlNode*) _tmp413_;
#line 311 "SerializableGeeArrayListTest.vala"
		_tmp415_ = gxml_node_get_name (_tmp414_);
#line 311 "SerializableGeeArrayListTest.vala"
		_tmp416_ = _tmp415_;
#line 311 "SerializableGeeArrayListTest.vala"
		_tmp417_ = _tmp416_;
#line 311 "SerializableGeeArrayListTest.vala"
		_vala_assert (g_strcmp0 (_tmp417_, "BallFill") == 0, "d2.root.children_nodes[0].children_nodes[0].children_nodes[0].name == \"BallFill\"");
#line 311 "SerializableGeeArrayListTest.vala"
		_g_free0 (_tmp417_);
#line 311 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp414_);
#line 311 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp412_);
#line 311 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp409_);
#line 311 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp407_);
#line 311 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp404_);
#line 311 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp402_);
#line 311 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp399_);
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp418_ = d2;
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp419_ = gxml_document_get_root ((GXmlDocument*) _tmp418_);
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp420_ = _tmp419_;
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp421_ = _tmp420_;
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp422_ = gxml_node_get_children_nodes (_tmp421_);
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp423_ = _tmp422_;
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp424_ = _tmp423_;
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp425_ = gee_list_get ((GeeList*) _tmp424_, 0);
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp426_ = (GXmlNode*) _tmp425_;
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp427_ = gxml_node_get_children_nodes (_tmp426_);
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp428_ = _tmp427_;
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp429_ = _tmp428_;
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp430_ = gee_list_get ((GeeList*) _tmp429_, 0);
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp431_ = (GXmlNode*) _tmp430_;
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp432_ = gxml_node_get_children_nodes (_tmp431_);
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp433_ = _tmp432_;
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp434_ = _tmp433_;
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp435_ = gee_list_get ((GeeList*) _tmp434_, 0);
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp436_ = (GXmlNode*) _tmp435_;
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp437_ = gxml_node_get_children_nodes (_tmp436_);
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp438_ = _tmp437_;
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp439_ = _tmp438_;
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp440_ = gee_collection_get_size ((GeeCollection*) _tmp439_);
#line 312 "SerializableGeeArrayListTest.vala"
		_tmp441_ = _tmp440_;
#line 312 "SerializableGeeArrayListTest.vala"
		_vala_assert (_tmp441_ == 1, "d2.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes.size == 1");
#line 312 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp439_);
#line 312 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp436_);
#line 312 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp434_);
#line 312 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp431_);
#line 312 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp429_);
#line 312 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp426_);
#line 312 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp424_);
#line 312 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp421_);
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp442_ = d2;
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp443_ = gxml_document_get_root ((GXmlDocument*) _tmp442_);
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp444_ = _tmp443_;
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp445_ = _tmp444_;
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp446_ = gxml_node_get_children_nodes (_tmp445_);
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp447_ = _tmp446_;
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp448_ = _tmp447_;
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp449_ = gee_list_get ((GeeList*) _tmp448_, 0);
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp450_ = (GXmlNode*) _tmp449_;
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp451_ = gxml_node_get_children_nodes (_tmp450_);
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp452_ = _tmp451_;
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp453_ = _tmp452_;
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp454_ = gee_list_get ((GeeList*) _tmp453_, 0);
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp455_ = (GXmlNode*) _tmp454_;
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp456_ = gxml_node_get_children_nodes (_tmp455_);
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp457_ = _tmp456_;
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp458_ = _tmp457_;
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp459_ = gee_list_get ((GeeList*) _tmp458_, 0);
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp460_ = (GXmlNode*) _tmp459_;
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp461_ = gxml_node_get_children_nodes (_tmp460_);
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp462_ = _tmp461_;
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp463_ = _tmp462_;
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp464_ = gee_list_get ((GeeList*) _tmp463_, 0);
#line 313 "SerializableGeeArrayListTest.vala"
		_tmp465_ = (GXmlNode*) _tmp464_;
#line 313 "SerializableGeeArrayListTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp465_, GXML_TYPE_TEXT), "d2.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes[0] is GXml.Text");
#line 313 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp465_);
#line 313 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp463_);
#line 313 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp460_);
#line 313 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp458_);
#line 313 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp455_);
#line 313 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp453_);
#line 313 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp450_);
#line 313 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp448_);
#line 313 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp445_);
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp466_ = d2;
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp467_ = gxml_document_get_root ((GXmlDocument*) _tmp466_);
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp468_ = _tmp467_;
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp469_ = _tmp468_;
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp470_ = gxml_node_get_children_nodes (_tmp469_);
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp471_ = _tmp470_;
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp472_ = _tmp471_;
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp473_ = gee_list_get ((GeeList*) _tmp472_, 0);
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp474_ = (GXmlNode*) _tmp473_;
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp475_ = gxml_node_get_children_nodes (_tmp474_);
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp476_ = _tmp475_;
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp477_ = _tmp476_;
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp478_ = gee_list_get ((GeeList*) _tmp477_, 0);
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp479_ = (GXmlNode*) _tmp478_;
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp480_ = gxml_node_get_children_nodes (_tmp479_);
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp481_ = _tmp480_;
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp482_ = _tmp481_;
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp483_ = gee_list_get ((GeeList*) _tmp482_, 0);
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp484_ = (GXmlNode*) _tmp483_;
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp485_ = gxml_node_get_children_nodes (_tmp484_);
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp486_ = _tmp485_;
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp487_ = _tmp486_;
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp488_ = gee_list_get ((GeeList*) _tmp487_, 0);
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp489_ = (GXmlNode*) _tmp488_;
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp490_ = gxml_node_get_value (_tmp489_);
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp491_ = _tmp490_;
#line 314 "SerializableGeeArrayListTest.vala"
		_tmp492_ = _tmp491_;
#line 314 "SerializableGeeArrayListTest.vala"
		_vala_assert (g_strcmp0 (_tmp492_, "golden dust") == 0, "d2.root.children_nodes[0].children_nodes[0].children_nodes[0].children_nodes[0].value == \"golden dust\"");
#line 314 "SerializableGeeArrayListTest.vala"
		_g_free0 (_tmp492_);
#line 314 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp489_);
#line 314 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp487_);
#line 314 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp484_);
#line 314 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp482_);
#line 314 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp479_);
#line 314 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp477_);
#line 314 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp474_);
#line 314 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp472_);
#line 314 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (_tmp469_);
#line 254 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (d2);
#line 254 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (bag2);
#line 254 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (bagt);
#line 254 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (d);
#line 254 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (bag);
#line 4799 "SerializableGeeArrayListTest.c"
	}
	goto __finally361;
	__catch361_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp493_;
		gchar* _tmp494_;
		gchar* _tmp495_;
#line 254 "SerializableGeeArrayListTest.vala"
		e = _inner_error0_;
#line 254 "SerializableGeeArrayListTest.vala"
		_inner_error0_ = NULL;
#line 316 "SerializableGeeArrayListTest.vala"
		_tmp493_ = e->message;
#line 316 "SerializableGeeArrayListTest.vala"
		_tmp494_ = g_strconcat ("ERROR: ", _tmp493_, NULL);
#line 316 "SerializableGeeArrayListTest.vala"
		_tmp495_ = _tmp494_;
#line 316 "SerializableGeeArrayListTest.vala"
		g_message ("SerializableGeeArrayListTest.vala:316: %s", _tmp495_);
#line 316 "SerializableGeeArrayListTest.vala"
		_g_free0 (_tmp495_);
#line 317 "SerializableGeeArrayListTest.vala"
		g_assert_not_reached ();
#line 254 "SerializableGeeArrayListTest.vala"
		_g_error_free0 (e);
#line 4826 "SerializableGeeArrayListTest.c"
	}
	__finally361:
#line 254 "SerializableGeeArrayListTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 254 "SerializableGeeArrayListTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 254 "SerializableGeeArrayListTest.vala"
		g_clear_error (&_inner_error0_);
#line 254 "SerializableGeeArrayListTest.vala"
		return;
#line 4837 "SerializableGeeArrayListTest.c"
	}
}

static void
___lambda310__gtest_func (void)
{
#line 252 "SerializableGeeArrayListTest.vala"
	__lambda310_ ();
#line 4846 "SerializableGeeArrayListTest.c"
}

void
serializable_gee_array_list_test_add_tests (void)
{
#line 89 "SerializableGeeArrayListTest.vala"
	g_test_add_func ("/gxml/serializable/arraylist/api", ___lambda305__gtest_func);
#line 111 "SerializableGeeArrayListTest.vala"
	g_test_add_func ("/gxml/serializable/arraylist/serialize", ___lambda306__gtest_func);
#line 149 "SerializableGeeArrayListTest.vala"
	g_test_add_func ("/gxml/serializable/arraylist/deserialize", ___lambda307__gtest_func);
#line 180 "SerializableGeeArrayListTest.vala"
	g_test_add_func ("/gxml/serializable/arraylist/deserialize-serialize", ___lambda308__gtest_func);
#line 223 "SerializableGeeArrayListTest.vala"
	g_test_add_func ("/gxml/serializable/arraylist/deserialize-node-names", ___lambda309__gtest_func);
#line 252 "SerializableGeeArrayListTest.vala"
	g_test_add_func ("/gxml/serializable/arraylist/post-deserialization/serialize/contents", ___lambda310__gtest_func);
#line 4864 "SerializableGeeArrayListTest.c"
}

SerializableGeeArrayListTest*
serializable_gee_array_list_test_construct (GType object_type)
{
	SerializableGeeArrayListTest* self = NULL;
#line 46 "SerializableGeeArrayListTest.vala"
	self = (SerializableGeeArrayListTest*) gxml_test_construct (object_type);
#line 46 "SerializableGeeArrayListTest.vala"
	return self;
#line 4875 "SerializableGeeArrayListTest.c"
}

SerializableGeeArrayListTest*
serializable_gee_array_list_test_new (void)
{
#line 46 "SerializableGeeArrayListTest.vala"
	return serializable_gee_array_list_test_construct (TYPE_SERIALIZABLE_GEE_ARRAY_LIST_TEST);
#line 4883 "SerializableGeeArrayListTest.c"
}

static inline gpointer
serializable_gee_array_list_test_ball_fill_get_instance_private (SerializableGeeArrayListTestBallFill* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeArrayListTestBallFill_private_offset);
}

static void
serializable_gee_array_list_test_ball_fill_set_text (SerializableGeeArrayListTestBallFill* self,
                                                     const gchar* txt)
{
#line 51 "SerializableGeeArrayListTest.vala"
	g_return_if_fail (self != NULL);
#line 51 "SerializableGeeArrayListTest.vala"
	g_return_if_fail (txt != NULL);
#line 51 "SerializableGeeArrayListTest.vala"
	gxml_serializable_set_serialized_xml_node_value ((GXmlSerializable*) self, txt);
#line 4902 "SerializableGeeArrayListTest.c"
}

static gchar*
serializable_gee_array_list_test_ball_fill_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeArrayListTestBallFill * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 52 "SerializableGeeArrayListTest.vala"
	self = (SerializableGeeArrayListTestBallFill*) base;
#line 52 "SerializableGeeArrayListTest.vala"
	_tmp0_ = self->priv->_name;
#line 52 "SerializableGeeArrayListTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 52 "SerializableGeeArrayListTest.vala"
	result = _tmp1_;
#line 52 "SerializableGeeArrayListTest.vala"
	return result;
#line 4922 "SerializableGeeArrayListTest.c"
}

static gchar*
serializable_gee_array_list_test_ball_fill_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeArrayListTestBallFill * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 53 "SerializableGeeArrayListTest.vala"
	self = (SerializableGeeArrayListTestBallFill*) base;
#line 53 "SerializableGeeArrayListTest.vala"
	_tmp0_ = g_strdup ("BallFill");
#line 53 "SerializableGeeArrayListTest.vala"
	result = _tmp0_;
#line 53 "SerializableGeeArrayListTest.vala"
	return result;
#line 4939 "SerializableGeeArrayListTest.c"
}

static gboolean
serializable_gee_array_list_test_ball_fill_real_serialize_use_xml_node_value (GXmlSerializableObjectModel* base)
{
	SerializableGeeArrayListTestBallFill * self;
	gboolean result = FALSE;
#line 54 "SerializableGeeArrayListTest.vala"
	self = (SerializableGeeArrayListTestBallFill*) base;
#line 54 "SerializableGeeArrayListTest.vala"
	result = TRUE;
#line 54 "SerializableGeeArrayListTest.vala"
	return result;
#line 4953 "SerializableGeeArrayListTest.c"
}

static SerializableGeeArrayListTestBallFill*
serializable_gee_array_list_test_ball_fill_construct (GType object_type)
{
	SerializableGeeArrayListTestBallFill * self = NULL;
#line 48 "SerializableGeeArrayListTest.vala"
	self = (SerializableGeeArrayListTestBallFill*) gxml_serializable_object_model_construct (object_type);
#line 48 "SerializableGeeArrayListTest.vala"
	return self;
#line 4964 "SerializableGeeArrayListTest.c"
}

static SerializableGeeArrayListTestBallFill*
serializable_gee_array_list_test_ball_fill_new (void)
{
#line 48 "SerializableGeeArrayListTest.vala"
	return serializable_gee_array_list_test_ball_fill_construct (SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BALL_FILL);
#line 4972 "SerializableGeeArrayListTest.c"
}

static const gchar*
serializable_gee_array_list_test_ball_fill_get_name (SerializableGeeArrayListTestBallFill* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 50 "SerializableGeeArrayListTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 50 "SerializableGeeArrayListTest.vala"
	_tmp0_ = self->priv->_name;
#line 50 "SerializableGeeArrayListTest.vala"
	result = _tmp0_;
#line 50 "SerializableGeeArrayListTest.vala"
	return result;
#line 4988 "SerializableGeeArrayListTest.c"
}

static void
serializable_gee_array_list_test_ball_fill_set_name (SerializableGeeArrayListTestBallFill* self,
                                                     const gchar* value)
{
#line 50 "SerializableGeeArrayListTest.vala"
	g_return_if_fail (self != NULL);
#line 50 "SerializableGeeArrayListTest.vala"
	if (g_strcmp0 (value, serializable_gee_array_list_test_ball_fill_get_name (self)) != 0) {
#line 4999 "SerializableGeeArrayListTest.c"
		gchar* _tmp0_;
#line 50 "SerializableGeeArrayListTest.vala"
		_tmp0_ = g_strdup (value);
#line 50 "SerializableGeeArrayListTest.vala"
		_g_free0 (self->priv->_name);
#line 50 "SerializableGeeArrayListTest.vala"
		self->priv->_name = _tmp0_;
#line 50 "SerializableGeeArrayListTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_array_list_test_ball_fill_properties[SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_FILL_NAME_PROPERTY]);
#line 5009 "SerializableGeeArrayListTest.c"
	}
}

static void
serializable_gee_array_list_test_ball_fill_class_init (SerializableGeeArrayListTestBallFillClass * klass,
                                                       gpointer klass_data)
{
#line 48 "SerializableGeeArrayListTest.vala"
	serializable_gee_array_list_test_ball_fill_parent_class = g_type_class_peek_parent (klass);
#line 48 "SerializableGeeArrayListTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeArrayListTestBallFill_private_offset);
#line 48 "SerializableGeeArrayListTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_array_list_test_ball_fill_real_to_string;
#line 48 "SerializableGeeArrayListTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_array_list_test_ball_fill_real_node_name;
#line 48 "SerializableGeeArrayListTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->serialize_use_xml_node_value = (gboolean (*) (GXmlSerializableObjectModel*)) serializable_gee_array_list_test_ball_fill_real_serialize_use_xml_node_value;
#line 48 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_array_list_test_ball_fill_get_property;
#line 48 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_array_list_test_ball_fill_set_property;
#line 48 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_array_list_test_ball_fill_finalize;
#line 48 "SerializableGeeArrayListTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_FILL_NAME_PROPERTY, serializable_gee_array_list_test_ball_fill_properties[SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_FILL_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5035 "SerializableGeeArrayListTest.c"
}

static void
serializable_gee_array_list_test_ball_fill_instance_init (SerializableGeeArrayListTestBallFill * self,
                                                          gpointer klass)
{
	gchar* _tmp0_;
#line 48 "SerializableGeeArrayListTest.vala"
	self->priv = serializable_gee_array_list_test_ball_fill_get_instance_private (self);
#line 50 "SerializableGeeArrayListTest.vala"
	_tmp0_ = g_strdup ("Fill");
#line 50 "SerializableGeeArrayListTest.vala"
	self->priv->_name = _tmp0_;
#line 5049 "SerializableGeeArrayListTest.c"
}

static void
serializable_gee_array_list_test_ball_fill_finalize (GObject * obj)
{
	SerializableGeeArrayListTestBallFill * self;
#line 48 "SerializableGeeArrayListTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BALL_FILL, SerializableGeeArrayListTestBallFill);
#line 50 "SerializableGeeArrayListTest.vala"
	_g_free0 (self->priv->_name);
#line 48 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (serializable_gee_array_list_test_ball_fill_parent_class)->finalize (obj);
#line 5062 "SerializableGeeArrayListTest.c"
}

static GType
serializable_gee_array_list_test_ball_fill_get_type (void)
{
	static volatile gsize serializable_gee_array_list_test_ball_fill_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_array_list_test_ball_fill_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeArrayListTestBallFillClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_array_list_test_ball_fill_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeArrayListTestBallFill), 0, (GInstanceInitFunc) serializable_gee_array_list_test_ball_fill_instance_init, NULL };
		GType serializable_gee_array_list_test_ball_fill_type_id;
		serializable_gee_array_list_test_ball_fill_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeArrayListTestBallFill", &g_define_type_info, 0);
		SerializableGeeArrayListTestBallFill_private_offset = g_type_add_instance_private (serializable_gee_array_list_test_ball_fill_type_id, sizeof (SerializableGeeArrayListTestBallFillPrivate));
		g_once_init_leave (&serializable_gee_array_list_test_ball_fill_type_id__volatile, serializable_gee_array_list_test_ball_fill_type_id);
	}
	return serializable_gee_array_list_test_ball_fill_type_id__volatile;
}

static void
_vala_serializable_gee_array_list_test_ball_fill_get_property (GObject * object,
                                                               guint property_id,
                                                               GValue * value,
                                                               GParamSpec * pspec)
{
	SerializableGeeArrayListTestBallFill * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BALL_FILL, SerializableGeeArrayListTestBallFill);
#line 48 "SerializableGeeArrayListTest.vala"
	switch (property_id) {
#line 48 "SerializableGeeArrayListTest.vala"
		case SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_FILL_NAME_PROPERTY:
#line 48 "SerializableGeeArrayListTest.vala"
		g_value_set_string (value, serializable_gee_array_list_test_ball_fill_get_name (self));
#line 48 "SerializableGeeArrayListTest.vala"
		break;
#line 5095 "SerializableGeeArrayListTest.c"
		default:
#line 48 "SerializableGeeArrayListTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 48 "SerializableGeeArrayListTest.vala"
		break;
#line 5101 "SerializableGeeArrayListTest.c"
	}
}

static void
_vala_serializable_gee_array_list_test_ball_fill_set_property (GObject * object,
                                                               guint property_id,
                                                               const GValue * value,
                                                               GParamSpec * pspec)
{
	SerializableGeeArrayListTestBallFill * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BALL_FILL, SerializableGeeArrayListTestBallFill);
#line 48 "SerializableGeeArrayListTest.vala"
	switch (property_id) {
#line 48 "SerializableGeeArrayListTest.vala"
		case SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_FILL_NAME_PROPERTY:
#line 48 "SerializableGeeArrayListTest.vala"
		serializable_gee_array_list_test_ball_fill_set_name (self, g_value_get_string (value));
#line 48 "SerializableGeeArrayListTest.vala"
		break;
#line 5121 "SerializableGeeArrayListTest.c"
		default:
#line 48 "SerializableGeeArrayListTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 48 "SerializableGeeArrayListTest.vala"
		break;
#line 5127 "SerializableGeeArrayListTest.c"
	}
}

static inline gpointer
serializable_gee_array_list_test_ball_get_instance_private (SerializableGeeArrayListTestBall* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeArrayListTestBall_private_offset);
}

static gchar*
serializable_gee_array_list_test_ball_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeArrayListTestBall * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 61 "SerializableGeeArrayListTest.vala"
	self = (SerializableGeeArrayListTestBall*) base;
#line 61 "SerializableGeeArrayListTest.vala"
	_tmp0_ = self->priv->_name;
#line 61 "SerializableGeeArrayListTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 61 "SerializableGeeArrayListTest.vala"
	result = _tmp1_;
#line 61 "SerializableGeeArrayListTest.vala"
	return result;
#line 5154 "SerializableGeeArrayListTest.c"
}

static gchar*
serializable_gee_array_list_test_ball_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeArrayListTestBall * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 62 "SerializableGeeArrayListTest.vala"
	self = (SerializableGeeArrayListTestBall*) base;
#line 62 "SerializableGeeArrayListTest.vala"
	_tmp0_ = g_strdup ("Ball");
#line 62 "SerializableGeeArrayListTest.vala"
	result = _tmp0_;
#line 62 "SerializableGeeArrayListTest.vala"
	return result;
#line 5171 "SerializableGeeArrayListTest.c"
}

static SerializableGeeArrayListTestBall*
serializable_gee_array_list_test_ball_construct (GType object_type)
{
	SerializableGeeArrayListTestBall * self = NULL;
#line 57 "SerializableGeeArrayListTest.vala"
	self = (SerializableGeeArrayListTestBall*) gxml_serializable_object_model_construct (object_type);
#line 57 "SerializableGeeArrayListTest.vala"
	return self;
#line 5182 "SerializableGeeArrayListTest.c"
}

static SerializableGeeArrayListTestBall*
serializable_gee_array_list_test_ball_new (void)
{
#line 57 "SerializableGeeArrayListTest.vala"
	return serializable_gee_array_list_test_ball_construct (SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BALL);
#line 5190 "SerializableGeeArrayListTest.c"
}

static const gchar*
serializable_gee_array_list_test_ball_get_name (SerializableGeeArrayListTestBall* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 59 "SerializableGeeArrayListTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 59 "SerializableGeeArrayListTest.vala"
	_tmp0_ = self->priv->_name;
#line 59 "SerializableGeeArrayListTest.vala"
	result = _tmp0_;
#line 59 "SerializableGeeArrayListTest.vala"
	return result;
#line 5206 "SerializableGeeArrayListTest.c"
}

static void
serializable_gee_array_list_test_ball_set_name (SerializableGeeArrayListTestBall* self,
                                                const gchar* value)
{
#line 59 "SerializableGeeArrayListTest.vala"
	g_return_if_fail (self != NULL);
#line 59 "SerializableGeeArrayListTest.vala"
	if (g_strcmp0 (value, serializable_gee_array_list_test_ball_get_name (self)) != 0) {
#line 5217 "SerializableGeeArrayListTest.c"
		gchar* _tmp0_;
#line 59 "SerializableGeeArrayListTest.vala"
		_tmp0_ = g_strdup (value);
#line 59 "SerializableGeeArrayListTest.vala"
		_g_free0 (self->priv->_name);
#line 59 "SerializableGeeArrayListTest.vala"
		self->priv->_name = _tmp0_;
#line 59 "SerializableGeeArrayListTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_array_list_test_ball_properties[SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_NAME_PROPERTY]);
#line 5227 "SerializableGeeArrayListTest.c"
	}
}

static SerializableGeeArrayListTestBallFill*
serializable_gee_array_list_test_ball_get_ballfill (SerializableGeeArrayListTestBall* self)
{
	SerializableGeeArrayListTestBallFill* result;
	SerializableGeeArrayListTestBallFill* _tmp0_;
#line 60 "SerializableGeeArrayListTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 60 "SerializableGeeArrayListTest.vala"
	_tmp0_ = self->priv->_ballfill;
#line 60 "SerializableGeeArrayListTest.vala"
	result = _tmp0_;
#line 60 "SerializableGeeArrayListTest.vala"
	return result;
#line 5244 "SerializableGeeArrayListTest.c"
}

static void
serializable_gee_array_list_test_ball_set_ballfill (SerializableGeeArrayListTestBall* self,
                                                    SerializableGeeArrayListTestBallFill* value)
{
#line 60 "SerializableGeeArrayListTest.vala"
	g_return_if_fail (self != NULL);
#line 60 "SerializableGeeArrayListTest.vala"
	if (serializable_gee_array_list_test_ball_get_ballfill (self) != value) {
#line 5255 "SerializableGeeArrayListTest.c"
		SerializableGeeArrayListTestBallFill* _tmp0_;
#line 60 "SerializableGeeArrayListTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 60 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (self->priv->_ballfill);
#line 60 "SerializableGeeArrayListTest.vala"
		self->priv->_ballfill = _tmp0_;
#line 60 "SerializableGeeArrayListTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_array_list_test_ball_properties[SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_BALLFILL_PROPERTY]);
#line 5265 "SerializableGeeArrayListTest.c"
	}
}

static gboolean
serializable_gee_array_list_test_ball_array_real_deserialize_proceed (GXmlSerializableArrayList* base)
{
	SerializableGeeArrayListTestBallArray * self;
	gboolean result = FALSE;
#line 64 "SerializableGeeArrayListTest.vala"
	self = (SerializableGeeArrayListTestBallArray*) base;
#line 64 "SerializableGeeArrayListTest.vala"
	result = FALSE;
#line 64 "SerializableGeeArrayListTest.vala"
	return result;
#line 5280 "SerializableGeeArrayListTest.c"
}

static SerializableGeeArrayListTestBallArray*
serializable_gee_array_list_test_ball_array_construct (GType object_type)
{
	SerializableGeeArrayListTestBallArray * self = NULL;
#line 63 "SerializableGeeArrayListTest.vala"
	self = (SerializableGeeArrayListTestBallArray*) gxml_serializable_array_list_construct (object_type, SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BALL, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 63 "SerializableGeeArrayListTest.vala"
	return self;
#line 5291 "SerializableGeeArrayListTest.c"
}

static SerializableGeeArrayListTestBallArray*
serializable_gee_array_list_test_ball_array_new (void)
{
#line 63 "SerializableGeeArrayListTest.vala"
	return serializable_gee_array_list_test_ball_array_construct (SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_TYPE_ARRAY);
#line 5299 "SerializableGeeArrayListTest.c"
}

static void
serializable_gee_array_list_test_ball_array_class_init (SerializableGeeArrayListTestBallArrayClass * klass,
                                                        gpointer klass_data)
{
#line 63 "SerializableGeeArrayListTest.vala"
	serializable_gee_array_list_test_ball_array_parent_class = g_type_class_peek_parent (klass);
#line 63 "SerializableGeeArrayListTest.vala"
	((GXmlSerializableArrayListClass *) klass)->deserialize_proceed = (gboolean (*) (GXmlSerializableArrayList*)) serializable_gee_array_list_test_ball_array_real_deserialize_proceed;
#line 5310 "SerializableGeeArrayListTest.c"
}

static void
serializable_gee_array_list_test_ball_array_instance_init (SerializableGeeArrayListTestBallArray * self,
                                                           gpointer klass)
{
}

GType
serializable_gee_array_list_test_ball_array_get_type (void)
{
	static volatile gsize serializable_gee_array_list_test_ball_array_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_array_list_test_ball_array_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeArrayListTestBallArrayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_array_list_test_ball_array_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeArrayListTestBallArray), 0, (GInstanceInitFunc) serializable_gee_array_list_test_ball_array_instance_init, NULL };
		GType serializable_gee_array_list_test_ball_array_type_id;
		serializable_gee_array_list_test_ball_array_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_ARRAY_LIST, "SerializableGeeArrayListTestBallArray", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_array_list_test_ball_array_type_id__volatile, serializable_gee_array_list_test_ball_array_type_id);
	}
	return serializable_gee_array_list_test_ball_array_type_id__volatile;
}

static void
serializable_gee_array_list_test_ball_class_init (SerializableGeeArrayListTestBallClass * klass,
                                                  gpointer klass_data)
{
#line 57 "SerializableGeeArrayListTest.vala"
	serializable_gee_array_list_test_ball_parent_class = g_type_class_peek_parent (klass);
#line 57 "SerializableGeeArrayListTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeArrayListTestBall_private_offset);
#line 57 "SerializableGeeArrayListTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_array_list_test_ball_real_to_string;
#line 57 "SerializableGeeArrayListTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_array_list_test_ball_real_node_name;
#line 57 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_array_list_test_ball_get_property;
#line 57 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_array_list_test_ball_set_property;
#line 57 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_array_list_test_ball_finalize;
#line 57 "SerializableGeeArrayListTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_NAME_PROPERTY, serializable_gee_array_list_test_ball_properties[SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 57 "SerializableGeeArrayListTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_BALLFILL_PROPERTY, serializable_gee_array_list_test_ball_properties[SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_BALLFILL_PROPERTY] = g_param_spec_object ("ballfill", "ballfill", "ballfill", SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BALL_FILL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5354 "SerializableGeeArrayListTest.c"
}

static void
serializable_gee_array_list_test_ball_instance_init (SerializableGeeArrayListTestBall * self,
                                                     gpointer klass)
{
	gchar* _tmp0_;
#line 57 "SerializableGeeArrayListTest.vala"
	self->priv = serializable_gee_array_list_test_ball_get_instance_private (self);
#line 59 "SerializableGeeArrayListTest.vala"
	_tmp0_ = g_strdup ("Ball");
#line 59 "SerializableGeeArrayListTest.vala"
	self->priv->_name = _tmp0_;
#line 5368 "SerializableGeeArrayListTest.c"
}

static void
serializable_gee_array_list_test_ball_finalize (GObject * obj)
{
	SerializableGeeArrayListTestBall * self;
#line 57 "SerializableGeeArrayListTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BALL, SerializableGeeArrayListTestBall);
#line 59 "SerializableGeeArrayListTest.vala"
	_g_free0 (self->priv->_name);
#line 60 "SerializableGeeArrayListTest.vala"
	_g_object_unref0 (self->priv->_ballfill);
#line 57 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (serializable_gee_array_list_test_ball_parent_class)->finalize (obj);
#line 5383 "SerializableGeeArrayListTest.c"
}

static GType
serializable_gee_array_list_test_ball_get_type (void)
{
	static volatile gsize serializable_gee_array_list_test_ball_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_array_list_test_ball_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeArrayListTestBallClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_array_list_test_ball_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeArrayListTestBall), 0, (GInstanceInitFunc) serializable_gee_array_list_test_ball_instance_init, NULL };
		GType serializable_gee_array_list_test_ball_type_id;
		serializable_gee_array_list_test_ball_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeArrayListTestBall", &g_define_type_info, 0);
		SerializableGeeArrayListTestBall_private_offset = g_type_add_instance_private (serializable_gee_array_list_test_ball_type_id, sizeof (SerializableGeeArrayListTestBallPrivate));
		g_once_init_leave (&serializable_gee_array_list_test_ball_type_id__volatile, serializable_gee_array_list_test_ball_type_id);
	}
	return serializable_gee_array_list_test_ball_type_id__volatile;
}

static void
_vala_serializable_gee_array_list_test_ball_get_property (GObject * object,
                                                          guint property_id,
                                                          GValue * value,
                                                          GParamSpec * pspec)
{
	SerializableGeeArrayListTestBall * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BALL, SerializableGeeArrayListTestBall);
#line 57 "SerializableGeeArrayListTest.vala"
	switch (property_id) {
#line 57 "SerializableGeeArrayListTest.vala"
		case SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_NAME_PROPERTY:
#line 57 "SerializableGeeArrayListTest.vala"
		g_value_set_string (value, serializable_gee_array_list_test_ball_get_name (self));
#line 57 "SerializableGeeArrayListTest.vala"
		break;
#line 57 "SerializableGeeArrayListTest.vala"
		case SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_BALLFILL_PROPERTY:
#line 57 "SerializableGeeArrayListTest.vala"
		g_value_set_object (value, serializable_gee_array_list_test_ball_get_ballfill (self));
#line 57 "SerializableGeeArrayListTest.vala"
		break;
#line 5422 "SerializableGeeArrayListTest.c"
		default:
#line 57 "SerializableGeeArrayListTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 57 "SerializableGeeArrayListTest.vala"
		break;
#line 5428 "SerializableGeeArrayListTest.c"
	}
}

static void
_vala_serializable_gee_array_list_test_ball_set_property (GObject * object,
                                                          guint property_id,
                                                          const GValue * value,
                                                          GParamSpec * pspec)
{
	SerializableGeeArrayListTestBall * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BALL, SerializableGeeArrayListTestBall);
#line 57 "SerializableGeeArrayListTest.vala"
	switch (property_id) {
#line 57 "SerializableGeeArrayListTest.vala"
		case SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_NAME_PROPERTY:
#line 57 "SerializableGeeArrayListTest.vala"
		serializable_gee_array_list_test_ball_set_name (self, g_value_get_string (value));
#line 57 "SerializableGeeArrayListTest.vala"
		break;
#line 57 "SerializableGeeArrayListTest.vala"
		case SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_BALLFILL_PROPERTY:
#line 57 "SerializableGeeArrayListTest.vala"
		serializable_gee_array_list_test_ball_set_ballfill (self, g_value_get_object (value));
#line 57 "SerializableGeeArrayListTest.vala"
		break;
#line 5454 "SerializableGeeArrayListTest.c"
		default:
#line 57 "SerializableGeeArrayListTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 57 "SerializableGeeArrayListTest.vala"
		break;
#line 5460 "SerializableGeeArrayListTest.c"
	}
}

static inline gpointer
serializable_gee_array_list_test_small_bag_get_instance_private (SerializableGeeArrayListTestSmallBag* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeArrayListTestSmallBag_private_offset);
}

static gchar*
serializable_gee_array_list_test_small_bag_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeArrayListTestSmallBag * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 72 "SerializableGeeArrayListTest.vala"
	self = (SerializableGeeArrayListTestSmallBag*) base;
#line 72 "SerializableGeeArrayListTest.vala"
	_tmp0_ = self->priv->_name;
#line 72 "SerializableGeeArrayListTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 72 "SerializableGeeArrayListTest.vala"
	result = _tmp1_;
#line 72 "SerializableGeeArrayListTest.vala"
	return result;
#line 5487 "SerializableGeeArrayListTest.c"
}

static gchar*
serializable_gee_array_list_test_small_bag_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeArrayListTestSmallBag * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 73 "SerializableGeeArrayListTest.vala"
	self = (SerializableGeeArrayListTestSmallBag*) base;
#line 73 "SerializableGeeArrayListTest.vala"
	_tmp0_ = g_strdup ("SmallBag");
#line 73 "SerializableGeeArrayListTest.vala"
	result = _tmp0_;
#line 73 "SerializableGeeArrayListTest.vala"
	return result;
#line 5504 "SerializableGeeArrayListTest.c"
}

static SerializableGeeArrayListTestSmallBag*
serializable_gee_array_list_test_small_bag_construct (GType object_type)
{
	SerializableGeeArrayListTestSmallBag * self = NULL;
#line 68 "SerializableGeeArrayListTest.vala"
	self = (SerializableGeeArrayListTestSmallBag*) gxml_serializable_object_model_construct (object_type);
#line 68 "SerializableGeeArrayListTest.vala"
	return self;
#line 5515 "SerializableGeeArrayListTest.c"
}

static SerializableGeeArrayListTestSmallBag*
serializable_gee_array_list_test_small_bag_new (void)
{
#line 68 "SerializableGeeArrayListTest.vala"
	return serializable_gee_array_list_test_small_bag_construct (SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_SMALL_BAG);
#line 5523 "SerializableGeeArrayListTest.c"
}

static const gchar*
serializable_gee_array_list_test_small_bag_get_name (SerializableGeeArrayListTestSmallBag* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 70 "SerializableGeeArrayListTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 70 "SerializableGeeArrayListTest.vala"
	_tmp0_ = self->priv->_name;
#line 70 "SerializableGeeArrayListTest.vala"
	result = _tmp0_;
#line 70 "SerializableGeeArrayListTest.vala"
	return result;
#line 5539 "SerializableGeeArrayListTest.c"
}

static void
serializable_gee_array_list_test_small_bag_set_name (SerializableGeeArrayListTestSmallBag* self,
                                                     const gchar* value)
{
#line 70 "SerializableGeeArrayListTest.vala"
	g_return_if_fail (self != NULL);
#line 70 "SerializableGeeArrayListTest.vala"
	if (g_strcmp0 (value, serializable_gee_array_list_test_small_bag_get_name (self)) != 0) {
#line 5550 "SerializableGeeArrayListTest.c"
		gchar* _tmp0_;
#line 70 "SerializableGeeArrayListTest.vala"
		_tmp0_ = g_strdup (value);
#line 70 "SerializableGeeArrayListTest.vala"
		_g_free0 (self->priv->_name);
#line 70 "SerializableGeeArrayListTest.vala"
		self->priv->_name = _tmp0_;
#line 70 "SerializableGeeArrayListTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_array_list_test_small_bag_properties[SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_NAME_PROPERTY]);
#line 5560 "SerializableGeeArrayListTest.c"
	}
}

static SerializableGeeArrayListTestBallArray*
serializable_gee_array_list_test_small_bag_get_balls (SerializableGeeArrayListTestSmallBag* self)
{
	SerializableGeeArrayListTestBallArray* result;
	SerializableGeeArrayListTestBallArray* _tmp0_;
#line 71 "SerializableGeeArrayListTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 71 "SerializableGeeArrayListTest.vala"
	_tmp0_ = self->priv->_balls;
#line 71 "SerializableGeeArrayListTest.vala"
	result = _tmp0_;
#line 71 "SerializableGeeArrayListTest.vala"
	return result;
#line 5577 "SerializableGeeArrayListTest.c"
}

static void
serializable_gee_array_list_test_small_bag_set_balls (SerializableGeeArrayListTestSmallBag* self,
                                                      SerializableGeeArrayListTestBallArray* value)
{
#line 71 "SerializableGeeArrayListTest.vala"
	g_return_if_fail (self != NULL);
#line 71 "SerializableGeeArrayListTest.vala"
	if (serializable_gee_array_list_test_small_bag_get_balls (self) != value) {
#line 5588 "SerializableGeeArrayListTest.c"
		SerializableGeeArrayListTestBallArray* _tmp0_;
#line 71 "SerializableGeeArrayListTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 71 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (self->priv->_balls);
#line 71 "SerializableGeeArrayListTest.vala"
		self->priv->_balls = _tmp0_;
#line 71 "SerializableGeeArrayListTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_array_list_test_small_bag_properties[SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_BALLS_PROPERTY]);
#line 5598 "SerializableGeeArrayListTest.c"
	}
}

static gboolean
serializable_gee_array_list_test_small_bag_array_real_deserialize_proceed (GXmlSerializableArrayList* base)
{
	SerializableGeeArrayListTestSmallBagArray * self;
	gboolean result = FALSE;
#line 75 "SerializableGeeArrayListTest.vala"
	self = (SerializableGeeArrayListTestSmallBagArray*) base;
#line 75 "SerializableGeeArrayListTest.vala"
	result = FALSE;
#line 75 "SerializableGeeArrayListTest.vala"
	return result;
#line 5613 "SerializableGeeArrayListTest.c"
}

static SerializableGeeArrayListTestSmallBagArray*
serializable_gee_array_list_test_small_bag_array_construct (GType object_type)
{
	SerializableGeeArrayListTestSmallBagArray * self = NULL;
#line 74 "SerializableGeeArrayListTest.vala"
	self = (SerializableGeeArrayListTestSmallBagArray*) gxml_serializable_array_list_construct (object_type, SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_SMALL_BAG, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 74 "SerializableGeeArrayListTest.vala"
	return self;
#line 5624 "SerializableGeeArrayListTest.c"
}

static SerializableGeeArrayListTestSmallBagArray*
serializable_gee_array_list_test_small_bag_array_new (void)
{
#line 74 "SerializableGeeArrayListTest.vala"
	return serializable_gee_array_list_test_small_bag_array_construct (SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_TYPE_ARRAY);
#line 5632 "SerializableGeeArrayListTest.c"
}

static void
serializable_gee_array_list_test_small_bag_array_class_init (SerializableGeeArrayListTestSmallBagArrayClass * klass,
                                                             gpointer klass_data)
{
#line 74 "SerializableGeeArrayListTest.vala"
	serializable_gee_array_list_test_small_bag_array_parent_class = g_type_class_peek_parent (klass);
#line 74 "SerializableGeeArrayListTest.vala"
	((GXmlSerializableArrayListClass *) klass)->deserialize_proceed = (gboolean (*) (GXmlSerializableArrayList*)) serializable_gee_array_list_test_small_bag_array_real_deserialize_proceed;
#line 5643 "SerializableGeeArrayListTest.c"
}

static void
serializable_gee_array_list_test_small_bag_array_instance_init (SerializableGeeArrayListTestSmallBagArray * self,
                                                                gpointer klass)
{
}

GType
serializable_gee_array_list_test_small_bag_array_get_type (void)
{
	static volatile gsize serializable_gee_array_list_test_small_bag_array_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_array_list_test_small_bag_array_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeArrayListTestSmallBagArrayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_array_list_test_small_bag_array_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeArrayListTestSmallBagArray), 0, (GInstanceInitFunc) serializable_gee_array_list_test_small_bag_array_instance_init, NULL };
		GType serializable_gee_array_list_test_small_bag_array_type_id;
		serializable_gee_array_list_test_small_bag_array_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_ARRAY_LIST, "SerializableGeeArrayListTestSmallBagArray", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_array_list_test_small_bag_array_type_id__volatile, serializable_gee_array_list_test_small_bag_array_type_id);
	}
	return serializable_gee_array_list_test_small_bag_array_type_id__volatile;
}

static void
serializable_gee_array_list_test_small_bag_class_init (SerializableGeeArrayListTestSmallBagClass * klass,
                                                       gpointer klass_data)
{
#line 68 "SerializableGeeArrayListTest.vala"
	serializable_gee_array_list_test_small_bag_parent_class = g_type_class_peek_parent (klass);
#line 68 "SerializableGeeArrayListTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeArrayListTestSmallBag_private_offset);
#line 68 "SerializableGeeArrayListTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_array_list_test_small_bag_real_to_string;
#line 68 "SerializableGeeArrayListTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_array_list_test_small_bag_real_node_name;
#line 68 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_array_list_test_small_bag_get_property;
#line 68 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_array_list_test_small_bag_set_property;
#line 68 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_array_list_test_small_bag_finalize;
#line 68 "SerializableGeeArrayListTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_NAME_PROPERTY, serializable_gee_array_list_test_small_bag_properties[SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 68 "SerializableGeeArrayListTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_BALLS_PROPERTY, serializable_gee_array_list_test_small_bag_properties[SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_BALLS_PROPERTY] = g_param_spec_object ("balls", "balls", "balls", SERIALIZABLE_GEE_ARRAY_LIST_TEST_BALL_TYPE_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5687 "SerializableGeeArrayListTest.c"
}

static void
serializable_gee_array_list_test_small_bag_instance_init (SerializableGeeArrayListTestSmallBag * self,
                                                          gpointer klass)
{
	gchar* _tmp0_;
	SerializableGeeArrayListTestBallArray* _tmp1_;
#line 68 "SerializableGeeArrayListTest.vala"
	self->priv = serializable_gee_array_list_test_small_bag_get_instance_private (self);
#line 70 "SerializableGeeArrayListTest.vala"
	_tmp0_ = g_strdup ("SmallBag");
#line 70 "SerializableGeeArrayListTest.vala"
	self->priv->_name = _tmp0_;
#line 71 "SerializableGeeArrayListTest.vala"
	_tmp1_ = serializable_gee_array_list_test_ball_array_new ();
#line 71 "SerializableGeeArrayListTest.vala"
	self->priv->_balls = _tmp1_;
#line 5706 "SerializableGeeArrayListTest.c"
}

static void
serializable_gee_array_list_test_small_bag_finalize (GObject * obj)
{
	SerializableGeeArrayListTestSmallBag * self;
#line 68 "SerializableGeeArrayListTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_SMALL_BAG, SerializableGeeArrayListTestSmallBag);
#line 70 "SerializableGeeArrayListTest.vala"
	_g_free0 (self->priv->_name);
#line 71 "SerializableGeeArrayListTest.vala"
	_g_object_unref0 (self->priv->_balls);
#line 68 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (serializable_gee_array_list_test_small_bag_parent_class)->finalize (obj);
#line 5721 "SerializableGeeArrayListTest.c"
}

static GType
serializable_gee_array_list_test_small_bag_get_type (void)
{
	static volatile gsize serializable_gee_array_list_test_small_bag_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_array_list_test_small_bag_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeArrayListTestSmallBagClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_array_list_test_small_bag_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeArrayListTestSmallBag), 0, (GInstanceInitFunc) serializable_gee_array_list_test_small_bag_instance_init, NULL };
		GType serializable_gee_array_list_test_small_bag_type_id;
		serializable_gee_array_list_test_small_bag_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeArrayListTestSmallBag", &g_define_type_info, 0);
		SerializableGeeArrayListTestSmallBag_private_offset = g_type_add_instance_private (serializable_gee_array_list_test_small_bag_type_id, sizeof (SerializableGeeArrayListTestSmallBagPrivate));
		g_once_init_leave (&serializable_gee_array_list_test_small_bag_type_id__volatile, serializable_gee_array_list_test_small_bag_type_id);
	}
	return serializable_gee_array_list_test_small_bag_type_id__volatile;
}

static void
_vala_serializable_gee_array_list_test_small_bag_get_property (GObject * object,
                                                               guint property_id,
                                                               GValue * value,
                                                               GParamSpec * pspec)
{
	SerializableGeeArrayListTestSmallBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_SMALL_BAG, SerializableGeeArrayListTestSmallBag);
#line 68 "SerializableGeeArrayListTest.vala"
	switch (property_id) {
#line 68 "SerializableGeeArrayListTest.vala"
		case SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_NAME_PROPERTY:
#line 68 "SerializableGeeArrayListTest.vala"
		g_value_set_string (value, serializable_gee_array_list_test_small_bag_get_name (self));
#line 68 "SerializableGeeArrayListTest.vala"
		break;
#line 68 "SerializableGeeArrayListTest.vala"
		case SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_BALLS_PROPERTY:
#line 68 "SerializableGeeArrayListTest.vala"
		g_value_set_object (value, serializable_gee_array_list_test_small_bag_get_balls (self));
#line 68 "SerializableGeeArrayListTest.vala"
		break;
#line 5760 "SerializableGeeArrayListTest.c"
		default:
#line 68 "SerializableGeeArrayListTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 68 "SerializableGeeArrayListTest.vala"
		break;
#line 5766 "SerializableGeeArrayListTest.c"
	}
}

static void
_vala_serializable_gee_array_list_test_small_bag_set_property (GObject * object,
                                                               guint property_id,
                                                               const GValue * value,
                                                               GParamSpec * pspec)
{
	SerializableGeeArrayListTestSmallBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_SMALL_BAG, SerializableGeeArrayListTestSmallBag);
#line 68 "SerializableGeeArrayListTest.vala"
	switch (property_id) {
#line 68 "SerializableGeeArrayListTest.vala"
		case SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_NAME_PROPERTY:
#line 68 "SerializableGeeArrayListTest.vala"
		serializable_gee_array_list_test_small_bag_set_name (self, g_value_get_string (value));
#line 68 "SerializableGeeArrayListTest.vala"
		break;
#line 68 "SerializableGeeArrayListTest.vala"
		case SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_BALLS_PROPERTY:
#line 68 "SerializableGeeArrayListTest.vala"
		serializable_gee_array_list_test_small_bag_set_balls (self, g_value_get_object (value));
#line 68 "SerializableGeeArrayListTest.vala"
		break;
#line 5792 "SerializableGeeArrayListTest.c"
		default:
#line 68 "SerializableGeeArrayListTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 68 "SerializableGeeArrayListTest.vala"
		break;
#line 5798 "SerializableGeeArrayListTest.c"
	}
}

static inline gpointer
serializable_gee_array_list_test_big_bag_get_instance_private (SerializableGeeArrayListTestBigBag* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeArrayListTestBigBag_private_offset);
}

static gchar*
serializable_gee_array_list_test_big_bag_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeArrayListTestBigBag * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 83 "SerializableGeeArrayListTest.vala"
	self = (SerializableGeeArrayListTestBigBag*) base;
#line 83 "SerializableGeeArrayListTest.vala"
	_tmp0_ = self->priv->_name;
#line 83 "SerializableGeeArrayListTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 83 "SerializableGeeArrayListTest.vala"
	result = _tmp1_;
#line 83 "SerializableGeeArrayListTest.vala"
	return result;
#line 5825 "SerializableGeeArrayListTest.c"
}

static gchar*
serializable_gee_array_list_test_big_bag_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeArrayListTestBigBag * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 84 "SerializableGeeArrayListTest.vala"
	self = (SerializableGeeArrayListTestBigBag*) base;
#line 84 "SerializableGeeArrayListTest.vala"
	_tmp0_ = g_strdup ("BigBag");
#line 84 "SerializableGeeArrayListTest.vala"
	result = _tmp0_;
#line 84 "SerializableGeeArrayListTest.vala"
	return result;
#line 5842 "SerializableGeeArrayListTest.c"
}

static SerializableGeeArrayListTestBigBag*
serializable_gee_array_list_test_big_bag_construct (GType object_type)
{
	SerializableGeeArrayListTestBigBag * self = NULL;
#line 79 "SerializableGeeArrayListTest.vala"
	self = (SerializableGeeArrayListTestBigBag*) gxml_serializable_object_model_construct (object_type);
#line 79 "SerializableGeeArrayListTest.vala"
	return self;
#line 5853 "SerializableGeeArrayListTest.c"
}

static SerializableGeeArrayListTestBigBag*
serializable_gee_array_list_test_big_bag_new (void)
{
#line 79 "SerializableGeeArrayListTest.vala"
	return serializable_gee_array_list_test_big_bag_construct (SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BIG_BAG);
#line 5861 "SerializableGeeArrayListTest.c"
}

static const gchar*
serializable_gee_array_list_test_big_bag_get_name (SerializableGeeArrayListTestBigBag* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 81 "SerializableGeeArrayListTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 81 "SerializableGeeArrayListTest.vala"
	_tmp0_ = self->priv->_name;
#line 81 "SerializableGeeArrayListTest.vala"
	result = _tmp0_;
#line 81 "SerializableGeeArrayListTest.vala"
	return result;
#line 5877 "SerializableGeeArrayListTest.c"
}

static void
serializable_gee_array_list_test_big_bag_set_name (SerializableGeeArrayListTestBigBag* self,
                                                   const gchar* value)
{
#line 81 "SerializableGeeArrayListTest.vala"
	g_return_if_fail (self != NULL);
#line 81 "SerializableGeeArrayListTest.vala"
	if (g_strcmp0 (value, serializable_gee_array_list_test_big_bag_get_name (self)) != 0) {
#line 5888 "SerializableGeeArrayListTest.c"
		gchar* _tmp0_;
#line 81 "SerializableGeeArrayListTest.vala"
		_tmp0_ = g_strdup (value);
#line 81 "SerializableGeeArrayListTest.vala"
		_g_free0 (self->priv->_name);
#line 81 "SerializableGeeArrayListTest.vala"
		self->priv->_name = _tmp0_;
#line 81 "SerializableGeeArrayListTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_array_list_test_big_bag_properties[SERIALIZABLE_GEE_ARRAY_LIST_TEST_BIG_BAG_NAME_PROPERTY]);
#line 5898 "SerializableGeeArrayListTest.c"
	}
}

static SerializableGeeArrayListTestSmallBagArray*
serializable_gee_array_list_test_big_bag_get_bags (SerializableGeeArrayListTestBigBag* self)
{
	SerializableGeeArrayListTestSmallBagArray* result;
	SerializableGeeArrayListTestSmallBagArray* _tmp0_;
#line 82 "SerializableGeeArrayListTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 82 "SerializableGeeArrayListTest.vala"
	_tmp0_ = self->priv->_bags;
#line 82 "SerializableGeeArrayListTest.vala"
	result = _tmp0_;
#line 82 "SerializableGeeArrayListTest.vala"
	return result;
#line 5915 "SerializableGeeArrayListTest.c"
}

static void
serializable_gee_array_list_test_big_bag_set_bags (SerializableGeeArrayListTestBigBag* self,
                                                   SerializableGeeArrayListTestSmallBagArray* value)
{
#line 82 "SerializableGeeArrayListTest.vala"
	g_return_if_fail (self != NULL);
#line 82 "SerializableGeeArrayListTest.vala"
	if (serializable_gee_array_list_test_big_bag_get_bags (self) != value) {
#line 5926 "SerializableGeeArrayListTest.c"
		SerializableGeeArrayListTestSmallBagArray* _tmp0_;
#line 82 "SerializableGeeArrayListTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 82 "SerializableGeeArrayListTest.vala"
		_g_object_unref0 (self->priv->_bags);
#line 82 "SerializableGeeArrayListTest.vala"
		self->priv->_bags = _tmp0_;
#line 82 "SerializableGeeArrayListTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_array_list_test_big_bag_properties[SERIALIZABLE_GEE_ARRAY_LIST_TEST_BIG_BAG_BAGS_PROPERTY]);
#line 5936 "SerializableGeeArrayListTest.c"
	}
}

static void
serializable_gee_array_list_test_big_bag_class_init (SerializableGeeArrayListTestBigBagClass * klass,
                                                     gpointer klass_data)
{
#line 79 "SerializableGeeArrayListTest.vala"
	serializable_gee_array_list_test_big_bag_parent_class = g_type_class_peek_parent (klass);
#line 79 "SerializableGeeArrayListTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeArrayListTestBigBag_private_offset);
#line 79 "SerializableGeeArrayListTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_array_list_test_big_bag_real_to_string;
#line 79 "SerializableGeeArrayListTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_array_list_test_big_bag_real_node_name;
#line 79 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_array_list_test_big_bag_get_property;
#line 79 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_array_list_test_big_bag_set_property;
#line 79 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_array_list_test_big_bag_finalize;
#line 79 "SerializableGeeArrayListTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_ARRAY_LIST_TEST_BIG_BAG_NAME_PROPERTY, serializable_gee_array_list_test_big_bag_properties[SERIALIZABLE_GEE_ARRAY_LIST_TEST_BIG_BAG_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 79 "SerializableGeeArrayListTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_ARRAY_LIST_TEST_BIG_BAG_BAGS_PROPERTY, serializable_gee_array_list_test_big_bag_properties[SERIALIZABLE_GEE_ARRAY_LIST_TEST_BIG_BAG_BAGS_PROPERTY] = g_param_spec_object ("bags", "bags", "bags", SERIALIZABLE_GEE_ARRAY_LIST_TEST_SMALL_BAG_TYPE_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5962 "SerializableGeeArrayListTest.c"
}

static void
serializable_gee_array_list_test_big_bag_instance_init (SerializableGeeArrayListTestBigBag * self,
                                                        gpointer klass)
{
	gchar* _tmp0_;
	SerializableGeeArrayListTestSmallBagArray* _tmp1_;
#line 79 "SerializableGeeArrayListTest.vala"
	self->priv = serializable_gee_array_list_test_big_bag_get_instance_private (self);
#line 81 "SerializableGeeArrayListTest.vala"
	_tmp0_ = g_strdup ("ball");
#line 81 "SerializableGeeArrayListTest.vala"
	self->priv->_name = _tmp0_;
#line 82 "SerializableGeeArrayListTest.vala"
	_tmp1_ = serializable_gee_array_list_test_small_bag_array_new ();
#line 82 "SerializableGeeArrayListTest.vala"
	self->priv->_bags = _tmp1_;
#line 5981 "SerializableGeeArrayListTest.c"
}

static void
serializable_gee_array_list_test_big_bag_finalize (GObject * obj)
{
	SerializableGeeArrayListTestBigBag * self;
#line 79 "SerializableGeeArrayListTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BIG_BAG, SerializableGeeArrayListTestBigBag);
#line 81 "SerializableGeeArrayListTest.vala"
	_g_free0 (self->priv->_name);
#line 82 "SerializableGeeArrayListTest.vala"
	_g_object_unref0 (self->priv->_bags);
#line 79 "SerializableGeeArrayListTest.vala"
	G_OBJECT_CLASS (serializable_gee_array_list_test_big_bag_parent_class)->finalize (obj);
#line 5996 "SerializableGeeArrayListTest.c"
}

static GType
serializable_gee_array_list_test_big_bag_get_type (void)
{
	static volatile gsize serializable_gee_array_list_test_big_bag_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_array_list_test_big_bag_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeArrayListTestBigBagClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_array_list_test_big_bag_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeArrayListTestBigBag), 0, (GInstanceInitFunc) serializable_gee_array_list_test_big_bag_instance_init, NULL };
		GType serializable_gee_array_list_test_big_bag_type_id;
		serializable_gee_array_list_test_big_bag_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeArrayListTestBigBag", &g_define_type_info, 0);
		SerializableGeeArrayListTestBigBag_private_offset = g_type_add_instance_private (serializable_gee_array_list_test_big_bag_type_id, sizeof (SerializableGeeArrayListTestBigBagPrivate));
		g_once_init_leave (&serializable_gee_array_list_test_big_bag_type_id__volatile, serializable_gee_array_list_test_big_bag_type_id);
	}
	return serializable_gee_array_list_test_big_bag_type_id__volatile;
}

static void
_vala_serializable_gee_array_list_test_big_bag_get_property (GObject * object,
                                                             guint property_id,
                                                             GValue * value,
                                                             GParamSpec * pspec)
{
	SerializableGeeArrayListTestBigBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BIG_BAG, SerializableGeeArrayListTestBigBag);
#line 79 "SerializableGeeArrayListTest.vala"
	switch (property_id) {
#line 79 "SerializableGeeArrayListTest.vala"
		case SERIALIZABLE_GEE_ARRAY_LIST_TEST_BIG_BAG_NAME_PROPERTY:
#line 79 "SerializableGeeArrayListTest.vala"
		g_value_set_string (value, serializable_gee_array_list_test_big_bag_get_name (self));
#line 79 "SerializableGeeArrayListTest.vala"
		break;
#line 79 "SerializableGeeArrayListTest.vala"
		case SERIALIZABLE_GEE_ARRAY_LIST_TEST_BIG_BAG_BAGS_PROPERTY:
#line 79 "SerializableGeeArrayListTest.vala"
		g_value_set_object (value, serializable_gee_array_list_test_big_bag_get_bags (self));
#line 79 "SerializableGeeArrayListTest.vala"
		break;
#line 6035 "SerializableGeeArrayListTest.c"
		default:
#line 79 "SerializableGeeArrayListTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 79 "SerializableGeeArrayListTest.vala"
		break;
#line 6041 "SerializableGeeArrayListTest.c"
	}
}

static void
_vala_serializable_gee_array_list_test_big_bag_set_property (GObject * object,
                                                             guint property_id,
                                                             const GValue * value,
                                                             GParamSpec * pspec)
{
	SerializableGeeArrayListTestBigBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_ARRAY_LIST_TEST_TYPE_BIG_BAG, SerializableGeeArrayListTestBigBag);
#line 79 "SerializableGeeArrayListTest.vala"
	switch (property_id) {
#line 79 "SerializableGeeArrayListTest.vala"
		case SERIALIZABLE_GEE_ARRAY_LIST_TEST_BIG_BAG_NAME_PROPERTY:
#line 79 "SerializableGeeArrayListTest.vala"
		serializable_gee_array_list_test_big_bag_set_name (self, g_value_get_string (value));
#line 79 "SerializableGeeArrayListTest.vala"
		break;
#line 79 "SerializableGeeArrayListTest.vala"
		case SERIALIZABLE_GEE_ARRAY_LIST_TEST_BIG_BAG_BAGS_PROPERTY:
#line 79 "SerializableGeeArrayListTest.vala"
		serializable_gee_array_list_test_big_bag_set_bags (self, g_value_get_object (value));
#line 79 "SerializableGeeArrayListTest.vala"
		break;
#line 6067 "SerializableGeeArrayListTest.c"
		default:
#line 79 "SerializableGeeArrayListTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 79 "SerializableGeeArrayListTest.vala"
		break;
#line 6073 "SerializableGeeArrayListTest.c"
	}
}

static void
serializable_gee_array_list_test_class_init (SerializableGeeArrayListTestClass * klass,
                                             gpointer klass_data)
{
#line 46 "SerializableGeeArrayListTest.vala"
	serializable_gee_array_list_test_parent_class = g_type_class_peek_parent (klass);
#line 6083 "SerializableGeeArrayListTest.c"
}

static void
serializable_gee_array_list_test_instance_init (SerializableGeeArrayListTest * self,
                                                gpointer klass)
{
}

GType
serializable_gee_array_list_test_get_type (void)
{
	static volatile gsize serializable_gee_array_list_test_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_array_list_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeArrayListTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_array_list_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeArrayListTest), 0, (GInstanceInitFunc) serializable_gee_array_list_test_instance_init, NULL };
		GType serializable_gee_array_list_test_type_id;
		serializable_gee_array_list_test_type_id = g_type_register_static (TYPE_GXML_TEST, "SerializableGeeArrayListTest", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_array_list_test_type_id__volatile, serializable_gee_array_list_test_type_id);
	}
	return serializable_gee_array_list_test_type_id__volatile;
}

static void
_vala_array_destroy (gpointer array,
                     gint array_length,
                     GDestroyNotify destroy_func)
{
#line 356 "GomSerializationTest.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 6112 "SerializableGeeArrayListTest.c"
		int i;
#line 356 "GomSerializationTest.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 356 "GomSerializationTest.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 356 "GomSerializationTest.vala"
				destroy_func (((gpointer*) array)[i]);
#line 6120 "SerializableGeeArrayListTest.c"
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gint array_length,
                  GDestroyNotify destroy_func)
{
#line 356 "GomSerializationTest.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 356 "GomSerializationTest.vala"
	g_free (array);
#line 6135 "SerializableGeeArrayListTest.c"
}

