/* GomElementTest.c generated by valac 0.44.3, the Vala compiler
 * generated from GomElementTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* Notation.vala
 *
 * Copyright (C) 2016  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib-object.h>
#include <gxml/gxml.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gee.h>
#include <gio/gio.h>

#define TYPE_NO_INSTANTIATABLE (no_instantiatable_get_type ())
#define NO_INSTANTIATABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_NO_INSTANTIATABLE, NoInstantiatable))
#define IS_NO_INSTANTIATABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_NO_INSTANTIATABLE))
#define NO_INSTANTIATABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_NO_INSTANTIATABLE, NoInstantiatableIface))

typedef struct _NoInstantiatable NoInstantiatable;
typedef struct _NoInstantiatableIface NoInstantiatableIface;

#define TYPE_PROPERTY (property_get_type ())
#define PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PROPERTY, Property))
#define IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PROPERTY))
#define PROPERTY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_PROPERTY, PropertyIface))

typedef struct _Property Property;
typedef struct _PropertyIface PropertyIface;

#define TYPE_OBJECT_PARENT (object_parent_get_type ())
#define OBJECT_PARENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_OBJECT_PARENT, ObjectParent))
#define OBJECT_PARENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_OBJECT_PARENT, ObjectParentClass))
#define IS_OBJECT_PARENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_OBJECT_PARENT))
#define IS_OBJECT_PARENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_OBJECT_PARENT))
#define OBJECT_PARENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_OBJECT_PARENT, ObjectParentClass))

typedef struct _ObjectParent ObjectParent;
typedef struct _ObjectParentClass ObjectParentClass;
typedef struct _ObjectParentPrivate ObjectParentPrivate;

#define OBJECT_PARENT_TYPE_OBJECT_PROPERTY (object_parent_object_property_get_type ())
#define OBJECT_PARENT_OBJECT_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECT_PARENT_TYPE_OBJECT_PROPERTY, ObjectParentObjectProperty))
#define OBJECT_PARENT_OBJECT_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECT_PARENT_TYPE_OBJECT_PROPERTY, ObjectParentObjectPropertyClass))
#define OBJECT_PARENT_IS_OBJECT_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECT_PARENT_TYPE_OBJECT_PROPERTY))
#define OBJECT_PARENT_IS_OBJECT_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECT_PARENT_TYPE_OBJECT_PROPERTY))
#define OBJECT_PARENT_OBJECT_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECT_PARENT_TYPE_OBJECT_PROPERTY, ObjectParentObjectPropertyClass))

typedef struct _ObjectParentObjectProperty ObjectParentObjectProperty;
typedef struct _ObjectParentObjectPropertyClass ObjectParentObjectPropertyClass;

#define OBJECT_PARENT_TYPE_OBJECT_CHILD (object_parent_object_child_get_type ())
#define OBJECT_PARENT_OBJECT_CHILD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECT_PARENT_TYPE_OBJECT_CHILD, ObjectParentObjectChild))
#define OBJECT_PARENT_OBJECT_CHILD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECT_PARENT_TYPE_OBJECT_CHILD, ObjectParentObjectChildClass))
#define OBJECT_PARENT_IS_OBJECT_CHILD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECT_PARENT_TYPE_OBJECT_CHILD))
#define OBJECT_PARENT_IS_OBJECT_CHILD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECT_PARENT_TYPE_OBJECT_CHILD))
#define OBJECT_PARENT_OBJECT_CHILD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECT_PARENT_TYPE_OBJECT_CHILD, ObjectParentObjectChildClass))

typedef struct _ObjectParentObjectChild ObjectParentObjectChild;
typedef struct _ObjectParentObjectChildClass ObjectParentObjectChildClass;
enum  {
	OBJECT_PARENT_0_PROPERTY,
	OBJECT_PARENT_TEXT_PROPERTY,
	OBJECT_PARENT_PROP_PROPERTY,
	OBJECT_PARENT_PROP1_PROPERTY,
	OBJECT_PARENT_PROP2_PROPERTY,
	OBJECT_PARENT_PROP3_PROPERTY,
	OBJECT_PARENT_CHILD_PROPERTY,
	OBJECT_PARENT_NUM_PROPERTIES
};
static GParamSpec* object_parent_properties[OBJECT_PARENT_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _ObjectParentObjectPropertyPrivate ObjectParentObjectPropertyPrivate;
enum  {
	OBJECT_PARENT_OBJECT_PROPERTY_0_PROPERTY,
	OBJECT_PARENT_OBJECT_PROPERTY_VALUE_PROPERTY,
	OBJECT_PARENT_OBJECT_PROPERTY_NUM_PROPERTIES
};
static GParamSpec* object_parent_object_property_properties[OBJECT_PARENT_OBJECT_PROPERTY_NUM_PROPERTIES];
typedef struct _ObjectParentObjectChildPrivate ObjectParentObjectChildPrivate;
enum  {
	OBJECT_PARENT_OBJECT_CHILD_0_PROPERTY,
	OBJECT_PARENT_OBJECT_CHILD_NUM_PROPERTIES
};
static GParamSpec* object_parent_object_child_properties[OBJECT_PARENT_OBJECT_CHILD_NUM_PROPERTIES];

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_GOM_ELEMENT_TEST (gom_element_test_get_type ())
#define GOM_ELEMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_ELEMENT_TEST, GomElementTest))
#define GOM_ELEMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_ELEMENT_TEST, GomElementTestClass))
#define IS_GOM_ELEMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_ELEMENT_TEST))
#define IS_GOM_ELEMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_ELEMENT_TEST))
#define GOM_ELEMENT_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_ELEMENT_TEST, GomElementTestClass))

typedef struct _GomElementTest GomElementTest;
typedef struct _GomElementTestClass GomElementTestClass;
typedef struct _GomElementTestPrivate GomElementTestPrivate;

#define GOM_ELEMENT_TEST_TYPE_POTION (gom_element_test_potion_get_type ())
#define GOM_ELEMENT_TEST_POTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_POTION, GomElementTestPotion))
#define GOM_ELEMENT_TEST_POTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_POTION, GomElementTestPotionClass))
#define GOM_ELEMENT_TEST_IS_POTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_POTION))
#define GOM_ELEMENT_TEST_IS_POTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_POTION))
#define GOM_ELEMENT_TEST_POTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_POTION, GomElementTestPotionClass))

typedef struct _GomElementTestPotion GomElementTestPotion;
typedef struct _GomElementTestPotionClass GomElementTestPotionClass;

#define GOM_ELEMENT_TEST_TYPE_INGREDIENT (gom_element_test_ingredient_get_type ())
#define GOM_ELEMENT_TEST_INGREDIENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_INGREDIENT, GomElementTestIngredient))
#define GOM_ELEMENT_TEST_INGREDIENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_INGREDIENT, GomElementTestIngredientClass))
#define GOM_ELEMENT_TEST_IS_INGREDIENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_INGREDIENT))
#define GOM_ELEMENT_TEST_IS_INGREDIENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_INGREDIENT))
#define GOM_ELEMENT_TEST_INGREDIENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_INGREDIENT, GomElementTestIngredientClass))

typedef struct _GomElementTestIngredient GomElementTestIngredient;
typedef struct _GomElementTestIngredientClass GomElementTestIngredientClass;

#define GOM_ELEMENT_TEST_METHOD_TYPE_MAP (gom_element_test_method_map_get_type ())
#define GOM_ELEMENT_TEST_METHOD_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_METHOD_TYPE_MAP, GomElementTestMethodMap))
#define GOM_ELEMENT_TEST_METHOD_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_METHOD_TYPE_MAP, GomElementTestMethodMapClass))
#define GOM_ELEMENT_TEST_METHOD_IS_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_METHOD_TYPE_MAP))
#define GOM_ELEMENT_TEST_METHOD_IS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_METHOD_TYPE_MAP))
#define GOM_ELEMENT_TEST_METHOD_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_METHOD_TYPE_MAP, GomElementTestMethodMapClass))

typedef struct _GomElementTestMethodMap GomElementTestMethodMap;
typedef struct _GomElementTestMethodMapClass GomElementTestMethodMapClass;

#define GOM_ELEMENT_TEST_TYPE_METHOD (gom_element_test_method_get_type ())
#define GOM_ELEMENT_TEST_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_METHOD, GomElementTestMethod))
#define GOM_ELEMENT_TEST_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_METHOD, GomElementTestMethodClass))
#define GOM_ELEMENT_TEST_IS_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_METHOD))
#define GOM_ELEMENT_TEST_IS_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_METHOD))
#define GOM_ELEMENT_TEST_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_METHOD, GomElementTestMethodClass))

typedef struct _GomElementTestMethod GomElementTestMethod;
typedef struct _GomElementTestMethodClass GomElementTestMethodClass;

#define GOM_ELEMENT_TEST_TYPE_REPOSITORY (gom_element_test_repository_get_type ())
#define GOM_ELEMENT_TEST_REPOSITORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_REPOSITORY, GomElementTestRepository))
#define GOM_ELEMENT_TEST_REPOSITORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_REPOSITORY, GomElementTestRepositoryClass))
#define GOM_ELEMENT_TEST_IS_REPOSITORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_REPOSITORY))
#define GOM_ELEMENT_TEST_IS_REPOSITORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_REPOSITORY))
#define GOM_ELEMENT_TEST_REPOSITORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_REPOSITORY, GomElementTestRepositoryClass))

typedef struct _GomElementTestRepository GomElementTestRepository;
typedef struct _GomElementTestRepositoryClass GomElementTestRepositoryClass;

#define GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED (gom_element_test_parsed_delayed_get_type ())
#define GOM_ELEMENT_TEST_PARSED_DELAYED(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED, GomElementTestParsedDelayed))
#define GOM_ELEMENT_TEST_PARSED_DELAYED_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED, GomElementTestParsedDelayedClass))
#define GOM_ELEMENT_TEST_IS_PARSED_DELAYED(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED))
#define GOM_ELEMENT_TEST_IS_PARSED_DELAYED_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED))
#define GOM_ELEMENT_TEST_PARSED_DELAYED_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED, GomElementTestParsedDelayedClass))

typedef struct _GomElementTestParsedDelayed GomElementTestParsedDelayed;
typedef struct _GomElementTestParsedDelayedClass GomElementTestParsedDelayedClass;

#define GOM_ELEMENT_TEST_TYPE_TOP (gom_element_test_top_get_type ())
#define GOM_ELEMENT_TEST_TOP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_TOP, GomElementTestTop))
#define GOM_ELEMENT_TEST_TOP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_TOP, GomElementTestTopClass))
#define GOM_ELEMENT_TEST_IS_TOP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_TOP))
#define GOM_ELEMENT_TEST_IS_TOP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_TOP))
#define GOM_ELEMENT_TEST_TOP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_TOP, GomElementTestTopClass))

typedef struct _GomElementTestTop GomElementTestTop;
typedef struct _GomElementTestTopClass GomElementTestTopClass;

#define GOM_ELEMENT_TEST_TYPE_GTOP (gom_element_test_gtop_get_type ())
#define GOM_ELEMENT_TEST_GTOP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_GTOP, GomElementTestGTop))
#define GOM_ELEMENT_TEST_GTOP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_GTOP, GomElementTestGTopClass))
#define GOM_ELEMENT_TEST_IS_GTOP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_GTOP))
#define GOM_ELEMENT_TEST_IS_GTOP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_GTOP))
#define GOM_ELEMENT_TEST_GTOP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_GTOP, GomElementTestGTopClass))

typedef struct _GomElementTestGTop GomElementTestGTop;
typedef struct _GomElementTestGTopClass GomElementTestGTopClass;
typedef struct _GomElementTestParsedDelayedPrivate GomElementTestParsedDelayedPrivate;
enum  {
	GOM_ELEMENT_TEST_PARSED_DELAYED_0_PROPERTY,
	GOM_ELEMENT_TEST_PARSED_DELAYED_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_parsed_delayed_properties[GOM_ELEMENT_TEST_PARSED_DELAYED_NUM_PROPERTIES];

#define GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE (gom_element_test_instantiatable_get_type ())
#define GOM_ELEMENT_TEST_INSTANTIATABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, GomElementTestInstantiatable))
#define GOM_ELEMENT_TEST_INSTANTIATABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, GomElementTestInstantiatableClass))
#define GOM_ELEMENT_TEST_IS_INSTANTIATABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE))
#define GOM_ELEMENT_TEST_IS_INSTANTIATABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE))
#define GOM_ELEMENT_TEST_INSTANTIATABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, GomElementTestInstantiatableClass))

typedef struct _GomElementTestInstantiatable GomElementTestInstantiatable;
typedef struct _GomElementTestInstantiatableClass GomElementTestInstantiatableClass;
typedef struct _GomElementTestInstantiatablePrivate GomElementTestInstantiatablePrivate;
enum  {
	GOM_ELEMENT_TEST_INSTANTIATABLE_0_PROPERTY,
	GOM_ELEMENT_TEST_INSTANTIATABLE_NAME_PROPERTY,
	GOM_ELEMENT_TEST_INSTANTIATABLE_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_instantiatable_properties[GOM_ELEMENT_TEST_INSTANTIATABLE_NUM_PROPERTIES];
typedef struct _GomElementTestTopPrivate GomElementTestTopPrivate;
enum  {
	GOM_ELEMENT_TEST_TOP_0_PROPERTY,
	GOM_ELEMENT_TEST_TOP_INST_PROPERTY,
	GOM_ELEMENT_TEST_TOP_INST_I_PROPERTY,
	GOM_ELEMENT_TEST_TOP_PQ_PROPERTY,
	GOM_ELEMENT_TEST_TOP_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_top_properties[GOM_ELEMENT_TEST_TOP_NUM_PROPERTIES];

#define GOM_ELEMENT_TEST_TYPE_GPROPERTY (gom_element_test_gproperty_get_type ())
#define GOM_ELEMENT_TEST_GPROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_GPROPERTY, GomElementTestGProperty))
#define GOM_ELEMENT_TEST_GPROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_GPROPERTY, GomElementTestGPropertyClass))
#define GOM_ELEMENT_TEST_IS_GPROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_GPROPERTY))
#define GOM_ELEMENT_TEST_IS_GPROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_GPROPERTY))
#define GOM_ELEMENT_TEST_GPROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_GPROPERTY, GomElementTestGPropertyClass))

typedef struct _GomElementTestGProperty GomElementTestGProperty;
typedef struct _GomElementTestGPropertyClass GomElementTestGPropertyClass;
typedef struct _GomElementTestGPropertyPrivate GomElementTestGPropertyPrivate;
enum  {
	GOM_ELEMENT_TEST_GPROPERTY_0_PROPERTY,
	GOM_ELEMENT_TEST_GPROPERTY_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_gproperty_properties[GOM_ELEMENT_TEST_GPROPERTY_NUM_PROPERTIES];
typedef struct _GomElementTestGTopPrivate GomElementTestGTopPrivate;
enum  {
	GOM_ELEMENT_TEST_GTOP_0_PROPERTY,
	GOM_ELEMENT_TEST_GTOP_INST_PROPERTY,
	GOM_ELEMENT_TEST_GTOP_INST_I_PROPERTY,
	GOM_ELEMENT_TEST_GTOP_GPQ_PROPERTY,
	GOM_ELEMENT_TEST_GTOP_PQ_PROPERTY,
	GOM_ELEMENT_TEST_GTOP_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_gtop_properties[GOM_ELEMENT_TEST_GTOP_NUM_PROPERTIES];
typedef struct _GomElementTestPotionPrivate GomElementTestPotionPrivate;
enum  {
	GOM_ELEMENT_TEST_POTION_0_PROPERTY,
	GOM_ELEMENT_TEST_POTION_CNAME_PROPERTY,
	GOM_ELEMENT_TEST_POTION_INGREDIENT_PROPERTY,
	GOM_ELEMENT_TEST_POTION_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_potion_properties[GOM_ELEMENT_TEST_POTION_NUM_PROPERTIES];
typedef struct _GomElementTestIngredientPrivate GomElementTestIngredientPrivate;
enum  {
	GOM_ELEMENT_TEST_INGREDIENT_0_PROPERTY,
	GOM_ELEMENT_TEST_INGREDIENT_CNAME_PROPERTY,
	GOM_ELEMENT_TEST_INGREDIENT_METHODS_PROPERTY,
	GOM_ELEMENT_TEST_INGREDIENT_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_ingredient_properties[GOM_ELEMENT_TEST_INGREDIENT_NUM_PROPERTIES];

#define GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP (gom_element_test_ingredient_map_get_type ())
#define GOM_ELEMENT_TEST_INGREDIENT_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP, GomElementTestIngredientMap))
#define GOM_ELEMENT_TEST_INGREDIENT_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP, GomElementTestIngredientMapClass))
#define GOM_ELEMENT_TEST_INGREDIENT_IS_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP))
#define GOM_ELEMENT_TEST_INGREDIENT_IS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP))
#define GOM_ELEMENT_TEST_INGREDIENT_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP, GomElementTestIngredientMapClass))

typedef struct _GomElementTestIngredientMap GomElementTestIngredientMap;
typedef struct _GomElementTestIngredientMapClass GomElementTestIngredientMapClass;
typedef struct _GomElementTestIngredientMapPrivate GomElementTestIngredientMapPrivate;
enum  {
	GOM_ELEMENT_TEST_INGREDIENT_MAP_0_PROPERTY,
	GOM_ELEMENT_TEST_INGREDIENT_MAP_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_ingredient_map_properties[GOM_ELEMENT_TEST_INGREDIENT_MAP_NUM_PROPERTIES];
typedef struct _GomElementTestMethodPrivate GomElementTestMethodPrivate;
enum  {
	GOM_ELEMENT_TEST_METHOD_0_PROPERTY,
	GOM_ELEMENT_TEST_METHOD_CNAME_PROPERTY,
	GOM_ELEMENT_TEST_METHOD_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_method_properties[GOM_ELEMENT_TEST_METHOD_NUM_PROPERTIES];
typedef struct _GomElementTestMethodMapPrivate GomElementTestMethodMapPrivate;
enum  {
	GOM_ELEMENT_TEST_METHOD_MAP_0_PROPERTY,
	GOM_ELEMENT_TEST_METHOD_MAP_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_method_map_properties[GOM_ELEMENT_TEST_METHOD_MAP_NUM_PROPERTIES];
typedef struct _GomElementTestRepositoryPrivate GomElementTestRepositoryPrivate;

#define GOM_ELEMENT_TEST_TYPE_NAMESPACE (gom_element_test_namespace_get_type ())
#define GOM_ELEMENT_TEST_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_NAMESPACE, GomElementTestNamespace))
#define GOM_ELEMENT_TEST_NAMESPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_NAMESPACE, GomElementTestNamespaceClass))
#define GOM_ELEMENT_TEST_IS_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_NAMESPACE))
#define GOM_ELEMENT_TEST_IS_NAMESPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_NAMESPACE))
#define GOM_ELEMENT_TEST_NAMESPACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_NAMESPACE, GomElementTestNamespaceClass))

typedef struct _GomElementTestNamespace GomElementTestNamespace;
typedef struct _GomElementTestNamespaceClass GomElementTestNamespaceClass;
enum  {
	GOM_ELEMENT_TEST_REPOSITORY_0_PROPERTY,
	GOM_ELEMENT_TEST_REPOSITORY_VERSION_PROPERTY,
	GOM_ELEMENT_TEST_REPOSITORY_NS_PROPERTY,
	GOM_ELEMENT_TEST_REPOSITORY_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_repository_properties[GOM_ELEMENT_TEST_REPOSITORY_NUM_PROPERTIES];
typedef struct _GomElementTestNamespacePrivate GomElementTestNamespacePrivate;

#define GOM_ELEMENT_TEST_TCLASS_TYPE_MAP (gom_element_test_tclass_map_get_type ())
#define GOM_ELEMENT_TEST_TCLASS_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TCLASS_TYPE_MAP, GomElementTestTClassMap))
#define GOM_ELEMENT_TEST_TCLASS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TCLASS_TYPE_MAP, GomElementTestTClassMapClass))
#define GOM_ELEMENT_TEST_TCLASS_IS_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TCLASS_TYPE_MAP))
#define GOM_ELEMENT_TEST_TCLASS_IS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TCLASS_TYPE_MAP))
#define GOM_ELEMENT_TEST_TCLASS_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TCLASS_TYPE_MAP, GomElementTestTClassMapClass))

typedef struct _GomElementTestTClassMap GomElementTestTClassMap;
typedef struct _GomElementTestTClassMapClass GomElementTestTClassMapClass;
enum  {
	GOM_ELEMENT_TEST_NAMESPACE_0_PROPERTY,
	GOM_ELEMENT_TEST_NAMESPACE_NAME_PROPERTY,
	GOM_ELEMENT_TEST_NAMESPACE_VERSION_PROPERTY,
	GOM_ELEMENT_TEST_NAMESPACE_CPREFIX_PROPERTY,
	GOM_ELEMENT_TEST_NAMESPACE_CLASSES_PROPERTY,
	GOM_ELEMENT_TEST_NAMESPACE_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_namespace_properties[GOM_ELEMENT_TEST_NAMESPACE_NUM_PROPERTIES];

#define GOM_ELEMENT_TEST_TYPE_TCLASS (gom_element_test_tclass_get_type ())
#define GOM_ELEMENT_TEST_TCLASS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_TCLASS, GomElementTestTClass))
#define GOM_ELEMENT_TEST_TCLASS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_TCLASS, GomElementTestTClassClass))
#define GOM_ELEMENT_TEST_IS_TCLASS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_TCLASS))
#define GOM_ELEMENT_TEST_IS_TCLASS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_TCLASS))
#define GOM_ELEMENT_TEST_TCLASS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_TCLASS, GomElementTestTClassClass))

typedef struct _GomElementTestTClass GomElementTestTClass;
typedef struct _GomElementTestTClassClass GomElementTestTClassClass;
typedef struct _GomElementTestTClassPrivate GomElementTestTClassPrivate;
enum  {
	GOM_ELEMENT_TEST_TCLASS_0_PROPERTY,
	GOM_ELEMENT_TEST_TCLASS_NAME_PROPERTY,
	GOM_ELEMENT_TEST_TCLASS_VERSION_PROPERTY,
	GOM_ELEMENT_TEST_TCLASS_CPREFIX_PROPERTY,
	GOM_ELEMENT_TEST_TCLASS_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_tclass_properties[GOM_ELEMENT_TEST_TCLASS_NUM_PROPERTIES];
typedef struct _GomElementTestTClassMapPrivate GomElementTestTClassMapPrivate;
enum  {
	GOM_ELEMENT_TEST_TCLASS_MAP_0_PROPERTY,
	GOM_ELEMENT_TEST_TCLASS_MAP_NUM_PROPERTIES
};
static GParamSpec* gom_element_test_tclass_map_properties[GOM_ELEMENT_TEST_TCLASS_MAP_NUM_PROPERTIES];
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _NoInstantiatableIface {
	GTypeInterface parent_iface;
	const gchar* (*get_name) (NoInstantiatable* self);
	void (*set_name) (NoInstantiatable* self, const gchar* value);
};

struct _PropertyIface {
	GTypeInterface parent_iface;
};

struct _ObjectParent {
	GXmlGomElement parent_instance;
	ObjectParentPrivate * priv;
};

struct _ObjectParentClass {
	GXmlGomElementClass parent_class;
};

struct _ObjectParentPrivate {
	gchar* _text;
	ObjectParentObjectProperty* _prop;
	ObjectParentObjectProperty* _prop1;
	ObjectParentObjectProperty* _prop2;
	ObjectParentObjectProperty* _prop3;
	ObjectParentObjectChild* _child;
};

struct _ObjectParentObjectProperty {
	GObject parent_instance;
	ObjectParentObjectPropertyPrivate * priv;
};

struct _ObjectParentObjectPropertyClass {
	GObjectClass parent_class;
};

struct _ObjectParentObjectPropertyPrivate {
	gchar* _value;
};

struct _ObjectParentObjectChild {
	GXmlGomElement parent_instance;
	ObjectParentObjectChildPrivate * priv;
};

struct _ObjectParentObjectChildClass {
	GXmlGomElementClass parent_class;
};

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _GomElementTest {
	GXmlTest parent_instance;
	GomElementTestPrivate * priv;
};

struct _GomElementTestClass {
	GXmlTestClass parent_class;
};

struct _GomElementTestParsedDelayed {
	GXmlGomElement parent_instance;
	GomElementTestParsedDelayedPrivate * priv;
};

struct _GomElementTestParsedDelayedClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestInstantiatable {
	GXmlGomElement parent_instance;
	GomElementTestInstantiatablePrivate * priv;
};

struct _GomElementTestInstantiatableClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestInstantiatablePrivate {
	gchar* _name;
};

struct _GomElementTestTop {
	GXmlGomElement parent_instance;
	GomElementTestTopPrivate * priv;
};

struct _GomElementTestTopClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestTopPrivate {
	GomElementTestInstantiatable* _inst_i;
	Property* _pq;
};

struct _GomElementTestGProperty {
	GXmlGomString parent_instance;
	GomElementTestGPropertyPrivate * priv;
};

struct _GomElementTestGPropertyClass {
	GXmlGomStringClass parent_class;
};

struct _GomElementTestGTop {
	GXmlGomElement parent_instance;
	GomElementTestGTopPrivate * priv;
};

struct _GomElementTestGTopClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestGTopPrivate {
	NoInstantiatable* _inst;
	Property* _pq;
};

struct _GomElementTestPotion {
	GXmlGomElement parent_instance;
	GomElementTestPotionPrivate * priv;
};

struct _GomElementTestPotionClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestPotionPrivate {
	gchar* _cname;
	GomElementTestIngredient* _ingredient;
};

struct _GomElementTestIngredient {
	GXmlGomElement parent_instance;
	GomElementTestIngredientPrivate * priv;
};

struct _GomElementTestIngredientClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestIngredientPrivate {
	gchar* _cname;
	GomElementTestMethodMap* _methods;
};

struct _GomElementTestIngredientMap {
	GXmlGomHashMap parent_instance;
	GomElementTestIngredientMapPrivate * priv;
};

struct _GomElementTestIngredientMapClass {
	GXmlGomHashMapClass parent_class;
};

struct _GomElementTestMethod {
	GXmlGomElement parent_instance;
	GomElementTestMethodPrivate * priv;
};

struct _GomElementTestMethodClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestMethodPrivate {
	gchar* _cname;
};

struct _GomElementTestMethodMap {
	GXmlGomHashMap parent_instance;
	GomElementTestMethodMapPrivate * priv;
};

struct _GomElementTestMethodMapClass {
	GXmlGomHashMapClass parent_class;
};

struct _GomElementTestRepository {
	GXmlGomElement parent_instance;
	GomElementTestRepositoryPrivate * priv;
};

struct _GomElementTestRepositoryClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestRepositoryPrivate {
	gchar* _version;
	GomElementTestNamespace* _ns;
};

struct _GomElementTestNamespace {
	GXmlGomElement parent_instance;
	GomElementTestNamespacePrivate * priv;
};

struct _GomElementTestNamespaceClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestNamespacePrivate {
	GomElementTestTClassMap* _classes;
	gchar* _name;
	gchar* _version;
	gchar* _cprefix;
};

struct _GomElementTestTClass {
	GXmlGomElement parent_instance;
	GomElementTestTClassPrivate * priv;
};

struct _GomElementTestTClassClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestTClassPrivate {
	gchar* _name;
	gchar* _version;
	gchar* _cprefix;
};

struct _GomElementTestTClassMap {
	GXmlGomHashMap parent_instance;
	GomElementTestTClassMapPrivate * priv;
};

struct _GomElementTestTClassMapClass {
	GXmlGomHashMapClass parent_class;
};

static gint ObjectParent_private_offset;
static gpointer object_parent_parent_class = NULL;
static gint ObjectParentObjectProperty_private_offset;
static gpointer object_parent_object_property_parent_class = NULL;
static GXmlGomPropertyIface * object_parent_object_property_gxml_gom_property_parent_iface = NULL;
static gpointer object_parent_object_child_parent_class = NULL;
static gpointer gom_element_test_parent_class = NULL;
static gpointer gom_element_test_parsed_delayed_parent_class = NULL;
static gint GomElementTestInstantiatable_private_offset;
static gpointer gom_element_test_instantiatable_parent_class = NULL;
static NoInstantiatableIface * gom_element_test_instantiatable_no_instantiatable_parent_iface = NULL;
static gint GomElementTestTop_private_offset;
static gpointer gom_element_test_top_parent_class = NULL;
static gpointer gom_element_test_gproperty_parent_class = NULL;
static PropertyIface * gom_element_test_gproperty_property_parent_iface = NULL;
static gint GomElementTestGTop_private_offset;
static gpointer gom_element_test_gtop_parent_class = NULL;
static gint GomElementTestPotion_private_offset;
static gpointer gom_element_test_potion_parent_class = NULL;
static gint GomElementTestIngredient_private_offset;
static gpointer gom_element_test_ingredient_parent_class = NULL;
static gpointer gom_element_test_ingredient_map_parent_class = NULL;
static GXmlMappeableElementIface * gom_element_test_ingredient_gxml_mappeable_element_parent_iface = NULL;
static gint GomElementTestMethod_private_offset;
static gpointer gom_element_test_method_parent_class = NULL;
static gpointer gom_element_test_method_map_parent_class = NULL;
static GXmlMappeableElementIface * gom_element_test_method_gxml_mappeable_element_parent_iface = NULL;
static gint GomElementTestRepository_private_offset;
static gpointer gom_element_test_repository_parent_class = NULL;
static gint GomElementTestNamespace_private_offset;
static gpointer gom_element_test_namespace_parent_class = NULL;
static gint GomElementTestTClass_private_offset;
static gpointer gom_element_test_tclass_parent_class = NULL;
static gpointer gom_element_test_tclass_map_parent_class = NULL;
static GXmlMappeableElementIface * gom_element_test_tclass_gxml_mappeable_element_parent_iface = NULL;

GType no_instantiatable_get_type (void) G_GNUC_CONST;
const gchar* no_instantiatable_get_name (NoInstantiatable* self);
void no_instantiatable_set_name (NoInstantiatable* self,
                                 const gchar* value);
GType property_get_type (void) G_GNUC_CONST;
GType object_parent_get_type (void) G_GNUC_CONST;
GType object_parent_object_property_get_type (void) G_GNUC_CONST;
GType object_parent_object_child_get_type (void) G_GNUC_CONST;
ObjectParent* object_parent_new (void);
ObjectParent* object_parent_construct (GType object_type);
const gchar* object_parent_get_text (ObjectParent* self);
void object_parent_set_text (ObjectParent* self,
                             const gchar* value);
ObjectParentObjectProperty* object_parent_get_prop (ObjectParent* self);
void object_parent_set_prop (ObjectParent* self,
                             ObjectParentObjectProperty* value);
ObjectParentObjectProperty* object_parent_get_prop1 (ObjectParent* self);
void object_parent_set_prop1 (ObjectParent* self,
                              ObjectParentObjectProperty* value);
ObjectParentObjectProperty* object_parent_get_prop2 (ObjectParent* self);
void object_parent_set_prop2 (ObjectParent* self,
                              ObjectParentObjectProperty* value);
ObjectParentObjectProperty* object_parent_get_prop3 (ObjectParent* self);
void object_parent_set_prop3 (ObjectParent* self,
                              ObjectParentObjectProperty* value);
ObjectParentObjectChild* object_parent_get_child (ObjectParent* self);
void object_parent_set_child (ObjectParent* self,
                              ObjectParentObjectChild* value);
static GObject * object_parent_constructor (GType type,
                                     guint n_construct_properties,
                                     GObjectConstructParam * construct_properties);
static gboolean object_parent_object_property_real_validate_value (GXmlGomProperty* base,
                                                            const gchar* val);
ObjectParentObjectProperty* object_parent_object_property_new (void);
ObjectParentObjectProperty* object_parent_object_property_construct (GType object_type);
static void object_parent_object_property_finalize (GObject * obj);
static void _vala_object_parent_object_property_get_property (GObject * object,
                                                       guint property_id,
                                                       GValue * value,
                                                       GParamSpec * pspec);
static void _vala_object_parent_object_property_set_property (GObject * object,
                                                       guint property_id,
                                                       const GValue * value,
                                                       GParamSpec * pspec);
ObjectParentObjectChild* object_parent_object_child_new (void);
ObjectParentObjectChild* object_parent_object_child_construct (GType object_type);
static GObject * object_parent_object_child_constructor (GType type,
                                                  guint n_construct_properties,
                                                  GObjectConstructParam * construct_properties);
static void object_parent_finalize (GObject * obj);
static void _vala_object_parent_get_property (GObject * object,
                                       guint property_id,
                                       GValue * value,
                                       GParamSpec * pspec);
static void _vala_object_parent_set_property (GObject * object,
                                       guint property_id,
                                       const GValue * value,
                                       GParamSpec * pspec);
gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType gom_element_test_get_type (void) G_GNUC_CONST;
void gom_element_test_add_tests (void);
static void __lambda97_ (void);
static void ___lambda97__gtest_func (void);
static void __lambda98_ (void);
static void ___lambda98__gtest_func (void);
static void __lambda99_ (void);
static void ___lambda99__gtest_func (void);
static void __lambda100_ (void);
static void ___lambda100__gtest_func (void);
static void __lambda101_ (void);
GType gom_element_test_potion_get_type (void) G_GNUC_CONST;
GomElementTestPotion* gom_element_test_potion_new (void);
GomElementTestPotion* gom_element_test_potion_construct (GType object_type);
const gchar* gom_element_test_potion_get_cname (GomElementTestPotion* self);
GType gom_element_test_ingredient_get_type (void) G_GNUC_CONST;
GomElementTestIngredient* gom_element_test_potion_get_ingredient (GomElementTestPotion* self);
const gchar* gom_element_test_ingredient_get_cname (GomElementTestIngredient* self);
GType gom_element_test_method_map_get_type (void) G_GNUC_CONST;
GomElementTestMethodMap* gom_element_test_ingredient_get_methods (GomElementTestIngredient* self);
GType gom_element_test_method_get_type (void) G_GNUC_CONST;
const gchar* gom_element_test_method_get_cname (GomElementTestMethod* self);
static void ___lambda101__gtest_func (void);
static void __lambda102_ (void);
GType gom_element_test_repository_get_type (void) G_GNUC_CONST;
GomElementTestRepository* gom_element_test_repository_new (void);
GomElementTestRepository* gom_element_test_repository_construct (GType object_type);
static void ___lambda102__gtest_func (void);
static void __lambda103_ (void);
static void ___lambda103__gtest_func (void);
static void __lambda104_ (void);
static void ___lambda104__gtest_func (void);
static void __lambda105_ (void);
static void ___lambda105__gtest_func (void);
static void __lambda106_ (void);
static void ___lambda106__gtest_func (void);
static void __lambda107_ (void);
static void ___lambda107__gtest_func (void);
static void __lambda108_ (void);
GType gom_element_test_parsed_delayed_get_type (void) G_GNUC_CONST;
GomElementTestParsedDelayed* gom_element_test_parsed_delayed_new (void);
GomElementTestParsedDelayed* gom_element_test_parsed_delayed_construct (GType object_type);
static void ___lambda108__gtest_func (void);
static void __lambda109_ (void);
static void ___lambda109__gtest_func (void);
static void __lambda110_ (void);
static void ___lambda110__gtest_func (void);
static void __lambda111_ (void);
static void ___lambda111__gtest_func (void);
static void __lambda112_ (void);
static void ___lambda112__gtest_func (void);
static void __lambda113_ (void);
static void ___lambda113__gtest_func (void);
static void __lambda114_ (void);
GType gom_element_test_top_get_type (void) G_GNUC_CONST;
GomElementTestTop* gom_element_test_top_new (void);
GomElementTestTop* gom_element_test_top_construct (GType object_type);
NoInstantiatable* gom_element_test_top_get_inst (GomElementTestTop* self);
static void ___lambda114__gtest_func (void);
static void __lambda115_ (void);
GType gom_element_test_gtop_get_type (void) G_GNUC_CONST;
GomElementTestGTop* gom_element_test_gtop_new (void);
GomElementTestGTop* gom_element_test_gtop_construct (GType object_type);
NoInstantiatable* gom_element_test_gtop_get_inst (GomElementTestGTop* self);
Property* gom_element_test_gtop_get_pq (GomElementTestGTop* self);
static void ___lambda115__gtest_func (void);
static void __lambda116_ (void);
static void ___lambda116__gtest_func (void);
static void __lambda117_ (void);
static void ___lambda117__gtest_func (void);
static void __lambda118_ (void);
static void ___lambda118__gtest_func (void);
GomElementTest* gom_element_test_new (void);
GomElementTest* gom_element_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static GObject * gom_element_test_parsed_delayed_constructor (GType type,
                                                       guint n_construct_properties,
                                                       GObjectConstructParam * construct_properties);
GType gom_element_test_instantiatable_get_type (void) G_GNUC_CONST;
GomElementTestInstantiatable* gom_element_test_instantiatable_new (void);
GomElementTestInstantiatable* gom_element_test_instantiatable_construct (GType object_type);
static GObject * gom_element_test_instantiatable_constructor (GType type,
                                                       guint n_construct_properties,
                                                       GObjectConstructParam * construct_properties);
static void gom_element_test_instantiatable_finalize (GObject * obj);
static void _vala_gom_element_test_instantiatable_get_property (GObject * object,
                                                         guint property_id,
                                                         GValue * value,
                                                         GParamSpec * pspec);
static void _vala_gom_element_test_instantiatable_set_property (GObject * object,
                                                         guint property_id,
                                                         const GValue * value,
                                                         GParamSpec * pspec);
GomElementTestInstantiatable* gom_element_test_top_get_inst_i (GomElementTestTop* self);
void gom_element_test_top_set_inst (GomElementTestTop* self,
                                    NoInstantiatable* value);
void gom_element_test_top_set_inst_i (GomElementTestTop* self,
                                      GomElementTestInstantiatable* value);
Property* gom_element_test_top_get_pq (GomElementTestTop* self);
void gom_element_test_top_set_pq (GomElementTestTop* self,
                                  Property* value);
static GObject * gom_element_test_top_constructor (GType type,
                                            guint n_construct_properties,
                                            GObjectConstructParam * construct_properties);
static void gom_element_test_top_finalize (GObject * obj);
static void _vala_gom_element_test_top_get_property (GObject * object,
                                              guint property_id,
                                              GValue * value,
                                              GParamSpec * pspec);
static void _vala_gom_element_test_top_set_property (GObject * object,
                                              guint property_id,
                                              const GValue * value,
                                              GParamSpec * pspec);
GType gom_element_test_gproperty_get_type (void) G_GNUC_CONST;
GomElementTestGProperty* gom_element_test_gproperty_new (void);
GomElementTestGProperty* gom_element_test_gproperty_construct (GType object_type);
void gom_element_test_gtop_set_inst (GomElementTestGTop* self,
                                     NoInstantiatable* value);
GomElementTestInstantiatable* gom_element_test_gtop_get_inst_i (GomElementTestGTop* self);
void gom_element_test_gtop_set_inst_i (GomElementTestGTop* self,
                                       GomElementTestInstantiatable* value);
GomElementTestGProperty* gom_element_test_gtop_get_gpq (GomElementTestGTop* self);
void gom_element_test_gtop_set_gpq (GomElementTestGTop* self,
                                    GomElementTestGProperty* value);
void gom_element_test_gtop_set_pq (GomElementTestGTop* self,
                                   Property* value);
static GObject * gom_element_test_gtop_constructor (GType type,
                                             guint n_construct_properties,
                                             GObjectConstructParam * construct_properties);
static void gom_element_test_gtop_finalize (GObject * obj);
static void _vala_gom_element_test_gtop_get_property (GObject * object,
                                               guint property_id,
                                               GValue * value,
                                               GParamSpec * pspec);
static void _vala_gom_element_test_gtop_set_property (GObject * object,
                                               guint property_id,
                                               const GValue * value,
                                               GParamSpec * pspec);
void gom_element_test_potion_set_cname (GomElementTestPotion* self,
                                        const gchar* value);
void gom_element_test_potion_set_ingredient (GomElementTestPotion* self,
                                             GomElementTestIngredient* value);
static GObject * gom_element_test_potion_constructor (GType type,
                                               guint n_construct_properties,
                                               GObjectConstructParam * construct_properties);
static void gom_element_test_potion_finalize (GObject * obj);
static void _vala_gom_element_test_potion_get_property (GObject * object,
                                                 guint property_id,
                                                 GValue * value,
                                                 GParamSpec * pspec);
static void _vala_gom_element_test_potion_set_property (GObject * object,
                                                 guint property_id,
                                                 const GValue * value,
                                                 GParamSpec * pspec);
static gchar* gom_element_test_ingredient_real_get_map_key (GXmlMappeableElement* base);
GomElementTestIngredient* gom_element_test_ingredient_new (void);
GomElementTestIngredient* gom_element_test_ingredient_construct (GType object_type);
void gom_element_test_ingredient_set_cname (GomElementTestIngredient* self,
                                            const gchar* value);
void gom_element_test_ingredient_set_methods (GomElementTestIngredient* self,
                                              GomElementTestMethodMap* value);
static GObject * gom_element_test_ingredient_constructor (GType type,
                                                   guint n_construct_properties,
                                                   GObjectConstructParam * construct_properties);
GType gom_element_test_ingredient_map_get_type (void) G_GNUC_CONST;
GomElementTestIngredientMap* gom_element_test_ingredient_map_new (void);
GomElementTestIngredientMap* gom_element_test_ingredient_map_construct (GType object_type);
static GObject * gom_element_test_ingredient_map_constructor (GType type,
                                                       guint n_construct_properties,
                                                       GObjectConstructParam * construct_properties);
static void gom_element_test_ingredient_finalize (GObject * obj);
static void _vala_gom_element_test_ingredient_get_property (GObject * object,
                                                     guint property_id,
                                                     GValue * value,
                                                     GParamSpec * pspec);
static void _vala_gom_element_test_ingredient_set_property (GObject * object,
                                                     guint property_id,
                                                     const GValue * value,
                                                     GParamSpec * pspec);
static gchar* gom_element_test_method_real_get_map_key (GXmlMappeableElement* base);
GomElementTestMethod* gom_element_test_method_new (void);
GomElementTestMethod* gom_element_test_method_construct (GType object_type);
void gom_element_test_method_set_cname (GomElementTestMethod* self,
                                        const gchar* value);
static GObject * gom_element_test_method_constructor (GType type,
                                               guint n_construct_properties,
                                               GObjectConstructParam * construct_properties);
GomElementTestMethodMap* gom_element_test_method_map_new (void);
GomElementTestMethodMap* gom_element_test_method_map_construct (GType object_type);
static GObject * gom_element_test_method_map_constructor (GType type,
                                                   guint n_construct_properties,
                                                   GObjectConstructParam * construct_properties);
static void gom_element_test_method_finalize (GObject * obj);
static void _vala_gom_element_test_method_get_property (GObject * object,
                                                 guint property_id,
                                                 GValue * value,
                                                 GParamSpec * pspec);
static void _vala_gom_element_test_method_set_property (GObject * object,
                                                 guint property_id,
                                                 const GValue * value,
                                                 GParamSpec * pspec);
GType gom_element_test_namespace_get_type (void) G_GNUC_CONST;
const gchar* gom_element_test_repository_get_version (GomElementTestRepository* self);
void gom_element_test_repository_set_version (GomElementTestRepository* self,
                                              const gchar* value);
GomElementTestNamespace* gom_element_test_repository_get_ns (GomElementTestRepository* self);
void gom_element_test_repository_set_ns (GomElementTestRepository* self,
                                         GomElementTestNamespace* value);
static GObject * gom_element_test_repository_constructor (GType type,
                                                   guint n_construct_properties,
                                                   GObjectConstructParam * construct_properties);
static void gom_element_test_repository_finalize (GObject * obj);
static void _vala_gom_element_test_repository_get_property (GObject * object,
                                                     guint property_id,
                                                     GValue * value,
                                                     GParamSpec * pspec);
static void _vala_gom_element_test_repository_set_property (GObject * object,
                                                     guint property_id,
                                                     const GValue * value,
                                                     GParamSpec * pspec);
GType gom_element_test_tclass_map_get_type (void) G_GNUC_CONST;
GomElementTestNamespace* gom_element_test_namespace_new (void);
GomElementTestNamespace* gom_element_test_namespace_construct (GType object_type);
const gchar* gom_element_test_namespace_get_name (GomElementTestNamespace* self);
void gom_element_test_namespace_set_name (GomElementTestNamespace* self,
                                          const gchar* value);
const gchar* gom_element_test_namespace_get_version (GomElementTestNamespace* self);
void gom_element_test_namespace_set_version (GomElementTestNamespace* self,
                                             const gchar* value);
const gchar* gom_element_test_namespace_get_cprefix (GomElementTestNamespace* self);
void gom_element_test_namespace_set_cprefix (GomElementTestNamespace* self,
                                             const gchar* value);
GomElementTestTClassMap* gom_element_test_namespace_get_classes (GomElementTestNamespace* self);
void gom_element_test_namespace_set_classes (GomElementTestNamespace* self,
                                             GomElementTestTClassMap* value);
static GObject * gom_element_test_namespace_constructor (GType type,
                                                  guint n_construct_properties,
                                                  GObjectConstructParam * construct_properties);
GomElementTestTClassMap* gom_element_test_tclass_map_new (void);
GomElementTestTClassMap* gom_element_test_tclass_map_construct (GType object_type);
static void gom_element_test_namespace_finalize (GObject * obj);
static void _vala_gom_element_test_namespace_get_property (GObject * object,
                                                    guint property_id,
                                                    GValue * value,
                                                    GParamSpec * pspec);
static void _vala_gom_element_test_namespace_set_property (GObject * object,
                                                    guint property_id,
                                                    const GValue * value,
                                                    GParamSpec * pspec);
GType gom_element_test_tclass_get_type (void) G_GNUC_CONST;
static gchar* gom_element_test_tclass_real_get_map_key (GXmlMappeableElement* base);
const gchar* gom_element_test_tclass_get_name (GomElementTestTClass* self);
GomElementTestTClass* gom_element_test_tclass_new (void);
GomElementTestTClass* gom_element_test_tclass_construct (GType object_type);
void gom_element_test_tclass_set_name (GomElementTestTClass* self,
                                       const gchar* value);
const gchar* gom_element_test_tclass_get_version (GomElementTestTClass* self);
void gom_element_test_tclass_set_version (GomElementTestTClass* self,
                                          const gchar* value);
const gchar* gom_element_test_tclass_get_cprefix (GomElementTestTClass* self);
void gom_element_test_tclass_set_cprefix (GomElementTestTClass* self,
                                          const gchar* value);
static GObject * gom_element_test_tclass_constructor (GType type,
                                               guint n_construct_properties,
                                               GObjectConstructParam * construct_properties);
static GObject * gom_element_test_tclass_map_constructor (GType type,
                                                   guint n_construct_properties,
                                                   GObjectConstructParam * construct_properties);
static void gom_element_test_tclass_finalize (GObject * obj);
static void _vala_gom_element_test_tclass_get_property (GObject * object,
                                                 guint property_id,
                                                 GValue * value,
                                                 GParamSpec * pspec);
static void _vala_gom_element_test_tclass_set_property (GObject * object,
                                                 guint property_id,
                                                 const GValue * value,
                                                 GParamSpec * pspec);
static void _vala_array_destroy (gpointer array,
                          gint array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gint array_length,
                       GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);

const gchar*
no_instantiatable_get_name (NoInstantiatable* self)
{
#line 26 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 26 "GomElementTest.vala"
	return NO_INSTANTIATABLE_GET_INTERFACE (self)->get_name (self);
#line 1023 "GomElementTest.c"
}

void
no_instantiatable_set_name (NoInstantiatable* self,
                            const gchar* value)
{
#line 26 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 26 "GomElementTest.vala"
	NO_INSTANTIATABLE_GET_INTERFACE (self)->set_name (self, value);
#line 1034 "GomElementTest.c"
}

static void
no_instantiatable_default_init (NoInstantiatableIface * iface,
                                gpointer iface_data)
{
#line 25 "GomElementTest.vala"
	g_object_interface_install_property (iface, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1043 "GomElementTest.c"
}

GType
no_instantiatable_get_type (void)
{
	static volatile gsize no_instantiatable_type_id__volatile = 0;
	if (g_once_init_enter (&no_instantiatable_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (NoInstantiatableIface), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) no_instantiatable_default_init, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType no_instantiatable_type_id;
		no_instantiatable_type_id = g_type_register_static (G_TYPE_INTERFACE, "NoInstantiatable", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (no_instantiatable_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (no_instantiatable_type_id, GXML_TYPE_GOM_OBJECT);
		g_once_init_leave (&no_instantiatable_type_id__volatile, no_instantiatable_type_id);
	}
	return no_instantiatable_type_id__volatile;
}

static void
property_default_init (PropertyIface * iface,
                       gpointer iface_data)
{
}

GType
property_get_type (void)
{
	static volatile gsize property_type_id__volatile = 0;
	if (g_once_init_enter (&property_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PropertyIface), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) property_default_init, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType property_type_id;
		property_type_id = g_type_register_static (G_TYPE_INTERFACE, "Property", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (property_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (property_type_id, GXML_TYPE_GOM_PROPERTY);
		g_once_init_leave (&property_type_id__volatile, property_type_id);
	}
	return property_type_id__volatile;
}

static inline gpointer
object_parent_get_instance_private (ObjectParent* self)
{
	return G_STRUCT_MEMBER_P (self, ObjectParent_private_offset);
}

ObjectParent*
object_parent_construct (GType object_type)
{
	ObjectParent * self = NULL;
#line 30 "GomElementTest.vala"
	self = (ObjectParent*) gxml_gom_element_construct (object_type);
#line 30 "GomElementTest.vala"
	return self;
#line 1096 "GomElementTest.c"
}

ObjectParent*
object_parent_new (void)
{
#line 30 "GomElementTest.vala"
	return object_parent_construct (TYPE_OBJECT_PARENT);
#line 1104 "GomElementTest.c"
}

const gchar*
object_parent_get_text (ObjectParent* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 36 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 36 "GomElementTest.vala"
	_tmp0_ = self->priv->_text;
#line 36 "GomElementTest.vala"
	result = _tmp0_;
#line 36 "GomElementTest.vala"
	return result;
#line 1120 "GomElementTest.c"
}

void
object_parent_set_text (ObjectParent* self,
                        const gchar* value)
{
#line 36 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 36 "GomElementTest.vala"
	if (g_strcmp0 (value, object_parent_get_text (self)) != 0) {
#line 1131 "GomElementTest.c"
		gchar* _tmp0_;
#line 36 "GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 36 "GomElementTest.vala"
		_g_free0 (self->priv->_text);
#line 36 "GomElementTest.vala"
		self->priv->_text = _tmp0_;
#line 36 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, object_parent_properties[OBJECT_PARENT_TEXT_PROPERTY]);
#line 1141 "GomElementTest.c"
	}
}

ObjectParentObjectProperty*
object_parent_get_prop (ObjectParent* self)
{
	ObjectParentObjectProperty* result;
	ObjectParentObjectProperty* _tmp0_;
#line 38 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 38 "GomElementTest.vala"
	_tmp0_ = self->priv->_prop;
#line 38 "GomElementTest.vala"
	result = _tmp0_;
#line 38 "GomElementTest.vala"
	return result;
#line 1158 "GomElementTest.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 38 "GomElementTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 1166 "GomElementTest.c"
}

void
object_parent_set_prop (ObjectParent* self,
                        ObjectParentObjectProperty* value)
{
#line 38 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 38 "GomElementTest.vala"
	if (object_parent_get_prop (self) != value) {
#line 1177 "GomElementTest.c"
		ObjectParentObjectProperty* _tmp0_;
#line 38 "GomElementTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 38 "GomElementTest.vala"
		_g_object_unref0 (self->priv->_prop);
#line 38 "GomElementTest.vala"
		self->priv->_prop = _tmp0_;
#line 38 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, object_parent_properties[OBJECT_PARENT_PROP_PROPERTY]);
#line 1187 "GomElementTest.c"
	}
}

ObjectParentObjectProperty*
object_parent_get_prop1 (ObjectParent* self)
{
	ObjectParentObjectProperty* result;
	ObjectParentObjectProperty* _tmp0_;
#line 40 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 40 "GomElementTest.vala"
	_tmp0_ = self->priv->_prop1;
#line 40 "GomElementTest.vala"
	result = _tmp0_;
#line 40 "GomElementTest.vala"
	return result;
#line 1204 "GomElementTest.c"
}

void
object_parent_set_prop1 (ObjectParent* self,
                         ObjectParentObjectProperty* value)
{
#line 40 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 40 "GomElementTest.vala"
	if (object_parent_get_prop1 (self) != value) {
#line 1215 "GomElementTest.c"
		ObjectParentObjectProperty* _tmp0_;
#line 40 "GomElementTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 40 "GomElementTest.vala"
		_g_object_unref0 (self->priv->_prop1);
#line 40 "GomElementTest.vala"
		self->priv->_prop1 = _tmp0_;
#line 40 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, object_parent_properties[OBJECT_PARENT_PROP1_PROPERTY]);
#line 1225 "GomElementTest.c"
	}
}

ObjectParentObjectProperty*
object_parent_get_prop2 (ObjectParent* self)
{
	ObjectParentObjectProperty* result;
	ObjectParentObjectProperty* _tmp0_;
#line 42 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 42 "GomElementTest.vala"
	_tmp0_ = self->priv->_prop2;
#line 42 "GomElementTest.vala"
	result = _tmp0_;
#line 42 "GomElementTest.vala"
	return result;
#line 1242 "GomElementTest.c"
}

void
object_parent_set_prop2 (ObjectParent* self,
                         ObjectParentObjectProperty* value)
{
#line 42 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 42 "GomElementTest.vala"
	if (object_parent_get_prop2 (self) != value) {
#line 1253 "GomElementTest.c"
		ObjectParentObjectProperty* _tmp0_;
#line 42 "GomElementTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 42 "GomElementTest.vala"
		_g_object_unref0 (self->priv->_prop2);
#line 42 "GomElementTest.vala"
		self->priv->_prop2 = _tmp0_;
#line 42 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, object_parent_properties[OBJECT_PARENT_PROP2_PROPERTY]);
#line 1263 "GomElementTest.c"
	}
}

ObjectParentObjectProperty*
object_parent_get_prop3 (ObjectParent* self)
{
	ObjectParentObjectProperty* result;
	ObjectParentObjectProperty* _tmp0_;
#line 44 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 44 "GomElementTest.vala"
	_tmp0_ = self->priv->_prop3;
#line 44 "GomElementTest.vala"
	result = _tmp0_;
#line 44 "GomElementTest.vala"
	return result;
#line 1280 "GomElementTest.c"
}

void
object_parent_set_prop3 (ObjectParent* self,
                         ObjectParentObjectProperty* value)
{
#line 44 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 44 "GomElementTest.vala"
	if (object_parent_get_prop3 (self) != value) {
#line 1291 "GomElementTest.c"
		ObjectParentObjectProperty* _tmp0_;
#line 44 "GomElementTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 44 "GomElementTest.vala"
		_g_object_unref0 (self->priv->_prop3);
#line 44 "GomElementTest.vala"
		self->priv->_prop3 = _tmp0_;
#line 44 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, object_parent_properties[OBJECT_PARENT_PROP3_PROPERTY]);
#line 1301 "GomElementTest.c"
	}
}

ObjectParentObjectChild*
object_parent_get_child (ObjectParent* self)
{
	ObjectParentObjectChild* result;
	ObjectParentObjectChild* _tmp0_;
#line 51 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 51 "GomElementTest.vala"
	_tmp0_ = self->priv->_child;
#line 51 "GomElementTest.vala"
	result = _tmp0_;
#line 51 "GomElementTest.vala"
	return result;
#line 1318 "GomElementTest.c"
}

void
object_parent_set_child (ObjectParent* self,
                         ObjectParentObjectChild* value)
{
#line 51 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 51 "GomElementTest.vala"
	if (object_parent_get_child (self) != value) {
#line 1329 "GomElementTest.c"
		ObjectParentObjectChild* _tmp0_;
#line 51 "GomElementTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 51 "GomElementTest.vala"
		_g_object_unref0 (self->priv->_child);
#line 51 "GomElementTest.vala"
		self->priv->_child = _tmp0_;
#line 51 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, object_parent_properties[OBJECT_PARENT_CHILD_PROPERTY]);
#line 1339 "GomElementTest.c"
	}
}

static GObject *
object_parent_constructor (GType type,
                           guint n_construct_properties,
                           GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	ObjectParent * self;
	GError* _inner_error0_ = NULL;
#line 31 "GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (object_parent_parent_class);
#line 31 "GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 31 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_OBJECT_PARENT, ObjectParent);
#line 1358 "GomElementTest.c"
	{
#line 32 "GomElementTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "root");
#line 1362 "GomElementTest.c"
	}
	goto __finally118;
	__catch118_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 32 "GomElementTest.vala"
		e = _inner_error0_;
#line 32 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 33 "GomElementTest.vala"
		_tmp0_ = e;
#line 33 "GomElementTest.vala"
		_tmp1_ = _tmp0_->message;
#line 33 "GomElementTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 33 "GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 33 "GomElementTest.vala"
		g_warning ("GomElementTest.vala:33: %s", _tmp3_);
#line 33 "GomElementTest.vala"
		_g_free0 (_tmp3_);
#line 32 "GomElementTest.vala"
		_g_error_free0 (e);
#line 1390 "GomElementTest.c"
	}
	__finally118:
#line 32 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 32 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 32 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 1399 "GomElementTest.c"
	}
#line 31 "GomElementTest.vala"
	return obj;
#line 1403 "GomElementTest.c"
}

static inline gpointer
object_parent_object_property_get_instance_private (ObjectParentObjectProperty* self)
{
	return G_STRUCT_MEMBER_P (self, ObjectParentObjectProperty_private_offset);
}

static gboolean
object_parent_object_property_real_validate_value (GXmlGomProperty* base,
                                                   const gchar* val)
{
	ObjectParentObjectProperty * self;
	gboolean result = FALSE;
#line 47 "GomElementTest.vala"
	self = (ObjectParentObjectProperty*) base;
#line 48 "GomElementTest.vala"
	result = TRUE;
#line 48 "GomElementTest.vala"
	return result;
#line 1424 "GomElementTest.c"
}

ObjectParentObjectProperty*
object_parent_object_property_construct (GType object_type)
{
	ObjectParentObjectProperty * self = NULL;
#line 45 "GomElementTest.vala"
	self = (ObjectParentObjectProperty*) g_object_new (object_type, NULL);
#line 45 "GomElementTest.vala"
	return self;
#line 1435 "GomElementTest.c"
}

ObjectParentObjectProperty*
object_parent_object_property_new (void)
{
#line 45 "GomElementTest.vala"
	return object_parent_object_property_construct (OBJECT_PARENT_TYPE_OBJECT_PROPERTY);
#line 1443 "GomElementTest.c"
}

static gchar*
object_parent_object_property_real_get_value (GXmlGomProperty* base)
{
	gchar* result;
	ObjectParentObjectProperty* self;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 46 "GomElementTest.vala"
	self = (ObjectParentObjectProperty*) base;
#line 46 "GomElementTest.vala"
	_tmp0_ = self->priv->_value;
#line 46 "GomElementTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 46 "GomElementTest.vala"
	result = _tmp1_;
#line 46 "GomElementTest.vala"
	return result;
#line 1463 "GomElementTest.c"
}

static void
object_parent_object_property_real_set_value (GXmlGomProperty* base,
                                              const gchar* value)
{
	ObjectParentObjectProperty* self;
#line 46 "GomElementTest.vala"
	self = (ObjectParentObjectProperty*) base;
#line 46 "GomElementTest.vala"
	if (g_strcmp0 (value, object_parent_object_property_real_get_value (base)) != 0) {
#line 1475 "GomElementTest.c"
		gchar* _tmp0_;
#line 46 "GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 46 "GomElementTest.vala"
		_g_free0 (self->priv->_value);
#line 46 "GomElementTest.vala"
		self->priv->_value = _tmp0_;
#line 46 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, object_parent_object_property_properties[OBJECT_PARENT_OBJECT_PROPERTY_VALUE_PROPERTY]);
#line 1485 "GomElementTest.c"
	}
}

static void
object_parent_object_property_class_init (ObjectParentObjectPropertyClass * klass,
                                          gpointer klass_data)
{
#line 45 "GomElementTest.vala"
	object_parent_object_property_parent_class = g_type_class_peek_parent (klass);
#line 45 "GomElementTest.vala"
	g_type_class_adjust_private_offset (klass, &ObjectParentObjectProperty_private_offset);
#line 45 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_object_parent_object_property_get_property;
#line 45 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_object_parent_object_property_set_property;
#line 45 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = object_parent_object_property_finalize;
#line 45 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), OBJECT_PARENT_OBJECT_PROPERTY_VALUE_PROPERTY, object_parent_object_property_properties[OBJECT_PARENT_OBJECT_PROPERTY_VALUE_PROPERTY] = g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1505 "GomElementTest.c"
}

static void
object_parent_object_property_gxml_gom_property_interface_init (GXmlGomPropertyIface * iface,
                                                                gpointer iface_data)
{
#line 45 "GomElementTest.vala"
	object_parent_object_property_gxml_gom_property_parent_iface = g_type_interface_peek_parent (iface);
#line 45 "GomElementTest.vala"
	iface->validate_value = (gboolean (*) (GXmlGomProperty*, const gchar*)) object_parent_object_property_real_validate_value;
#line 45 "GomElementTest.vala"
	iface->get_value = object_parent_object_property_real_get_value;
#line 45 "GomElementTest.vala"
	iface->set_value = object_parent_object_property_real_set_value;
#line 1520 "GomElementTest.c"
}

static void
object_parent_object_property_instance_init (ObjectParentObjectProperty * self,
                                             gpointer klass)
{
#line 45 "GomElementTest.vala"
	self->priv = object_parent_object_property_get_instance_private (self);
#line 1529 "GomElementTest.c"
}

static void
object_parent_object_property_finalize (GObject * obj)
{
	ObjectParentObjectProperty * self;
#line 45 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, OBJECT_PARENT_TYPE_OBJECT_PROPERTY, ObjectParentObjectProperty);
#line 46 "GomElementTest.vala"
	_g_free0 (self->priv->_value);
#line 45 "GomElementTest.vala"
	G_OBJECT_CLASS (object_parent_object_property_parent_class)->finalize (obj);
#line 1542 "GomElementTest.c"
}

GType
object_parent_object_property_get_type (void)
{
	static volatile gsize object_parent_object_property_type_id__volatile = 0;
	if (g_once_init_enter (&object_parent_object_property_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ObjectParentObjectPropertyClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) object_parent_object_property_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ObjectParentObjectProperty), 0, (GInstanceInitFunc) object_parent_object_property_instance_init, NULL };
		static const GInterfaceInfo gxml_gom_property_info = { (GInterfaceInitFunc) object_parent_object_property_gxml_gom_property_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType object_parent_object_property_type_id;
		object_parent_object_property_type_id = g_type_register_static (G_TYPE_OBJECT, "ObjectParentObjectProperty", &g_define_type_info, 0);
		g_type_add_interface_static (object_parent_object_property_type_id, GXML_TYPE_GOM_PROPERTY, &gxml_gom_property_info);
		ObjectParentObjectProperty_private_offset = g_type_add_instance_private (object_parent_object_property_type_id, sizeof (ObjectParentObjectPropertyPrivate));
		g_once_init_leave (&object_parent_object_property_type_id__volatile, object_parent_object_property_type_id);
	}
	return object_parent_object_property_type_id__volatile;
}

static void
_vala_object_parent_object_property_get_property (GObject * object,
                                                  guint property_id,
                                                  GValue * value,
                                                  GParamSpec * pspec)
{
	ObjectParentObjectProperty * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, OBJECT_PARENT_TYPE_OBJECT_PROPERTY, ObjectParentObjectProperty);
#line 45 "GomElementTest.vala"
	switch (property_id) {
#line 45 "GomElementTest.vala"
		case OBJECT_PARENT_OBJECT_PROPERTY_VALUE_PROPERTY:
#line 45 "GomElementTest.vala"
		g_value_take_string (value, gxml_gom_property_get_value ((GXmlGomProperty*) self));
#line 45 "GomElementTest.vala"
		break;
#line 1577 "GomElementTest.c"
		default:
#line 45 "GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 45 "GomElementTest.vala"
		break;
#line 1583 "GomElementTest.c"
	}
}

static void
_vala_object_parent_object_property_set_property (GObject * object,
                                                  guint property_id,
                                                  const GValue * value,
                                                  GParamSpec * pspec)
{
	ObjectParentObjectProperty * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, OBJECT_PARENT_TYPE_OBJECT_PROPERTY, ObjectParentObjectProperty);
#line 45 "GomElementTest.vala"
	switch (property_id) {
#line 45 "GomElementTest.vala"
		case OBJECT_PARENT_OBJECT_PROPERTY_VALUE_PROPERTY:
#line 45 "GomElementTest.vala"
		gxml_gom_property_set_value ((GXmlGomProperty*) self, g_value_get_string (value));
#line 45 "GomElementTest.vala"
		break;
#line 1603 "GomElementTest.c"
		default:
#line 45 "GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 45 "GomElementTest.vala"
		break;
#line 1609 "GomElementTest.c"
	}
}

ObjectParentObjectChild*
object_parent_object_child_construct (GType object_type)
{
	ObjectParentObjectChild * self = NULL;
#line 52 "GomElementTest.vala"
	self = (ObjectParentObjectChild*) gxml_gom_element_construct (object_type);
#line 52 "GomElementTest.vala"
	return self;
#line 1621 "GomElementTest.c"
}

ObjectParentObjectChild*
object_parent_object_child_new (void)
{
#line 52 "GomElementTest.vala"
	return object_parent_object_child_construct (OBJECT_PARENT_TYPE_OBJECT_CHILD);
#line 1629 "GomElementTest.c"
}

static GObject *
object_parent_object_child_constructor (GType type,
                                        guint n_construct_properties,
                                        GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	ObjectParentObjectChild * self;
	GError* _inner_error0_ = NULL;
#line 53 "GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (object_parent_object_child_parent_class);
#line 53 "GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 53 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, OBJECT_PARENT_TYPE_OBJECT_CHILD, ObjectParentObjectChild);
#line 1647 "GomElementTest.c"
	{
#line 54 "GomElementTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "child");
#line 1651 "GomElementTest.c"
	}
	goto __finally119;
	__catch119_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 54 "GomElementTest.vala"
		e = _inner_error0_;
#line 54 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 55 "GomElementTest.vala"
		_tmp0_ = e;
#line 55 "GomElementTest.vala"
		_tmp1_ = _tmp0_->message;
#line 55 "GomElementTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 55 "GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 55 "GomElementTest.vala"
		g_warning ("GomElementTest.vala:55: %s", _tmp3_);
#line 55 "GomElementTest.vala"
		_g_free0 (_tmp3_);
#line 54 "GomElementTest.vala"
		_g_error_free0 (e);
#line 1679 "GomElementTest.c"
	}
	__finally119:
#line 54 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 54 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 54 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 1688 "GomElementTest.c"
	}
#line 53 "GomElementTest.vala"
	return obj;
#line 1692 "GomElementTest.c"
}

static void
object_parent_object_child_class_init (ObjectParentObjectChildClass * klass,
                                       gpointer klass_data)
{
#line 52 "GomElementTest.vala"
	object_parent_object_child_parent_class = g_type_class_peek_parent (klass);
#line 52 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = object_parent_object_child_constructor;
#line 1703 "GomElementTest.c"
}

static void
object_parent_object_child_instance_init (ObjectParentObjectChild * self,
                                          gpointer klass)
{
}

GType
object_parent_object_child_get_type (void)
{
	static volatile gsize object_parent_object_child_type_id__volatile = 0;
	if (g_once_init_enter (&object_parent_object_child_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ObjectParentObjectChildClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) object_parent_object_child_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ObjectParentObjectChild), 0, (GInstanceInitFunc) object_parent_object_child_instance_init, NULL };
		GType object_parent_object_child_type_id;
		object_parent_object_child_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "ObjectParentObjectChild", &g_define_type_info, 0);
		g_once_init_leave (&object_parent_object_child_type_id__volatile, object_parent_object_child_type_id);
	}
	return object_parent_object_child_type_id__volatile;
}

static void
object_parent_class_init (ObjectParentClass * klass,
                          gpointer klass_data)
{
#line 30 "GomElementTest.vala"
	object_parent_parent_class = g_type_class_peek_parent (klass);
#line 30 "GomElementTest.vala"
	g_type_class_adjust_private_offset (klass, &ObjectParent_private_offset);
#line 30 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_object_parent_get_property;
#line 30 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_object_parent_set_property;
#line 30 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = object_parent_constructor;
#line 30 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = object_parent_finalize;
#line 30 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), OBJECT_PARENT_TEXT_PROPERTY, object_parent_properties[OBJECT_PARENT_TEXT_PROPERTY] = g_param_spec_string ("text", "::text", "text", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 30 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), OBJECT_PARENT_PROP_PROPERTY, object_parent_properties[OBJECT_PARENT_PROP_PROPERTY] = g_param_spec_object ("prop", "::prop", "prop", OBJECT_PARENT_TYPE_OBJECT_PROPERTY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 30 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), OBJECT_PARENT_PROP1_PROPERTY, object_parent_properties[OBJECT_PARENT_PROP1_PROPERTY] = g_param_spec_object ("prop1", "::prop1", "prop1", OBJECT_PARENT_TYPE_OBJECT_PROPERTY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 30 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), OBJECT_PARENT_PROP2_PROPERTY, object_parent_properties[OBJECT_PARENT_PROP2_PROPERTY] = g_param_spec_object ("prop2", "::prop2", "prop2", OBJECT_PARENT_TYPE_OBJECT_PROPERTY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 30 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), OBJECT_PARENT_PROP3_PROPERTY, object_parent_properties[OBJECT_PARENT_PROP3_PROPERTY] = g_param_spec_object ("prop3", "::prop3", "prop3", OBJECT_PARENT_TYPE_OBJECT_PROPERTY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 30 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), OBJECT_PARENT_CHILD_PROPERTY, object_parent_properties[OBJECT_PARENT_CHILD_PROPERTY] = g_param_spec_object ("child", "child", "child", OBJECT_PARENT_TYPE_OBJECT_CHILD, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1753 "GomElementTest.c"
}

static void
object_parent_instance_init (ObjectParent * self,
                             gpointer klass)
{
#line 30 "GomElementTest.vala"
	self->priv = object_parent_get_instance_private (self);
#line 1762 "GomElementTest.c"
}

static void
object_parent_finalize (GObject * obj)
{
	ObjectParent * self;
#line 30 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_OBJECT_PARENT, ObjectParent);
#line 36 "GomElementTest.vala"
	_g_free0 (self->priv->_text);
#line 38 "GomElementTest.vala"
	_g_object_unref0 (self->priv->_prop);
#line 40 "GomElementTest.vala"
	_g_object_unref0 (self->priv->_prop1);
#line 42 "GomElementTest.vala"
	_g_object_unref0 (self->priv->_prop2);
#line 44 "GomElementTest.vala"
	_g_object_unref0 (self->priv->_prop3);
#line 51 "GomElementTest.vala"
	_g_object_unref0 (self->priv->_child);
#line 30 "GomElementTest.vala"
	G_OBJECT_CLASS (object_parent_parent_class)->finalize (obj);
#line 1785 "GomElementTest.c"
}

GType
object_parent_get_type (void)
{
	static volatile gsize object_parent_type_id__volatile = 0;
	if (g_once_init_enter (&object_parent_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ObjectParentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) object_parent_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ObjectParent), 0, (GInstanceInitFunc) object_parent_instance_init, NULL };
		GType object_parent_type_id;
		object_parent_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "ObjectParent", &g_define_type_info, 0);
		ObjectParent_private_offset = g_type_add_instance_private (object_parent_type_id, sizeof (ObjectParentPrivate));
		g_once_init_leave (&object_parent_type_id__volatile, object_parent_type_id);
	}
	return object_parent_type_id__volatile;
}

static void
_vala_object_parent_get_property (GObject * object,
                                  guint property_id,
                                  GValue * value,
                                  GParamSpec * pspec)
{
	ObjectParent * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_OBJECT_PARENT, ObjectParent);
#line 30 "GomElementTest.vala"
	switch (property_id) {
#line 30 "GomElementTest.vala"
		case OBJECT_PARENT_TEXT_PROPERTY:
#line 30 "GomElementTest.vala"
		g_value_set_string (value, object_parent_get_text (self));
#line 30 "GomElementTest.vala"
		break;
#line 30 "GomElementTest.vala"
		case OBJECT_PARENT_PROP_PROPERTY:
#line 30 "GomElementTest.vala"
		g_value_set_object (value, object_parent_get_prop (self));
#line 30 "GomElementTest.vala"
		break;
#line 30 "GomElementTest.vala"
		case OBJECT_PARENT_PROP1_PROPERTY:
#line 30 "GomElementTest.vala"
		g_value_set_object (value, object_parent_get_prop1 (self));
#line 30 "GomElementTest.vala"
		break;
#line 30 "GomElementTest.vala"
		case OBJECT_PARENT_PROP2_PROPERTY:
#line 30 "GomElementTest.vala"
		g_value_set_object (value, object_parent_get_prop2 (self));
#line 30 "GomElementTest.vala"
		break;
#line 30 "GomElementTest.vala"
		case OBJECT_PARENT_PROP3_PROPERTY:
#line 30 "GomElementTest.vala"
		g_value_set_object (value, object_parent_get_prop3 (self));
#line 30 "GomElementTest.vala"
		break;
#line 30 "GomElementTest.vala"
		case OBJECT_PARENT_CHILD_PROPERTY:
#line 30 "GomElementTest.vala"
		g_value_set_object (value, object_parent_get_child (self));
#line 30 "GomElementTest.vala"
		break;
#line 1848 "GomElementTest.c"
		default:
#line 30 "GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 30 "GomElementTest.vala"
		break;
#line 1854 "GomElementTest.c"
	}
}

static void
_vala_object_parent_set_property (GObject * object,
                                  guint property_id,
                                  const GValue * value,
                                  GParamSpec * pspec)
{
	ObjectParent * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_OBJECT_PARENT, ObjectParent);
#line 30 "GomElementTest.vala"
	switch (property_id) {
#line 30 "GomElementTest.vala"
		case OBJECT_PARENT_TEXT_PROPERTY:
#line 30 "GomElementTest.vala"
		object_parent_set_text (self, g_value_get_string (value));
#line 30 "GomElementTest.vala"
		break;
#line 30 "GomElementTest.vala"
		case OBJECT_PARENT_PROP_PROPERTY:
#line 30 "GomElementTest.vala"
		object_parent_set_prop (self, g_value_get_object (value));
#line 30 "GomElementTest.vala"
		break;
#line 30 "GomElementTest.vala"
		case OBJECT_PARENT_PROP1_PROPERTY:
#line 30 "GomElementTest.vala"
		object_parent_set_prop1 (self, g_value_get_object (value));
#line 30 "GomElementTest.vala"
		break;
#line 30 "GomElementTest.vala"
		case OBJECT_PARENT_PROP2_PROPERTY:
#line 30 "GomElementTest.vala"
		object_parent_set_prop2 (self, g_value_get_object (value));
#line 30 "GomElementTest.vala"
		break;
#line 30 "GomElementTest.vala"
		case OBJECT_PARENT_PROP3_PROPERTY:
#line 30 "GomElementTest.vala"
		object_parent_set_prop3 (self, g_value_get_object (value));
#line 30 "GomElementTest.vala"
		break;
#line 30 "GomElementTest.vala"
		case OBJECT_PARENT_CHILD_PROPERTY:
#line 30 "GomElementTest.vala"
		object_parent_set_child (self, g_value_get_object (value));
#line 30 "GomElementTest.vala"
		break;
#line 1904 "GomElementTest.c"
		default:
#line 30 "GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 30 "GomElementTest.vala"
		break;
#line 1910 "GomElementTest.c"
	}
}

static void
__lambda97_ (void)
{
	GXmlDomDocument* doc = NULL;
	GError* _inner_error0_ = NULL;
#line 213 "GomElementTest.vala"
	doc = NULL;
#line 1921 "GomElementTest.c"
	{
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_;
		GXmlGomDocument* _tmp2_;
		GXmlGomNode* root = NULL;
		GXmlDomDocument* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlDomElement* _tmp5_;
		GXmlGomNode* _tmp6_;
		GXmlGomNode* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		GXmlGomNode* node = NULL;
		GXmlGomNode* _tmp11_;
		GXmlDomNodeList* _tmp12_;
		GXmlDomNodeList* _tmp13_;
		GXmlDomNodeList* _tmp14_;
		gpointer _tmp15_;
		GXmlGomNode* _tmp16_;
		GXmlGomNode* _tmp17_;
		GXmlGomNode* _tmp18_;
		GXmlGomNode* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
		GXmlGomNode* _tmp23_;
		gchar* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		GXmlGomNode* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
		gchar* _tmp30_;
		GXmlGomNode* _tmp31_;
		gchar* _tmp32_;
		gchar* _tmp33_;
		gchar* _tmp34_;
		GXmlGomNode* _tmp35_;
		GXmlDomNamedNodeMap* _tmp36_;
		GXmlDomNamedNodeMap* _tmp37_;
		GXmlDomNamedNodeMap* _tmp38_;
		gint _tmp39_;
		gint _tmp40_;
		GXmlGomNode* _tmp41_;
		GXmlDomNamedNodeMap* _tmp42_;
		GXmlDomNamedNodeMap* _tmp43_;
		GXmlDomNamedNodeMap* _tmp44_;
		gint _tmp45_;
		gint _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
		gchar* _tmp49_;
		gchar* _tmp50_;
		GXmlGomNode* _tmp51_;
		gchar* _tmp52_;
		gchar* _tmp53_;
		GXmlGomNode* _tmp54_;
		gchar* _tmp55_;
		gchar* _tmp56_;
		GXmlGomNode* _tmp57_;
		gchar* _tmp58_;
		gchar* _tmp59_;
		GXmlGomNode* _tmp60_;
		gchar* _tmp61_;
		gchar* _tmp62_;
		GXmlGomNode* _tmp63_;
		gchar* _tmp64_;
		gchar* _tmp65_;
		GXmlGomNode* _tmp66_;
		gchar* _tmp67_;
		gchar* _tmp68_;
		GXmlGomNode* _tmp69_;
#line 215 "GomElementTest.vala"
		_tmp1_ = gxml_gom_document_new_from_string ("<Potions><magic:Potion xmlns:magic=\"http://hogwarts.co.uk/magic\" xml" \
"ns:products=\"http://diagonalley.co.uk/products\"><ingredient products" \
":name=\"spider\"/></magic:Potion></Potions>", &_inner_error0_);
#line 215 "GomElementTest.vala"
		_tmp0_ = _tmp1_;
#line 215 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2001 "GomElementTest.c"
			goto __catch120_g_error;
		}
#line 215 "GomElementTest.vala"
		_tmp2_ = _tmp0_;
#line 215 "GomElementTest.vala"
		_tmp0_ = NULL;
#line 215 "GomElementTest.vala"
		_g_object_unref0 (doc);
#line 215 "GomElementTest.vala"
		doc = (GXmlDomDocument*) _tmp2_;
#line 216 "GomElementTest.vala"
		_tmp3_ = doc;
#line 216 "GomElementTest.vala"
		_tmp4_ = gxml_dom_document_get_document_element (_tmp3_);
#line 216 "GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 216 "GomElementTest.vala"
		root = G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GXML_TYPE_GOM_NODE, GXmlGomNode);
#line 217 "GomElementTest.vala"
		_tmp6_ = root;
#line 217 "GomElementTest.vala"
		_vala_assert (_tmp6_ != NULL, "root != null");
#line 218 "GomElementTest.vala"
		_tmp7_ = root;
#line 218 "GomElementTest.vala"
		_tmp8_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp7_);
#line 218 "GomElementTest.vala"
		_tmp9_ = _tmp8_;
#line 218 "GomElementTest.vala"
		_tmp10_ = _tmp9_;
#line 218 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp10_, "Potions") == 0, "root.node_name == \"Potions\"");
#line 218 "GomElementTest.vala"
		_g_free0 (_tmp10_);
#line 219 "GomElementTest.vala"
		_tmp11_ = root;
#line 219 "GomElementTest.vala"
		_tmp12_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp11_);
#line 219 "GomElementTest.vala"
		_tmp13_ = _tmp12_;
#line 219 "GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 219 "GomElementTest.vala"
		_tmp15_ = gee_list_get ((GeeList*) _tmp14_, 0);
#line 219 "GomElementTest.vala"
		_tmp16_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlDomNode*) _tmp15_, GXML_TYPE_GOM_NODE, GXmlGomNode);
#line 219 "GomElementTest.vala"
		_g_object_unref0 (_tmp14_);
#line 219 "GomElementTest.vala"
		node = _tmp16_;
#line 220 "GomElementTest.vala"
		_tmp17_ = node;
#line 220 "GomElementTest.vala"
		_vala_assert (_tmp17_ != NULL, "node != null");
#line 221 "GomElementTest.vala"
		_tmp18_ = node;
#line 221 "GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, GXML_TYPE_DOM_ELEMENT), "node is DomElement");
#line 222 "GomElementTest.vala"
		_tmp19_ = node;
#line 222 "GomElementTest.vala"
		_tmp20_ = gxml_dom_element_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp19_) : NULL);
#line 222 "GomElementTest.vala"
		_tmp21_ = _tmp20_;
#line 222 "GomElementTest.vala"
		_tmp22_ = _tmp21_;
#line 222 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp22_, "Potion") == 0, "(node as DomElement).local_name == \"Potion\"");
#line 222 "GomElementTest.vala"
		_g_free0 (_tmp22_);
#line 223 "GomElementTest.vala"
		_tmp23_ = node;
#line 223 "GomElementTest.vala"
		_tmp24_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp23_);
#line 223 "GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 223 "GomElementTest.vala"
		_tmp26_ = _tmp25_;
#line 223 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp26_, "magic:Potion") == 0, "node.node_name == \"magic:Potion\"");
#line 223 "GomElementTest.vala"
		_g_free0 (_tmp26_);
#line 224 "GomElementTest.vala"
		_tmp27_ = node;
#line 224 "GomElementTest.vala"
		_tmp28_ = gxml_dom_element_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp27_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp27_) : NULL);
#line 224 "GomElementTest.vala"
		_tmp29_ = _tmp28_;
#line 224 "GomElementTest.vala"
		_tmp30_ = _tmp29_;
#line 224 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp30_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).namespace_uri == \"http://hogwarts.co.uk/magic\"");
#line 224 "GomElementTest.vala"
		_g_free0 (_tmp30_);
#line 225 "GomElementTest.vala"
		_tmp31_ = node;
#line 225 "GomElementTest.vala"
		_tmp32_ = gxml_dom_element_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp31_) : NULL);
#line 225 "GomElementTest.vala"
		_tmp33_ = _tmp32_;
#line 225 "GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 225 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "magic") == 0, "(node as DomElement).prefix == \"magic\"");
#line 225 "GomElementTest.vala"
		_g_free0 (_tmp34_);
#line 226 "GomElementTest.vala"
		_tmp35_ = node;
#line 226 "GomElementTest.vala"
		_tmp36_ = gxml_dom_element_get_attributes (G_TYPE_CHECK_INSTANCE_TYPE (_tmp35_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp35_) : NULL);
#line 226 "GomElementTest.vala"
		_tmp37_ = _tmp36_;
#line 226 "GomElementTest.vala"
		_tmp38_ = _tmp37_;
#line 226 "GomElementTest.vala"
		_tmp39_ = gee_map_get_size ((GeeMap*) _tmp38_);
#line 226 "GomElementTest.vala"
		_tmp40_ = _tmp39_;
#line 226 "GomElementTest.vala"
		_vala_assert (_tmp40_ == 2, "(node as DomElement).attributes.size == 2");
#line 226 "GomElementTest.vala"
		_g_object_unref0 (_tmp38_);
#line 227 "GomElementTest.vala"
		_tmp41_ = node;
#line 227 "GomElementTest.vala"
		_tmp42_ = gxml_dom_element_get_attributes (G_TYPE_CHECK_INSTANCE_TYPE (_tmp41_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp41_) : NULL);
#line 227 "GomElementTest.vala"
		_tmp43_ = _tmp42_;
#line 227 "GomElementTest.vala"
		_tmp44_ = _tmp43_;
#line 227 "GomElementTest.vala"
		_tmp45_ = gee_map_get_size ((GeeMap*) _tmp44_);
#line 227 "GomElementTest.vala"
		_tmp46_ = _tmp45_;
#line 227 "GomElementTest.vala"
		_tmp47_ = g_strdup_printf ("%i", _tmp46_);
#line 227 "GomElementTest.vala"
		_tmp48_ = _tmp47_;
#line 227 "GomElementTest.vala"
		_tmp49_ = g_strconcat ("Attributes: ", _tmp48_, NULL);
#line 227 "GomElementTest.vala"
		_tmp50_ = _tmp49_;
#line 227 "GomElementTest.vala"
		g_message ("GomElementTest.vala:227: %s", _tmp50_);
#line 227 "GomElementTest.vala"
		_g_free0 (_tmp50_);
#line 227 "GomElementTest.vala"
		_g_free0 (_tmp48_);
#line 227 "GomElementTest.vala"
		_g_object_unref0 (_tmp44_);
#line 228 "GomElementTest.vala"
		_tmp51_ = node;
#line 228 "GomElementTest.vala"
		_tmp52_ = gxml_dom_element_get_attribute (G_TYPE_CHECK_INSTANCE_TYPE (_tmp51_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp51_) : NULL, "xmlns:magic");
#line 228 "GomElementTest.vala"
		_tmp53_ = _tmp52_;
#line 228 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp53_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).get_attribute (\"xmlns:magic\") == \"http://hogwarts.co.uk/magic\"");
#line 228 "GomElementTest.vala"
		_g_free0 (_tmp53_);
#line 229 "GomElementTest.vala"
		_tmp54_ = node;
#line 229 "GomElementTest.vala"
		_tmp55_ = gxml_dom_element_get_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (_tmp54_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp54_) : NULL, "http://www.w3.org/2000/xmlns/", "magic");
#line 229 "GomElementTest.vala"
		_tmp56_ = _tmp55_;
#line 229 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp56_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).get_attribute_ns (\"http://www.w3.org/2000/xmlns/\", \"magic\") == \"http://hogwarts.co.uk/magic\"");
#line 229 "GomElementTest.vala"
		_g_free0 (_tmp56_);
#line 230 "GomElementTest.vala"
		_tmp57_ = node;
#line 230 "GomElementTest.vala"
		_tmp58_ = gxml_dom_element_get_attribute (G_TYPE_CHECK_INSTANCE_TYPE (_tmp57_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp57_) : NULL, "xmlns:products");
#line 230 "GomElementTest.vala"
		_tmp59_ = _tmp58_;
#line 230 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp59_, "http://diagonalley.co.uk/products") == 0, "(node as DomElement).get_attribute (\"xmlns:products\") == \"http://diagonalley.co.uk/products\"");
#line 230 "GomElementTest.vala"
		_g_free0 (_tmp59_);
#line 231 "GomElementTest.vala"
		_tmp60_ = node;
#line 231 "GomElementTest.vala"
		_tmp61_ = gxml_dom_element_get_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (_tmp60_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp60_) : NULL, "http://www.w3.org/2000/xmlns/", "products");
#line 231 "GomElementTest.vala"
		_tmp62_ = _tmp61_;
#line 231 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp62_, "http://diagonalley.co.uk/products") == 0, "(node as DomElement).get_attribute_ns (\"http://www.w3.org/2000/xmlns/\",\"products\") == \"http://diagonalley.co.uk/products\"");
#line 231 "GomElementTest.vala"
		_g_free0 (_tmp62_);
#line 232 "GomElementTest.vala"
		_tmp63_ = node;
#line 232 "GomElementTest.vala"
		_tmp64_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) _tmp63_, "http://diagonalley.co.uk/products");
#line 232 "GomElementTest.vala"
		_tmp65_ = _tmp64_;
#line 232 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp65_, "products") == 0, "node.lookup_prefix (\"http://diagonalley.co.uk/products\") == \"products\"");
#line 232 "GomElementTest.vala"
		_g_free0 (_tmp65_);
#line 233 "GomElementTest.vala"
		_tmp66_ = node;
#line 233 "GomElementTest.vala"
		_tmp67_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp66_, "products");
#line 233 "GomElementTest.vala"
		_tmp68_ = _tmp67_;
#line 233 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp68_, "http://diagonalley.co.uk/products") == 0, "node.lookup_namespace_uri (\"products\") == \"http://diagonalley.co.uk/products\"");
#line 233 "GomElementTest.vala"
		_g_free0 (_tmp68_);
#line 234 "GomElementTest.vala"
		_tmp69_ = node;
#line 234 "GomElementTest.vala"
		gxml_dom_element_set_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (_tmp69_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp69_) : NULL, "http://www.w3.org/2000/xmlns", "xmlns:gxmlt", "http://org.gnome.org/GXmlTest/", &_inner_error0_);
#line 234 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 234 "GomElementTest.vala"
			_g_object_unref0 (node);
#line 234 "GomElementTest.vala"
			_g_object_unref0 (root);
#line 234 "GomElementTest.vala"
			_g_object_unref0 (_tmp0_);
#line 2224 "GomElementTest.c"
			goto __catch120_g_error;
		}
#line 214 "GomElementTest.vala"
		_g_object_unref0 (node);
#line 214 "GomElementTest.vala"
		_g_object_unref0 (root);
#line 214 "GomElementTest.vala"
		_g_object_unref0 (_tmp0_);
#line 2233 "GomElementTest.c"
	}
	goto __finally120;
	__catch120_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp70_;
#line 214 "GomElementTest.vala"
		e = _inner_error0_;
#line 214 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 236 "GomElementTest.vala"
		_tmp70_ = e->message;
#line 236 "GomElementTest.vala"
		g_message ("GomElementTest.vala:236: %s", _tmp70_);
#line 237 "GomElementTest.vala"
		g_assert_not_reached ();
#line 214 "GomElementTest.vala"
		_g_error_free0 (e);
#line 2252 "GomElementTest.c"
	}
	__finally120:
#line 214 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 214 "GomElementTest.vala"
		_g_object_unref0 (doc);
#line 214 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 214 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 214 "GomElementTest.vala"
		return;
#line 2265 "GomElementTest.c"
	}
#line 212 "GomElementTest.vala"
	_g_object_unref0 (doc);
#line 2269 "GomElementTest.c"
}

static void
___lambda97__gtest_func (void)
{
#line 212 "GomElementTest.vala"
	__lambda97_ ();
#line 2277 "GomElementTest.c"
}

static void
__lambda98_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlGomNode* root = NULL;
		GXmlGomDocument* _tmp1_;
		GXmlDomElement* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlGomNode* _tmp4_;
		GXmlGomNode* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		GXmlGomNode* node = NULL;
		GXmlGomNode* _tmp9_;
		GXmlDomNodeList* _tmp10_;
		GXmlDomNodeList* _tmp11_;
		GXmlDomNodeList* _tmp12_;
		gpointer _tmp13_;
		GXmlGomNode* _tmp14_;
		GXmlGomNode* _tmp15_;
		GXmlGomNode* _tmp16_;
		GXmlGomNode* _tmp17_;
		gchar* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		GXmlGomNode* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
		GXmlGomNode* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
		GXmlGomNode* _tmp29_;
		gchar* _tmp30_;
		gchar* _tmp31_;
		gchar* _tmp32_;
		gchar* _tmp33_ = NULL;
		GXmlGomNode* _tmp34_;
		gchar* _tmp35_;
		GXmlGomNode* _tmp36_;
		GXmlDomNamedNodeMap* _tmp37_;
		GXmlDomNamedNodeMap* _tmp38_;
		GXmlDomNamedNodeMap* _tmp39_;
		gint _tmp40_;
		gint _tmp41_;
		GXmlGomNode* _tmp42_;
		gchar* _tmp43_;
		gchar* _tmp44_;
		GXmlGomNode* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
		GXmlGomNode* _tmp48_;
		gchar* _tmp49_;
		gchar* _tmp50_;
		GXmlGomNode* _tmp51_;
		gchar* _tmp52_;
		gchar* _tmp53_;
		GXmlGomNode* _tmp54_;
		gchar* _tmp55_;
		gchar* _tmp56_;
		GXmlGomNode* _tmp57_;
		gchar* _tmp58_;
		gchar* _tmp59_;
#line 242 "GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<Potions><magic:Potion xmlns:magic=\"http://hogwarts.co.uk/magic\" xml" \
"ns:products=\"http://diagonalley.co.uk/products\"/></Potions>", &_inner_error0_);
#line 242 "GomElementTest.vala"
		doc = _tmp0_;
#line 242 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2354 "GomElementTest.c"
			goto __catch121_g_error;
		}
#line 243 "GomElementTest.vala"
		_tmp1_ = doc;
#line 243 "GomElementTest.vala"
		_tmp2_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp1_);
#line 243 "GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 243 "GomElementTest.vala"
		root = G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GXML_TYPE_GOM_NODE, GXmlGomNode);
#line 244 "GomElementTest.vala"
		_tmp4_ = root;
#line 244 "GomElementTest.vala"
		_vala_assert (_tmp4_ != NULL, "root != null");
#line 245 "GomElementTest.vala"
		_tmp5_ = root;
#line 245 "GomElementTest.vala"
		_tmp6_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp5_);
#line 245 "GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 245 "GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 245 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp8_, "Potions") == 0, "root.node_name == \"Potions\"");
#line 245 "GomElementTest.vala"
		_g_free0 (_tmp8_);
#line 246 "GomElementTest.vala"
		_tmp9_ = root;
#line 246 "GomElementTest.vala"
		_tmp10_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp9_);
#line 246 "GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 246 "GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 246 "GomElementTest.vala"
		_tmp13_ = gee_list_get ((GeeList*) _tmp12_, 0);
#line 246 "GomElementTest.vala"
		_tmp14_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlDomNode*) _tmp13_, GXML_TYPE_GOM_NODE, GXmlGomNode);
#line 246 "GomElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 246 "GomElementTest.vala"
		node = _tmp14_;
#line 247 "GomElementTest.vala"
		_tmp15_ = node;
#line 247 "GomElementTest.vala"
		_vala_assert (_tmp15_ != NULL, "node != null");
#line 248 "GomElementTest.vala"
		_tmp16_ = node;
#line 248 "GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp16_, GXML_TYPE_DOM_ELEMENT), "node is DomElement");
#line 249 "GomElementTest.vala"
		_tmp17_ = node;
#line 249 "GomElementTest.vala"
		_tmp18_ = gxml_dom_element_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp17_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp17_) : NULL);
#line 249 "GomElementTest.vala"
		_tmp19_ = _tmp18_;
#line 249 "GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 249 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp20_, "Potion") == 0, "(node as DomElement).local_name == \"Potion\"");
#line 249 "GomElementTest.vala"
		_g_free0 (_tmp20_);
#line 250 "GomElementTest.vala"
		_tmp21_ = node;
#line 250 "GomElementTest.vala"
		_tmp22_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp21_);
#line 250 "GomElementTest.vala"
		_tmp23_ = _tmp22_;
#line 250 "GomElementTest.vala"
		_tmp24_ = _tmp23_;
#line 250 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp24_, "magic:Potion") == 0, "node.node_name == \"magic:Potion\"");
#line 250 "GomElementTest.vala"
		_g_free0 (_tmp24_);
#line 251 "GomElementTest.vala"
		_tmp25_ = node;
#line 251 "GomElementTest.vala"
		_tmp26_ = gxml_dom_element_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp25_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp25_) : NULL);
#line 251 "GomElementTest.vala"
		_tmp27_ = _tmp26_;
#line 251 "GomElementTest.vala"
		_tmp28_ = _tmp27_;
#line 251 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp28_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).namespace_uri == \"http://hogwarts.co.uk/magic\"");
#line 251 "GomElementTest.vala"
		_g_free0 (_tmp28_);
#line 252 "GomElementTest.vala"
		_tmp29_ = node;
#line 252 "GomElementTest.vala"
		_tmp30_ = gxml_dom_element_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp29_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp29_) : NULL);
#line 252 "GomElementTest.vala"
		_tmp31_ = _tmp30_;
#line 252 "GomElementTest.vala"
		_tmp32_ = _tmp31_;
#line 252 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp32_, "magic") == 0, "(node as DomElement).prefix == \"magic\"");
#line 252 "GomElementTest.vala"
		_g_free0 (_tmp32_);
#line 262 "GomElementTest.vala"
		_tmp34_ = node;
#line 262 "GomElementTest.vala"
		_tmp35_ = gxml_dom_element_write_string ((GXmlDomElement*) (G_TYPE_CHECK_INSTANCE_TYPE (_tmp34_, GXML_TYPE_GOM_ELEMENT) ? ((GXmlGomElement*) _tmp34_) : NULL), NULL, &_inner_error0_);
#line 262 "GomElementTest.vala"
		_tmp33_ = _tmp35_;
#line 262 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 262 "GomElementTest.vala"
			_g_object_unref0 (node);
#line 262 "GomElementTest.vala"
			_g_object_unref0 (root);
#line 262 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2467 "GomElementTest.c"
			goto __catch121_g_error;
		}
#line 262 "GomElementTest.vala"
		g_message ("GomElementTest.vala:262: %s", _tmp33_);
#line 263 "GomElementTest.vala"
		_tmp36_ = node;
#line 263 "GomElementTest.vala"
		_tmp37_ = gxml_dom_element_get_attributes (G_TYPE_CHECK_INSTANCE_TYPE (_tmp36_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp36_) : NULL);
#line 263 "GomElementTest.vala"
		_tmp38_ = _tmp37_;
#line 263 "GomElementTest.vala"
		_tmp39_ = _tmp38_;
#line 263 "GomElementTest.vala"
		_tmp40_ = gxml_dom_named_node_map_get_length (_tmp39_);
#line 263 "GomElementTest.vala"
		_tmp41_ = _tmp40_;
#line 263 "GomElementTest.vala"
		_vala_assert (_tmp41_ == 2, "(node as DomElement).attributes.length == 2");
#line 263 "GomElementTest.vala"
		_g_object_unref0 (_tmp39_);
#line 264 "GomElementTest.vala"
		_tmp42_ = node;
#line 264 "GomElementTest.vala"
		_tmp43_ = gxml_dom_element_get_attribute (G_TYPE_CHECK_INSTANCE_TYPE (_tmp42_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp42_) : NULL, "xmlns:magic");
#line 264 "GomElementTest.vala"
		_tmp44_ = _tmp43_;
#line 264 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp44_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).get_attribute (\"xmlns:magic\") == \"http://hogwarts.co.uk/magic\"");
#line 264 "GomElementTest.vala"
		_g_free0 (_tmp44_);
#line 265 "GomElementTest.vala"
		_tmp45_ = node;
#line 265 "GomElementTest.vala"
		_tmp46_ = gxml_dom_element_get_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (_tmp45_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp45_) : NULL, "http://www.w3.org/2000/xmlns/", "magic");
#line 265 "GomElementTest.vala"
		_tmp47_ = _tmp46_;
#line 265 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp47_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).get_attribute_ns (\"http://www.w3.org/2000/xmlns/\", \"magic\") == \"http://hogwarts.co.uk/magic\"");
#line 265 "GomElementTest.vala"
		_g_free0 (_tmp47_);
#line 266 "GomElementTest.vala"
		_tmp48_ = node;
#line 266 "GomElementTest.vala"
		_tmp49_ = gxml_dom_element_get_attribute (G_TYPE_CHECK_INSTANCE_TYPE (_tmp48_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp48_) : NULL, "xmlns:products");
#line 266 "GomElementTest.vala"
		_tmp50_ = _tmp49_;
#line 266 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp50_, "http://diagonalley.co.uk/products") == 0, "(node as DomElement).get_attribute (\"xmlns:products\") == \"http://diagonalley.co.uk/products\"");
#line 266 "GomElementTest.vala"
		_g_free0 (_tmp50_);
#line 267 "GomElementTest.vala"
		_tmp51_ = node;
#line 267 "GomElementTest.vala"
		_tmp52_ = gxml_dom_element_get_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (_tmp51_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp51_) : NULL, "http://www.w3.org/2000/xmlns/", "products");
#line 267 "GomElementTest.vala"
		_tmp53_ = _tmp52_;
#line 267 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp53_, "http://diagonalley.co.uk/products") == 0, "(node as DomElement).get_attribute_ns (\"http://www.w3.org/2000/xmlns/\",\"products\") == \"http://diagonalley.co.uk/products\"");
#line 267 "GomElementTest.vala"
		_g_free0 (_tmp53_);
#line 268 "GomElementTest.vala"
		_tmp54_ = node;
#line 268 "GomElementTest.vala"
		_tmp55_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) _tmp54_, "http://diagonalley.co.uk/products");
#line 268 "GomElementTest.vala"
		_tmp56_ = _tmp55_;
#line 268 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp56_, "products") == 0, "node.lookup_prefix (\"http://diagonalley.co.uk/products\") == \"products\"");
#line 268 "GomElementTest.vala"
		_g_free0 (_tmp56_);
#line 269 "GomElementTest.vala"
		_tmp57_ = node;
#line 269 "GomElementTest.vala"
		_tmp58_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp57_, "products");
#line 269 "GomElementTest.vala"
		_tmp59_ = _tmp58_;
#line 269 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp59_, "http://diagonalley.co.uk/products") == 0, "node.lookup_namespace_uri (\"products\") == \"http://diagonalley.co.uk/products\"");
#line 269 "GomElementTest.vala"
		_g_free0 (_tmp59_);
#line 241 "GomElementTest.vala"
		_g_free0 (_tmp33_);
#line 241 "GomElementTest.vala"
		_g_object_unref0 (node);
#line 241 "GomElementTest.vala"
		_g_object_unref0 (root);
#line 241 "GomElementTest.vala"
		_g_object_unref0 (doc);
#line 2556 "GomElementTest.c"
	}
	goto __finally121;
	__catch121_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp60_;
#line 241 "GomElementTest.vala"
		e = _inner_error0_;
#line 241 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 271 "GomElementTest.vala"
		_tmp60_ = e->message;
#line 271 "GomElementTest.vala"
		g_message ("GomElementTest.vala:271: %s", _tmp60_);
#line 272 "GomElementTest.vala"
		g_assert_not_reached ();
#line 241 "GomElementTest.vala"
		_g_error_free0 (e);
#line 2575 "GomElementTest.c"
	}
	__finally121:
#line 241 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 241 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 241 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 241 "GomElementTest.vala"
		return;
#line 2586 "GomElementTest.c"
	}
}

static void
___lambda98__gtest_func (void)
{
#line 240 "GomElementTest.vala"
	__lambda98_ ();
#line 2595 "GomElementTest.c"
}

static void
__lambda99_ (void)
{
	GXmlDomDocument* doc = NULL;
	GError* _inner_error0_ = NULL;
#line 275 "GomElementTest.vala"
	doc = NULL;
#line 2605 "GomElementTest.c"
	{
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_;
		GXmlGomDocument* _tmp2_;
		GXmlDomElement* r = NULL;
		GXmlDomDocument* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlDomElement* _tmp5_;
		GXmlDomElement* _tmp6_;
		GXmlDomElement* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		GXmlDomElement* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		GXmlDomElement* _tmp14_;
		gchar* _tmp15_;
		gchar* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlDomNodeList* _tmp18_;
		GXmlDomNodeList* _tmp19_;
		GXmlDomNodeList* _tmp20_;
		gint _tmp21_;
		gint _tmp22_;
		GXmlDomNode* n1 = NULL;
		GXmlDomElement* _tmp23_;
		GXmlDomNodeList* _tmp24_;
		GXmlDomNodeList* _tmp25_;
		GXmlDomNodeList* _tmp26_;
		GXmlDomNode* _tmp27_;
		GXmlDomNode* _tmp28_;
		GXmlDomNode* _tmp29_;
		GXmlDomNode* _tmp30_;
		GXmlDomNode* _tmp31_;
		gchar* _tmp32_;
		gchar* _tmp33_;
		gchar* _tmp34_;
		GXmlDomNode* _tmp35_;
		gchar* _tmp36_;
		gchar* _tmp37_;
		gchar* _tmp38_;
		GXmlDomNode* _tmp39_;
		gchar* _tmp40_;
		gchar* _tmp41_;
		gchar* _tmp42_;
		GXmlDomNode* n2 = NULL;
		GXmlDomElement* _tmp43_;
		GXmlDomNodeList* _tmp44_;
		GXmlDomNodeList* _tmp45_;
		GXmlDomNodeList* _tmp46_;
		GXmlDomNode* _tmp47_;
		GXmlDomNode* _tmp48_;
		GXmlDomNode* _tmp49_;
		GXmlDomNode* _tmp50_;
		GXmlDomNode* _tmp51_;
		gchar* _tmp52_;
		gchar* _tmp53_;
		gchar* _tmp54_;
		GXmlDomNode* _tmp55_;
		gchar* _tmp56_;
		gchar* _tmp57_;
		gchar* _tmp58_;
		GXmlDomNode* _tmp59_;
		gchar* _tmp60_;
		gchar* _tmp61_;
		gchar* _tmp62_;
#line 277 "GomElementTest.vala"
		_tmp1_ = gxml_gom_document_new_from_string ("<magic:Potion xmlns:magic=\"http://hogwarts.co.uk/magic\" xmlns:produc" \
"ts=\"http://hogwarts.co.uk/magic\"><magic:Arc/><products:Diamond/></ma" \
"gic:Potion>", &_inner_error0_);
#line 277 "GomElementTest.vala"
		_tmp0_ = _tmp1_;
#line 277 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2679 "GomElementTest.c"
			goto __catch122_g_error;
		}
#line 277 "GomElementTest.vala"
		_tmp2_ = _tmp0_;
#line 277 "GomElementTest.vala"
		_tmp0_ = NULL;
#line 277 "GomElementTest.vala"
		_g_object_unref0 (doc);
#line 277 "GomElementTest.vala"
		doc = (GXmlDomDocument*) _tmp2_;
#line 278 "GomElementTest.vala"
		_tmp3_ = doc;
#line 278 "GomElementTest.vala"
		_tmp4_ = gxml_dom_document_get_document_element (_tmp3_);
#line 278 "GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 278 "GomElementTest.vala"
		r = _tmp5_;
#line 279 "GomElementTest.vala"
		_tmp6_ = r;
#line 279 "GomElementTest.vala"
		_vala_assert (_tmp6_ != NULL, "r != null");
#line 280 "GomElementTest.vala"
		_tmp7_ = r;
#line 280 "GomElementTest.vala"
		_tmp8_ = gxml_dom_element_get_local_name (_tmp7_);
#line 280 "GomElementTest.vala"
		_tmp9_ = _tmp8_;
#line 280 "GomElementTest.vala"
		_tmp10_ = _tmp9_;
#line 280 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp10_, "Potion") == 0, "r.local_name == \"Potion\"");
#line 280 "GomElementTest.vala"
		_g_free0 (_tmp10_);
#line 281 "GomElementTest.vala"
		_tmp11_ = r;
#line 281 "GomElementTest.vala"
		_tmp12_ = gxml_dom_element_get_attribute_ns (_tmp11_, "http://www.w3.org/2000/xmlns/", "magic");
#line 281 "GomElementTest.vala"
		_tmp13_ = _tmp12_;
#line 281 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp13_, "http://hogwarts.co.uk/magic") == 0, "r.get_attribute_ns (\"http://www.w3.org/2000/xmlns/\", \"magic\") == \"http://hogwarts.co.uk/magic\"");
#line 281 "GomElementTest.vala"
		_g_free0 (_tmp13_);
#line 282 "GomElementTest.vala"
		_tmp14_ = r;
#line 282 "GomElementTest.vala"
		_tmp15_ = gxml_dom_element_get_attribute_ns (_tmp14_, "http://www.w3.org/2000/xmlns/", "products");
#line 282 "GomElementTest.vala"
		_tmp16_ = _tmp15_;
#line 282 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp16_, "http://hogwarts.co.uk/magic") == 0, "r.get_attribute_ns (\"http://www.w3.org/2000/xmlns/\", \"products\") == \"http://hogwarts.co.uk/magic\"");
#line 282 "GomElementTest.vala"
		_g_free0 (_tmp16_);
#line 283 "GomElementTest.vala"
		_tmp17_ = r;
#line 283 "GomElementTest.vala"
		_tmp18_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp17_);
#line 283 "GomElementTest.vala"
		_tmp19_ = _tmp18_;
#line 283 "GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 283 "GomElementTest.vala"
		_tmp21_ = gxml_dom_node_list_get_length (_tmp20_);
#line 283 "GomElementTest.vala"
		_tmp22_ = _tmp21_;
#line 283 "GomElementTest.vala"
		_vala_assert (_tmp22_ == 2, "r.child_nodes.length == 2");
#line 283 "GomElementTest.vala"
		_g_object_unref0 (_tmp20_);
#line 284 "GomElementTest.vala"
		_tmp23_ = r;
#line 284 "GomElementTest.vala"
		_tmp24_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp23_);
#line 284 "GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 284 "GomElementTest.vala"
		_tmp26_ = _tmp25_;
#line 284 "GomElementTest.vala"
		_tmp27_ = gxml_dom_node_list_item (_tmp26_, 0);
#line 284 "GomElementTest.vala"
		_tmp28_ = _tmp27_;
#line 284 "GomElementTest.vala"
		_g_object_unref0 (_tmp26_);
#line 284 "GomElementTest.vala"
		n1 = _tmp28_;
#line 285 "GomElementTest.vala"
		_tmp29_ = n1;
#line 285 "GomElementTest.vala"
		_vala_assert (_tmp29_ != NULL, "n1 != null");
#line 286 "GomElementTest.vala"
		_tmp30_ = n1;
#line 286 "GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp30_, GXML_TYPE_DOM_ELEMENT), "n1 is DomElement");
#line 287 "GomElementTest.vala"
		_tmp31_ = n1;
#line 287 "GomElementTest.vala"
		_tmp32_ = gxml_dom_element_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp31_) : NULL);
#line 287 "GomElementTest.vala"
		_tmp33_ = _tmp32_;
#line 287 "GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 287 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "Arc") == 0, "(n1 as DomElement).local_name == \"Arc\"");
#line 287 "GomElementTest.vala"
		_g_free0 (_tmp34_);
#line 288 "GomElementTest.vala"
		_tmp35_ = n1;
#line 288 "GomElementTest.vala"
		_tmp36_ = gxml_dom_element_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp35_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp35_) : NULL);
#line 288 "GomElementTest.vala"
		_tmp37_ = _tmp36_;
#line 288 "GomElementTest.vala"
		_tmp38_ = _tmp37_;
#line 288 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp38_, "magic") == 0, "(n1 as DomElement).prefix == \"magic\"");
#line 288 "GomElementTest.vala"
		_g_free0 (_tmp38_);
#line 289 "GomElementTest.vala"
		_tmp39_ = n1;
#line 289 "GomElementTest.vala"
		_tmp40_ = gxml_dom_element_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp39_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp39_) : NULL);
#line 289 "GomElementTest.vala"
		_tmp41_ = _tmp40_;
#line 289 "GomElementTest.vala"
		_tmp42_ = _tmp41_;
#line 289 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp42_, "http://hogwarts.co.uk/magic") == 0, "(n1 as DomElement).namespace_uri == \"http://hogwarts.co.uk/magic\"");
#line 289 "GomElementTest.vala"
		_g_free0 (_tmp42_);
#line 290 "GomElementTest.vala"
		_tmp43_ = r;
#line 290 "GomElementTest.vala"
		_tmp44_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp43_);
#line 290 "GomElementTest.vala"
		_tmp45_ = _tmp44_;
#line 290 "GomElementTest.vala"
		_tmp46_ = _tmp45_;
#line 290 "GomElementTest.vala"
		_tmp47_ = gxml_dom_node_list_item (_tmp46_, 1);
#line 290 "GomElementTest.vala"
		_tmp48_ = _tmp47_;
#line 290 "GomElementTest.vala"
		_g_object_unref0 (_tmp46_);
#line 290 "GomElementTest.vala"
		n2 = _tmp48_;
#line 291 "GomElementTest.vala"
		_tmp49_ = n2;
#line 291 "GomElementTest.vala"
		_vala_assert (_tmp49_ != NULL, "n2 != null");
#line 292 "GomElementTest.vala"
		_tmp50_ = n2;
#line 292 "GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp50_, GXML_TYPE_DOM_ELEMENT), "n2 is DomElement");
#line 293 "GomElementTest.vala"
		_tmp51_ = n2;
#line 293 "GomElementTest.vala"
		_tmp52_ = gxml_dom_element_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp51_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp51_) : NULL);
#line 293 "GomElementTest.vala"
		_tmp53_ = _tmp52_;
#line 293 "GomElementTest.vala"
		_tmp54_ = _tmp53_;
#line 293 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp54_, "Diamond") == 0, "(n2 as DomElement).local_name == \"Diamond\"");
#line 293 "GomElementTest.vala"
		_g_free0 (_tmp54_);
#line 294 "GomElementTest.vala"
		_tmp55_ = n2;
#line 294 "GomElementTest.vala"
		_tmp56_ = gxml_dom_element_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp55_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp55_) : NULL);
#line 294 "GomElementTest.vala"
		_tmp57_ = _tmp56_;
#line 294 "GomElementTest.vala"
		_tmp58_ = _tmp57_;
#line 294 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp58_, "products") == 0, "(n2 as DomElement).prefix == \"products\"");
#line 294 "GomElementTest.vala"
		_g_free0 (_tmp58_);
#line 295 "GomElementTest.vala"
		_tmp59_ = n2;
#line 295 "GomElementTest.vala"
		_tmp60_ = gxml_dom_element_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp59_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp59_) : NULL);
#line 295 "GomElementTest.vala"
		_tmp61_ = _tmp60_;
#line 295 "GomElementTest.vala"
		_tmp62_ = _tmp61_;
#line 295 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp62_, "http://hogwarts.co.uk/magic") == 0, "(n2 as DomElement).namespace_uri == \"http://hogwarts.co.uk/magic\"");
#line 295 "GomElementTest.vala"
		_g_free0 (_tmp62_);
#line 276 "GomElementTest.vala"
		_g_object_unref0 (n2);
#line 276 "GomElementTest.vala"
		_g_object_unref0 (n1);
#line 276 "GomElementTest.vala"
		_g_object_unref0 (r);
#line 276 "GomElementTest.vala"
		_g_object_unref0 (_tmp0_);
#line 2878 "GomElementTest.c"
	}
	goto __finally122;
	__catch122_g_error:
	{
		GError* e = NULL;
		GError* _tmp63_;
		const gchar* _tmp64_;
#line 276 "GomElementTest.vala"
		e = _inner_error0_;
#line 276 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 297 "GomElementTest.vala"
		_tmp63_ = e;
#line 297 "GomElementTest.vala"
		_tmp64_ = _tmp63_->message;
#line 297 "GomElementTest.vala"
		g_warning ("GomElementTest.vala:297: %s", _tmp64_);
#line 276 "GomElementTest.vala"
		_g_error_free0 (e);
#line 2898 "GomElementTest.c"
	}
	__finally122:
#line 276 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 276 "GomElementTest.vala"
		_g_object_unref0 (doc);
#line 276 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 276 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 276 "GomElementTest.vala"
		return;
#line 2911 "GomElementTest.c"
	}
#line 274 "GomElementTest.vala"
	_g_object_unref0 (doc);
#line 2915 "GomElementTest.c"
}

static void
___lambda99__gtest_func (void)
{
#line 274 "GomElementTest.vala"
	__lambda99_ ();
#line 2923 "GomElementTest.c"
}

static gboolean
string_contains (const gchar* self,
                 const gchar* needle)
{
	gboolean result = FALSE;
	gchar* _tmp0_;
#line 1476 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1476 "glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1477 "glib-2.0.vapi"
	_tmp0_ = strstr ((gchar*) self, (gchar*) needle);
#line 1477 "glib-2.0.vapi"
	result = _tmp0_ != NULL;
#line 1477 "glib-2.0.vapi"
	return result;
#line 2942 "GomElementTest.c"
}

static void
__lambda100_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlGomDocument* _tmp1_;
		GXmlDomElement* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlDomElement* _tmp5_ = NULL;
		GXmlGomDocument* _tmp6_;
		GXmlDomElement* _tmp7_;
		GXmlGomElement* elem = NULL;
		GXmlGomElement* _tmp8_;
		GXmlGomDocument* _tmp9_;
		GXmlDomElement* _tmp10_;
		GXmlDomElement* _tmp11_;
		GXmlDomElement* _tmp12_;
		GXmlDomNodeList* _tmp13_;
		GXmlDomNodeList* _tmp14_;
		GXmlDomNodeList* _tmp15_;
		GXmlGomElement* _tmp16_;
		GXmlGomElement* _tmp17_;
		GXmlDomNamedNodeMap* _tmp18_;
		GXmlDomNamedNodeMap* _tmp19_;
		GXmlDomNamedNodeMap* _tmp20_;
		GXmlGomElement* _tmp21_;
		GXmlDomNamedNodeMap* _tmp22_;
		GXmlDomNamedNodeMap* _tmp23_;
		GXmlDomNamedNodeMap* _tmp24_;
		gint _tmp25_;
		gint _tmp26_;
		GXmlGomElement* _tmp27_;
		GXmlGomElement* _tmp28_;
		GXmlGomElement* _tmp29_;
		GXmlDomNamedNodeMap* _tmp30_;
		GXmlDomNamedNodeMap* _tmp31_;
		GXmlDomNamedNodeMap* _tmp32_;
		gint _tmp33_;
		gint _tmp34_;
		GXmlXParser* parser = NULL;
		GXmlGomDocument* _tmp35_;
		GXmlXParser* _tmp36_;
		gchar* _tmp37_ = NULL;
		GXmlXParser* _tmp38_;
		gchar* _tmp39_;
		gchar* _tmp40_;
		gchar* _tmp41_;
		GXmlGomElement* _tmp42_;
		GXmlDomNamedNodeMap* _tmp43_;
		GXmlDomNamedNodeMap* _tmp44_;
		GXmlDomNamedNodeMap* _tmp45_;
		GXmlDomNode* _tmp46_;
		GXmlDomNode* _tmp47_;
		gchar* _tmp48_;
		gchar* _tmp49_;
		gchar* _tmp50_;
		GXmlGomElement* _tmp51_;
		GXmlDomNamedNodeMap* _tmp52_;
		GXmlDomNamedNodeMap* _tmp53_;
		GXmlDomNamedNodeMap* _tmp54_;
		GXmlDomNode* _tmp55_;
		GXmlDomNode* _tmp56_;
		gchar* _tmp57_;
		gchar* _tmp58_;
		gchar* _tmp59_;
		GXmlGomElement* _tmp60_;
		GXmlGomAttr* attr = NULL;
		GXmlGomElement* _tmp61_;
		GXmlDomNamedNodeMap* _tmp62_;
		GXmlDomNamedNodeMap* _tmp63_;
		GXmlDomNamedNodeMap* _tmp64_;
		GXmlDomNode* _tmp65_;
		GXmlGomAttr* _tmp66_;
		GXmlGomAttr* _tmp67_;
		GXmlGomAttr* _tmp68_;
		GXmlGomAttr* _tmp69_;
		gchar* _tmp70_;
		gchar* _tmp71_;
		gchar* _tmp72_;
		GXmlGomElement* _tmp73_;
		GXmlDomNamedNodeMap* _tmp74_;
		GXmlDomNamedNodeMap* _tmp75_;
		GXmlDomNamedNodeMap* _tmp76_;
		gint _tmp77_;
		gint _tmp78_;
		GXmlGomElement* _tmp79_;
		gchar* _tmp80_;
		gchar* _tmp81_;
		GXmlGomElement* _tmp82_;
		GXmlDomNamedNodeMap* _tmp83_;
		GXmlDomNamedNodeMap* _tmp84_;
		GXmlDomNamedNodeMap* _tmp85_;
		GXmlDomNode* _tmp86_;
		GXmlDomNode* _tmp87_;
		GXmlGomElement* _tmp88_;
		gchar* _tmp89_;
		gchar* _tmp90_;
		GXmlGomElement* _tmp91_;
		GXmlDomNamedNodeMap* _tmp92_;
		GXmlDomNamedNodeMap* _tmp93_;
		GXmlDomNamedNodeMap* _tmp94_;
		gint _tmp95_;
		gint _tmp96_;
		GXmlGomElement* _tmp97_;
		GXmlGomElement* _tmp98_;
		GXmlDomNamedNodeMap* _tmp99_;
		GXmlDomNamedNodeMap* _tmp100_;
		GXmlDomNamedNodeMap* _tmp101_;
		gint _tmp102_;
		gint _tmp103_;
		GXmlGomElement* _tmp104_;
		GXmlGomElement* _tmp105_;
		GXmlDomNamedNodeMap* _tmp106_;
		GXmlDomNamedNodeMap* _tmp107_;
		GXmlDomNamedNodeMap* _tmp108_;
		gint _tmp109_;
		gint _tmp110_;
		GXmlGomElement* _tmp111_;
		GXmlGomElement* _tmp112_;
		GXmlDomNamedNodeMap* _tmp113_;
		GXmlDomNamedNodeMap* _tmp114_;
		GXmlDomNamedNodeMap* _tmp115_;
		gint _tmp116_;
		gint _tmp117_;
		GXmlGomElement* _tmp118_;
		gchar* _tmp119_;
		gchar* _tmp120_;
		GXmlGomElement* _tmp121_;
		GXmlGomElement* _tmp122_;
		gchar* _tmp123_;
		gchar* _tmp124_;
		GXmlGomElement* _tmp125_;
		gchar* _tmp126_;
		gchar* _tmp127_;
		GXmlGomElement* _tmp128_;
		GXmlDomNamedNodeMap* _tmp129_;
		GXmlDomNamedNodeMap* _tmp130_;
		GXmlDomNamedNodeMap* _tmp131_;
		gint _tmp132_;
		gint _tmp133_;
		GXmlGomElement* _tmp134_;
		gchar* _tmp135_ = NULL;
		GXmlGomElement* _tmp136_;
		gchar* _tmp137_;
		GXmlGomElement* _tmp138_;
		gchar* _tmp139_;
		gchar* _tmp140_;
		gchar* _tmp141_;
		GXmlGomElement* _tmp147_;
		GXmlGomElement* _tmp148_;
		GXmlDomNamedNodeMap* _tmp149_;
		GXmlDomNamedNodeMap* _tmp150_;
		GXmlDomNamedNodeMap* _tmp151_;
		GXmlGomElement* _tmp152_;
		GXmlDomNamedNodeMap* _tmp153_;
		GXmlDomNamedNodeMap* _tmp154_;
		GXmlDomNamedNodeMap* _tmp155_;
		gint _tmp156_;
		gint _tmp157_;
		GXmlDomElement* n = NULL;
		GXmlGomDocument* _tmp158_;
		GXmlDomElement* _tmp159_;
		GXmlGomElement* _tmp160_;
		GXmlDomElement* _tmp161_;
		GXmlDomNode* _tmp162_;
		GXmlDomNode* _tmp163_;
		GXmlDomElement* child = NULL;
		GXmlGomDocument* _tmp164_;
		GXmlDomElement* _tmp165_;
		GXmlDomElement* _tmp166_;
		GXmlDomElement* _tmp167_;
		GXmlDomNode* _tmp168_;
		GXmlDomNode* _tmp169_;
		GXmlGomElement* _tmp170_;
		GXmlGomElement* _tmp171_;
		gchar* _tmp172_;
		gchar* _tmp173_;
		GXmlDomElement* _tmp174_;
		gchar* _tmp175_;
		gchar* _tmp176_;
		GXmlDomElement* _tmp177_;
		gchar* _tmp178_;
		gchar* _tmp179_;
		GXmlGomElement* _tmp180_;
		gchar* _tmp181_;
		gchar* _tmp182_;
		GXmlDomElement* _tmp183_;
		gchar* _tmp184_;
		gchar* _tmp185_;
		GXmlDomElement* _tmp186_;
		gchar* _tmp187_;
		gchar* _tmp188_;
		gchar* _tmp189_ = NULL;
		GXmlGomElement* _tmp190_;
		gchar* _tmp191_;
		GXmlDomElement* _tmp192_;
		GXmlGomElement* _tmp193_;
		gchar* _tmp194_;
		gchar* _tmp195_;
		GXmlGomElement* _tmp196_;
		gchar* _tmp197_;
		gchar* _tmp198_;
		GXmlDomElement* _tmp199_;
		gchar* _tmp200_;
		gchar* _tmp201_;
#line 302 "GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<root />", &_inner_error0_);
#line 302 "GomElementTest.vala"
		doc = _tmp0_;
#line 302 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 3159 "GomElementTest.c"
			goto __catch123_g_error;
		}
#line 303 "GomElementTest.vala"
		_tmp1_ = doc;
#line 303 "GomElementTest.vala"
		_tmp2_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp1_);
#line 303 "GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 303 "GomElementTest.vala"
		_tmp4_ = _tmp3_;
#line 303 "GomElementTest.vala"
		_vala_assert (_tmp4_ != NULL, "doc.document_element != null");
#line 303 "GomElementTest.vala"
		_g_object_unref0 (_tmp4_);
#line 304 "GomElementTest.vala"
		_tmp6_ = doc;
#line 304 "GomElementTest.vala"
		_tmp7_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp6_, "alphanumeric", &_inner_error0_);
#line 304 "GomElementTest.vala"
		_tmp5_ = _tmp7_;
#line 304 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 304 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3184 "GomElementTest.c"
			goto __catch123_g_error;
		}
#line 304 "GomElementTest.vala"
		_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GXML_TYPE_GOM_ELEMENT, GXmlGomElement));
#line 304 "GomElementTest.vala"
		elem = _tmp8_;
#line 305 "GomElementTest.vala"
		_tmp9_ = doc;
#line 305 "GomElementTest.vala"
		_tmp10_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp9_);
#line 305 "GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 305 "GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 305 "GomElementTest.vala"
		_tmp13_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp12_);
#line 305 "GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 305 "GomElementTest.vala"
		_tmp15_ = _tmp14_;
#line 305 "GomElementTest.vala"
		_tmp16_ = elem;
#line 305 "GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp15_, (GXmlDomNode*) _tmp16_);
#line 305 "GomElementTest.vala"
		_g_object_unref0 (_tmp15_);
#line 305 "GomElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 306 "GomElementTest.vala"
		_tmp17_ = elem;
#line 306 "GomElementTest.vala"
		_tmp18_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp17_);
#line 306 "GomElementTest.vala"
		_tmp19_ = _tmp18_;
#line 306 "GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 306 "GomElementTest.vala"
		_vala_assert (_tmp20_ != NULL, "elem.attributes != null");
#line 306 "GomElementTest.vala"
		_g_object_unref0 (_tmp20_);
#line 307 "GomElementTest.vala"
		_tmp21_ = elem;
#line 307 "GomElementTest.vala"
		_tmp22_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp21_);
#line 307 "GomElementTest.vala"
		_tmp23_ = _tmp22_;
#line 307 "GomElementTest.vala"
		_tmp24_ = _tmp23_;
#line 307 "GomElementTest.vala"
		_tmp25_ = gee_map_get_size ((GeeMap*) _tmp24_);
#line 307 "GomElementTest.vala"
		_tmp26_ = _tmp25_;
#line 307 "GomElementTest.vala"
		_vala_assert (_tmp26_ == 0, "elem.attributes.size == 0");
#line 307 "GomElementTest.vala"
		_g_object_unref0 (_tmp24_);
#line 308 "GomElementTest.vala"
		_tmp27_ = elem;
#line 308 "GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp27_, "alley", "Diagon", &_inner_error0_);
#line 308 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 308 "GomElementTest.vala"
			_g_object_unref0 (elem);
#line 308 "GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 308 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3253 "GomElementTest.c"
			goto __catch123_g_error;
		}
#line 309 "GomElementTest.vala"
		_tmp28_ = elem;
#line 309 "GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp28_, "train", "Hogwarts Express", &_inner_error0_);
#line 309 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 309 "GomElementTest.vala"
			_g_object_unref0 (elem);
#line 309 "GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 309 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3268 "GomElementTest.c"
			goto __catch123_g_error;
		}
#line 310 "GomElementTest.vala"
		_tmp29_ = elem;
#line 310 "GomElementTest.vala"
		_tmp30_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp29_);
#line 310 "GomElementTest.vala"
		_tmp31_ = _tmp30_;
#line 310 "GomElementTest.vala"
		_tmp32_ = _tmp31_;
#line 310 "GomElementTest.vala"
		_tmp33_ = gee_map_get_size ((GeeMap*) _tmp32_);
#line 310 "GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 310 "GomElementTest.vala"
		_vala_assert (_tmp34_ == 2, "elem.attributes.size == 2");
#line 310 "GomElementTest.vala"
		_g_object_unref0 (_tmp32_);
#line 311 "GomElementTest.vala"
		_tmp35_ = doc;
#line 311 "GomElementTest.vala"
		_tmp36_ = gxml_xparser_new ((GXmlDomNode*) _tmp35_);
#line 311 "GomElementTest.vala"
		parser = _tmp36_;
#line 312 "GomElementTest.vala"
		_tmp38_ = parser;
#line 312 "GomElementTest.vala"
		_tmp39_ = gxml_parser_write_string ((GXmlParser*) _tmp38_, &_inner_error0_);
#line 312 "GomElementTest.vala"
		_tmp37_ = _tmp39_;
#line 312 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 312 "GomElementTest.vala"
			_g_object_unref0 (parser);
#line 312 "GomElementTest.vala"
			_g_object_unref0 (elem);
#line 312 "GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 312 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3309 "GomElementTest.c"
			goto __catch123_g_error;
		}
#line 312 "GomElementTest.vala"
		_tmp40_ = g_strconcat ("Getting attributes value alley... Node: ", _tmp37_, NULL);
#line 312 "GomElementTest.vala"
		_tmp41_ = _tmp40_;
#line 312 "GomElementTest.vala"
		g_test_message ("%s", _tmp41_);
#line 312 "GomElementTest.vala"
		_g_free0 (_tmp41_);
#line 313 "GomElementTest.vala"
		_tmp42_ = elem;
#line 313 "GomElementTest.vala"
		_tmp43_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp42_);
#line 313 "GomElementTest.vala"
		_tmp44_ = _tmp43_;
#line 313 "GomElementTest.vala"
		_tmp45_ = _tmp44_;
#line 313 "GomElementTest.vala"
		_tmp46_ = gxml_dom_named_node_map_get_named_item (_tmp45_, "alley");
#line 313 "GomElementTest.vala"
		_tmp47_ = _tmp46_;
#line 313 "GomElementTest.vala"
		_tmp48_ = gxml_dom_node_get_node_value (_tmp47_);
#line 313 "GomElementTest.vala"
		_tmp49_ = _tmp48_;
#line 313 "GomElementTest.vala"
		_tmp50_ = _tmp49_;
#line 313 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp50_, "Diagon") == 0, "elem.attributes.get_named_item (\"alley\").node_value == \"Diagon\"");
#line 313 "GomElementTest.vala"
		_g_free0 (_tmp50_);
#line 313 "GomElementTest.vala"
		_g_object_unref0 (_tmp47_);
#line 313 "GomElementTest.vala"
		_g_object_unref0 (_tmp45_);
#line 314 "GomElementTest.vala"
		_tmp51_ = elem;
#line 314 "GomElementTest.vala"
		_tmp52_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp51_);
#line 314 "GomElementTest.vala"
		_tmp53_ = _tmp52_;
#line 314 "GomElementTest.vala"
		_tmp54_ = _tmp53_;
#line 314 "GomElementTest.vala"
		_tmp55_ = gxml_dom_named_node_map_get_named_item (_tmp54_, "train");
#line 314 "GomElementTest.vala"
		_tmp56_ = _tmp55_;
#line 314 "GomElementTest.vala"
		_tmp57_ = gxml_dom_node_get_node_value (_tmp56_);
#line 314 "GomElementTest.vala"
		_tmp58_ = _tmp57_;
#line 314 "GomElementTest.vala"
		_tmp59_ = _tmp58_;
#line 314 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp59_, "Hogwarts Express") == 0, "elem.attributes.get_named_item (\"train\").node_value == \"Hogwarts Express\"");
#line 314 "GomElementTest.vala"
		_g_free0 (_tmp59_);
#line 314 "GomElementTest.vala"
		_g_object_unref0 (_tmp56_);
#line 314 "GomElementTest.vala"
		_g_object_unref0 (_tmp54_);
#line 316 "GomElementTest.vala"
		_tmp60_ = elem;
#line 316 "GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp60_, "owl", "Hedwig", &_inner_error0_);
#line 316 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 316 "GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 316 "GomElementTest.vala"
			_g_object_unref0 (parser);
#line 316 "GomElementTest.vala"
			_g_object_unref0 (elem);
#line 316 "GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 316 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3388 "GomElementTest.c"
			goto __catch123_g_error;
		}
#line 317 "GomElementTest.vala"
		_tmp61_ = elem;
#line 317 "GomElementTest.vala"
		_tmp62_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp61_);
#line 317 "GomElementTest.vala"
		_tmp63_ = _tmp62_;
#line 317 "GomElementTest.vala"
		_tmp64_ = _tmp63_;
#line 317 "GomElementTest.vala"
		_tmp65_ = gxml_dom_named_node_map_get_named_item (_tmp64_, "owl");
#line 317 "GomElementTest.vala"
		_tmp66_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp65_, GXML_TYPE_GOM_ATTR) ? ((GXmlGomAttr*) _tmp65_) : NULL;
#line 317 "GomElementTest.vala"
		if (_tmp66_ == NULL) {
#line 317 "GomElementTest.vala"
			_g_object_unref0 (_tmp65_);
#line 3407 "GomElementTest.c"
		}
#line 317 "GomElementTest.vala"
		_tmp67_ = _tmp66_;
#line 317 "GomElementTest.vala"
		_g_object_unref0 (_tmp64_);
#line 317 "GomElementTest.vala"
		attr = _tmp67_;
#line 318 "GomElementTest.vala"
		_tmp68_ = attr;
#line 318 "GomElementTest.vala"
		_vala_assert (_tmp68_ != NULL, "attr != null");
#line 319 "GomElementTest.vala"
		_tmp69_ = attr;
#line 319 "GomElementTest.vala"
		_tmp70_ = gxml_dom_node_get_node_value ((GXmlDomNode*) _tmp69_);
#line 319 "GomElementTest.vala"
		_tmp71_ = _tmp70_;
#line 319 "GomElementTest.vala"
		_tmp72_ = _tmp71_;
#line 319 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp72_, "Hedwig") == 0, "attr.node_value == \"Hedwig\"");
#line 319 "GomElementTest.vala"
		_g_free0 (_tmp72_);
#line 321 "GomElementTest.vala"
		_tmp73_ = elem;
#line 321 "GomElementTest.vala"
		_tmp74_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp73_);
#line 321 "GomElementTest.vala"
		_tmp75_ = _tmp74_;
#line 321 "GomElementTest.vala"
		_tmp76_ = _tmp75_;
#line 321 "GomElementTest.vala"
		_tmp77_ = gee_map_get_size ((GeeMap*) _tmp76_);
#line 321 "GomElementTest.vala"
		_tmp78_ = _tmp77_;
#line 321 "GomElementTest.vala"
		_vala_assert (_tmp78_ == 3, "elem.attributes.size == 3");
#line 321 "GomElementTest.vala"
		_g_object_unref0 (_tmp76_);
#line 322 "GomElementTest.vala"
		_tmp79_ = elem;
#line 322 "GomElementTest.vala"
		_tmp80_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp79_, "owl");
#line 322 "GomElementTest.vala"
		_tmp81_ = _tmp80_;
#line 322 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp81_, "Hedwig") == 0, "elem.get_attribute (\"owl\") == \"Hedwig\"");
#line 322 "GomElementTest.vala"
		_g_free0 (_tmp81_);
#line 324 "GomElementTest.vala"
		_tmp82_ = elem;
#line 324 "GomElementTest.vala"
		_tmp83_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp82_);
#line 324 "GomElementTest.vala"
		_tmp84_ = _tmp83_;
#line 324 "GomElementTest.vala"
		_tmp85_ = _tmp84_;
#line 324 "GomElementTest.vala"
		_tmp86_ = gxml_dom_named_node_map_remove_named_item (_tmp85_, "alley", &_inner_error0_);
#line 324 "GomElementTest.vala"
		_tmp87_ = _tmp86_;
#line 324 "GomElementTest.vala"
		_g_object_unref0 (_tmp87_);
#line 324 "GomElementTest.vala"
		_g_object_unref0 (_tmp85_);
#line 324 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 324 "GomElementTest.vala"
			_g_object_unref0 (attr);
#line 324 "GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 324 "GomElementTest.vala"
			_g_object_unref0 (parser);
#line 324 "GomElementTest.vala"
			_g_object_unref0 (elem);
#line 324 "GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 324 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3487 "GomElementTest.c"
			goto __catch123_g_error;
		}
#line 326 "GomElementTest.vala"
		_tmp88_ = elem;
#line 326 "GomElementTest.vala"
		_tmp89_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp88_, "alley");
#line 326 "GomElementTest.vala"
		_tmp90_ = _tmp89_;
#line 326 "GomElementTest.vala"
		_vala_assert (_tmp90_ == NULL, "elem.get_attribute (\"alley\") == null");
#line 326 "GomElementTest.vala"
		_g_free0 (_tmp90_);
#line 327 "GomElementTest.vala"
		_tmp91_ = elem;
#line 327 "GomElementTest.vala"
		_tmp92_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp91_);
#line 327 "GomElementTest.vala"
		_tmp93_ = _tmp92_;
#line 327 "GomElementTest.vala"
		_tmp94_ = _tmp93_;
#line 327 "GomElementTest.vala"
		_tmp95_ = gee_map_get_size ((GeeMap*) _tmp94_);
#line 327 "GomElementTest.vala"
		_tmp96_ = _tmp95_;
#line 327 "GomElementTest.vala"
		_vala_assert (_tmp96_ == 2, "elem.attributes.size == 2");
#line 327 "GomElementTest.vala"
		_g_object_unref0 (_tmp94_);
#line 328 "GomElementTest.vala"
		_tmp97_ = elem;
#line 328 "GomElementTest.vala"
		gxml_dom_element_remove_attribute ((GXmlDomElement*) _tmp97_, "owl");
#line 329 "GomElementTest.vala"
		_tmp98_ = elem;
#line 329 "GomElementTest.vala"
		_tmp99_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp98_);
#line 329 "GomElementTest.vala"
		_tmp100_ = _tmp99_;
#line 329 "GomElementTest.vala"
		_tmp101_ = _tmp100_;
#line 329 "GomElementTest.vala"
		_tmp102_ = gee_map_get_size ((GeeMap*) _tmp101_);
#line 329 "GomElementTest.vala"
		_tmp103_ = _tmp102_;
#line 329 "GomElementTest.vala"
		_vala_assert (_tmp103_ == 1, "elem.attributes.size == 1");
#line 329 "GomElementTest.vala"
		_g_object_unref0 (_tmp101_);
#line 331 "GomElementTest.vala"
		_tmp104_ = elem;
#line 331 "GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp104_, "http://www.w3.org/2000/xmlns/", "xmlns:gxml", "http://www.gnome.org/GXml", &_inner_error0_);
#line 331 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 331 "GomElementTest.vala"
			_g_object_unref0 (attr);
#line 331 "GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 331 "GomElementTest.vala"
			_g_object_unref0 (parser);
#line 331 "GomElementTest.vala"
			_g_object_unref0 (elem);
#line 331 "GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 331 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3554 "GomElementTest.c"
			goto __catch123_g_error;
		}
#line 333 "GomElementTest.vala"
		_tmp105_ = elem;
#line 333 "GomElementTest.vala"
		_tmp106_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp105_);
#line 333 "GomElementTest.vala"
		_tmp107_ = _tmp106_;
#line 333 "GomElementTest.vala"
		_tmp108_ = _tmp107_;
#line 333 "GomElementTest.vala"
		_tmp109_ = gee_map_get_size ((GeeMap*) _tmp108_);
#line 333 "GomElementTest.vala"
		_tmp110_ = _tmp109_;
#line 333 "GomElementTest.vala"
		_vala_assert (_tmp110_ == 2, "elem.attributes.size == 2");
#line 333 "GomElementTest.vala"
		_g_object_unref0 (_tmp108_);
#line 334 "GomElementTest.vala"
		_tmp111_ = elem;
#line 334 "GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp111_, "http://www.gnome.org/GXml", "gxml:xola", "Mexico", &_inner_error0_);
#line 334 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 334 "GomElementTest.vala"
			_g_object_unref0 (attr);
#line 334 "GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 334 "GomElementTest.vala"
			_g_object_unref0 (parser);
#line 334 "GomElementTest.vala"
			_g_object_unref0 (elem);
#line 334 "GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 334 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3591 "GomElementTest.c"
			goto __catch123_g_error;
		}
#line 335 "GomElementTest.vala"
		_tmp112_ = elem;
#line 335 "GomElementTest.vala"
		_tmp113_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp112_);
#line 335 "GomElementTest.vala"
		_tmp114_ = _tmp113_;
#line 335 "GomElementTest.vala"
		_tmp115_ = _tmp114_;
#line 335 "GomElementTest.vala"
		_tmp116_ = gee_map_get_size ((GeeMap*) _tmp115_);
#line 335 "GomElementTest.vala"
		_tmp117_ = _tmp116_;
#line 335 "GomElementTest.vala"
		_vala_assert (_tmp117_ == 3, "elem.attributes.size == 3");
#line 335 "GomElementTest.vala"
		_g_object_unref0 (_tmp115_);
#line 336 "GomElementTest.vala"
		_tmp118_ = elem;
#line 336 "GomElementTest.vala"
		_tmp119_ = gxml_dom_element_get_attribute_ns ((GXmlDomElement*) _tmp118_, "http://www.gnome.org/GXml", "xola");
#line 336 "GomElementTest.vala"
		_tmp120_ = _tmp119_;
#line 336 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp120_, "Mexico") == 0, "elem.get_attribute_ns (\"http://www.gnome.org/GXml\", \"xola\") == \"Mexico\"");
#line 336 "GomElementTest.vala"
		_g_free0 (_tmp120_);
#line 337 "GomElementTest.vala"
		_tmp121_ = elem;
#line 337 "GomElementTest.vala"
		gxml_dom_element_remove_attribute_ns ((GXmlDomElement*) _tmp121_, "http://www.gnome.org/GXml", "xola");
#line 338 "GomElementTest.vala"
		_tmp122_ = elem;
#line 338 "GomElementTest.vala"
		_tmp123_ = gxml_dom_element_get_attribute_ns ((GXmlDomElement*) _tmp122_, "http://www.gnome.org/GXml", "xola");
#line 338 "GomElementTest.vala"
		_tmp124_ = _tmp123_;
#line 338 "GomElementTest.vala"
		_vala_assert (_tmp124_ == NULL, "elem.get_attribute_ns (\"http://www.gnome.org/GXml\", \"xola\") == null");
#line 338 "GomElementTest.vala"
		_g_free0 (_tmp124_);
#line 339 "GomElementTest.vala"
		_tmp125_ = elem;
#line 339 "GomElementTest.vala"
		_tmp126_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp125_, "xola");
#line 339 "GomElementTest.vala"
		_tmp127_ = _tmp126_;
#line 339 "GomElementTest.vala"
		_vala_assert (_tmp127_ == NULL, "elem.get_attribute (\"xola\") == null");
#line 339 "GomElementTest.vala"
		_g_free0 (_tmp127_);
#line 340 "GomElementTest.vala"
		_tmp128_ = elem;
#line 340 "GomElementTest.vala"
		_tmp129_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp128_);
#line 340 "GomElementTest.vala"
		_tmp130_ = _tmp129_;
#line 340 "GomElementTest.vala"
		_tmp131_ = _tmp130_;
#line 340 "GomElementTest.vala"
		_tmp132_ = gee_map_get_size ((GeeMap*) _tmp131_);
#line 340 "GomElementTest.vala"
		_tmp133_ = _tmp132_;
#line 340 "GomElementTest.vala"
		_vala_assert (_tmp133_ == 2, "elem.attributes.size == 2");
#line 340 "GomElementTest.vala"
		_g_object_unref0 (_tmp131_);
#line 341 "GomElementTest.vala"
		_tmp134_ = elem;
#line 341 "GomElementTest.vala"
		gxml_dom_element_set_id ((GXmlDomElement*) _tmp134_, "idnode");
#line 342 "GomElementTest.vala"
		_tmp136_ = elem;
#line 342 "GomElementTest.vala"
		_tmp137_ = gxml_dom_element_write_string ((GXmlDomElement*) _tmp136_, NULL, &_inner_error0_);
#line 342 "GomElementTest.vala"
		_tmp135_ = _tmp137_;
#line 342 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 342 "GomElementTest.vala"
			_g_object_unref0 (attr);
#line 342 "GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 342 "GomElementTest.vala"
			_g_object_unref0 (parser);
#line 342 "GomElementTest.vala"
			_g_object_unref0 (elem);
#line 342 "GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 342 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3684 "GomElementTest.c"
			goto __catch123_g_error;
		}
#line 342 "GomElementTest.vala"
		_vala_assert (string_contains (_tmp135_, "id=\"idnode\""), "\"id=\\\"idnode\\\"\" in elem.write_string ()");
#line 343 "GomElementTest.vala"
		_tmp138_ = elem;
#line 343 "GomElementTest.vala"
		_tmp139_ = gxml_dom_element_get_id ((GXmlDomElement*) _tmp138_);
#line 343 "GomElementTest.vala"
		_tmp140_ = _tmp139_;
#line 343 "GomElementTest.vala"
		_tmp141_ = _tmp140_;
#line 343 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp141_, "idnode") == 0, "elem.id == \"idnode\"");
#line 343 "GomElementTest.vala"
		_g_free0 (_tmp141_);
#line 3701 "GomElementTest.c"
		{
			GXmlGomElement* _tmp142_;
#line 345 "GomElementTest.vala"
			_tmp142_ = elem;
#line 345 "GomElementTest.vala"
			gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp142_, "http://www.gnome.org/GXml", "gxml2:xola", "Mexico", &_inner_error0_);
#line 345 "GomElementTest.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 3710 "GomElementTest.c"
				goto __catch124_g_error;
			}
#line 346 "GomElementTest.vala"
			g_assert_not_reached ();
#line 3715 "GomElementTest.c"
		}
		goto __finally124;
		__catch124_g_error:
		{
			GError* e = NULL;
			GError* _tmp143_;
			const gchar* _tmp144_;
			gchar* _tmp145_;
			gchar* _tmp146_;
#line 344 "GomElementTest.vala"
			e = _inner_error0_;
#line 344 "GomElementTest.vala"
			_inner_error0_ = NULL;
#line 348 "GomElementTest.vala"
			_tmp143_ = e;
#line 348 "GomElementTest.vala"
			_tmp144_ = _tmp143_->message;
#line 348 "GomElementTest.vala"
			_tmp145_ = g_strconcat ("Correctly Cough Error:", _tmp144_, NULL);
#line 348 "GomElementTest.vala"
			_tmp146_ = _tmp145_;
#line 348 "GomElementTest.vala"
			g_message ("GomElementTest.vala:348: %s", _tmp146_);
#line 348 "GomElementTest.vala"
			_g_free0 (_tmp146_);
#line 344 "GomElementTest.vala"
			_g_error_free0 (e);
#line 3743 "GomElementTest.c"
		}
		__finally124:
#line 344 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 344 "GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 344 "GomElementTest.vala"
			_g_object_unref0 (attr);
#line 344 "GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 344 "GomElementTest.vala"
			_g_object_unref0 (parser);
#line 344 "GomElementTest.vala"
			_g_object_unref0 (elem);
#line 344 "GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 344 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3762 "GomElementTest.c"
			goto __catch123_g_error;
		}
#line 350 "GomElementTest.vala"
		_tmp147_ = elem;
#line 350 "GomElementTest.vala"
		_vala_assert (_tmp147_ != NULL, "elem != null");
#line 351 "GomElementTest.vala"
		_tmp148_ = elem;
#line 351 "GomElementTest.vala"
		_tmp149_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp148_);
#line 351 "GomElementTest.vala"
		_tmp150_ = _tmp149_;
#line 351 "GomElementTest.vala"
		_tmp151_ = _tmp150_;
#line 351 "GomElementTest.vala"
		_vala_assert (_tmp151_ != NULL, "elem.attributes != null");
#line 351 "GomElementTest.vala"
		_g_object_unref0 (_tmp151_);
#line 352 "GomElementTest.vala"
		_tmp152_ = elem;
#line 352 "GomElementTest.vala"
		_tmp153_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp152_);
#line 352 "GomElementTest.vala"
		_tmp154_ = _tmp153_;
#line 352 "GomElementTest.vala"
		_tmp155_ = _tmp154_;
#line 352 "GomElementTest.vala"
		_tmp156_ = gee_map_get_size ((GeeMap*) _tmp155_);
#line 352 "GomElementTest.vala"
		_tmp157_ = _tmp156_;
#line 352 "GomElementTest.vala"
		_vala_assert (_tmp157_ == 3, "elem.attributes.size == 3");
#line 352 "GomElementTest.vala"
		_g_object_unref0 (_tmp155_);
#line 353 "GomElementTest.vala"
		_tmp158_ = doc;
#line 353 "GomElementTest.vala"
		_tmp159_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp158_, "node", &_inner_error0_);
#line 353 "GomElementTest.vala"
		n = _tmp159_;
#line 353 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 353 "GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 353 "GomElementTest.vala"
			_g_object_unref0 (attr);
#line 353 "GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 353 "GomElementTest.vala"
			_g_object_unref0 (parser);
#line 353 "GomElementTest.vala"
			_g_object_unref0 (elem);
#line 353 "GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 353 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3819 "GomElementTest.c"
			goto __catch123_g_error;
		}
#line 354 "GomElementTest.vala"
		_tmp160_ = elem;
#line 354 "GomElementTest.vala"
		_tmp161_ = n;
#line 354 "GomElementTest.vala"
		_tmp162_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp160_, (GXmlDomNode*) _tmp161_, &_inner_error0_);
#line 354 "GomElementTest.vala"
		_tmp163_ = _tmp162_;
#line 354 "GomElementTest.vala"
		_g_object_unref0 (_tmp163_);
#line 354 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 354 "GomElementTest.vala"
			_g_object_unref0 (n);
#line 354 "GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 354 "GomElementTest.vala"
			_g_object_unref0 (attr);
#line 354 "GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 354 "GomElementTest.vala"
			_g_object_unref0 (parser);
#line 354 "GomElementTest.vala"
			_g_object_unref0 (elem);
#line 354 "GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 354 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3850 "GomElementTest.c"
			goto __catch123_g_error;
		}
#line 355 "GomElementTest.vala"
		_tmp164_ = doc;
#line 355 "GomElementTest.vala"
		_tmp165_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp164_, "child", &_inner_error0_);
#line 355 "GomElementTest.vala"
		child = _tmp165_;
#line 355 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 355 "GomElementTest.vala"
			_g_object_unref0 (n);
#line 355 "GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 355 "GomElementTest.vala"
			_g_object_unref0 (attr);
#line 355 "GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 355 "GomElementTest.vala"
			_g_object_unref0 (parser);
#line 355 "GomElementTest.vala"
			_g_object_unref0 (elem);
#line 355 "GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 355 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3877 "GomElementTest.c"
			goto __catch123_g_error;
		}
#line 356 "GomElementTest.vala"
		_tmp166_ = n;
#line 356 "GomElementTest.vala"
		_tmp167_ = child;
#line 356 "GomElementTest.vala"
		_tmp168_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp166_, (GXmlDomNode*) _tmp167_, &_inner_error0_);
#line 356 "GomElementTest.vala"
		_tmp169_ = _tmp168_;
#line 356 "GomElementTest.vala"
		_g_object_unref0 (_tmp169_);
#line 356 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 356 "GomElementTest.vala"
			_g_object_unref0 (child);
#line 356 "GomElementTest.vala"
			_g_object_unref0 (n);
#line 356 "GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 356 "GomElementTest.vala"
			_g_object_unref0 (attr);
#line 356 "GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 356 "GomElementTest.vala"
			_g_object_unref0 (parser);
#line 356 "GomElementTest.vala"
			_g_object_unref0 (elem);
#line 356 "GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 356 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3910 "GomElementTest.c"
			goto __catch123_g_error;
		}
#line 357 "GomElementTest.vala"
		_tmp170_ = elem;
#line 357 "GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp170_, "http://www.w3.org/2000/xmlns", "xmlns:xtest", "http://www.w3c.org/test", &_inner_error0_);
#line 357 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 357 "GomElementTest.vala"
			_g_object_unref0 (child);
#line 357 "GomElementTest.vala"
			_g_object_unref0 (n);
#line 357 "GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 357 "GomElementTest.vala"
			_g_object_unref0 (attr);
#line 357 "GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 357 "GomElementTest.vala"
			_g_object_unref0 (parser);
#line 357 "GomElementTest.vala"
			_g_object_unref0 (elem);
#line 357 "GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 357 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3937 "GomElementTest.c"
			goto __catch123_g_error;
		}
#line 358 "GomElementTest.vala"
		_tmp171_ = elem;
#line 358 "GomElementTest.vala"
		_tmp172_ = gxml_gom_element_lookup_prefix (_tmp171_, "http://www.w3c.org/test");
#line 358 "GomElementTest.vala"
		_tmp173_ = _tmp172_;
#line 358 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp173_, "xtest") == 0, "elem.lookup_prefix (\"http://www.w3c.org/test\") == \"xtest\"");
#line 358 "GomElementTest.vala"
		_g_free0 (_tmp173_);
#line 359 "GomElementTest.vala"
		_tmp174_ = n;
#line 359 "GomElementTest.vala"
		_tmp175_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) _tmp174_, "http://www.w3c.org/test");
#line 359 "GomElementTest.vala"
		_tmp176_ = _tmp175_;
#line 359 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp176_, "xtest") == 0, "n.lookup_prefix (\"http://www.w3c.org/test\") == \"xtest\"");
#line 359 "GomElementTest.vala"
		_g_free0 (_tmp176_);
#line 360 "GomElementTest.vala"
		_tmp177_ = child;
#line 360 "GomElementTest.vala"
		_tmp178_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) _tmp177_, "http://www.w3c.org/test");
#line 360 "GomElementTest.vala"
		_tmp179_ = _tmp178_;
#line 360 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp179_, "xtest") == 0, "child.lookup_prefix (\"http://www.w3c.org/test\") == \"xtest\"");
#line 360 "GomElementTest.vala"
		_g_free0 (_tmp179_);
#line 361 "GomElementTest.vala"
		_tmp180_ = elem;
#line 361 "GomElementTest.vala"
		_tmp181_ = gxml_gom_element_lookup_namespace_uri (_tmp180_, "xtest");
#line 361 "GomElementTest.vala"
		_tmp182_ = _tmp181_;
#line 361 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp182_, "http://www.w3c.org/test") == 0, "elem.lookup_namespace_uri (\"xtest\") == \"http://www.w3c.org/test\"");
#line 361 "GomElementTest.vala"
		_g_free0 (_tmp182_);
#line 362 "GomElementTest.vala"
		_tmp183_ = n;
#line 362 "GomElementTest.vala"
		_tmp184_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp183_, "xtest");
#line 362 "GomElementTest.vala"
		_tmp185_ = _tmp184_;
#line 362 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp185_, "http://www.w3c.org/test") == 0, "n.lookup_namespace_uri (\"xtest\") == \"http://www.w3c.org/test\"");
#line 362 "GomElementTest.vala"
		_g_free0 (_tmp185_);
#line 363 "GomElementTest.vala"
		_tmp186_ = child;
#line 363 "GomElementTest.vala"
		_tmp187_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp186_, "xtest");
#line 363 "GomElementTest.vala"
		_tmp188_ = _tmp187_;
#line 363 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp188_, "http://www.w3c.org/test") == 0, "child.lookup_namespace_uri (\"xtest\") == \"http://www.w3c.org/test\"");
#line 363 "GomElementTest.vala"
		_g_free0 (_tmp188_);
#line 364 "GomElementTest.vala"
		_tmp190_ = elem;
#line 364 "GomElementTest.vala"
		_tmp191_ = gxml_dom_element_write_string ((GXmlDomElement*) (G_TYPE_CHECK_INSTANCE_TYPE (_tmp190_, GXML_TYPE_GOM_ELEMENT) ? ((GXmlGomElement*) _tmp190_) : NULL), NULL, &_inner_error0_);
#line 364 "GomElementTest.vala"
		_tmp189_ = _tmp191_;
#line 364 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 364 "GomElementTest.vala"
			_g_object_unref0 (child);
#line 364 "GomElementTest.vala"
			_g_object_unref0 (n);
#line 364 "GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 364 "GomElementTest.vala"
			_g_object_unref0 (attr);
#line 364 "GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 364 "GomElementTest.vala"
			_g_object_unref0 (parser);
#line 364 "GomElementTest.vala"
			_g_object_unref0 (elem);
#line 364 "GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 364 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 4026 "GomElementTest.c"
			goto __catch123_g_error;
		}
#line 364 "GomElementTest.vala"
		g_message ("GomElementTest.vala:364: %s", _tmp189_);
#line 365 "GomElementTest.vala"
		_tmp192_ = child;
#line 365 "GomElementTest.vala"
		gxml_dom_element_set_attribute_ns (_tmp192_, "http://www.w3c.org/test", "xtest:val", "Value", &_inner_error0_);
#line 365 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 365 "GomElementTest.vala"
			_g_free0 (_tmp189_);
#line 365 "GomElementTest.vala"
			_g_object_unref0 (child);
#line 365 "GomElementTest.vala"
			_g_object_unref0 (n);
#line 365 "GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 365 "GomElementTest.vala"
			_g_object_unref0 (attr);
#line 365 "GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 365 "GomElementTest.vala"
			_g_object_unref0 (parser);
#line 365 "GomElementTest.vala"
			_g_object_unref0 (elem);
#line 365 "GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 365 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 4057 "GomElementTest.c"
			goto __catch123_g_error;
		}
#line 366 "GomElementTest.vala"
		_tmp193_ = elem;
#line 366 "GomElementTest.vala"
		_tmp194_ = gxml_dom_element_get_attribute_ns ((GXmlDomElement*) _tmp193_, "http://www.w3.org/2000/xmlns/", "xtest");
#line 366 "GomElementTest.vala"
		_tmp195_ = _tmp194_;
#line 366 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp195_, "http://www.w3c.org/test") == 0, "elem.get_attribute_ns (\"http://www.w3.org/2000/xmlns/\",\"xtest\") == \"http://www.w3c.org/test\"");
#line 366 "GomElementTest.vala"
		_g_free0 (_tmp195_);
#line 367 "GomElementTest.vala"
		_tmp196_ = elem;
#line 367 "GomElementTest.vala"
		_tmp197_ = gxml_dom_element_get_attribute_ns ((GXmlDomElement*) _tmp196_, "http://www.w3.org/2000/xmlns", "xtest");
#line 367 "GomElementTest.vala"
		_tmp198_ = _tmp197_;
#line 367 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp198_, "http://www.w3c.org/test") == 0, "elem.get_attribute_ns (\"http://www.w3.org/2000/xmlns\",\"xtest\") == \"http://www.w3c.org/test\"");
#line 367 "GomElementTest.vala"
		_g_free0 (_tmp198_);
#line 368 "GomElementTest.vala"
		_tmp199_ = child;
#line 368 "GomElementTest.vala"
		_tmp200_ = gxml_dom_element_get_attribute_ns (_tmp199_, "http://www.w3c.org/test", "val");
#line 368 "GomElementTest.vala"
		_tmp201_ = _tmp200_;
#line 368 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp201_, "Value") == 0, "child.get_attribute_ns (\"http://www.w3c.org/test\",\"val\") == \"Value\"");
#line 368 "GomElementTest.vala"
		_g_free0 (_tmp201_);
#line 301 "GomElementTest.vala"
		_g_free0 (_tmp189_);
#line 301 "GomElementTest.vala"
		_g_object_unref0 (child);
#line 301 "GomElementTest.vala"
		_g_object_unref0 (n);
#line 301 "GomElementTest.vala"
		_g_free0 (_tmp135_);
#line 301 "GomElementTest.vala"
		_g_object_unref0 (attr);
#line 301 "GomElementTest.vala"
		_g_free0 (_tmp37_);
#line 301 "GomElementTest.vala"
		_g_object_unref0 (parser);
#line 301 "GomElementTest.vala"
		_g_object_unref0 (elem);
#line 301 "GomElementTest.vala"
		_g_object_unref0 (_tmp5_);
#line 301 "GomElementTest.vala"
		_g_object_unref0 (doc);
#line 4110 "GomElementTest.c"
	}
	goto __finally123;
	__catch123_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp202_;
#line 301 "GomElementTest.vala"
		e = _inner_error0_;
#line 301 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 370 "GomElementTest.vala"
		_tmp202_ = e->message;
#line 370 "GomElementTest.vala"
		g_message ("GomElementTest.vala:370: %s", _tmp202_);
#line 371 "GomElementTest.vala"
		g_assert_not_reached ();
#line 301 "GomElementTest.vala"
		_g_error_free0 (e);
#line 4129 "GomElementTest.c"
	}
	__finally123:
#line 301 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 301 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 301 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 301 "GomElementTest.vala"
		return;
#line 4140 "GomElementTest.c"
	}
}

static void
___lambda100__gtest_func (void)
{
#line 300 "GomElementTest.vala"
	__lambda100_ ();
#line 4149 "GomElementTest.c"
}

static void
__lambda101_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		gchar* str = NULL;
		gchar* _tmp0_;
		GomElementTestPotion* p = NULL;
		GomElementTestPotion* _tmp1_;
		GomElementTestPotion* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		GomElementTestPotion* _tmp6_;
		const gchar* _tmp7_;
		const gchar* _tmp8_;
		GomElementTestPotion* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		GomElementTestPotion* _tmp12_;
		const gchar* _tmp13_;
		gchar* _tmp14_ = NULL;
		GomElementTestPotion* _tmp15_;
		gchar* _tmp16_;
		GomElementTestPotion* _tmp17_;
		const gchar* _tmp18_;
		const gchar* _tmp19_;
		GomElementTestPotion* _tmp20_;
		GomElementTestIngredient* _tmp21_;
		GomElementTestIngredient* _tmp22_;
		GomElementTestPotion* _tmp23_;
		GomElementTestIngredient* _tmp24_;
		GomElementTestIngredient* _tmp25_;
		const gchar* _tmp26_;
		const gchar* _tmp27_;
		GomElementTestPotion* _tmp28_;
		GomElementTestIngredient* _tmp29_;
		GomElementTestIngredient* _tmp30_;
		GomElementTestMethodMap* _tmp31_;
		GomElementTestMethodMap* _tmp32_;
		GomElementTestPotion* _tmp33_;
		GomElementTestIngredient* _tmp34_;
		GomElementTestIngredient* _tmp35_;
		GomElementTestMethodMap* _tmp36_;
		GomElementTestMethodMap* _tmp37_;
		gint _tmp38_;
		gint _tmp39_;
		GXmlDomElement* _tmp40_ = NULL;
		GomElementTestPotion* _tmp41_;
		GomElementTestIngredient* _tmp42_;
		GomElementTestIngredient* _tmp43_;
		GomElementTestMethodMap* _tmp44_;
		GomElementTestMethodMap* _tmp45_;
		GXmlDomElement* _tmp46_;
		GomElementTestMethod* m = NULL;
		GomElementTestMethod* _tmp47_;
		const gchar* _tmp48_;
		const gchar* _tmp49_;
#line 376 "GomElementTest.vala"
		_tmp0_ = g_strdup ("<Potion xmlns:c=\"http://c.org/1.0\" c:name=\"edumor\"><ingredient c:n" \
"ame=\"spider\"><child/><method c:name=\"move\"/></ingredient></Potion>");
#line 376 "GomElementTest.vala"
		str = _tmp0_;
#line 377 "GomElementTest.vala"
		_tmp1_ = gom_element_test_potion_new ();
#line 377 "GomElementTest.vala"
		p = _tmp1_;
#line 378 "GomElementTest.vala"
		_tmp2_ = p;
#line 378 "GomElementTest.vala"
		_tmp3_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp2_);
#line 378 "GomElementTest.vala"
		_tmp4_ = _tmp3_;
#line 378 "GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 378 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp5_, "Potion") == 0, "p.node_name == \"Potion\"");
#line 378 "GomElementTest.vala"
		_g_free0 (_tmp5_);
#line 379 "GomElementTest.vala"
		_tmp6_ = p;
#line 379 "GomElementTest.vala"
		_tmp7_ = gom_element_test_potion_get_cname (_tmp6_);
#line 379 "GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 379 "GomElementTest.vala"
		_vala_assert (_tmp8_ == NULL, "p.cname == null");
#line 380 "GomElementTest.vala"
		_tmp9_ = p;
#line 380 "GomElementTest.vala"
		_tmp10_ = gxml_dom_element_get_attribute_ns ((GXmlDomElement*) _tmp9_, "http://www.w3.org/2000/xmlns", "c");
#line 380 "GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 380 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp11_, "http://c.org/1.0") == 0, "p.get_attribute_ns (\"http://www.w3.org/2000/xmlns\", \"c\") == \"http://c.org/1.0\"");
#line 380 "GomElementTest.vala"
		_g_free0 (_tmp11_);
#line 381 "GomElementTest.vala"
		_tmp12_ = p;
#line 381 "GomElementTest.vala"
		_tmp13_ = str;
#line 381 "GomElementTest.vala"
		gxml_dom_element_read_from_string ((GXmlDomElement*) _tmp12_, _tmp13_, NULL, &_inner_error0_);
#line 381 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 381 "GomElementTest.vala"
			_g_object_unref0 (p);
#line 381 "GomElementTest.vala"
			_g_free0 (str);
#line 4260 "GomElementTest.c"
			goto __catch125_g_error;
		}
#line 382 "GomElementTest.vala"
		_tmp15_ = p;
#line 382 "GomElementTest.vala"
		_tmp16_ = gxml_dom_element_write_string ((GXmlDomElement*) _tmp15_, NULL, &_inner_error0_);
#line 382 "GomElementTest.vala"
		_tmp14_ = _tmp16_;
#line 382 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 382 "GomElementTest.vala"
			_g_object_unref0 (p);
#line 382 "GomElementTest.vala"
			_g_free0 (str);
#line 4275 "GomElementTest.c"
			goto __catch125_g_error;
		}
#line 382 "GomElementTest.vala"
		g_message ("GomElementTest.vala:382: %s", _tmp14_);
#line 383 "GomElementTest.vala"
		_tmp17_ = p;
#line 383 "GomElementTest.vala"
		_tmp18_ = gom_element_test_potion_get_cname (_tmp17_);
#line 383 "GomElementTest.vala"
		_tmp19_ = _tmp18_;
#line 383 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp19_, "edumor") == 0, "p.cname == \"edumor\"");
#line 384 "GomElementTest.vala"
		_tmp20_ = p;
#line 384 "GomElementTest.vala"
		_tmp21_ = gom_element_test_potion_get_ingredient (_tmp20_);
#line 384 "GomElementTest.vala"
		_tmp22_ = _tmp21_;
#line 384 "GomElementTest.vala"
		_vala_assert (_tmp22_ != NULL, "p.ingredient != null");
#line 385 "GomElementTest.vala"
		_tmp23_ = p;
#line 385 "GomElementTest.vala"
		_tmp24_ = gom_element_test_potion_get_ingredient (_tmp23_);
#line 385 "GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 385 "GomElementTest.vala"
		_tmp26_ = gom_element_test_ingredient_get_cname (_tmp25_);
#line 385 "GomElementTest.vala"
		_tmp27_ = _tmp26_;
#line 385 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp27_, "spider") == 0, "p.ingredient.cname == \"spider\"");
#line 386 "GomElementTest.vala"
		_tmp28_ = p;
#line 386 "GomElementTest.vala"
		_tmp29_ = gom_element_test_potion_get_ingredient (_tmp28_);
#line 386 "GomElementTest.vala"
		_tmp30_ = _tmp29_;
#line 386 "GomElementTest.vala"
		_tmp31_ = gom_element_test_ingredient_get_methods (_tmp30_);
#line 386 "GomElementTest.vala"
		_tmp32_ = _tmp31_;
#line 386 "GomElementTest.vala"
		_vala_assert (_tmp32_ != NULL, "p.ingredient.methods != null");
#line 387 "GomElementTest.vala"
		_tmp33_ = p;
#line 387 "GomElementTest.vala"
		_tmp34_ = gom_element_test_potion_get_ingredient (_tmp33_);
#line 387 "GomElementTest.vala"
		_tmp35_ = _tmp34_;
#line 387 "GomElementTest.vala"
		_tmp36_ = gom_element_test_ingredient_get_methods (_tmp35_);
#line 387 "GomElementTest.vala"
		_tmp37_ = _tmp36_;
#line 387 "GomElementTest.vala"
		_tmp38_ = gxml_collection_get_length ((GXmlCollection*) _tmp37_);
#line 387 "GomElementTest.vala"
		_tmp39_ = _tmp38_;
#line 387 "GomElementTest.vala"
		_vala_assert (_tmp39_ == 1, "p.ingredient.methods.length == 1");
#line 388 "GomElementTest.vala"
		_tmp41_ = p;
#line 388 "GomElementTest.vala"
		_tmp42_ = gom_element_test_potion_get_ingredient (_tmp41_);
#line 388 "GomElementTest.vala"
		_tmp43_ = _tmp42_;
#line 388 "GomElementTest.vala"
		_tmp44_ = gom_element_test_ingredient_get_methods (_tmp43_);
#line 388 "GomElementTest.vala"
		_tmp45_ = _tmp44_;
#line 388 "GomElementTest.vala"
		_tmp46_ = gxml_collection_get_item ((GXmlCollection*) _tmp45_, 0, &_inner_error0_);
#line 388 "GomElementTest.vala"
		_tmp40_ = _tmp46_;
#line 388 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 388 "GomElementTest.vala"
			_g_free0 (_tmp14_);
#line 388 "GomElementTest.vala"
			_g_object_unref0 (p);
#line 388 "GomElementTest.vala"
			_g_free0 (str);
#line 4358 "GomElementTest.c"
			goto __catch125_g_error;
		}
#line 388 "GomElementTest.vala"
		_tmp47_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp40_, GOM_ELEMENT_TEST_TYPE_METHOD) ? ((GomElementTestMethod*) _tmp40_) : NULL);
#line 388 "GomElementTest.vala"
		m = _tmp47_;
#line 389 "GomElementTest.vala"
		_tmp48_ = gom_element_test_method_get_cname (m);
#line 389 "GomElementTest.vala"
		_tmp49_ = _tmp48_;
#line 389 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp49_, "move") == 0, "m.cname == \"move\"");
#line 375 "GomElementTest.vala"
		_g_object_unref0 (m);
#line 375 "GomElementTest.vala"
		_g_object_unref0 (_tmp40_);
#line 375 "GomElementTest.vala"
		_g_free0 (_tmp14_);
#line 375 "GomElementTest.vala"
		_g_object_unref0 (p);
#line 375 "GomElementTest.vala"
		_g_free0 (str);
#line 4381 "GomElementTest.c"
	}
	goto __finally125;
	__catch125_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp50_;
#line 375 "GomElementTest.vala"
		e = _inner_error0_;
#line 375 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 391 "GomElementTest.vala"
		_tmp50_ = e->message;
#line 391 "GomElementTest.vala"
		g_message ("GomElementTest.vala:391: %s", _tmp50_);
#line 392 "GomElementTest.vala"
		g_assert_not_reached ();
#line 375 "GomElementTest.vala"
		_g_error_free0 (e);
#line 4400 "GomElementTest.c"
	}
	__finally125:
#line 375 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 375 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 375 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 375 "GomElementTest.vala"
		return;
#line 4411 "GomElementTest.c"
	}
}

static void
___lambda101__gtest_func (void)
{
#line 374 "GomElementTest.vala"
	__lambda101_ ();
#line 4420 "GomElementTest.c"
}

static void
__lambda102_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		gchar* str = NULL;
		gchar* _tmp0_;
		GomElementTestRepository* r = NULL;
		GomElementTestRepository* _tmp1_;
#line 397 "GomElementTest.vala"
		_tmp0_ = g_strdup ("<?xml version=\"1.0\"?>\n" \
"<repository version=\"1.2\" xmlns=\"http://www.gtk.org/introspection/c" \
"ore/1.0\" xmlns:c=\"http://www.gtk.org/introspection/c/1.0\" xmlns:gli" \
"b=\"http://www.gtk.org/introspection/glib/1.0\">\n" \
"<include name=\"GXml\" version=\"0.16\"/>\n" \
"<package name=\"girp-0.2\"/>\n" \
"<c:include name=\"girp.h\"/>\n" \
"<namespace name=\"Girp\" version=\"0.2\" c:prefix=\"Girp\">\n" \
"\t<attribute name=\"ccode.gir-version\" value=\"0.2\"/>\n" \
"\t<attribute name=\"ccode.cheader-filename\" value=\"girp.h\"/>\n" \
"\t<attribute name=\"ccode.gir-namespace\" value=\"Girp\"/>\n" \
"\t<class name=\"Repository\" c:type=\"GirpRepository\" glib:type-name=" \
"\"GirpRepository\" glib:get-type=\"girp_repository_get_type\" glib:typ" \
"e-struct=\"RepositoryClass\" parent=\"GXml.GomElement\">\n" \
"\t</class>\n" \
"</namespace>\n" \
"</repository>");
#line 397 "GomElementTest.vala"
		str = _tmp0_;
#line 410 "GomElementTest.vala"
		_tmp1_ = gom_element_test_repository_new ();
#line 410 "GomElementTest.vala"
		r = _tmp1_;
#line 411 "GomElementTest.vala"
		gxml_dom_element_read_from_string ((GXmlDomElement*) r, str, NULL, &_inner_error0_);
#line 411 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 411 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 411 "GomElementTest.vala"
			_g_free0 (str);
#line 4448 "GomElementTest.c"
			goto __catch126_g_error;
		}
#line 396 "GomElementTest.vala"
		_g_object_unref0 (r);
#line 396 "GomElementTest.vala"
		_g_free0 (str);
#line 4455 "GomElementTest.c"
	}
	goto __finally126;
	__catch126_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp2_;
#line 396 "GomElementTest.vala"
		e = _inner_error0_;
#line 396 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 413 "GomElementTest.vala"
		_tmp2_ = e->message;
#line 413 "GomElementTest.vala"
		g_message ("GomElementTest.vala:413: %s", _tmp2_);
#line 414 "GomElementTest.vala"
		g_assert_not_reached ();
#line 396 "GomElementTest.vala"
		_g_error_free0 (e);
#line 4474 "GomElementTest.c"
	}
	__finally126:
#line 396 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 396 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 396 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 396 "GomElementTest.vala"
		return;
#line 4485 "GomElementTest.c"
	}
}

static void
___lambda102__gtest_func (void)
{
#line 395 "GomElementTest.vala"
	__lambda102_ ();
#line 4494 "GomElementTest.c"
}

static void
__lambda103_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		gchar* str = NULL;
		gchar* _tmp0_;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp1_;
		GXmlDomElement* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlDomElement* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		GXmlDomHTMLCollection* lt = NULL;
		GXmlDomElement* _tmp8_;
		GXmlDomElement* _tmp9_;
		GXmlDomElement* _tmp10_;
		GXmlDomHTMLCollection* _tmp11_;
		GXmlDomHTMLCollection* _tmp12_;
		gint _tmp13_;
		gint _tmp14_;
		GXmlDomElement* n = NULL;
		gpointer _tmp15_;
		gchar* _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
#line 419 "GomElementTest.vala"
		_tmp0_ = g_strdup ("<?xml version=\"1.0\"?>\n" \
"<repository version=\"1.2\" xmlns=\"http://www.gtk.org/introspection/c" \
"ore/1.0\" xmlns:c=\"http://www.gtk.org/introspection/c/1.0\" xmlns:gli" \
"b=\"http://www.gtk.org/introspection/glib/1.0\">\n" \
"<include name=\"GXml\" version=\"0.16\"/>\n" \
"<package name=\"girp-0.2\"/>\n" \
"<c:include name=\"girp.h\"/>\n" \
"<namespace name=\"Girp\" version=\"0.2\" c:prefix=\"Girp\">\n" \
"\t<attribute name=\"ccode.gir-version\" value=\"0.2\"/>\n" \
"\t<attribute name=\"ccode.cheader-filename\" value=\"girp.h\"/>\n" \
"\t<attribute name=\"ccode.gir-namespace\" value=\"Girp\"/>\n" \
"\t<class name=\"Repository\" c:type=\"GirpRepository\" glib:type-name=" \
"\"GirpRepository\" glib:get-type=\"girp_repository_get_type\" glib:typ" \
"e-struct=\"RepositoryClass\" parent=\"GXml.GomElement\">\n" \
"\t</class>\n" \
"</namespace>\n" \
"</repository>");
#line 419 "GomElementTest.vala"
		str = _tmp0_;
#line 432 "GomElementTest.vala"
		_tmp1_ = gxml_gom_document_new_from_string (str, &_inner_error0_);
#line 432 "GomElementTest.vala"
		d = _tmp1_;
#line 432 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 432 "GomElementTest.vala"
			_g_free0 (str);
#line 4541 "GomElementTest.c"
			goto __catch127_g_error;
		}
#line 433 "GomElementTest.vala"
		_tmp2_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 433 "GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 433 "GomElementTest.vala"
		_tmp4_ = _tmp3_;
#line 433 "GomElementTest.vala"
		_tmp5_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp4_);
#line 433 "GomElementTest.vala"
		_tmp6_ = _tmp5_;
#line 433 "GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 433 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "repository") == 0, "d.document_element.node_name == \"repository\"");
#line 433 "GomElementTest.vala"
		_g_free0 (_tmp7_);
#line 433 "GomElementTest.vala"
		_g_object_unref0 (_tmp4_);
#line 434 "GomElementTest.vala"
		_tmp8_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 434 "GomElementTest.vala"
		_tmp9_ = _tmp8_;
#line 434 "GomElementTest.vala"
		_tmp10_ = _tmp9_;
#line 434 "GomElementTest.vala"
		_tmp11_ = gxml_dom_element_get_elements_by_tag_name (_tmp10_, "class");
#line 434 "GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 434 "GomElementTest.vala"
		_g_object_unref0 (_tmp10_);
#line 434 "GomElementTest.vala"
		lt = _tmp12_;
#line 435 "GomElementTest.vala"
		_tmp13_ = gxml_dom_html_collection_get_length (lt);
#line 435 "GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 435 "GomElementTest.vala"
		_vala_assert (_tmp14_ == 1, "lt.length == 1");
#line 436 "GomElementTest.vala"
		_tmp15_ = gee_list_get ((GeeList*) lt, 0);
#line 436 "GomElementTest.vala"
		n = (GXmlDomElement*) _tmp15_;
#line 437 "GomElementTest.vala"
		_tmp16_ = gxml_dom_node_get_node_name ((GXmlDomNode*) n);
#line 437 "GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 437 "GomElementTest.vala"
		_tmp18_ = _tmp17_;
#line 437 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp18_, "class") == 0, "n.node_name == \"class\"");
#line 437 "GomElementTest.vala"
		_g_free0 (_tmp18_);
#line 438 "GomElementTest.vala"
		_tmp19_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) n, "c");
#line 438 "GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 438 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp20_, "http://www.gtk.org/introspection/c/1.0") == 0, "n.lookup_namespace_uri (\"c\") == \"http://www.gtk.org/introspection/c/1.0\"");
#line 438 "GomElementTest.vala"
		_g_free0 (_tmp20_);
#line 439 "GomElementTest.vala"
		_tmp21_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) n, "http://www.gtk.org/introspection/c/1.0");
#line 439 "GomElementTest.vala"
		_tmp22_ = _tmp21_;
#line 439 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp22_, "c") == 0, "n.lookup_prefix (\"http://www.gtk.org/introspection/c/1.0\") == \"c\"");
#line 439 "GomElementTest.vala"
		_g_free0 (_tmp22_);
#line 418 "GomElementTest.vala"
		_g_object_unref0 (n);
#line 418 "GomElementTest.vala"
		_g_object_unref0 (lt);
#line 418 "GomElementTest.vala"
		_g_object_unref0 (d);
#line 418 "GomElementTest.vala"
		_g_free0 (str);
#line 4620 "GomElementTest.c"
	}
	goto __finally127;
	__catch127_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp23_;
#line 418 "GomElementTest.vala"
		e = _inner_error0_;
#line 418 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 441 "GomElementTest.vala"
		_tmp23_ = e->message;
#line 441 "GomElementTest.vala"
		g_message ("GomElementTest.vala:441: %s", _tmp23_);
#line 442 "GomElementTest.vala"
		g_assert_not_reached ();
#line 418 "GomElementTest.vala"
		_g_error_free0 (e);
#line 4639 "GomElementTest.c"
	}
	__finally127:
#line 418 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 418 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 418 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 418 "GomElementTest.vala"
		return;
#line 4650 "GomElementTest.c"
	}
}

static void
___lambda103__gtest_func (void)
{
#line 417 "GomElementTest.vala"
	__lambda103_ ();
#line 4659 "GomElementTest.c"
}

static void
__lambda104_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlDomElement* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlGomElement* root = NULL;
		GXmlGomElement* _tmp4_;
		GXmlGomDocument* _tmp5_;
		GXmlDomNodeList* _tmp6_;
		GXmlDomNodeList* _tmp7_;
		GXmlDomNodeList* _tmp8_;
		GXmlGomElement* _tmp9_;
		GXmlDomElement* _tmp10_ = NULL;
		GXmlGomDocument* _tmp11_;
		GXmlDomElement* _tmp12_;
		GXmlGomElement* n = NULL;
		GXmlGomElement* _tmp13_;
		GXmlGomElement* _tmp14_;
		GXmlDomNodeList* _tmp15_;
		GXmlDomNodeList* _tmp16_;
		GXmlDomNodeList* _tmp17_;
		GXmlGomElement* _tmp18_;
		GXmlDomText* t = NULL;
		GXmlGomDocument* _tmp19_;
		GXmlDomText* _tmp20_;
		GXmlGomElement* _tmp21_;
		GXmlDomNodeList* _tmp22_;
		GXmlDomNodeList* _tmp23_;
		GXmlDomNodeList* _tmp24_;
		GXmlDomText* _tmp25_;
		GXmlXParser* parser = NULL;
		GXmlGomDocument* _tmp26_;
		GXmlXParser* _tmp27_;
		gchar* _tmp28_ = NULL;
		GXmlXParser* _tmp29_;
		gchar* _tmp30_;
		gchar* s = NULL;
		gchar** _tmp31_;
		gchar** _tmp32_;
		gchar** _tmp33_;
		gint _tmp33__length1;
		const gchar* _tmp34_;
		gchar* _tmp35_;
		gchar* _tmp36_;
#line 447 "GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new ();
#line 447 "GomElementTest.vala"
		doc = _tmp0_;
#line 448 "GomElementTest.vala"
		_tmp2_ = doc;
#line 448 "GomElementTest.vala"
		_tmp3_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp2_, "root", &_inner_error0_);
#line 448 "GomElementTest.vala"
		_tmp1_ = _tmp3_;
#line 448 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 448 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 4725 "GomElementTest.c"
			goto __catch128_g_error;
		}
#line 448 "GomElementTest.vala"
		_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_GOM_ELEMENT, GXmlGomElement));
#line 448 "GomElementTest.vala"
		root = _tmp4_;
#line 449 "GomElementTest.vala"
		_tmp5_ = doc;
#line 449 "GomElementTest.vala"
		_tmp6_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp5_);
#line 449 "GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 449 "GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 449 "GomElementTest.vala"
		_tmp9_ = root;
#line 449 "GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp8_, (GXmlDomNode*) _tmp9_);
#line 449 "GomElementTest.vala"
		_g_object_unref0 (_tmp8_);
#line 450 "GomElementTest.vala"
		_tmp11_ = doc;
#line 450 "GomElementTest.vala"
		_tmp12_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp11_, "child", &_inner_error0_);
#line 450 "GomElementTest.vala"
		_tmp10_ = _tmp12_;
#line 450 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 450 "GomElementTest.vala"
			_g_object_unref0 (root);
#line 450 "GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 450 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 4760 "GomElementTest.c"
			goto __catch128_g_error;
		}
#line 450 "GomElementTest.vala"
		_tmp13_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GXML_TYPE_GOM_ELEMENT, GXmlGomElement));
#line 450 "GomElementTest.vala"
		n = _tmp13_;
#line 451 "GomElementTest.vala"
		_tmp14_ = root;
#line 451 "GomElementTest.vala"
		_tmp15_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp14_);
#line 451 "GomElementTest.vala"
		_tmp16_ = _tmp15_;
#line 451 "GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 451 "GomElementTest.vala"
		_tmp18_ = n;
#line 451 "GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp17_, (GXmlDomNode*) _tmp18_);
#line 451 "GomElementTest.vala"
		_g_object_unref0 (_tmp17_);
#line 452 "GomElementTest.vala"
		_tmp19_ = doc;
#line 452 "GomElementTest.vala"
		_tmp20_ = gxml_dom_document_create_text_node ((GXmlDomDocument*) _tmp19_, "TEXT1", &_inner_error0_);
#line 452 "GomElementTest.vala"
		t = _tmp20_;
#line 452 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 452 "GomElementTest.vala"
			_g_object_unref0 (n);
#line 452 "GomElementTest.vala"
			_g_object_unref0 (_tmp10_);
#line 452 "GomElementTest.vala"
			_g_object_unref0 (root);
#line 452 "GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 452 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 4799 "GomElementTest.c"
			goto __catch128_g_error;
		}
#line 453 "GomElementTest.vala"
		_tmp21_ = root;
#line 453 "GomElementTest.vala"
		_tmp22_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp21_);
#line 453 "GomElementTest.vala"
		_tmp23_ = _tmp22_;
#line 453 "GomElementTest.vala"
		_tmp24_ = _tmp23_;
#line 453 "GomElementTest.vala"
		_tmp25_ = t;
#line 453 "GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp24_, (GXmlDomNode*) _tmp25_);
#line 453 "GomElementTest.vala"
		_g_object_unref0 (_tmp24_);
#line 454 "GomElementTest.vala"
		_tmp26_ = doc;
#line 454 "GomElementTest.vala"
		_tmp27_ = gxml_xparser_new ((GXmlDomNode*) _tmp26_);
#line 454 "GomElementTest.vala"
		parser = _tmp27_;
#line 455 "GomElementTest.vala"
		_tmp29_ = parser;
#line 455 "GomElementTest.vala"
		_tmp30_ = gxml_parser_write_string ((GXmlParser*) _tmp29_, &_inner_error0_);
#line 455 "GomElementTest.vala"
		_tmp28_ = _tmp30_;
#line 455 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 455 "GomElementTest.vala"
			_g_object_unref0 (parser);
#line 455 "GomElementTest.vala"
			_g_object_unref0 (t);
#line 455 "GomElementTest.vala"
			_g_object_unref0 (n);
#line 455 "GomElementTest.vala"
			_g_object_unref0 (_tmp10_);
#line 455 "GomElementTest.vala"
			_g_object_unref0 (root);
#line 455 "GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 455 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 4844 "GomElementTest.c"
			goto __catch128_g_error;
		}
#line 455 "GomElementTest.vala"
		_tmp32_ = _tmp31_ = g_strsplit (_tmp28_, "\n", 0);
#line 455 "GomElementTest.vala"
		_tmp33_ = _tmp32_;
#line 455 "GomElementTest.vala"
		_tmp33__length1 = _vala_array_length (_tmp31_);
#line 455 "GomElementTest.vala"
		_tmp34_ = _tmp33_[1];
#line 455 "GomElementTest.vala"
		_tmp35_ = g_strdup (_tmp34_);
#line 455 "GomElementTest.vala"
		_tmp36_ = _tmp35_;
#line 455 "GomElementTest.vala"
		_tmp33_ = (_vala_array_free (_tmp33_, _tmp33__length1, (GDestroyNotify) g_free), NULL);
#line 455 "GomElementTest.vala"
		s = _tmp36_;
#line 456 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (s, "<root><child/>TEXT1</root>") == 0, "s == \"<root><child/>TEXT1</root>\"");
#line 446 "GomElementTest.vala"
		_g_free0 (s);
#line 446 "GomElementTest.vala"
		_g_free0 (_tmp28_);
#line 446 "GomElementTest.vala"
		_g_object_unref0 (parser);
#line 446 "GomElementTest.vala"
		_g_object_unref0 (t);
#line 446 "GomElementTest.vala"
		_g_object_unref0 (n);
#line 446 "GomElementTest.vala"
		_g_object_unref0 (_tmp10_);
#line 446 "GomElementTest.vala"
		_g_object_unref0 (root);
#line 446 "GomElementTest.vala"
		_g_object_unref0 (_tmp1_);
#line 446 "GomElementTest.vala"
		_g_object_unref0 (doc);
#line 4883 "GomElementTest.c"
	}
	goto __finally128;
	__catch128_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp37_;
#line 446 "GomElementTest.vala"
		e = _inner_error0_;
#line 446 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 458 "GomElementTest.vala"
		_tmp37_ = e->message;
#line 458 "GomElementTest.vala"
		g_test_message ("%s", _tmp37_);
#line 459 "GomElementTest.vala"
		g_assert_not_reached ();
#line 446 "GomElementTest.vala"
		_g_error_free0 (e);
#line 4902 "GomElementTest.c"
	}
	__finally128:
#line 446 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 446 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 446 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 446 "GomElementTest.vala"
		return;
#line 4913 "GomElementTest.c"
	}
}

static void
___lambda104__gtest_func (void)
{
#line 445 "GomElementTest.vala"
	__lambda104_ ();
#line 4922 "GomElementTest.c"
}

static void
__lambda105_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlDomElement* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlGomElement* root = NULL;
		GXmlGomElement* _tmp4_;
		GXmlGomDocument* _tmp5_;
		GXmlDomNodeList* _tmp6_;
		GXmlDomNodeList* _tmp7_;
		GXmlDomNodeList* _tmp8_;
		GXmlGomElement* _tmp9_;
		GXmlDomElement* _tmp10_ = NULL;
		GXmlGomDocument* _tmp11_;
		GXmlDomElement* _tmp12_;
		GXmlGomElement* n = NULL;
		GXmlGomElement* _tmp13_;
		GXmlGomElement* _tmp14_;
		GXmlDomNodeList* _tmp15_;
		GXmlDomNodeList* _tmp16_;
		GXmlDomNodeList* _tmp17_;
		GXmlGomElement* _tmp18_;
		GXmlDomText* _tmp19_ = NULL;
		GXmlGomDocument* _tmp20_;
		GXmlDomText* _tmp21_;
		GXmlDomText* t = NULL;
		GXmlDomText* _tmp22_;
		GXmlGomElement* _tmp23_;
		GXmlDomNodeList* _tmp24_;
		GXmlDomNodeList* _tmp25_;
		GXmlDomNodeList* _tmp26_;
		GXmlDomText* _tmp27_;
		GXmlXParser* parser = NULL;
		GXmlGomDocument* _tmp28_;
		GXmlXParser* _tmp29_;
		gchar* _tmp30_ = NULL;
		GXmlXParser* _tmp31_;
		gchar* _tmp32_;
		gchar* s = NULL;
		gchar** _tmp33_;
		gchar** _tmp34_;
		gchar** _tmp35_;
		gint _tmp35__length1;
		const gchar* _tmp36_;
		gchar* _tmp37_;
		gchar* _tmp38_;
#line 464 "GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new ();
#line 464 "GomElementTest.vala"
		doc = _tmp0_;
#line 465 "GomElementTest.vala"
		_tmp2_ = doc;
#line 465 "GomElementTest.vala"
		_tmp3_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp2_, "root", &_inner_error0_);
#line 465 "GomElementTest.vala"
		_tmp1_ = _tmp3_;
#line 465 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 465 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 4990 "GomElementTest.c"
			goto __catch129_g_error;
		}
#line 465 "GomElementTest.vala"
		_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_GOM_ELEMENT, GXmlGomElement));
#line 465 "GomElementTest.vala"
		root = _tmp4_;
#line 466 "GomElementTest.vala"
		_tmp5_ = doc;
#line 466 "GomElementTest.vala"
		_tmp6_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp5_);
#line 466 "GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 466 "GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 466 "GomElementTest.vala"
		_tmp9_ = root;
#line 466 "GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp8_, (GXmlDomNode*) _tmp9_);
#line 466 "GomElementTest.vala"
		_g_object_unref0 (_tmp8_);
#line 467 "GomElementTest.vala"
		_tmp11_ = doc;
#line 467 "GomElementTest.vala"
		_tmp12_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp11_, "child", &_inner_error0_);
#line 467 "GomElementTest.vala"
		_tmp10_ = _tmp12_;
#line 467 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 467 "GomElementTest.vala"
			_g_object_unref0 (root);
#line 467 "GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 467 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 5025 "GomElementTest.c"
			goto __catch129_g_error;
		}
#line 467 "GomElementTest.vala"
		_tmp13_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GXML_TYPE_GOM_ELEMENT, GXmlGomElement));
#line 467 "GomElementTest.vala"
		n = _tmp13_;
#line 468 "GomElementTest.vala"
		_tmp14_ = root;
#line 468 "GomElementTest.vala"
		_tmp15_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp14_);
#line 468 "GomElementTest.vala"
		_tmp16_ = _tmp15_;
#line 468 "GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 468 "GomElementTest.vala"
		_tmp18_ = n;
#line 468 "GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp17_, (GXmlDomNode*) _tmp18_);
#line 468 "GomElementTest.vala"
		_g_object_unref0 (_tmp17_);
#line 469 "GomElementTest.vala"
		_tmp20_ = doc;
#line 469 "GomElementTest.vala"
		_tmp21_ = gxml_dom_document_create_text_node ((GXmlDomDocument*) _tmp20_, "TEXT1", &_inner_error0_);
#line 469 "GomElementTest.vala"
		_tmp19_ = _tmp21_;
#line 469 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 469 "GomElementTest.vala"
			_g_object_unref0 (n);
#line 469 "GomElementTest.vala"
			_g_object_unref0 (_tmp10_);
#line 469 "GomElementTest.vala"
			_g_object_unref0 (root);
#line 469 "GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 469 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 5064 "GomElementTest.c"
			goto __catch129_g_error;
		}
#line 469 "GomElementTest.vala"
		_tmp22_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, GXML_TYPE_DOM_TEXT) ? ((GXmlDomText*) _tmp19_) : NULL);
#line 469 "GomElementTest.vala"
		t = _tmp22_;
#line 470 "GomElementTest.vala"
		_tmp23_ = root;
#line 470 "GomElementTest.vala"
		_tmp24_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp23_);
#line 470 "GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 470 "GomElementTest.vala"
		_tmp26_ = _tmp25_;
#line 470 "GomElementTest.vala"
		_tmp27_ = t;
#line 470 "GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp26_, (GXmlDomNode*) _tmp27_);
#line 470 "GomElementTest.vala"
		_g_object_unref0 (_tmp26_);
#line 471 "GomElementTest.vala"
		_tmp28_ = doc;
#line 471 "GomElementTest.vala"
		_tmp29_ = gxml_xparser_new ((GXmlDomNode*) _tmp28_);
#line 471 "GomElementTest.vala"
		parser = _tmp29_;
#line 472 "GomElementTest.vala"
		_tmp31_ = parser;
#line 472 "GomElementTest.vala"
		_tmp32_ = gxml_parser_write_string ((GXmlParser*) _tmp31_, &_inner_error0_);
#line 472 "GomElementTest.vala"
		_tmp30_ = _tmp32_;
#line 472 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 472 "GomElementTest.vala"
			_g_object_unref0 (parser);
#line 472 "GomElementTest.vala"
			_g_object_unref0 (t);
#line 472 "GomElementTest.vala"
			_g_object_unref0 (_tmp19_);
#line 472 "GomElementTest.vala"
			_g_object_unref0 (n);
#line 472 "GomElementTest.vala"
			_g_object_unref0 (_tmp10_);
#line 472 "GomElementTest.vala"
			_g_object_unref0 (root);
#line 472 "GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 472 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 5115 "GomElementTest.c"
			goto __catch129_g_error;
		}
#line 472 "GomElementTest.vala"
		_tmp34_ = _tmp33_ = g_strsplit (_tmp30_, "\n", 0);
#line 472 "GomElementTest.vala"
		_tmp35_ = _tmp34_;
#line 472 "GomElementTest.vala"
		_tmp35__length1 = _vala_array_length (_tmp33_);
#line 472 "GomElementTest.vala"
		_tmp36_ = _tmp35_[1];
#line 472 "GomElementTest.vala"
		_tmp37_ = g_strdup (_tmp36_);
#line 472 "GomElementTest.vala"
		_tmp38_ = _tmp37_;
#line 472 "GomElementTest.vala"
		_tmp35_ = (_vala_array_free (_tmp35_, _tmp35__length1, (GDestroyNotify) g_free), NULL);
#line 472 "GomElementTest.vala"
		s = _tmp38_;
#line 473 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (s, "<root><child/>TEXT1</root>") == 0, "s == \"<root><child/>TEXT1</root>\"");
#line 463 "GomElementTest.vala"
		_g_free0 (s);
#line 463 "GomElementTest.vala"
		_g_free0 (_tmp30_);
#line 463 "GomElementTest.vala"
		_g_object_unref0 (parser);
#line 463 "GomElementTest.vala"
		_g_object_unref0 (t);
#line 463 "GomElementTest.vala"
		_g_object_unref0 (_tmp19_);
#line 463 "GomElementTest.vala"
		_g_object_unref0 (n);
#line 463 "GomElementTest.vala"
		_g_object_unref0 (_tmp10_);
#line 463 "GomElementTest.vala"
		_g_object_unref0 (root);
#line 463 "GomElementTest.vala"
		_g_object_unref0 (_tmp1_);
#line 463 "GomElementTest.vala"
		_g_object_unref0 (doc);
#line 5156 "GomElementTest.c"
	}
	goto __finally129;
	__catch129_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp39_;
#line 463 "GomElementTest.vala"
		e = _inner_error0_;
#line 463 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 475 "GomElementTest.vala"
		_tmp39_ = e->message;
#line 475 "GomElementTest.vala"
		g_test_message ("%s", _tmp39_);
#line 476 "GomElementTest.vala"
		g_assert_not_reached ();
#line 463 "GomElementTest.vala"
		_g_error_free0 (e);
#line 5175 "GomElementTest.c"
	}
	__finally129:
#line 463 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 463 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 463 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 463 "GomElementTest.vala"
		return;
#line 5186 "GomElementTest.c"
	}
}

static void
___lambda105__gtest_func (void)
{
#line 462 "GomElementTest.vala"
	__lambda105_ ();
#line 5195 "GomElementTest.c"
}

static void
__lambda106_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlDomElement* _tmp1_;
		GXmlDomElement* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlDomElement* _tmp5_;
		GXmlDomElement* _tmp6_;
		GXmlDomNode* _tmp7_;
		GXmlDomNode* _tmp8_;
		GXmlDomNode* _tmp9_;
		GXmlDomElement* _tmp10_;
		GXmlDomElement* _tmp11_;
		GXmlDomElement* _tmp12_;
		GXmlDomNode* _tmp13_;
		GXmlDomNode* _tmp14_;
		GXmlDomNode* _tmp15_;
		GXmlDomElement* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlDomElement* _tmp18_;
		GXmlDomNodeList* _tmp19_;
		GXmlDomNodeList* _tmp20_;
		GXmlDomNodeList* _tmp21_;
		gpointer _tmp22_;
		GXmlDomNode* _tmp23_;
		GXmlDomElement* _tmp24_;
		GXmlDomElement* _tmp25_;
		GXmlDomElement* _tmp26_;
		GXmlDomNodeList* _tmp27_;
		GXmlDomNodeList* _tmp28_;
		GXmlDomNodeList* _tmp29_;
		gpointer _tmp30_;
		GXmlDomNode* _tmp31_;
		GXmlDomNode* _tmp32_;
		GXmlDomNode* _tmp33_;
		GXmlDomNode* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomElement* _tmp37_;
		GXmlDomNodeList* _tmp38_;
		GXmlDomNodeList* _tmp39_;
		GXmlDomNodeList* _tmp40_;
		gpointer _tmp41_;
		GXmlDomNode* _tmp42_;
		GXmlDomNode* _tmp43_;
		GXmlDomNode* _tmp44_;
		GXmlDomNode* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
#line 481 "GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<root><child/></root>", &_inner_error0_);
#line 481 "GomElementTest.vala"
		doc = _tmp0_;
#line 481 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 5259 "GomElementTest.c"
			goto __catch130_g_error;
		}
#line 482 "GomElementTest.vala"
		_tmp1_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 482 "GomElementTest.vala"
		_tmp2_ = _tmp1_;
#line 482 "GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 482 "GomElementTest.vala"
		_vala_assert (_tmp3_ != NULL, "doc.document_element != null");
#line 482 "GomElementTest.vala"
		_g_object_unref0 (_tmp3_);
#line 483 "GomElementTest.vala"
		_tmp4_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 483 "GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 483 "GomElementTest.vala"
		_tmp6_ = _tmp5_;
#line 483 "GomElementTest.vala"
		_tmp7_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp6_);
#line 483 "GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 483 "GomElementTest.vala"
		_tmp9_ = _tmp8_;
#line 483 "GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_DOM_NODE), "doc.document_element.parent_node is GXml.DomNode");
#line 483 "GomElementTest.vala"
		_g_object_unref0 (_tmp9_);
#line 483 "GomElementTest.vala"
		_g_object_unref0 (_tmp6_);
#line 484 "GomElementTest.vala"
		_tmp10_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 484 "GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 484 "GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 484 "GomElementTest.vala"
		_tmp13_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp12_);
#line 484 "GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 484 "GomElementTest.vala"
		_tmp15_ = _tmp14_;
#line 484 "GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GXML_TYPE_DOM_DOCUMENT), "doc.document_element.parent_node is GXml.DomDocument");
#line 484 "GomElementTest.vala"
		_g_object_unref0 (_tmp15_);
#line 484 "GomElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 485 "GomElementTest.vala"
		_tmp16_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 485 "GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 485 "GomElementTest.vala"
		_tmp18_ = _tmp17_;
#line 485 "GomElementTest.vala"
		_tmp19_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp18_);
#line 485 "GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 485 "GomElementTest.vala"
		_tmp21_ = _tmp20_;
#line 485 "GomElementTest.vala"
		_tmp22_ = gee_list_get ((GeeList*) _tmp21_, 0);
#line 485 "GomElementTest.vala"
		_tmp23_ = (GXmlDomNode*) _tmp22_;
#line 485 "GomElementTest.vala"
		_vala_assert (_tmp23_ != NULL, "doc.document_element.child_nodes[0] != null");
#line 485 "GomElementTest.vala"
		_g_object_unref0 (_tmp23_);
#line 485 "GomElementTest.vala"
		_g_object_unref0 (_tmp21_);
#line 485 "GomElementTest.vala"
		_g_object_unref0 (_tmp18_);
#line 486 "GomElementTest.vala"
		_tmp24_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 486 "GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 486 "GomElementTest.vala"
		_tmp26_ = _tmp25_;
#line 486 "GomElementTest.vala"
		_tmp27_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp26_);
#line 486 "GomElementTest.vala"
		_tmp28_ = _tmp27_;
#line 486 "GomElementTest.vala"
		_tmp29_ = _tmp28_;
#line 486 "GomElementTest.vala"
		_tmp30_ = gee_list_get ((GeeList*) _tmp29_, 0);
#line 486 "GomElementTest.vala"
		_tmp31_ = (GXmlDomNode*) _tmp30_;
#line 486 "GomElementTest.vala"
		_tmp32_ = gxml_dom_node_get_parent_node (_tmp31_);
#line 486 "GomElementTest.vala"
		_tmp33_ = _tmp32_;
#line 486 "GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 486 "GomElementTest.vala"
		_vala_assert (_tmp34_ != NULL, "doc.document_element.child_nodes[0].parent_node != null");
#line 486 "GomElementTest.vala"
		_g_object_unref0 (_tmp34_);
#line 486 "GomElementTest.vala"
		_g_object_unref0 (_tmp31_);
#line 486 "GomElementTest.vala"
		_g_object_unref0 (_tmp29_);
#line 486 "GomElementTest.vala"
		_g_object_unref0 (_tmp26_);
#line 487 "GomElementTest.vala"
		_tmp35_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 487 "GomElementTest.vala"
		_tmp36_ = _tmp35_;
#line 487 "GomElementTest.vala"
		_tmp37_ = _tmp36_;
#line 487 "GomElementTest.vala"
		_tmp38_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp37_);
#line 487 "GomElementTest.vala"
		_tmp39_ = _tmp38_;
#line 487 "GomElementTest.vala"
		_tmp40_ = _tmp39_;
#line 487 "GomElementTest.vala"
		_tmp41_ = gee_list_get ((GeeList*) _tmp40_, 0);
#line 487 "GomElementTest.vala"
		_tmp42_ = (GXmlDomNode*) _tmp41_;
#line 487 "GomElementTest.vala"
		_tmp43_ = gxml_dom_node_get_parent_node (_tmp42_);
#line 487 "GomElementTest.vala"
		_tmp44_ = _tmp43_;
#line 487 "GomElementTest.vala"
		_tmp45_ = _tmp44_;
#line 487 "GomElementTest.vala"
		_tmp46_ = gxml_dom_node_get_node_name (_tmp45_);
#line 487 "GomElementTest.vala"
		_tmp47_ = _tmp46_;
#line 487 "GomElementTest.vala"
		_tmp48_ = _tmp47_;
#line 487 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp48_, "root") == 0, "doc.document_element.child_nodes[0].parent_node.node_name == \"root\"");
#line 487 "GomElementTest.vala"
		_g_free0 (_tmp48_);
#line 487 "GomElementTest.vala"
		_g_object_unref0 (_tmp45_);
#line 487 "GomElementTest.vala"
		_g_object_unref0 (_tmp42_);
#line 487 "GomElementTest.vala"
		_g_object_unref0 (_tmp40_);
#line 487 "GomElementTest.vala"
		_g_object_unref0 (_tmp37_);
#line 480 "GomElementTest.vala"
		_g_object_unref0 (doc);
#line 5406 "GomElementTest.c"
	}
	goto __finally130;
	__catch130_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp49_;
		gchar* _tmp50_;
		gchar* _tmp51_;
#line 480 "GomElementTest.vala"
		e = _inner_error0_;
#line 480 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 489 "GomElementTest.vala"
		_tmp49_ = e->message;
#line 489 "GomElementTest.vala"
		_tmp50_ = g_strconcat ("Error: ", _tmp49_, NULL);
#line 489 "GomElementTest.vala"
		_tmp51_ = _tmp50_;
#line 489 "GomElementTest.vala"
		g_message ("GomElementTest.vala:489: %s", _tmp51_);
#line 489 "GomElementTest.vala"
		_g_free0 (_tmp51_);
#line 490 "GomElementTest.vala"
		g_assert_not_reached ();
#line 480 "GomElementTest.vala"
		_g_error_free0 (e);
#line 5433 "GomElementTest.c"
	}
	__finally130:
#line 480 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 480 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 480 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 480 "GomElementTest.vala"
		return;
#line 5444 "GomElementTest.c"
	}
}

static void
___lambda106__gtest_func (void)
{
#line 479 "GomElementTest.vala"
	__lambda106_ ();
#line 5453 "GomElementTest.c"
}

static void
__lambda107_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlGomDocument* _tmp1_;
		GXmlDomElement* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlGomDocument* _tmp5_;
		GXmlDomElement* _tmp6_;
		GXmlDomElement* _tmp7_;
		GXmlDomElement* _tmp8_;
		GXmlDomNode* _tmp9_;
		GXmlDomNode* _tmp10_;
		GXmlDomNode* _tmp11_;
		GXmlGomDocument* _tmp12_;
		GXmlDomElement* _tmp13_;
		GXmlDomElement* _tmp14_;
		GXmlDomElement* _tmp15_;
		GXmlDomNode* _tmp16_;
		GXmlDomNode* _tmp17_;
		GXmlDomNode* _tmp18_;
		GXmlGomDocument* _tmp19_;
		GXmlDomElement* _tmp20_;
		GXmlDomElement* _tmp21_;
		GXmlDomElement* _tmp22_;
		GXmlDomNodeList* _tmp23_;
		GXmlDomNodeList* _tmp24_;
		GXmlDomNodeList* _tmp25_;
		gint _tmp26_;
		gint _tmp27_;
		GXmlGomDocument* _tmp28_;
		GXmlDomElement* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomElement* _tmp31_;
		GXmlDomNodeList* _tmp32_;
		GXmlDomNodeList* _tmp33_;
		GXmlDomNodeList* _tmp34_;
		gpointer _tmp35_;
		GXmlDomNode* _tmp36_;
		GXmlGomDocument* _tmp37_;
		GXmlDomElement* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomElement* _tmp40_;
		GXmlDomNodeList* _tmp41_;
		GXmlDomNodeList* _tmp42_;
		GXmlDomNodeList* _tmp43_;
		gpointer _tmp44_;
		GXmlDomNode* _tmp45_;
		GXmlDomChildNode* _tmp46_;
		GXmlDomChildNode* _tmp47_;
		GXmlGomDocument* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlDomElement* _tmp51_;
		GXmlDomNodeList* _tmp52_;
		GXmlDomNodeList* _tmp53_;
		GXmlDomNodeList* _tmp54_;
		gint _tmp55_;
		gint _tmp56_;
		gchar* _tmp57_ = NULL;
		GXmlGomDocument* _tmp58_;
		gchar* _tmp59_;
#line 495 "GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<root><child/></root>", &_inner_error0_);
#line 495 "GomElementTest.vala"
		doc = _tmp0_;
#line 495 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 5528 "GomElementTest.c"
			goto __catch131_g_error;
		}
#line 496 "GomElementTest.vala"
		_tmp1_ = doc;
#line 496 "GomElementTest.vala"
		_tmp2_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp1_);
#line 496 "GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 496 "GomElementTest.vala"
		_tmp4_ = _tmp3_;
#line 496 "GomElementTest.vala"
		_vala_assert (_tmp4_ != NULL, "doc.document_element != null");
#line 496 "GomElementTest.vala"
		_g_object_unref0 (_tmp4_);
#line 497 "GomElementTest.vala"
		_tmp5_ = doc;
#line 497 "GomElementTest.vala"
		_tmp6_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp5_);
#line 497 "GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 497 "GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 497 "GomElementTest.vala"
		_tmp9_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp8_);
#line 497 "GomElementTest.vala"
		_tmp10_ = _tmp9_;
#line 497 "GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 497 "GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, GXML_TYPE_DOM_NODE), "doc.document_element.parent_node is GXml.DomNode");
#line 497 "GomElementTest.vala"
		_g_object_unref0 (_tmp11_);
#line 497 "GomElementTest.vala"
		_g_object_unref0 (_tmp8_);
#line 498 "GomElementTest.vala"
		_tmp12_ = doc;
#line 498 "GomElementTest.vala"
		_tmp13_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp12_);
#line 498 "GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 498 "GomElementTest.vala"
		_tmp15_ = _tmp14_;
#line 498 "GomElementTest.vala"
		_tmp16_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp15_);
#line 498 "GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 498 "GomElementTest.vala"
		_tmp18_ = _tmp17_;
#line 498 "GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, GXML_TYPE_DOM_DOCUMENT), "doc.document_element.parent_node is GXml.DomDocument");
#line 498 "GomElementTest.vala"
		_g_object_unref0 (_tmp18_);
#line 498 "GomElementTest.vala"
		_g_object_unref0 (_tmp15_);
#line 499 "GomElementTest.vala"
		_tmp19_ = doc;
#line 499 "GomElementTest.vala"
		_tmp20_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp19_);
#line 499 "GomElementTest.vala"
		_tmp21_ = _tmp20_;
#line 499 "GomElementTest.vala"
		_tmp22_ = _tmp21_;
#line 499 "GomElementTest.vala"
		_tmp23_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp22_);
#line 499 "GomElementTest.vala"
		_tmp24_ = _tmp23_;
#line 499 "GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 499 "GomElementTest.vala"
		_tmp26_ = gxml_dom_node_list_get_length (_tmp25_);
#line 499 "GomElementTest.vala"
		_tmp27_ = _tmp26_;
#line 499 "GomElementTest.vala"
		_vala_assert (_tmp27_ == 1, "doc.document_element.child_nodes.length == 1");
#line 499 "GomElementTest.vala"
		_g_object_unref0 (_tmp25_);
#line 499 "GomElementTest.vala"
		_g_object_unref0 (_tmp22_);
#line 500 "GomElementTest.vala"
		_tmp28_ = doc;
#line 500 "GomElementTest.vala"
		_tmp29_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp28_);
#line 500 "GomElementTest.vala"
		_tmp30_ = _tmp29_;
#line 500 "GomElementTest.vala"
		_tmp31_ = _tmp30_;
#line 500 "GomElementTest.vala"
		_tmp32_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp31_);
#line 500 "GomElementTest.vala"
		_tmp33_ = _tmp32_;
#line 500 "GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 500 "GomElementTest.vala"
		_tmp35_ = gee_list_get ((GeeList*) _tmp34_, 0);
#line 500 "GomElementTest.vala"
		_tmp36_ = (GXmlDomNode*) _tmp35_;
#line 500 "GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp36_, GXML_TYPE_DOM_CHILD_NODE), "doc.document_element.child_nodes[0] is DomChildNode");
#line 500 "GomElementTest.vala"
		_g_object_unref0 (_tmp36_);
#line 500 "GomElementTest.vala"
		_g_object_unref0 (_tmp34_);
#line 500 "GomElementTest.vala"
		_g_object_unref0 (_tmp31_);
#line 501 "GomElementTest.vala"
		_tmp37_ = doc;
#line 501 "GomElementTest.vala"
		_tmp38_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp37_);
#line 501 "GomElementTest.vala"
		_tmp39_ = _tmp38_;
#line 501 "GomElementTest.vala"
		_tmp40_ = _tmp39_;
#line 501 "GomElementTest.vala"
		_tmp41_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp40_);
#line 501 "GomElementTest.vala"
		_tmp42_ = _tmp41_;
#line 501 "GomElementTest.vala"
		_tmp43_ = _tmp42_;
#line 501 "GomElementTest.vala"
		_tmp44_ = gee_list_get ((GeeList*) _tmp43_, 0);
#line 501 "GomElementTest.vala"
		_tmp45_ = (GXmlDomNode*) _tmp44_;
#line 501 "GomElementTest.vala"
		_tmp46_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp45_, GXML_TYPE_DOM_CHILD_NODE) ? ((GXmlDomChildNode*) _tmp45_) : NULL;
#line 501 "GomElementTest.vala"
		if (_tmp46_ == NULL) {
#line 501 "GomElementTest.vala"
			_g_object_unref0 (_tmp45_);
#line 5657 "GomElementTest.c"
		}
#line 501 "GomElementTest.vala"
		_tmp47_ = _tmp46_;
#line 501 "GomElementTest.vala"
		gxml_dom_child_node_remove (_tmp47_);
#line 501 "GomElementTest.vala"
		_g_object_unref0 (_tmp47_);
#line 501 "GomElementTest.vala"
		_g_object_unref0 (_tmp43_);
#line 501 "GomElementTest.vala"
		_g_object_unref0 (_tmp40_);
#line 502 "GomElementTest.vala"
		_tmp48_ = doc;
#line 502 "GomElementTest.vala"
		_tmp49_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp48_);
#line 502 "GomElementTest.vala"
		_tmp50_ = _tmp49_;
#line 502 "GomElementTest.vala"
		_tmp51_ = _tmp50_;
#line 502 "GomElementTest.vala"
		_tmp52_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp51_);
#line 502 "GomElementTest.vala"
		_tmp53_ = _tmp52_;
#line 502 "GomElementTest.vala"
		_tmp54_ = _tmp53_;
#line 502 "GomElementTest.vala"
		_tmp55_ = gxml_dom_node_list_get_length (_tmp54_);
#line 502 "GomElementTest.vala"
		_tmp56_ = _tmp55_;
#line 502 "GomElementTest.vala"
		_vala_assert (_tmp56_ == 0, "doc.document_element.child_nodes.length == 0");
#line 502 "GomElementTest.vala"
		_g_object_unref0 (_tmp54_);
#line 502 "GomElementTest.vala"
		_g_object_unref0 (_tmp51_);
#line 503 "GomElementTest.vala"
		_tmp58_ = doc;
#line 503 "GomElementTest.vala"
		_tmp59_ = gxml_dom_document_write_string ((GXmlDomDocument*) _tmp58_, NULL, &_inner_error0_);
#line 503 "GomElementTest.vala"
		_tmp57_ = _tmp59_;
#line 503 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 503 "GomElementTest.vala"
			_g_object_unref0 (doc);
#line 5703 "GomElementTest.c"
			goto __catch131_g_error;
		}
#line 503 "GomElementTest.vala"
		_vala_assert (string_contains (_tmp57_, "<root/>"), "\"<root/>\" in  doc.write_string ()");
#line 494 "GomElementTest.vala"
		_g_free0 (_tmp57_);
#line 494 "GomElementTest.vala"
		_g_object_unref0 (doc);
#line 5712 "GomElementTest.c"
	}
	goto __finally131;
	__catch131_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp60_;
		gchar* _tmp61_;
		gchar* _tmp62_;
#line 494 "GomElementTest.vala"
		e = _inner_error0_;
#line 494 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 505 "GomElementTest.vala"
		_tmp60_ = e->message;
#line 505 "GomElementTest.vala"
		_tmp61_ = g_strconcat ("Error: ", _tmp60_, NULL);
#line 505 "GomElementTest.vala"
		_tmp62_ = _tmp61_;
#line 505 "GomElementTest.vala"
		g_message ("GomElementTest.vala:505: %s", _tmp62_);
#line 505 "GomElementTest.vala"
		_g_free0 (_tmp62_);
#line 506 "GomElementTest.vala"
		g_assert_not_reached ();
#line 494 "GomElementTest.vala"
		_g_error_free0 (e);
#line 5739 "GomElementTest.c"
	}
	__finally131:
#line 494 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 494 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 494 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 494 "GomElementTest.vala"
		return;
#line 5750 "GomElementTest.c"
	}
}

static void
___lambda107__gtest_func (void)
{
#line 493 "GomElementTest.vala"
	__lambda107_ ();
#line 5759 "GomElementTest.c"
}

static void
__lambda108_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GomElementTestParsedDelayed* n = NULL;
		GomElementTestParsedDelayed* _tmp0_;
		GomElementTestParsedDelayed* _tmp1_;
		GomElementTestParsedDelayed* _tmp2_;
		const gchar* _tmp3_;
		const gchar* _tmp4_;
		GomElementTestParsedDelayed* _tmp5_;
		const gchar* _tmp6_;
		const gchar* _tmp7_;
		GomElementTestParsedDelayed* _tmp8_;
		GomElementTestParsedDelayed* _tmp9_;
		GXmlDomNodeList* _tmp10_;
		GXmlDomNodeList* _tmp11_;
		GXmlDomNodeList* _tmp12_;
		gint _tmp13_;
		gint _tmp14_;
		GomElementTestParsedDelayed* _tmp15_;
		GomElementTestParsedDelayed* _tmp16_;
		GomElementTestParsedDelayed* _tmp17_;
		GXmlDomNodeList* _tmp18_;
		GXmlDomNodeList* _tmp19_;
		GXmlDomNodeList* _tmp20_;
		gint _tmp21_;
		gint _tmp22_;
		GomElementTestParsedDelayed* _tmp23_;
		const gchar* _tmp24_;
		const gchar* _tmp25_;
#line 511 "GomElementTest.vala"
		_tmp0_ = gom_element_test_parsed_delayed_new ();
#line 511 "GomElementTest.vala"
		n = _tmp0_;
#line 512 "GomElementTest.vala"
		_tmp1_ = n;
#line 512 "GomElementTest.vala"
		gxml_dom_element_read_from_string ((GXmlDomElement*) _tmp1_, "<root><child p1=\"Value1\" p2=\"Value2\"><child2/></child></root>", NULL, &_inner_error0_);
#line 512 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 512 "GomElementTest.vala"
			_g_object_unref0 (n);
#line 5806 "GomElementTest.c"
			goto __catch132_g_error;
		}
#line 513 "GomElementTest.vala"
		_tmp2_ = n;
#line 513 "GomElementTest.vala"
		_tmp3_ = gxml_gom_element_get_unparsed ((GXmlGomElement*) _tmp2_);
#line 513 "GomElementTest.vala"
		_tmp4_ = _tmp3_;
#line 513 "GomElementTest.vala"
		_vala_assert (_tmp4_ != NULL, "n.unparsed != null");
#line 514 "GomElementTest.vala"
		_tmp5_ = n;
#line 514 "GomElementTest.vala"
		_tmp6_ = gxml_gom_element_get_unparsed ((GXmlGomElement*) _tmp5_);
#line 514 "GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 514 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "<child p1=\"Value1\" p2=\"Value2\"><child2/></child>") == 0, "n.unparsed == \"<child p1=\\\"Value1\\\" p2=\\\"Value2\\\"><child2/></child>\"");
#line 515 "GomElementTest.vala"
		_tmp8_ = n;
#line 515 "GomElementTest.vala"
		_vala_assert (!gxml_dom_node_has_child_nodes ((GXmlDomNode*) _tmp8_), "!n.has_child_nodes ()");
#line 516 "GomElementTest.vala"
		_tmp9_ = n;
#line 516 "GomElementTest.vala"
		_tmp10_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp9_);
#line 516 "GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 516 "GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 516 "GomElementTest.vala"
		_tmp13_ = gxml_dom_node_list_get_length (_tmp12_);
#line 516 "GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 516 "GomElementTest.vala"
		_vala_assert (_tmp14_ == 0, "n.child_nodes.length == 0");
#line 516 "GomElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 517 "GomElementTest.vala"
		_tmp15_ = n;
#line 517 "GomElementTest.vala"
		gxml_gom_element_read_unparsed ((GXmlGomElement*) _tmp15_, &_inner_error0_);
#line 517 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 517 "GomElementTest.vala"
			_g_object_unref0 (n);
#line 5853 "GomElementTest.c"
			goto __catch132_g_error;
		}
#line 518 "GomElementTest.vala"
		_tmp16_ = n;
#line 518 "GomElementTest.vala"
		_vala_assert (gxml_dom_node_has_child_nodes ((GXmlDomNode*) _tmp16_), "n.has_child_nodes ()");
#line 519 "GomElementTest.vala"
		_tmp17_ = n;
#line 519 "GomElementTest.vala"
		_tmp18_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp17_);
#line 519 "GomElementTest.vala"
		_tmp19_ = _tmp18_;
#line 519 "GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 519 "GomElementTest.vala"
		_tmp21_ = gxml_dom_node_list_get_length (_tmp20_);
#line 519 "GomElementTest.vala"
		_tmp22_ = _tmp21_;
#line 519 "GomElementTest.vala"
		_vala_assert (_tmp22_ == 1, "n.child_nodes.length == 1");
#line 519 "GomElementTest.vala"
		_g_object_unref0 (_tmp20_);
#line 520 "GomElementTest.vala"
		_tmp23_ = n;
#line 520 "GomElementTest.vala"
		_tmp24_ = gxml_gom_element_get_unparsed ((GXmlGomElement*) _tmp23_);
#line 520 "GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 520 "GomElementTest.vala"
		_vala_assert (_tmp25_ == NULL, "n.unparsed == null");
#line 510 "GomElementTest.vala"
		_g_object_unref0 (n);
#line 5886 "GomElementTest.c"
	}
	goto __finally132;
	__catch132_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
#line 510 "GomElementTest.vala"
		e = _inner_error0_;
#line 510 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 522 "GomElementTest.vala"
		_tmp26_ = e->message;
#line 522 "GomElementTest.vala"
		_tmp27_ = g_strconcat ("Error: ", _tmp26_, NULL);
#line 522 "GomElementTest.vala"
		_tmp28_ = _tmp27_;
#line 522 "GomElementTest.vala"
		g_message ("GomElementTest.vala:522: %s", _tmp28_);
#line 522 "GomElementTest.vala"
		_g_free0 (_tmp28_);
#line 523 "GomElementTest.vala"
		g_assert_not_reached ();
#line 510 "GomElementTest.vala"
		_g_error_free0 (e);
#line 5913 "GomElementTest.c"
	}
	__finally132:
#line 510 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 510 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 510 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 510 "GomElementTest.vala"
		return;
#line 5924 "GomElementTest.c"
	}
}

static void
___lambda108__gtest_func (void)
{
#line 509 "GomElementTest.vala"
	__lambda108_ ();
#line 5933 "GomElementTest.c"
}

static void
__lambda109_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGomElement* n = NULL;
		GXmlGomElement* _tmp0_;
		GXmlGomElement* _tmp1_;
		GXmlGomElement* _tmp2_;
		GXmlDomElement* _tmp3_ = NULL;
		GXmlGomElement* _tmp4_;
		GXmlDomDocument* _tmp5_;
		GXmlDomDocument* _tmp6_;
		GXmlDomElement* _tmp7_;
		GXmlGomElement* n2 = NULL;
		GXmlGomElement* _tmp8_;
		GXmlGomElement* _tmp9_;
		GXmlGomElement* _tmp10_;
		GXmlDomNode* _tmp11_;
		GXmlDomNode* _tmp12_;
		gchar* str = NULL;
		GXmlGomElement* _tmp13_;
		gchar* _tmp14_;
		const gchar* _tmp15_;
		const gchar* _tmp16_;
		gchar* _tmp17_ = NULL;
		GXmlGomElement* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		const gchar* _tmp21_;
		const gchar* _tmp22_;
#line 528 "GomElementTest.vala"
		_tmp0_ = gxml_gom_element_new ();
#line 528 "GomElementTest.vala"
		n = _tmp0_;
#line 529 "GomElementTest.vala"
		_tmp1_ = n;
#line 529 "GomElementTest.vala"
		gxml_gom_element_initialize (_tmp1_, "Node");
#line 530 "GomElementTest.vala"
		_tmp2_ = n;
#line 530 "GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp2_, "name", "value", &_inner_error0_);
#line 530 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 530 "GomElementTest.vala"
			_g_object_unref0 (n);
#line 5983 "GomElementTest.c"
			goto __catch133_g_error;
		}
#line 531 "GomElementTest.vala"
		_tmp4_ = n;
#line 531 "GomElementTest.vala"
		_tmp5_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _tmp4_);
#line 531 "GomElementTest.vala"
		_tmp6_ = _tmp5_;
#line 531 "GomElementTest.vala"
		_tmp7_ = gxml_dom_document_create_element (_tmp6_, "Node2", &_inner_error0_);
#line 531 "GomElementTest.vala"
		_tmp3_ = _tmp7_;
#line 531 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 531 "GomElementTest.vala"
			_g_object_unref0 (n);
#line 6000 "GomElementTest.c"
			goto __catch133_g_error;
		}
#line 531 "GomElementTest.vala"
		_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_GOM_ELEMENT) ? ((GXmlGomElement*) _tmp3_) : NULL);
#line 531 "GomElementTest.vala"
		n2 = _tmp8_;
#line 532 "GomElementTest.vala"
		_tmp9_ = n;
#line 532 "GomElementTest.vala"
		_tmp10_ = n2;
#line 532 "GomElementTest.vala"
		_tmp11_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp9_, (GXmlDomNode*) _tmp10_, &_inner_error0_);
#line 532 "GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 532 "GomElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 532 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 532 "GomElementTest.vala"
			_g_object_unref0 (n2);
#line 532 "GomElementTest.vala"
			_g_object_unref0 (_tmp3_);
#line 532 "GomElementTest.vala"
			_g_object_unref0 (n);
#line 6025 "GomElementTest.c"
			goto __catch133_g_error;
		}
#line 533 "GomElementTest.vala"
		_tmp13_ = n;
#line 533 "GomElementTest.vala"
		_tmp14_ = gxml_dom_element_write_string ((GXmlDomElement*) _tmp13_, NULL, &_inner_error0_);
#line 533 "GomElementTest.vala"
		str = _tmp14_;
#line 533 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 533 "GomElementTest.vala"
			_g_object_unref0 (n2);
#line 533 "GomElementTest.vala"
			_g_object_unref0 (_tmp3_);
#line 533 "GomElementTest.vala"
			_g_object_unref0 (n);
#line 6042 "GomElementTest.c"
			goto __catch133_g_error;
		}
#line 534 "GomElementTest.vala"
		_tmp15_ = str;
#line 534 "GomElementTest.vala"
		_vala_assert (string_contains (_tmp15_, "<Node"), "\"<Node\" in str");
#line 535 "GomElementTest.vala"
		_tmp16_ = str;
#line 535 "GomElementTest.vala"
		_vala_assert (string_contains (_tmp16_, "<Node name=\"value\"><Node2/></Node>"), "\"<Node name=\\\"value\\\"><Node2/></Node>\" in str");
#line 536 "GomElementTest.vala"
		_tmp18_ = n2;
#line 536 "GomElementTest.vala"
		_tmp19_ = gxml_dom_element_write_string ((GXmlDomElement*) _tmp18_, NULL, &_inner_error0_);
#line 536 "GomElementTest.vala"
		_tmp17_ = _tmp19_;
#line 536 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 536 "GomElementTest.vala"
			_g_free0 (str);
#line 536 "GomElementTest.vala"
			_g_object_unref0 (n2);
#line 536 "GomElementTest.vala"
			_g_object_unref0 (_tmp3_);
#line 536 "GomElementTest.vala"
			_g_object_unref0 (n);
#line 6069 "GomElementTest.c"
			goto __catch133_g_error;
		}
#line 536 "GomElementTest.vala"
		_tmp20_ = _tmp17_;
#line 536 "GomElementTest.vala"
		_tmp17_ = NULL;
#line 536 "GomElementTest.vala"
		_g_free0 (str);
#line 536 "GomElementTest.vala"
		str = _tmp20_;
#line 537 "GomElementTest.vala"
		_tmp21_ = str;
#line 537 "GomElementTest.vala"
		_vala_assert (string_contains (_tmp21_, "<Node2/>"), "\"<Node2/>\" in str");
#line 538 "GomElementTest.vala"
		_tmp22_ = str;
#line 538 "GomElementTest.vala"
		_vala_assert (!string_contains (_tmp22_, "<Node name=\"value\"><Node2/></Node>"), "!(\"<Node name=\\\"value\\\"><Node2/></Node>\" in str)");
#line 527 "GomElementTest.vala"
		_g_free0 (_tmp17_);
#line 527 "GomElementTest.vala"
		_g_free0 (str);
#line 527 "GomElementTest.vala"
		_g_object_unref0 (n2);
#line 527 "GomElementTest.vala"
		_g_object_unref0 (_tmp3_);
#line 527 "GomElementTest.vala"
		_g_object_unref0 (n);
#line 6098 "GomElementTest.c"
	}
	goto __finally133;
	__catch133_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp23_;
		gchar* _tmp24_;
		gchar* _tmp25_;
#line 527 "GomElementTest.vala"
		e = _inner_error0_;
#line 527 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 540 "GomElementTest.vala"
		_tmp23_ = e->message;
#line 540 "GomElementTest.vala"
		_tmp24_ = g_strconcat ("Error: ", _tmp23_, NULL);
#line 540 "GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 540 "GomElementTest.vala"
		g_message ("GomElementTest.vala:540: %s", _tmp25_);
#line 540 "GomElementTest.vala"
		_g_free0 (_tmp25_);
#line 541 "GomElementTest.vala"
		g_assert_not_reached ();
#line 527 "GomElementTest.vala"
		_g_error_free0 (e);
#line 6125 "GomElementTest.c"
	}
	__finally133:
#line 527 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 527 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 527 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 527 "GomElementTest.vala"
		return;
#line 6136 "GomElementTest.c"
	}
}

static void
___lambda109__gtest_func (void)
{
#line 526 "GomElementTest.vala"
	__lambda109_ ();
#line 6145 "GomElementTest.c"
}

static void
__lambda110_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGomElement* n = NULL;
		GXmlGomElement* _tmp0_;
		GXmlGomElement* _tmp1_;
		GXmlGomElement* _tmp2_;
		GMemoryOutputStream* ostream = NULL;
		GMemoryOutputStream* _tmp3_;
		GXmlGomElement* _tmp4_;
		GMemoryOutputStream* _tmp5_;
		gchar* str = NULL;
		GMemoryOutputStream* _tmp6_;
		void* _tmp7_;
		void* _tmp8_;
		gchar* _tmp9_;
#line 546 "GomElementTest.vala"
		_tmp0_ = gxml_gom_element_new ();
#line 546 "GomElementTest.vala"
		n = _tmp0_;
#line 547 "GomElementTest.vala"
		_tmp1_ = n;
#line 547 "GomElementTest.vala"
		gxml_gom_element_initialize (_tmp1_, "Node");
#line 548 "GomElementTest.vala"
		_tmp2_ = n;
#line 548 "GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp2_, "name", "value", &_inner_error0_);
#line 548 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 548 "GomElementTest.vala"
			_g_object_unref0 (n);
#line 6182 "GomElementTest.c"
			goto __catch134_g_error;
		}
#line 549 "GomElementTest.vala"
		_tmp3_ = (GMemoryOutputStream*) g_memory_output_stream_new_resizable ();
#line 549 "GomElementTest.vala"
		ostream = _tmp3_;
#line 550 "GomElementTest.vala"
		_tmp4_ = n;
#line 550 "GomElementTest.vala"
		_tmp5_ = ostream;
#line 550 "GomElementTest.vala"
		gxml_dom_element_write_stream ((GXmlDomElement*) _tmp4_, (GOutputStream*) _tmp5_, &_inner_error0_);
#line 550 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 550 "GomElementTest.vala"
			_g_object_unref0 (ostream);
#line 550 "GomElementTest.vala"
			_g_object_unref0 (n);
#line 6201 "GomElementTest.c"
			goto __catch134_g_error;
		}
#line 551 "GomElementTest.vala"
		_tmp6_ = ostream;
#line 551 "GomElementTest.vala"
		_tmp7_ = g_memory_output_stream_get_data (_tmp6_);
#line 551 "GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 551 "GomElementTest.vala"
		_tmp9_ = g_strdup ((const gchar*) _tmp8_);
#line 551 "GomElementTest.vala"
		str = _tmp9_;
#line 552 "GomElementTest.vala"
		_vala_assert (string_contains (str, "<Node"), "\"<Node\" in str");
#line 553 "GomElementTest.vala"
		_vala_assert (string_contains (str, "<Node name=\"value\"/>"), "\"<Node name=\\\"value\\\"/>\" in str");
#line 545 "GomElementTest.vala"
		_g_free0 (str);
#line 545 "GomElementTest.vala"
		_g_object_unref0 (ostream);
#line 545 "GomElementTest.vala"
		_g_object_unref0 (n);
#line 6224 "GomElementTest.c"
	}
	goto __finally134;
	__catch134_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
#line 545 "GomElementTest.vala"
		e = _inner_error0_;
#line 545 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 555 "GomElementTest.vala"
		_tmp10_ = e->message;
#line 555 "GomElementTest.vala"
		_tmp11_ = g_strconcat ("Error: ", _tmp10_, NULL);
#line 555 "GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 555 "GomElementTest.vala"
		g_message ("GomElementTest.vala:555: %s", _tmp12_);
#line 555 "GomElementTest.vala"
		_g_free0 (_tmp12_);
#line 556 "GomElementTest.vala"
		g_assert_not_reached ();
#line 545 "GomElementTest.vala"
		_g_error_free0 (e);
#line 6251 "GomElementTest.c"
	}
	__finally134:
#line 545 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 545 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 545 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 545 "GomElementTest.vala"
		return;
#line 6262 "GomElementTest.c"
	}
}

static void
___lambda110__gtest_func (void)
{
#line 544 "GomElementTest.vala"
	__lambda110_ ();
#line 6271 "GomElementTest.c"
}

static void
__lambda111_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGomElement* n = NULL;
		GXmlGomElement* _tmp0_;
		GXmlGomElement* _tmp1_;
		GXmlGomElement* _tmp2_;
		GMemoryOutputStream* ostream = NULL;
		GMemoryOutputStream* _tmp3_;
		GInputStream* istream = NULL;
		GXmlGomElement* _tmp4_;
		GInputStream* _tmp5_;
		GMemoryOutputStream* _tmp6_;
		GInputStream* _tmp7_;
		gchar* str = NULL;
		GMemoryOutputStream* _tmp8_;
		void* _tmp9_;
		void* _tmp10_;
		gchar* _tmp11_;
#line 561 "GomElementTest.vala"
		_tmp0_ = gxml_gom_element_new ();
#line 561 "GomElementTest.vala"
		n = _tmp0_;
#line 562 "GomElementTest.vala"
		_tmp1_ = n;
#line 562 "GomElementTest.vala"
		gxml_gom_element_initialize (_tmp1_, "Node");
#line 563 "GomElementTest.vala"
		_tmp2_ = n;
#line 563 "GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp2_, "name", "value", &_inner_error0_);
#line 563 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 563 "GomElementTest.vala"
			_g_object_unref0 (n);
#line 6311 "GomElementTest.c"
			goto __catch135_g_error;
		}
#line 564 "GomElementTest.vala"
		_tmp3_ = (GMemoryOutputStream*) g_memory_output_stream_new_resizable ();
#line 564 "GomElementTest.vala"
		ostream = _tmp3_;
#line 565 "GomElementTest.vala"
		_tmp4_ = n;
#line 565 "GomElementTest.vala"
		_tmp5_ = gxml_dom_element_create_stream ((GXmlDomElement*) _tmp4_, &_inner_error0_);
#line 565 "GomElementTest.vala"
		istream = _tmp5_;
#line 565 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 565 "GomElementTest.vala"
			_g_object_unref0 (ostream);
#line 565 "GomElementTest.vala"
			_g_object_unref0 (n);
#line 6330 "GomElementTest.c"
			goto __catch135_g_error;
		}
#line 566 "GomElementTest.vala"
		_tmp6_ = ostream;
#line 566 "GomElementTest.vala"
		_tmp7_ = istream;
#line 566 "GomElementTest.vala"
		g_output_stream_splice ((GOutputStream*) _tmp6_, _tmp7_, G_OUTPUT_STREAM_SPLICE_NONE, NULL, &_inner_error0_);
#line 566 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 566 "GomElementTest.vala"
			_g_object_unref0 (istream);
#line 566 "GomElementTest.vala"
			_g_object_unref0 (ostream);
#line 566 "GomElementTest.vala"
			_g_object_unref0 (n);
#line 6347 "GomElementTest.c"
			goto __catch135_g_error;
		}
#line 567 "GomElementTest.vala"
		_tmp8_ = ostream;
#line 567 "GomElementTest.vala"
		_tmp9_ = g_memory_output_stream_get_data (_tmp8_);
#line 567 "GomElementTest.vala"
		_tmp10_ = _tmp9_;
#line 567 "GomElementTest.vala"
		_tmp11_ = g_strdup ((const gchar*) _tmp10_);
#line 567 "GomElementTest.vala"
		str = _tmp11_;
#line 568 "GomElementTest.vala"
		_vala_assert (string_contains (str, "<Node"), "\"<Node\" in str");
#line 569 "GomElementTest.vala"
		_vala_assert (string_contains (str, "<Node name=\"value\"/>"), "\"<Node name=\\\"value\\\"/>\" in str");
#line 560 "GomElementTest.vala"
		_g_free0 (str);
#line 560 "GomElementTest.vala"
		_g_object_unref0 (istream);
#line 560 "GomElementTest.vala"
		_g_object_unref0 (ostream);
#line 560 "GomElementTest.vala"
		_g_object_unref0 (n);
#line 6372 "GomElementTest.c"
	}
	goto __finally135;
	__catch135_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
#line 560 "GomElementTest.vala"
		e = _inner_error0_;
#line 560 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 571 "GomElementTest.vala"
		_tmp12_ = e->message;
#line 571 "GomElementTest.vala"
		_tmp13_ = g_strconcat ("Error: ", _tmp12_, NULL);
#line 571 "GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 571 "GomElementTest.vala"
		g_message ("GomElementTest.vala:571: %s", _tmp14_);
#line 571 "GomElementTest.vala"
		_g_free0 (_tmp14_);
#line 572 "GomElementTest.vala"
		g_assert_not_reached ();
#line 560 "GomElementTest.vala"
		_g_error_free0 (e);
#line 6399 "GomElementTest.c"
	}
	__finally135:
#line 560 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 560 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 560 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 560 "GomElementTest.vala"
		return;
#line 6410 "GomElementTest.c"
	}
}

static void
___lambda111__gtest_func (void)
{
#line 559 "GomElementTest.vala"
	__lambda111_ ();
#line 6419 "GomElementTest.c"
}

static void
__lambda112_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlDomElement* _tmp1_;
		GXmlDomElement* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlDomElement* _tmp5_;
		GXmlDomElement* _tmp6_;
		GXmlDomNode* _tmp7_;
		GXmlDomNode* _tmp8_;
		GXmlDomNode* _tmp9_;
		GXmlDomElement* _tmp10_;
		GXmlDomElement* _tmp11_;
		GXmlDomElement* _tmp12_;
		GXmlDomNode* _tmp13_;
		GXmlDomNode* _tmp14_;
		GXmlDomNode* _tmp15_;
		GXmlDomElement* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlDomElement* _tmp18_;
		GXmlDomNodeList* _tmp19_;
		GXmlDomNodeList* _tmp20_;
		GXmlDomNodeList* _tmp21_;
		gpointer _tmp22_;
		GXmlDomNode* _tmp23_;
		GXmlDomElement* _tmp24_;
		GXmlDomElement* _tmp25_;
		GXmlDomElement* _tmp26_;
		GXmlDomNodeList* _tmp27_;
		GXmlDomNodeList* _tmp28_;
		GXmlDomNodeList* _tmp29_;
		gpointer _tmp30_;
		GXmlDomNode* _tmp31_;
		GXmlDomNode* _tmp32_;
		GXmlDomNode* _tmp33_;
		GXmlDomNode* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomElement* _tmp37_;
		GXmlDomNodeList* _tmp38_;
		GXmlDomNodeList* _tmp39_;
		GXmlDomNodeList* _tmp40_;
		gpointer _tmp41_;
		GXmlDomNode* _tmp42_;
		GXmlDomNode* _tmp43_;
		GXmlDomNode* _tmp44_;
		GXmlDomNode* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlDomElement* _tmp51_;
		GXmlDomNodeList* _tmp52_;
		GXmlDomNodeList* _tmp53_;
		GXmlDomNodeList* _tmp54_;
		gpointer _tmp55_;
		GXmlDomNode* _tmp56_;
		GXmlDomElement* _tmp57_;
		GXmlDomElement* _tmp58_;
		GXmlDomElement* _tmp59_;
		GXmlDomNodeList* _tmp60_;
		GXmlDomNodeList* _tmp61_;
		GXmlDomNodeList* _tmp62_;
		gpointer _tmp63_;
		GXmlDomNode* _tmp64_;
		GXmlDomElement* _tmp65_;
		GXmlDomElement* _tmp66_;
		GXmlDomElement* _tmp67_;
		GXmlDomNodeList* _tmp68_;
		GXmlDomNodeList* _tmp69_;
		GXmlDomNodeList* _tmp70_;
		gpointer _tmp71_;
		GXmlDomNode* _tmp72_;
		GXmlDomElement* _tmp73_;
		GXmlDomElement* _tmp74_;
		GXmlDomElement* _tmp75_;
		GXmlDomNodeList* _tmp76_;
		GXmlDomNodeList* _tmp77_;
		GXmlDomNodeList* _tmp78_;
		gpointer _tmp79_;
		GXmlDomNode* _tmp80_;
		gchar* _tmp81_;
		gchar* _tmp82_;
		gchar* _tmp83_;
		GXmlDomElement* _tmp84_;
		GXmlDomElement* _tmp85_;
		GXmlDomElement* _tmp86_;
		GXmlDomNodeList* _tmp87_;
		GXmlDomNodeList* _tmp88_;
		GXmlDomNodeList* _tmp89_;
		gpointer _tmp90_;
		GXmlDomNode* _tmp91_;
		GXmlDomElement* _tmp92_;
		GXmlDomElement* _tmp93_;
		GXmlDomElement* _tmp94_;
		GXmlDomElement* _tmp95_;
		GXmlDomElement* _tmp96_;
		GXmlDomElement* _tmp97_;
		GXmlDomElement* _tmp98_;
		GXmlDomElement* _tmp99_;
		GXmlDomNodeList* _tmp100_;
		GXmlDomNodeList* _tmp101_;
		GXmlDomNodeList* _tmp102_;
		gpointer _tmp103_;
		GXmlDomNode* _tmp104_;
		GXmlDomElement* _tmp105_;
		GXmlDomElement* _tmp106_;
		GXmlDomElement* _tmp107_;
		GXmlDomElement* _tmp108_;
		GXmlDomElement* _tmp109_;
		GXmlDomElement* _tmp110_;
		GXmlDomElement* _tmp111_;
		GXmlDomElement* _tmp112_;
		GXmlDomNodeList* _tmp113_;
		GXmlDomNodeList* _tmp114_;
		GXmlDomNodeList* _tmp115_;
		gpointer _tmp116_;
		GXmlDomNode* _tmp117_;
		GXmlDomElement* _tmp118_;
		GXmlDomElement* _tmp119_;
		GXmlDomElement* _tmp120_;
		GXmlDomElement* _tmp121_;
		GXmlDomElement* _tmp122_;
		gchar* _tmp123_;
		gchar* _tmp124_;
		gchar* _tmp125_;
		GXmlDomElement* _tmp126_;
		GXmlDomElement* _tmp127_;
		GXmlDomElement* _tmp128_;
		GXmlDomNodeList* _tmp129_;
		GXmlDomNodeList* _tmp130_;
		GXmlDomNodeList* _tmp131_;
		gpointer _tmp132_;
		GXmlDomNode* _tmp133_;
		GXmlDomElement* _tmp134_;
		GXmlDomElement* _tmp135_;
		GXmlDomElement* _tmp136_;
		GXmlDomNodeList* _tmp137_;
		GXmlDomNodeList* _tmp138_;
		GXmlDomNodeList* _tmp139_;
		gpointer _tmp140_;
		GXmlDomNode* _tmp141_;
		GXmlDomNode* _tmp142_;
		GXmlDomNode* _tmp143_;
		GXmlDomNode* _tmp144_;
		GXmlDomElement* _tmp145_;
		GXmlDomElement* _tmp146_;
		GXmlDomElement* _tmp147_;
		GXmlDomNodeList* _tmp148_;
		GXmlDomNodeList* _tmp149_;
		GXmlDomNodeList* _tmp150_;
		gpointer _tmp151_;
		GXmlDomNode* _tmp152_;
		GXmlDomNode* _tmp153_;
		GXmlDomNode* _tmp154_;
		GXmlDomNode* _tmp155_;
		gchar* _tmp156_;
		gchar* _tmp157_;
		gchar* _tmp158_;
		GXmlDomElement* _tmp159_;
		GXmlDomElement* _tmp160_;
		GXmlDomElement* _tmp161_;
		GXmlDomNodeList* _tmp162_;
		GXmlDomNodeList* _tmp163_;
		GXmlDomNodeList* _tmp164_;
		gpointer _tmp165_;
		GXmlDomNode* _tmp166_;
		GXmlDomElement* _tmp167_;
		GXmlDomElement* _tmp168_;
		GXmlDomElement* _tmp169_;
		GXmlDomNodeList* _tmp170_;
		GXmlDomNodeList* _tmp171_;
		GXmlDomNodeList* _tmp172_;
		gpointer _tmp173_;
		GXmlDomNode* _tmp174_;
		GXmlDomElement* _tmp175_;
		GXmlDomElement* _tmp176_;
		GXmlDomElement* _tmp177_;
		GXmlDomNodeList* _tmp178_;
		GXmlDomNodeList* _tmp179_;
		GXmlDomNodeList* _tmp180_;
		gpointer _tmp181_;
		GXmlDomNode* _tmp182_;
		GXmlDomElement* _tmp183_;
		GXmlDomElement* _tmp184_;
		GXmlDomElement* _tmp185_;
		GXmlDomNodeList* _tmp186_;
		GXmlDomNodeList* _tmp187_;
		GXmlDomNodeList* _tmp188_;
		gpointer _tmp189_;
		GXmlDomNode* _tmp190_;
		gchar* _tmp191_;
		gchar* _tmp192_;
		gchar* _tmp193_;
		GXmlDomElement* _tmp194_;
		GXmlDomElement* _tmp195_;
		GXmlDomElement* _tmp196_;
		GXmlDomNodeList* _tmp197_;
		GXmlDomNodeList* _tmp198_;
		GXmlDomNodeList* _tmp199_;
		gpointer _tmp200_;
		GXmlDomNode* _tmp201_;
		GXmlDomElement* _tmp202_;
		GXmlDomElement* _tmp203_;
		GXmlDomElement* _tmp204_;
		GXmlDomElement* _tmp205_;
		GXmlDomElement* _tmp206_;
		GXmlDomElement* _tmp207_;
		GXmlDomElement* _tmp208_;
		GXmlDomElement* _tmp209_;
		GXmlDomNodeList* _tmp210_;
		GXmlDomNodeList* _tmp211_;
		GXmlDomNodeList* _tmp212_;
		gpointer _tmp213_;
		GXmlDomNode* _tmp214_;
		GXmlDomElement* _tmp215_;
		GXmlDomElement* _tmp216_;
		GXmlDomElement* _tmp217_;
		GXmlDomElement* _tmp218_;
		GXmlDomElement* _tmp219_;
		GXmlDomElement* _tmp220_;
		GXmlDomElement* _tmp221_;
		GXmlDomElement* _tmp222_;
		GXmlDomNodeList* _tmp223_;
		GXmlDomNodeList* _tmp224_;
		GXmlDomNodeList* _tmp225_;
		gpointer _tmp226_;
		GXmlDomNode* _tmp227_;
		GXmlDomElement* _tmp228_;
		GXmlDomElement* _tmp229_;
		GXmlDomElement* _tmp230_;
		GXmlDomElement* _tmp231_;
		GXmlDomElement* _tmp232_;
		gchar* _tmp233_;
		gchar* _tmp234_;
		gchar* _tmp235_;
#line 577 "GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<root> <child/> <child/></root>", &_inner_error0_);
#line 577 "GomElementTest.vala"
		doc = _tmp0_;
#line 577 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 6670 "GomElementTest.c"
			goto __catch136_g_error;
		}
#line 578 "GomElementTest.vala"
		_tmp1_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 578 "GomElementTest.vala"
		_tmp2_ = _tmp1_;
#line 578 "GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 578 "GomElementTest.vala"
		_vala_assert (_tmp3_ != NULL, "doc.document_element != null");
#line 578 "GomElementTest.vala"
		_g_object_unref0 (_tmp3_);
#line 579 "GomElementTest.vala"
		_tmp4_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 579 "GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 579 "GomElementTest.vala"
		_tmp6_ = _tmp5_;
#line 579 "GomElementTest.vala"
		_tmp7_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp6_);
#line 579 "GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 579 "GomElementTest.vala"
		_tmp9_ = _tmp8_;
#line 579 "GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_DOM_NODE), "doc.document_element.parent_node is GXml.DomNode");
#line 579 "GomElementTest.vala"
		_g_object_unref0 (_tmp9_);
#line 579 "GomElementTest.vala"
		_g_object_unref0 (_tmp6_);
#line 580 "GomElementTest.vala"
		_tmp10_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 580 "GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 580 "GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 580 "GomElementTest.vala"
		_tmp13_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp12_);
#line 580 "GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 580 "GomElementTest.vala"
		_tmp15_ = _tmp14_;
#line 580 "GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GXML_TYPE_DOM_DOCUMENT), "doc.document_element.parent_node is GXml.DomDocument");
#line 580 "GomElementTest.vala"
		_g_object_unref0 (_tmp15_);
#line 580 "GomElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 581 "GomElementTest.vala"
		_tmp16_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 581 "GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 581 "GomElementTest.vala"
		_tmp18_ = _tmp17_;
#line 581 "GomElementTest.vala"
		_tmp19_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp18_);
#line 581 "GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 581 "GomElementTest.vala"
		_tmp21_ = _tmp20_;
#line 581 "GomElementTest.vala"
		_tmp22_ = gee_list_get ((GeeList*) _tmp21_, 0);
#line 581 "GomElementTest.vala"
		_tmp23_ = (GXmlDomNode*) _tmp22_;
#line 581 "GomElementTest.vala"
		_vala_assert (_tmp23_ != NULL, "doc.document_element.child_nodes[0] != null");
#line 581 "GomElementTest.vala"
		_g_object_unref0 (_tmp23_);
#line 581 "GomElementTest.vala"
		_g_object_unref0 (_tmp21_);
#line 581 "GomElementTest.vala"
		_g_object_unref0 (_tmp18_);
#line 582 "GomElementTest.vala"
		_tmp24_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 582 "GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 582 "GomElementTest.vala"
		_tmp26_ = _tmp25_;
#line 582 "GomElementTest.vala"
		_tmp27_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp26_);
#line 582 "GomElementTest.vala"
		_tmp28_ = _tmp27_;
#line 582 "GomElementTest.vala"
		_tmp29_ = _tmp28_;
#line 582 "GomElementTest.vala"
		_tmp30_ = gee_list_get ((GeeList*) _tmp29_, 0);
#line 582 "GomElementTest.vala"
		_tmp31_ = (GXmlDomNode*) _tmp30_;
#line 582 "GomElementTest.vala"
		_tmp32_ = gxml_dom_node_get_parent_node (_tmp31_);
#line 582 "GomElementTest.vala"
		_tmp33_ = _tmp32_;
#line 582 "GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 582 "GomElementTest.vala"
		_vala_assert (_tmp34_ != NULL, "doc.document_element.child_nodes[0].parent_node != null");
#line 582 "GomElementTest.vala"
		_g_object_unref0 (_tmp34_);
#line 582 "GomElementTest.vala"
		_g_object_unref0 (_tmp31_);
#line 582 "GomElementTest.vala"
		_g_object_unref0 (_tmp29_);
#line 582 "GomElementTest.vala"
		_g_object_unref0 (_tmp26_);
#line 583 "GomElementTest.vala"
		_tmp35_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 583 "GomElementTest.vala"
		_tmp36_ = _tmp35_;
#line 583 "GomElementTest.vala"
		_tmp37_ = _tmp36_;
#line 583 "GomElementTest.vala"
		_tmp38_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp37_);
#line 583 "GomElementTest.vala"
		_tmp39_ = _tmp38_;
#line 583 "GomElementTest.vala"
		_tmp40_ = _tmp39_;
#line 583 "GomElementTest.vala"
		_tmp41_ = gee_list_get ((GeeList*) _tmp40_, 0);
#line 583 "GomElementTest.vala"
		_tmp42_ = (GXmlDomNode*) _tmp41_;
#line 583 "GomElementTest.vala"
		_tmp43_ = gxml_dom_node_get_parent_node (_tmp42_);
#line 583 "GomElementTest.vala"
		_tmp44_ = _tmp43_;
#line 583 "GomElementTest.vala"
		_tmp45_ = _tmp44_;
#line 583 "GomElementTest.vala"
		_tmp46_ = gxml_dom_node_get_node_name (_tmp45_);
#line 583 "GomElementTest.vala"
		_tmp47_ = _tmp46_;
#line 583 "GomElementTest.vala"
		_tmp48_ = _tmp47_;
#line 583 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp48_, "root") == 0, "doc.document_element.child_nodes[0].parent_node.node_name == \"root\"");
#line 583 "GomElementTest.vala"
		_g_free0 (_tmp48_);
#line 583 "GomElementTest.vala"
		_g_object_unref0 (_tmp45_);
#line 583 "GomElementTest.vala"
		_g_object_unref0 (_tmp42_);
#line 583 "GomElementTest.vala"
		_g_object_unref0 (_tmp40_);
#line 583 "GomElementTest.vala"
		_g_object_unref0 (_tmp37_);
#line 584 "GomElementTest.vala"
		_tmp49_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 584 "GomElementTest.vala"
		_tmp50_ = _tmp49_;
#line 584 "GomElementTest.vala"
		_tmp51_ = _tmp50_;
#line 584 "GomElementTest.vala"
		_tmp52_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp51_);
#line 584 "GomElementTest.vala"
		_tmp53_ = _tmp52_;
#line 584 "GomElementTest.vala"
		_tmp54_ = _tmp53_;
#line 584 "GomElementTest.vala"
		_tmp55_ = gee_list_get ((GeeList*) _tmp54_, 0);
#line 584 "GomElementTest.vala"
		_tmp56_ = (GXmlDomNode*) _tmp55_;
#line 584 "GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp56_, GXML_TYPE_DOM_TEXT), "doc.document_element.child_nodes[0] is DomText");
#line 584 "GomElementTest.vala"
		_g_object_unref0 (_tmp56_);
#line 584 "GomElementTest.vala"
		_g_object_unref0 (_tmp54_);
#line 584 "GomElementTest.vala"
		_g_object_unref0 (_tmp51_);
#line 585 "GomElementTest.vala"
		_tmp57_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 585 "GomElementTest.vala"
		_tmp58_ = _tmp57_;
#line 585 "GomElementTest.vala"
		_tmp59_ = _tmp58_;
#line 585 "GomElementTest.vala"
		_tmp60_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp59_);
#line 585 "GomElementTest.vala"
		_tmp61_ = _tmp60_;
#line 585 "GomElementTest.vala"
		_tmp62_ = _tmp61_;
#line 585 "GomElementTest.vala"
		_tmp63_ = gee_list_get ((GeeList*) _tmp62_, 1);
#line 585 "GomElementTest.vala"
		_tmp64_ = (GXmlDomNode*) _tmp63_;
#line 585 "GomElementTest.vala"
		_vala_assert (_tmp64_ != NULL, "doc.document_element.child_nodes[1] != null");
#line 585 "GomElementTest.vala"
		_g_object_unref0 (_tmp64_);
#line 585 "GomElementTest.vala"
		_g_object_unref0 (_tmp62_);
#line 585 "GomElementTest.vala"
		_g_object_unref0 (_tmp59_);
#line 586 "GomElementTest.vala"
		_tmp65_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 586 "GomElementTest.vala"
		_tmp66_ = _tmp65_;
#line 586 "GomElementTest.vala"
		_tmp67_ = _tmp66_;
#line 586 "GomElementTest.vala"
		_tmp68_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp67_);
#line 586 "GomElementTest.vala"
		_tmp69_ = _tmp68_;
#line 586 "GomElementTest.vala"
		_tmp70_ = _tmp69_;
#line 586 "GomElementTest.vala"
		_tmp71_ = gee_list_get ((GeeList*) _tmp70_, 1);
#line 586 "GomElementTest.vala"
		_tmp72_ = (GXmlDomNode*) _tmp71_;
#line 586 "GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp72_, GXML_TYPE_DOM_ELEMENT), "doc.document_element.child_nodes[1] is DomElement");
#line 586 "GomElementTest.vala"
		_g_object_unref0 (_tmp72_);
#line 586 "GomElementTest.vala"
		_g_object_unref0 (_tmp70_);
#line 586 "GomElementTest.vala"
		_g_object_unref0 (_tmp67_);
#line 587 "GomElementTest.vala"
		_tmp73_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 587 "GomElementTest.vala"
		_tmp74_ = _tmp73_;
#line 587 "GomElementTest.vala"
		_tmp75_ = _tmp74_;
#line 587 "GomElementTest.vala"
		_tmp76_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp75_);
#line 587 "GomElementTest.vala"
		_tmp77_ = _tmp76_;
#line 587 "GomElementTest.vala"
		_tmp78_ = _tmp77_;
#line 587 "GomElementTest.vala"
		_tmp79_ = gee_list_get ((GeeList*) _tmp78_, 1);
#line 587 "GomElementTest.vala"
		_tmp80_ = (GXmlDomNode*) _tmp79_;
#line 587 "GomElementTest.vala"
		_tmp81_ = gxml_dom_node_get_node_name (_tmp80_);
#line 587 "GomElementTest.vala"
		_tmp82_ = _tmp81_;
#line 587 "GomElementTest.vala"
		_tmp83_ = _tmp82_;
#line 587 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp83_, "child") == 0, "doc.document_element.child_nodes[1].node_name == \"child\"");
#line 587 "GomElementTest.vala"
		_g_free0 (_tmp83_);
#line 587 "GomElementTest.vala"
		_g_object_unref0 (_tmp80_);
#line 587 "GomElementTest.vala"
		_g_object_unref0 (_tmp78_);
#line 587 "GomElementTest.vala"
		_g_object_unref0 (_tmp75_);
#line 588 "GomElementTest.vala"
		_tmp84_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 588 "GomElementTest.vala"
		_tmp85_ = _tmp84_;
#line 588 "GomElementTest.vala"
		_tmp86_ = _tmp85_;
#line 588 "GomElementTest.vala"
		_tmp87_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp86_);
#line 588 "GomElementTest.vala"
		_tmp88_ = _tmp87_;
#line 588 "GomElementTest.vala"
		_tmp89_ = _tmp88_;
#line 588 "GomElementTest.vala"
		_tmp90_ = gee_list_get ((GeeList*) _tmp89_, 1);
#line 588 "GomElementTest.vala"
		_tmp91_ = (GXmlDomNode*) _tmp90_;
#line 588 "GomElementTest.vala"
		_tmp92_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp91_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp91_) : NULL;
#line 588 "GomElementTest.vala"
		if (_tmp92_ == NULL) {
#line 588 "GomElementTest.vala"
			_g_object_unref0 (_tmp91_);
#line 6941 "GomElementTest.c"
		}
#line 588 "GomElementTest.vala"
		_tmp93_ = _tmp92_;
#line 588 "GomElementTest.vala"
		_tmp94_ = gxml_dom_non_document_type_child_node_get_next_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp93_);
#line 588 "GomElementTest.vala"
		_tmp95_ = _tmp94_;
#line 588 "GomElementTest.vala"
		_tmp96_ = _tmp95_;
#line 588 "GomElementTest.vala"
		_vala_assert (_tmp96_ != NULL, "(doc.document_element.child_nodes[1] as DomElement).next_element_sibling != null");
#line 588 "GomElementTest.vala"
		_g_object_unref0 (_tmp96_);
#line 588 "GomElementTest.vala"
		_g_object_unref0 (_tmp93_);
#line 588 "GomElementTest.vala"
		_g_object_unref0 (_tmp89_);
#line 588 "GomElementTest.vala"
		_g_object_unref0 (_tmp86_);
#line 589 "GomElementTest.vala"
		_tmp97_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 589 "GomElementTest.vala"
		_tmp98_ = _tmp97_;
#line 589 "GomElementTest.vala"
		_tmp99_ = _tmp98_;
#line 589 "GomElementTest.vala"
		_tmp100_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp99_);
#line 589 "GomElementTest.vala"
		_tmp101_ = _tmp100_;
#line 589 "GomElementTest.vala"
		_tmp102_ = _tmp101_;
#line 589 "GomElementTest.vala"
		_tmp103_ = gee_list_get ((GeeList*) _tmp102_, 1);
#line 589 "GomElementTest.vala"
		_tmp104_ = (GXmlDomNode*) _tmp103_;
#line 589 "GomElementTest.vala"
		_tmp105_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp104_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp104_) : NULL;
#line 589 "GomElementTest.vala"
		if (_tmp105_ == NULL) {
#line 589 "GomElementTest.vala"
			_g_object_unref0 (_tmp104_);
#line 6983 "GomElementTest.c"
		}
#line 589 "GomElementTest.vala"
		_tmp106_ = _tmp105_;
#line 589 "GomElementTest.vala"
		_tmp107_ = gxml_dom_non_document_type_child_node_get_next_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp106_);
#line 589 "GomElementTest.vala"
		_tmp108_ = _tmp107_;
#line 589 "GomElementTest.vala"
		_tmp109_ = _tmp108_;
#line 589 "GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp109_, GXML_TYPE_DOM_ELEMENT), "(doc.document_element.child_nodes[1] as DomElement).next_element_sibling is DomElement");
#line 589 "GomElementTest.vala"
		_g_object_unref0 (_tmp109_);
#line 589 "GomElementTest.vala"
		_g_object_unref0 (_tmp106_);
#line 589 "GomElementTest.vala"
		_g_object_unref0 (_tmp102_);
#line 589 "GomElementTest.vala"
		_g_object_unref0 (_tmp99_);
#line 590 "GomElementTest.vala"
		_tmp110_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 590 "GomElementTest.vala"
		_tmp111_ = _tmp110_;
#line 590 "GomElementTest.vala"
		_tmp112_ = _tmp111_;
#line 590 "GomElementTest.vala"
		_tmp113_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp112_);
#line 590 "GomElementTest.vala"
		_tmp114_ = _tmp113_;
#line 590 "GomElementTest.vala"
		_tmp115_ = _tmp114_;
#line 590 "GomElementTest.vala"
		_tmp116_ = gee_list_get ((GeeList*) _tmp115_, 1);
#line 590 "GomElementTest.vala"
		_tmp117_ = (GXmlDomNode*) _tmp116_;
#line 590 "GomElementTest.vala"
		_tmp118_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp117_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp117_) : NULL;
#line 590 "GomElementTest.vala"
		if (_tmp118_ == NULL) {
#line 590 "GomElementTest.vala"
			_g_object_unref0 (_tmp117_);
#line 7025 "GomElementTest.c"
		}
#line 590 "GomElementTest.vala"
		_tmp119_ = _tmp118_;
#line 590 "GomElementTest.vala"
		_tmp120_ = gxml_dom_non_document_type_child_node_get_next_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp119_);
#line 590 "GomElementTest.vala"
		_tmp121_ = _tmp120_;
#line 590 "GomElementTest.vala"
		_tmp122_ = _tmp121_;
#line 590 "GomElementTest.vala"
		_tmp123_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp122_);
#line 590 "GomElementTest.vala"
		_tmp124_ = _tmp123_;
#line 590 "GomElementTest.vala"
		_tmp125_ = _tmp124_;
#line 590 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp125_, "child") == 0, "(doc.document_element.child_nodes[1] as DomElement).next_element_sibling.node_name == \"child\"");
#line 590 "GomElementTest.vala"
		_g_free0 (_tmp125_);
#line 590 "GomElementTest.vala"
		_g_object_unref0 (_tmp122_);
#line 590 "GomElementTest.vala"
		_g_object_unref0 (_tmp119_);
#line 590 "GomElementTest.vala"
		_g_object_unref0 (_tmp115_);
#line 590 "GomElementTest.vala"
		_g_object_unref0 (_tmp112_);
#line 591 "GomElementTest.vala"
		_tmp126_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 591 "GomElementTest.vala"
		_tmp127_ = _tmp126_;
#line 591 "GomElementTest.vala"
		_tmp128_ = _tmp127_;
#line 591 "GomElementTest.vala"
		_tmp129_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp128_);
#line 591 "GomElementTest.vala"
		_tmp130_ = _tmp129_;
#line 591 "GomElementTest.vala"
		_tmp131_ = _tmp130_;
#line 591 "GomElementTest.vala"
		_tmp132_ = gee_list_get ((GeeList*) _tmp131_, 2);
#line 591 "GomElementTest.vala"
		_tmp133_ = (GXmlDomNode*) _tmp132_;
#line 591 "GomElementTest.vala"
		_vala_assert (_tmp133_ != NULL, "doc.document_element.child_nodes[2] != null");
#line 591 "GomElementTest.vala"
		_g_object_unref0 (_tmp133_);
#line 591 "GomElementTest.vala"
		_g_object_unref0 (_tmp131_);
#line 591 "GomElementTest.vala"
		_g_object_unref0 (_tmp128_);
#line 592 "GomElementTest.vala"
		_tmp134_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 592 "GomElementTest.vala"
		_tmp135_ = _tmp134_;
#line 592 "GomElementTest.vala"
		_tmp136_ = _tmp135_;
#line 592 "GomElementTest.vala"
		_tmp137_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp136_);
#line 592 "GomElementTest.vala"
		_tmp138_ = _tmp137_;
#line 592 "GomElementTest.vala"
		_tmp139_ = _tmp138_;
#line 592 "GomElementTest.vala"
		_tmp140_ = gee_list_get ((GeeList*) _tmp139_, 2);
#line 592 "GomElementTest.vala"
		_tmp141_ = (GXmlDomNode*) _tmp140_;
#line 592 "GomElementTest.vala"
		_tmp142_ = gxml_dom_node_get_parent_node (_tmp141_);
#line 592 "GomElementTest.vala"
		_tmp143_ = _tmp142_;
#line 592 "GomElementTest.vala"
		_tmp144_ = _tmp143_;
#line 592 "GomElementTest.vala"
		_vala_assert (_tmp144_ != NULL, "doc.document_element.child_nodes[2].parent_node != null");
#line 592 "GomElementTest.vala"
		_g_object_unref0 (_tmp144_);
#line 592 "GomElementTest.vala"
		_g_object_unref0 (_tmp141_);
#line 592 "GomElementTest.vala"
		_g_object_unref0 (_tmp139_);
#line 592 "GomElementTest.vala"
		_g_object_unref0 (_tmp136_);
#line 593 "GomElementTest.vala"
		_tmp145_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 593 "GomElementTest.vala"
		_tmp146_ = _tmp145_;
#line 593 "GomElementTest.vala"
		_tmp147_ = _tmp146_;
#line 593 "GomElementTest.vala"
		_tmp148_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp147_);
#line 593 "GomElementTest.vala"
		_tmp149_ = _tmp148_;
#line 593 "GomElementTest.vala"
		_tmp150_ = _tmp149_;
#line 593 "GomElementTest.vala"
		_tmp151_ = gee_list_get ((GeeList*) _tmp150_, 2);
#line 593 "GomElementTest.vala"
		_tmp152_ = (GXmlDomNode*) _tmp151_;
#line 593 "GomElementTest.vala"
		_tmp153_ = gxml_dom_node_get_parent_node (_tmp152_);
#line 593 "GomElementTest.vala"
		_tmp154_ = _tmp153_;
#line 593 "GomElementTest.vala"
		_tmp155_ = _tmp154_;
#line 593 "GomElementTest.vala"
		_tmp156_ = gxml_dom_node_get_node_name (_tmp155_);
#line 593 "GomElementTest.vala"
		_tmp157_ = _tmp156_;
#line 593 "GomElementTest.vala"
		_tmp158_ = _tmp157_;
#line 593 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp158_, "root") == 0, "doc.document_element.child_nodes[2].parent_node.node_name == \"root\"");
#line 593 "GomElementTest.vala"
		_g_free0 (_tmp158_);
#line 593 "GomElementTest.vala"
		_g_object_unref0 (_tmp155_);
#line 593 "GomElementTest.vala"
		_g_object_unref0 (_tmp152_);
#line 593 "GomElementTest.vala"
		_g_object_unref0 (_tmp150_);
#line 593 "GomElementTest.vala"
		_g_object_unref0 (_tmp147_);
#line 594 "GomElementTest.vala"
		_tmp159_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 594 "GomElementTest.vala"
		_tmp160_ = _tmp159_;
#line 594 "GomElementTest.vala"
		_tmp161_ = _tmp160_;
#line 594 "GomElementTest.vala"
		_tmp162_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp161_);
#line 594 "GomElementTest.vala"
		_tmp163_ = _tmp162_;
#line 594 "GomElementTest.vala"
		_tmp164_ = _tmp163_;
#line 594 "GomElementTest.vala"
		_tmp165_ = gee_list_get ((GeeList*) _tmp164_, 2);
#line 594 "GomElementTest.vala"
		_tmp166_ = (GXmlDomNode*) _tmp165_;
#line 594 "GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp166_, GXML_TYPE_DOM_TEXT), "doc.document_element.child_nodes[2] is DomText");
#line 594 "GomElementTest.vala"
		_g_object_unref0 (_tmp166_);
#line 594 "GomElementTest.vala"
		_g_object_unref0 (_tmp164_);
#line 594 "GomElementTest.vala"
		_g_object_unref0 (_tmp161_);
#line 595 "GomElementTest.vala"
		_tmp167_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 595 "GomElementTest.vala"
		_tmp168_ = _tmp167_;
#line 595 "GomElementTest.vala"
		_tmp169_ = _tmp168_;
#line 595 "GomElementTest.vala"
		_tmp170_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp169_);
#line 595 "GomElementTest.vala"
		_tmp171_ = _tmp170_;
#line 595 "GomElementTest.vala"
		_tmp172_ = _tmp171_;
#line 595 "GomElementTest.vala"
		_tmp173_ = gee_list_get ((GeeList*) _tmp172_, 3);
#line 595 "GomElementTest.vala"
		_tmp174_ = (GXmlDomNode*) _tmp173_;
#line 595 "GomElementTest.vala"
		_vala_assert (_tmp174_ != NULL, "doc.document_element.child_nodes[3] != null");
#line 595 "GomElementTest.vala"
		_g_object_unref0 (_tmp174_);
#line 595 "GomElementTest.vala"
		_g_object_unref0 (_tmp172_);
#line 595 "GomElementTest.vala"
		_g_object_unref0 (_tmp169_);
#line 596 "GomElementTest.vala"
		_tmp175_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 596 "GomElementTest.vala"
		_tmp176_ = _tmp175_;
#line 596 "GomElementTest.vala"
		_tmp177_ = _tmp176_;
#line 596 "GomElementTest.vala"
		_tmp178_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp177_);
#line 596 "GomElementTest.vala"
		_tmp179_ = _tmp178_;
#line 596 "GomElementTest.vala"
		_tmp180_ = _tmp179_;
#line 596 "GomElementTest.vala"
		_tmp181_ = gee_list_get ((GeeList*) _tmp180_, 3);
#line 596 "GomElementTest.vala"
		_tmp182_ = (GXmlDomNode*) _tmp181_;
#line 596 "GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp182_, GXML_TYPE_DOM_ELEMENT), "doc.document_element.child_nodes[3] is DomElement");
#line 596 "GomElementTest.vala"
		_g_object_unref0 (_tmp182_);
#line 596 "GomElementTest.vala"
		_g_object_unref0 (_tmp180_);
#line 596 "GomElementTest.vala"
		_g_object_unref0 (_tmp177_);
#line 597 "GomElementTest.vala"
		_tmp183_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 597 "GomElementTest.vala"
		_tmp184_ = _tmp183_;
#line 597 "GomElementTest.vala"
		_tmp185_ = _tmp184_;
#line 597 "GomElementTest.vala"
		_tmp186_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp185_);
#line 597 "GomElementTest.vala"
		_tmp187_ = _tmp186_;
#line 597 "GomElementTest.vala"
		_tmp188_ = _tmp187_;
#line 597 "GomElementTest.vala"
		_tmp189_ = gee_list_get ((GeeList*) _tmp188_, 3);
#line 597 "GomElementTest.vala"
		_tmp190_ = (GXmlDomNode*) _tmp189_;
#line 597 "GomElementTest.vala"
		_tmp191_ = gxml_dom_node_get_node_name (_tmp190_);
#line 597 "GomElementTest.vala"
		_tmp192_ = _tmp191_;
#line 597 "GomElementTest.vala"
		_tmp193_ = _tmp192_;
#line 597 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp193_, "child") == 0, "doc.document_element.child_nodes[3].node_name == \"child\"");
#line 597 "GomElementTest.vala"
		_g_free0 (_tmp193_);
#line 597 "GomElementTest.vala"
		_g_object_unref0 (_tmp190_);
#line 597 "GomElementTest.vala"
		_g_object_unref0 (_tmp188_);
#line 597 "GomElementTest.vala"
		_g_object_unref0 (_tmp185_);
#line 598 "GomElementTest.vala"
		_tmp194_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 598 "GomElementTest.vala"
		_tmp195_ = _tmp194_;
#line 598 "GomElementTest.vala"
		_tmp196_ = _tmp195_;
#line 598 "GomElementTest.vala"
		_tmp197_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp196_);
#line 598 "GomElementTest.vala"
		_tmp198_ = _tmp197_;
#line 598 "GomElementTest.vala"
		_tmp199_ = _tmp198_;
#line 598 "GomElementTest.vala"
		_tmp200_ = gee_list_get ((GeeList*) _tmp199_, 3);
#line 598 "GomElementTest.vala"
		_tmp201_ = (GXmlDomNode*) _tmp200_;
#line 598 "GomElementTest.vala"
		_tmp202_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp201_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp201_) : NULL;
#line 598 "GomElementTest.vala"
		if (_tmp202_ == NULL) {
#line 598 "GomElementTest.vala"
			_g_object_unref0 (_tmp201_);
#line 7275 "GomElementTest.c"
		}
#line 598 "GomElementTest.vala"
		_tmp203_ = _tmp202_;
#line 598 "GomElementTest.vala"
		_tmp204_ = gxml_dom_non_document_type_child_node_get_previous_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp203_);
#line 598 "GomElementTest.vala"
		_tmp205_ = _tmp204_;
#line 598 "GomElementTest.vala"
		_tmp206_ = _tmp205_;
#line 598 "GomElementTest.vala"
		_vala_assert (_tmp206_ != NULL, "(doc.document_element.child_nodes[3] as DomElement).previous_element_sibling != null");
#line 598 "GomElementTest.vala"
		_g_object_unref0 (_tmp206_);
#line 598 "GomElementTest.vala"
		_g_object_unref0 (_tmp203_);
#line 598 "GomElementTest.vala"
		_g_object_unref0 (_tmp199_);
#line 598 "GomElementTest.vala"
		_g_object_unref0 (_tmp196_);
#line 599 "GomElementTest.vala"
		_tmp207_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 599 "GomElementTest.vala"
		_tmp208_ = _tmp207_;
#line 599 "GomElementTest.vala"
		_tmp209_ = _tmp208_;
#line 599 "GomElementTest.vala"
		_tmp210_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp209_);
#line 599 "GomElementTest.vala"
		_tmp211_ = _tmp210_;
#line 599 "GomElementTest.vala"
		_tmp212_ = _tmp211_;
#line 599 "GomElementTest.vala"
		_tmp213_ = gee_list_get ((GeeList*) _tmp212_, 3);
#line 599 "GomElementTest.vala"
		_tmp214_ = (GXmlDomNode*) _tmp213_;
#line 599 "GomElementTest.vala"
		_tmp215_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp214_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp214_) : NULL;
#line 599 "GomElementTest.vala"
		if (_tmp215_ == NULL) {
#line 599 "GomElementTest.vala"
			_g_object_unref0 (_tmp214_);
#line 7317 "GomElementTest.c"
		}
#line 599 "GomElementTest.vala"
		_tmp216_ = _tmp215_;
#line 599 "GomElementTest.vala"
		_tmp217_ = gxml_dom_non_document_type_child_node_get_previous_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp216_);
#line 599 "GomElementTest.vala"
		_tmp218_ = _tmp217_;
#line 599 "GomElementTest.vala"
		_tmp219_ = _tmp218_;
#line 599 "GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp219_, GXML_TYPE_DOM_ELEMENT), "(doc.document_element.child_nodes[3] as DomElement).previous_element_sibling is DomElement");
#line 599 "GomElementTest.vala"
		_g_object_unref0 (_tmp219_);
#line 599 "GomElementTest.vala"
		_g_object_unref0 (_tmp216_);
#line 599 "GomElementTest.vala"
		_g_object_unref0 (_tmp212_);
#line 599 "GomElementTest.vala"
		_g_object_unref0 (_tmp209_);
#line 600 "GomElementTest.vala"
		_tmp220_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 600 "GomElementTest.vala"
		_tmp221_ = _tmp220_;
#line 600 "GomElementTest.vala"
		_tmp222_ = _tmp221_;
#line 600 "GomElementTest.vala"
		_tmp223_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp222_);
#line 600 "GomElementTest.vala"
		_tmp224_ = _tmp223_;
#line 600 "GomElementTest.vala"
		_tmp225_ = _tmp224_;
#line 600 "GomElementTest.vala"
		_tmp226_ = gee_list_get ((GeeList*) _tmp225_, 3);
#line 600 "GomElementTest.vala"
		_tmp227_ = (GXmlDomNode*) _tmp226_;
#line 600 "GomElementTest.vala"
		_tmp228_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp227_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp227_) : NULL;
#line 600 "GomElementTest.vala"
		if (_tmp228_ == NULL) {
#line 600 "GomElementTest.vala"
			_g_object_unref0 (_tmp227_);
#line 7359 "GomElementTest.c"
		}
#line 600 "GomElementTest.vala"
		_tmp229_ = _tmp228_;
#line 600 "GomElementTest.vala"
		_tmp230_ = gxml_dom_non_document_type_child_node_get_previous_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp229_);
#line 600 "GomElementTest.vala"
		_tmp231_ = _tmp230_;
#line 600 "GomElementTest.vala"
		_tmp232_ = _tmp231_;
#line 600 "GomElementTest.vala"
		_tmp233_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp232_);
#line 600 "GomElementTest.vala"
		_tmp234_ = _tmp233_;
#line 600 "GomElementTest.vala"
		_tmp235_ = _tmp234_;
#line 600 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp235_, "child") == 0, "(doc.document_element.child_nodes[3] as DomElement).previous_element_sibling.node_name == \"child\"");
#line 600 "GomElementTest.vala"
		_g_free0 (_tmp235_);
#line 600 "GomElementTest.vala"
		_g_object_unref0 (_tmp232_);
#line 600 "GomElementTest.vala"
		_g_object_unref0 (_tmp229_);
#line 600 "GomElementTest.vala"
		_g_object_unref0 (_tmp225_);
#line 600 "GomElementTest.vala"
		_g_object_unref0 (_tmp222_);
#line 576 "GomElementTest.vala"
		_g_object_unref0 (doc);
#line 7389 "GomElementTest.c"
	}
	goto __finally136;
	__catch136_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp236_;
#line 576 "GomElementTest.vala"
		e = _inner_error0_;
#line 576 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 602 "GomElementTest.vala"
		_tmp236_ = e->message;
#line 602 "GomElementTest.vala"
		g_test_message ("%s", _tmp236_);
#line 603 "GomElementTest.vala"
		g_assert_not_reached ();
#line 576 "GomElementTest.vala"
		_g_error_free0 (e);
#line 7408 "GomElementTest.c"
	}
	__finally136:
#line 576 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 576 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 576 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 576 "GomElementTest.vala"
		return;
#line 7419 "GomElementTest.c"
	}
}

static void
___lambda112__gtest_func (void)
{
#line 575 "GomElementTest.vala"
	__lambda112_ ();
#line 7428 "GomElementTest.c"
}

static void
__lambda113_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp0_;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp1_;
		GXmlDomElement* _tmp2_;
		GXmlGomDocument* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlDomNode* _tmp5_;
		GXmlDomNode* _tmp6_;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp7_;
		GXmlDomElement* _tmp8_;
		GXmlDomElement* _tmp9_;
		GXmlDomElement* _tmp10_;
		GXmlDomElement* _tmp11_;
		GXmlDomNode* _tmp12_;
		GXmlDomNode* _tmp13_;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp14_;
		GXmlDomElement* _tmp15_;
		GXmlDomElement* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlDomElement* _tmp18_;
		GXmlDomNode* _tmp19_;
		GXmlDomNode* _tmp20_;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp21_;
		GXmlDomElement* _tmp22_;
		GXmlDomElement* _tmp23_;
		GXmlDomElement* _tmp24_;
		GXmlDomElement* _tmp25_;
		GXmlDomNode* _tmp26_;
		GXmlDomNode* _tmp27_;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp28_;
		GXmlDomElement* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomElement* _tmp31_;
		GXmlDomElement* _tmp32_;
		GXmlDomNode* _tmp33_;
		GXmlDomNode* _tmp34_;
		GXmlDomElement* c5 = NULL;
		GXmlGomDocument* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomElement* _tmp37_;
		GXmlDomElement* _tmp38_;
		GXmlDomNode* _tmp39_;
		GXmlDomNode* _tmp40_;
		GXmlDomElement* n1 = NULL;
		GXmlDomElement* _tmp41_;
		GXmlDomElement* _tmp42_;
		GXmlDomElement* _tmp43_;
		GXmlDomElement* _tmp44_;
		gchar* _tmp45_;
		gchar* _tmp46_;
		GXmlDomElement* n2 = NULL;
		GXmlDomElement* _tmp47_;
		GXmlDomElement* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		gchar* _tmp51_;
		gchar* _tmp52_;
		GXmlDomElement* n3 = NULL;
		GXmlDomElement* _tmp53_;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomElement* _tmp56_;
		gchar* _tmp57_;
		gchar* _tmp58_;
		GXmlDomElement* n4 = NULL;
		GXmlDomElement* _tmp59_;
		GXmlDomElement* _tmp60_;
		GXmlDomElement* _tmp61_;
		GXmlDomElement* _tmp62_;
		gchar* _tmp63_;
		gchar* _tmp64_;
		GXmlDomNodeList* l1 = NULL;
		GXmlDomElement* _tmp65_;
		GXmlDomNodeList* _tmp66_;
		GXmlDomNodeList* _tmp67_;
		GXmlDomNodeList* _tmp68_;
		gint _tmp69_;
		gint _tmp70_;
		gchar* _tmp71_;
		gchar* _tmp72_;
		GXmlDomNodeList* _tmp73_;
		gint _tmp74_;
		gint _tmp75_;
		GXmlDomNodeList* _tmp76_;
		GXmlDomNode* _tmp77_;
		GXmlDomNode* _tmp78_;
		gchar* _tmp79_;
		gchar* _tmp80_;
		gchar* _tmp81_;
		GXmlDomNodeList* l2 = NULL;
		GXmlDomElement* _tmp82_;
		GXmlDomNodeList* _tmp83_;
		GXmlDomNodeList* _tmp84_;
		GXmlDomNodeList* _tmp85_;
		gint _tmp86_;
		gint _tmp87_;
		GXmlDomNodeList* _tmp88_;
		GXmlDomNode* _tmp89_;
		GXmlDomNode* _tmp90_;
		gchar* _tmp91_;
		gchar* _tmp92_;
		gchar* _tmp93_;
		GXmlDomNodeList* l3 = NULL;
		GXmlDomElement* _tmp94_;
		GXmlDomNodeList* _tmp95_;
		GXmlDomNodeList* _tmp96_;
		GXmlDomNodeList* _tmp97_;
		gint _tmp98_;
		gint _tmp99_;
		GXmlDomNodeList* _tmp100_;
		GXmlDomNode* _tmp101_;
		GXmlDomNode* _tmp102_;
		gchar* _tmp103_;
		gchar* _tmp104_;
		gchar* _tmp105_;
		GXmlDomElement* c6 = NULL;
		GXmlGomDocument* _tmp106_;
		GXmlDomElement* _tmp107_;
		GXmlDomElement* _tmp108_;
		GXmlDomElement* _tmp109_;
		GXmlDomElement* _tmp110_;
		GXmlDomNode* _tmp111_;
		GXmlDomNode* _tmp112_;
		GXmlDomElement* c7 = NULL;
		GXmlGomDocument* _tmp113_;
		GXmlDomElement* _tmp114_;
		GXmlDomElement* _tmp115_;
		GXmlDomElement* _tmp116_;
		GXmlDomElement* _tmp117_;
		GXmlDomNode* _tmp118_;
		GXmlDomNode* _tmp119_;
		GXmlDomNodeList* l4 = NULL;
		GXmlDomElement* _tmp120_;
		GXmlDomNodeList* _tmp121_;
		GXmlDomNodeList* _tmp122_;
		GXmlDomNodeList* _tmp123_;
		gint _tmp124_;
		gint _tmp125_;
		GXmlDomNodeList* _tmp126_;
		GXmlDomNode* _tmp127_;
		GXmlDomNode* _tmp128_;
		gchar* _tmp129_;
		gchar* _tmp130_;
		gchar* _tmp131_;
#line 608 "GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new ();
#line 608 "GomElementTest.vala"
		d = _tmp0_;
#line 609 "GomElementTest.vala"
		_tmp1_ = d;
#line 609 "GomElementTest.vala"
		_tmp2_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp1_, "root", &_inner_error0_);
#line 609 "GomElementTest.vala"
		r = _tmp2_;
#line 609 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 609 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 7599 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 610 "GomElementTest.vala"
		_tmp3_ = d;
#line 610 "GomElementTest.vala"
		_tmp4_ = r;
#line 610 "GomElementTest.vala"
		_tmp5_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp3_, (GXmlDomNode*) _tmp4_, &_inner_error0_);
#line 610 "GomElementTest.vala"
		_tmp6_ = _tmp5_;
#line 610 "GomElementTest.vala"
		_g_object_unref0 (_tmp6_);
#line 610 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 610 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 610 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 7618 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 611 "GomElementTest.vala"
		_tmp7_ = d;
#line 611 "GomElementTest.vala"
		_tmp8_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp7_, "child", &_inner_error0_);
#line 611 "GomElementTest.vala"
		c1 = _tmp8_;
#line 611 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 611 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 611 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 7633 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 612 "GomElementTest.vala"
		_tmp9_ = c1;
#line 612 "GomElementTest.vala"
		gxml_dom_element_set_attribute (_tmp9_, "class", "error", &_inner_error0_);
#line 612 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 612 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 612 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 612 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 7648 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 613 "GomElementTest.vala"
		_tmp10_ = r;
#line 613 "GomElementTest.vala"
		_tmp11_ = c1;
#line 613 "GomElementTest.vala"
		_tmp12_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp10_, (GXmlDomNode*) _tmp11_, &_inner_error0_);
#line 613 "GomElementTest.vala"
		_tmp13_ = _tmp12_;
#line 613 "GomElementTest.vala"
		_g_object_unref0 (_tmp13_);
#line 613 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 613 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 613 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 613 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 7669 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 614 "GomElementTest.vala"
		_tmp14_ = d;
#line 614 "GomElementTest.vala"
		_tmp15_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp14_, "child", &_inner_error0_);
#line 614 "GomElementTest.vala"
		c2 = _tmp15_;
#line 614 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 614 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 614 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 614 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 7686 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 615 "GomElementTest.vala"
		_tmp16_ = c2;
#line 615 "GomElementTest.vala"
		gxml_dom_element_set_attribute (_tmp16_, "class", "warning", &_inner_error0_);
#line 615 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 615 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 615 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 615 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 615 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 7703 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 616 "GomElementTest.vala"
		_tmp17_ = r;
#line 616 "GomElementTest.vala"
		_tmp18_ = c2;
#line 616 "GomElementTest.vala"
		_tmp19_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp17_, (GXmlDomNode*) _tmp18_, &_inner_error0_);
#line 616 "GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 616 "GomElementTest.vala"
		_g_object_unref0 (_tmp20_);
#line 616 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 616 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 616 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 616 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 616 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 7726 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 617 "GomElementTest.vala"
		_tmp21_ = d;
#line 617 "GomElementTest.vala"
		_tmp22_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp21_, "child", &_inner_error0_);
#line 617 "GomElementTest.vala"
		c3 = _tmp22_;
#line 617 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 617 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 617 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 617 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 617 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 7745 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 618 "GomElementTest.vala"
		_tmp23_ = c3;
#line 618 "GomElementTest.vala"
		gxml_dom_element_set_attribute (_tmp23_, "class", "error warning", &_inner_error0_);
#line 618 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 618 "GomElementTest.vala"
			_g_object_unref0 (c3);
#line 618 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 618 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 618 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 618 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 7764 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 619 "GomElementTest.vala"
		_tmp24_ = r;
#line 619 "GomElementTest.vala"
		_tmp25_ = c3;
#line 619 "GomElementTest.vala"
		_tmp26_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp24_, (GXmlDomNode*) _tmp25_, &_inner_error0_);
#line 619 "GomElementTest.vala"
		_tmp27_ = _tmp26_;
#line 619 "GomElementTest.vala"
		_g_object_unref0 (_tmp27_);
#line 619 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 619 "GomElementTest.vala"
			_g_object_unref0 (c3);
#line 619 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 619 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 619 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 619 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 7789 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 620 "GomElementTest.vala"
		_tmp28_ = d;
#line 620 "GomElementTest.vala"
		_tmp29_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp28_, "child", &_inner_error0_);
#line 620 "GomElementTest.vala"
		c4 = _tmp29_;
#line 620 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 620 "GomElementTest.vala"
			_g_object_unref0 (c3);
#line 620 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 620 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 620 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 620 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 7810 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 621 "GomElementTest.vala"
		_tmp30_ = c4;
#line 621 "GomElementTest.vala"
		gxml_dom_element_set_attribute (_tmp30_, "class", "error calc", &_inner_error0_);
#line 621 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 621 "GomElementTest.vala"
			_g_object_unref0 (c4);
#line 621 "GomElementTest.vala"
			_g_object_unref0 (c3);
#line 621 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 621 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 621 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 621 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 7831 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 622 "GomElementTest.vala"
		_tmp31_ = r;
#line 622 "GomElementTest.vala"
		_tmp32_ = c4;
#line 622 "GomElementTest.vala"
		_tmp33_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp31_, (GXmlDomNode*) _tmp32_, &_inner_error0_);
#line 622 "GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 622 "GomElementTest.vala"
		_g_object_unref0 (_tmp34_);
#line 622 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 622 "GomElementTest.vala"
			_g_object_unref0 (c4);
#line 622 "GomElementTest.vala"
			_g_object_unref0 (c3);
#line 622 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 622 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 622 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 622 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 7858 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 623 "GomElementTest.vala"
		_tmp35_ = d;
#line 623 "GomElementTest.vala"
		_tmp36_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp35_, "child", &_inner_error0_);
#line 623 "GomElementTest.vala"
		c5 = _tmp36_;
#line 623 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 623 "GomElementTest.vala"
			_g_object_unref0 (c4);
#line 623 "GomElementTest.vala"
			_g_object_unref0 (c3);
#line 623 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 623 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 623 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 623 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 7881 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 624 "GomElementTest.vala"
		_tmp37_ = r;
#line 624 "GomElementTest.vala"
		_tmp38_ = c5;
#line 624 "GomElementTest.vala"
		_tmp39_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp37_, (GXmlDomNode*) _tmp38_, &_inner_error0_);
#line 624 "GomElementTest.vala"
		_tmp40_ = _tmp39_;
#line 624 "GomElementTest.vala"
		_g_object_unref0 (_tmp40_);
#line 624 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 624 "GomElementTest.vala"
			_g_object_unref0 (c5);
#line 624 "GomElementTest.vala"
			_g_object_unref0 (c4);
#line 624 "GomElementTest.vala"
			_g_object_unref0 (c3);
#line 624 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 624 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 624 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 624 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 7910 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 625 "GomElementTest.vala"
		_tmp41_ = r;
#line 625 "GomElementTest.vala"
		_tmp42_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp41_, "child", &_inner_error0_);
#line 625 "GomElementTest.vala"
		n1 = _tmp42_;
#line 625 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 625 "GomElementTest.vala"
			_g_object_unref0 (c5);
#line 625 "GomElementTest.vala"
			_g_object_unref0 (c4);
#line 625 "GomElementTest.vala"
			_g_object_unref0 (c3);
#line 625 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 625 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 625 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 625 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 7935 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 626 "GomElementTest.vala"
		_tmp43_ = n1;
#line 626 "GomElementTest.vala"
		_vala_assert (_tmp43_ != NULL, "n1 != null");
#line 627 "GomElementTest.vala"
		_tmp44_ = n1;
#line 627 "GomElementTest.vala"
		_tmp45_ = gxml_dom_element_get_attribute (_tmp44_, "class");
#line 627 "GomElementTest.vala"
		_tmp46_ = _tmp45_;
#line 627 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp46_, "error") == 0, "n1.get_attribute (\"class\") == \"error\"");
#line 627 "GomElementTest.vala"
		_g_free0 (_tmp46_);
#line 628 "GomElementTest.vala"
		_tmp47_ = r;
#line 628 "GomElementTest.vala"
		_tmp48_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp47_, "child.warning", &_inner_error0_);
#line 628 "GomElementTest.vala"
		n2 = _tmp48_;
#line 628 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 628 "GomElementTest.vala"
			_g_object_unref0 (n1);
#line 628 "GomElementTest.vala"
			_g_object_unref0 (c5);
#line 628 "GomElementTest.vala"
			_g_object_unref0 (c4);
#line 628 "GomElementTest.vala"
			_g_object_unref0 (c3);
#line 628 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 628 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 628 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 628 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 7976 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 629 "GomElementTest.vala"
		_tmp49_ = n2;
#line 629 "GomElementTest.vala"
		_vala_assert (_tmp49_ != NULL, "n2 != null");
#line 630 "GomElementTest.vala"
		_tmp50_ = n2;
#line 630 "GomElementTest.vala"
		_tmp51_ = gxml_dom_element_get_attribute (_tmp50_, "class");
#line 630 "GomElementTest.vala"
		_tmp52_ = _tmp51_;
#line 630 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp52_, "warning") == 0, "n2.get_attribute (\"class\") == \"warning\"");
#line 630 "GomElementTest.vala"
		_g_free0 (_tmp52_);
#line 631 "GomElementTest.vala"
		_tmp53_ = r;
#line 631 "GomElementTest.vala"
		_tmp54_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp53_, "child[class]", &_inner_error0_);
#line 631 "GomElementTest.vala"
		n3 = _tmp54_;
#line 631 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 631 "GomElementTest.vala"
			_g_object_unref0 (n2);
#line 631 "GomElementTest.vala"
			_g_object_unref0 (n1);
#line 631 "GomElementTest.vala"
			_g_object_unref0 (c5);
#line 631 "GomElementTest.vala"
			_g_object_unref0 (c4);
#line 631 "GomElementTest.vala"
			_g_object_unref0 (c3);
#line 631 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 631 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 631 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 631 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 8019 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 632 "GomElementTest.vala"
		_tmp55_ = n3;
#line 632 "GomElementTest.vala"
		_vala_assert (_tmp55_ != NULL, "n3 != null");
#line 633 "GomElementTest.vala"
		_tmp56_ = n3;
#line 633 "GomElementTest.vala"
		_tmp57_ = gxml_dom_element_get_attribute (_tmp56_, "class");
#line 633 "GomElementTest.vala"
		_tmp58_ = _tmp57_;
#line 633 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp58_, "error") == 0, "n3.get_attribute (\"class\") == \"error\"");
#line 633 "GomElementTest.vala"
		_g_free0 (_tmp58_);
#line 634 "GomElementTest.vala"
		_tmp59_ = r;
#line 634 "GomElementTest.vala"
		_tmp60_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp59_, "child[class=\"error calc\"]", &_inner_error0_);
#line 634 "GomElementTest.vala"
		n4 = _tmp60_;
#line 634 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 634 "GomElementTest.vala"
			_g_object_unref0 (n3);
#line 634 "GomElementTest.vala"
			_g_object_unref0 (n2);
#line 634 "GomElementTest.vala"
			_g_object_unref0 (n1);
#line 634 "GomElementTest.vala"
			_g_object_unref0 (c5);
#line 634 "GomElementTest.vala"
			_g_object_unref0 (c4);
#line 634 "GomElementTest.vala"
			_g_object_unref0 (c3);
#line 634 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 634 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 634 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 634 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 8064 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 635 "GomElementTest.vala"
		_tmp61_ = n4;
#line 635 "GomElementTest.vala"
		_vala_assert (_tmp61_ != NULL, "n4 != null");
#line 636 "GomElementTest.vala"
		_tmp62_ = n4;
#line 636 "GomElementTest.vala"
		_tmp63_ = gxml_dom_element_get_attribute (_tmp62_, "class");
#line 636 "GomElementTest.vala"
		_tmp64_ = _tmp63_;
#line 636 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp64_, "error calc") == 0, "n4.get_attribute (\"class\") == \"error calc\"");
#line 636 "GomElementTest.vala"
		_g_free0 (_tmp64_);
#line 637 "GomElementTest.vala"
		_tmp65_ = r;
#line 637 "GomElementTest.vala"
		_tmp66_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp65_, "child", &_inner_error0_);
#line 637 "GomElementTest.vala"
		l1 = _tmp66_;
#line 637 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 637 "GomElementTest.vala"
			_g_object_unref0 (n4);
#line 637 "GomElementTest.vala"
			_g_object_unref0 (n3);
#line 637 "GomElementTest.vala"
			_g_object_unref0 (n2);
#line 637 "GomElementTest.vala"
			_g_object_unref0 (n1);
#line 637 "GomElementTest.vala"
			_g_object_unref0 (c5);
#line 637 "GomElementTest.vala"
			_g_object_unref0 (c4);
#line 637 "GomElementTest.vala"
			_g_object_unref0 (c3);
#line 637 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 637 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 637 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 637 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 8111 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 638 "GomElementTest.vala"
		_tmp67_ = l1;
#line 638 "GomElementTest.vala"
		_vala_assert (_tmp67_ != NULL, "l1 != null");
#line 639 "GomElementTest.vala"
		_tmp68_ = l1;
#line 639 "GomElementTest.vala"
		_tmp69_ = gxml_dom_node_list_get_length (_tmp68_);
#line 639 "GomElementTest.vala"
		_tmp70_ = _tmp69_;
#line 639 "GomElementTest.vala"
		_tmp71_ = g_strdup_printf ("%i", _tmp70_);
#line 639 "GomElementTest.vala"
		_tmp72_ = _tmp71_;
#line 639 "GomElementTest.vala"
		g_message ("GomElementTest.vala:639: %s", _tmp72_);
#line 639 "GomElementTest.vala"
		_g_free0 (_tmp72_);
#line 640 "GomElementTest.vala"
		_tmp73_ = l1;
#line 640 "GomElementTest.vala"
		_tmp74_ = gxml_dom_node_list_get_length (_tmp73_);
#line 640 "GomElementTest.vala"
		_tmp75_ = _tmp74_;
#line 640 "GomElementTest.vala"
		_vala_assert (_tmp75_ == 5, "l1.length == 5");
#line 641 "GomElementTest.vala"
		_tmp76_ = l1;
#line 641 "GomElementTest.vala"
		_tmp77_ = gxml_dom_node_list_item (_tmp76_, 4);
#line 641 "GomElementTest.vala"
		_tmp78_ = _tmp77_;
#line 641 "GomElementTest.vala"
		_tmp79_ = gxml_dom_node_get_node_name (_tmp78_);
#line 641 "GomElementTest.vala"
		_tmp80_ = _tmp79_;
#line 641 "GomElementTest.vala"
		_tmp81_ = _tmp80_;
#line 641 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp81_, "child") == 0, "l1.item (4).node_name == \"child\"");
#line 641 "GomElementTest.vala"
		_g_free0 (_tmp81_);
#line 641 "GomElementTest.vala"
		_g_object_unref0 (_tmp78_);
#line 642 "GomElementTest.vala"
		_tmp82_ = r;
#line 642 "GomElementTest.vala"
		_tmp83_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp82_, "child[class]", &_inner_error0_);
#line 642 "GomElementTest.vala"
		l2 = _tmp83_;
#line 642 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 642 "GomElementTest.vala"
			_g_object_unref0 (l1);
#line 642 "GomElementTest.vala"
			_g_object_unref0 (n4);
#line 642 "GomElementTest.vala"
			_g_object_unref0 (n3);
#line 642 "GomElementTest.vala"
			_g_object_unref0 (n2);
#line 642 "GomElementTest.vala"
			_g_object_unref0 (n1);
#line 642 "GomElementTest.vala"
			_g_object_unref0 (c5);
#line 642 "GomElementTest.vala"
			_g_object_unref0 (c4);
#line 642 "GomElementTest.vala"
			_g_object_unref0 (c3);
#line 642 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 642 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 642 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 642 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 8190 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 643 "GomElementTest.vala"
		_tmp84_ = l2;
#line 643 "GomElementTest.vala"
		_vala_assert (_tmp84_ != NULL, "l2 != null");
#line 644 "GomElementTest.vala"
		_tmp85_ = l2;
#line 644 "GomElementTest.vala"
		_tmp86_ = gxml_dom_node_list_get_length (_tmp85_);
#line 644 "GomElementTest.vala"
		_tmp87_ = _tmp86_;
#line 644 "GomElementTest.vala"
		_vala_assert (_tmp87_ == 4, "l2.length == 4");
#line 645 "GomElementTest.vala"
		_tmp88_ = l2;
#line 645 "GomElementTest.vala"
		_tmp89_ = gxml_dom_node_list_item (_tmp88_, 3);
#line 645 "GomElementTest.vala"
		_tmp90_ = _tmp89_;
#line 645 "GomElementTest.vala"
		_tmp91_ = gxml_dom_node_get_node_name (_tmp90_);
#line 645 "GomElementTest.vala"
		_tmp92_ = _tmp91_;
#line 645 "GomElementTest.vala"
		_tmp93_ = _tmp92_;
#line 645 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp93_, "child") == 0, "l2.item (3).node_name == \"child\"");
#line 645 "GomElementTest.vala"
		_g_free0 (_tmp93_);
#line 645 "GomElementTest.vala"
		_g_object_unref0 (_tmp90_);
#line 646 "GomElementTest.vala"
		_tmp94_ = r;
#line 646 "GomElementTest.vala"
		_tmp95_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp94_, "child[class=\"error\"]", &_inner_error0_);
#line 646 "GomElementTest.vala"
		l3 = _tmp95_;
#line 646 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 646 "GomElementTest.vala"
			_g_object_unref0 (l2);
#line 646 "GomElementTest.vala"
			_g_object_unref0 (l1);
#line 646 "GomElementTest.vala"
			_g_object_unref0 (n4);
#line 646 "GomElementTest.vala"
			_g_object_unref0 (n3);
#line 646 "GomElementTest.vala"
			_g_object_unref0 (n2);
#line 646 "GomElementTest.vala"
			_g_object_unref0 (n1);
#line 646 "GomElementTest.vala"
			_g_object_unref0 (c5);
#line 646 "GomElementTest.vala"
			_g_object_unref0 (c4);
#line 646 "GomElementTest.vala"
			_g_object_unref0 (c3);
#line 646 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 646 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 646 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 646 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 8257 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 647 "GomElementTest.vala"
		_tmp96_ = l3;
#line 647 "GomElementTest.vala"
		_vala_assert (_tmp96_ != NULL, "l3 != null");
#line 648 "GomElementTest.vala"
		_tmp97_ = l3;
#line 648 "GomElementTest.vala"
		_tmp98_ = gxml_dom_node_list_get_length (_tmp97_);
#line 648 "GomElementTest.vala"
		_tmp99_ = _tmp98_;
#line 648 "GomElementTest.vala"
		_vala_assert (_tmp99_ == 1, "l3.length == 1");
#line 649 "GomElementTest.vala"
		_tmp100_ = l3;
#line 649 "GomElementTest.vala"
		_tmp101_ = gxml_dom_node_list_item (_tmp100_, 0);
#line 649 "GomElementTest.vala"
		_tmp102_ = _tmp101_;
#line 649 "GomElementTest.vala"
		_tmp103_ = gxml_dom_node_get_node_name (_tmp102_);
#line 649 "GomElementTest.vala"
		_tmp104_ = _tmp103_;
#line 649 "GomElementTest.vala"
		_tmp105_ = _tmp104_;
#line 649 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp105_, "child") == 0, "l3.item (0).node_name == \"child\"");
#line 649 "GomElementTest.vala"
		_g_free0 (_tmp105_);
#line 649 "GomElementTest.vala"
		_g_object_unref0 (_tmp102_);
#line 650 "GomElementTest.vala"
		_tmp106_ = d;
#line 650 "GomElementTest.vala"
		_tmp107_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp106_, "child", &_inner_error0_);
#line 650 "GomElementTest.vala"
		c6 = _tmp107_;
#line 650 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 650 "GomElementTest.vala"
			_g_object_unref0 (l3);
#line 650 "GomElementTest.vala"
			_g_object_unref0 (l2);
#line 650 "GomElementTest.vala"
			_g_object_unref0 (l1);
#line 650 "GomElementTest.vala"
			_g_object_unref0 (n4);
#line 650 "GomElementTest.vala"
			_g_object_unref0 (n3);
#line 650 "GomElementTest.vala"
			_g_object_unref0 (n2);
#line 650 "GomElementTest.vala"
			_g_object_unref0 (n1);
#line 650 "GomElementTest.vala"
			_g_object_unref0 (c5);
#line 650 "GomElementTest.vala"
			_g_object_unref0 (c4);
#line 650 "GomElementTest.vala"
			_g_object_unref0 (c3);
#line 650 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 650 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 650 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 650 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 8326 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 651 "GomElementTest.vala"
		_tmp108_ = c6;
#line 651 "GomElementTest.vala"
		gxml_dom_element_set_attribute (_tmp108_, "prop", "val1", &_inner_error0_);
#line 651 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 651 "GomElementTest.vala"
			_g_object_unref0 (c6);
#line 651 "GomElementTest.vala"
			_g_object_unref0 (l3);
#line 651 "GomElementTest.vala"
			_g_object_unref0 (l2);
#line 651 "GomElementTest.vala"
			_g_object_unref0 (l1);
#line 651 "GomElementTest.vala"
			_g_object_unref0 (n4);
#line 651 "GomElementTest.vala"
			_g_object_unref0 (n3);
#line 651 "GomElementTest.vala"
			_g_object_unref0 (n2);
#line 651 "GomElementTest.vala"
			_g_object_unref0 (n1);
#line 651 "GomElementTest.vala"
			_g_object_unref0 (c5);
#line 651 "GomElementTest.vala"
			_g_object_unref0 (c4);
#line 651 "GomElementTest.vala"
			_g_object_unref0 (c3);
#line 651 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 651 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 651 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 651 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 8365 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 652 "GomElementTest.vala"
		_tmp109_ = r;
#line 652 "GomElementTest.vala"
		_tmp110_ = c6;
#line 652 "GomElementTest.vala"
		_tmp111_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp109_, (GXmlDomNode*) _tmp110_, &_inner_error0_);
#line 652 "GomElementTest.vala"
		_tmp112_ = _tmp111_;
#line 652 "GomElementTest.vala"
		_g_object_unref0 (_tmp112_);
#line 652 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 652 "GomElementTest.vala"
			_g_object_unref0 (c6);
#line 652 "GomElementTest.vala"
			_g_object_unref0 (l3);
#line 652 "GomElementTest.vala"
			_g_object_unref0 (l2);
#line 652 "GomElementTest.vala"
			_g_object_unref0 (l1);
#line 652 "GomElementTest.vala"
			_g_object_unref0 (n4);
#line 652 "GomElementTest.vala"
			_g_object_unref0 (n3);
#line 652 "GomElementTest.vala"
			_g_object_unref0 (n2);
#line 652 "GomElementTest.vala"
			_g_object_unref0 (n1);
#line 652 "GomElementTest.vala"
			_g_object_unref0 (c5);
#line 652 "GomElementTest.vala"
			_g_object_unref0 (c4);
#line 652 "GomElementTest.vala"
			_g_object_unref0 (c3);
#line 652 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 652 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 652 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 652 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 8410 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 653 "GomElementTest.vala"
		_tmp113_ = d;
#line 653 "GomElementTest.vala"
		_tmp114_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp113_, "child", &_inner_error0_);
#line 653 "GomElementTest.vala"
		c7 = _tmp114_;
#line 653 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 653 "GomElementTest.vala"
			_g_object_unref0 (c6);
#line 653 "GomElementTest.vala"
			_g_object_unref0 (l3);
#line 653 "GomElementTest.vala"
			_g_object_unref0 (l2);
#line 653 "GomElementTest.vala"
			_g_object_unref0 (l1);
#line 653 "GomElementTest.vala"
			_g_object_unref0 (n4);
#line 653 "GomElementTest.vala"
			_g_object_unref0 (n3);
#line 653 "GomElementTest.vala"
			_g_object_unref0 (n2);
#line 653 "GomElementTest.vala"
			_g_object_unref0 (n1);
#line 653 "GomElementTest.vala"
			_g_object_unref0 (c5);
#line 653 "GomElementTest.vala"
			_g_object_unref0 (c4);
#line 653 "GomElementTest.vala"
			_g_object_unref0 (c3);
#line 653 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 653 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 653 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 653 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 8451 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 654 "GomElementTest.vala"
		_tmp115_ = c7;
#line 654 "GomElementTest.vala"
		gxml_dom_element_set_attribute (_tmp115_, "prop", "val1", &_inner_error0_);
#line 654 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 654 "GomElementTest.vala"
			_g_object_unref0 (c7);
#line 654 "GomElementTest.vala"
			_g_object_unref0 (c6);
#line 654 "GomElementTest.vala"
			_g_object_unref0 (l3);
#line 654 "GomElementTest.vala"
			_g_object_unref0 (l2);
#line 654 "GomElementTest.vala"
			_g_object_unref0 (l1);
#line 654 "GomElementTest.vala"
			_g_object_unref0 (n4);
#line 654 "GomElementTest.vala"
			_g_object_unref0 (n3);
#line 654 "GomElementTest.vala"
			_g_object_unref0 (n2);
#line 654 "GomElementTest.vala"
			_g_object_unref0 (n1);
#line 654 "GomElementTest.vala"
			_g_object_unref0 (c5);
#line 654 "GomElementTest.vala"
			_g_object_unref0 (c4);
#line 654 "GomElementTest.vala"
			_g_object_unref0 (c3);
#line 654 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 654 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 654 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 654 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 8492 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 655 "GomElementTest.vala"
		_tmp116_ = r;
#line 655 "GomElementTest.vala"
		_tmp117_ = c7;
#line 655 "GomElementTest.vala"
		_tmp118_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp116_, (GXmlDomNode*) _tmp117_, &_inner_error0_);
#line 655 "GomElementTest.vala"
		_tmp119_ = _tmp118_;
#line 655 "GomElementTest.vala"
		_g_object_unref0 (_tmp119_);
#line 655 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 655 "GomElementTest.vala"
			_g_object_unref0 (c7);
#line 655 "GomElementTest.vala"
			_g_object_unref0 (c6);
#line 655 "GomElementTest.vala"
			_g_object_unref0 (l3);
#line 655 "GomElementTest.vala"
			_g_object_unref0 (l2);
#line 655 "GomElementTest.vala"
			_g_object_unref0 (l1);
#line 655 "GomElementTest.vala"
			_g_object_unref0 (n4);
#line 655 "GomElementTest.vala"
			_g_object_unref0 (n3);
#line 655 "GomElementTest.vala"
			_g_object_unref0 (n2);
#line 655 "GomElementTest.vala"
			_g_object_unref0 (n1);
#line 655 "GomElementTest.vala"
			_g_object_unref0 (c5);
#line 655 "GomElementTest.vala"
			_g_object_unref0 (c4);
#line 655 "GomElementTest.vala"
			_g_object_unref0 (c3);
#line 655 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 655 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 655 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 655 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 8539 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 656 "GomElementTest.vala"
		_tmp120_ = r;
#line 656 "GomElementTest.vala"
		_tmp121_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp120_, "child[prop=\"val1\"]", &_inner_error0_);
#line 656 "GomElementTest.vala"
		l4 = _tmp121_;
#line 656 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 656 "GomElementTest.vala"
			_g_object_unref0 (c7);
#line 656 "GomElementTest.vala"
			_g_object_unref0 (c6);
#line 656 "GomElementTest.vala"
			_g_object_unref0 (l3);
#line 656 "GomElementTest.vala"
			_g_object_unref0 (l2);
#line 656 "GomElementTest.vala"
			_g_object_unref0 (l1);
#line 656 "GomElementTest.vala"
			_g_object_unref0 (n4);
#line 656 "GomElementTest.vala"
			_g_object_unref0 (n3);
#line 656 "GomElementTest.vala"
			_g_object_unref0 (n2);
#line 656 "GomElementTest.vala"
			_g_object_unref0 (n1);
#line 656 "GomElementTest.vala"
			_g_object_unref0 (c5);
#line 656 "GomElementTest.vala"
			_g_object_unref0 (c4);
#line 656 "GomElementTest.vala"
			_g_object_unref0 (c3);
#line 656 "GomElementTest.vala"
			_g_object_unref0 (c2);
#line 656 "GomElementTest.vala"
			_g_object_unref0 (c1);
#line 656 "GomElementTest.vala"
			_g_object_unref0 (r);
#line 656 "GomElementTest.vala"
			_g_object_unref0 (d);
#line 8582 "GomElementTest.c"
			goto __catch137_g_error;
		}
#line 657 "GomElementTest.vala"
		_tmp122_ = l4;
#line 657 "GomElementTest.vala"
		_vala_assert (_tmp122_ != NULL, "l4 != null");
#line 658 "GomElementTest.vala"
		_tmp123_ = l4;
#line 658 "GomElementTest.vala"
		_tmp124_ = gxml_dom_node_list_get_length (_tmp123_);
#line 658 "GomElementTest.vala"
		_tmp125_ = _tmp124_;
#line 658 "GomElementTest.vala"
		_vala_assert (_tmp125_ == 2, "l4.length == 2");
#line 659 "GomElementTest.vala"
		_tmp126_ = l4;
#line 659 "GomElementTest.vala"
		_tmp127_ = gxml_dom_node_list_item (_tmp126_, 0);
#line 659 "GomElementTest.vala"
		_tmp128_ = _tmp127_;
#line 659 "GomElementTest.vala"
		_tmp129_ = gxml_dom_node_get_node_name (_tmp128_);
#line 659 "GomElementTest.vala"
		_tmp130_ = _tmp129_;
#line 659 "GomElementTest.vala"
		_tmp131_ = _tmp130_;
#line 659 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp131_, "child") == 0, "l4.item (0).node_name == \"child\"");
#line 659 "GomElementTest.vala"
		_g_free0 (_tmp131_);
#line 659 "GomElementTest.vala"
		_g_object_unref0 (_tmp128_);
#line 607 "GomElementTest.vala"
		_g_object_unref0 (l4);
#line 607 "GomElementTest.vala"
		_g_object_unref0 (c7);
#line 607 "GomElementTest.vala"
		_g_object_unref0 (c6);
#line 607 "GomElementTest.vala"
		_g_object_unref0 (l3);
#line 607 "GomElementTest.vala"
		_g_object_unref0 (l2);
#line 607 "GomElementTest.vala"
		_g_object_unref0 (l1);
#line 607 "GomElementTest.vala"
		_g_object_unref0 (n4);
#line 607 "GomElementTest.vala"
		_g_object_unref0 (n3);
#line 607 "GomElementTest.vala"
		_g_object_unref0 (n2);
#line 607 "GomElementTest.vala"
		_g_object_unref0 (n1);
#line 607 "GomElementTest.vala"
		_g_object_unref0 (c5);
#line 607 "GomElementTest.vala"
		_g_object_unref0 (c4);
#line 607 "GomElementTest.vala"
		_g_object_unref0 (c3);
#line 607 "GomElementTest.vala"
		_g_object_unref0 (c2);
#line 607 "GomElementTest.vala"
		_g_object_unref0 (c1);
#line 607 "GomElementTest.vala"
		_g_object_unref0 (r);
#line 607 "GomElementTest.vala"
		_g_object_unref0 (d);
#line 8649 "GomElementTest.c"
	}
	goto __finally137;
	__catch137_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp132_;
		gchar* _tmp133_;
		gchar* _tmp134_;
#line 607 "GomElementTest.vala"
		e = _inner_error0_;
#line 607 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 661 "GomElementTest.vala"
		_tmp132_ = e->message;
#line 661 "GomElementTest.vala"
		_tmp133_ = g_strconcat ("Error: ", _tmp132_, NULL);
#line 661 "GomElementTest.vala"
		_tmp134_ = _tmp133_;
#line 661 "GomElementTest.vala"
		g_message ("GomElementTest.vala:661: %s", _tmp134_);
#line 661 "GomElementTest.vala"
		_g_free0 (_tmp134_);
#line 662 "GomElementTest.vala"
		g_assert_not_reached ();
#line 607 "GomElementTest.vala"
		_g_error_free0 (e);
#line 8676 "GomElementTest.c"
	}
	__finally137:
#line 607 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 607 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 607 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 607 "GomElementTest.vala"
		return;
#line 8687 "GomElementTest.c"
	}
}

static void
___lambda113__gtest_func (void)
{
#line 606 "GomElementTest.vala"
	__lambda113_ ();
#line 8696 "GomElementTest.c"
}

static void
__lambda114_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		gchar* str = NULL;
		gchar* _tmp0_;
		GomElementTestTop* t = NULL;
		GomElementTestTop* _tmp1_;
		NoInstantiatable* _tmp2_;
		NoInstantiatable* _tmp3_;
		NoInstantiatable* _tmp4_;
		NoInstantiatable* _tmp5_;
		const gchar* _tmp6_;
		const gchar* _tmp7_;
#line 667 "GomElementTest.vala"
		_tmp0_ = g_strdup ("<Top pq=\"Qlt\"><Instantiatable name=\"Nop\"/></Top>");
#line 667 "GomElementTest.vala"
		str = _tmp0_;
#line 668 "GomElementTest.vala"
		_tmp1_ = gom_element_test_top_new ();
#line 668 "GomElementTest.vala"
		t = _tmp1_;
#line 669 "GomElementTest.vala"
		gxml_dom_element_read_from_string ((GXmlDomElement*) t, str, NULL, &_inner_error0_);
#line 669 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 669 "GomElementTest.vala"
			_g_object_unref0 (t);
#line 669 "GomElementTest.vala"
			_g_free0 (str);
#line 8730 "GomElementTest.c"
			goto __catch138_g_error;
		}
#line 670 "GomElementTest.vala"
		_tmp2_ = gom_element_test_top_get_inst (t);
#line 670 "GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 670 "GomElementTest.vala"
		_vala_assert (_tmp3_ != NULL, "t.inst != null");
#line 671 "GomElementTest.vala"
		_tmp4_ = gom_element_test_top_get_inst (t);
#line 671 "GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 671 "GomElementTest.vala"
		_tmp6_ = no_instantiatable_get_name (_tmp5_);
#line 671 "GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 671 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "Nop") == 0, "t.inst.name == \"Nop\"");
#line 666 "GomElementTest.vala"
		_g_object_unref0 (t);
#line 666 "GomElementTest.vala"
		_g_free0 (str);
#line 8753 "GomElementTest.c"
	}
	goto __finally138;
	__catch138_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
#line 666 "GomElementTest.vala"
		e = _inner_error0_;
#line 666 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 673 "GomElementTest.vala"
		_tmp8_ = e->message;
#line 673 "GomElementTest.vala"
		_tmp9_ = g_strconcat ("Error: ", _tmp8_, NULL);
#line 673 "GomElementTest.vala"
		_tmp10_ = _tmp9_;
#line 673 "GomElementTest.vala"
		g_message ("GomElementTest.vala:673: %s", _tmp10_);
#line 673 "GomElementTest.vala"
		_g_free0 (_tmp10_);
#line 674 "GomElementTest.vala"
		g_assert_not_reached ();
#line 666 "GomElementTest.vala"
		_g_error_free0 (e);
#line 8780 "GomElementTest.c"
	}
	__finally138:
#line 666 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 666 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 666 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 666 "GomElementTest.vala"
		return;
#line 8791 "GomElementTest.c"
	}
}

static void
___lambda114__gtest_func (void)
{
#line 665 "GomElementTest.vala"
	__lambda114_ ();
#line 8800 "GomElementTest.c"
}

static void
__lambda115_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		gchar* str = NULL;
		gchar* _tmp0_;
		GomElementTestGTop* t = NULL;
		GomElementTestGTop* _tmp1_;
		NoInstantiatable* _tmp2_;
		NoInstantiatable* _tmp3_;
		NoInstantiatable* _tmp4_;
		NoInstantiatable* _tmp5_;
		const gchar* _tmp6_;
		const gchar* _tmp7_;
		Property* _tmp8_;
		Property* _tmp9_;
		Property* _tmp10_;
		Property* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
#line 679 "GomElementTest.vala"
		_tmp0_ = g_strdup ("<Top pq=\"Qlt\"><Instantiatable name=\"Nop\"/></Top>");
#line 679 "GomElementTest.vala"
		str = _tmp0_;
#line 680 "GomElementTest.vala"
		_tmp1_ = gom_element_test_gtop_new ();
#line 680 "GomElementTest.vala"
		t = _tmp1_;
#line 681 "GomElementTest.vala"
		gxml_dom_element_read_from_string ((GXmlDomElement*) t, str, NULL, &_inner_error0_);
#line 681 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 681 "GomElementTest.vala"
			_g_object_unref0 (t);
#line 681 "GomElementTest.vala"
			_g_free0 (str);
#line 8841 "GomElementTest.c"
			goto __catch139_g_error;
		}
#line 682 "GomElementTest.vala"
		_tmp2_ = gom_element_test_gtop_get_inst (t);
#line 682 "GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 682 "GomElementTest.vala"
		_vala_assert (_tmp3_ != NULL, "t.inst != null");
#line 683 "GomElementTest.vala"
		_tmp4_ = gom_element_test_gtop_get_inst (t);
#line 683 "GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 683 "GomElementTest.vala"
		_tmp6_ = no_instantiatable_get_name (_tmp5_);
#line 683 "GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 683 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "Nop") == 0, "t.inst.name == \"Nop\"");
#line 684 "GomElementTest.vala"
		_tmp8_ = gom_element_test_gtop_get_pq (t);
#line 684 "GomElementTest.vala"
		_tmp9_ = _tmp8_;
#line 684 "GomElementTest.vala"
		_vala_assert (_tmp9_ != NULL, "t.pq != null");
#line 685 "GomElementTest.vala"
		_tmp10_ = gom_element_test_gtop_get_pq (t);
#line 685 "GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 685 "GomElementTest.vala"
		_tmp12_ = gxml_gom_property_get_value ((GXmlGomProperty*) _tmp11_);
#line 685 "GomElementTest.vala"
		_tmp13_ = _tmp12_;
#line 685 "GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 685 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp14_, "Qlt") == 0, "t.pq.value == \"Qlt\"");
#line 685 "GomElementTest.vala"
		_g_free0 (_tmp14_);
#line 678 "GomElementTest.vala"
		_g_object_unref0 (t);
#line 678 "GomElementTest.vala"
		_g_free0 (str);
#line 8884 "GomElementTest.c"
	}
	goto __finally139;
	__catch139_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp15_;
		gchar* _tmp16_;
		gchar* _tmp17_;
#line 678 "GomElementTest.vala"
		e = _inner_error0_;
#line 678 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 687 "GomElementTest.vala"
		_tmp15_ = e->message;
#line 687 "GomElementTest.vala"
		_tmp16_ = g_strconcat ("Error: ", _tmp15_, NULL);
#line 687 "GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 687 "GomElementTest.vala"
		g_message ("GomElementTest.vala:687: %s", _tmp17_);
#line 687 "GomElementTest.vala"
		_g_free0 (_tmp17_);
#line 688 "GomElementTest.vala"
		g_assert_not_reached ();
#line 678 "GomElementTest.vala"
		_g_error_free0 (e);
#line 8911 "GomElementTest.c"
	}
	__finally139:
#line 678 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 678 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 678 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 678 "GomElementTest.vala"
		return;
#line 8922 "GomElementTest.c"
	}
}

static void
___lambda115__gtest_func (void)
{
#line 677 "GomElementTest.vala"
	__lambda115_ ();
#line 8931 "GomElementTest.c"
}

static void
__lambda116_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGomElement* e = NULL;
		GXmlGomElement* _tmp0_;
		GXmlGomElement* _tmp1_;
		GXmlGomElement* _tmp2_;
		GXmlGomElement* _tmp3_;
		GXmlGomElement* _tmp4_;
		GXmlGomElement* _tmp5_;
		GXmlDomNamedNodeMap* _tmp6_;
		GXmlDomNamedNodeMap* _tmp7_;
		GXmlDomNamedNodeMap* _tmp8_;
		gint _tmp9_;
		gint _tmp10_;
		GXmlGomElement* _tmp26_;
		GXmlDomNamedNodeMap* _tmp27_;
		GXmlDomNamedNodeMap* _tmp28_;
		GXmlDomNamedNodeMap* _tmp29_;
		GXmlDomNode* _tmp30_;
		GXmlDomNode* _tmp31_;
		GXmlGomElement* _tmp32_;
		GXmlDomNamedNodeMap* _tmp33_;
		GXmlDomNamedNodeMap* _tmp34_;
		GXmlDomNamedNodeMap* _tmp35_;
		GXmlDomNode* _tmp36_;
		GXmlDomNode* _tmp37_;
		gchar* _tmp38_;
		gchar* _tmp39_;
		gchar* _tmp40_;
		GXmlGomElement* _tmp41_;
		GXmlDomNamedNodeMap* _tmp42_;
		GXmlDomNamedNodeMap* _tmp43_;
		GXmlDomNamedNodeMap* _tmp44_;
		GXmlDomNode* _tmp45_;
		GXmlDomNode* _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
		gchar* _tmp49_;
		GXmlGomElement* _tmp50_;
		GXmlDomNamedNodeMap* _tmp51_;
		GXmlDomNamedNodeMap* _tmp52_;
		GXmlDomNamedNodeMap* _tmp53_;
		GXmlDomNode* _tmp54_;
		GXmlDomNode* _tmp55_;
		GXmlGomElement* _tmp56_;
		GXmlDomNamedNodeMap* _tmp57_;
		GXmlDomNamedNodeMap* _tmp58_;
		GXmlDomNamedNodeMap* _tmp59_;
		GXmlDomNode* _tmp60_;
		GXmlDomNode* _tmp61_;
		gchar* _tmp62_;
		gchar* _tmp63_;
		gchar* _tmp64_;
		GXmlGomElement* _tmp65_;
		GXmlDomNamedNodeMap* _tmp66_;
		GXmlDomNamedNodeMap* _tmp67_;
		GXmlDomNamedNodeMap* _tmp68_;
		GXmlDomNode* _tmp69_;
		GXmlDomNode* _tmp70_;
		gchar* _tmp71_;
		gchar* _tmp72_;
		gchar* _tmp73_;
		GXmlGomElement* _tmp74_;
		GXmlDomNamedNodeMap* _tmp75_;
		GXmlDomNamedNodeMap* _tmp76_;
		GXmlDomNamedNodeMap* _tmp77_;
		GXmlDomNode* _tmp78_;
		GXmlDomNode* _tmp79_;
		GXmlGomElement* _tmp80_;
		GXmlDomNamedNodeMap* _tmp81_;
		GXmlDomNamedNodeMap* _tmp82_;
		GXmlDomNamedNodeMap* _tmp83_;
		GXmlDomNode* _tmp84_;
		GXmlDomNode* _tmp85_;
		gchar* _tmp86_;
		gchar* _tmp87_;
		gchar* _tmp88_;
		GXmlGomElement* _tmp89_;
		GXmlDomNamedNodeMap* _tmp90_;
		GXmlDomNamedNodeMap* _tmp91_;
		GXmlDomNamedNodeMap* _tmp92_;
		GXmlDomNode* _tmp93_;
		GXmlDomNode* _tmp94_;
		gchar* _tmp95_;
		gchar* _tmp96_;
		gchar* _tmp97_;
		GXmlGomElement* _tmp98_;
		GXmlDomNamedNodeMap* _tmp99_;
		GXmlDomNamedNodeMap* _tmp100_;
		GXmlDomNamedNodeMap* _tmp101_;
		GXmlDomNode* _tmp102_;
		GXmlDomNode* _tmp103_;
		GXmlGomElement* _tmp104_;
		GXmlDomNamedNodeMap* _tmp105_;
		GXmlDomNamedNodeMap* _tmp106_;
		GXmlDomNamedNodeMap* _tmp107_;
		GXmlDomNode* _tmp108_;
		GXmlDomNode* _tmp109_;
		gchar* _tmp110_;
		gchar* _tmp111_;
		gchar* _tmp112_;
		GXmlGomElement* _tmp113_;
		GXmlDomNamedNodeMap* _tmp114_;
		GXmlDomNamedNodeMap* _tmp115_;
		GXmlDomNamedNodeMap* _tmp116_;
		GXmlDomNode* _tmp117_;
		GXmlDomNode* _tmp118_;
		gchar* _tmp119_;
		gchar* _tmp120_;
		gchar* _tmp121_;
		GXmlGomElement* _tmp122_;
		GXmlGomElement* _tmp123_;
		GXmlDomNamedNodeMap* _tmp124_;
		GXmlDomNamedNodeMap* _tmp125_;
		GXmlDomNamedNodeMap* _tmp126_;
		gint _tmp127_;
		gint _tmp128_;
		GXmlGomElement* _tmp129_;
		GXmlDomNamedNodeMap* _tmp130_;
		GXmlDomNamedNodeMap* _tmp131_;
		GXmlDomNamedNodeMap* _tmp132_;
		GXmlDomNode* _tmp133_;
		GXmlDomNode* _tmp134_;
		GXmlGomElement* _tmp135_;
		GXmlDomNamedNodeMap* _tmp136_;
		GXmlDomNamedNodeMap* _tmp137_;
		GXmlDomNamedNodeMap* _tmp138_;
		GXmlDomNode* _tmp139_;
		GXmlDomNode* _tmp140_;
		gchar* _tmp141_;
		gchar* _tmp142_;
		gchar* _tmp143_;
		GXmlGomElement* _tmp144_;
		GXmlDomNamedNodeMap* _tmp145_;
		GXmlDomNamedNodeMap* _tmp146_;
		GXmlDomNamedNodeMap* _tmp147_;
		GXmlDomNode* _tmp148_;
		GXmlDomNode* _tmp149_;
		gchar* _tmp150_;
		gchar* _tmp151_;
		gchar* _tmp152_;
		GXmlGomElement* _tmp153_;
		GXmlDomNamedNodeMap* _tmp154_;
		GXmlDomNamedNodeMap* _tmp155_;
		GXmlDomNamedNodeMap* _tmp156_;
		GXmlDomNode* _tmp157_;
		GXmlDomNode* _tmp158_;
		GXmlGomElement* e2 = NULL;
		GXmlGomElement* _tmp159_;
		GXmlGomElement* _tmp160_;
		GXmlGomElement* _tmp161_;
		GXmlGomElement* _tmp162_;
		GXmlGomElement* _tmp163_;
		GXmlGomElement* _tmp164_;
		GXmlGomElement* _tmp165_;
		GXmlDomNamedNodeMap* _tmp166_;
		GXmlDomNamedNodeMap* _tmp167_;
		GXmlDomNamedNodeMap* _tmp168_;
		gint _tmp169_;
		gint _tmp170_;
		GXmlGomElement* _tmp186_;
		GXmlDomNamedNodeMap* _tmp187_;
		GXmlDomNamedNodeMap* _tmp188_;
		GXmlDomNamedNodeMap* _tmp189_;
		GXmlDomNode* _tmp190_;
		GXmlDomNode* _tmp191_;
		GXmlGomElement* _tmp192_;
		GXmlDomNamedNodeMap* _tmp193_;
		GXmlDomNamedNodeMap* _tmp194_;
		GXmlDomNamedNodeMap* _tmp195_;
		GXmlDomNode* _tmp196_;
		GXmlDomNode* _tmp197_;
		gchar* _tmp198_;
		gchar* _tmp199_;
		gchar* _tmp200_;
		GXmlGomElement* _tmp201_;
		GXmlDomNamedNodeMap* _tmp202_;
		GXmlDomNamedNodeMap* _tmp203_;
		GXmlDomNamedNodeMap* _tmp204_;
		GXmlDomNode* _tmp205_;
		GXmlDomNode* _tmp206_;
		gchar* _tmp207_;
		gchar* _tmp208_;
		gchar* _tmp209_;
		GXmlGomElement* _tmp210_;
		GXmlDomNamedNodeMap* _tmp211_;
		GXmlDomNamedNodeMap* _tmp212_;
		GXmlDomNamedNodeMap* _tmp213_;
		GXmlDomNode* _tmp214_;
		GXmlDomNode* _tmp215_;
		GXmlGomElement* _tmp216_;
		GXmlDomNamedNodeMap* _tmp217_;
		GXmlDomNamedNodeMap* _tmp218_;
		GXmlDomNamedNodeMap* _tmp219_;
		GXmlDomNode* _tmp220_;
		GXmlDomNode* _tmp221_;
		gchar* _tmp222_;
		gchar* _tmp223_;
		gchar* _tmp224_;
		GXmlGomElement* _tmp225_;
		GXmlDomNamedNodeMap* _tmp226_;
		GXmlDomNamedNodeMap* _tmp227_;
		GXmlDomNamedNodeMap* _tmp228_;
		GXmlDomNode* _tmp229_;
		GXmlDomNode* _tmp230_;
		gchar* _tmp231_;
		gchar* _tmp232_;
		gchar* _tmp233_;
		GXmlGomElement* _tmp234_;
		GXmlDomNamedNodeMap* _tmp235_;
		GXmlDomNamedNodeMap* _tmp236_;
		GXmlDomNamedNodeMap* _tmp237_;
		GXmlDomNode* _tmp238_;
		GXmlDomNode* _tmp239_;
		GXmlGomElement* _tmp240_;
		GXmlDomNamedNodeMap* _tmp241_;
		GXmlDomNamedNodeMap* _tmp242_;
		GXmlDomNamedNodeMap* _tmp243_;
		GXmlDomNode* _tmp244_;
		GXmlDomNode* _tmp245_;
		gchar* _tmp246_;
		gchar* _tmp247_;
		gchar* _tmp248_;
		GXmlGomElement* _tmp249_;
		GXmlDomNamedNodeMap* _tmp250_;
		GXmlDomNamedNodeMap* _tmp251_;
		GXmlDomNamedNodeMap* _tmp252_;
		GXmlDomNode* _tmp253_;
		GXmlDomNode* _tmp254_;
		gchar* _tmp255_;
		gchar* _tmp256_;
		gchar* _tmp257_;
		GXmlGomElement* _tmp258_;
		GXmlDomNamedNodeMap* _tmp259_;
		GXmlDomNamedNodeMap* _tmp260_;
		GXmlDomNamedNodeMap* _tmp261_;
		GXmlDomNode* _tmp262_;
		GXmlDomNode* _tmp263_;
		GXmlGomElement* _tmp264_;
		GXmlDomNamedNodeMap* _tmp265_;
		GXmlDomNamedNodeMap* _tmp266_;
		GXmlDomNamedNodeMap* _tmp267_;
		GXmlDomNode* _tmp268_;
		GXmlDomNode* _tmp269_;
		gchar* _tmp270_;
		gchar* _tmp271_;
		gchar* _tmp272_;
		GXmlGomElement* _tmp273_;
		GXmlDomNamedNodeMap* _tmp274_;
		GXmlDomNamedNodeMap* _tmp275_;
		GXmlDomNamedNodeMap* _tmp276_;
		GXmlDomNode* _tmp277_;
		GXmlDomNode* _tmp278_;
		gchar* _tmp279_;
		gchar* _tmp280_;
		gchar* _tmp281_;
		GXmlGomElement* _tmp282_;
		GXmlDomNamedNodeMap* _tmp283_;
		GXmlDomNamedNodeMap* _tmp284_;
		GXmlDomNamedNodeMap* _tmp285_;
		GXmlDomNode* _tmp286_;
		GXmlDomNode* _tmp287_;
		GXmlGomElement* _tmp288_;
		GXmlDomNamedNodeMap* _tmp289_;
		GXmlDomNamedNodeMap* _tmp290_;
		GXmlDomNamedNodeMap* _tmp291_;
		GXmlDomNode* _tmp292_;
		GXmlDomNode* _tmp293_;
		gchar* _tmp294_;
		gchar* _tmp295_;
		gchar* _tmp296_;
		GXmlGomElement* _tmp297_;
		GXmlDomNamedNodeMap* _tmp298_;
		GXmlDomNamedNodeMap* _tmp299_;
		GXmlDomNamedNodeMap* _tmp300_;
		GXmlDomNode* _tmp301_;
		GXmlDomNode* _tmp302_;
		gchar* _tmp303_;
		gchar* _tmp304_;
		gchar* _tmp305_;
		GXmlGomElement* _tmp306_;
		GXmlGomElement* _tmp307_;
		GXmlDomNamedNodeMap* _tmp308_;
		GXmlDomNamedNodeMap* _tmp309_;
		GXmlDomNamedNodeMap* _tmp310_;
		gint _tmp311_;
		gint _tmp312_;
		GXmlGomElement* _tmp313_;
		GXmlDomNamedNodeMap* _tmp314_;
		GXmlDomNamedNodeMap* _tmp315_;
		GXmlDomNamedNodeMap* _tmp316_;
		GXmlDomNode* _tmp317_;
		GXmlDomNode* _tmp318_;
		GXmlGomElement* _tmp319_;
		GXmlDomNamedNodeMap* _tmp320_;
		GXmlDomNamedNodeMap* _tmp321_;
		GXmlDomNamedNodeMap* _tmp322_;
		GXmlDomNode* _tmp323_;
		GXmlDomNode* _tmp324_;
		gchar* _tmp325_;
		gchar* _tmp326_;
		gchar* _tmp327_;
		GXmlGomElement* _tmp328_;
		GXmlDomNamedNodeMap* _tmp329_;
		GXmlDomNamedNodeMap* _tmp330_;
		GXmlDomNamedNodeMap* _tmp331_;
		GXmlDomNode* _tmp332_;
		GXmlDomNode* _tmp333_;
		gchar* _tmp334_;
		gchar* _tmp335_;
		gchar* _tmp336_;
		GXmlGomElement* _tmp337_;
		GXmlDomNamedNodeMap* _tmp338_;
		GXmlDomNamedNodeMap* _tmp339_;
		GXmlDomNamedNodeMap* _tmp340_;
		GXmlDomNode* _tmp341_;
		GXmlDomNode* _tmp342_;
#line 693 "GomElementTest.vala"
		_tmp0_ = gxml_gom_element_new ();
#line 693 "GomElementTest.vala"
		e = _tmp0_;
#line 694 "GomElementTest.vala"
		_tmp1_ = e;
#line 694 "GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp1_, "a1", "v1", &_inner_error0_);
#line 694 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 694 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 9266 "GomElementTest.c"
			goto __catch140_g_error;
		}
#line 695 "GomElementTest.vala"
		_tmp2_ = e;
#line 695 "GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp2_, "a2", "v2", &_inner_error0_);
#line 695 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 695 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 9277 "GomElementTest.c"
			goto __catch140_g_error;
		}
#line 696 "GomElementTest.vala"
		_tmp3_ = e;
#line 696 "GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp3_, "a3", "v3", &_inner_error0_);
#line 696 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 696 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 9288 "GomElementTest.c"
			goto __catch140_g_error;
		}
#line 697 "GomElementTest.vala"
		_tmp4_ = e;
#line 697 "GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp4_, "a4", "v4", &_inner_error0_);
#line 697 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 697 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 9299 "GomElementTest.c"
			goto __catch140_g_error;
		}
#line 698 "GomElementTest.vala"
		_tmp5_ = e;
#line 698 "GomElementTest.vala"
		_tmp6_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp5_);
#line 698 "GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 698 "GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 698 "GomElementTest.vala"
		_tmp9_ = gxml_dom_named_node_map_get_length (_tmp8_);
#line 698 "GomElementTest.vala"
		_tmp10_ = _tmp9_;
#line 698 "GomElementTest.vala"
		_vala_assert (_tmp10_ == 4, "e.attributes.length == 4");
#line 698 "GomElementTest.vala"
		_g_object_unref0 (_tmp8_);
#line 9318 "GomElementTest.c"
		{
			gint i = 0;
#line 699 "GomElementTest.vala"
			i = 0;
#line 9323 "GomElementTest.c"
			{
				gboolean _tmp11_ = FALSE;
#line 699 "GomElementTest.vala"
				_tmp11_ = TRUE;
#line 699 "GomElementTest.vala"
				while (TRUE) {
#line 9330 "GomElementTest.c"
					GXmlGomElement* _tmp13_;
					GXmlDomNamedNodeMap* _tmp14_;
					GXmlDomNamedNodeMap* _tmp15_;
					GXmlDomNamedNodeMap* _tmp16_;
					gint _tmp17_;
					gint _tmp18_;
					gboolean _tmp19_;
					GXmlGomElement* _tmp20_;
					GXmlDomNamedNodeMap* _tmp21_;
					GXmlDomNamedNodeMap* _tmp22_;
					GXmlDomNamedNodeMap* _tmp23_;
					GXmlDomNode* _tmp24_;
					GXmlDomNode* _tmp25_;
#line 699 "GomElementTest.vala"
					if (!_tmp11_) {
#line 9346 "GomElementTest.c"
						gint _tmp12_;
#line 699 "GomElementTest.vala"
						_tmp12_ = i;
#line 699 "GomElementTest.vala"
						i = _tmp12_ + 1;
#line 9352 "GomElementTest.c"
					}
#line 699 "GomElementTest.vala"
					_tmp11_ = FALSE;
#line 699 "GomElementTest.vala"
					_tmp13_ = e;
#line 699 "GomElementTest.vala"
					_tmp14_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp13_);
#line 699 "GomElementTest.vala"
					_tmp15_ = _tmp14_;
#line 699 "GomElementTest.vala"
					_tmp16_ = _tmp15_;
#line 699 "GomElementTest.vala"
					_tmp17_ = gxml_dom_named_node_map_get_length (_tmp16_);
#line 699 "GomElementTest.vala"
					_tmp18_ = _tmp17_;
#line 699 "GomElementTest.vala"
					_tmp19_ = !(i < _tmp18_);
#line 699 "GomElementTest.vala"
					_g_object_unref0 (_tmp16_);
#line 699 "GomElementTest.vala"
					if (_tmp19_) {
#line 699 "GomElementTest.vala"
						break;
#line 9376 "GomElementTest.c"
					}
#line 700 "GomElementTest.vala"
					_tmp20_ = e;
#line 700 "GomElementTest.vala"
					_tmp21_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp20_);
#line 700 "GomElementTest.vala"
					_tmp22_ = _tmp21_;
#line 700 "GomElementTest.vala"
					_tmp23_ = _tmp22_;
#line 700 "GomElementTest.vala"
					_tmp24_ = gxml_dom_named_node_map_item (_tmp23_, i);
#line 700 "GomElementTest.vala"
					_tmp25_ = _tmp24_;
#line 700 "GomElementTest.vala"
					_vala_assert (_tmp25_ != NULL, "e.attributes.item (i) != null");
#line 700 "GomElementTest.vala"
					_g_object_unref0 (_tmp25_);
#line 700 "GomElementTest.vala"
					_g_object_unref0 (_tmp23_);
#line 9396 "GomElementTest.c"
				}
			}
		}
#line 702 "GomElementTest.vala"
		_tmp26_ = e;
#line 702 "GomElementTest.vala"
		_tmp27_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp26_);
#line 702 "GomElementTest.vala"
		_tmp28_ = _tmp27_;
#line 702 "GomElementTest.vala"
		_tmp29_ = _tmp28_;
#line 702 "GomElementTest.vala"
		_tmp30_ = gxml_dom_named_node_map_item (_tmp29_, 0);
#line 702 "GomElementTest.vala"
		_tmp31_ = _tmp30_;
#line 702 "GomElementTest.vala"
		_vala_assert (_tmp31_ != NULL, "e.attributes.item (0) != null");
#line 702 "GomElementTest.vala"
		_g_object_unref0 (_tmp31_);
#line 702 "GomElementTest.vala"
		_g_object_unref0 (_tmp29_);
#line 703 "GomElementTest.vala"
		_tmp32_ = e;
#line 703 "GomElementTest.vala"
		_tmp33_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp32_);
#line 703 "GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 703 "GomElementTest.vala"
		_tmp35_ = _tmp34_;
#line 703 "GomElementTest.vala"
		_tmp36_ = gxml_dom_named_node_map_item (_tmp35_, 0);
#line 703 "GomElementTest.vala"
		_tmp37_ = _tmp36_;
#line 703 "GomElementTest.vala"
		_tmp38_ = gxml_dom_node_get_node_name (_tmp37_);
#line 703 "GomElementTest.vala"
		_tmp39_ = _tmp38_;
#line 703 "GomElementTest.vala"
		_tmp40_ = _tmp39_;
#line 703 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp40_, "a1") == 0, "e.attributes.item (0).node_name == \"a1\"");
#line 703 "GomElementTest.vala"
		_g_free0 (_tmp40_);
#line 703 "GomElementTest.vala"
		_g_object_unref0 (_tmp37_);
#line 703 "GomElementTest.vala"
		_g_object_unref0 (_tmp35_);
#line 704 "GomElementTest.vala"
		_tmp41_ = e;
#line 704 "GomElementTest.vala"
		_tmp42_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp41_);
#line 704 "GomElementTest.vala"
		_tmp43_ = _tmp42_;
#line 704 "GomElementTest.vala"
		_tmp44_ = _tmp43_;
#line 704 "GomElementTest.vala"
		_tmp45_ = gxml_dom_named_node_map_item (_tmp44_, 0);
#line 704 "GomElementTest.vala"
		_tmp46_ = _tmp45_;
#line 704 "GomElementTest.vala"
		_tmp47_ = gxml_dom_node_get_node_value (_tmp46_);
#line 704 "GomElementTest.vala"
		_tmp48_ = _tmp47_;
#line 704 "GomElementTest.vala"
		_tmp49_ = _tmp48_;
#line 704 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp49_, "v1") == 0, "e.attributes.item (0).node_value == \"v1\"");
#line 704 "GomElementTest.vala"
		_g_free0 (_tmp49_);
#line 704 "GomElementTest.vala"
		_g_object_unref0 (_tmp46_);
#line 704 "GomElementTest.vala"
		_g_object_unref0 (_tmp44_);
#line 705 "GomElementTest.vala"
		_tmp50_ = e;
#line 705 "GomElementTest.vala"
		_tmp51_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp50_);
#line 705 "GomElementTest.vala"
		_tmp52_ = _tmp51_;
#line 705 "GomElementTest.vala"
		_tmp53_ = _tmp52_;
#line 705 "GomElementTest.vala"
		_tmp54_ = gxml_dom_named_node_map_item (_tmp53_, 1);
#line 705 "GomElementTest.vala"
		_tmp55_ = _tmp54_;
#line 705 "GomElementTest.vala"
		_vala_assert (_tmp55_ != NULL, "e.attributes.item (1) != null");
#line 705 "GomElementTest.vala"
		_g_object_unref0 (_tmp55_);
#line 705 "GomElementTest.vala"
		_g_object_unref0 (_tmp53_);
#line 706 "GomElementTest.vala"
		_tmp56_ = e;
#line 706 "GomElementTest.vala"
		_tmp57_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp56_);
#line 706 "GomElementTest.vala"
		_tmp58_ = _tmp57_;
#line 706 "GomElementTest.vala"
		_tmp59_ = _tmp58_;
#line 706 "GomElementTest.vala"
		_tmp60_ = gxml_dom_named_node_map_item (_tmp59_, 1);
#line 706 "GomElementTest.vala"
		_tmp61_ = _tmp60_;
#line 706 "GomElementTest.vala"
		_tmp62_ = gxml_dom_node_get_node_name (_tmp61_);
#line 706 "GomElementTest.vala"
		_tmp63_ = _tmp62_;
#line 706 "GomElementTest.vala"
		_tmp64_ = _tmp63_;
#line 706 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp64_, "a2") == 0, "e.attributes.item (1).node_name == \"a2\"");
#line 706 "GomElementTest.vala"
		_g_free0 (_tmp64_);
#line 706 "GomElementTest.vala"
		_g_object_unref0 (_tmp61_);
#line 706 "GomElementTest.vala"
		_g_object_unref0 (_tmp59_);
#line 707 "GomElementTest.vala"
		_tmp65_ = e;
#line 707 "GomElementTest.vala"
		_tmp66_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp65_);
#line 707 "GomElementTest.vala"
		_tmp67_ = _tmp66_;
#line 707 "GomElementTest.vala"
		_tmp68_ = _tmp67_;
#line 707 "GomElementTest.vala"
		_tmp69_ = gxml_dom_named_node_map_item (_tmp68_, 1);
#line 707 "GomElementTest.vala"
		_tmp70_ = _tmp69_;
#line 707 "GomElementTest.vala"
		_tmp71_ = gxml_dom_node_get_node_value (_tmp70_);
#line 707 "GomElementTest.vala"
		_tmp72_ = _tmp71_;
#line 707 "GomElementTest.vala"
		_tmp73_ = _tmp72_;
#line 707 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp73_, "v2") == 0, "e.attributes.item (1).node_value == \"v2\"");
#line 707 "GomElementTest.vala"
		_g_free0 (_tmp73_);
#line 707 "GomElementTest.vala"
		_g_object_unref0 (_tmp70_);
#line 707 "GomElementTest.vala"
		_g_object_unref0 (_tmp68_);
#line 708 "GomElementTest.vala"
		_tmp74_ = e;
#line 708 "GomElementTest.vala"
		_tmp75_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp74_);
#line 708 "GomElementTest.vala"
		_tmp76_ = _tmp75_;
#line 708 "GomElementTest.vala"
		_tmp77_ = _tmp76_;
#line 708 "GomElementTest.vala"
		_tmp78_ = gxml_dom_named_node_map_item (_tmp77_, 2);
#line 708 "GomElementTest.vala"
		_tmp79_ = _tmp78_;
#line 708 "GomElementTest.vala"
		_vala_assert (_tmp79_ != NULL, "e.attributes.item (2) != null");
#line 708 "GomElementTest.vala"
		_g_object_unref0 (_tmp79_);
#line 708 "GomElementTest.vala"
		_g_object_unref0 (_tmp77_);
#line 709 "GomElementTest.vala"
		_tmp80_ = e;
#line 709 "GomElementTest.vala"
		_tmp81_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp80_);
#line 709 "GomElementTest.vala"
		_tmp82_ = _tmp81_;
#line 709 "GomElementTest.vala"
		_tmp83_ = _tmp82_;
#line 709 "GomElementTest.vala"
		_tmp84_ = gxml_dom_named_node_map_item (_tmp83_, 2);
#line 709 "GomElementTest.vala"
		_tmp85_ = _tmp84_;
#line 709 "GomElementTest.vala"
		_tmp86_ = gxml_dom_node_get_node_name (_tmp85_);
#line 709 "GomElementTest.vala"
		_tmp87_ = _tmp86_;
#line 709 "GomElementTest.vala"
		_tmp88_ = _tmp87_;
#line 709 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp88_, "a3") == 0, "e.attributes.item (2).node_name == \"a3\"");
#line 709 "GomElementTest.vala"
		_g_free0 (_tmp88_);
#line 709 "GomElementTest.vala"
		_g_object_unref0 (_tmp85_);
#line 709 "GomElementTest.vala"
		_g_object_unref0 (_tmp83_);
#line 710 "GomElementTest.vala"
		_tmp89_ = e;
#line 710 "GomElementTest.vala"
		_tmp90_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp89_);
#line 710 "GomElementTest.vala"
		_tmp91_ = _tmp90_;
#line 710 "GomElementTest.vala"
		_tmp92_ = _tmp91_;
#line 710 "GomElementTest.vala"
		_tmp93_ = gxml_dom_named_node_map_item (_tmp92_, 2);
#line 710 "GomElementTest.vala"
		_tmp94_ = _tmp93_;
#line 710 "GomElementTest.vala"
		_tmp95_ = gxml_dom_node_get_node_value (_tmp94_);
#line 710 "GomElementTest.vala"
		_tmp96_ = _tmp95_;
#line 710 "GomElementTest.vala"
		_tmp97_ = _tmp96_;
#line 710 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp97_, "v3") == 0, "e.attributes.item (2).node_value == \"v3\"");
#line 710 "GomElementTest.vala"
		_g_free0 (_tmp97_);
#line 710 "GomElementTest.vala"
		_g_object_unref0 (_tmp94_);
#line 710 "GomElementTest.vala"
		_g_object_unref0 (_tmp92_);
#line 711 "GomElementTest.vala"
		_tmp98_ = e;
#line 711 "GomElementTest.vala"
		_tmp99_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp98_);
#line 711 "GomElementTest.vala"
		_tmp100_ = _tmp99_;
#line 711 "GomElementTest.vala"
		_tmp101_ = _tmp100_;
#line 711 "GomElementTest.vala"
		_tmp102_ = gxml_dom_named_node_map_item (_tmp101_, 3);
#line 711 "GomElementTest.vala"
		_tmp103_ = _tmp102_;
#line 711 "GomElementTest.vala"
		_vala_assert (_tmp103_ != NULL, "e.attributes.item (3) != null");
#line 711 "GomElementTest.vala"
		_g_object_unref0 (_tmp103_);
#line 711 "GomElementTest.vala"
		_g_object_unref0 (_tmp101_);
#line 712 "GomElementTest.vala"
		_tmp104_ = e;
#line 712 "GomElementTest.vala"
		_tmp105_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp104_);
#line 712 "GomElementTest.vala"
		_tmp106_ = _tmp105_;
#line 712 "GomElementTest.vala"
		_tmp107_ = _tmp106_;
#line 712 "GomElementTest.vala"
		_tmp108_ = gxml_dom_named_node_map_item (_tmp107_, 3);
#line 712 "GomElementTest.vala"
		_tmp109_ = _tmp108_;
#line 712 "GomElementTest.vala"
		_tmp110_ = gxml_dom_node_get_node_name (_tmp109_);
#line 712 "GomElementTest.vala"
		_tmp111_ = _tmp110_;
#line 712 "GomElementTest.vala"
		_tmp112_ = _tmp111_;
#line 712 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp112_, "a4") == 0, "e.attributes.item (3).node_name == \"a4\"");
#line 712 "GomElementTest.vala"
		_g_free0 (_tmp112_);
#line 712 "GomElementTest.vala"
		_g_object_unref0 (_tmp109_);
#line 712 "GomElementTest.vala"
		_g_object_unref0 (_tmp107_);
#line 713 "GomElementTest.vala"
		_tmp113_ = e;
#line 713 "GomElementTest.vala"
		_tmp114_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp113_);
#line 713 "GomElementTest.vala"
		_tmp115_ = _tmp114_;
#line 713 "GomElementTest.vala"
		_tmp116_ = _tmp115_;
#line 713 "GomElementTest.vala"
		_tmp117_ = gxml_dom_named_node_map_item (_tmp116_, 3);
#line 713 "GomElementTest.vala"
		_tmp118_ = _tmp117_;
#line 713 "GomElementTest.vala"
		_tmp119_ = gxml_dom_node_get_node_value (_tmp118_);
#line 713 "GomElementTest.vala"
		_tmp120_ = _tmp119_;
#line 713 "GomElementTest.vala"
		_tmp121_ = _tmp120_;
#line 713 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp121_, "v4") == 0, "e.attributes.item (3).node_value == \"v4\"");
#line 713 "GomElementTest.vala"
		_g_free0 (_tmp121_);
#line 713 "GomElementTest.vala"
		_g_object_unref0 (_tmp118_);
#line 713 "GomElementTest.vala"
		_g_object_unref0 (_tmp116_);
#line 714 "GomElementTest.vala"
		_tmp122_ = e;
#line 714 "GomElementTest.vala"
		gxml_dom_element_remove_attribute ((GXmlDomElement*) _tmp122_, "a3");
#line 715 "GomElementTest.vala"
		_tmp123_ = e;
#line 715 "GomElementTest.vala"
		_tmp124_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp123_);
#line 715 "GomElementTest.vala"
		_tmp125_ = _tmp124_;
#line 715 "GomElementTest.vala"
		_tmp126_ = _tmp125_;
#line 715 "GomElementTest.vala"
		_tmp127_ = gxml_dom_named_node_map_get_length (_tmp126_);
#line 715 "GomElementTest.vala"
		_tmp128_ = _tmp127_;
#line 715 "GomElementTest.vala"
		_vala_assert (_tmp128_ == 3, "e.attributes.length == 3");
#line 715 "GomElementTest.vala"
		_g_object_unref0 (_tmp126_);
#line 716 "GomElementTest.vala"
		_tmp129_ = e;
#line 716 "GomElementTest.vala"
		_tmp130_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp129_);
#line 716 "GomElementTest.vala"
		_tmp131_ = _tmp130_;
#line 716 "GomElementTest.vala"
		_tmp132_ = _tmp131_;
#line 716 "GomElementTest.vala"
		_tmp133_ = gxml_dom_named_node_map_item (_tmp132_, 2);
#line 716 "GomElementTest.vala"
		_tmp134_ = _tmp133_;
#line 716 "GomElementTest.vala"
		_vala_assert (_tmp134_ != NULL, "e.attributes.item (2) != null");
#line 716 "GomElementTest.vala"
		_g_object_unref0 (_tmp134_);
#line 716 "GomElementTest.vala"
		_g_object_unref0 (_tmp132_);
#line 717 "GomElementTest.vala"
		_tmp135_ = e;
#line 717 "GomElementTest.vala"
		_tmp136_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp135_);
#line 717 "GomElementTest.vala"
		_tmp137_ = _tmp136_;
#line 717 "GomElementTest.vala"
		_tmp138_ = _tmp137_;
#line 717 "GomElementTest.vala"
		_tmp139_ = gxml_dom_named_node_map_item (_tmp138_, 2);
#line 717 "GomElementTest.vala"
		_tmp140_ = _tmp139_;
#line 717 "GomElementTest.vala"
		_tmp141_ = gxml_dom_node_get_node_name (_tmp140_);
#line 717 "GomElementTest.vala"
		_tmp142_ = _tmp141_;
#line 717 "GomElementTest.vala"
		_tmp143_ = _tmp142_;
#line 717 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp143_, "a4") == 0, "e.attributes.item (2).node_name == \"a4\"");
#line 717 "GomElementTest.vala"
		_g_free0 (_tmp143_);
#line 717 "GomElementTest.vala"
		_g_object_unref0 (_tmp140_);
#line 717 "GomElementTest.vala"
		_g_object_unref0 (_tmp138_);
#line 718 "GomElementTest.vala"
		_tmp144_ = e;
#line 718 "GomElementTest.vala"
		_tmp145_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp144_);
#line 718 "GomElementTest.vala"
		_tmp146_ = _tmp145_;
#line 718 "GomElementTest.vala"
		_tmp147_ = _tmp146_;
#line 718 "GomElementTest.vala"
		_tmp148_ = gxml_dom_named_node_map_item (_tmp147_, 2);
#line 718 "GomElementTest.vala"
		_tmp149_ = _tmp148_;
#line 718 "GomElementTest.vala"
		_tmp150_ = gxml_dom_node_get_node_value (_tmp149_);
#line 718 "GomElementTest.vala"
		_tmp151_ = _tmp150_;
#line 718 "GomElementTest.vala"
		_tmp152_ = _tmp151_;
#line 718 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp152_, "v4") == 0, "e.attributes.item (2).node_value == \"v4\"");
#line 718 "GomElementTest.vala"
		_g_free0 (_tmp152_);
#line 718 "GomElementTest.vala"
		_g_object_unref0 (_tmp149_);
#line 718 "GomElementTest.vala"
		_g_object_unref0 (_tmp147_);
#line 719 "GomElementTest.vala"
		_tmp153_ = e;
#line 719 "GomElementTest.vala"
		_tmp154_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp153_);
#line 719 "GomElementTest.vala"
		_tmp155_ = _tmp154_;
#line 719 "GomElementTest.vala"
		_tmp156_ = _tmp155_;
#line 719 "GomElementTest.vala"
		_tmp157_ = gxml_dom_named_node_map_item (_tmp156_, 3);
#line 719 "GomElementTest.vala"
		_tmp158_ = _tmp157_;
#line 719 "GomElementTest.vala"
		_vala_assert (_tmp158_ == NULL, "e.attributes.item (3) == null");
#line 719 "GomElementTest.vala"
		_g_object_unref0 (_tmp158_);
#line 719 "GomElementTest.vala"
		_g_object_unref0 (_tmp156_);
#line 721 "GomElementTest.vala"
		_tmp159_ = gxml_gom_element_new ();
#line 721 "GomElementTest.vala"
		e2 = _tmp159_;
#line 722 "GomElementTest.vala"
		_tmp160_ = e2;
#line 722 "GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp160_, "http://www.w3.org/2000/xmlns", "xmlns:gxml", "http://wiki.gnome.org/GXml", &_inner_error0_);
#line 722 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 722 "GomElementTest.vala"
			_g_object_unref0 (e2);
#line 722 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 9802 "GomElementTest.c"
			goto __catch140_g_error;
		}
#line 723 "GomElementTest.vala"
		_tmp161_ = e2;
#line 723 "GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp161_, "http://wiki.gnome.org/GXml", "gxml:a1", "v1", &_inner_error0_);
#line 723 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 723 "GomElementTest.vala"
			_g_object_unref0 (e2);
#line 723 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 9815 "GomElementTest.c"
			goto __catch140_g_error;
		}
#line 724 "GomElementTest.vala"
		_tmp162_ = e2;
#line 724 "GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp162_, "http://wiki.gnome.org/GXml", "gxml:a2", "v2", &_inner_error0_);
#line 724 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 724 "GomElementTest.vala"
			_g_object_unref0 (e2);
#line 724 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 9828 "GomElementTest.c"
			goto __catch140_g_error;
		}
#line 725 "GomElementTest.vala"
		_tmp163_ = e2;
#line 725 "GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp163_, "http://wiki.gnome.org/GXml", "gxml:a3", "v3", &_inner_error0_);
#line 725 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 725 "GomElementTest.vala"
			_g_object_unref0 (e2);
#line 725 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 9841 "GomElementTest.c"
			goto __catch140_g_error;
		}
#line 726 "GomElementTest.vala"
		_tmp164_ = e2;
#line 726 "GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp164_, "http://wiki.gnome.org/GXml", "gxml:a4", "v4", &_inner_error0_);
#line 726 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 726 "GomElementTest.vala"
			_g_object_unref0 (e2);
#line 726 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 9854 "GomElementTest.c"
			goto __catch140_g_error;
		}
#line 727 "GomElementTest.vala"
		_tmp165_ = e2;
#line 727 "GomElementTest.vala"
		_tmp166_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp165_);
#line 727 "GomElementTest.vala"
		_tmp167_ = _tmp166_;
#line 727 "GomElementTest.vala"
		_tmp168_ = _tmp167_;
#line 727 "GomElementTest.vala"
		_tmp169_ = gxml_dom_named_node_map_get_length (_tmp168_);
#line 727 "GomElementTest.vala"
		_tmp170_ = _tmp169_;
#line 727 "GomElementTest.vala"
		_vala_assert (_tmp170_ == 5, "e2.attributes.length == 5");
#line 727 "GomElementTest.vala"
		_g_object_unref0 (_tmp168_);
#line 9873 "GomElementTest.c"
		{
			gint i = 0;
#line 728 "GomElementTest.vala"
			i = 0;
#line 9878 "GomElementTest.c"
			{
				gboolean _tmp171_ = FALSE;
#line 728 "GomElementTest.vala"
				_tmp171_ = TRUE;
#line 728 "GomElementTest.vala"
				while (TRUE) {
#line 9885 "GomElementTest.c"
					GXmlGomElement* _tmp173_;
					GXmlDomNamedNodeMap* _tmp174_;
					GXmlDomNamedNodeMap* _tmp175_;
					GXmlDomNamedNodeMap* _tmp176_;
					gint _tmp177_;
					gint _tmp178_;
					gboolean _tmp179_;
					GXmlGomElement* _tmp180_;
					GXmlDomNamedNodeMap* _tmp181_;
					GXmlDomNamedNodeMap* _tmp182_;
					GXmlDomNamedNodeMap* _tmp183_;
					GXmlDomNode* _tmp184_;
					GXmlDomNode* _tmp185_;
#line 728 "GomElementTest.vala"
					if (!_tmp171_) {
#line 9901 "GomElementTest.c"
						gint _tmp172_;
#line 728 "GomElementTest.vala"
						_tmp172_ = i;
#line 728 "GomElementTest.vala"
						i = _tmp172_ + 1;
#line 9907 "GomElementTest.c"
					}
#line 728 "GomElementTest.vala"
					_tmp171_ = FALSE;
#line 728 "GomElementTest.vala"
					_tmp173_ = e2;
#line 728 "GomElementTest.vala"
					_tmp174_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp173_);
#line 728 "GomElementTest.vala"
					_tmp175_ = _tmp174_;
#line 728 "GomElementTest.vala"
					_tmp176_ = _tmp175_;
#line 728 "GomElementTest.vala"
					_tmp177_ = gxml_dom_named_node_map_get_length (_tmp176_);
#line 728 "GomElementTest.vala"
					_tmp178_ = _tmp177_;
#line 728 "GomElementTest.vala"
					_tmp179_ = !(i < _tmp178_);
#line 728 "GomElementTest.vala"
					_g_object_unref0 (_tmp176_);
#line 728 "GomElementTest.vala"
					if (_tmp179_) {
#line 728 "GomElementTest.vala"
						break;
#line 9931 "GomElementTest.c"
					}
#line 729 "GomElementTest.vala"
					_tmp180_ = e2;
#line 729 "GomElementTest.vala"
					_tmp181_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp180_);
#line 729 "GomElementTest.vala"
					_tmp182_ = _tmp181_;
#line 729 "GomElementTest.vala"
					_tmp183_ = _tmp182_;
#line 729 "GomElementTest.vala"
					_tmp184_ = gxml_dom_named_node_map_item (_tmp183_, i);
#line 729 "GomElementTest.vala"
					_tmp185_ = _tmp184_;
#line 729 "GomElementTest.vala"
					_vala_assert (_tmp185_ != NULL, "e2.attributes.item (i) != null");
#line 729 "GomElementTest.vala"
					_g_object_unref0 (_tmp185_);
#line 729 "GomElementTest.vala"
					_g_object_unref0 (_tmp183_);
#line 9951 "GomElementTest.c"
				}
			}
		}
#line 731 "GomElementTest.vala"
		_tmp186_ = e2;
#line 731 "GomElementTest.vala"
		_tmp187_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp186_);
#line 731 "GomElementTest.vala"
		_tmp188_ = _tmp187_;
#line 731 "GomElementTest.vala"
		_tmp189_ = _tmp188_;
#line 731 "GomElementTest.vala"
		_tmp190_ = gxml_dom_named_node_map_item (_tmp189_, 0);
#line 731 "GomElementTest.vala"
		_tmp191_ = _tmp190_;
#line 731 "GomElementTest.vala"
		_vala_assert (_tmp191_ != NULL, "e2.attributes.item (0) != null");
#line 731 "GomElementTest.vala"
		_g_object_unref0 (_tmp191_);
#line 731 "GomElementTest.vala"
		_g_object_unref0 (_tmp189_);
#line 732 "GomElementTest.vala"
		_tmp192_ = e2;
#line 732 "GomElementTest.vala"
		_tmp193_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp192_);
#line 732 "GomElementTest.vala"
		_tmp194_ = _tmp193_;
#line 732 "GomElementTest.vala"
		_tmp195_ = _tmp194_;
#line 732 "GomElementTest.vala"
		_tmp196_ = gxml_dom_named_node_map_item (_tmp195_, 0);
#line 732 "GomElementTest.vala"
		_tmp197_ = _tmp196_;
#line 732 "GomElementTest.vala"
		_tmp198_ = gxml_dom_node_get_node_name (_tmp197_);
#line 732 "GomElementTest.vala"
		_tmp199_ = _tmp198_;
#line 732 "GomElementTest.vala"
		_tmp200_ = _tmp199_;
#line 732 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp200_, "xmlns:gxml") == 0, "e2.attributes.item (0).node_name == \"xmlns:gxml\"");
#line 732 "GomElementTest.vala"
		_g_free0 (_tmp200_);
#line 732 "GomElementTest.vala"
		_g_object_unref0 (_tmp197_);
#line 732 "GomElementTest.vala"
		_g_object_unref0 (_tmp195_);
#line 733 "GomElementTest.vala"
		_tmp201_ = e2;
#line 733 "GomElementTest.vala"
		_tmp202_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp201_);
#line 733 "GomElementTest.vala"
		_tmp203_ = _tmp202_;
#line 733 "GomElementTest.vala"
		_tmp204_ = _tmp203_;
#line 733 "GomElementTest.vala"
		_tmp205_ = gxml_dom_named_node_map_item (_tmp204_, 0);
#line 733 "GomElementTest.vala"
		_tmp206_ = _tmp205_;
#line 733 "GomElementTest.vala"
		_tmp207_ = gxml_dom_node_get_node_value (_tmp206_);
#line 733 "GomElementTest.vala"
		_tmp208_ = _tmp207_;
#line 733 "GomElementTest.vala"
		_tmp209_ = _tmp208_;
#line 733 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp209_, "http://wiki.gnome.org/GXml") == 0, "e2.attributes.item (0).node_value == \"http://wiki.gnome.org/GXml\"");
#line 733 "GomElementTest.vala"
		_g_free0 (_tmp209_);
#line 733 "GomElementTest.vala"
		_g_object_unref0 (_tmp206_);
#line 733 "GomElementTest.vala"
		_g_object_unref0 (_tmp204_);
#line 734 "GomElementTest.vala"
		_tmp210_ = e2;
#line 734 "GomElementTest.vala"
		_tmp211_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp210_);
#line 734 "GomElementTest.vala"
		_tmp212_ = _tmp211_;
#line 734 "GomElementTest.vala"
		_tmp213_ = _tmp212_;
#line 734 "GomElementTest.vala"
		_tmp214_ = gxml_dom_named_node_map_item (_tmp213_, 1);
#line 734 "GomElementTest.vala"
		_tmp215_ = _tmp214_;
#line 734 "GomElementTest.vala"
		_vala_assert (_tmp215_ != NULL, "e2.attributes.item (1) != null");
#line 734 "GomElementTest.vala"
		_g_object_unref0 (_tmp215_);
#line 734 "GomElementTest.vala"
		_g_object_unref0 (_tmp213_);
#line 735 "GomElementTest.vala"
		_tmp216_ = e2;
#line 735 "GomElementTest.vala"
		_tmp217_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp216_);
#line 735 "GomElementTest.vala"
		_tmp218_ = _tmp217_;
#line 735 "GomElementTest.vala"
		_tmp219_ = _tmp218_;
#line 735 "GomElementTest.vala"
		_tmp220_ = gxml_dom_named_node_map_item (_tmp219_, 1);
#line 735 "GomElementTest.vala"
		_tmp221_ = _tmp220_;
#line 735 "GomElementTest.vala"
		_tmp222_ = gxml_dom_node_get_node_name (_tmp221_);
#line 735 "GomElementTest.vala"
		_tmp223_ = _tmp222_;
#line 735 "GomElementTest.vala"
		_tmp224_ = _tmp223_;
#line 735 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp224_, "gxml:a1") == 0, "e2.attributes.item (1).node_name == \"gxml:a1\"");
#line 735 "GomElementTest.vala"
		_g_free0 (_tmp224_);
#line 735 "GomElementTest.vala"
		_g_object_unref0 (_tmp221_);
#line 735 "GomElementTest.vala"
		_g_object_unref0 (_tmp219_);
#line 736 "GomElementTest.vala"
		_tmp225_ = e2;
#line 736 "GomElementTest.vala"
		_tmp226_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp225_);
#line 736 "GomElementTest.vala"
		_tmp227_ = _tmp226_;
#line 736 "GomElementTest.vala"
		_tmp228_ = _tmp227_;
#line 736 "GomElementTest.vala"
		_tmp229_ = gxml_dom_named_node_map_item (_tmp228_, 1);
#line 736 "GomElementTest.vala"
		_tmp230_ = _tmp229_;
#line 736 "GomElementTest.vala"
		_tmp231_ = gxml_dom_node_get_node_value (_tmp230_);
#line 736 "GomElementTest.vala"
		_tmp232_ = _tmp231_;
#line 736 "GomElementTest.vala"
		_tmp233_ = _tmp232_;
#line 736 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp233_, "v1") == 0, "e2.attributes.item (1).node_value == \"v1\"");
#line 736 "GomElementTest.vala"
		_g_free0 (_tmp233_);
#line 736 "GomElementTest.vala"
		_g_object_unref0 (_tmp230_);
#line 736 "GomElementTest.vala"
		_g_object_unref0 (_tmp228_);
#line 737 "GomElementTest.vala"
		_tmp234_ = e2;
#line 737 "GomElementTest.vala"
		_tmp235_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp234_);
#line 737 "GomElementTest.vala"
		_tmp236_ = _tmp235_;
#line 737 "GomElementTest.vala"
		_tmp237_ = _tmp236_;
#line 737 "GomElementTest.vala"
		_tmp238_ = gxml_dom_named_node_map_item (_tmp237_, 2);
#line 737 "GomElementTest.vala"
		_tmp239_ = _tmp238_;
#line 737 "GomElementTest.vala"
		_vala_assert (_tmp239_ != NULL, "e2.attributes.item (2) != null");
#line 737 "GomElementTest.vala"
		_g_object_unref0 (_tmp239_);
#line 737 "GomElementTest.vala"
		_g_object_unref0 (_tmp237_);
#line 738 "GomElementTest.vala"
		_tmp240_ = e2;
#line 738 "GomElementTest.vala"
		_tmp241_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp240_);
#line 738 "GomElementTest.vala"
		_tmp242_ = _tmp241_;
#line 738 "GomElementTest.vala"
		_tmp243_ = _tmp242_;
#line 738 "GomElementTest.vala"
		_tmp244_ = gxml_dom_named_node_map_item (_tmp243_, 2);
#line 738 "GomElementTest.vala"
		_tmp245_ = _tmp244_;
#line 738 "GomElementTest.vala"
		_tmp246_ = gxml_dom_node_get_node_name (_tmp245_);
#line 738 "GomElementTest.vala"
		_tmp247_ = _tmp246_;
#line 738 "GomElementTest.vala"
		_tmp248_ = _tmp247_;
#line 738 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp248_, "gxml:a2") == 0, "e2.attributes.item (2).node_name == \"gxml:a2\"");
#line 738 "GomElementTest.vala"
		_g_free0 (_tmp248_);
#line 738 "GomElementTest.vala"
		_g_object_unref0 (_tmp245_);
#line 738 "GomElementTest.vala"
		_g_object_unref0 (_tmp243_);
#line 739 "GomElementTest.vala"
		_tmp249_ = e2;
#line 739 "GomElementTest.vala"
		_tmp250_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp249_);
#line 739 "GomElementTest.vala"
		_tmp251_ = _tmp250_;
#line 739 "GomElementTest.vala"
		_tmp252_ = _tmp251_;
#line 739 "GomElementTest.vala"
		_tmp253_ = gxml_dom_named_node_map_item (_tmp252_, 2);
#line 739 "GomElementTest.vala"
		_tmp254_ = _tmp253_;
#line 739 "GomElementTest.vala"
		_tmp255_ = gxml_dom_node_get_node_value (_tmp254_);
#line 739 "GomElementTest.vala"
		_tmp256_ = _tmp255_;
#line 739 "GomElementTest.vala"
		_tmp257_ = _tmp256_;
#line 739 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp257_, "v2") == 0, "e2.attributes.item (2).node_value == \"v2\"");
#line 739 "GomElementTest.vala"
		_g_free0 (_tmp257_);
#line 739 "GomElementTest.vala"
		_g_object_unref0 (_tmp254_);
#line 739 "GomElementTest.vala"
		_g_object_unref0 (_tmp252_);
#line 740 "GomElementTest.vala"
		_tmp258_ = e2;
#line 740 "GomElementTest.vala"
		_tmp259_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp258_);
#line 740 "GomElementTest.vala"
		_tmp260_ = _tmp259_;
#line 740 "GomElementTest.vala"
		_tmp261_ = _tmp260_;
#line 740 "GomElementTest.vala"
		_tmp262_ = gxml_dom_named_node_map_item (_tmp261_, 3);
#line 740 "GomElementTest.vala"
		_tmp263_ = _tmp262_;
#line 740 "GomElementTest.vala"
		_vala_assert (_tmp263_ != NULL, "e2.attributes.item (3) != null");
#line 740 "GomElementTest.vala"
		_g_object_unref0 (_tmp263_);
#line 740 "GomElementTest.vala"
		_g_object_unref0 (_tmp261_);
#line 741 "GomElementTest.vala"
		_tmp264_ = e2;
#line 741 "GomElementTest.vala"
		_tmp265_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp264_);
#line 741 "GomElementTest.vala"
		_tmp266_ = _tmp265_;
#line 741 "GomElementTest.vala"
		_tmp267_ = _tmp266_;
#line 741 "GomElementTest.vala"
		_tmp268_ = gxml_dom_named_node_map_item (_tmp267_, 3);
#line 741 "GomElementTest.vala"
		_tmp269_ = _tmp268_;
#line 741 "GomElementTest.vala"
		_tmp270_ = gxml_dom_node_get_node_name (_tmp269_);
#line 741 "GomElementTest.vala"
		_tmp271_ = _tmp270_;
#line 741 "GomElementTest.vala"
		_tmp272_ = _tmp271_;
#line 741 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp272_, "gxml:a3") == 0, "e2.attributes.item (3).node_name == \"gxml:a3\"");
#line 741 "GomElementTest.vala"
		_g_free0 (_tmp272_);
#line 741 "GomElementTest.vala"
		_g_object_unref0 (_tmp269_);
#line 741 "GomElementTest.vala"
		_g_object_unref0 (_tmp267_);
#line 742 "GomElementTest.vala"
		_tmp273_ = e2;
#line 742 "GomElementTest.vala"
		_tmp274_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp273_);
#line 742 "GomElementTest.vala"
		_tmp275_ = _tmp274_;
#line 742 "GomElementTest.vala"
		_tmp276_ = _tmp275_;
#line 742 "GomElementTest.vala"
		_tmp277_ = gxml_dom_named_node_map_item (_tmp276_, 3);
#line 742 "GomElementTest.vala"
		_tmp278_ = _tmp277_;
#line 742 "GomElementTest.vala"
		_tmp279_ = gxml_dom_node_get_node_value (_tmp278_);
#line 742 "GomElementTest.vala"
		_tmp280_ = _tmp279_;
#line 742 "GomElementTest.vala"
		_tmp281_ = _tmp280_;
#line 742 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp281_, "v3") == 0, "e2.attributes.item (3).node_value == \"v3\"");
#line 742 "GomElementTest.vala"
		_g_free0 (_tmp281_);
#line 742 "GomElementTest.vala"
		_g_object_unref0 (_tmp278_);
#line 742 "GomElementTest.vala"
		_g_object_unref0 (_tmp276_);
#line 743 "GomElementTest.vala"
		_tmp282_ = e2;
#line 743 "GomElementTest.vala"
		_tmp283_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp282_);
#line 743 "GomElementTest.vala"
		_tmp284_ = _tmp283_;
#line 743 "GomElementTest.vala"
		_tmp285_ = _tmp284_;
#line 743 "GomElementTest.vala"
		_tmp286_ = gxml_dom_named_node_map_item (_tmp285_, 4);
#line 743 "GomElementTest.vala"
		_tmp287_ = _tmp286_;
#line 743 "GomElementTest.vala"
		_vala_assert (_tmp287_ != NULL, "e2.attributes.item (4) != null");
#line 743 "GomElementTest.vala"
		_g_object_unref0 (_tmp287_);
#line 743 "GomElementTest.vala"
		_g_object_unref0 (_tmp285_);
#line 744 "GomElementTest.vala"
		_tmp288_ = e2;
#line 744 "GomElementTest.vala"
		_tmp289_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp288_);
#line 744 "GomElementTest.vala"
		_tmp290_ = _tmp289_;
#line 744 "GomElementTest.vala"
		_tmp291_ = _tmp290_;
#line 744 "GomElementTest.vala"
		_tmp292_ = gxml_dom_named_node_map_item (_tmp291_, 4);
#line 744 "GomElementTest.vala"
		_tmp293_ = _tmp292_;
#line 744 "GomElementTest.vala"
		_tmp294_ = gxml_dom_node_get_node_name (_tmp293_);
#line 744 "GomElementTest.vala"
		_tmp295_ = _tmp294_;
#line 744 "GomElementTest.vala"
		_tmp296_ = _tmp295_;
#line 744 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp296_, "gxml:a4") == 0, "e2.attributes.item (4).node_name == \"gxml:a4\"");
#line 744 "GomElementTest.vala"
		_g_free0 (_tmp296_);
#line 744 "GomElementTest.vala"
		_g_object_unref0 (_tmp293_);
#line 744 "GomElementTest.vala"
		_g_object_unref0 (_tmp291_);
#line 745 "GomElementTest.vala"
		_tmp297_ = e2;
#line 745 "GomElementTest.vala"
		_tmp298_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp297_);
#line 745 "GomElementTest.vala"
		_tmp299_ = _tmp298_;
#line 745 "GomElementTest.vala"
		_tmp300_ = _tmp299_;
#line 745 "GomElementTest.vala"
		_tmp301_ = gxml_dom_named_node_map_item (_tmp300_, 4);
#line 745 "GomElementTest.vala"
		_tmp302_ = _tmp301_;
#line 745 "GomElementTest.vala"
		_tmp303_ = gxml_dom_node_get_node_value (_tmp302_);
#line 745 "GomElementTest.vala"
		_tmp304_ = _tmp303_;
#line 745 "GomElementTest.vala"
		_tmp305_ = _tmp304_;
#line 745 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp305_, "v4") == 0, "e2.attributes.item (4).node_value == \"v4\"");
#line 745 "GomElementTest.vala"
		_g_free0 (_tmp305_);
#line 745 "GomElementTest.vala"
		_g_object_unref0 (_tmp302_);
#line 745 "GomElementTest.vala"
		_g_object_unref0 (_tmp300_);
#line 746 "GomElementTest.vala"
		_tmp306_ = e2;
#line 746 "GomElementTest.vala"
		gxml_dom_element_remove_attribute_ns ((GXmlDomElement*) _tmp306_, "http://wiki.gnome.org/GXml", "a3");
#line 747 "GomElementTest.vala"
		_tmp307_ = e2;
#line 747 "GomElementTest.vala"
		_tmp308_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp307_);
#line 747 "GomElementTest.vala"
		_tmp309_ = _tmp308_;
#line 747 "GomElementTest.vala"
		_tmp310_ = _tmp309_;
#line 747 "GomElementTest.vala"
		_tmp311_ = gxml_dom_named_node_map_get_length (_tmp310_);
#line 747 "GomElementTest.vala"
		_tmp312_ = _tmp311_;
#line 747 "GomElementTest.vala"
		_vala_assert (_tmp312_ == 4, "e2.attributes.length == 4");
#line 747 "GomElementTest.vala"
		_g_object_unref0 (_tmp310_);
#line 748 "GomElementTest.vala"
		_tmp313_ = e2;
#line 748 "GomElementTest.vala"
		_tmp314_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp313_);
#line 748 "GomElementTest.vala"
		_tmp315_ = _tmp314_;
#line 748 "GomElementTest.vala"
		_tmp316_ = _tmp315_;
#line 748 "GomElementTest.vala"
		_tmp317_ = gxml_dom_named_node_map_item (_tmp316_, 3);
#line 748 "GomElementTest.vala"
		_tmp318_ = _tmp317_;
#line 748 "GomElementTest.vala"
		_vala_assert (_tmp318_ != NULL, "e2.attributes.item (3) != null");
#line 748 "GomElementTest.vala"
		_g_object_unref0 (_tmp318_);
#line 748 "GomElementTest.vala"
		_g_object_unref0 (_tmp316_);
#line 749 "GomElementTest.vala"
		_tmp319_ = e2;
#line 749 "GomElementTest.vala"
		_tmp320_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp319_);
#line 749 "GomElementTest.vala"
		_tmp321_ = _tmp320_;
#line 749 "GomElementTest.vala"
		_tmp322_ = _tmp321_;
#line 749 "GomElementTest.vala"
		_tmp323_ = gxml_dom_named_node_map_item (_tmp322_, 3);
#line 749 "GomElementTest.vala"
		_tmp324_ = _tmp323_;
#line 749 "GomElementTest.vala"
		_tmp325_ = gxml_dom_node_get_node_name (_tmp324_);
#line 749 "GomElementTest.vala"
		_tmp326_ = _tmp325_;
#line 749 "GomElementTest.vala"
		_tmp327_ = _tmp326_;
#line 749 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp327_, "gxml:a4") == 0, "e2.attributes.item (3).node_name == \"gxml:a4\"");
#line 749 "GomElementTest.vala"
		_g_free0 (_tmp327_);
#line 749 "GomElementTest.vala"
		_g_object_unref0 (_tmp324_);
#line 749 "GomElementTest.vala"
		_g_object_unref0 (_tmp322_);
#line 750 "GomElementTest.vala"
		_tmp328_ = e2;
#line 750 "GomElementTest.vala"
		_tmp329_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp328_);
#line 750 "GomElementTest.vala"
		_tmp330_ = _tmp329_;
#line 750 "GomElementTest.vala"
		_tmp331_ = _tmp330_;
#line 750 "GomElementTest.vala"
		_tmp332_ = gxml_dom_named_node_map_item (_tmp331_, 3);
#line 750 "GomElementTest.vala"
		_tmp333_ = _tmp332_;
#line 750 "GomElementTest.vala"
		_tmp334_ = gxml_dom_node_get_node_value (_tmp333_);
#line 750 "GomElementTest.vala"
		_tmp335_ = _tmp334_;
#line 750 "GomElementTest.vala"
		_tmp336_ = _tmp335_;
#line 750 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp336_, "v4") == 0, "e2.attributes.item (3).node_value == \"v4\"");
#line 750 "GomElementTest.vala"
		_g_free0 (_tmp336_);
#line 750 "GomElementTest.vala"
		_g_object_unref0 (_tmp333_);
#line 750 "GomElementTest.vala"
		_g_object_unref0 (_tmp331_);
#line 751 "GomElementTest.vala"
		_tmp337_ = e2;
#line 751 "GomElementTest.vala"
		_tmp338_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp337_);
#line 751 "GomElementTest.vala"
		_tmp339_ = _tmp338_;
#line 751 "GomElementTest.vala"
		_tmp340_ = _tmp339_;
#line 751 "GomElementTest.vala"
		_tmp341_ = gxml_dom_named_node_map_item (_tmp340_, 4);
#line 751 "GomElementTest.vala"
		_tmp342_ = _tmp341_;
#line 751 "GomElementTest.vala"
		_vala_assert (_tmp342_ == NULL, "e2.attributes.item (4) == null");
#line 751 "GomElementTest.vala"
		_g_object_unref0 (_tmp342_);
#line 751 "GomElementTest.vala"
		_g_object_unref0 (_tmp340_);
#line 692 "GomElementTest.vala"
		_g_object_unref0 (e2);
#line 692 "GomElementTest.vala"
		_g_object_unref0 (e);
#line 10417 "GomElementTest.c"
	}
	goto __finally140;
	__catch140_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp343_;
		gchar* _tmp344_;
		gchar* _tmp345_;
#line 692 "GomElementTest.vala"
		e = _inner_error0_;
#line 692 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 753 "GomElementTest.vala"
		_tmp343_ = e->message;
#line 753 "GomElementTest.vala"
		_tmp344_ = g_strconcat ("Error: ", _tmp343_, NULL);
#line 753 "GomElementTest.vala"
		_tmp345_ = _tmp344_;
#line 753 "GomElementTest.vala"
		g_message ("GomElementTest.vala:753: %s", _tmp345_);
#line 753 "GomElementTest.vala"
		_g_free0 (_tmp345_);
#line 754 "GomElementTest.vala"
		g_assert_not_reached ();
#line 692 "GomElementTest.vala"
		_g_error_free0 (e);
#line 10444 "GomElementTest.c"
	}
	__finally140:
#line 692 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 692 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 692 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 692 "GomElementTest.vala"
		return;
#line 10455 "GomElementTest.c"
	}
}

static void
___lambda116__gtest_func (void)
{
#line 691 "GomElementTest.vala"
	__lambda116_ ();
#line 10464 "GomElementTest.c"
}

static void
__lambda117_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		ObjectParent* e = NULL;
		ObjectParent* _tmp0_;
		ObjectParent* _tmp1_;
		const gchar* _tmp2_;
		const gchar* _tmp3_;
		ObjectParent* _tmp4_;
		ObjectParentObjectProperty* _tmp5_;
		ObjectParentObjectProperty* _tmp6_;
		ObjectParent* _tmp7_;
		GXmlDomNamedNodeMap* _tmp8_;
		GXmlDomNamedNodeMap* _tmp9_;
		GXmlDomNamedNodeMap* _tmp10_;
		ObjectParent* _tmp11_;
		GXmlDomNamedNodeMap* _tmp12_;
		GXmlDomNamedNodeMap* _tmp13_;
		GXmlDomNamedNodeMap* _tmp14_;
		gint _tmp15_;
		gint _tmp16_;
		ObjectParent* _tmp17_;
		ObjectParent* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		ObjectParent* _tmp21_;
		ObjectParent* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
		ObjectParent* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		ObjectParent* _tmp28_;
		const gchar* _tmp29_;
		const gchar* _tmp30_;
		ObjectParent* _tmp31_;
		ObjectParentObjectProperty* _tmp32_;
		ObjectParentObjectProperty* _tmp33_;
		ObjectParent* _tmp34_;
		GXmlDomNamedNodeMap* _tmp35_;
		GXmlDomNamedNodeMap* _tmp36_;
		GXmlDomNamedNodeMap* _tmp37_;
		gint _tmp38_;
		gint _tmp39_;
		ObjectParent* _tmp40_;
		GXmlDomNamedNodeMap* _tmp41_;
		GXmlDomNamedNodeMap* _tmp42_;
		GXmlDomNamedNodeMap* _tmp43_;
		GXmlDomNode* _tmp44_;
		GXmlDomNode* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
		ObjectParent* _tmp49_;
		GXmlDomNamedNodeMap* _tmp50_;
		GXmlDomNamedNodeMap* _tmp51_;
		GXmlDomNamedNodeMap* _tmp52_;
		GXmlDomNode* _tmp53_;
		GXmlDomNode* _tmp54_;
		gchar* _tmp55_;
		gchar* _tmp56_;
		gchar* _tmp57_;
		ObjectParent* _tmp87_;
		GXmlDomNamedNodeMap* _tmp88_;
		GXmlDomNamedNodeMap* _tmp89_;
		GXmlDomNamedNodeMap* _tmp90_;
		GXmlDomNode* _tmp91_;
		GXmlDomAttr* _tmp92_;
		GXmlDomAttr* _tmp93_;
		gchar* _tmp94_;
		gchar* _tmp95_;
		gchar* _tmp96_;
		ObjectParent* _tmp97_;
		GXmlDomNamedNodeMap* _tmp98_;
		GXmlDomNamedNodeMap* _tmp99_;
		GXmlDomNamedNodeMap* _tmp100_;
		GXmlDomNode* _tmp101_;
		GXmlDomAttr* _tmp102_;
		GXmlDomAttr* _tmp103_;
		gchar* _tmp104_;
		gchar* _tmp105_;
		gchar* _tmp106_;
		ObjectParent* _tmp107_;
		ObjectParent* _tmp108_;
		ObjectParent* _tmp109_;
		ObjectParent* _tmp110_;
		GXmlDomNamedNodeMap* _tmp111_;
		GXmlDomNamedNodeMap* _tmp112_;
		GXmlDomNamedNodeMap* _tmp113_;
		gint _tmp114_;
		gint _tmp115_;
		ObjectParent* _tmp116_;
		GXmlDomNamedNodeMap* _tmp117_;
		GXmlDomNamedNodeMap* _tmp118_;
		GXmlDomNamedNodeMap* _tmp119_;
		GXmlDomNode* _tmp120_;
		GXmlDomAttr* _tmp121_;
		GXmlDomAttr* _tmp122_;
		gchar* _tmp123_;
		gchar* _tmp124_;
		gchar* _tmp125_;
		ObjectParent* _tmp126_;
		GXmlDomNamedNodeMap* _tmp127_;
		GXmlDomNamedNodeMap* _tmp128_;
		GXmlDomNamedNodeMap* _tmp129_;
		GXmlDomNode* _tmp130_;
		GXmlDomAttr* _tmp131_;
		GXmlDomAttr* _tmp132_;
		gchar* _tmp133_;
		gchar* _tmp134_;
		gchar* _tmp135_;
		ObjectParent* _tmp136_;
		GXmlDomNamedNodeMap* _tmp137_;
		GXmlDomNamedNodeMap* _tmp138_;
		GXmlDomNamedNodeMap* _tmp139_;
		GXmlDomNode* _tmp140_;
		GXmlDomAttr* _tmp141_;
		GXmlDomAttr* _tmp142_;
		gchar* _tmp143_;
		gchar* _tmp144_;
		gchar* _tmp145_;
		ObjectParent* _tmp146_;
		GXmlDomNamedNodeMap* _tmp147_;
		GXmlDomNamedNodeMap* _tmp148_;
		GXmlDomNamedNodeMap* _tmp149_;
		GXmlDomNode* _tmp150_;
		GXmlDomAttr* _tmp151_;
		GXmlDomAttr* _tmp152_;
		gchar* _tmp153_;
		gchar* _tmp154_;
		gchar* _tmp155_;
		ObjectParent* _tmp156_;
		GXmlDomNamedNodeMap* _tmp157_;
		GXmlDomNamedNodeMap* _tmp158_;
		GXmlDomNamedNodeMap* _tmp159_;
		GXmlDomNode* _tmp160_;
		GXmlDomAttr* _tmp161_;
		GXmlDomAttr* _tmp162_;
		gchar* _tmp163_;
		gchar* _tmp164_;
		gchar* _tmp165_;
		ObjectParent* _tmp166_;
		ObjectParent* _tmp167_;
		ObjectParent* _tmp168_;
		ObjectParent* _tmp169_;
		gchar* _tmp170_;
		gchar* _tmp171_;
		ObjectParent* _tmp172_;
		gchar* _tmp173_;
		gchar* _tmp174_;
		ObjectParent* _tmp175_;
		GXmlDomNamedNodeMap* _tmp176_;
		GXmlDomNamedNodeMap* _tmp177_;
		GXmlDomNamedNodeMap* _tmp178_;
		gint _tmp179_;
		gint _tmp180_;
		ObjectParent* _tmp181_;
		GXmlDomNamedNodeMap* _tmp182_;
		GXmlDomNamedNodeMap* _tmp183_;
		GXmlDomNamedNodeMap* _tmp184_;
		GXmlDomNode* _tmp185_;
		GXmlDomAttr* _tmp186_;
		GXmlDomAttr* _tmp187_;
		gchar* _tmp188_;
		gchar* _tmp189_;
		gchar* _tmp190_;
		ObjectParent* _tmp191_;
		GXmlDomNamedNodeMap* _tmp192_;
		GXmlDomNamedNodeMap* _tmp193_;
		GXmlDomNamedNodeMap* _tmp194_;
		GXmlDomNode* _tmp195_;
		GXmlDomAttr* _tmp196_;
		GXmlDomAttr* _tmp197_;
		gchar* _tmp198_;
		gchar* _tmp199_;
		gchar* _tmp200_;
		ObjectParent* _tmp201_;
		GXmlDomNamedNodeMap* _tmp202_;
		GXmlDomNamedNodeMap* _tmp203_;
		GXmlDomNamedNodeMap* _tmp204_;
		GXmlDomNode* _tmp205_;
		GXmlDomAttr* _tmp206_;
		GXmlDomAttr* _tmp207_;
		gchar* _tmp208_;
		gchar* _tmp209_;
		gchar* _tmp210_;
		ObjectParent* _tmp211_;
		GXmlDomNamedNodeMap* _tmp212_;
		GXmlDomNamedNodeMap* _tmp213_;
		GXmlDomNamedNodeMap* _tmp214_;
		GXmlDomNode* _tmp215_;
		GXmlDomAttr* _tmp216_;
		GXmlDomAttr* _tmp217_;
		gchar* _tmp218_;
		gchar* _tmp219_;
		gchar* _tmp220_;
		ObjectParent* _tmp221_;
		GXmlDomNamedNodeMap* _tmp222_;
		GXmlDomNamedNodeMap* _tmp223_;
		GXmlDomNamedNodeMap* _tmp224_;
		GXmlDomNode* _tmp225_;
		GXmlDomAttr* _tmp226_;
		GXmlDomAttr* _tmp227_;
		gchar* _tmp228_;
		gchar* _tmp229_;
		gchar* _tmp230_;
		ObjectParent* _tmp231_;
		GXmlDomNamedNodeMap* _tmp232_;
		GXmlDomNamedNodeMap* _tmp233_;
		GXmlDomNamedNodeMap* _tmp234_;
		GXmlDomNode* _tmp235_;
		GXmlDomAttr* _tmp236_;
		GXmlDomAttr* _tmp237_;
		gchar* _tmp238_;
		gchar* _tmp239_;
		gchar* _tmp240_;
		ObjectParent* _tmp241_;
		GXmlDomNamedNodeMap* _tmp242_;
		GXmlDomNamedNodeMap* _tmp243_;
		GXmlDomNamedNodeMap* _tmp244_;
		GXmlDomNode* _tmp245_;
		GXmlDomAttr* _tmp246_;
		GXmlDomAttr* _tmp247_;
		gchar* _tmp248_;
		gchar* _tmp249_;
		gchar* _tmp250_;
		ObjectParent* _tmp251_;
		GXmlDomNamedNodeMap* _tmp252_;
		GXmlDomNamedNodeMap* _tmp253_;
		GXmlDomNamedNodeMap* _tmp254_;
		GXmlDomNode* _tmp255_;
		GXmlDomAttr* _tmp256_;
		GXmlDomAttr* _tmp257_;
		gchar* _tmp258_;
		gchar* _tmp259_;
		gchar* _tmp260_;
		ObjectParent* _tmp261_;
		ObjectParent* _tmp262_;
		gchar* _tmp263_;
		gchar* _tmp264_;
		gchar* _tmp265_;
		ObjectParent* _tmp266_;
		gchar* _tmp267_;
		gchar* _tmp268_;
		ObjectParent* _tmp269_;
		GXmlDomNamedNodeMap* _tmp270_;
		GXmlDomNamedNodeMap* _tmp271_;
		GXmlDomNamedNodeMap* _tmp272_;
		gint _tmp273_;
		gint _tmp274_;
		ObjectParent* _tmp275_;
		GXmlDomNamedNodeMap* _tmp276_;
		GXmlDomNamedNodeMap* _tmp277_;
		GXmlDomNamedNodeMap* _tmp278_;
		GXmlDomNode* _tmp279_;
		GXmlDomNode* _tmp280_;
		ObjectParent* _tmp281_;
		GXmlDomNamedNodeMap* _tmp282_;
		GXmlDomNamedNodeMap* _tmp283_;
		GXmlDomNamedNodeMap* _tmp284_;
		GXmlDomNode* _tmp285_;
		GXmlDomAttr* _tmp286_;
		GXmlDomAttr* _tmp287_;
		gchar* _tmp288_;
		gchar* _tmp289_;
		gchar* _tmp290_;
		ObjectParent* _tmp291_;
		ObjectParent* _tmp292_;
		GXmlDomDocument* _tmp293_;
		GXmlDomDocument* _tmp294_;
		GObject* _tmp295_;
		GObject* _tmp296_;
		ObjectParentObjectChild* _tmp297_;
		ObjectParentObjectChild* _tmp298_;
		ObjectParent* _tmp299_;
		ObjectParent* _tmp300_;
		ObjectParentObjectChild* _tmp301_;
		ObjectParentObjectChild* _tmp302_;
		GXmlDomNode* _tmp303_;
		GXmlDomNode* _tmp304_;
		ObjectParent* _tmp305_;
		ObjectParentObjectChild* _tmp306_;
		ObjectParentObjectChild* _tmp307_;
		gchar* _tmp308_ = NULL;
		ObjectParent* _tmp309_;
		gchar* _tmp310_;
		ObjectParent* e2 = NULL;
		ObjectParent* _tmp311_;
		gchar* _tmp312_ = NULL;
		ObjectParent* _tmp313_;
		gchar* _tmp314_;
		ObjectParent* _tmp315_;
		gchar* _tmp316_ = NULL;
		ObjectParent* _tmp317_;
		gchar* _tmp318_;
		ObjectParent* _tmp319_;
		ObjectParentObjectChild* _tmp320_;
		ObjectParentObjectChild* _tmp321_;
		ObjectParent* _tmp322_;
		GXmlDomNamedNodeMap* _tmp323_;
		GXmlDomNamedNodeMap* _tmp324_;
		GXmlDomNamedNodeMap* _tmp325_;
#line 759 "GomElementTest.vala"
		_tmp0_ = object_parent_new ();
#line 759 "GomElementTest.vala"
		e = _tmp0_;
#line 760 "GomElementTest.vala"
		_tmp1_ = e;
#line 760 "GomElementTest.vala"
		_tmp2_ = object_parent_get_text (_tmp1_);
#line 760 "GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 760 "GomElementTest.vala"
		_vala_assert (_tmp3_ == NULL, "e.text == null");
#line 761 "GomElementTest.vala"
		_tmp4_ = e;
#line 761 "GomElementTest.vala"
		_tmp5_ = object_parent_get_prop (_tmp4_);
#line 761 "GomElementTest.vala"
		_tmp6_ = _tmp5_;
#line 761 "GomElementTest.vala"
		_vala_assert (_tmp6_ == NULL, "e.prop == null");
#line 762 "GomElementTest.vala"
		_tmp7_ = e;
#line 762 "GomElementTest.vala"
		_tmp8_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp7_);
#line 762 "GomElementTest.vala"
		_tmp9_ = _tmp8_;
#line 762 "GomElementTest.vala"
		_tmp10_ = _tmp9_;
#line 762 "GomElementTest.vala"
		_vala_assert (_tmp10_ != NULL, "e.attributes != null");
#line 762 "GomElementTest.vala"
		_g_object_unref0 (_tmp10_);
#line 763 "GomElementTest.vala"
		_tmp11_ = e;
#line 763 "GomElementTest.vala"
		_tmp12_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp11_);
#line 763 "GomElementTest.vala"
		_tmp13_ = _tmp12_;
#line 763 "GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 763 "GomElementTest.vala"
		_tmp15_ = gxml_dom_named_node_map_get_length (_tmp14_);
#line 763 "GomElementTest.vala"
		_tmp16_ = _tmp15_;
#line 763 "GomElementTest.vala"
		_vala_assert (_tmp16_ == 0, "e.attributes.length == 0");
#line 763 "GomElementTest.vala"
		_g_object_unref0 (_tmp14_);
#line 764 "GomElementTest.vala"
		_tmp17_ = e;
#line 764 "GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp17_, "text", "value1", &_inner_error0_);
#line 764 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 764 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 10827 "GomElementTest.c"
			goto __catch141_g_error;
		}
#line 765 "GomElementTest.vala"
		_tmp18_ = e;
#line 765 "GomElementTest.vala"
		_tmp19_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp18_, "text");
#line 765 "GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 765 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp20_, "value1") == 0, "e.get_attribute (\"text\") == \"value1\"");
#line 765 "GomElementTest.vala"
		_g_free0 (_tmp20_);
#line 766 "GomElementTest.vala"
		_tmp21_ = e;
#line 766 "GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp21_, "prop", "value_prop", &_inner_error0_);
#line 766 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 766 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 10848 "GomElementTest.c"
			goto __catch141_g_error;
		}
#line 767 "GomElementTest.vala"
		_tmp22_ = e;
#line 767 "GomElementTest.vala"
		_tmp23_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp22_, "prop");
#line 767 "GomElementTest.vala"
		_tmp24_ = _tmp23_;
#line 767 "GomElementTest.vala"
		g_message ("GomElementTest.vala:767: Attribute: prop: %s", _tmp24_);
#line 767 "GomElementTest.vala"
		_g_free0 (_tmp24_);
#line 768 "GomElementTest.vala"
		_tmp25_ = e;
#line 768 "GomElementTest.vala"
		_tmp26_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp25_, "prop");
#line 768 "GomElementTest.vala"
		_tmp27_ = _tmp26_;
#line 768 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp27_, "value_prop") == 0, "e.get_attribute (\"prop\") == \"value_prop\"");
#line 768 "GomElementTest.vala"
		_g_free0 (_tmp27_);
#line 769 "GomElementTest.vala"
		_tmp28_ = e;
#line 769 "GomElementTest.vala"
		_tmp29_ = object_parent_get_text (_tmp28_);
#line 769 "GomElementTest.vala"
		_tmp30_ = _tmp29_;
#line 769 "GomElementTest.vala"
		_vala_assert (_tmp30_ != NULL, "e.text != null");
#line 770 "GomElementTest.vala"
		_tmp31_ = e;
#line 770 "GomElementTest.vala"
		_tmp32_ = object_parent_get_prop (_tmp31_);
#line 770 "GomElementTest.vala"
		_tmp33_ = _tmp32_;
#line 770 "GomElementTest.vala"
		_vala_assert (_tmp33_ != NULL, "e.prop != null");
#line 771 "GomElementTest.vala"
		_tmp34_ = e;
#line 771 "GomElementTest.vala"
		_tmp35_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp34_);
#line 771 "GomElementTest.vala"
		_tmp36_ = _tmp35_;
#line 771 "GomElementTest.vala"
		_tmp37_ = _tmp36_;
#line 771 "GomElementTest.vala"
		_tmp38_ = gxml_dom_named_node_map_get_length (_tmp37_);
#line 771 "GomElementTest.vala"
		_tmp39_ = _tmp38_;
#line 771 "GomElementTest.vala"
		_vala_assert (_tmp39_ == 2, "e.attributes.length == 2");
#line 771 "GomElementTest.vala"
		_g_object_unref0 (_tmp37_);
#line 772 "GomElementTest.vala"
		_tmp40_ = e;
#line 772 "GomElementTest.vala"
		_tmp41_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp40_);
#line 772 "GomElementTest.vala"
		_tmp42_ = _tmp41_;
#line 772 "GomElementTest.vala"
		_tmp43_ = _tmp42_;
#line 772 "GomElementTest.vala"
		_tmp44_ = gxml_dom_named_node_map_item (_tmp43_, 0);
#line 772 "GomElementTest.vala"
		_tmp45_ = _tmp44_;
#line 772 "GomElementTest.vala"
		_tmp46_ = gxml_dom_node_get_node_name (_tmp45_);
#line 772 "GomElementTest.vala"
		_tmp47_ = _tmp46_;
#line 772 "GomElementTest.vala"
		_tmp48_ = _tmp47_;
#line 772 "GomElementTest.vala"
		_tmp49_ = e;
#line 772 "GomElementTest.vala"
		_tmp50_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp49_);
#line 772 "GomElementTest.vala"
		_tmp51_ = _tmp50_;
#line 772 "GomElementTest.vala"
		_tmp52_ = _tmp51_;
#line 772 "GomElementTest.vala"
		_tmp53_ = gxml_dom_named_node_map_item (_tmp52_, 0);
#line 772 "GomElementTest.vala"
		_tmp54_ = _tmp53_;
#line 772 "GomElementTest.vala"
		_tmp55_ = gxml_dom_node_get_node_value (_tmp54_);
#line 772 "GomElementTest.vala"
		_tmp56_ = _tmp55_;
#line 772 "GomElementTest.vala"
		_tmp57_ = _tmp56_;
#line 772 "GomElementTest.vala"
		g_message ("GomElementTest.vala:772: Attr 0: %s:%s", _tmp48_, _tmp57_);
#line 772 "GomElementTest.vala"
		_g_free0 (_tmp57_);
#line 772 "GomElementTest.vala"
		_g_object_unref0 (_tmp54_);
#line 772 "GomElementTest.vala"
		_g_object_unref0 (_tmp52_);
#line 772 "GomElementTest.vala"
		_g_free0 (_tmp48_);
#line 772 "GomElementTest.vala"
		_g_object_unref0 (_tmp45_);
#line 772 "GomElementTest.vala"
		_g_object_unref0 (_tmp43_);
#line 10953 "GomElementTest.c"
		{
			GeeIterator* _k_it = NULL;
			ObjectParent* _tmp58_;
			GXmlDomNamedNodeMap* _tmp59_;
			GXmlDomNamedNodeMap* _tmp60_;
			GXmlDomNamedNodeMap* _tmp61_;
			GeeSet* _tmp62_;
			GeeSet* _tmp63_;
			GeeSet* _tmp64_;
			GeeIterator* _tmp65_;
			GeeIterator* _tmp66_;
#line 773 "GomElementTest.vala"
			_tmp58_ = e;
#line 773 "GomElementTest.vala"
			_tmp59_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp58_);
#line 773 "GomElementTest.vala"
			_tmp60_ = _tmp59_;
#line 773 "GomElementTest.vala"
			_tmp61_ = _tmp60_;
#line 773 "GomElementTest.vala"
			_tmp62_ = gee_map_get_keys ((GeeMap*) _tmp61_);
#line 773 "GomElementTest.vala"
			_tmp63_ = _tmp62_;
#line 773 "GomElementTest.vala"
			_tmp64_ = _tmp63_;
#line 773 "GomElementTest.vala"
			_tmp65_ = gee_iterable_iterator ((GeeIterable*) _tmp64_);
#line 773 "GomElementTest.vala"
			_tmp66_ = _tmp65_;
#line 773 "GomElementTest.vala"
			_g_object_unref0 (_tmp64_);
#line 773 "GomElementTest.vala"
			_g_object_unref0 (_tmp61_);
#line 773 "GomElementTest.vala"
			_k_it = _tmp66_;
#line 773 "GomElementTest.vala"
			while (TRUE) {
#line 10991 "GomElementTest.c"
				GeeIterator* _tmp67_;
				gchar* k = NULL;
				GeeIterator* _tmp68_;
				gpointer _tmp69_;
				GXmlDomAttr* a = NULL;
				ObjectParent* _tmp70_;
				GXmlDomNamedNodeMap* _tmp71_;
				GXmlDomNamedNodeMap* _tmp72_;
				GXmlDomNamedNodeMap* _tmp73_;
				const gchar* _tmp74_;
				gpointer _tmp75_;
				GXmlDomNode* _tmp76_;
				GXmlDomAttr* _tmp77_;
				GXmlDomAttr* _tmp78_;
				GXmlDomAttr* _tmp79_;
				gchar* _tmp80_;
				gchar* _tmp81_;
				gchar* _tmp82_;
				GXmlDomAttr* _tmp83_;
				gchar* _tmp84_;
				gchar* _tmp85_;
				gchar* _tmp86_;
#line 773 "GomElementTest.vala"
				_tmp67_ = _k_it;
#line 773 "GomElementTest.vala"
				if (!gee_iterator_next (_tmp67_)) {
#line 773 "GomElementTest.vala"
					break;
#line 11020 "GomElementTest.c"
				}
#line 773 "GomElementTest.vala"
				_tmp68_ = _k_it;
#line 773 "GomElementTest.vala"
				_tmp69_ = gee_iterator_get (_tmp68_);
#line 773 "GomElementTest.vala"
				k = (gchar*) _tmp69_;
#line 774 "GomElementTest.vala"
				_tmp70_ = e;
#line 774 "GomElementTest.vala"
				_tmp71_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp70_);
#line 774 "GomElementTest.vala"
				_tmp72_ = _tmp71_;
#line 774 "GomElementTest.vala"
				_tmp73_ = _tmp72_;
#line 774 "GomElementTest.vala"
				_tmp74_ = k;
#line 774 "GomElementTest.vala"
				_tmp75_ = gee_map_get ((GeeMap*) _tmp73_, _tmp74_);
#line 774 "GomElementTest.vala"
				_tmp76_ = (GXmlDomNode*) _tmp75_;
#line 774 "GomElementTest.vala"
				_tmp77_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp76_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp76_) : NULL;
#line 774 "GomElementTest.vala"
				if (_tmp77_ == NULL) {
#line 774 "GomElementTest.vala"
					_g_object_unref0 (_tmp76_);
#line 11048 "GomElementTest.c"
				}
#line 774 "GomElementTest.vala"
				_tmp78_ = _tmp77_;
#line 774 "GomElementTest.vala"
				_g_object_unref0 (_tmp73_);
#line 774 "GomElementTest.vala"
				a = _tmp78_;
#line 775 "GomElementTest.vala"
				_tmp79_ = a;
#line 775 "GomElementTest.vala"
				_tmp80_ = gxml_dom_attr_get_name (_tmp79_);
#line 775 "GomElementTest.vala"
				_tmp81_ = _tmp80_;
#line 775 "GomElementTest.vala"
				_tmp82_ = _tmp81_;
#line 775 "GomElementTest.vala"
				_tmp83_ = a;
#line 775 "GomElementTest.vala"
				_tmp84_ = gxml_dom_attr_get_value (_tmp83_);
#line 775 "GomElementTest.vala"
				_tmp85_ = _tmp84_;
#line 775 "GomElementTest.vala"
				_tmp86_ = _tmp85_;
#line 775 "GomElementTest.vala"
				g_message ("GomElementTest.vala:775: Attr: %s:%s", _tmp82_, _tmp86_);
#line 775 "GomElementTest.vala"
				_g_free0 (_tmp86_);
#line 775 "GomElementTest.vala"
				_g_free0 (_tmp82_);
#line 773 "GomElementTest.vala"
				_g_object_unref0 (a);
#line 773 "GomElementTest.vala"
				_g_free0 (k);
#line 11082 "GomElementTest.c"
			}
#line 773 "GomElementTest.vala"
			_g_object_unref0 (_k_it);
#line 11086 "GomElementTest.c"
		}
#line 777 "GomElementTest.vala"
		_tmp87_ = e;
#line 777 "GomElementTest.vala"
		_tmp88_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp87_);
#line 777 "GomElementTest.vala"
		_tmp89_ = _tmp88_;
#line 777 "GomElementTest.vala"
		_tmp90_ = _tmp89_;
#line 777 "GomElementTest.vala"
		_tmp91_ = gxml_dom_named_node_map_item (_tmp90_, 0);
#line 777 "GomElementTest.vala"
		_tmp92_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp91_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp91_) : NULL;
#line 777 "GomElementTest.vala"
		if (_tmp92_ == NULL) {
#line 777 "GomElementTest.vala"
			_g_object_unref0 (_tmp91_);
#line 11104 "GomElementTest.c"
		}
#line 777 "GomElementTest.vala"
		_tmp93_ = _tmp92_;
#line 777 "GomElementTest.vala"
		_tmp94_ = gxml_dom_attr_get_value (_tmp93_);
#line 777 "GomElementTest.vala"
		_tmp95_ = _tmp94_;
#line 777 "GomElementTest.vala"
		_tmp96_ = _tmp95_;
#line 777 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp96_, "value1") == 0, "(e.attributes.item (0) as DomAttr).@value == \"value1\"");
#line 777 "GomElementTest.vala"
		_g_free0 (_tmp96_);
#line 777 "GomElementTest.vala"
		_g_object_unref0 (_tmp93_);
#line 777 "GomElementTest.vala"
		_g_object_unref0 (_tmp90_);
#line 778 "GomElementTest.vala"
		_tmp97_ = e;
#line 778 "GomElementTest.vala"
		_tmp98_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp97_);
#line 778 "GomElementTest.vala"
		_tmp99_ = _tmp98_;
#line 778 "GomElementTest.vala"
		_tmp100_ = _tmp99_;
#line 778 "GomElementTest.vala"
		_tmp101_ = gxml_dom_named_node_map_item (_tmp100_, 1);
#line 778 "GomElementTest.vala"
		_tmp102_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp101_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp101_) : NULL;
#line 778 "GomElementTest.vala"
		if (_tmp102_ == NULL) {
#line 778 "GomElementTest.vala"
			_g_object_unref0 (_tmp101_);
#line 11138 "GomElementTest.c"
		}
#line 778 "GomElementTest.vala"
		_tmp103_ = _tmp102_;
#line 778 "GomElementTest.vala"
		_tmp104_ = gxml_dom_attr_get_value (_tmp103_);
#line 778 "GomElementTest.vala"
		_tmp105_ = _tmp104_;
#line 778 "GomElementTest.vala"
		_tmp106_ = _tmp105_;
#line 778 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp106_, "value_prop") == 0, "(e.attributes.item (1) as DomAttr).@value == \"value_prop\"");
#line 778 "GomElementTest.vala"
		_g_free0 (_tmp106_);
#line 778 "GomElementTest.vala"
		_g_object_unref0 (_tmp103_);
#line 778 "GomElementTest.vala"
		_g_object_unref0 (_tmp100_);
#line 779 "GomElementTest.vala"
		_tmp107_ = e;
#line 779 "GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp107_, "p1", "prop1", &_inner_error0_);
#line 779 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 779 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 11164 "GomElementTest.c"
			goto __catch141_g_error;
		}
#line 780 "GomElementTest.vala"
		_tmp108_ = e;
#line 780 "GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp108_, "p2", "prop2", &_inner_error0_);
#line 780 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 780 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 11175 "GomElementTest.c"
			goto __catch141_g_error;
		}
#line 781 "GomElementTest.vala"
		_tmp109_ = e;
#line 781 "GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp109_, "p3", "prop3", &_inner_error0_);
#line 781 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 781 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 11186 "GomElementTest.c"
			goto __catch141_g_error;
		}
#line 782 "GomElementTest.vala"
		_tmp110_ = e;
#line 782 "GomElementTest.vala"
		_tmp111_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp110_);
#line 782 "GomElementTest.vala"
		_tmp112_ = _tmp111_;
#line 782 "GomElementTest.vala"
		_tmp113_ = _tmp112_;
#line 782 "GomElementTest.vala"
		_tmp114_ = gxml_dom_named_node_map_get_length (_tmp113_);
#line 782 "GomElementTest.vala"
		_tmp115_ = _tmp114_;
#line 782 "GomElementTest.vala"
		_vala_assert (_tmp115_ == 5, "e.attributes.length == 5");
#line 782 "GomElementTest.vala"
		_g_object_unref0 (_tmp113_);
#line 783 "GomElementTest.vala"
		_tmp116_ = e;
#line 783 "GomElementTest.vala"
		_tmp117_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp116_);
#line 783 "GomElementTest.vala"
		_tmp118_ = _tmp117_;
#line 783 "GomElementTest.vala"
		_tmp119_ = _tmp118_;
#line 783 "GomElementTest.vala"
		_tmp120_ = gxml_dom_named_node_map_item (_tmp119_, 0);
#line 783 "GomElementTest.vala"
		_tmp121_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp120_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp120_) : NULL;
#line 783 "GomElementTest.vala"
		if (_tmp121_ == NULL) {
#line 783 "GomElementTest.vala"
			_g_object_unref0 (_tmp120_);
#line 11221 "GomElementTest.c"
		}
#line 783 "GomElementTest.vala"
		_tmp122_ = _tmp121_;
#line 783 "GomElementTest.vala"
		_tmp123_ = gxml_dom_attr_get_value (_tmp122_);
#line 783 "GomElementTest.vala"
		_tmp124_ = _tmp123_;
#line 783 "GomElementTest.vala"
		_tmp125_ = _tmp124_;
#line 783 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp125_, "value1") == 0, "(e.attributes.item (0) as DomAttr).@value == \"value1\"");
#line 783 "GomElementTest.vala"
		_g_free0 (_tmp125_);
#line 783 "GomElementTest.vala"
		_g_object_unref0 (_tmp122_);
#line 783 "GomElementTest.vala"
		_g_object_unref0 (_tmp119_);
#line 784 "GomElementTest.vala"
		_tmp126_ = e;
#line 784 "GomElementTest.vala"
		_tmp127_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp126_);
#line 784 "GomElementTest.vala"
		_tmp128_ = _tmp127_;
#line 784 "GomElementTest.vala"
		_tmp129_ = _tmp128_;
#line 784 "GomElementTest.vala"
		_tmp130_ = gxml_dom_named_node_map_item (_tmp129_, 1);
#line 784 "GomElementTest.vala"
		_tmp131_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp130_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp130_) : NULL;
#line 784 "GomElementTest.vala"
		if (_tmp131_ == NULL) {
#line 784 "GomElementTest.vala"
			_g_object_unref0 (_tmp130_);
#line 11255 "GomElementTest.c"
		}
#line 784 "GomElementTest.vala"
		_tmp132_ = _tmp131_;
#line 784 "GomElementTest.vala"
		_tmp133_ = gxml_dom_attr_get_value (_tmp132_);
#line 784 "GomElementTest.vala"
		_tmp134_ = _tmp133_;
#line 784 "GomElementTest.vala"
		_tmp135_ = _tmp134_;
#line 784 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp135_, "value_prop") == 0, "(e.attributes.item (1) as DomAttr).@value == \"value_prop\"");
#line 784 "GomElementTest.vala"
		_g_free0 (_tmp135_);
#line 784 "GomElementTest.vala"
		_g_object_unref0 (_tmp132_);
#line 784 "GomElementTest.vala"
		_g_object_unref0 (_tmp129_);
#line 785 "GomElementTest.vala"
		_tmp136_ = e;
#line 785 "GomElementTest.vala"
		_tmp137_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp136_);
#line 785 "GomElementTest.vala"
		_tmp138_ = _tmp137_;
#line 785 "GomElementTest.vala"
		_tmp139_ = _tmp138_;
#line 785 "GomElementTest.vala"
		_tmp140_ = gxml_dom_named_node_map_item (_tmp139_, 2);
#line 785 "GomElementTest.vala"
		_tmp141_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp140_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp140_) : NULL;
#line 785 "GomElementTest.vala"
		if (_tmp141_ == NULL) {
#line 785 "GomElementTest.vala"
			_g_object_unref0 (_tmp140_);
#line 11289 "GomElementTest.c"
		}
#line 785 "GomElementTest.vala"
		_tmp142_ = _tmp141_;
#line 785 "GomElementTest.vala"
		_tmp143_ = gxml_dom_attr_get_value (_tmp142_);
#line 785 "GomElementTest.vala"
		_tmp144_ = _tmp143_;
#line 785 "GomElementTest.vala"
		_tmp145_ = _tmp144_;
#line 785 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp145_, "prop1") == 0, "(e.attributes.item (2) as DomAttr).@value == \"prop1\"");
#line 785 "GomElementTest.vala"
		_g_free0 (_tmp145_);
#line 785 "GomElementTest.vala"
		_g_object_unref0 (_tmp142_);
#line 785 "GomElementTest.vala"
		_g_object_unref0 (_tmp139_);
#line 786 "GomElementTest.vala"
		_tmp146_ = e;
#line 786 "GomElementTest.vala"
		_tmp147_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp146_);
#line 786 "GomElementTest.vala"
		_tmp148_ = _tmp147_;
#line 786 "GomElementTest.vala"
		_tmp149_ = _tmp148_;
#line 786 "GomElementTest.vala"
		_tmp150_ = gxml_dom_named_node_map_item (_tmp149_, 3);
#line 786 "GomElementTest.vala"
		_tmp151_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp150_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp150_) : NULL;
#line 786 "GomElementTest.vala"
		if (_tmp151_ == NULL) {
#line 786 "GomElementTest.vala"
			_g_object_unref0 (_tmp150_);
#line 11323 "GomElementTest.c"
		}
#line 786 "GomElementTest.vala"
		_tmp152_ = _tmp151_;
#line 786 "GomElementTest.vala"
		_tmp153_ = gxml_dom_attr_get_value (_tmp152_);
#line 786 "GomElementTest.vala"
		_tmp154_ = _tmp153_;
#line 786 "GomElementTest.vala"
		_tmp155_ = _tmp154_;
#line 786 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp155_, "prop2") == 0, "(e.attributes.item (3) as DomAttr).@value == \"prop2\"");
#line 786 "GomElementTest.vala"
		_g_free0 (_tmp155_);
#line 786 "GomElementTest.vala"
		_g_object_unref0 (_tmp152_);
#line 786 "GomElementTest.vala"
		_g_object_unref0 (_tmp149_);
#line 787 "GomElementTest.vala"
		_tmp156_ = e;
#line 787 "GomElementTest.vala"
		_tmp157_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp156_);
#line 787 "GomElementTest.vala"
		_tmp158_ = _tmp157_;
#line 787 "GomElementTest.vala"
		_tmp159_ = _tmp158_;
#line 787 "GomElementTest.vala"
		_tmp160_ = gxml_dom_named_node_map_item (_tmp159_, 4);
#line 787 "GomElementTest.vala"
		_tmp161_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp160_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp160_) : NULL;
#line 787 "GomElementTest.vala"
		if (_tmp161_ == NULL) {
#line 787 "GomElementTest.vala"
			_g_object_unref0 (_tmp160_);
#line 11357 "GomElementTest.c"
		}
#line 787 "GomElementTest.vala"
		_tmp162_ = _tmp161_;
#line 787 "GomElementTest.vala"
		_tmp163_ = gxml_dom_attr_get_value (_tmp162_);
#line 787 "GomElementTest.vala"
		_tmp164_ = _tmp163_;
#line 787 "GomElementTest.vala"
		_tmp165_ = _tmp164_;
#line 787 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp165_, "prop3") == 0, "(e.attributes.item (4) as DomAttr).@value == \"prop3\"");
#line 787 "GomElementTest.vala"
		_g_free0 (_tmp165_);
#line 787 "GomElementTest.vala"
		_g_object_unref0 (_tmp162_);
#line 787 "GomElementTest.vala"
		_g_object_unref0 (_tmp159_);
#line 788 "GomElementTest.vala"
		_tmp166_ = e;
#line 788 "GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp166_, "http://www.w3.org/2000/xmlns/", "xmlns:t", "http://www.gnome.org/gxml/test", &_inner_error0_);
#line 788 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 788 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 11383 "GomElementTest.c"
			goto __catch141_g_error;
		}
#line 789 "GomElementTest.vala"
		_tmp167_ = e;
#line 789 "GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp167_, "http://www.gnome.org/gxml/test", "t:p1", "prop1_test", &_inner_error0_);
#line 789 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 789 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 11394 "GomElementTest.c"
			goto __catch141_g_error;
		}
#line 790 "GomElementTest.vala"
		_tmp168_ = e;
#line 790 "GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp168_, "http://www.gnome.org/gxml/test", "t:p2", "prop2_test", &_inner_error0_);
#line 790 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 790 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 11405 "GomElementTest.c"
			goto __catch141_g_error;
		}
#line 791 "GomElementTest.vala"
		_tmp169_ = e;
#line 791 "GomElementTest.vala"
		_tmp170_ = gxml_dom_element_get_attribute_ns ((GXmlDomElement*) _tmp169_, "http://www.gnome.org/gxml/test", "p1");
#line 791 "GomElementTest.vala"
		_tmp171_ = _tmp170_;
#line 791 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp171_, "prop1_test") == 0, "e.get_attribute_ns (\"http://www.gnome.org/gxml/test\", \"p1\") == \"prop1_test\"");
#line 791 "GomElementTest.vala"
		_g_free0 (_tmp171_);
#line 792 "GomElementTest.vala"
		_tmp172_ = e;
#line 792 "GomElementTest.vala"
		_tmp173_ = gxml_dom_element_get_attribute_ns ((GXmlDomElement*) _tmp172_, "http://www.gnome.org/gxml/test", "p2");
#line 792 "GomElementTest.vala"
		_tmp174_ = _tmp173_;
#line 792 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp174_, "prop2_test") == 0, "e.get_attribute_ns (\"http://www.gnome.org/gxml/test\", \"p2\") == \"prop2_test\"");
#line 792 "GomElementTest.vala"
		_g_free0 (_tmp174_);
#line 793 "GomElementTest.vala"
		_tmp175_ = e;
#line 793 "GomElementTest.vala"
		_tmp176_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp175_);
#line 793 "GomElementTest.vala"
		_tmp177_ = _tmp176_;
#line 793 "GomElementTest.vala"
		_tmp178_ = _tmp177_;
#line 793 "GomElementTest.vala"
		_tmp179_ = gxml_dom_named_node_map_get_length (_tmp178_);
#line 793 "GomElementTest.vala"
		_tmp180_ = _tmp179_;
#line 793 "GomElementTest.vala"
		_vala_assert (_tmp180_ == 8, "e.attributes.length == 8");
#line 793 "GomElementTest.vala"
		_g_object_unref0 (_tmp178_);
#line 794 "GomElementTest.vala"
		_tmp181_ = e;
#line 794 "GomElementTest.vala"
		_tmp182_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp181_);
#line 794 "GomElementTest.vala"
		_tmp183_ = _tmp182_;
#line 794 "GomElementTest.vala"
		_tmp184_ = _tmp183_;
#line 794 "GomElementTest.vala"
		_tmp185_ = gxml_dom_named_node_map_item (_tmp184_, 0);
#line 794 "GomElementTest.vala"
		_tmp186_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp185_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp185_) : NULL;
#line 794 "GomElementTest.vala"
		if (_tmp186_ == NULL) {
#line 794 "GomElementTest.vala"
			_g_object_unref0 (_tmp185_);
#line 11460 "GomElementTest.c"
		}
#line 794 "GomElementTest.vala"
		_tmp187_ = _tmp186_;
#line 794 "GomElementTest.vala"
		_tmp188_ = gxml_dom_attr_get_value (_tmp187_);
#line 794 "GomElementTest.vala"
		_tmp189_ = _tmp188_;
#line 794 "GomElementTest.vala"
		_tmp190_ = _tmp189_;
#line 794 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp190_, "value1") == 0, "(e.attributes.item (0) as DomAttr).@value == \"value1\"");
#line 794 "GomElementTest.vala"
		_g_free0 (_tmp190_);
#line 794 "GomElementTest.vala"
		_g_object_unref0 (_tmp187_);
#line 794 "GomElementTest.vala"
		_g_object_unref0 (_tmp184_);
#line 795 "GomElementTest.vala"
		_tmp191_ = e;
#line 795 "GomElementTest.vala"
		_tmp192_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp191_);
#line 795 "GomElementTest.vala"
		_tmp193_ = _tmp192_;
#line 795 "GomElementTest.vala"
		_tmp194_ = _tmp193_;
#line 795 "GomElementTest.vala"
		_tmp195_ = gxml_dom_named_node_map_item (_tmp194_, 1);
#line 795 "GomElementTest.vala"
		_tmp196_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp195_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp195_) : NULL;
#line 795 "GomElementTest.vala"
		if (_tmp196_ == NULL) {
#line 795 "GomElementTest.vala"
			_g_object_unref0 (_tmp195_);
#line 11494 "GomElementTest.c"
		}
#line 795 "GomElementTest.vala"
		_tmp197_ = _tmp196_;
#line 795 "GomElementTest.vala"
		_tmp198_ = gxml_dom_attr_get_value (_tmp197_);
#line 795 "GomElementTest.vala"
		_tmp199_ = _tmp198_;
#line 795 "GomElementTest.vala"
		_tmp200_ = _tmp199_;
#line 795 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp200_, "value_prop") == 0, "(e.attributes.item (1) as DomAttr).@value == \"value_prop\"");
#line 795 "GomElementTest.vala"
		_g_free0 (_tmp200_);
#line 795 "GomElementTest.vala"
		_g_object_unref0 (_tmp197_);
#line 795 "GomElementTest.vala"
		_g_object_unref0 (_tmp194_);
#line 796 "GomElementTest.vala"
		_tmp201_ = e;
#line 796 "GomElementTest.vala"
		_tmp202_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp201_);
#line 796 "GomElementTest.vala"
		_tmp203_ = _tmp202_;
#line 796 "GomElementTest.vala"
		_tmp204_ = _tmp203_;
#line 796 "GomElementTest.vala"
		_tmp205_ = gxml_dom_named_node_map_item (_tmp204_, 2);
#line 796 "GomElementTest.vala"
		_tmp206_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp205_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp205_) : NULL;
#line 796 "GomElementTest.vala"
		if (_tmp206_ == NULL) {
#line 796 "GomElementTest.vala"
			_g_object_unref0 (_tmp205_);
#line 11528 "GomElementTest.c"
		}
#line 796 "GomElementTest.vala"
		_tmp207_ = _tmp206_;
#line 796 "GomElementTest.vala"
		_tmp208_ = gxml_dom_attr_get_value (_tmp207_);
#line 796 "GomElementTest.vala"
		_tmp209_ = _tmp208_;
#line 796 "GomElementTest.vala"
		_tmp210_ = _tmp209_;
#line 796 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp210_, "prop1") == 0, "(e.attributes.item (2) as DomAttr).@value == \"prop1\"");
#line 796 "GomElementTest.vala"
		_g_free0 (_tmp210_);
#line 796 "GomElementTest.vala"
		_g_object_unref0 (_tmp207_);
#line 796 "GomElementTest.vala"
		_g_object_unref0 (_tmp204_);
#line 797 "GomElementTest.vala"
		_tmp211_ = e;
#line 797 "GomElementTest.vala"
		_tmp212_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp211_);
#line 797 "GomElementTest.vala"
		_tmp213_ = _tmp212_;
#line 797 "GomElementTest.vala"
		_tmp214_ = _tmp213_;
#line 797 "GomElementTest.vala"
		_tmp215_ = gxml_dom_named_node_map_item (_tmp214_, 3);
#line 797 "GomElementTest.vala"
		_tmp216_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp215_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp215_) : NULL;
#line 797 "GomElementTest.vala"
		if (_tmp216_ == NULL) {
#line 797 "GomElementTest.vala"
			_g_object_unref0 (_tmp215_);
#line 11562 "GomElementTest.c"
		}
#line 797 "GomElementTest.vala"
		_tmp217_ = _tmp216_;
#line 797 "GomElementTest.vala"
		_tmp218_ = gxml_dom_attr_get_value (_tmp217_);
#line 797 "GomElementTest.vala"
		_tmp219_ = _tmp218_;
#line 797 "GomElementTest.vala"
		_tmp220_ = _tmp219_;
#line 797 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp220_, "prop2") == 0, "(e.attributes.item (3) as DomAttr).@value == \"prop2\"");
#line 797 "GomElementTest.vala"
		_g_free0 (_tmp220_);
#line 797 "GomElementTest.vala"
		_g_object_unref0 (_tmp217_);
#line 797 "GomElementTest.vala"
		_g_object_unref0 (_tmp214_);
#line 798 "GomElementTest.vala"
		_tmp221_ = e;
#line 798 "GomElementTest.vala"
		_tmp222_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp221_);
#line 798 "GomElementTest.vala"
		_tmp223_ = _tmp222_;
#line 798 "GomElementTest.vala"
		_tmp224_ = _tmp223_;
#line 798 "GomElementTest.vala"
		_tmp225_ = gxml_dom_named_node_map_item (_tmp224_, 4);
#line 798 "GomElementTest.vala"
		_tmp226_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp225_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp225_) : NULL;
#line 798 "GomElementTest.vala"
		if (_tmp226_ == NULL) {
#line 798 "GomElementTest.vala"
			_g_object_unref0 (_tmp225_);
#line 11596 "GomElementTest.c"
		}
#line 798 "GomElementTest.vala"
		_tmp227_ = _tmp226_;
#line 798 "GomElementTest.vala"
		_tmp228_ = gxml_dom_attr_get_value (_tmp227_);
#line 798 "GomElementTest.vala"
		_tmp229_ = _tmp228_;
#line 798 "GomElementTest.vala"
		_tmp230_ = _tmp229_;
#line 798 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp230_, "prop3") == 0, "(e.attributes.item (4) as DomAttr).@value == \"prop3\"");
#line 798 "GomElementTest.vala"
		_g_free0 (_tmp230_);
#line 798 "GomElementTest.vala"
		_g_object_unref0 (_tmp227_);
#line 798 "GomElementTest.vala"
		_g_object_unref0 (_tmp224_);
#line 799 "GomElementTest.vala"
		_tmp231_ = e;
#line 799 "GomElementTest.vala"
		_tmp232_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp231_);
#line 799 "GomElementTest.vala"
		_tmp233_ = _tmp232_;
#line 799 "GomElementTest.vala"
		_tmp234_ = _tmp233_;
#line 799 "GomElementTest.vala"
		_tmp235_ = gxml_dom_named_node_map_item (_tmp234_, 5);
#line 799 "GomElementTest.vala"
		_tmp236_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp235_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp235_) : NULL;
#line 799 "GomElementTest.vala"
		if (_tmp236_ == NULL) {
#line 799 "GomElementTest.vala"
			_g_object_unref0 (_tmp235_);
#line 11630 "GomElementTest.c"
		}
#line 799 "GomElementTest.vala"
		_tmp237_ = _tmp236_;
#line 799 "GomElementTest.vala"
		_tmp238_ = gxml_dom_attr_get_value (_tmp237_);
#line 799 "GomElementTest.vala"
		_tmp239_ = _tmp238_;
#line 799 "GomElementTest.vala"
		_tmp240_ = _tmp239_;
#line 799 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp240_, "http://www.gnome.org/gxml/test") == 0, "(e.attributes.item (5) as DomAttr).@value == \"http://www.gnome.org/gxml/test\"");
#line 799 "GomElementTest.vala"
		_g_free0 (_tmp240_);
#line 799 "GomElementTest.vala"
		_g_object_unref0 (_tmp237_);
#line 799 "GomElementTest.vala"
		_g_object_unref0 (_tmp234_);
#line 800 "GomElementTest.vala"
		_tmp241_ = e;
#line 800 "GomElementTest.vala"
		_tmp242_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp241_);
#line 800 "GomElementTest.vala"
		_tmp243_ = _tmp242_;
#line 800 "GomElementTest.vala"
		_tmp244_ = _tmp243_;
#line 800 "GomElementTest.vala"
		_tmp245_ = gxml_dom_named_node_map_item (_tmp244_, 6);
#line 800 "GomElementTest.vala"
		_tmp246_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp245_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp245_) : NULL;
#line 800 "GomElementTest.vala"
		if (_tmp246_ == NULL) {
#line 800 "GomElementTest.vala"
			_g_object_unref0 (_tmp245_);
#line 11664 "GomElementTest.c"
		}
#line 800 "GomElementTest.vala"
		_tmp247_ = _tmp246_;
#line 800 "GomElementTest.vala"
		_tmp248_ = gxml_dom_attr_get_value (_tmp247_);
#line 800 "GomElementTest.vala"
		_tmp249_ = _tmp248_;
#line 800 "GomElementTest.vala"
		_tmp250_ = _tmp249_;
#line 800 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp250_, "prop1_test") == 0, "(e.attributes.item (6) as DomAttr).@value == \"prop1_test\"");
#line 800 "GomElementTest.vala"
		_g_free0 (_tmp250_);
#line 800 "GomElementTest.vala"
		_g_object_unref0 (_tmp247_);
#line 800 "GomElementTest.vala"
		_g_object_unref0 (_tmp244_);
#line 801 "GomElementTest.vala"
		_tmp251_ = e;
#line 801 "GomElementTest.vala"
		_tmp252_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp251_);
#line 801 "GomElementTest.vala"
		_tmp253_ = _tmp252_;
#line 801 "GomElementTest.vala"
		_tmp254_ = _tmp253_;
#line 801 "GomElementTest.vala"
		_tmp255_ = gxml_dom_named_node_map_item (_tmp254_, 7);
#line 801 "GomElementTest.vala"
		_tmp256_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp255_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp255_) : NULL;
#line 801 "GomElementTest.vala"
		if (_tmp256_ == NULL) {
#line 801 "GomElementTest.vala"
			_g_object_unref0 (_tmp255_);
#line 11698 "GomElementTest.c"
		}
#line 801 "GomElementTest.vala"
		_tmp257_ = _tmp256_;
#line 801 "GomElementTest.vala"
		_tmp258_ = gxml_dom_attr_get_value (_tmp257_);
#line 801 "GomElementTest.vala"
		_tmp259_ = _tmp258_;
#line 801 "GomElementTest.vala"
		_tmp260_ = _tmp259_;
#line 801 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp260_, "prop2_test") == 0, "(e.attributes.item (7) as DomAttr).@value == \"prop2_test\"");
#line 801 "GomElementTest.vala"
		_g_free0 (_tmp260_);
#line 801 "GomElementTest.vala"
		_g_object_unref0 (_tmp257_);
#line 801 "GomElementTest.vala"
		_g_object_unref0 (_tmp254_);
#line 802 "GomElementTest.vala"
		_tmp261_ = e;
#line 802 "GomElementTest.vala"
		gxml_dom_element_set_id ((GXmlDomElement*) _tmp261_, "di1");
#line 803 "GomElementTest.vala"
		_tmp262_ = e;
#line 803 "GomElementTest.vala"
		_tmp263_ = gxml_dom_element_get_id ((GXmlDomElement*) _tmp262_);
#line 803 "GomElementTest.vala"
		_tmp264_ = _tmp263_;
#line 803 "GomElementTest.vala"
		_tmp265_ = _tmp264_;
#line 803 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp265_, "di1") == 0, "e.id == \"di1\"");
#line 803 "GomElementTest.vala"
		_g_free0 (_tmp265_);
#line 804 "GomElementTest.vala"
		_tmp266_ = e;
#line 804 "GomElementTest.vala"
		_tmp267_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp266_, "id");
#line 804 "GomElementTest.vala"
		_tmp268_ = _tmp267_;
#line 804 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp268_, "di1") == 0, "e.get_attribute (\"id\") == \"di1\"");
#line 804 "GomElementTest.vala"
		_g_free0 (_tmp268_);
#line 805 "GomElementTest.vala"
		_tmp269_ = e;
#line 805 "GomElementTest.vala"
		_tmp270_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp269_);
#line 805 "GomElementTest.vala"
		_tmp271_ = _tmp270_;
#line 805 "GomElementTest.vala"
		_tmp272_ = _tmp271_;
#line 805 "GomElementTest.vala"
		_tmp273_ = gxml_dom_named_node_map_get_length (_tmp272_);
#line 805 "GomElementTest.vala"
		_tmp274_ = _tmp273_;
#line 805 "GomElementTest.vala"
		_vala_assert (_tmp274_ == 9, "e.attributes.length == 9");
#line 805 "GomElementTest.vala"
		_g_object_unref0 (_tmp272_);
#line 806 "GomElementTest.vala"
		_tmp275_ = e;
#line 806 "GomElementTest.vala"
		_tmp276_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp275_);
#line 806 "GomElementTest.vala"
		_tmp277_ = _tmp276_;
#line 806 "GomElementTest.vala"
		_tmp278_ = _tmp277_;
#line 806 "GomElementTest.vala"
		_tmp279_ = gxml_dom_named_node_map_item (_tmp278_, 8);
#line 806 "GomElementTest.vala"
		_tmp280_ = _tmp279_;
#line 806 "GomElementTest.vala"
		_vala_assert (_tmp280_ != NULL, "e.attributes.item (8) != null");
#line 806 "GomElementTest.vala"
		_g_object_unref0 (_tmp280_);
#line 806 "GomElementTest.vala"
		_g_object_unref0 (_tmp278_);
#line 807 "GomElementTest.vala"
		_tmp281_ = e;
#line 807 "GomElementTest.vala"
		_tmp282_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp281_);
#line 807 "GomElementTest.vala"
		_tmp283_ = _tmp282_;
#line 807 "GomElementTest.vala"
		_tmp284_ = _tmp283_;
#line 807 "GomElementTest.vala"
		_tmp285_ = gxml_dom_named_node_map_item (_tmp284_, 8);
#line 807 "GomElementTest.vala"
		_tmp286_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp285_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp285_) : NULL;
#line 807 "GomElementTest.vala"
		if (_tmp286_ == NULL) {
#line 807 "GomElementTest.vala"
			_g_object_unref0 (_tmp285_);
#line 11792 "GomElementTest.c"
		}
#line 807 "GomElementTest.vala"
		_tmp287_ = _tmp286_;
#line 807 "GomElementTest.vala"
		_tmp288_ = gxml_dom_attr_get_value (_tmp287_);
#line 807 "GomElementTest.vala"
		_tmp289_ = _tmp288_;
#line 807 "GomElementTest.vala"
		_tmp290_ = _tmp289_;
#line 807 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp290_, "di1") == 0, "(e.attributes.item (8) as DomAttr).@value == \"di1\"");
#line 807 "GomElementTest.vala"
		_g_free0 (_tmp290_);
#line 807 "GomElementTest.vala"
		_g_object_unref0 (_tmp287_);
#line 807 "GomElementTest.vala"
		_g_object_unref0 (_tmp284_);
#line 808 "GomElementTest.vala"
		_tmp291_ = e;
#line 808 "GomElementTest.vala"
		_tmp292_ = e;
#line 808 "GomElementTest.vala"
		_tmp293_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _tmp292_);
#line 808 "GomElementTest.vala"
		_tmp294_ = _tmp293_;
#line 808 "GomElementTest.vala"
		_tmp295_ = g_object_new (OBJECT_PARENT_TYPE_OBJECT_CHILD, "owner-document", _tmp294_, NULL);
#line 808 "GomElementTest.vala"
		_tmp296_ = G_IS_INITIALLY_UNOWNED (_tmp295_) ? g_object_ref_sink (_tmp295_) : _tmp295_;
#line 808 "GomElementTest.vala"
		_tmp297_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp296_, OBJECT_PARENT_TYPE_OBJECT_CHILD) ? ((ObjectParentObjectChild*) _tmp296_) : NULL;
#line 808 "GomElementTest.vala"
		if (_tmp297_ == NULL) {
#line 808 "GomElementTest.vala"
			_g_object_unref0 (_tmp296_);
#line 11828 "GomElementTest.c"
		}
#line 808 "GomElementTest.vala"
		_tmp298_ = _tmp297_;
#line 808 "GomElementTest.vala"
		object_parent_set_child (_tmp291_, _tmp298_);
#line 808 "GomElementTest.vala"
		_g_object_unref0 (_tmp298_);
#line 810 "GomElementTest.vala"
		_tmp299_ = e;
#line 810 "GomElementTest.vala"
		_tmp300_ = e;
#line 810 "GomElementTest.vala"
		_tmp301_ = object_parent_get_child (_tmp300_);
#line 810 "GomElementTest.vala"
		_tmp302_ = _tmp301_;
#line 810 "GomElementTest.vala"
		_tmp303_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp299_, (GXmlDomNode*) _tmp302_, &_inner_error0_);
#line 810 "GomElementTest.vala"
		_tmp304_ = _tmp303_;
#line 810 "GomElementTest.vala"
		_g_object_unref0 (_tmp304_);
#line 810 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 810 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 11854 "GomElementTest.c"
			goto __catch141_g_error;
		}
#line 811 "GomElementTest.vala"
		_tmp305_ = e;
#line 811 "GomElementTest.vala"
		_tmp306_ = object_parent_get_child (_tmp305_);
#line 811 "GomElementTest.vala"
		_tmp307_ = _tmp306_;
#line 811 "GomElementTest.vala"
		_vala_assert (_tmp307_ != NULL, "e.child != null");
#line 812 "GomElementTest.vala"
		_tmp309_ = e;
#line 812 "GomElementTest.vala"
		_tmp310_ = gxml_dom_element_write_string ((GXmlDomElement*) _tmp309_, NULL, &_inner_error0_);
#line 812 "GomElementTest.vala"
		_tmp308_ = _tmp310_;
#line 812 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 812 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 11875 "GomElementTest.c"
			goto __catch141_g_error;
		}
#line 812 "GomElementTest.vala"
		g_message ("GomElementTest.vala:812: %s", _tmp308_);
#line 813 "GomElementTest.vala"
		_tmp311_ = object_parent_new ();
#line 813 "GomElementTest.vala"
		e2 = _tmp311_;
#line 814 "GomElementTest.vala"
		_tmp313_ = e;
#line 814 "GomElementTest.vala"
		_tmp314_ = gxml_dom_element_write_string ((GXmlDomElement*) _tmp313_, NULL, &_inner_error0_);
#line 814 "GomElementTest.vala"
		_tmp312_ = _tmp314_;
#line 814 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 814 "GomElementTest.vala"
			_g_object_unref0 (e2);
#line 814 "GomElementTest.vala"
			_g_free0 (_tmp308_);
#line 814 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 11898 "GomElementTest.c"
			goto __catch141_g_error;
		}
#line 814 "GomElementTest.vala"
		_tmp315_ = e2;
#line 814 "GomElementTest.vala"
		gxml_dom_element_read_from_string ((GXmlDomElement*) _tmp315_, _tmp312_, NULL, &_inner_error0_);
#line 814 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 814 "GomElementTest.vala"
			_g_free0 (_tmp312_);
#line 814 "GomElementTest.vala"
			_g_object_unref0 (e2);
#line 814 "GomElementTest.vala"
			_g_free0 (_tmp308_);
#line 814 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 11915 "GomElementTest.c"
			goto __catch141_g_error;
		}
#line 815 "GomElementTest.vala"
		_tmp317_ = e;
#line 815 "GomElementTest.vala"
		_tmp318_ = gxml_dom_element_write_string ((GXmlDomElement*) _tmp317_, NULL, &_inner_error0_);
#line 815 "GomElementTest.vala"
		_tmp316_ = _tmp318_;
#line 815 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 815 "GomElementTest.vala"
			_g_free0 (_tmp312_);
#line 815 "GomElementTest.vala"
			_g_object_unref0 (e2);
#line 815 "GomElementTest.vala"
			_g_free0 (_tmp308_);
#line 815 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 11934 "GomElementTest.c"
			goto __catch141_g_error;
		}
#line 815 "GomElementTest.vala"
		g_message ("GomElementTest.vala:815: %s", _tmp316_);
#line 816 "GomElementTest.vala"
		_tmp319_ = e2;
#line 816 "GomElementTest.vala"
		_tmp320_ = object_parent_get_child (_tmp319_);
#line 816 "GomElementTest.vala"
		_tmp321_ = _tmp320_;
#line 816 "GomElementTest.vala"
		_vala_assert (_tmp321_ != NULL, "e2.child != null");
#line 818 "GomElementTest.vala"
		_tmp322_ = e;
#line 818 "GomElementTest.vala"
		_tmp323_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp322_);
#line 818 "GomElementTest.vala"
		_tmp324_ = _tmp323_;
#line 818 "GomElementTest.vala"
		_tmp325_ = _tmp324_;
#line 818 "GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp325_, GXML_TYPE_DOM_NAMED_NODE_MAP), "e.attributes is DomNamedNodeMap");
#line 818 "GomElementTest.vala"
		_g_object_unref0 (_tmp325_);
#line 11959 "GomElementTest.c"
		{
			GeeIterator* _k_it = NULL;
			ObjectParent* _tmp326_;
			GXmlDomNamedNodeMap* _tmp327_;
			GXmlDomNamedNodeMap* _tmp328_;
			GXmlDomNamedNodeMap* _tmp329_;
			GeeSet* _tmp330_;
			GeeSet* _tmp331_;
			GeeSet* _tmp332_;
			GeeIterator* _tmp333_;
			GeeIterator* _tmp334_;
#line 819 "GomElementTest.vala"
			_tmp326_ = e;
#line 819 "GomElementTest.vala"
			_tmp327_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp326_);
#line 819 "GomElementTest.vala"
			_tmp328_ = _tmp327_;
#line 819 "GomElementTest.vala"
			_tmp329_ = _tmp328_;
#line 819 "GomElementTest.vala"
			_tmp330_ = gee_map_get_keys ((GeeMap*) _tmp329_);
#line 819 "GomElementTest.vala"
			_tmp331_ = _tmp330_;
#line 819 "GomElementTest.vala"
			_tmp332_ = _tmp331_;
#line 819 "GomElementTest.vala"
			_tmp333_ = gee_iterable_iterator ((GeeIterable*) _tmp332_);
#line 819 "GomElementTest.vala"
			_tmp334_ = _tmp333_;
#line 819 "GomElementTest.vala"
			_g_object_unref0 (_tmp332_);
#line 819 "GomElementTest.vala"
			_g_object_unref0 (_tmp329_);
#line 819 "GomElementTest.vala"
			_k_it = _tmp334_;
#line 819 "GomElementTest.vala"
			while (TRUE) {
#line 11997 "GomElementTest.c"
				GeeIterator* _tmp335_;
				gchar* k = NULL;
				GeeIterator* _tmp336_;
				gpointer _tmp337_;
				GXmlDomAttr* item = NULL;
				ObjectParent* _tmp338_;
				GXmlDomNamedNodeMap* _tmp339_;
				GXmlDomNamedNodeMap* _tmp340_;
				GXmlDomNamedNodeMap* _tmp341_;
				const gchar* _tmp342_;
				gpointer _tmp343_;
				GXmlDomNode* _tmp344_;
				GXmlDomAttr* _tmp345_;
				GXmlDomAttr* _tmp346_;
				GXmlDomAttr* _tmp347_;
#line 819 "GomElementTest.vala"
				_tmp335_ = _k_it;
#line 819 "GomElementTest.vala"
				if (!gee_iterator_next (_tmp335_)) {
#line 819 "GomElementTest.vala"
					break;
#line 12019 "GomElementTest.c"
				}
#line 819 "GomElementTest.vala"
				_tmp336_ = _k_it;
#line 819 "GomElementTest.vala"
				_tmp337_ = gee_iterator_get (_tmp336_);
#line 819 "GomElementTest.vala"
				k = (gchar*) _tmp337_;
#line 820 "GomElementTest.vala"
				_tmp338_ = e;
#line 820 "GomElementTest.vala"
				_tmp339_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp338_);
#line 820 "GomElementTest.vala"
				_tmp340_ = _tmp339_;
#line 820 "GomElementTest.vala"
				_tmp341_ = _tmp340_;
#line 820 "GomElementTest.vala"
				_tmp342_ = k;
#line 820 "GomElementTest.vala"
				_tmp343_ = gee_map_get ((GeeMap*) _tmp341_, _tmp342_);
#line 820 "GomElementTest.vala"
				_tmp344_ = (GXmlDomNode*) _tmp343_;
#line 820 "GomElementTest.vala"
				_tmp345_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp344_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp344_) : NULL;
#line 820 "GomElementTest.vala"
				if (_tmp345_ == NULL) {
#line 820 "GomElementTest.vala"
					_g_object_unref0 (_tmp344_);
#line 12047 "GomElementTest.c"
				}
#line 820 "GomElementTest.vala"
				_tmp346_ = _tmp345_;
#line 820 "GomElementTest.vala"
				_g_object_unref0 (_tmp341_);
#line 820 "GomElementTest.vala"
				item = _tmp346_;
#line 821 "GomElementTest.vala"
				_tmp347_ = item;
#line 821 "GomElementTest.vala"
				_vala_assert (_tmp347_ != NULL, "item != null");
#line 819 "GomElementTest.vala"
				_g_object_unref0 (item);
#line 819 "GomElementTest.vala"
				_g_free0 (k);
#line 12063 "GomElementTest.c"
			}
#line 819 "GomElementTest.vala"
			_g_object_unref0 (_k_it);
#line 12067 "GomElementTest.c"
		}
#line 808 "GomElementTest.vala"
		_g_free0 (_tmp316_);
#line 808 "GomElementTest.vala"
		_g_free0 (_tmp312_);
#line 808 "GomElementTest.vala"
		_g_object_unref0 (e2);
#line 808 "GomElementTest.vala"
		_g_free0 (_tmp308_);
#line 808 "GomElementTest.vala"
		_g_object_unref0 (e);
#line 12079 "GomElementTest.c"
	}
	goto __finally141;
	__catch141_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp348_;
		gchar* _tmp349_;
		gchar* _tmp350_;
#line 808 "GomElementTest.vala"
		e = _inner_error0_;
#line 808 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 824 "GomElementTest.vala"
		_tmp348_ = e->message;
#line 824 "GomElementTest.vala"
		_tmp349_ = g_strconcat ("Error: ", _tmp348_, NULL);
#line 824 "GomElementTest.vala"
		_tmp350_ = _tmp349_;
#line 824 "GomElementTest.vala"
		g_message ("GomElementTest.vala:824: %s", _tmp350_);
#line 824 "GomElementTest.vala"
		_g_free0 (_tmp350_);
#line 825 "GomElementTest.vala"
		g_assert_not_reached ();
#line 808 "GomElementTest.vala"
		_g_error_free0 (e);
#line 12106 "GomElementTest.c"
	}
	__finally141:
#line 808 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 808 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 808 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 808 "GomElementTest.vala"
		return;
#line 12117 "GomElementTest.c"
	}
}

static void
___lambda117__gtest_func (void)
{
#line 757 "GomElementTest.vala"
	__lambda117_ ();
#line 12126 "GomElementTest.c"
}

static void
__lambda118_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		ObjectParent* e = NULL;
		ObjectParent* _tmp0_;
		ObjectParent* _tmp1_;
		ObjectParent* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		ObjectParent* _tmp5_;
		ObjectParent* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		ObjectParent* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		ObjectParent* _tmp13_;
		GXmlDomNamedNodeMap* _tmp14_;
		GXmlDomNamedNodeMap* _tmp15_;
		GXmlDomNamedNodeMap* _tmp16_;
		GXmlDomNode* _tmp17_;
		GXmlDomAttr* _tmp18_;
		GXmlDomAttr* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
		ObjectParent* _tmp23_;
		ObjectParent* _tmp24_;
		ObjectParentObjectProperty* _tmp25_;
		ObjectParentObjectProperty* _tmp26_;
		ObjectParent* _tmp27_;
		ObjectParentObjectProperty* _tmp28_;
		ObjectParentObjectProperty* _tmp29_;
		ObjectParent* _tmp30_;
		ObjectParentObjectProperty* _tmp31_;
		ObjectParentObjectProperty* _tmp32_;
		gchar* _tmp33_;
		gchar* _tmp34_;
		gchar* _tmp35_;
		ObjectParent* _tmp36_;
		gchar* _tmp37_;
		gchar* _tmp38_;
		ObjectParent* _tmp39_;
		GXmlDomNamedNodeMap* _tmp40_;
		GXmlDomNamedNodeMap* _tmp41_;
		GXmlDomNamedNodeMap* _tmp42_;
		GXmlDomNode* _tmp43_;
		GXmlDomAttr* _tmp44_;
		GXmlDomAttr* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
		ObjectParent* _tmp49_;
		ObjectParent* _tmp50_;
		ObjectParentObjectProperty* _tmp51_;
		ObjectParentObjectProperty* _tmp52_;
		ObjectParent* _tmp53_;
		ObjectParentObjectProperty* _tmp54_;
		ObjectParentObjectProperty* _tmp55_;
		ObjectParent* _tmp56_;
		ObjectParentObjectProperty* _tmp57_;
		ObjectParentObjectProperty* _tmp58_;
		gchar* _tmp59_;
		gchar* _tmp60_;
		gchar* _tmp61_;
		ObjectParent* _tmp62_;
		gchar* _tmp63_;
		gchar* _tmp64_;
		ObjectParent* _tmp65_;
		GXmlDomNamedNodeMap* _tmp66_;
		GXmlDomNamedNodeMap* _tmp67_;
		GXmlDomNamedNodeMap* _tmp68_;
		GXmlDomNode* _tmp69_;
		GXmlDomAttr* _tmp70_;
		GXmlDomAttr* _tmp71_;
		gchar* _tmp72_;
		gchar* _tmp73_;
		gchar* _tmp74_;
		ObjectParent* _tmp75_;
		ObjectParent* _tmp76_;
		ObjectParentObjectProperty* _tmp77_;
		ObjectParentObjectProperty* _tmp78_;
		ObjectParent* _tmp79_;
		ObjectParentObjectProperty* _tmp80_;
		ObjectParentObjectProperty* _tmp81_;
		ObjectParent* _tmp82_;
		ObjectParentObjectProperty* _tmp83_;
		ObjectParentObjectProperty* _tmp84_;
		gchar* _tmp85_;
		gchar* _tmp86_;
		gchar* _tmp87_;
		ObjectParent* _tmp88_;
		gchar* _tmp89_;
		gchar* _tmp90_;
		ObjectParent* _tmp91_;
		GXmlDomNamedNodeMap* _tmp92_;
		GXmlDomNamedNodeMap* _tmp93_;
		GXmlDomNamedNodeMap* _tmp94_;
		GXmlDomNode* _tmp95_;
		GXmlDomAttr* _tmp96_;
		GXmlDomAttr* _tmp97_;
		gchar* _tmp98_;
		gchar* _tmp99_;
		gchar* _tmp100_;
		ObjectParent* _tmp101_;
		ObjectParent* _tmp102_;
		ObjectParentObjectProperty* _tmp103_;
		ObjectParentObjectProperty* _tmp104_;
		ObjectParent* _tmp105_;
		ObjectParentObjectProperty* _tmp106_;
		ObjectParentObjectProperty* _tmp107_;
		ObjectParent* _tmp108_;
		ObjectParentObjectProperty* _tmp109_;
		ObjectParentObjectProperty* _tmp110_;
		gchar* _tmp111_;
		gchar* _tmp112_;
		gchar* _tmp113_;
		ObjectParent* _tmp114_;
		gchar* _tmp115_;
		gchar* _tmp116_;
		ObjectParent* _tmp117_;
		GXmlDomNamedNodeMap* _tmp118_;
		GXmlDomNamedNodeMap* _tmp119_;
		GXmlDomNamedNodeMap* _tmp120_;
		GXmlDomNode* _tmp121_;
		GXmlDomAttr* _tmp122_;
		GXmlDomAttr* _tmp123_;
		gchar* _tmp124_;
		gchar* _tmp125_;
		gchar* _tmp126_;
#line 830 "GomElementTest.vala"
		_tmp0_ = object_parent_new ();
#line 830 "GomElementTest.vala"
		e = _tmp0_;
#line 831 "GomElementTest.vala"
		_tmp1_ = e;
#line 831 "GomElementTest.vala"
		gxml_dom_element_set_id ((GXmlDomElement*) _tmp1_, "id1");
#line 832 "GomElementTest.vala"
		_tmp2_ = e;
#line 832 "GomElementTest.vala"
		_tmp3_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp2_, "id");
#line 832 "GomElementTest.vala"
		_tmp4_ = _tmp3_;
#line 832 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp4_, "id1") == 0, "e.get_attribute (\"id\") == \"id1\"");
#line 832 "GomElementTest.vala"
		_g_free0 (_tmp4_);
#line 833 "GomElementTest.vala"
		_tmp5_ = e;
#line 833 "GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp5_, "id", "id2", &_inner_error0_);
#line 833 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 833 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 12288 "GomElementTest.c"
			goto __catch142_g_error;
		}
#line 834 "GomElementTest.vala"
		_tmp6_ = e;
#line 834 "GomElementTest.vala"
		_tmp7_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp6_, "id");
#line 834 "GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 834 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp8_, "id2") == 0, "e.get_attribute (\"id\") == \"id2\"");
#line 834 "GomElementTest.vala"
		_g_free0 (_tmp8_);
#line 835 "GomElementTest.vala"
		_tmp9_ = e;
#line 835 "GomElementTest.vala"
		_tmp10_ = gxml_dom_element_get_id ((GXmlDomElement*) _tmp9_);
#line 835 "GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 835 "GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 835 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp12_, "id2") == 0, "e.id == \"id2\"");
#line 835 "GomElementTest.vala"
		_g_free0 (_tmp12_);
#line 836 "GomElementTest.vala"
		_tmp13_ = e;
#line 836 "GomElementTest.vala"
		_tmp14_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp13_);
#line 836 "GomElementTest.vala"
		_tmp15_ = _tmp14_;
#line 836 "GomElementTest.vala"
		_tmp16_ = _tmp15_;
#line 836 "GomElementTest.vala"
		_tmp17_ = gxml_dom_named_node_map_item (_tmp16_, 0);
#line 836 "GomElementTest.vala"
		_tmp18_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp17_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp17_) : NULL;
#line 836 "GomElementTest.vala"
		if (_tmp18_ == NULL) {
#line 836 "GomElementTest.vala"
			_g_object_unref0 (_tmp17_);
#line 12329 "GomElementTest.c"
		}
#line 836 "GomElementTest.vala"
		_tmp19_ = _tmp18_;
#line 836 "GomElementTest.vala"
		_tmp20_ = gxml_dom_attr_get_value (_tmp19_);
#line 836 "GomElementTest.vala"
		_tmp21_ = _tmp20_;
#line 836 "GomElementTest.vala"
		_tmp22_ = _tmp21_;
#line 836 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp22_, "id2") == 0, "(e.attributes.item (0) as DomAttr).value == \"id2\"");
#line 836 "GomElementTest.vala"
		_g_free0 (_tmp22_);
#line 836 "GomElementTest.vala"
		_g_object_unref0 (_tmp19_);
#line 836 "GomElementTest.vala"
		_g_object_unref0 (_tmp16_);
#line 837 "GomElementTest.vala"
		_tmp23_ = e;
#line 837 "GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp23_, "prop", "val_prop", &_inner_error0_);
#line 837 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 837 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 12355 "GomElementTest.c"
			goto __catch142_g_error;
		}
#line 838 "GomElementTest.vala"
		_tmp24_ = e;
#line 838 "GomElementTest.vala"
		_tmp25_ = object_parent_get_prop (_tmp24_);
#line 838 "GomElementTest.vala"
		_tmp26_ = _tmp25_;
#line 838 "GomElementTest.vala"
		_vala_assert (_tmp26_ != NULL, "e.prop != null");
#line 839 "GomElementTest.vala"
		_tmp27_ = e;
#line 839 "GomElementTest.vala"
		_tmp28_ = object_parent_get_prop (_tmp27_);
#line 839 "GomElementTest.vala"
		_tmp29_ = _tmp28_;
#line 839 "GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp29_, OBJECT_PARENT_TYPE_OBJECT_PROPERTY), "e.prop is ObjectParent.ObjectProperty");
#line 840 "GomElementTest.vala"
		_tmp30_ = e;
#line 840 "GomElementTest.vala"
		_tmp31_ = object_parent_get_prop (_tmp30_);
#line 840 "GomElementTest.vala"
		_tmp32_ = _tmp31_;
#line 840 "GomElementTest.vala"
		_tmp33_ = gxml_gom_property_get_value ((GXmlGomProperty*) _tmp32_);
#line 840 "GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 840 "GomElementTest.vala"
		_tmp35_ = _tmp34_;
#line 840 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp35_, "val_prop") == 0, "e.prop.value == \"val_prop\"");
#line 840 "GomElementTest.vala"
		_g_free0 (_tmp35_);
#line 841 "GomElementTest.vala"
		_tmp36_ = e;
#line 841 "GomElementTest.vala"
		_tmp37_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp36_, "prop");
#line 841 "GomElementTest.vala"
		_tmp38_ = _tmp37_;
#line 841 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp38_, "val_prop") == 0, "e.get_attribute (\"prop\") == \"val_prop\"");
#line 841 "GomElementTest.vala"
		_g_free0 (_tmp38_);
#line 842 "GomElementTest.vala"
		_tmp39_ = e;
#line 842 "GomElementTest.vala"
		_tmp40_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp39_);
#line 842 "GomElementTest.vala"
		_tmp41_ = _tmp40_;
#line 842 "GomElementTest.vala"
		_tmp42_ = _tmp41_;
#line 842 "GomElementTest.vala"
		_tmp43_ = gxml_dom_named_node_map_item (_tmp42_, 1);
#line 842 "GomElementTest.vala"
		_tmp44_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp43_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp43_) : NULL;
#line 842 "GomElementTest.vala"
		if (_tmp44_ == NULL) {
#line 842 "GomElementTest.vala"
			_g_object_unref0 (_tmp43_);
#line 12416 "GomElementTest.c"
		}
#line 842 "GomElementTest.vala"
		_tmp45_ = _tmp44_;
#line 842 "GomElementTest.vala"
		_tmp46_ = gxml_dom_attr_get_value (_tmp45_);
#line 842 "GomElementTest.vala"
		_tmp47_ = _tmp46_;
#line 842 "GomElementTest.vala"
		_tmp48_ = _tmp47_;
#line 842 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp48_, "val_prop") == 0, "(e.attributes.item (1) as DomAttr).value == \"val_prop\"");
#line 842 "GomElementTest.vala"
		_g_free0 (_tmp48_);
#line 842 "GomElementTest.vala"
		_g_object_unref0 (_tmp45_);
#line 842 "GomElementTest.vala"
		_g_object_unref0 (_tmp42_);
#line 843 "GomElementTest.vala"
		_tmp49_ = e;
#line 843 "GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp49_, "prop1", "val_prop1", &_inner_error0_);
#line 843 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 843 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 12442 "GomElementTest.c"
			goto __catch142_g_error;
		}
#line 844 "GomElementTest.vala"
		_tmp50_ = e;
#line 844 "GomElementTest.vala"
		_tmp51_ = object_parent_get_prop1 (_tmp50_);
#line 844 "GomElementTest.vala"
		_tmp52_ = _tmp51_;
#line 844 "GomElementTest.vala"
		_vala_assert (_tmp52_ != NULL, "e.prop1 != null");
#line 845 "GomElementTest.vala"
		_tmp53_ = e;
#line 845 "GomElementTest.vala"
		_tmp54_ = object_parent_get_prop1 (_tmp53_);
#line 845 "GomElementTest.vala"
		_tmp55_ = _tmp54_;
#line 845 "GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp55_, OBJECT_PARENT_TYPE_OBJECT_PROPERTY), "e.prop1 is ObjectParent.ObjectProperty");
#line 846 "GomElementTest.vala"
		_tmp56_ = e;
#line 846 "GomElementTest.vala"
		_tmp57_ = object_parent_get_prop1 (_tmp56_);
#line 846 "GomElementTest.vala"
		_tmp58_ = _tmp57_;
#line 846 "GomElementTest.vala"
		_tmp59_ = gxml_gom_property_get_value ((GXmlGomProperty*) _tmp58_);
#line 846 "GomElementTest.vala"
		_tmp60_ = _tmp59_;
#line 846 "GomElementTest.vala"
		_tmp61_ = _tmp60_;
#line 846 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp61_, "val_prop1") == 0, "e.prop1.value == \"val_prop1\"");
#line 846 "GomElementTest.vala"
		_g_free0 (_tmp61_);
#line 847 "GomElementTest.vala"
		_tmp62_ = e;
#line 847 "GomElementTest.vala"
		_tmp63_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp62_, "prop1");
#line 847 "GomElementTest.vala"
		_tmp64_ = _tmp63_;
#line 847 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp64_, "val_prop1") == 0, "e.get_attribute (\"prop1\") == \"val_prop1\"");
#line 847 "GomElementTest.vala"
		_g_free0 (_tmp64_);
#line 848 "GomElementTest.vala"
		_tmp65_ = e;
#line 848 "GomElementTest.vala"
		_tmp66_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp65_);
#line 848 "GomElementTest.vala"
		_tmp67_ = _tmp66_;
#line 848 "GomElementTest.vala"
		_tmp68_ = _tmp67_;
#line 848 "GomElementTest.vala"
		_tmp69_ = gxml_dom_named_node_map_item (_tmp68_, 2);
#line 848 "GomElementTest.vala"
		_tmp70_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp69_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp69_) : NULL;
#line 848 "GomElementTest.vala"
		if (_tmp70_ == NULL) {
#line 848 "GomElementTest.vala"
			_g_object_unref0 (_tmp69_);
#line 12503 "GomElementTest.c"
		}
#line 848 "GomElementTest.vala"
		_tmp71_ = _tmp70_;
#line 848 "GomElementTest.vala"
		_tmp72_ = gxml_dom_attr_get_value (_tmp71_);
#line 848 "GomElementTest.vala"
		_tmp73_ = _tmp72_;
#line 848 "GomElementTest.vala"
		_tmp74_ = _tmp73_;
#line 848 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp74_, "val_prop1") == 0, "(e.attributes.item (2) as DomAttr).value == \"val_prop1\"");
#line 848 "GomElementTest.vala"
		_g_free0 (_tmp74_);
#line 848 "GomElementTest.vala"
		_g_object_unref0 (_tmp71_);
#line 848 "GomElementTest.vala"
		_g_object_unref0 (_tmp68_);
#line 849 "GomElementTest.vala"
		_tmp75_ = e;
#line 849 "GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp75_, "prop2", "val_prop2", &_inner_error0_);
#line 849 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 849 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 12529 "GomElementTest.c"
			goto __catch142_g_error;
		}
#line 850 "GomElementTest.vala"
		_tmp76_ = e;
#line 850 "GomElementTest.vala"
		_tmp77_ = object_parent_get_prop2 (_tmp76_);
#line 850 "GomElementTest.vala"
		_tmp78_ = _tmp77_;
#line 850 "GomElementTest.vala"
		_vala_assert (_tmp78_ != NULL, "e.prop2 != null");
#line 851 "GomElementTest.vala"
		_tmp79_ = e;
#line 851 "GomElementTest.vala"
		_tmp80_ = object_parent_get_prop2 (_tmp79_);
#line 851 "GomElementTest.vala"
		_tmp81_ = _tmp80_;
#line 851 "GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp81_, OBJECT_PARENT_TYPE_OBJECT_PROPERTY), "e.prop2 is ObjectParent.ObjectProperty");
#line 852 "GomElementTest.vala"
		_tmp82_ = e;
#line 852 "GomElementTest.vala"
		_tmp83_ = object_parent_get_prop2 (_tmp82_);
#line 852 "GomElementTest.vala"
		_tmp84_ = _tmp83_;
#line 852 "GomElementTest.vala"
		_tmp85_ = gxml_gom_property_get_value ((GXmlGomProperty*) _tmp84_);
#line 852 "GomElementTest.vala"
		_tmp86_ = _tmp85_;
#line 852 "GomElementTest.vala"
		_tmp87_ = _tmp86_;
#line 852 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp87_, "val_prop2") == 0, "e.prop2.value == \"val_prop2\"");
#line 852 "GomElementTest.vala"
		_g_free0 (_tmp87_);
#line 853 "GomElementTest.vala"
		_tmp88_ = e;
#line 853 "GomElementTest.vala"
		_tmp89_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp88_, "prop2");
#line 853 "GomElementTest.vala"
		_tmp90_ = _tmp89_;
#line 853 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp90_, "val_prop2") == 0, "e.get_attribute (\"prop2\") == \"val_prop2\"");
#line 853 "GomElementTest.vala"
		_g_free0 (_tmp90_);
#line 854 "GomElementTest.vala"
		_tmp91_ = e;
#line 854 "GomElementTest.vala"
		_tmp92_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp91_);
#line 854 "GomElementTest.vala"
		_tmp93_ = _tmp92_;
#line 854 "GomElementTest.vala"
		_tmp94_ = _tmp93_;
#line 854 "GomElementTest.vala"
		_tmp95_ = gxml_dom_named_node_map_item (_tmp94_, 3);
#line 854 "GomElementTest.vala"
		_tmp96_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp95_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp95_) : NULL;
#line 854 "GomElementTest.vala"
		if (_tmp96_ == NULL) {
#line 854 "GomElementTest.vala"
			_g_object_unref0 (_tmp95_);
#line 12590 "GomElementTest.c"
		}
#line 854 "GomElementTest.vala"
		_tmp97_ = _tmp96_;
#line 854 "GomElementTest.vala"
		_tmp98_ = gxml_dom_attr_get_value (_tmp97_);
#line 854 "GomElementTest.vala"
		_tmp99_ = _tmp98_;
#line 854 "GomElementTest.vala"
		_tmp100_ = _tmp99_;
#line 854 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp100_, "val_prop2") == 0, "(e.attributes.item (3) as DomAttr).value == \"val_prop2\"");
#line 854 "GomElementTest.vala"
		_g_free0 (_tmp100_);
#line 854 "GomElementTest.vala"
		_g_object_unref0 (_tmp97_);
#line 854 "GomElementTest.vala"
		_g_object_unref0 (_tmp94_);
#line 855 "GomElementTest.vala"
		_tmp101_ = e;
#line 855 "GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp101_, "prop3", "val_prop3", &_inner_error0_);
#line 855 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 855 "GomElementTest.vala"
			_g_object_unref0 (e);
#line 12616 "GomElementTest.c"
			goto __catch142_g_error;
		}
#line 856 "GomElementTest.vala"
		_tmp102_ = e;
#line 856 "GomElementTest.vala"
		_tmp103_ = object_parent_get_prop3 (_tmp102_);
#line 856 "GomElementTest.vala"
		_tmp104_ = _tmp103_;
#line 856 "GomElementTest.vala"
		_vala_assert (_tmp104_ != NULL, "e.prop3 != null");
#line 857 "GomElementTest.vala"
		_tmp105_ = e;
#line 857 "GomElementTest.vala"
		_tmp106_ = object_parent_get_prop3 (_tmp105_);
#line 857 "GomElementTest.vala"
		_tmp107_ = _tmp106_;
#line 857 "GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp107_, OBJECT_PARENT_TYPE_OBJECT_PROPERTY), "e.prop3 is ObjectParent.ObjectProperty");
#line 858 "GomElementTest.vala"
		_tmp108_ = e;
#line 858 "GomElementTest.vala"
		_tmp109_ = object_parent_get_prop3 (_tmp108_);
#line 858 "GomElementTest.vala"
		_tmp110_ = _tmp109_;
#line 858 "GomElementTest.vala"
		_tmp111_ = gxml_gom_property_get_value ((GXmlGomProperty*) _tmp110_);
#line 858 "GomElementTest.vala"
		_tmp112_ = _tmp111_;
#line 858 "GomElementTest.vala"
		_tmp113_ = _tmp112_;
#line 858 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp113_, "val_prop3") == 0, "e.prop3.value == \"val_prop3\"");
#line 858 "GomElementTest.vala"
		_g_free0 (_tmp113_);
#line 859 "GomElementTest.vala"
		_tmp114_ = e;
#line 859 "GomElementTest.vala"
		_tmp115_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp114_, "prop3");
#line 859 "GomElementTest.vala"
		_tmp116_ = _tmp115_;
#line 859 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp116_, "val_prop3") == 0, "e.get_attribute (\"prop3\") == \"val_prop3\"");
#line 859 "GomElementTest.vala"
		_g_free0 (_tmp116_);
#line 860 "GomElementTest.vala"
		_tmp117_ = e;
#line 860 "GomElementTest.vala"
		_tmp118_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp117_);
#line 860 "GomElementTest.vala"
		_tmp119_ = _tmp118_;
#line 860 "GomElementTest.vala"
		_tmp120_ = _tmp119_;
#line 860 "GomElementTest.vala"
		_tmp121_ = gxml_dom_named_node_map_item (_tmp120_, 4);
#line 860 "GomElementTest.vala"
		_tmp122_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp121_, GXML_TYPE_DOM_ATTR) ? ((GXmlDomAttr*) _tmp121_) : NULL;
#line 860 "GomElementTest.vala"
		if (_tmp122_ == NULL) {
#line 860 "GomElementTest.vala"
			_g_object_unref0 (_tmp121_);
#line 12677 "GomElementTest.c"
		}
#line 860 "GomElementTest.vala"
		_tmp123_ = _tmp122_;
#line 860 "GomElementTest.vala"
		_tmp124_ = gxml_dom_attr_get_value (_tmp123_);
#line 860 "GomElementTest.vala"
		_tmp125_ = _tmp124_;
#line 860 "GomElementTest.vala"
		_tmp126_ = _tmp125_;
#line 860 "GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp126_, "val_prop3") == 0, "(e.attributes.item (4) as DomAttr).value == \"val_prop3\"");
#line 860 "GomElementTest.vala"
		_g_free0 (_tmp126_);
#line 860 "GomElementTest.vala"
		_g_object_unref0 (_tmp123_);
#line 860 "GomElementTest.vala"
		_g_object_unref0 (_tmp120_);
#line 829 "GomElementTest.vala"
		_g_object_unref0 (e);
#line 12697 "GomElementTest.c"
	}
	goto __finally142;
	__catch142_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp127_;
		gchar* _tmp128_;
		gchar* _tmp129_;
#line 829 "GomElementTest.vala"
		e = _inner_error0_;
#line 829 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 862 "GomElementTest.vala"
		_tmp127_ = e->message;
#line 862 "GomElementTest.vala"
		_tmp128_ = g_strconcat ("Error: ", _tmp127_, NULL);
#line 862 "GomElementTest.vala"
		_tmp129_ = _tmp128_;
#line 862 "GomElementTest.vala"
		g_message ("GomElementTest.vala:862: %s", _tmp129_);
#line 862 "GomElementTest.vala"
		_g_free0 (_tmp129_);
#line 863 "GomElementTest.vala"
		g_assert_not_reached ();
#line 829 "GomElementTest.vala"
		_g_error_free0 (e);
#line 12724 "GomElementTest.c"
	}
	__finally142:
#line 829 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 829 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 829 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 829 "GomElementTest.vala"
		return;
#line 12735 "GomElementTest.c"
	}
}

static void
___lambda118__gtest_func (void)
{
#line 828 "GomElementTest.vala"
	__lambda118_ ();
#line 12744 "GomElementTest.c"
}

void
gom_element_test_add_tests (void)
{
#line 212 "GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/read/namespace_uri", ___lambda97__gtest_func);
#line 240 "GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/namespace_uri", ___lambda98__gtest_func);
#line 274 "GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/read/namespace/redefinition", ___lambda99__gtest_func);
#line 300 "GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/attributes", ___lambda100__gtest_func);
#line 374 "GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/attributes/property-ns", ___lambda101__gtest_func);
#line 395 "GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/attribute-ns/collection", ___lambda102__gtest_func);
#line 417 "GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/lookup-prefix", ___lambda103__gtest_func);
#line 445 "GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/content/add_aside_child_nodes", ___lambda104__gtest_func);
#line 462 "GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/content/keep_child_nodes", ___lambda105__gtest_func);
#line 479 "GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/parent", ___lambda106__gtest_func);
#line 493 "GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/remove", ___lambda107__gtest_func);
#line 509 "GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/parsed-delayed", ___lambda108__gtest_func);
#line 526 "GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/write/string", ___lambda109__gtest_func);
#line 544 "GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/write/stream", ___lambda110__gtest_func);
#line 559 "GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/write/input_stream", ___lambda111__gtest_func);
#line 575 "GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/previous_element_sibling", ___lambda112__gtest_func);
#line 606 "GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/css-selector", ___lambda113__gtest_func);
#line 665 "GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/no-instantiatable/avoid", ___lambda114__gtest_func);
#line 677 "GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/no-instantiatable/set", ___lambda115__gtest_func);
#line 691 "GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/ordered-attributes", ___lambda116__gtest_func);
#line 757 "GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/object-attributes/attributes-collection", ___lambda117__gtest_func);
#line 828 "GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/object-attributes/attributes-update", ___lambda118__gtest_func);
#line 12794 "GomElementTest.c"
}

GomElementTest*
gom_element_test_construct (GType object_type)
{
	GomElementTest* self = NULL;
#line 60 "GomElementTest.vala"
	self = (GomElementTest*) gxml_test_construct (object_type);
#line 60 "GomElementTest.vala"
	return self;
#line 12805 "GomElementTest.c"
}

GomElementTest*
gom_element_test_new (void)
{
#line 60 "GomElementTest.vala"
	return gom_element_test_construct (TYPE_GOM_ELEMENT_TEST);
#line 12813 "GomElementTest.c"
}

GomElementTestParsedDelayed*
gom_element_test_parsed_delayed_construct (GType object_type)
{
	GomElementTestParsedDelayed * self = NULL;
#line 61 "GomElementTest.vala"
	self = (GomElementTestParsedDelayed*) gxml_gom_element_construct (object_type);
#line 61 "GomElementTest.vala"
	return self;
#line 12824 "GomElementTest.c"
}

GomElementTestParsedDelayed*
gom_element_test_parsed_delayed_new (void)
{
#line 61 "GomElementTest.vala"
	return gom_element_test_parsed_delayed_construct (GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED);
#line 12832 "GomElementTest.c"
}

static GObject *
gom_element_test_parsed_delayed_constructor (GType type,
                                             guint n_construct_properties,
                                             GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestParsedDelayed * self;
	GError* _inner_error0_ = NULL;
#line 62 "GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_parsed_delayed_parent_class);
#line 62 "GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 62 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED, GomElementTestParsedDelayed);
#line 12850 "GomElementTest.c"
	{
#line 63 "GomElementTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "root");
#line 12854 "GomElementTest.c"
	}
	goto __finally143;
	__catch143_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 63 "GomElementTest.vala"
		e = _inner_error0_;
#line 63 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 64 "GomElementTest.vala"
		_tmp0_ = e;
#line 64 "GomElementTest.vala"
		_tmp1_ = _tmp0_->message;
#line 64 "GomElementTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 64 "GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 64 "GomElementTest.vala"
		g_warning ("GomElementTest.vala:64: %s", _tmp3_);
#line 64 "GomElementTest.vala"
		_g_free0 (_tmp3_);
#line 63 "GomElementTest.vala"
		_g_error_free0 (e);
#line 12882 "GomElementTest.c"
	}
	__finally143:
#line 63 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 63 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 63 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 12891 "GomElementTest.c"
	}
#line 65 "GomElementTest.vala"
	gxml_gom_element_set_parse_children ((GXmlGomElement*) self, FALSE);
#line 62 "GomElementTest.vala"
	return obj;
#line 12897 "GomElementTest.c"
}

static void
gom_element_test_parsed_delayed_class_init (GomElementTestParsedDelayedClass * klass,
                                            gpointer klass_data)
{
#line 61 "GomElementTest.vala"
	gom_element_test_parsed_delayed_parent_class = g_type_class_peek_parent (klass);
#line 61 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_parsed_delayed_constructor;
#line 12908 "GomElementTest.c"
}

static void
gom_element_test_parsed_delayed_instance_init (GomElementTestParsedDelayed * self,
                                               gpointer klass)
{
}

GType
gom_element_test_parsed_delayed_get_type (void)
{
	static volatile gsize gom_element_test_parsed_delayed_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_parsed_delayed_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestParsedDelayedClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_parsed_delayed_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestParsedDelayed), 0, (GInstanceInitFunc) gom_element_test_parsed_delayed_instance_init, NULL };
		GType gom_element_test_parsed_delayed_type_id;
		gom_element_test_parsed_delayed_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestParsedDelayed", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_parsed_delayed_type_id__volatile, gom_element_test_parsed_delayed_type_id);
	}
	return gom_element_test_parsed_delayed_type_id__volatile;
}

static inline gpointer
gom_element_test_instantiatable_get_instance_private (GomElementTestInstantiatable* self)
{
	return G_STRUCT_MEMBER_P (self, GomElementTestInstantiatable_private_offset);
}

GomElementTestInstantiatable*
gom_element_test_instantiatable_construct (GType object_type)
{
	GomElementTestInstantiatable * self = NULL;
#line 68 "GomElementTest.vala"
	self = (GomElementTestInstantiatable*) gxml_gom_element_construct (object_type);
#line 68 "GomElementTest.vala"
	return self;
#line 12944 "GomElementTest.c"
}

GomElementTestInstantiatable*
gom_element_test_instantiatable_new (void)
{
#line 68 "GomElementTest.vala"
	return gom_element_test_instantiatable_construct (GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE);
#line 12952 "GomElementTest.c"
}

static const gchar*
gom_element_test_instantiatable_real_get_name (NoInstantiatable* base)
{
	const gchar* result;
	GomElementTestInstantiatable* self;
	const gchar* _tmp0_;
#line 70 "GomElementTest.vala"
	self = (GomElementTestInstantiatable*) base;
#line 70 "GomElementTest.vala"
	_tmp0_ = self->priv->_name;
#line 70 "GomElementTest.vala"
	result = _tmp0_;
#line 70 "GomElementTest.vala"
	return result;
#line 12969 "GomElementTest.c"
}

static void
gom_element_test_instantiatable_real_set_name (NoInstantiatable* base,
                                               const gchar* value)
{
	GomElementTestInstantiatable* self;
#line 70 "GomElementTest.vala"
	self = (GomElementTestInstantiatable*) base;
#line 70 "GomElementTest.vala"
	if (g_strcmp0 (value, gom_element_test_instantiatable_real_get_name (base)) != 0) {
#line 12981 "GomElementTest.c"
		gchar* _tmp0_;
#line 70 "GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 70 "GomElementTest.vala"
		_g_free0 (self->priv->_name);
#line 70 "GomElementTest.vala"
		self->priv->_name = _tmp0_;
#line 70 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_instantiatable_properties[GOM_ELEMENT_TEST_INSTANTIATABLE_NAME_PROPERTY]);
#line 12991 "GomElementTest.c"
	}
}

static GObject *
gom_element_test_instantiatable_constructor (GType type,
                                             guint n_construct_properties,
                                             GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestInstantiatable * self;
#line 71 "GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_instantiatable_parent_class);
#line 71 "GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 71 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, GomElementTestInstantiatable);
#line 71 "GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "Instantiatable");
#line 71 "GomElementTest.vala"
	return obj;
#line 13013 "GomElementTest.c"
}

static void
gom_element_test_instantiatable_class_init (GomElementTestInstantiatableClass * klass,
                                            gpointer klass_data)
{
#line 68 "GomElementTest.vala"
	gom_element_test_instantiatable_parent_class = g_type_class_peek_parent (klass);
#line 68 "GomElementTest.vala"
	g_type_class_adjust_private_offset (klass, &GomElementTestInstantiatable_private_offset);
#line 68 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_instantiatable_get_property;
#line 68 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_instantiatable_set_property;
#line 68 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_instantiatable_constructor;
#line 68 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_instantiatable_finalize;
#line 68 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_INSTANTIATABLE_NAME_PROPERTY, gom_element_test_instantiatable_properties[GOM_ELEMENT_TEST_INSTANTIATABLE_NAME_PROPERTY] = g_param_spec_string ("name", "::name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13034 "GomElementTest.c"
}

static void
gom_element_test_instantiatable_no_instantiatable_interface_init (NoInstantiatableIface * iface,
                                                                  gpointer iface_data)
{
#line 68 "GomElementTest.vala"
	gom_element_test_instantiatable_no_instantiatable_parent_iface = g_type_interface_peek_parent (iface);
#line 68 "GomElementTest.vala"
	iface->get_name = gom_element_test_instantiatable_real_get_name;
#line 68 "GomElementTest.vala"
	iface->set_name = gom_element_test_instantiatable_real_set_name;
#line 13047 "GomElementTest.c"
}

static void
gom_element_test_instantiatable_instance_init (GomElementTestInstantiatable * self,
                                               gpointer klass)
{
#line 68 "GomElementTest.vala"
	self->priv = gom_element_test_instantiatable_get_instance_private (self);
#line 13056 "GomElementTest.c"
}

static void
gom_element_test_instantiatable_finalize (GObject * obj)
{
	GomElementTestInstantiatable * self;
#line 68 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, GomElementTestInstantiatable);
#line 70 "GomElementTest.vala"
	_g_free0 (self->priv->_name);
#line 68 "GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_instantiatable_parent_class)->finalize (obj);
#line 13069 "GomElementTest.c"
}

GType
gom_element_test_instantiatable_get_type (void)
{
	static volatile gsize gom_element_test_instantiatable_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_instantiatable_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestInstantiatableClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_instantiatable_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestInstantiatable), 0, (GInstanceInitFunc) gom_element_test_instantiatable_instance_init, NULL };
		static const GInterfaceInfo no_instantiatable_info = { (GInterfaceInitFunc) gom_element_test_instantiatable_no_instantiatable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gom_element_test_instantiatable_type_id;
		gom_element_test_instantiatable_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestInstantiatable", &g_define_type_info, 0);
		g_type_add_interface_static (gom_element_test_instantiatable_type_id, TYPE_NO_INSTANTIATABLE, &no_instantiatable_info);
		GomElementTestInstantiatable_private_offset = g_type_add_instance_private (gom_element_test_instantiatable_type_id, sizeof (GomElementTestInstantiatablePrivate));
		g_once_init_leave (&gom_element_test_instantiatable_type_id__volatile, gom_element_test_instantiatable_type_id);
	}
	return gom_element_test_instantiatable_type_id__volatile;
}

static void
_vala_gom_element_test_instantiatable_get_property (GObject * object,
                                                    guint property_id,
                                                    GValue * value,
                                                    GParamSpec * pspec)
{
	GomElementTestInstantiatable * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, GomElementTestInstantiatable);
#line 68 "GomElementTest.vala"
	switch (property_id) {
#line 68 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_INSTANTIATABLE_NAME_PROPERTY:
#line 68 "GomElementTest.vala"
		g_value_set_string (value, no_instantiatable_get_name ((NoInstantiatable*) self));
#line 68 "GomElementTest.vala"
		break;
#line 13104 "GomElementTest.c"
		default:
#line 68 "GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 68 "GomElementTest.vala"
		break;
#line 13110 "GomElementTest.c"
	}
}

static void
_vala_gom_element_test_instantiatable_set_property (GObject * object,
                                                    guint property_id,
                                                    const GValue * value,
                                                    GParamSpec * pspec)
{
	GomElementTestInstantiatable * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, GomElementTestInstantiatable);
#line 68 "GomElementTest.vala"
	switch (property_id) {
#line 68 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_INSTANTIATABLE_NAME_PROPERTY:
#line 68 "GomElementTest.vala"
		no_instantiatable_set_name ((NoInstantiatable*) self, g_value_get_string (value));
#line 68 "GomElementTest.vala"
		break;
#line 13130 "GomElementTest.c"
		default:
#line 68 "GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 68 "GomElementTest.vala"
		break;
#line 13136 "GomElementTest.c"
	}
}

static inline gpointer
gom_element_test_top_get_instance_private (GomElementTestTop* self)
{
	return G_STRUCT_MEMBER_P (self, GomElementTestTop_private_offset);
}

GomElementTestTop*
gom_element_test_top_construct (GType object_type)
{
	GomElementTestTop * self = NULL;
#line 73 "GomElementTest.vala"
	self = (GomElementTestTop*) gxml_gom_element_construct (object_type);
#line 73 "GomElementTest.vala"
	return self;
#line 13154 "GomElementTest.c"
}

GomElementTestTop*
gom_element_test_top_new (void)
{
#line 73 "GomElementTest.vala"
	return gom_element_test_top_construct (GOM_ELEMENT_TEST_TYPE_TOP);
#line 13162 "GomElementTest.c"
}

NoInstantiatable*
gom_element_test_top_get_inst (GomElementTestTop* self)
{
	NoInstantiatable* result;
	GomElementTestInstantiatable* _tmp0_;
#line 75 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 75 "GomElementTest.vala"
	_tmp0_ = self->priv->_inst_i;
#line 75 "GomElementTest.vala"
	result = (NoInstantiatable*) _tmp0_;
#line 75 "GomElementTest.vala"
	return result;
#line 13178 "GomElementTest.c"
}

void
gom_element_test_top_set_inst (GomElementTestTop* self,
                               NoInstantiatable* value)
{
#line 75 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 75 "GomElementTest.vala"
	gom_element_test_top_set_inst_i (self, G_TYPE_CHECK_INSTANCE_TYPE (value, GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE) ? ((GomElementTestInstantiatable*) value) : NULL);
#line 75 "GomElementTest.vala"
	g_object_notify_by_pspec ((GObject *) self, gom_element_test_top_properties[GOM_ELEMENT_TEST_TOP_INST_PROPERTY]);
#line 13191 "GomElementTest.c"
}

GomElementTestInstantiatable*
gom_element_test_top_get_inst_i (GomElementTestTop* self)
{
	GomElementTestInstantiatable* result;
	GomElementTestInstantiatable* _tmp0_;
#line 77 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 77 "GomElementTest.vala"
	_tmp0_ = self->priv->_inst_i;
#line 77 "GomElementTest.vala"
	result = _tmp0_;
#line 77 "GomElementTest.vala"
	return result;
#line 13207 "GomElementTest.c"
}

void
gom_element_test_top_set_inst_i (GomElementTestTop* self,
                                 GomElementTestInstantiatable* value)
{
#line 77 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 77 "GomElementTest.vala"
	if (gom_element_test_top_get_inst_i (self) != value) {
#line 13218 "GomElementTest.c"
		GomElementTestInstantiatable* _tmp0_;
#line 77 "GomElementTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 77 "GomElementTest.vala"
		_g_object_unref0 (self->priv->_inst_i);
#line 77 "GomElementTest.vala"
		self->priv->_inst_i = _tmp0_;
#line 77 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_top_properties[GOM_ELEMENT_TEST_TOP_INST_I_PROPERTY]);
#line 13228 "GomElementTest.c"
	}
}

Property*
gom_element_test_top_get_pq (GomElementTestTop* self)
{
	Property* result;
	Property* _tmp0_;
#line 79 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 79 "GomElementTest.vala"
	_tmp0_ = self->priv->_pq;
#line 79 "GomElementTest.vala"
	result = _tmp0_;
#line 79 "GomElementTest.vala"
	return result;
#line 13245 "GomElementTest.c"
}

void
gom_element_test_top_set_pq (GomElementTestTop* self,
                             Property* value)
{
#line 79 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 79 "GomElementTest.vala"
	if (gom_element_test_top_get_pq (self) != value) {
#line 13256 "GomElementTest.c"
		Property* _tmp0_;
#line 79 "GomElementTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 79 "GomElementTest.vala"
		_g_object_unref0 (self->priv->_pq);
#line 79 "GomElementTest.vala"
		self->priv->_pq = _tmp0_;
#line 79 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_top_properties[GOM_ELEMENT_TEST_TOP_PQ_PROPERTY]);
#line 13266 "GomElementTest.c"
	}
}

static GObject *
gom_element_test_top_constructor (GType type,
                                  guint n_construct_properties,
                                  GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestTop * self;
#line 80 "GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_top_parent_class);
#line 80 "GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 80 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_TOP, GomElementTestTop);
#line 80 "GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "Top");
#line 80 "GomElementTest.vala"
	return obj;
#line 13288 "GomElementTest.c"
}

static void
gom_element_test_top_class_init (GomElementTestTopClass * klass,
                                 gpointer klass_data)
{
#line 73 "GomElementTest.vala"
	gom_element_test_top_parent_class = g_type_class_peek_parent (klass);
#line 73 "GomElementTest.vala"
	g_type_class_adjust_private_offset (klass, &GomElementTestTop_private_offset);
#line 73 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_top_get_property;
#line 73 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_top_set_property;
#line 73 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_top_constructor;
#line 73 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_top_finalize;
#line 73 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_TOP_INST_PROPERTY, gom_element_test_top_properties[GOM_ELEMENT_TEST_TOP_INST_PROPERTY] = g_param_spec_object ("inst", "inst", "inst", TYPE_NO_INSTANTIATABLE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 73 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_TOP_INST_I_PROPERTY, gom_element_test_top_properties[GOM_ELEMENT_TEST_TOP_INST_I_PROPERTY] = g_param_spec_object ("inst-i", "inst-i", "inst-i", GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 73 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_TOP_PQ_PROPERTY, gom_element_test_top_properties[GOM_ELEMENT_TEST_TOP_PQ_PROPERTY] = g_param_spec_object ("pq", "::pq", "pq", TYPE_PROPERTY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13313 "GomElementTest.c"
}

static void
gom_element_test_top_instance_init (GomElementTestTop * self,
                                    gpointer klass)
{
#line 73 "GomElementTest.vala"
	self->priv = gom_element_test_top_get_instance_private (self);
#line 13322 "GomElementTest.c"
}

static void
gom_element_test_top_finalize (GObject * obj)
{
	GomElementTestTop * self;
#line 73 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_TOP, GomElementTestTop);
#line 77 "GomElementTest.vala"
	_g_object_unref0 (self->priv->_inst_i);
#line 79 "GomElementTest.vala"
	_g_object_unref0 (self->priv->_pq);
#line 73 "GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_top_parent_class)->finalize (obj);
#line 13337 "GomElementTest.c"
}

GType
gom_element_test_top_get_type (void)
{
	static volatile gsize gom_element_test_top_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_top_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestTopClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_top_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestTop), 0, (GInstanceInitFunc) gom_element_test_top_instance_init, NULL };
		GType gom_element_test_top_type_id;
		gom_element_test_top_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestTop", &g_define_type_info, 0);
		GomElementTestTop_private_offset = g_type_add_instance_private (gom_element_test_top_type_id, sizeof (GomElementTestTopPrivate));
		g_once_init_leave (&gom_element_test_top_type_id__volatile, gom_element_test_top_type_id);
	}
	return gom_element_test_top_type_id__volatile;
}

static void
_vala_gom_element_test_top_get_property (GObject * object,
                                         guint property_id,
                                         GValue * value,
                                         GParamSpec * pspec)
{
	GomElementTestTop * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_TOP, GomElementTestTop);
#line 73 "GomElementTest.vala"
	switch (property_id) {
#line 73 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_TOP_INST_PROPERTY:
#line 73 "GomElementTest.vala"
		g_value_set_object (value, gom_element_test_top_get_inst (self));
#line 73 "GomElementTest.vala"
		break;
#line 73 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_TOP_INST_I_PROPERTY:
#line 73 "GomElementTest.vala"
		g_value_set_object (value, gom_element_test_top_get_inst_i (self));
#line 73 "GomElementTest.vala"
		break;
#line 73 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_TOP_PQ_PROPERTY:
#line 73 "GomElementTest.vala"
		g_value_set_object (value, gom_element_test_top_get_pq (self));
#line 73 "GomElementTest.vala"
		break;
#line 13382 "GomElementTest.c"
		default:
#line 73 "GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 73 "GomElementTest.vala"
		break;
#line 13388 "GomElementTest.c"
	}
}

static void
_vala_gom_element_test_top_set_property (GObject * object,
                                         guint property_id,
                                         const GValue * value,
                                         GParamSpec * pspec)
{
	GomElementTestTop * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_TOP, GomElementTestTop);
#line 73 "GomElementTest.vala"
	switch (property_id) {
#line 73 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_TOP_INST_PROPERTY:
#line 73 "GomElementTest.vala"
		gom_element_test_top_set_inst (self, g_value_get_object (value));
#line 73 "GomElementTest.vala"
		break;
#line 73 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_TOP_INST_I_PROPERTY:
#line 73 "GomElementTest.vala"
		gom_element_test_top_set_inst_i (self, g_value_get_object (value));
#line 73 "GomElementTest.vala"
		break;
#line 73 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_TOP_PQ_PROPERTY:
#line 73 "GomElementTest.vala"
		gom_element_test_top_set_pq (self, g_value_get_object (value));
#line 73 "GomElementTest.vala"
		break;
#line 13420 "GomElementTest.c"
		default:
#line 73 "GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 73 "GomElementTest.vala"
		break;
#line 13426 "GomElementTest.c"
	}
}

GomElementTestGProperty*
gom_element_test_gproperty_construct (GType object_type)
{
	GomElementTestGProperty * self = NULL;
#line 82 "GomElementTest.vala"
	self = (GomElementTestGProperty*) gxml_gom_string_construct (object_type);
#line 82 "GomElementTest.vala"
	return self;
#line 13438 "GomElementTest.c"
}

GomElementTestGProperty*
gom_element_test_gproperty_new (void)
{
#line 82 "GomElementTest.vala"
	return gom_element_test_gproperty_construct (GOM_ELEMENT_TEST_TYPE_GPROPERTY);
#line 13446 "GomElementTest.c"
}

static void
gom_element_test_gproperty_class_init (GomElementTestGPropertyClass * klass,
                                       gpointer klass_data)
{
#line 82 "GomElementTest.vala"
	gom_element_test_gproperty_parent_class = g_type_class_peek_parent (klass);
#line 13455 "GomElementTest.c"
}

static void
gom_element_test_gproperty_property_interface_init (PropertyIface * iface,
                                                    gpointer iface_data)
{
#line 82 "GomElementTest.vala"
	gom_element_test_gproperty_property_parent_iface = g_type_interface_peek_parent (iface);
#line 13464 "GomElementTest.c"
}

static void
gom_element_test_gproperty_instance_init (GomElementTestGProperty * self,
                                          gpointer klass)
{
}

GType
gom_element_test_gproperty_get_type (void)
{
	static volatile gsize gom_element_test_gproperty_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_gproperty_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestGPropertyClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_gproperty_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestGProperty), 0, (GInstanceInitFunc) gom_element_test_gproperty_instance_init, NULL };
		static const GInterfaceInfo property_info = { (GInterfaceInitFunc) gom_element_test_gproperty_property_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gom_element_test_gproperty_type_id;
		gom_element_test_gproperty_type_id = g_type_register_static (GXML_TYPE_GOM_STRING, "GomElementTestGProperty", &g_define_type_info, 0);
		g_type_add_interface_static (gom_element_test_gproperty_type_id, TYPE_PROPERTY, &property_info);
		g_once_init_leave (&gom_element_test_gproperty_type_id__volatile, gom_element_test_gproperty_type_id);
	}
	return gom_element_test_gproperty_type_id__volatile;
}

static inline gpointer
gom_element_test_gtop_get_instance_private (GomElementTestGTop* self)
{
	return G_STRUCT_MEMBER_P (self, GomElementTestGTop_private_offset);
}

GomElementTestGTop*
gom_element_test_gtop_construct (GType object_type)
{
	GomElementTestGTop * self = NULL;
#line 83 "GomElementTest.vala"
	self = (GomElementTestGTop*) gxml_gom_element_construct (object_type);
#line 83 "GomElementTest.vala"
	return self;
#line 13502 "GomElementTest.c"
}

GomElementTestGTop*
gom_element_test_gtop_new (void)
{
#line 83 "GomElementTest.vala"
	return gom_element_test_gtop_construct (GOM_ELEMENT_TEST_TYPE_GTOP);
#line 13510 "GomElementTest.c"
}

NoInstantiatable*
gom_element_test_gtop_get_inst (GomElementTestGTop* self)
{
	NoInstantiatable* result;
	NoInstantiatable* _tmp0_;
#line 84 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 84 "GomElementTest.vala"
	_tmp0_ = self->priv->_inst;
#line 84 "GomElementTest.vala"
	result = _tmp0_;
#line 84 "GomElementTest.vala"
	return result;
#line 13526 "GomElementTest.c"
}

void
gom_element_test_gtop_set_inst (GomElementTestGTop* self,
                                NoInstantiatable* value)
{
#line 84 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 84 "GomElementTest.vala"
	if (gom_element_test_gtop_get_inst (self) != value) {
#line 13537 "GomElementTest.c"
		NoInstantiatable* _tmp0_;
#line 84 "GomElementTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 84 "GomElementTest.vala"
		_g_object_unref0 (self->priv->_inst);
#line 84 "GomElementTest.vala"
		self->priv->_inst = _tmp0_;
#line 84 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_gtop_properties[GOM_ELEMENT_TEST_GTOP_INST_PROPERTY]);
#line 13547 "GomElementTest.c"
	}
}

GomElementTestInstantiatable*
gom_element_test_gtop_get_inst_i (GomElementTestGTop* self)
{
	GomElementTestInstantiatable* result;
	NoInstantiatable* _tmp0_;
#line 86 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 86 "GomElementTest.vala"
	_tmp0_ = self->priv->_inst;
#line 86 "GomElementTest.vala"
	result = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE) ? ((GomElementTestInstantiatable*) _tmp0_) : NULL;
#line 86 "GomElementTest.vala"
	return result;
#line 13564 "GomElementTest.c"
}

void
gom_element_test_gtop_set_inst_i (GomElementTestGTop* self,
                                  GomElementTestInstantiatable* value)
{
#line 87 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 87 "GomElementTest.vala"
	gom_element_test_gtop_set_inst (self, G_TYPE_CHECK_INSTANCE_TYPE (value, TYPE_NO_INSTANTIATABLE) ? ((NoInstantiatable*) value) : NULL);
#line 87 "GomElementTest.vala"
	g_object_notify_by_pspec ((GObject *) self, gom_element_test_gtop_properties[GOM_ELEMENT_TEST_GTOP_INST_I_PROPERTY]);
#line 13577 "GomElementTest.c"
}

GomElementTestGProperty*
gom_element_test_gtop_get_gpq (GomElementTestGTop* self)
{
	GomElementTestGProperty* result;
	Property* _tmp0_;
#line 92 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 92 "GomElementTest.vala"
	_tmp0_ = self->priv->_pq;
#line 92 "GomElementTest.vala"
	result = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GOM_ELEMENT_TEST_TYPE_GPROPERTY) ? ((GomElementTestGProperty*) _tmp0_) : NULL;
#line 92 "GomElementTest.vala"
	return result;
#line 13593 "GomElementTest.c"
}

void
gom_element_test_gtop_set_gpq (GomElementTestGTop* self,
                               GomElementTestGProperty* value)
{
#line 93 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 93 "GomElementTest.vala"
	gom_element_test_gtop_set_pq (self, G_TYPE_CHECK_INSTANCE_TYPE (value, TYPE_PROPERTY) ? ((Property*) value) : NULL);
#line 93 "GomElementTest.vala"
	g_object_notify_by_pspec ((GObject *) self, gom_element_test_gtop_properties[GOM_ELEMENT_TEST_GTOP_GPQ_PROPERTY]);
#line 13606 "GomElementTest.c"
}

Property*
gom_element_test_gtop_get_pq (GomElementTestGTop* self)
{
	Property* result;
	Property* _tmp0_;
#line 99 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 99 "GomElementTest.vala"
	_tmp0_ = self->priv->_pq;
#line 99 "GomElementTest.vala"
	result = _tmp0_;
#line 99 "GomElementTest.vala"
	return result;
#line 13622 "GomElementTest.c"
}

void
gom_element_test_gtop_set_pq (GomElementTestGTop* self,
                              Property* value)
{
#line 99 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 99 "GomElementTest.vala"
	if (gom_element_test_gtop_get_pq (self) != value) {
#line 13633 "GomElementTest.c"
		Property* _tmp0_;
#line 99 "GomElementTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 99 "GomElementTest.vala"
		_g_object_unref0 (self->priv->_pq);
#line 99 "GomElementTest.vala"
		self->priv->_pq = _tmp0_;
#line 99 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_gtop_properties[GOM_ELEMENT_TEST_GTOP_PQ_PROPERTY]);
#line 13643 "GomElementTest.c"
	}
}

static GObject *
gom_element_test_gtop_constructor (GType type,
                                   guint n_construct_properties,
                                   GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestGTop * self;
#line 100 "GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_gtop_parent_class);
#line 100 "GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 100 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_GTOP, GomElementTestGTop);
#line 100 "GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "Top");
#line 100 "GomElementTest.vala"
	return obj;
#line 13665 "GomElementTest.c"
}

static void
gom_element_test_gtop_class_init (GomElementTestGTopClass * klass,
                                  gpointer klass_data)
{
#line 83 "GomElementTest.vala"
	gom_element_test_gtop_parent_class = g_type_class_peek_parent (klass);
#line 83 "GomElementTest.vala"
	g_type_class_adjust_private_offset (klass, &GomElementTestGTop_private_offset);
#line 83 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_gtop_get_property;
#line 83 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_gtop_set_property;
#line 83 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_gtop_constructor;
#line 83 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_gtop_finalize;
#line 83 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_GTOP_INST_PROPERTY, gom_element_test_gtop_properties[GOM_ELEMENT_TEST_GTOP_INST_PROPERTY] = g_param_spec_object ("inst", "inst", "inst", TYPE_NO_INSTANTIATABLE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 83 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_GTOP_INST_I_PROPERTY, gom_element_test_gtop_properties[GOM_ELEMENT_TEST_GTOP_INST_I_PROPERTY] = g_param_spec_object ("inst-i", "inst-i", "inst-i", GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 83 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_GTOP_GPQ_PROPERTY, gom_element_test_gtop_properties[GOM_ELEMENT_TEST_GTOP_GPQ_PROPERTY] = g_param_spec_object ("gpq", "::pq", "gpq", GOM_ELEMENT_TEST_TYPE_GPROPERTY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 83 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_GTOP_PQ_PROPERTY, gom_element_test_gtop_properties[GOM_ELEMENT_TEST_GTOP_PQ_PROPERTY] = g_param_spec_object ("pq", "::pq", "pq", TYPE_PROPERTY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13692 "GomElementTest.c"
}

static void
gom_element_test_gtop_instance_init (GomElementTestGTop * self,
                                     gpointer klass)
{
#line 83 "GomElementTest.vala"
	self->priv = gom_element_test_gtop_get_instance_private (self);
#line 13701 "GomElementTest.c"
}

static void
gom_element_test_gtop_finalize (GObject * obj)
{
	GomElementTestGTop * self;
#line 83 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_GTOP, GomElementTestGTop);
#line 84 "GomElementTest.vala"
	_g_object_unref0 (self->priv->_inst);
#line 99 "GomElementTest.vala"
	_g_object_unref0 (self->priv->_pq);
#line 83 "GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_gtop_parent_class)->finalize (obj);
#line 13716 "GomElementTest.c"
}

GType
gom_element_test_gtop_get_type (void)
{
	static volatile gsize gom_element_test_gtop_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_gtop_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestGTopClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_gtop_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestGTop), 0, (GInstanceInitFunc) gom_element_test_gtop_instance_init, NULL };
		GType gom_element_test_gtop_type_id;
		gom_element_test_gtop_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestGTop", &g_define_type_info, 0);
		GomElementTestGTop_private_offset = g_type_add_instance_private (gom_element_test_gtop_type_id, sizeof (GomElementTestGTopPrivate));
		g_once_init_leave (&gom_element_test_gtop_type_id__volatile, gom_element_test_gtop_type_id);
	}
	return gom_element_test_gtop_type_id__volatile;
}

static void
_vala_gom_element_test_gtop_get_property (GObject * object,
                                          guint property_id,
                                          GValue * value,
                                          GParamSpec * pspec)
{
	GomElementTestGTop * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_GTOP, GomElementTestGTop);
#line 83 "GomElementTest.vala"
	switch (property_id) {
#line 83 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_INST_PROPERTY:
#line 83 "GomElementTest.vala"
		g_value_set_object (value, gom_element_test_gtop_get_inst (self));
#line 83 "GomElementTest.vala"
		break;
#line 83 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_INST_I_PROPERTY:
#line 83 "GomElementTest.vala"
		g_value_set_object (value, gom_element_test_gtop_get_inst_i (self));
#line 83 "GomElementTest.vala"
		break;
#line 83 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_GPQ_PROPERTY:
#line 83 "GomElementTest.vala"
		g_value_set_object (value, gom_element_test_gtop_get_gpq (self));
#line 83 "GomElementTest.vala"
		break;
#line 83 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_PQ_PROPERTY:
#line 83 "GomElementTest.vala"
		g_value_set_object (value, gom_element_test_gtop_get_pq (self));
#line 83 "GomElementTest.vala"
		break;
#line 13767 "GomElementTest.c"
		default:
#line 83 "GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 83 "GomElementTest.vala"
		break;
#line 13773 "GomElementTest.c"
	}
}

static void
_vala_gom_element_test_gtop_set_property (GObject * object,
                                          guint property_id,
                                          const GValue * value,
                                          GParamSpec * pspec)
{
	GomElementTestGTop * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_GTOP, GomElementTestGTop);
#line 83 "GomElementTest.vala"
	switch (property_id) {
#line 83 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_INST_PROPERTY:
#line 83 "GomElementTest.vala"
		gom_element_test_gtop_set_inst (self, g_value_get_object (value));
#line 83 "GomElementTest.vala"
		break;
#line 83 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_INST_I_PROPERTY:
#line 83 "GomElementTest.vala"
		gom_element_test_gtop_set_inst_i (self, g_value_get_object (value));
#line 83 "GomElementTest.vala"
		break;
#line 83 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_GPQ_PROPERTY:
#line 83 "GomElementTest.vala"
		gom_element_test_gtop_set_gpq (self, g_value_get_object (value));
#line 83 "GomElementTest.vala"
		break;
#line 83 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_PQ_PROPERTY:
#line 83 "GomElementTest.vala"
		gom_element_test_gtop_set_pq (self, g_value_get_object (value));
#line 83 "GomElementTest.vala"
		break;
#line 13811 "GomElementTest.c"
		default:
#line 83 "GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 83 "GomElementTest.vala"
		break;
#line 13817 "GomElementTest.c"
	}
}

static inline gpointer
gom_element_test_potion_get_instance_private (GomElementTestPotion* self)
{
	return G_STRUCT_MEMBER_P (self, GomElementTestPotion_private_offset);
}

GomElementTestPotion*
gom_element_test_potion_construct (GType object_type)
{
	GomElementTestPotion * self = NULL;
#line 102 "GomElementTest.vala"
	self = (GomElementTestPotion*) gxml_gom_element_construct (object_type);
#line 102 "GomElementTest.vala"
	return self;
#line 13835 "GomElementTest.c"
}

GomElementTestPotion*
gom_element_test_potion_new (void)
{
#line 102 "GomElementTest.vala"
	return gom_element_test_potion_construct (GOM_ELEMENT_TEST_TYPE_POTION);
#line 13843 "GomElementTest.c"
}

const gchar*
gom_element_test_potion_get_cname (GomElementTestPotion* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 104 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 104 "GomElementTest.vala"
	_tmp0_ = self->priv->_cname;
#line 104 "GomElementTest.vala"
	result = _tmp0_;
#line 104 "GomElementTest.vala"
	return result;
#line 13859 "GomElementTest.c"
}

void
gom_element_test_potion_set_cname (GomElementTestPotion* self,
                                   const gchar* value)
{
#line 104 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 104 "GomElementTest.vala"
	if (g_strcmp0 (value, gom_element_test_potion_get_cname (self)) != 0) {
#line 13870 "GomElementTest.c"
		gchar* _tmp0_;
#line 104 "GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 104 "GomElementTest.vala"
		_g_free0 (self->priv->_cname);
#line 104 "GomElementTest.vala"
		self->priv->_cname = _tmp0_;
#line 104 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_potion_properties[GOM_ELEMENT_TEST_POTION_CNAME_PROPERTY]);
#line 13880 "GomElementTest.c"
	}
}

GomElementTestIngredient*
gom_element_test_potion_get_ingredient (GomElementTestPotion* self)
{
	GomElementTestIngredient* result;
	GomElementTestIngredient* _tmp0_;
#line 105 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 105 "GomElementTest.vala"
	_tmp0_ = self->priv->_ingredient;
#line 105 "GomElementTest.vala"
	result = _tmp0_;
#line 105 "GomElementTest.vala"
	return result;
#line 13897 "GomElementTest.c"
}

void
gom_element_test_potion_set_ingredient (GomElementTestPotion* self,
                                        GomElementTestIngredient* value)
{
#line 105 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 105 "GomElementTest.vala"
	if (gom_element_test_potion_get_ingredient (self) != value) {
#line 13908 "GomElementTest.c"
		GomElementTestIngredient* _tmp0_;
#line 105 "GomElementTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 105 "GomElementTest.vala"
		_g_object_unref0 (self->priv->_ingredient);
#line 105 "GomElementTest.vala"
		self->priv->_ingredient = _tmp0_;
#line 105 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_potion_properties[GOM_ELEMENT_TEST_POTION_INGREDIENT_PROPERTY]);
#line 13918 "GomElementTest.c"
	}
}

static GObject *
gom_element_test_potion_constructor (GType type,
                                     guint n_construct_properties,
                                     GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestPotion * self;
	GError* _inner_error0_ = NULL;
#line 106 "GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_potion_parent_class);
#line 106 "GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 106 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_POTION, GomElementTestPotion);
#line 107 "GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "Potion");
#line 13939 "GomElementTest.c"
	{
#line 109 "GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) self, "http://www.w3.org/2000/xmlns", "xmlns:c", "http://c.org/1.0", &_inner_error0_);
#line 109 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 13945 "GomElementTest.c"
			goto __catch144_g_error;
		}
	}
	goto __finally144;
	__catch144_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 108 "GomElementTest.vala"
		e = _inner_error0_;
#line 108 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 110 "GomElementTest.vala"
		_tmp0_ = e;
#line 110 "GomElementTest.vala"
		_tmp1_ = _tmp0_->message;
#line 110 "GomElementTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 110 "GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 110 "GomElementTest.vala"
		g_warning ("GomElementTest.vala:110: %s", _tmp3_);
#line 110 "GomElementTest.vala"
		_g_free0 (_tmp3_);
#line 108 "GomElementTest.vala"
		_g_error_free0 (e);
#line 13975 "GomElementTest.c"
	}
	__finally144:
#line 108 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 108 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 108 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 13984 "GomElementTest.c"
	}
#line 106 "GomElementTest.vala"
	return obj;
#line 13988 "GomElementTest.c"
}

static void
gom_element_test_potion_class_init (GomElementTestPotionClass * klass,
                                    gpointer klass_data)
{
#line 102 "GomElementTest.vala"
	gom_element_test_potion_parent_class = g_type_class_peek_parent (klass);
#line 102 "GomElementTest.vala"
	g_type_class_adjust_private_offset (klass, &GomElementTestPotion_private_offset);
#line 102 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_potion_get_property;
#line 102 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_potion_set_property;
#line 102 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_potion_constructor;
#line 102 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_potion_finalize;
#line 102 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_POTION_CNAME_PROPERTY, gom_element_test_potion_properties[GOM_ELEMENT_TEST_POTION_CNAME_PROPERTY] = g_param_spec_string ("cname", "::c:name", "cname", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 102 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_POTION_INGREDIENT_PROPERTY, gom_element_test_potion_properties[GOM_ELEMENT_TEST_POTION_INGREDIENT_PROPERTY] = g_param_spec_object ("ingredient", "ingredient", "ingredient", GOM_ELEMENT_TEST_TYPE_INGREDIENT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 14011 "GomElementTest.c"
}

static void
gom_element_test_potion_instance_init (GomElementTestPotion * self,
                                       gpointer klass)
{
#line 102 "GomElementTest.vala"
	self->priv = gom_element_test_potion_get_instance_private (self);
#line 14020 "GomElementTest.c"
}

static void
gom_element_test_potion_finalize (GObject * obj)
{
	GomElementTestPotion * self;
#line 102 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_POTION, GomElementTestPotion);
#line 104 "GomElementTest.vala"
	_g_free0 (self->priv->_cname);
#line 105 "GomElementTest.vala"
	_g_object_unref0 (self->priv->_ingredient);
#line 102 "GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_potion_parent_class)->finalize (obj);
#line 14035 "GomElementTest.c"
}

GType
gom_element_test_potion_get_type (void)
{
	static volatile gsize gom_element_test_potion_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_potion_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestPotionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_potion_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestPotion), 0, (GInstanceInitFunc) gom_element_test_potion_instance_init, NULL };
		GType gom_element_test_potion_type_id;
		gom_element_test_potion_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestPotion", &g_define_type_info, 0);
		GomElementTestPotion_private_offset = g_type_add_instance_private (gom_element_test_potion_type_id, sizeof (GomElementTestPotionPrivate));
		g_once_init_leave (&gom_element_test_potion_type_id__volatile, gom_element_test_potion_type_id);
	}
	return gom_element_test_potion_type_id__volatile;
}

static void
_vala_gom_element_test_potion_get_property (GObject * object,
                                            guint property_id,
                                            GValue * value,
                                            GParamSpec * pspec)
{
	GomElementTestPotion * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_POTION, GomElementTestPotion);
#line 102 "GomElementTest.vala"
	switch (property_id) {
#line 102 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_POTION_CNAME_PROPERTY:
#line 102 "GomElementTest.vala"
		g_value_set_string (value, gom_element_test_potion_get_cname (self));
#line 102 "GomElementTest.vala"
		break;
#line 102 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_POTION_INGREDIENT_PROPERTY:
#line 102 "GomElementTest.vala"
		g_value_set_object (value, gom_element_test_potion_get_ingredient (self));
#line 102 "GomElementTest.vala"
		break;
#line 14074 "GomElementTest.c"
		default:
#line 102 "GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 102 "GomElementTest.vala"
		break;
#line 14080 "GomElementTest.c"
	}
}

static void
_vala_gom_element_test_potion_set_property (GObject * object,
                                            guint property_id,
                                            const GValue * value,
                                            GParamSpec * pspec)
{
	GomElementTestPotion * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_POTION, GomElementTestPotion);
#line 102 "GomElementTest.vala"
	switch (property_id) {
#line 102 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_POTION_CNAME_PROPERTY:
#line 102 "GomElementTest.vala"
		gom_element_test_potion_set_cname (self, g_value_get_string (value));
#line 102 "GomElementTest.vala"
		break;
#line 102 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_POTION_INGREDIENT_PROPERTY:
#line 102 "GomElementTest.vala"
		gom_element_test_potion_set_ingredient (self, g_value_get_object (value));
#line 102 "GomElementTest.vala"
		break;
#line 14106 "GomElementTest.c"
		default:
#line 102 "GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 102 "GomElementTest.vala"
		break;
#line 14112 "GomElementTest.c"
	}
}

static inline gpointer
gom_element_test_ingredient_get_instance_private (GomElementTestIngredient* self)
{
	return G_STRUCT_MEMBER_P (self, GomElementTestIngredient_private_offset);
}

static gchar*
gom_element_test_ingredient_real_get_map_key (GXmlMappeableElement* base)
{
	GomElementTestIngredient * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 118 "GomElementTest.vala"
	self = (GomElementTestIngredient*) base;
#line 118 "GomElementTest.vala"
	_tmp0_ = self->priv->_cname;
#line 118 "GomElementTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 118 "GomElementTest.vala"
	result = _tmp1_;
#line 118 "GomElementTest.vala"
	return result;
#line 14139 "GomElementTest.c"
}

GomElementTestIngredient*
gom_element_test_ingredient_construct (GType object_type)
{
	GomElementTestIngredient * self = NULL;
#line 113 "GomElementTest.vala"
	self = (GomElementTestIngredient*) gxml_gom_element_construct (object_type);
#line 113 "GomElementTest.vala"
	return self;
#line 14150 "GomElementTest.c"
}

GomElementTestIngredient*
gom_element_test_ingredient_new (void)
{
#line 113 "GomElementTest.vala"
	return gom_element_test_ingredient_construct (GOM_ELEMENT_TEST_TYPE_INGREDIENT);
#line 14158 "GomElementTest.c"
}

const gchar*
gom_element_test_ingredient_get_cname (GomElementTestIngredient* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 115 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 115 "GomElementTest.vala"
	_tmp0_ = self->priv->_cname;
#line 115 "GomElementTest.vala"
	result = _tmp0_;
#line 115 "GomElementTest.vala"
	return result;
#line 14174 "GomElementTest.c"
}

void
gom_element_test_ingredient_set_cname (GomElementTestIngredient* self,
                                       const gchar* value)
{
#line 115 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 115 "GomElementTest.vala"
	if (g_strcmp0 (value, gom_element_test_ingredient_get_cname (self)) != 0) {
#line 14185 "GomElementTest.c"
		gchar* _tmp0_;
#line 115 "GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 115 "GomElementTest.vala"
		_g_free0 (self->priv->_cname);
#line 115 "GomElementTest.vala"
		self->priv->_cname = _tmp0_;
#line 115 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_ingredient_properties[GOM_ELEMENT_TEST_INGREDIENT_CNAME_PROPERTY]);
#line 14195 "GomElementTest.c"
	}
}

GomElementTestMethodMap*
gom_element_test_ingredient_get_methods (GomElementTestIngredient* self)
{
	GomElementTestMethodMap* result;
	GomElementTestMethodMap* _tmp0_;
#line 116 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 116 "GomElementTest.vala"
	_tmp0_ = self->priv->_methods;
#line 116 "GomElementTest.vala"
	result = _tmp0_;
#line 116 "GomElementTest.vala"
	return result;
#line 14212 "GomElementTest.c"
}

void
gom_element_test_ingredient_set_methods (GomElementTestIngredient* self,
                                         GomElementTestMethodMap* value)
{
#line 116 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 116 "GomElementTest.vala"
	if (gom_element_test_ingredient_get_methods (self) != value) {
#line 14223 "GomElementTest.c"
		GomElementTestMethodMap* _tmp0_;
#line 116 "GomElementTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 116 "GomElementTest.vala"
		_g_object_unref0 (self->priv->_methods);
#line 116 "GomElementTest.vala"
		self->priv->_methods = _tmp0_;
#line 116 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_ingredient_properties[GOM_ELEMENT_TEST_INGREDIENT_METHODS_PROPERTY]);
#line 14233 "GomElementTest.c"
	}
}

static GObject *
gom_element_test_ingredient_constructor (GType type,
                                         guint n_construct_properties,
                                         GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestIngredient * self;
#line 117 "GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_ingredient_parent_class);
#line 117 "GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 117 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_INGREDIENT, GomElementTestIngredient);
#line 117 "GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "ingredient");
#line 117 "GomElementTest.vala"
	return obj;
#line 14255 "GomElementTest.c"
}

GomElementTestIngredientMap*
gom_element_test_ingredient_map_construct (GType object_type)
{
	GomElementTestIngredientMap * self = NULL;
#line 119 "GomElementTest.vala"
	self = (GomElementTestIngredientMap*) gxml_gom_hash_map_construct (object_type);
#line 119 "GomElementTest.vala"
	return self;
#line 14266 "GomElementTest.c"
}

GomElementTestIngredientMap*
gom_element_test_ingredient_map_new (void)
{
#line 119 "GomElementTest.vala"
	return gom_element_test_ingredient_map_construct (GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP);
#line 14274 "GomElementTest.c"
}

static GObject *
gom_element_test_ingredient_map_constructor (GType type,
                                             guint n_construct_properties,
                                             GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestIngredientMap * self;
	GError* _inner_error0_ = NULL;
#line 120 "GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_ingredient_map_parent_class);
#line 120 "GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 120 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP, GomElementTestIngredientMap);
#line 14292 "GomElementTest.c"
	{
#line 122 "GomElementTest.vala"
		gxml_collection_initialize ((GXmlCollection*) self, GOM_ELEMENT_TEST_TYPE_INGREDIENT, &_inner_error0_);
#line 122 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 14298 "GomElementTest.c"
			goto __catch145_g_error;
		}
	}
	goto __finally145;
	__catch145_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 121 "GomElementTest.vala"
		e = _inner_error0_;
#line 121 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 123 "GomElementTest.vala"
		_tmp0_ = e;
#line 123 "GomElementTest.vala"
		_tmp1_ = _tmp0_->message;
#line 123 "GomElementTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 123 "GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 123 "GomElementTest.vala"
		g_warning ("GomElementTest.vala:123: %s", _tmp3_);
#line 123 "GomElementTest.vala"
		_g_free0 (_tmp3_);
#line 121 "GomElementTest.vala"
		_g_error_free0 (e);
#line 14328 "GomElementTest.c"
	}
	__finally145:
#line 121 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 121 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 121 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 14337 "GomElementTest.c"
	}
#line 120 "GomElementTest.vala"
	return obj;
#line 14341 "GomElementTest.c"
}

static void
gom_element_test_ingredient_map_class_init (GomElementTestIngredientMapClass * klass,
                                            gpointer klass_data)
{
#line 119 "GomElementTest.vala"
	gom_element_test_ingredient_map_parent_class = g_type_class_peek_parent (klass);
#line 119 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_ingredient_map_constructor;
#line 14352 "GomElementTest.c"
}

static void
gom_element_test_ingredient_map_instance_init (GomElementTestIngredientMap * self,
                                               gpointer klass)
{
}

GType
gom_element_test_ingredient_map_get_type (void)
{
	static volatile gsize gom_element_test_ingredient_map_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_ingredient_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestIngredientMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_ingredient_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestIngredientMap), 0, (GInstanceInitFunc) gom_element_test_ingredient_map_instance_init, NULL };
		GType gom_element_test_ingredient_map_type_id;
		gom_element_test_ingredient_map_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_MAP, "GomElementTestIngredientMap", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_ingredient_map_type_id__volatile, gom_element_test_ingredient_map_type_id);
	}
	return gom_element_test_ingredient_map_type_id__volatile;
}

static void
gom_element_test_ingredient_class_init (GomElementTestIngredientClass * klass,
                                        gpointer klass_data)
{
#line 113 "GomElementTest.vala"
	gom_element_test_ingredient_parent_class = g_type_class_peek_parent (klass);
#line 113 "GomElementTest.vala"
	g_type_class_adjust_private_offset (klass, &GomElementTestIngredient_private_offset);
#line 113 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_ingredient_get_property;
#line 113 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_ingredient_set_property;
#line 113 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_ingredient_constructor;
#line 113 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_ingredient_finalize;
#line 113 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_INGREDIENT_CNAME_PROPERTY, gom_element_test_ingredient_properties[GOM_ELEMENT_TEST_INGREDIENT_CNAME_PROPERTY] = g_param_spec_string ("cname", "::c:name", "cname", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 113 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_INGREDIENT_METHODS_PROPERTY, gom_element_test_ingredient_properties[GOM_ELEMENT_TEST_INGREDIENT_METHODS_PROPERTY] = g_param_spec_object ("methods", "methods", "methods", GOM_ELEMENT_TEST_METHOD_TYPE_MAP, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 14394 "GomElementTest.c"
}

static void
gom_element_test_ingredient_gxml_mappeable_element_interface_init (GXmlMappeableElementIface * iface,
                                                                   gpointer iface_data)
{
#line 113 "GomElementTest.vala"
	gom_element_test_ingredient_gxml_mappeable_element_parent_iface = g_type_interface_peek_parent (iface);
#line 113 "GomElementTest.vala"
	iface->get_map_key = (gchar* (*) (GXmlMappeableElement*)) gom_element_test_ingredient_real_get_map_key;
#line 14405 "GomElementTest.c"
}

static void
gom_element_test_ingredient_instance_init (GomElementTestIngredient * self,
                                           gpointer klass)
{
#line 113 "GomElementTest.vala"
	self->priv = gom_element_test_ingredient_get_instance_private (self);
#line 14414 "GomElementTest.c"
}

static void
gom_element_test_ingredient_finalize (GObject * obj)
{
	GomElementTestIngredient * self;
#line 113 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_INGREDIENT, GomElementTestIngredient);
#line 115 "GomElementTest.vala"
	_g_free0 (self->priv->_cname);
#line 116 "GomElementTest.vala"
	_g_object_unref0 (self->priv->_methods);
#line 113 "GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_ingredient_parent_class)->finalize (obj);
#line 14429 "GomElementTest.c"
}

GType
gom_element_test_ingredient_get_type (void)
{
	static volatile gsize gom_element_test_ingredient_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_ingredient_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestIngredientClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_ingredient_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestIngredient), 0, (GInstanceInitFunc) gom_element_test_ingredient_instance_init, NULL };
		static const GInterfaceInfo gxml_mappeable_element_info = { (GInterfaceInitFunc) gom_element_test_ingredient_gxml_mappeable_element_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gom_element_test_ingredient_type_id;
		gom_element_test_ingredient_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestIngredient", &g_define_type_info, 0);
		g_type_add_interface_static (gom_element_test_ingredient_type_id, GXML_TYPE_MAPPEABLE_ELEMENT, &gxml_mappeable_element_info);
		GomElementTestIngredient_private_offset = g_type_add_instance_private (gom_element_test_ingredient_type_id, sizeof (GomElementTestIngredientPrivate));
		g_once_init_leave (&gom_element_test_ingredient_type_id__volatile, gom_element_test_ingredient_type_id);
	}
	return gom_element_test_ingredient_type_id__volatile;
}

static void
_vala_gom_element_test_ingredient_get_property (GObject * object,
                                                guint property_id,
                                                GValue * value,
                                                GParamSpec * pspec)
{
	GomElementTestIngredient * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_INGREDIENT, GomElementTestIngredient);
#line 113 "GomElementTest.vala"
	switch (property_id) {
#line 113 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_INGREDIENT_CNAME_PROPERTY:
#line 113 "GomElementTest.vala"
		g_value_set_string (value, gom_element_test_ingredient_get_cname (self));
#line 113 "GomElementTest.vala"
		break;
#line 113 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_INGREDIENT_METHODS_PROPERTY:
#line 113 "GomElementTest.vala"
		g_value_set_object (value, gom_element_test_ingredient_get_methods (self));
#line 113 "GomElementTest.vala"
		break;
#line 14470 "GomElementTest.c"
		default:
#line 113 "GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 113 "GomElementTest.vala"
		break;
#line 14476 "GomElementTest.c"
	}
}

static void
_vala_gom_element_test_ingredient_set_property (GObject * object,
                                                guint property_id,
                                                const GValue * value,
                                                GParamSpec * pspec)
{
	GomElementTestIngredient * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_INGREDIENT, GomElementTestIngredient);
#line 113 "GomElementTest.vala"
	switch (property_id) {
#line 113 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_INGREDIENT_CNAME_PROPERTY:
#line 113 "GomElementTest.vala"
		gom_element_test_ingredient_set_cname (self, g_value_get_string (value));
#line 113 "GomElementTest.vala"
		break;
#line 113 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_INGREDIENT_METHODS_PROPERTY:
#line 113 "GomElementTest.vala"
		gom_element_test_ingredient_set_methods (self, g_value_get_object (value));
#line 113 "GomElementTest.vala"
		break;
#line 14502 "GomElementTest.c"
		default:
#line 113 "GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 113 "GomElementTest.vala"
		break;
#line 14508 "GomElementTest.c"
	}
}

static inline gpointer
gom_element_test_method_get_instance_private (GomElementTestMethod* self)
{
	return G_STRUCT_MEMBER_P (self, GomElementTestMethod_private_offset);
}

static gchar*
gom_element_test_method_real_get_map_key (GXmlMappeableElement* base)
{
	GomElementTestMethod * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 131 "GomElementTest.vala"
	self = (GomElementTestMethod*) base;
#line 131 "GomElementTest.vala"
	_tmp0_ = self->priv->_cname;
#line 131 "GomElementTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 131 "GomElementTest.vala"
	result = _tmp1_;
#line 131 "GomElementTest.vala"
	return result;
#line 14535 "GomElementTest.c"
}

GomElementTestMethod*
gom_element_test_method_construct (GType object_type)
{
	GomElementTestMethod * self = NULL;
#line 127 "GomElementTest.vala"
	self = (GomElementTestMethod*) gxml_gom_element_construct (object_type);
#line 127 "GomElementTest.vala"
	return self;
#line 14546 "GomElementTest.c"
}

GomElementTestMethod*
gom_element_test_method_new (void)
{
#line 127 "GomElementTest.vala"
	return gom_element_test_method_construct (GOM_ELEMENT_TEST_TYPE_METHOD);
#line 14554 "GomElementTest.c"
}

const gchar*
gom_element_test_method_get_cname (GomElementTestMethod* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 129 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 129 "GomElementTest.vala"
	_tmp0_ = self->priv->_cname;
#line 129 "GomElementTest.vala"
	result = _tmp0_;
#line 129 "GomElementTest.vala"
	return result;
#line 14570 "GomElementTest.c"
}

void
gom_element_test_method_set_cname (GomElementTestMethod* self,
                                   const gchar* value)
{
#line 129 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 129 "GomElementTest.vala"
	if (g_strcmp0 (value, gom_element_test_method_get_cname (self)) != 0) {
#line 14581 "GomElementTest.c"
		gchar* _tmp0_;
#line 129 "GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 129 "GomElementTest.vala"
		_g_free0 (self->priv->_cname);
#line 129 "GomElementTest.vala"
		self->priv->_cname = _tmp0_;
#line 129 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_method_properties[GOM_ELEMENT_TEST_METHOD_CNAME_PROPERTY]);
#line 14591 "GomElementTest.c"
	}
}

static GObject *
gom_element_test_method_constructor (GType type,
                                     guint n_construct_properties,
                                     GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestMethod * self;
#line 130 "GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_method_parent_class);
#line 130 "GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 130 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_METHOD, GomElementTestMethod);
#line 130 "GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "method");
#line 130 "GomElementTest.vala"
	return obj;
#line 14613 "GomElementTest.c"
}

GomElementTestMethodMap*
gom_element_test_method_map_construct (GType object_type)
{
	GomElementTestMethodMap * self = NULL;
#line 132 "GomElementTest.vala"
	self = (GomElementTestMethodMap*) gxml_gom_hash_map_construct (object_type);
#line 132 "GomElementTest.vala"
	return self;
#line 14624 "GomElementTest.c"
}

GomElementTestMethodMap*
gom_element_test_method_map_new (void)
{
#line 132 "GomElementTest.vala"
	return gom_element_test_method_map_construct (GOM_ELEMENT_TEST_METHOD_TYPE_MAP);
#line 14632 "GomElementTest.c"
}

static GObject *
gom_element_test_method_map_constructor (GType type,
                                         guint n_construct_properties,
                                         GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestMethodMap * self;
	GError* _inner_error0_ = NULL;
#line 133 "GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_method_map_parent_class);
#line 133 "GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 133 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_METHOD_TYPE_MAP, GomElementTestMethodMap);
#line 14650 "GomElementTest.c"
	{
#line 135 "GomElementTest.vala"
		gxml_collection_initialize ((GXmlCollection*) self, GOM_ELEMENT_TEST_TYPE_METHOD, &_inner_error0_);
#line 135 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 14656 "GomElementTest.c"
			goto __catch146_g_error;
		}
	}
	goto __finally146;
	__catch146_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 134 "GomElementTest.vala"
		e = _inner_error0_;
#line 134 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 136 "GomElementTest.vala"
		_tmp0_ = e;
#line 136 "GomElementTest.vala"
		_tmp1_ = _tmp0_->message;
#line 136 "GomElementTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 136 "GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 136 "GomElementTest.vala"
		g_warning ("GomElementTest.vala:136: %s", _tmp3_);
#line 136 "GomElementTest.vala"
		_g_free0 (_tmp3_);
#line 134 "GomElementTest.vala"
		_g_error_free0 (e);
#line 14686 "GomElementTest.c"
	}
	__finally146:
#line 134 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 134 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 134 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 14695 "GomElementTest.c"
	}
#line 133 "GomElementTest.vala"
	return obj;
#line 14699 "GomElementTest.c"
}

static void
gom_element_test_method_map_class_init (GomElementTestMethodMapClass * klass,
                                        gpointer klass_data)
{
#line 132 "GomElementTest.vala"
	gom_element_test_method_map_parent_class = g_type_class_peek_parent (klass);
#line 132 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_method_map_constructor;
#line 14710 "GomElementTest.c"
}

static void
gom_element_test_method_map_instance_init (GomElementTestMethodMap * self,
                                           gpointer klass)
{
}

GType
gom_element_test_method_map_get_type (void)
{
	static volatile gsize gom_element_test_method_map_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_method_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestMethodMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_method_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestMethodMap), 0, (GInstanceInitFunc) gom_element_test_method_map_instance_init, NULL };
		GType gom_element_test_method_map_type_id;
		gom_element_test_method_map_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_MAP, "GomElementTestMethodMap", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_method_map_type_id__volatile, gom_element_test_method_map_type_id);
	}
	return gom_element_test_method_map_type_id__volatile;
}

static void
gom_element_test_method_class_init (GomElementTestMethodClass * klass,
                                    gpointer klass_data)
{
#line 127 "GomElementTest.vala"
	gom_element_test_method_parent_class = g_type_class_peek_parent (klass);
#line 127 "GomElementTest.vala"
	g_type_class_adjust_private_offset (klass, &GomElementTestMethod_private_offset);
#line 127 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_method_get_property;
#line 127 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_method_set_property;
#line 127 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_method_constructor;
#line 127 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_method_finalize;
#line 127 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_METHOD_CNAME_PROPERTY, gom_element_test_method_properties[GOM_ELEMENT_TEST_METHOD_CNAME_PROPERTY] = g_param_spec_string ("cname", "::c:name", "cname", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 14750 "GomElementTest.c"
}

static void
gom_element_test_method_gxml_mappeable_element_interface_init (GXmlMappeableElementIface * iface,
                                                               gpointer iface_data)
{
#line 127 "GomElementTest.vala"
	gom_element_test_method_gxml_mappeable_element_parent_iface = g_type_interface_peek_parent (iface);
#line 127 "GomElementTest.vala"
	iface->get_map_key = (gchar* (*) (GXmlMappeableElement*)) gom_element_test_method_real_get_map_key;
#line 14761 "GomElementTest.c"
}

static void
gom_element_test_method_instance_init (GomElementTestMethod * self,
                                       gpointer klass)
{
#line 127 "GomElementTest.vala"
	self->priv = gom_element_test_method_get_instance_private (self);
#line 14770 "GomElementTest.c"
}

static void
gom_element_test_method_finalize (GObject * obj)
{
	GomElementTestMethod * self;
#line 127 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_METHOD, GomElementTestMethod);
#line 129 "GomElementTest.vala"
	_g_free0 (self->priv->_cname);
#line 127 "GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_method_parent_class)->finalize (obj);
#line 14783 "GomElementTest.c"
}

GType
gom_element_test_method_get_type (void)
{
	static volatile gsize gom_element_test_method_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_method_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestMethod), 0, (GInstanceInitFunc) gom_element_test_method_instance_init, NULL };
		static const GInterfaceInfo gxml_mappeable_element_info = { (GInterfaceInitFunc) gom_element_test_method_gxml_mappeable_element_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gom_element_test_method_type_id;
		gom_element_test_method_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestMethod", &g_define_type_info, 0);
		g_type_add_interface_static (gom_element_test_method_type_id, GXML_TYPE_MAPPEABLE_ELEMENT, &gxml_mappeable_element_info);
		GomElementTestMethod_private_offset = g_type_add_instance_private (gom_element_test_method_type_id, sizeof (GomElementTestMethodPrivate));
		g_once_init_leave (&gom_element_test_method_type_id__volatile, gom_element_test_method_type_id);
	}
	return gom_element_test_method_type_id__volatile;
}

static void
_vala_gom_element_test_method_get_property (GObject * object,
                                            guint property_id,
                                            GValue * value,
                                            GParamSpec * pspec)
{
	GomElementTestMethod * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_METHOD, GomElementTestMethod);
#line 127 "GomElementTest.vala"
	switch (property_id) {
#line 127 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_METHOD_CNAME_PROPERTY:
#line 127 "GomElementTest.vala"
		g_value_set_string (value, gom_element_test_method_get_cname (self));
#line 127 "GomElementTest.vala"
		break;
#line 14818 "GomElementTest.c"
		default:
#line 127 "GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 127 "GomElementTest.vala"
		break;
#line 14824 "GomElementTest.c"
	}
}

static void
_vala_gom_element_test_method_set_property (GObject * object,
                                            guint property_id,
                                            const GValue * value,
                                            GParamSpec * pspec)
{
	GomElementTestMethod * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_METHOD, GomElementTestMethod);
#line 127 "GomElementTest.vala"
	switch (property_id) {
#line 127 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_METHOD_CNAME_PROPERTY:
#line 127 "GomElementTest.vala"
		gom_element_test_method_set_cname (self, g_value_get_string (value));
#line 127 "GomElementTest.vala"
		break;
#line 14844 "GomElementTest.c"
		default:
#line 127 "GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 127 "GomElementTest.vala"
		break;
#line 14850 "GomElementTest.c"
	}
}

static inline gpointer
gom_element_test_repository_get_instance_private (GomElementTestRepository* self)
{
	return G_STRUCT_MEMBER_P (self, GomElementTestRepository_private_offset);
}

GomElementTestRepository*
gom_element_test_repository_construct (GType object_type)
{
	GomElementTestRepository * self = NULL;
#line 140 "GomElementTest.vala"
	self = (GomElementTestRepository*) gxml_gom_element_construct (object_type);
#line 140 "GomElementTest.vala"
	return self;
#line 14868 "GomElementTest.c"
}

GomElementTestRepository*
gom_element_test_repository_new (void)
{
#line 140 "GomElementTest.vala"
	return gom_element_test_repository_construct (GOM_ELEMENT_TEST_TYPE_REPOSITORY);
#line 14876 "GomElementTest.c"
}

const gchar*
gom_element_test_repository_get_version (GomElementTestRepository* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 143 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 143 "GomElementTest.vala"
	_tmp0_ = self->priv->_version;
#line 143 "GomElementTest.vala"
	result = _tmp0_;
#line 143 "GomElementTest.vala"
	return result;
#line 14892 "GomElementTest.c"
}

void
gom_element_test_repository_set_version (GomElementTestRepository* self,
                                         const gchar* value)
{
#line 143 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 143 "GomElementTest.vala"
	if (g_strcmp0 (value, gom_element_test_repository_get_version (self)) != 0) {
#line 14903 "GomElementTest.c"
		gchar* _tmp0_;
#line 143 "GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 143 "GomElementTest.vala"
		_g_free0 (self->priv->_version);
#line 143 "GomElementTest.vala"
		self->priv->_version = _tmp0_;
#line 143 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_repository_properties[GOM_ELEMENT_TEST_REPOSITORY_VERSION_PROPERTY]);
#line 14913 "GomElementTest.c"
	}
}

GomElementTestNamespace*
gom_element_test_repository_get_ns (GomElementTestRepository* self)
{
	GomElementTestNamespace* result;
	GomElementTestNamespace* _tmp0_;
#line 145 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 145 "GomElementTest.vala"
	_tmp0_ = self->priv->_ns;
#line 145 "GomElementTest.vala"
	result = _tmp0_;
#line 145 "GomElementTest.vala"
	return result;
#line 14930 "GomElementTest.c"
}

void
gom_element_test_repository_set_ns (GomElementTestRepository* self,
                                    GomElementTestNamespace* value)
{
#line 145 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 145 "GomElementTest.vala"
	if (gom_element_test_repository_get_ns (self) != value) {
#line 14941 "GomElementTest.c"
		GomElementTestNamespace* _tmp0_;
#line 145 "GomElementTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 145 "GomElementTest.vala"
		_g_object_unref0 (self->priv->_ns);
#line 145 "GomElementTest.vala"
		self->priv->_ns = _tmp0_;
#line 145 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_repository_properties[GOM_ELEMENT_TEST_REPOSITORY_NS_PROPERTY]);
#line 14951 "GomElementTest.c"
	}
}

static GObject *
gom_element_test_repository_constructor (GType type,
                                         guint n_construct_properties,
                                         GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestRepository * self;
	GError* _inner_error0_ = NULL;
#line 147 "GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_repository_parent_class);
#line 147 "GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 147 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_REPOSITORY, GomElementTestRepository);
#line 148 "GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "repository");
#line 14972 "GomElementTest.c"
	{
#line 150 "GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) self, "http://www.w3.org/2000/xmlns", "xmlns", "http://www.gtk.org/introspection/core/1.0", &_inner_error0_);
#line 150 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 14978 "GomElementTest.c"
			goto __catch147_g_error;
		}
#line 152 "GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) self, "http://www.w3.org/2000/xmlns", "xmlns:c", "http://www.gtk.org/introspection/c/1.0", &_inner_error0_);
#line 152 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 14985 "GomElementTest.c"
			goto __catch147_g_error;
		}
#line 154 "GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) self, "http://www.w3.org/2000/xmlns", "xmlns:glib", "http://www.gtk.org/introspection/glib/1.0", &_inner_error0_);
#line 154 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 14992 "GomElementTest.c"
			goto __catch147_g_error;
		}
	}
	goto __finally147;
	__catch147_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 149 "GomElementTest.vala"
		e = _inner_error0_;
#line 149 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 156 "GomElementTest.vala"
		_tmp0_ = e;
#line 156 "GomElementTest.vala"
		_tmp1_ = _tmp0_->message;
#line 156 "GomElementTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 156 "GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 156 "GomElementTest.vala"
		g_warning ("GomElementTest.vala:156: %s", _tmp3_);
#line 156 "GomElementTest.vala"
		_g_free0 (_tmp3_);
#line 149 "GomElementTest.vala"
		_g_error_free0 (e);
#line 15022 "GomElementTest.c"
	}
	__finally147:
#line 149 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 149 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 149 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 15031 "GomElementTest.c"
	}
#line 157 "GomElementTest.vala"
	gom_element_test_repository_set_version (self, "1.2");
#line 147 "GomElementTest.vala"
	return obj;
#line 15037 "GomElementTest.c"
}

static void
gom_element_test_repository_class_init (GomElementTestRepositoryClass * klass,
                                        gpointer klass_data)
{
#line 140 "GomElementTest.vala"
	gom_element_test_repository_parent_class = g_type_class_peek_parent (klass);
#line 140 "GomElementTest.vala"
	g_type_class_adjust_private_offset (klass, &GomElementTestRepository_private_offset);
#line 140 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_repository_get_property;
#line 140 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_repository_set_property;
#line 140 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_repository_constructor;
#line 140 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_repository_finalize;
#line 140 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_REPOSITORY_VERSION_PROPERTY, gom_element_test_repository_properties[GOM_ELEMENT_TEST_REPOSITORY_VERSION_PROPERTY] = g_param_spec_string ("version", "::version", "version", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 140 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_REPOSITORY_NS_PROPERTY, gom_element_test_repository_properties[GOM_ELEMENT_TEST_REPOSITORY_NS_PROPERTY] = g_param_spec_object ("ns", "ns", "ns", GOM_ELEMENT_TEST_TYPE_NAMESPACE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 15060 "GomElementTest.c"
}

static void
gom_element_test_repository_instance_init (GomElementTestRepository * self,
                                           gpointer klass)
{
#line 140 "GomElementTest.vala"
	self->priv = gom_element_test_repository_get_instance_private (self);
#line 15069 "GomElementTest.c"
}

static void
gom_element_test_repository_finalize (GObject * obj)
{
	GomElementTestRepository * self;
#line 140 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_REPOSITORY, GomElementTestRepository);
#line 143 "GomElementTest.vala"
	_g_free0 (self->priv->_version);
#line 145 "GomElementTest.vala"
	_g_object_unref0 (self->priv->_ns);
#line 140 "GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_repository_parent_class)->finalize (obj);
#line 15084 "GomElementTest.c"
}

GType
gom_element_test_repository_get_type (void)
{
	static volatile gsize gom_element_test_repository_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_repository_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestRepositoryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_repository_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestRepository), 0, (GInstanceInitFunc) gom_element_test_repository_instance_init, NULL };
		GType gom_element_test_repository_type_id;
		gom_element_test_repository_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestRepository", &g_define_type_info, 0);
		GomElementTestRepository_private_offset = g_type_add_instance_private (gom_element_test_repository_type_id, sizeof (GomElementTestRepositoryPrivate));
		g_once_init_leave (&gom_element_test_repository_type_id__volatile, gom_element_test_repository_type_id);
	}
	return gom_element_test_repository_type_id__volatile;
}

static void
_vala_gom_element_test_repository_get_property (GObject * object,
                                                guint property_id,
                                                GValue * value,
                                                GParamSpec * pspec)
{
	GomElementTestRepository * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_REPOSITORY, GomElementTestRepository);
#line 140 "GomElementTest.vala"
	switch (property_id) {
#line 140 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_REPOSITORY_VERSION_PROPERTY:
#line 140 "GomElementTest.vala"
		g_value_set_string (value, gom_element_test_repository_get_version (self));
#line 140 "GomElementTest.vala"
		break;
#line 140 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_REPOSITORY_NS_PROPERTY:
#line 140 "GomElementTest.vala"
		g_value_set_object (value, gom_element_test_repository_get_ns (self));
#line 140 "GomElementTest.vala"
		break;
#line 15123 "GomElementTest.c"
		default:
#line 140 "GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 140 "GomElementTest.vala"
		break;
#line 15129 "GomElementTest.c"
	}
}

static void
_vala_gom_element_test_repository_set_property (GObject * object,
                                                guint property_id,
                                                const GValue * value,
                                                GParamSpec * pspec)
{
	GomElementTestRepository * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_REPOSITORY, GomElementTestRepository);
#line 140 "GomElementTest.vala"
	switch (property_id) {
#line 140 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_REPOSITORY_VERSION_PROPERTY:
#line 140 "GomElementTest.vala"
		gom_element_test_repository_set_version (self, g_value_get_string (value));
#line 140 "GomElementTest.vala"
		break;
#line 140 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_REPOSITORY_NS_PROPERTY:
#line 140 "GomElementTest.vala"
		gom_element_test_repository_set_ns (self, g_value_get_object (value));
#line 140 "GomElementTest.vala"
		break;
#line 15155 "GomElementTest.c"
		default:
#line 140 "GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 140 "GomElementTest.vala"
		break;
#line 15161 "GomElementTest.c"
	}
}

static inline gpointer
gom_element_test_namespace_get_instance_private (GomElementTestNamespace* self)
{
	return G_STRUCT_MEMBER_P (self, GomElementTestNamespace_private_offset);
}

GomElementTestNamespace*
gom_element_test_namespace_construct (GType object_type)
{
	GomElementTestNamespace * self = NULL;
#line 160 "GomElementTest.vala"
	self = (GomElementTestNamespace*) gxml_gom_element_construct (object_type);
#line 160 "GomElementTest.vala"
	return self;
#line 15179 "GomElementTest.c"
}

GomElementTestNamespace*
gom_element_test_namespace_new (void)
{
#line 160 "GomElementTest.vala"
	return gom_element_test_namespace_construct (GOM_ELEMENT_TEST_TYPE_NAMESPACE);
#line 15187 "GomElementTest.c"
}

const gchar*
gom_element_test_namespace_get_name (GomElementTestNamespace* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 164 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 164 "GomElementTest.vala"
	_tmp0_ = self->priv->_name;
#line 164 "GomElementTest.vala"
	result = _tmp0_;
#line 164 "GomElementTest.vala"
	return result;
#line 15203 "GomElementTest.c"
}

void
gom_element_test_namespace_set_name (GomElementTestNamespace* self,
                                     const gchar* value)
{
#line 164 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 164 "GomElementTest.vala"
	if (g_strcmp0 (value, gom_element_test_namespace_get_name (self)) != 0) {
#line 15214 "GomElementTest.c"
		gchar* _tmp0_;
#line 164 "GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 164 "GomElementTest.vala"
		_g_free0 (self->priv->_name);
#line 164 "GomElementTest.vala"
		self->priv->_name = _tmp0_;
#line 164 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_namespace_properties[GOM_ELEMENT_TEST_NAMESPACE_NAME_PROPERTY]);
#line 15224 "GomElementTest.c"
	}
}

const gchar*
gom_element_test_namespace_get_version (GomElementTestNamespace* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 166 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 166 "GomElementTest.vala"
	_tmp0_ = self->priv->_version;
#line 166 "GomElementTest.vala"
	result = _tmp0_;
#line 166 "GomElementTest.vala"
	return result;
#line 15241 "GomElementTest.c"
}

void
gom_element_test_namespace_set_version (GomElementTestNamespace* self,
                                        const gchar* value)
{
#line 166 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 166 "GomElementTest.vala"
	if (g_strcmp0 (value, gom_element_test_namespace_get_version (self)) != 0) {
#line 15252 "GomElementTest.c"
		gchar* _tmp0_;
#line 166 "GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 166 "GomElementTest.vala"
		_g_free0 (self->priv->_version);
#line 166 "GomElementTest.vala"
		self->priv->_version = _tmp0_;
#line 166 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_namespace_properties[GOM_ELEMENT_TEST_NAMESPACE_VERSION_PROPERTY]);
#line 15262 "GomElementTest.c"
	}
}

const gchar*
gom_element_test_namespace_get_cprefix (GomElementTestNamespace* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 168 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 168 "GomElementTest.vala"
	_tmp0_ = self->priv->_cprefix;
#line 168 "GomElementTest.vala"
	result = _tmp0_;
#line 168 "GomElementTest.vala"
	return result;
#line 15279 "GomElementTest.c"
}

void
gom_element_test_namespace_set_cprefix (GomElementTestNamespace* self,
                                        const gchar* value)
{
#line 168 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 168 "GomElementTest.vala"
	if (g_strcmp0 (value, gom_element_test_namespace_get_cprefix (self)) != 0) {
#line 15290 "GomElementTest.c"
		gchar* _tmp0_;
#line 168 "GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 168 "GomElementTest.vala"
		_g_free0 (self->priv->_cprefix);
#line 168 "GomElementTest.vala"
		self->priv->_cprefix = _tmp0_;
#line 168 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_namespace_properties[GOM_ELEMENT_TEST_NAMESPACE_CPREFIX_PROPERTY]);
#line 15300 "GomElementTest.c"
	}
}

GomElementTestTClassMap*
gom_element_test_namespace_get_classes (GomElementTestNamespace* self)
{
	GomElementTestTClassMap* result;
	GomElementTestTClassMap* _tmp0_;
	GomElementTestTClassMap* _tmp1_;
#line 170 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 171 "GomElementTest.vala"
	_tmp0_ = self->priv->_classes;
#line 171 "GomElementTest.vala"
	if (_tmp0_ == NULL) {
#line 172 "GomElementTest.vala"
		gxml_gom_object_set_instance_property ((GXmlGomObject*) self, "classes");
#line 15318 "GomElementTest.c"
	}
#line 173 "GomElementTest.vala"
	_tmp1_ = self->priv->_classes;
#line 173 "GomElementTest.vala"
	result = _tmp1_;
#line 173 "GomElementTest.vala"
	return result;
#line 15326 "GomElementTest.c"
}

void
gom_element_test_namespace_set_classes (GomElementTestNamespace* self,
                                        GomElementTestTClassMap* value)
{
	GomElementTestTClassMap* _tmp0_;
	GomElementTestTClassMap* _tmp5_;
	GError* _inner_error0_ = NULL;
#line 175 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 176 "GomElementTest.vala"
	_tmp0_ = self->priv->_classes;
#line 176 "GomElementTest.vala"
	if (_tmp0_ != NULL) {
#line 15342 "GomElementTest.c"
		{
#line 177 "GomElementTest.vala"
			gxml_gom_object_clean_property_elements ((GXmlGomObject*) self, "classes", &_inner_error0_);
#line 177 "GomElementTest.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 15348 "GomElementTest.c"
				goto __catch148_g_error;
			}
		}
		goto __finally148;
		__catch148_g_error:
		{
			GError* e = NULL;
			GError* _tmp1_;
			const gchar* _tmp2_;
			gchar* _tmp3_;
			gchar* _tmp4_;
#line 177 "GomElementTest.vala"
			e = _inner_error0_;
#line 177 "GomElementTest.vala"
			_inner_error0_ = NULL;
#line 178 "GomElementTest.vala"
			_tmp1_ = e;
#line 178 "GomElementTest.vala"
			_tmp2_ = _tmp1_->message;
#line 178 "GomElementTest.vala"
			_tmp3_ = g_strconcat ("Error: ", _tmp2_, NULL);
#line 178 "GomElementTest.vala"
			_tmp4_ = _tmp3_;
#line 178 "GomElementTest.vala"
			g_warning ("GomElementTest.vala:178: %s", _tmp4_);
#line 178 "GomElementTest.vala"
			_g_free0 (_tmp4_);
#line 177 "GomElementTest.vala"
			_g_error_free0 (e);
#line 15378 "GomElementTest.c"
		}
		__finally148:
#line 177 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 177 "GomElementTest.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 177 "GomElementTest.vala"
			g_clear_error (&_inner_error0_);
#line 177 "GomElementTest.vala"
			return;
#line 15389 "GomElementTest.c"
		}
	}
#line 180 "GomElementTest.vala"
	_tmp5_ = _g_object_ref0 (value);
#line 180 "GomElementTest.vala"
	_g_object_unref0 (self->priv->_classes);
#line 180 "GomElementTest.vala"
	self->priv->_classes = _tmp5_;
#line 175 "GomElementTest.vala"
	g_object_notify_by_pspec ((GObject *) self, gom_element_test_namespace_properties[GOM_ELEMENT_TEST_NAMESPACE_CLASSES_PROPERTY]);
#line 15400 "GomElementTest.c"
}

static GObject *
gom_element_test_namespace_constructor (GType type,
                                        guint n_construct_properties,
                                        GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestNamespace * self;
	GomElementTestTClassMap* _tmp0_;
	GError* _inner_error0_ = NULL;
#line 183 "GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_namespace_parent_class);
#line 183 "GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 183 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_NAMESPACE, GomElementTestNamespace);
#line 184 "GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "namespace");
#line 185 "GomElementTest.vala"
	_tmp0_ = gom_element_test_tclass_map_new ();
#line 185 "GomElementTest.vala"
	_g_object_unref0 (self->priv->_classes);
#line 185 "GomElementTest.vala"
	self->priv->_classes = _tmp0_;
#line 15427 "GomElementTest.c"
	{
		GomElementTestTClassMap* _tmp1_;
#line 186 "GomElementTest.vala"
		_tmp1_ = self->priv->_classes;
#line 186 "GomElementTest.vala"
		gxml_base_collection_initialize_element ((GXmlBaseCollection*) _tmp1_, (GXmlGomElement*) self, &_inner_error0_);
#line 186 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 15436 "GomElementTest.c"
			goto __catch149_g_error;
		}
	}
	goto __finally149;
	__catch149_g_error:
	{
		GError* e = NULL;
		GError* _tmp2_;
		const gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
#line 186 "GomElementTest.vala"
		e = _inner_error0_;
#line 186 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 187 "GomElementTest.vala"
		_tmp2_ = e;
#line 187 "GomElementTest.vala"
		_tmp3_ = _tmp2_->message;
#line 187 "GomElementTest.vala"
		_tmp4_ = g_strconcat ("Error: ", _tmp3_, NULL);
#line 187 "GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 187 "GomElementTest.vala"
		g_warning ("GomElementTest.vala:187: %s", _tmp5_);
#line 187 "GomElementTest.vala"
		_g_free0 (_tmp5_);
#line 186 "GomElementTest.vala"
		_g_error_free0 (e);
#line 15466 "GomElementTest.c"
	}
	__finally149:
#line 186 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 186 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 186 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 15475 "GomElementTest.c"
	}
#line 183 "GomElementTest.vala"
	return obj;
#line 15479 "GomElementTest.c"
}

static void
gom_element_test_namespace_class_init (GomElementTestNamespaceClass * klass,
                                       gpointer klass_data)
{
#line 160 "GomElementTest.vala"
	gom_element_test_namespace_parent_class = g_type_class_peek_parent (klass);
#line 160 "GomElementTest.vala"
	g_type_class_adjust_private_offset (klass, &GomElementTestNamespace_private_offset);
#line 160 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_namespace_get_property;
#line 160 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_namespace_set_property;
#line 160 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_namespace_constructor;
#line 160 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_namespace_finalize;
#line 160 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_NAMESPACE_NAME_PROPERTY, gom_element_test_namespace_properties[GOM_ELEMENT_TEST_NAMESPACE_NAME_PROPERTY] = g_param_spec_string ("name", "::name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 160 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_NAMESPACE_VERSION_PROPERTY, gom_element_test_namespace_properties[GOM_ELEMENT_TEST_NAMESPACE_VERSION_PROPERTY] = g_param_spec_string ("version", "::version", "version", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 160 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_NAMESPACE_CPREFIX_PROPERTY, gom_element_test_namespace_properties[GOM_ELEMENT_TEST_NAMESPACE_CPREFIX_PROPERTY] = g_param_spec_string ("cprefix", "::c:prefix", "cprefix", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 160 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_NAMESPACE_CLASSES_PROPERTY, gom_element_test_namespace_properties[GOM_ELEMENT_TEST_NAMESPACE_CLASSES_PROPERTY] = g_param_spec_object ("classes", "classes", "classes", GOM_ELEMENT_TEST_TCLASS_TYPE_MAP, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 15506 "GomElementTest.c"
}

static void
gom_element_test_namespace_instance_init (GomElementTestNamespace * self,
                                          gpointer klass)
{
#line 160 "GomElementTest.vala"
	self->priv = gom_element_test_namespace_get_instance_private (self);
#line 15515 "GomElementTest.c"
}

static void
gom_element_test_namespace_finalize (GObject * obj)
{
	GomElementTestNamespace * self;
#line 160 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_NAMESPACE, GomElementTestNamespace);
#line 162 "GomElementTest.vala"
	_g_object_unref0 (self->priv->_classes);
#line 164 "GomElementTest.vala"
	_g_free0 (self->priv->_name);
#line 166 "GomElementTest.vala"
	_g_free0 (self->priv->_version);
#line 168 "GomElementTest.vala"
	_g_free0 (self->priv->_cprefix);
#line 160 "GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_namespace_parent_class)->finalize (obj);
#line 15534 "GomElementTest.c"
}

GType
gom_element_test_namespace_get_type (void)
{
	static volatile gsize gom_element_test_namespace_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_namespace_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestNamespaceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_namespace_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestNamespace), 0, (GInstanceInitFunc) gom_element_test_namespace_instance_init, NULL };
		GType gom_element_test_namespace_type_id;
		gom_element_test_namespace_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestNamespace", &g_define_type_info, 0);
		GomElementTestNamespace_private_offset = g_type_add_instance_private (gom_element_test_namespace_type_id, sizeof (GomElementTestNamespacePrivate));
		g_once_init_leave (&gom_element_test_namespace_type_id__volatile, gom_element_test_namespace_type_id);
	}
	return gom_element_test_namespace_type_id__volatile;
}

static void
_vala_gom_element_test_namespace_get_property (GObject * object,
                                               guint property_id,
                                               GValue * value,
                                               GParamSpec * pspec)
{
	GomElementTestNamespace * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_NAMESPACE, GomElementTestNamespace);
#line 160 "GomElementTest.vala"
	switch (property_id) {
#line 160 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_NAME_PROPERTY:
#line 160 "GomElementTest.vala"
		g_value_set_string (value, gom_element_test_namespace_get_name (self));
#line 160 "GomElementTest.vala"
		break;
#line 160 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_VERSION_PROPERTY:
#line 160 "GomElementTest.vala"
		g_value_set_string (value, gom_element_test_namespace_get_version (self));
#line 160 "GomElementTest.vala"
		break;
#line 160 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_CPREFIX_PROPERTY:
#line 160 "GomElementTest.vala"
		g_value_set_string (value, gom_element_test_namespace_get_cprefix (self));
#line 160 "GomElementTest.vala"
		break;
#line 160 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_CLASSES_PROPERTY:
#line 160 "GomElementTest.vala"
		g_value_set_object (value, gom_element_test_namespace_get_classes (self));
#line 160 "GomElementTest.vala"
		break;
#line 15585 "GomElementTest.c"
		default:
#line 160 "GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 160 "GomElementTest.vala"
		break;
#line 15591 "GomElementTest.c"
	}
}

static void
_vala_gom_element_test_namespace_set_property (GObject * object,
                                               guint property_id,
                                               const GValue * value,
                                               GParamSpec * pspec)
{
	GomElementTestNamespace * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_NAMESPACE, GomElementTestNamespace);
#line 160 "GomElementTest.vala"
	switch (property_id) {
#line 160 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_NAME_PROPERTY:
#line 160 "GomElementTest.vala"
		gom_element_test_namespace_set_name (self, g_value_get_string (value));
#line 160 "GomElementTest.vala"
		break;
#line 160 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_VERSION_PROPERTY:
#line 160 "GomElementTest.vala"
		gom_element_test_namespace_set_version (self, g_value_get_string (value));
#line 160 "GomElementTest.vala"
		break;
#line 160 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_CPREFIX_PROPERTY:
#line 160 "GomElementTest.vala"
		gom_element_test_namespace_set_cprefix (self, g_value_get_string (value));
#line 160 "GomElementTest.vala"
		break;
#line 160 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_CLASSES_PROPERTY:
#line 160 "GomElementTest.vala"
		gom_element_test_namespace_set_classes (self, g_value_get_object (value));
#line 160 "GomElementTest.vala"
		break;
#line 15629 "GomElementTest.c"
		default:
#line 160 "GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 160 "GomElementTest.vala"
		break;
#line 15635 "GomElementTest.c"
	}
}

static inline gpointer
gom_element_test_tclass_get_instance_private (GomElementTestTClass* self)
{
	return G_STRUCT_MEMBER_P (self, GomElementTestTClass_private_offset);
}

static gchar*
gom_element_test_tclass_real_get_map_key (GXmlMappeableElement* base)
{
	GomElementTestTClass * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 203 "GomElementTest.vala"
	self = (GomElementTestTClass*) base;
#line 203 "GomElementTest.vala"
	_tmp0_ = self->priv->_name;
#line 203 "GomElementTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 203 "GomElementTest.vala"
	result = _tmp1_;
#line 203 "GomElementTest.vala"
	return result;
#line 15662 "GomElementTest.c"
}

GomElementTestTClass*
gom_element_test_tclass_construct (GType object_type)
{
	GomElementTestTClass * self = NULL;
#line 190 "GomElementTest.vala"
	self = (GomElementTestTClass*) gxml_gom_element_construct (object_type);
#line 190 "GomElementTest.vala"
	return self;
#line 15673 "GomElementTest.c"
}

GomElementTestTClass*
gom_element_test_tclass_new (void)
{
#line 190 "GomElementTest.vala"
	return gom_element_test_tclass_construct (GOM_ELEMENT_TEST_TYPE_TCLASS);
#line 15681 "GomElementTest.c"
}

const gchar*
gom_element_test_tclass_get_name (GomElementTestTClass* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 193 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 193 "GomElementTest.vala"
	_tmp0_ = self->priv->_name;
#line 193 "GomElementTest.vala"
	result = _tmp0_;
#line 193 "GomElementTest.vala"
	return result;
#line 15697 "GomElementTest.c"
}

void
gom_element_test_tclass_set_name (GomElementTestTClass* self,
                                  const gchar* value)
{
#line 193 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 193 "GomElementTest.vala"
	if (g_strcmp0 (value, gom_element_test_tclass_get_name (self)) != 0) {
#line 15708 "GomElementTest.c"
		gchar* _tmp0_;
#line 193 "GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 193 "GomElementTest.vala"
		_g_free0 (self->priv->_name);
#line 193 "GomElementTest.vala"
		self->priv->_name = _tmp0_;
#line 193 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_tclass_properties[GOM_ELEMENT_TEST_TCLASS_NAME_PROPERTY]);
#line 15718 "GomElementTest.c"
	}
}

const gchar*
gom_element_test_tclass_get_version (GomElementTestTClass* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 195 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 195 "GomElementTest.vala"
	_tmp0_ = self->priv->_version;
#line 195 "GomElementTest.vala"
	result = _tmp0_;
#line 195 "GomElementTest.vala"
	return result;
#line 15735 "GomElementTest.c"
}

void
gom_element_test_tclass_set_version (GomElementTestTClass* self,
                                     const gchar* value)
{
#line 195 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 195 "GomElementTest.vala"
	if (g_strcmp0 (value, gom_element_test_tclass_get_version (self)) != 0) {
#line 15746 "GomElementTest.c"
		gchar* _tmp0_;
#line 195 "GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 195 "GomElementTest.vala"
		_g_free0 (self->priv->_version);
#line 195 "GomElementTest.vala"
		self->priv->_version = _tmp0_;
#line 195 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_tclass_properties[GOM_ELEMENT_TEST_TCLASS_VERSION_PROPERTY]);
#line 15756 "GomElementTest.c"
	}
}

const gchar*
gom_element_test_tclass_get_cprefix (GomElementTestTClass* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 197 "GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 197 "GomElementTest.vala"
	_tmp0_ = self->priv->_cprefix;
#line 197 "GomElementTest.vala"
	result = _tmp0_;
#line 197 "GomElementTest.vala"
	return result;
#line 15773 "GomElementTest.c"
}

void
gom_element_test_tclass_set_cprefix (GomElementTestTClass* self,
                                     const gchar* value)
{
#line 197 "GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 197 "GomElementTest.vala"
	if (g_strcmp0 (value, gom_element_test_tclass_get_cprefix (self)) != 0) {
#line 15784 "GomElementTest.c"
		gchar* _tmp0_;
#line 197 "GomElementTest.vala"
		_tmp0_ = g_strdup (value);
#line 197 "GomElementTest.vala"
		_g_free0 (self->priv->_cprefix);
#line 197 "GomElementTest.vala"
		self->priv->_cprefix = _tmp0_;
#line 197 "GomElementTest.vala"
		g_object_notify_by_pspec ((GObject *) self, gom_element_test_tclass_properties[GOM_ELEMENT_TEST_TCLASS_CPREFIX_PROPERTY]);
#line 15794 "GomElementTest.c"
	}
}

static GObject *
gom_element_test_tclass_constructor (GType type,
                                     guint n_construct_properties,
                                     GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestTClass * self;
#line 199 "GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_tclass_parent_class);
#line 199 "GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 199 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_TCLASS, GomElementTestTClass);
#line 200 "GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "class");
#line 199 "GomElementTest.vala"
	return obj;
#line 15816 "GomElementTest.c"
}

GomElementTestTClassMap*
gom_element_test_tclass_map_construct (GType object_type)
{
	GomElementTestTClassMap * self = NULL;
#line 204 "GomElementTest.vala"
	self = (GomElementTestTClassMap*) gxml_gom_hash_map_construct (object_type);
#line 204 "GomElementTest.vala"
	return self;
#line 15827 "GomElementTest.c"
}

GomElementTestTClassMap*
gom_element_test_tclass_map_new (void)
{
#line 204 "GomElementTest.vala"
	return gom_element_test_tclass_map_construct (GOM_ELEMENT_TEST_TCLASS_TYPE_MAP);
#line 15835 "GomElementTest.c"
}

static GObject *
gom_element_test_tclass_map_constructor (GType type,
                                         guint n_construct_properties,
                                         GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestTClassMap * self;
	GError* _inner_error0_ = NULL;
#line 205 "GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_tclass_map_parent_class);
#line 205 "GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 205 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TCLASS_TYPE_MAP, GomElementTestTClassMap);
#line 15853 "GomElementTest.c"
	{
#line 206 "GomElementTest.vala"
		gxml_collection_initialize ((GXmlCollection*) self, GOM_ELEMENT_TEST_TYPE_TCLASS, &_inner_error0_);
#line 206 "GomElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 15859 "GomElementTest.c"
			goto __catch150_g_error;
		}
	}
	goto __finally150;
	__catch150_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 206 "GomElementTest.vala"
		e = _inner_error0_;
#line 206 "GomElementTest.vala"
		_inner_error0_ = NULL;
#line 207 "GomElementTest.vala"
		_tmp0_ = e;
#line 207 "GomElementTest.vala"
		_tmp1_ = _tmp0_->message;
#line 207 "GomElementTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 207 "GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 207 "GomElementTest.vala"
		g_warning ("GomElementTest.vala:207: %s", _tmp3_);
#line 207 "GomElementTest.vala"
		_g_free0 (_tmp3_);
#line 206 "GomElementTest.vala"
		_g_error_free0 (e);
#line 15889 "GomElementTest.c"
	}
	__finally150:
#line 206 "GomElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 206 "GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 206 "GomElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 15898 "GomElementTest.c"
	}
#line 205 "GomElementTest.vala"
	return obj;
#line 15902 "GomElementTest.c"
}

static void
gom_element_test_tclass_map_class_init (GomElementTestTClassMapClass * klass,
                                        gpointer klass_data)
{
#line 204 "GomElementTest.vala"
	gom_element_test_tclass_map_parent_class = g_type_class_peek_parent (klass);
#line 204 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_tclass_map_constructor;
#line 15913 "GomElementTest.c"
}

static void
gom_element_test_tclass_map_instance_init (GomElementTestTClassMap * self,
                                           gpointer klass)
{
}

GType
gom_element_test_tclass_map_get_type (void)
{
	static volatile gsize gom_element_test_tclass_map_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_tclass_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestTClassMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_tclass_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestTClassMap), 0, (GInstanceInitFunc) gom_element_test_tclass_map_instance_init, NULL };
		GType gom_element_test_tclass_map_type_id;
		gom_element_test_tclass_map_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_MAP, "GomElementTestTClassMap", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_tclass_map_type_id__volatile, gom_element_test_tclass_map_type_id);
	}
	return gom_element_test_tclass_map_type_id__volatile;
}

static void
gom_element_test_tclass_class_init (GomElementTestTClassClass * klass,
                                    gpointer klass_data)
{
#line 190 "GomElementTest.vala"
	gom_element_test_tclass_parent_class = g_type_class_peek_parent (klass);
#line 190 "GomElementTest.vala"
	g_type_class_adjust_private_offset (klass, &GomElementTestTClass_private_offset);
#line 190 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_tclass_get_property;
#line 190 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_tclass_set_property;
#line 190 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_tclass_constructor;
#line 190 "GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_tclass_finalize;
#line 190 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_TCLASS_NAME_PROPERTY, gom_element_test_tclass_properties[GOM_ELEMENT_TEST_TCLASS_NAME_PROPERTY] = g_param_spec_string ("name", "::name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 190 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_TCLASS_VERSION_PROPERTY, gom_element_test_tclass_properties[GOM_ELEMENT_TEST_TCLASS_VERSION_PROPERTY] = g_param_spec_string ("version", "::version", "version", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 190 "GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_TCLASS_CPREFIX_PROPERTY, gom_element_test_tclass_properties[GOM_ELEMENT_TEST_TCLASS_CPREFIX_PROPERTY] = g_param_spec_string ("cprefix", "::c:prefix", "cprefix", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 15957 "GomElementTest.c"
}

static void
gom_element_test_tclass_gxml_mappeable_element_interface_init (GXmlMappeableElementIface * iface,
                                                               gpointer iface_data)
{
#line 190 "GomElementTest.vala"
	gom_element_test_tclass_gxml_mappeable_element_parent_iface = g_type_interface_peek_parent (iface);
#line 190 "GomElementTest.vala"
	iface->get_map_key = (gchar* (*) (GXmlMappeableElement*)) gom_element_test_tclass_real_get_map_key;
#line 15968 "GomElementTest.c"
}

static void
gom_element_test_tclass_instance_init (GomElementTestTClass * self,
                                       gpointer klass)
{
#line 190 "GomElementTest.vala"
	self->priv = gom_element_test_tclass_get_instance_private (self);
#line 15977 "GomElementTest.c"
}

static void
gom_element_test_tclass_finalize (GObject * obj)
{
	GomElementTestTClass * self;
#line 190 "GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_TCLASS, GomElementTestTClass);
#line 193 "GomElementTest.vala"
	_g_free0 (self->priv->_name);
#line 195 "GomElementTest.vala"
	_g_free0 (self->priv->_version);
#line 197 "GomElementTest.vala"
	_g_free0 (self->priv->_cprefix);
#line 190 "GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_tclass_parent_class)->finalize (obj);
#line 15994 "GomElementTest.c"
}

GType
gom_element_test_tclass_get_type (void)
{
	static volatile gsize gom_element_test_tclass_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_tclass_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestTClassClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_tclass_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestTClass), 0, (GInstanceInitFunc) gom_element_test_tclass_instance_init, NULL };
		static const GInterfaceInfo gxml_mappeable_element_info = { (GInterfaceInitFunc) gom_element_test_tclass_gxml_mappeable_element_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gom_element_test_tclass_type_id;
		gom_element_test_tclass_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestTClass", &g_define_type_info, 0);
		g_type_add_interface_static (gom_element_test_tclass_type_id, GXML_TYPE_MAPPEABLE_ELEMENT, &gxml_mappeable_element_info);
		GomElementTestTClass_private_offset = g_type_add_instance_private (gom_element_test_tclass_type_id, sizeof (GomElementTestTClassPrivate));
		g_once_init_leave (&gom_element_test_tclass_type_id__volatile, gom_element_test_tclass_type_id);
	}
	return gom_element_test_tclass_type_id__volatile;
}

static void
_vala_gom_element_test_tclass_get_property (GObject * object,
                                            guint property_id,
                                            GValue * value,
                                            GParamSpec * pspec)
{
	GomElementTestTClass * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_TCLASS, GomElementTestTClass);
#line 190 "GomElementTest.vala"
	switch (property_id) {
#line 190 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_TCLASS_NAME_PROPERTY:
#line 190 "GomElementTest.vala"
		g_value_set_string (value, gom_element_test_tclass_get_name (self));
#line 190 "GomElementTest.vala"
		break;
#line 190 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_TCLASS_VERSION_PROPERTY:
#line 190 "GomElementTest.vala"
		g_value_set_string (value, gom_element_test_tclass_get_version (self));
#line 190 "GomElementTest.vala"
		break;
#line 190 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_TCLASS_CPREFIX_PROPERTY:
#line 190 "GomElementTest.vala"
		g_value_set_string (value, gom_element_test_tclass_get_cprefix (self));
#line 190 "GomElementTest.vala"
		break;
#line 16041 "GomElementTest.c"
		default:
#line 190 "GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 190 "GomElementTest.vala"
		break;
#line 16047 "GomElementTest.c"
	}
}

static void
_vala_gom_element_test_tclass_set_property (GObject * object,
                                            guint property_id,
                                            const GValue * value,
                                            GParamSpec * pspec)
{
	GomElementTestTClass * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_TCLASS, GomElementTestTClass);
#line 190 "GomElementTest.vala"
	switch (property_id) {
#line 190 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_TCLASS_NAME_PROPERTY:
#line 190 "GomElementTest.vala"
		gom_element_test_tclass_set_name (self, g_value_get_string (value));
#line 190 "GomElementTest.vala"
		break;
#line 190 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_TCLASS_VERSION_PROPERTY:
#line 190 "GomElementTest.vala"
		gom_element_test_tclass_set_version (self, g_value_get_string (value));
#line 190 "GomElementTest.vala"
		break;
#line 190 "GomElementTest.vala"
		case GOM_ELEMENT_TEST_TCLASS_CPREFIX_PROPERTY:
#line 190 "GomElementTest.vala"
		gom_element_test_tclass_set_cprefix (self, g_value_get_string (value));
#line 190 "GomElementTest.vala"
		break;
#line 16079 "GomElementTest.c"
		default:
#line 190 "GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 190 "GomElementTest.vala"
		break;
#line 16085 "GomElementTest.c"
	}
}

static void
gom_element_test_class_init (GomElementTestClass * klass,
                             gpointer klass_data)
{
#line 60 "GomElementTest.vala"
	gom_element_test_parent_class = g_type_class_peek_parent (klass);
#line 16095 "GomElementTest.c"
}

static void
gom_element_test_instance_init (GomElementTest * self,
                                gpointer klass)
{
}

GType
gom_element_test_get_type (void)
{
	static volatile gsize gom_element_test_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTest), 0, (GInstanceInitFunc) gom_element_test_instance_init, NULL };
		GType gom_element_test_type_id;
		gom_element_test_type_id = g_type_register_static (TYPE_GXML_TEST, "GomElementTest", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_type_id__volatile, gom_element_test_type_id);
	}
	return gom_element_test_type_id__volatile;
}

static void
_vala_array_destroy (gpointer array,
                     gint array_length,
                     GDestroyNotify destroy_func)
{
#line 60 "GomElementTest.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 16124 "GomElementTest.c"
		int i;
#line 60 "GomElementTest.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 60 "GomElementTest.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 60 "GomElementTest.vala"
				destroy_func (((gpointer*) array)[i]);
#line 16132 "GomElementTest.c"
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gint array_length,
                  GDestroyNotify destroy_func)
{
#line 60 "GomElementTest.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 60 "GomElementTest.vala"
	g_free (array);
#line 16147 "GomElementTest.c"
}

static gint
_vala_array_length (gpointer array)
{
	int length;
	length = 0;
#line 60 "GomElementTest.vala"
	if (array) {
#line 60 "GomElementTest.vala"
		while (((gpointer*) array)[length]) {
#line 60 "GomElementTest.vala"
			length++;
#line 16161 "GomElementTest.c"
		}
	}
#line 60 "GomElementTest.vala"
	return length;
#line 16166 "GomElementTest.c"
}

