/* SerializableGeeCollectionsTest.c generated by valac 0.44.3, the Vala compiler
 * generated from SerializableGeeCollectionsTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */

#include <glib-object.h>
#include <glib.h>
#include <gxml/gxml.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_SERIALIZABLE_GEE_COLLECTIONS_TEST (serializable_gee_collections_test_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_GEE_COLLECTIONS_TEST, SerializableGeeCollectionsTest))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_GEE_COLLECTIONS_TEST, SerializableGeeCollectionsTestClass))
#define IS_SERIALIZABLE_GEE_COLLECTIONS_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_GEE_COLLECTIONS_TEST))
#define IS_SERIALIZABLE_GEE_COLLECTIONS_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_GEE_COLLECTIONS_TEST))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_GEE_COLLECTIONS_TEST, SerializableGeeCollectionsTestClass))

typedef struct _SerializableGeeCollectionsTest SerializableGeeCollectionsTest;
typedef struct _SerializableGeeCollectionsTestClass SerializableGeeCollectionsTestClass;
typedef struct _SerializableGeeCollectionsTestPrivate SerializableGeeCollectionsTestPrivate;

#define SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE_BASE (serializable_gee_collections_test_space_base_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE_BASE, SerializableGeeCollectionsTestSpaceBase))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE_BASE, SerializableGeeCollectionsTestSpaceBaseClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_SPACE_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE_BASE))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_SPACE_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE_BASE))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE_BASE, SerializableGeeCollectionsTestSpaceBaseClass))

typedef struct _SerializableGeeCollectionsTestSpaceBase SerializableGeeCollectionsTestSpaceBase;
typedef struct _SerializableGeeCollectionsTestSpaceBaseClass SerializableGeeCollectionsTestSpaceBaseClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_STORAGE (serializable_gee_collections_test_storage_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_STORAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_STORAGE, SerializableGeeCollectionsTestStorage))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_STORAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_STORAGE, SerializableGeeCollectionsTestStorageClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_STORAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_STORAGE))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_STORAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_STORAGE))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_STORAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_STORAGE, SerializableGeeCollectionsTestStorageClass))

typedef struct _SerializableGeeCollectionsTestStorage SerializableGeeCollectionsTestStorage;
typedef struct _SerializableGeeCollectionsTestStorageClass SerializableGeeCollectionsTestStorageClass;
#define _g_free0(var) (var = (g_free (var), NULL))

#define SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_TYPE_COLLECTION (serializable_gee_collections_test_refaction_collection_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_TYPE_COLLECTION, SerializableGeeCollectionsTestRefactionCollection))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_TYPE_COLLECTION, SerializableGeeCollectionsTestRefactionCollectionClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_TYPE_COLLECTION))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_TYPE_COLLECTION))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_TYPE_COLLECTION, SerializableGeeCollectionsTestRefactionCollectionClass))

typedef struct _SerializableGeeCollectionsTestRefactionCollection SerializableGeeCollectionsTestRefactionCollection;
typedef struct _SerializableGeeCollectionsTestRefactionCollectionClass SerializableGeeCollectionsTestRefactionCollectionClass;

#define SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_REFACTION (serializable_gee_collections_test_refaction_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_REFACTION, SerializableGeeCollectionsTestRefaction))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_REFACTION, SerializableGeeCollectionsTestRefactionClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_REFACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_REFACTION))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_REFACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_REFACTION))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_REFACTION, SerializableGeeCollectionsTestRefactionClass))

typedef struct _SerializableGeeCollectionsTestRefaction SerializableGeeCollectionsTestRefaction;
typedef struct _SerializableGeeCollectionsTestRefactionClass SerializableGeeCollectionsTestRefactionClass;

#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_TYPE_COLLECTION (serializable_gee_collections_test_space_ship_collection_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_TYPE_COLLECTION, SerializableGeeCollectionsTestSpaceShipCollection))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_TYPE_COLLECTION, SerializableGeeCollectionsTestSpaceShipCollectionClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_TYPE_COLLECTION))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_TYPE_COLLECTION))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_TYPE_COLLECTION, SerializableGeeCollectionsTestSpaceShipCollectionClass))

typedef struct _SerializableGeeCollectionsTestSpaceShipCollection SerializableGeeCollectionsTestSpaceShipCollection;
typedef struct _SerializableGeeCollectionsTestSpaceShipCollectionClass SerializableGeeCollectionsTestSpaceShipCollectionClass;

#define SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE_SHIP (serializable_gee_collections_test_space_ship_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE_SHIP, SerializableGeeCollectionsTestSpaceShip))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE_SHIP, SerializableGeeCollectionsTestSpaceShipClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_SPACE_SHIP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE_SHIP))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_SPACE_SHIP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE_SHIP))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE_SHIP, SerializableGeeCollectionsTestSpaceShipClass))

typedef struct _SerializableGeeCollectionsTestSpaceShip SerializableGeeCollectionsTestSpaceShip;
typedef struct _SerializableGeeCollectionsTestSpaceShipClass SerializableGeeCollectionsTestSpaceShipClass;

#define SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_CHARGE_ZONE (serializable_gee_collections_test_charge_zone_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_CHARGE_ZONE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_CHARGE_ZONE, SerializableGeeCollectionsTestChargeZone))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_CHARGE_ZONE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_CHARGE_ZONE, SerializableGeeCollectionsTestChargeZoneClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_CHARGE_ZONE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_CHARGE_ZONE))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_CHARGE_ZONE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_CHARGE_ZONE))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_CHARGE_ZONE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_CHARGE_ZONE, SerializableGeeCollectionsTestChargeZoneClass))

typedef struct _SerializableGeeCollectionsTestChargeZone SerializableGeeCollectionsTestChargeZone;
typedef struct _SerializableGeeCollectionsTestChargeZoneClass SerializableGeeCollectionsTestChargeZoneClass;

#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_TYPE_COLLECTION (serializable_gee_collections_test_space_collection_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_TYPE_COLLECTION, SerializableGeeCollectionsTestSpaceCollection))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_TYPE_COLLECTION, SerializableGeeCollectionsTestSpaceCollectionClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_TYPE_COLLECTION))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_TYPE_COLLECTION))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_TYPE_COLLECTION, SerializableGeeCollectionsTestSpaceCollectionClass))

typedef struct _SerializableGeeCollectionsTestSpaceCollection SerializableGeeCollectionsTestSpaceCollection;
typedef struct _SerializableGeeCollectionsTestSpaceCollectionClass SerializableGeeCollectionsTestSpaceCollectionClass;

#define SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE (serializable_gee_collections_test_space_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE, SerializableGeeCollectionsTestSpace))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE, SerializableGeeCollectionsTestSpaceClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_SPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_SPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE, SerializableGeeCollectionsTestSpaceClass))

typedef struct _SerializableGeeCollectionsTestSpace SerializableGeeCollectionsTestSpace;
typedef struct _SerializableGeeCollectionsTestSpaceClass SerializableGeeCollectionsTestSpaceClass;

#define SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_TYPE_COLLECTION (serializable_gee_collections_test_planet_collection_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_TYPE_COLLECTION, SerializableGeeCollectionsTestPlanetCollection))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_TYPE_COLLECTION, SerializableGeeCollectionsTestPlanetCollectionClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_TYPE_COLLECTION))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_TYPE_COLLECTION))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_TYPE_COLLECTION, SerializableGeeCollectionsTestPlanetCollectionClass))

typedef struct _SerializableGeeCollectionsTestPlanetCollection SerializableGeeCollectionsTestPlanetCollection;
typedef struct _SerializableGeeCollectionsTestPlanetCollectionClass SerializableGeeCollectionsTestPlanetCollectionClass;

#define SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_PLANET (serializable_gee_collections_test_planet_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_PLANET, SerializableGeeCollectionsTestPlanet))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_PLANET, SerializableGeeCollectionsTestPlanetClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_PLANET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_PLANET))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_PLANET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_PLANET))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_PLANET, SerializableGeeCollectionsTestPlanetClass))

typedef struct _SerializableGeeCollectionsTestPlanet SerializableGeeCollectionsTestPlanet;
typedef struct _SerializableGeeCollectionsTestPlanetClass SerializableGeeCollectionsTestPlanetClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BIG_BAG (serializable_gee_collections_test_big_bag_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_BIG_BAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BIG_BAG, SerializableGeeCollectionsTestBigBag))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_BIG_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BIG_BAG, SerializableGeeCollectionsTestBigBagClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_BIG_BAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BIG_BAG))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_BIG_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BIG_BAG))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_BIG_BAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BIG_BAG, SerializableGeeCollectionsTestBigBagClass))

typedef struct _SerializableGeeCollectionsTestBigBag SerializableGeeCollectionsTestBigBag;
typedef struct _SerializableGeeCollectionsTestBigBagClass SerializableGeeCollectionsTestBigBagClass;

#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_TYPE_ARRAY (serializable_gee_collections_test_small_bag_array_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_TYPE_ARRAY, SerializableGeeCollectionsTestSmallBagArray))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_TYPE_ARRAY, SerializableGeeCollectionsTestSmallBagArrayClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_IS_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_TYPE_ARRAY))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_IS_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_TYPE_ARRAY))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_ARRAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_TYPE_ARRAY, SerializableGeeCollectionsTestSmallBagArrayClass))

typedef struct _SerializableGeeCollectionsTestSmallBagArray SerializableGeeCollectionsTestSmallBagArray;
typedef struct _SerializableGeeCollectionsTestSmallBagArrayClass SerializableGeeCollectionsTestSmallBagArrayClass;

#define SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SMALL_BAG (serializable_gee_collections_test_small_bag_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SMALL_BAG, SerializableGeeCollectionsTestSmallBag))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SMALL_BAG, SerializableGeeCollectionsTestSmallBagClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_SMALL_BAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SMALL_BAG))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_SMALL_BAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SMALL_BAG))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SMALL_BAG, SerializableGeeCollectionsTestSmallBagClass))

typedef struct _SerializableGeeCollectionsTestSmallBag SerializableGeeCollectionsTestSmallBag;
typedef struct _SerializableGeeCollectionsTestSmallBagClass SerializableGeeCollectionsTestSmallBagClass;

#define SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_TYPE_ARRAY (serializable_gee_collections_test_ball_array_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_TYPE_ARRAY, SerializableGeeCollectionsTestBallArray))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_TYPE_ARRAY, SerializableGeeCollectionsTestBallArrayClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_IS_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_TYPE_ARRAY))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_IS_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_TYPE_ARRAY))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_ARRAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_TYPE_ARRAY, SerializableGeeCollectionsTestBallArrayClass))

typedef struct _SerializableGeeCollectionsTestBallArray SerializableGeeCollectionsTestBallArray;
typedef struct _SerializableGeeCollectionsTestBallArrayClass SerializableGeeCollectionsTestBallArrayClass;

#define SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BALL (serializable_gee_collections_test_ball_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BALL, SerializableGeeCollectionsTestBall))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BALL, SerializableGeeCollectionsTestBallClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_BALL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BALL))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_BALL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BALL))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BALL, SerializableGeeCollectionsTestBallClass))

typedef struct _SerializableGeeCollectionsTestBall SerializableGeeCollectionsTestBall;
typedef struct _SerializableGeeCollectionsTestBallClass SerializableGeeCollectionsTestBallClass;

#define SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_CITIZEN (serializable_gee_collections_test_citizen_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_CITIZEN, SerializableGeeCollectionsTestCitizen))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_CITIZEN, SerializableGeeCollectionsTestCitizenClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_CITIZEN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_CITIZEN))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_CITIZEN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_CITIZEN))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_CITIZEN, SerializableGeeCollectionsTestCitizenClass))

typedef struct _SerializableGeeCollectionsTestCitizen SerializableGeeCollectionsTestCitizen;
typedef struct _SerializableGeeCollectionsTestCitizenClass SerializableGeeCollectionsTestCitizenClass;
typedef struct _SerializableGeeCollectionsTestCitizenPrivate SerializableGeeCollectionsTestCitizenPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_CTYPE_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_test_citizen_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_NUM_PROPERTIES];

#define SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_TYPE_ARRAY (serializable_gee_collections_test_citizen_array_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_TYPE_ARRAY, SerializableGeeCollectionsTestCitizenArray))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_TYPE_ARRAY, SerializableGeeCollectionsTestCitizenArrayClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_IS_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_TYPE_ARRAY))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_IS_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_TYPE_ARRAY))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_ARRAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_TYPE_ARRAY, SerializableGeeCollectionsTestCitizenArrayClass))

typedef struct _SerializableGeeCollectionsTestCitizenArray SerializableGeeCollectionsTestCitizenArray;
typedef struct _SerializableGeeCollectionsTestCitizenArrayClass SerializableGeeCollectionsTestCitizenArrayClass;
typedef struct _SerializableGeeCollectionsTestCitizenArrayPrivate SerializableGeeCollectionsTestCitizenArrayPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_ARRAY_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_ARRAY_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_test_citizen_array_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_ARRAY_NUM_PROPERTIES];

#define SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_ASTEROID (serializable_gee_collections_test_asteroid_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_ASTEROID, SerializableGeeCollectionsTestAsteroid))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_ASTEROID, SerializableGeeCollectionsTestAsteroidClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_ASTEROID(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_ASTEROID))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_ASTEROID_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_ASTEROID))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_ASTEROID, SerializableGeeCollectionsTestAsteroidClass))

typedef struct _SerializableGeeCollectionsTestAsteroid SerializableGeeCollectionsTestAsteroid;
typedef struct _SerializableGeeCollectionsTestAsteroidClass SerializableGeeCollectionsTestAsteroidClass;
typedef struct _SerializableGeeCollectionsTestAsteroidPrivate SerializableGeeCollectionsTestAsteroidPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_SIZE_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_test_asteroid_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_NUM_PROPERTIES];

#define SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_TYPE_ARRAY (serializable_gee_collections_test_asteroid_array_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_TYPE_ARRAY, SerializableGeeCollectionsTestAsteroidArray))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_TYPE_ARRAY, SerializableGeeCollectionsTestAsteroidArrayClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_IS_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_TYPE_ARRAY))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_IS_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_TYPE_ARRAY))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_ARRAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_TYPE_ARRAY, SerializableGeeCollectionsTestAsteroidArrayClass))

typedef struct _SerializableGeeCollectionsTestAsteroidArray SerializableGeeCollectionsTestAsteroidArray;
typedef struct _SerializableGeeCollectionsTestAsteroidArrayClass SerializableGeeCollectionsTestAsteroidArrayClass;
typedef struct _SerializableGeeCollectionsTestAsteroidArrayPrivate SerializableGeeCollectionsTestAsteroidArrayPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_ARRAY_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_ARRAY_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_test_asteroid_array_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_ARRAY_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTestPlanetPrivate SerializableGeeCollectionsTestPlanetPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_NAME_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_CITIZENS_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_test_planet_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTestPlanetCollectionPrivate SerializableGeeCollectionsTestPlanetCollectionPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_COLLECTION_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_COLLECTION_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_test_planet_collection_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_COLLECTION_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTestSpacePrivate SerializableGeeCollectionsTestSpacePrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_NAME_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_PLANETS_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_ASTEROIDS_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_test_space_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTestSpaceCollectionPrivate SerializableGeeCollectionsTestSpaceCollectionPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_COLLECTION_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_COLLECTION_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_test_space_collection_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_COLLECTION_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTestRefactionPrivate SerializableGeeCollectionsTestRefactionPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_MODEL_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_MANUFACTURER_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_SPACESHIPS_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_test_refaction_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTestRefactionCollectionPrivate SerializableGeeCollectionsTestRefactionCollectionPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_COLLECTION_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_COLLECTION_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_test_refaction_collection_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_COLLECTION_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTestSpaceShipPrivate SerializableGeeCollectionsTestSpaceShipPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_MODEL_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_MANUFACTURER_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_SPACES_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_test_space_ship_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTestSpaceShipCollectionPrivate SerializableGeeCollectionsTestSpaceShipCollectionPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_COLLECTION_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_COLLECTION_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_test_space_ship_collection_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_COLLECTION_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTestChargeZonePrivate SerializableGeeCollectionsTestChargeZonePrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TEST_CHARGE_ZONE_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_CHARGE_ZONE_NAME_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_CHARGE_ZONE_SPACESHIPS_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_CHARGE_ZONE_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_test_charge_zone_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_CHARGE_ZONE_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTestStoragePrivate SerializableGeeCollectionsTestStoragePrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TEST_STORAGE_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_STORAGE_NAME_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_STORAGE_REFACTIONS_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_STORAGE_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_test_storage_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_STORAGE_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTestSpaceBasePrivate SerializableGeeCollectionsTestSpaceBasePrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE_NAME_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE_CHARGE_ZONE_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE_STORAGE_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_test_space_base_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE_NUM_PROPERTIES];

#define SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BALL_FILL (serializable_gee_collections_test_ball_fill_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_FILL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BALL_FILL, SerializableGeeCollectionsTestBallFill))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_FILL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BALL_FILL, SerializableGeeCollectionsTestBallFillClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_BALL_FILL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BALL_FILL))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_IS_BALL_FILL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BALL_FILL))
#define SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_FILL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BALL_FILL, SerializableGeeCollectionsTestBallFillClass))

typedef struct _SerializableGeeCollectionsTestBallFill SerializableGeeCollectionsTestBallFill;
typedef struct _SerializableGeeCollectionsTestBallFillClass SerializableGeeCollectionsTestBallFillClass;
typedef struct _SerializableGeeCollectionsTestBallFillPrivate SerializableGeeCollectionsTestBallFillPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_FILL_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_FILL_NAME_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_FILL_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_test_ball_fill_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_FILL_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTestBallPrivate SerializableGeeCollectionsTestBallPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_NAME_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_BALLFILL_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_test_ball_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTestBallArrayPrivate SerializableGeeCollectionsTestBallArrayPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_ARRAY_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_ARRAY_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_test_ball_array_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_ARRAY_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTestSmallBagPrivate SerializableGeeCollectionsTestSmallBagPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_NAME_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_BALLS_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_test_small_bag_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTestSmallBagArrayPrivate SerializableGeeCollectionsTestSmallBagArrayPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_ARRAY_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_ARRAY_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_test_small_bag_array_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_ARRAY_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTestBigBagPrivate SerializableGeeCollectionsTestBigBagPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TEST_BIG_BAG_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_BIG_BAG_NAME_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_BIG_BAG_BAGS_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TEST_BIG_BAG_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_test_big_bag_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_BIG_BAG_NUM_PROPERTIES];
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _SerializableGeeCollectionsTest {
	GXmlTest parent_instance;
	SerializableGeeCollectionsTestPrivate * priv;
};

struct _SerializableGeeCollectionsTestClass {
	GXmlTestClass parent_class;
};

struct _SerializableGeeCollectionsTestCitizen {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeCollectionsTestCitizenPrivate * priv;
};

struct _SerializableGeeCollectionsTestCitizenClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeCollectionsTestCitizenPrivate {
	gchar* _ctype;
};

struct _SerializableGeeCollectionsTestCitizenArray {
	GXmlSerializableArrayList parent_instance;
	SerializableGeeCollectionsTestCitizenArrayPrivate * priv;
};

struct _SerializableGeeCollectionsTestCitizenArrayClass {
	GXmlSerializableArrayListClass parent_class;
};

struct _SerializableGeeCollectionsTestAsteroid {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeCollectionsTestAsteroidPrivate * priv;
};

struct _SerializableGeeCollectionsTestAsteroidClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeCollectionsTestAsteroidPrivate {
	gint _size;
};

struct _SerializableGeeCollectionsTestAsteroidArray {
	GXmlSerializableArrayList parent_instance;
	SerializableGeeCollectionsTestAsteroidArrayPrivate * priv;
};

struct _SerializableGeeCollectionsTestAsteroidArrayClass {
	GXmlSerializableArrayListClass parent_class;
};

struct _SerializableGeeCollectionsTestPlanet {
	GXmlSerializableContainer parent_instance;
	SerializableGeeCollectionsTestPlanetPrivate * priv;
};

struct _SerializableGeeCollectionsTestPlanetClass {
	GXmlSerializableContainerClass parent_class;
};

struct _SerializableGeeCollectionsTestPlanetPrivate {
	gchar* _name;
	SerializableGeeCollectionsTestCitizenArray* _citizens;
};

struct _SerializableGeeCollectionsTestPlanetCollection {
	GXmlSerializableTreeMap parent_instance;
	SerializableGeeCollectionsTestPlanetCollectionPrivate * priv;
};

struct _SerializableGeeCollectionsTestPlanetCollectionClass {
	GXmlSerializableTreeMapClass parent_class;
};

struct _SerializableGeeCollectionsTestSpace {
	GXmlSerializableContainer parent_instance;
	SerializableGeeCollectionsTestSpacePrivate * priv;
};

struct _SerializableGeeCollectionsTestSpaceClass {
	GXmlSerializableContainerClass parent_class;
};

struct _SerializableGeeCollectionsTestSpacePrivate {
	gchar* _name;
	SerializableGeeCollectionsTestPlanetCollection* _planets;
	SerializableGeeCollectionsTestAsteroidArray* _asteroids;
};

struct _SerializableGeeCollectionsTestSpaceCollection {
	GXmlSerializableTreeMap parent_instance;
	SerializableGeeCollectionsTestSpaceCollectionPrivate * priv;
};

struct _SerializableGeeCollectionsTestSpaceCollectionClass {
	GXmlSerializableTreeMapClass parent_class;
};

struct _SerializableGeeCollectionsTestRefaction {
	GXmlSerializableContainer parent_instance;
	SerializableGeeCollectionsTestRefactionPrivate * priv;
};

struct _SerializableGeeCollectionsTestRefactionClass {
	GXmlSerializableContainerClass parent_class;
};

struct _SerializableGeeCollectionsTestRefactionPrivate {
	gchar* _model;
	gchar* _manufacturer;
	SerializableGeeCollectionsTestSpaceShipCollection* _spaceships;
};

struct _SerializableGeeCollectionsTestRefactionCollection {
	GXmlSerializableDualKeyMap parent_instance;
	SerializableGeeCollectionsTestRefactionCollectionPrivate * priv;
};

struct _SerializableGeeCollectionsTestRefactionCollectionClass {
	GXmlSerializableDualKeyMapClass parent_class;
};

struct _SerializableGeeCollectionsTestSpaceShip {
	GXmlSerializableContainer parent_instance;
	SerializableGeeCollectionsTestSpaceShipPrivate * priv;
};

struct _SerializableGeeCollectionsTestSpaceShipClass {
	GXmlSerializableContainerClass parent_class;
};

struct _SerializableGeeCollectionsTestSpaceShipPrivate {
	gchar* _model;
	gchar* _manufacturer;
	SerializableGeeCollectionsTestSpaceCollection* _spaces;
};

struct _SerializableGeeCollectionsTestSpaceShipCollection {
	GXmlSerializableDualKeyMap parent_instance;
	SerializableGeeCollectionsTestSpaceShipCollectionPrivate * priv;
};

struct _SerializableGeeCollectionsTestSpaceShipCollectionClass {
	GXmlSerializableDualKeyMapClass parent_class;
};

struct _SerializableGeeCollectionsTestChargeZone {
	GXmlSerializableContainer parent_instance;
	SerializableGeeCollectionsTestChargeZonePrivate * priv;
};

struct _SerializableGeeCollectionsTestChargeZoneClass {
	GXmlSerializableContainerClass parent_class;
};

struct _SerializableGeeCollectionsTestChargeZonePrivate {
	gchar* _name;
	SerializableGeeCollectionsTestSpaceShipCollection* _spaceships;
};

struct _SerializableGeeCollectionsTestStorage {
	GXmlSerializableContainer parent_instance;
	SerializableGeeCollectionsTestStoragePrivate * priv;
};

struct _SerializableGeeCollectionsTestStorageClass {
	GXmlSerializableContainerClass parent_class;
};

struct _SerializableGeeCollectionsTestStoragePrivate {
	gchar* _name;
	SerializableGeeCollectionsTestRefactionCollection* _refactions;
};

struct _SerializableGeeCollectionsTestSpaceBase {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeCollectionsTestSpaceBasePrivate * priv;
};

struct _SerializableGeeCollectionsTestSpaceBaseClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeCollectionsTestSpaceBasePrivate {
	gchar* _name;
	SerializableGeeCollectionsTestChargeZone* _charge_zone;
	SerializableGeeCollectionsTestStorage* _storage;
};

struct _SerializableGeeCollectionsTestBallFill {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeCollectionsTestBallFillPrivate * priv;
};

struct _SerializableGeeCollectionsTestBallFillClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeCollectionsTestBallFillPrivate {
	gchar* _name;
};

struct _SerializableGeeCollectionsTestBall {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeCollectionsTestBallPrivate * priv;
};

struct _SerializableGeeCollectionsTestBallClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeCollectionsTestBallPrivate {
	gchar* _name;
	SerializableGeeCollectionsTestBallFill* _ballfill;
};

struct _SerializableGeeCollectionsTestBallArray {
	GXmlSerializableArrayList parent_instance;
	SerializableGeeCollectionsTestBallArrayPrivate * priv;
};

struct _SerializableGeeCollectionsTestBallArrayClass {
	GXmlSerializableArrayListClass parent_class;
};

struct _SerializableGeeCollectionsTestSmallBag {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeCollectionsTestSmallBagPrivate * priv;
};

struct _SerializableGeeCollectionsTestSmallBagClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeCollectionsTestSmallBagPrivate {
	gchar* _name;
	SerializableGeeCollectionsTestBallArray* _balls;
};

struct _SerializableGeeCollectionsTestSmallBagArray {
	GXmlSerializableArrayList parent_instance;
	SerializableGeeCollectionsTestSmallBagArrayPrivate * priv;
};

struct _SerializableGeeCollectionsTestSmallBagArrayClass {
	GXmlSerializableArrayListClass parent_class;
};

struct _SerializableGeeCollectionsTestBigBag {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeCollectionsTestBigBagPrivate * priv;
};

struct _SerializableGeeCollectionsTestBigBagClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeCollectionsTestBigBagPrivate {
	gchar* _name;
	SerializableGeeCollectionsTestSmallBagArray* _bags;
};

static gpointer serializable_gee_collections_test_parent_class = NULL;
static gint SerializableGeeCollectionsTestCitizen_private_offset;
static gpointer serializable_gee_collections_test_citizen_parent_class = NULL;
static gpointer serializable_gee_collections_test_citizen_array_parent_class = NULL;
static gint SerializableGeeCollectionsTestAsteroid_private_offset;
static gpointer serializable_gee_collections_test_asteroid_parent_class = NULL;
static gpointer serializable_gee_collections_test_asteroid_array_parent_class = NULL;
static gint SerializableGeeCollectionsTestPlanet_private_offset;
static gpointer serializable_gee_collections_test_planet_parent_class = NULL;
static gpointer serializable_gee_collections_test_planet_collection_parent_class = NULL;
static GXmlSerializableMapKeyIface * serializable_gee_collections_test_planet_gxml_serializable_map_key_parent_iface = NULL;
static gint SerializableGeeCollectionsTestSpace_private_offset;
static gpointer serializable_gee_collections_test_space_parent_class = NULL;
static gpointer serializable_gee_collections_test_space_collection_parent_class = NULL;
static GXmlSerializableMapKeyIface * serializable_gee_collections_test_space_gxml_serializable_map_key_parent_iface = NULL;
static gint SerializableGeeCollectionsTestRefaction_private_offset;
static gpointer serializable_gee_collections_test_refaction_parent_class = NULL;
static gpointer serializable_gee_collections_test_refaction_collection_parent_class = NULL;
static GXmlSerializableMapDualKeyIface * serializable_gee_collections_test_refaction_gxml_serializable_map_dual_key_parent_iface = NULL;
static gint SerializableGeeCollectionsTestSpaceShip_private_offset;
static gpointer serializable_gee_collections_test_space_ship_parent_class = NULL;
static gpointer serializable_gee_collections_test_space_ship_collection_parent_class = NULL;
static GXmlSerializableMapDualKeyIface * serializable_gee_collections_test_space_ship_gxml_serializable_map_dual_key_parent_iface = NULL;
static gint SerializableGeeCollectionsTestChargeZone_private_offset;
static gpointer serializable_gee_collections_test_charge_zone_parent_class = NULL;
static gint SerializableGeeCollectionsTestStorage_private_offset;
static gpointer serializable_gee_collections_test_storage_parent_class = NULL;
static gint SerializableGeeCollectionsTestSpaceBase_private_offset;
static gpointer serializable_gee_collections_test_space_base_parent_class = NULL;
static gint SerializableGeeCollectionsTestBallFill_private_offset;
static gpointer serializable_gee_collections_test_ball_fill_parent_class = NULL;
static gint SerializableGeeCollectionsTestBall_private_offset;
static gpointer serializable_gee_collections_test_ball_parent_class = NULL;
static gpointer serializable_gee_collections_test_ball_array_parent_class = NULL;
static gint SerializableGeeCollectionsTestSmallBag_private_offset;
static gpointer serializable_gee_collections_test_small_bag_parent_class = NULL;
static gpointer serializable_gee_collections_test_small_bag_array_parent_class = NULL;
static gint SerializableGeeCollectionsTestBigBag_private_offset;
static gpointer serializable_gee_collections_test_big_bag_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType serializable_gee_collections_test_get_type (void) G_GNUC_CONST;
void serializable_gee_collections_test_add_tests (void);
static void __lambda319_ (void);
static GType serializable_gee_collections_test_space_base_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeCollectionsTestSpaceBase* serializable_gee_collections_test_space_base_new (void);
static SerializableGeeCollectionsTestSpaceBase* serializable_gee_collections_test_space_base_construct (GType object_type);
static GType serializable_gee_collections_test_storage_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeCollectionsTestStorage* serializable_gee_collections_test_space_base_get_storage (SerializableGeeCollectionsTestSpaceBase* self);
GType serializable_gee_collections_test_refaction_collection_get_type (void) G_GNUC_CONST;
static SerializableGeeCollectionsTestRefactionCollection* serializable_gee_collections_test_storage_get_refactions (SerializableGeeCollectionsTestStorage* self);
static GType serializable_gee_collections_test_refaction_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
GType serializable_gee_collections_test_space_ship_collection_get_type (void) G_GNUC_CONST;
static SerializableGeeCollectionsTestSpaceShipCollection* serializable_gee_collections_test_refaction_get_spaceships (SerializableGeeCollectionsTestRefaction* self);
static GType serializable_gee_collections_test_space_ship_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static GType serializable_gee_collections_test_charge_zone_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeCollectionsTestChargeZone* serializable_gee_collections_test_space_base_get_charge_zone (SerializableGeeCollectionsTestSpaceBase* self);
static SerializableGeeCollectionsTestSpaceShipCollection* serializable_gee_collections_test_charge_zone_get_spaceships (SerializableGeeCollectionsTestChargeZone* self);
GType serializable_gee_collections_test_space_collection_get_type (void) G_GNUC_CONST;
static SerializableGeeCollectionsTestSpaceCollection* serializable_gee_collections_test_space_ship_get_spaces (SerializableGeeCollectionsTestSpaceShip* self);
static GType serializable_gee_collections_test_space_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
GType serializable_gee_collections_test_planet_collection_get_type (void) G_GNUC_CONST;
static SerializableGeeCollectionsTestPlanetCollection* serializable_gee_collections_test_space_get_planets (SerializableGeeCollectionsTestSpace* self);
static GType serializable_gee_collections_test_planet_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static void ___lambda319__gtest_func (void);
static void __lambda320_ (void);
static const gchar* serializable_gee_collections_test_space_ship_get_manufacturer (SerializableGeeCollectionsTestSpaceShip* self);
static void ___lambda320__gtest_func (void);
static void __lambda321_ (void);
static const gchar* serializable_gee_collections_test_space_base_get_name (SerializableGeeCollectionsTestSpaceBase* self);
static void ___lambda321__gtest_func (void);
static void __lambda322_ (void);
static GType serializable_gee_collections_test_big_bag_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeCollectionsTestBigBag* serializable_gee_collections_test_big_bag_new (void);
static SerializableGeeCollectionsTestBigBag* serializable_gee_collections_test_big_bag_construct (GType object_type);
GType serializable_gee_collections_test_small_bag_array_get_type (void) G_GNUC_CONST;
static SerializableGeeCollectionsTestSmallBagArray* serializable_gee_collections_test_big_bag_get_bags (SerializableGeeCollectionsTestBigBag* self);
static GType serializable_gee_collections_test_small_bag_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeCollectionsTestSmallBag* serializable_gee_collections_test_small_bag_new (void);
static SerializableGeeCollectionsTestSmallBag* serializable_gee_collections_test_small_bag_construct (GType object_type);
GType serializable_gee_collections_test_ball_array_get_type (void) G_GNUC_CONST;
static SerializableGeeCollectionsTestBallArray* serializable_gee_collections_test_small_bag_get_balls (SerializableGeeCollectionsTestSmallBag* self);
static GType serializable_gee_collections_test_ball_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeCollectionsTestBall* serializable_gee_collections_test_ball_new (void);
static SerializableGeeCollectionsTestBall* serializable_gee_collections_test_ball_construct (GType object_type);
static void ___lambda322__gtest_func (void);
SerializableGeeCollectionsTest* serializable_gee_collections_test_new (void);
SerializableGeeCollectionsTest* serializable_gee_collections_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static GType serializable_gee_collections_test_citizen_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static gboolean serializable_gee_collections_test_citizen_real_serialize_use_xml_node_value (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_collections_test_citizen_real_to_string (GXmlSerializableObjectModel* base);
static const gchar* serializable_gee_collections_test_citizen_get_ctype (SerializableGeeCollectionsTestCitizen* self);
static gchar* serializable_gee_collections_test_citizen_real_node_name (GXmlSerializableObjectModel* base);
static SerializableGeeCollectionsTestCitizen* serializable_gee_collections_test_citizen_new (void);
static SerializableGeeCollectionsTestCitizen* serializable_gee_collections_test_citizen_construct (GType object_type);
static void serializable_gee_collections_test_citizen_set_ctype (SerializableGeeCollectionsTestCitizen* self,
                                                          const gchar* value);
GType serializable_gee_collections_test_citizen_array_get_type (void) G_GNUC_CONST;
static SerializableGeeCollectionsTestCitizenArray* serializable_gee_collections_test_citizen_array_new (void);
static SerializableGeeCollectionsTestCitizenArray* serializable_gee_collections_test_citizen_array_construct (GType object_type);
static void serializable_gee_collections_test_citizen_finalize (GObject * obj);
static void _vala_serializable_gee_collections_test_citizen_get_property (GObject * object,
                                                                   guint property_id,
                                                                   GValue * value,
                                                                   GParamSpec * pspec);
static void _vala_serializable_gee_collections_test_citizen_set_property (GObject * object,
                                                                   guint property_id,
                                                                   const GValue * value,
                                                                   GParamSpec * pspec);
static GType serializable_gee_collections_test_asteroid_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeCollectionsTestAsteroid* serializable_gee_collections_test_asteroid_new_with_size (gint size);
static SerializableGeeCollectionsTestAsteroid* serializable_gee_collections_test_asteroid_construct_with_size (GType object_type,
                                                                                                        gint size);
static void serializable_gee_collections_test_asteroid_set_size (SerializableGeeCollectionsTestAsteroid* self,
                                                          gint value);
static gchar* serializable_gee_collections_test_asteroid_real_to_string (GXmlSerializableObjectModel* base);
static gint serializable_gee_collections_test_asteroid_get_size (SerializableGeeCollectionsTestAsteroid* self);
static gchar* serializable_gee_collections_test_asteroid_real_node_name (GXmlSerializableObjectModel* base);
static SerializableGeeCollectionsTestAsteroid* serializable_gee_collections_test_asteroid_new (void);
static SerializableGeeCollectionsTestAsteroid* serializable_gee_collections_test_asteroid_construct (GType object_type);
GType serializable_gee_collections_test_asteroid_array_get_type (void) G_GNUC_CONST;
static SerializableGeeCollectionsTestAsteroidArray* serializable_gee_collections_test_asteroid_array_new (void);
static SerializableGeeCollectionsTestAsteroidArray* serializable_gee_collections_test_asteroid_array_construct (GType object_type);
static void serializable_gee_collections_test_asteroid_finalize (GObject * obj);
static void _vala_serializable_gee_collections_test_asteroid_get_property (GObject * object,
                                                                    guint property_id,
                                                                    GValue * value,
                                                                    GParamSpec * pspec);
static void _vala_serializable_gee_collections_test_asteroid_set_property (GObject * object,
                                                                    guint property_id,
                                                                    const GValue * value,
                                                                    GParamSpec * pspec);
static gchar* serializable_gee_collections_test_planet_real_get_map_key (GXmlSerializableMapKey* base);
static const gchar* serializable_gee_collections_test_planet_get_name (SerializableGeeCollectionsTestPlanet* self);
static SerializableGeeCollectionsTestPlanet* serializable_gee_collections_test_planet_new_named (const gchar* name);
static SerializableGeeCollectionsTestPlanet* serializable_gee_collections_test_planet_construct_named (GType object_type,
                                                                                                const gchar* name);
static void serializable_gee_collections_test_planet_set_name (SerializableGeeCollectionsTestPlanet* self,
                                                        const gchar* value);
static gchar* serializable_gee_collections_test_planet_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_collections_test_planet_real_to_string (GXmlSerializableObjectModel* base);
static void serializable_gee_collections_test_planet_real_init_containers (GXmlSerializableContainer* base);
static SerializableGeeCollectionsTestCitizenArray* serializable_gee_collections_test_planet_get_citizens (SerializableGeeCollectionsTestPlanet* self);
static void serializable_gee_collections_test_planet_set_citizens (SerializableGeeCollectionsTestPlanet* self,
                                                            SerializableGeeCollectionsTestCitizenArray* value);
static SerializableGeeCollectionsTestPlanet* serializable_gee_collections_test_planet_new (void);
static SerializableGeeCollectionsTestPlanet* serializable_gee_collections_test_planet_construct (GType object_type);
static SerializableGeeCollectionsTestPlanetCollection* serializable_gee_collections_test_planet_collection_new (void);
static SerializableGeeCollectionsTestPlanetCollection* serializable_gee_collections_test_planet_collection_construct (GType object_type);
static void serializable_gee_collections_test_planet_finalize (GObject * obj);
static void _vala_serializable_gee_collections_test_planet_get_property (GObject * object,
                                                                  guint property_id,
                                                                  GValue * value,
                                                                  GParamSpec * pspec);
static void _vala_serializable_gee_collections_test_planet_set_property (GObject * object,
                                                                  guint property_id,
                                                                  const GValue * value,
                                                                  GParamSpec * pspec);
static gchar* serializable_gee_collections_test_space_real_get_map_key (GXmlSerializableMapKey* base);
static const gchar* serializable_gee_collections_test_space_get_name (SerializableGeeCollectionsTestSpace* self);
static SerializableGeeCollectionsTestSpace* serializable_gee_collections_test_space_new_named (const gchar* name);
static SerializableGeeCollectionsTestSpace* serializable_gee_collections_test_space_construct_named (GType object_type,
                                                                                              const gchar* name);
static void serializable_gee_collections_test_space_set_name (SerializableGeeCollectionsTestSpace* self,
                                                       const gchar* value);
static gchar* serializable_gee_collections_test_space_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_collections_test_space_real_to_string (GXmlSerializableObjectModel* base);
static void serializable_gee_collections_test_space_real_init_containers (GXmlSerializableContainer* base);
static SerializableGeeCollectionsTestAsteroidArray* serializable_gee_collections_test_space_get_asteroids (SerializableGeeCollectionsTestSpace* self);
static void serializable_gee_collections_test_space_set_asteroids (SerializableGeeCollectionsTestSpace* self,
                                                            SerializableGeeCollectionsTestAsteroidArray* value);
static void serializable_gee_collections_test_space_set_planets (SerializableGeeCollectionsTestSpace* self,
                                                          SerializableGeeCollectionsTestPlanetCollection* value);
static SerializableGeeCollectionsTestSpace* serializable_gee_collections_test_space_new (void);
static SerializableGeeCollectionsTestSpace* serializable_gee_collections_test_space_construct (GType object_type);
static SerializableGeeCollectionsTestSpaceCollection* serializable_gee_collections_test_space_collection_new (void);
static SerializableGeeCollectionsTestSpaceCollection* serializable_gee_collections_test_space_collection_construct (GType object_type);
static void serializable_gee_collections_test_space_finalize (GObject * obj);
static void _vala_serializable_gee_collections_test_space_get_property (GObject * object,
                                                                 guint property_id,
                                                                 GValue * value,
                                                                 GParamSpec * pspec);
static void _vala_serializable_gee_collections_test_space_set_property (GObject * object,
                                                                 guint property_id,
                                                                 const GValue * value,
                                                                 GParamSpec * pspec);
static SerializableGeeCollectionsTestRefaction* serializable_gee_collections_test_refaction_new_named (const gchar* manufacturer,
                                                                                                const gchar* model);
static SerializableGeeCollectionsTestRefaction* serializable_gee_collections_test_refaction_construct_named (GType object_type,
                                                                                                      const gchar* manufacturer,
                                                                                                      const gchar* model);
static void serializable_gee_collections_test_refaction_set_manufacturer (SerializableGeeCollectionsTestRefaction* self,
                                                                   const gchar* value);
static void serializable_gee_collections_test_refaction_set_model (SerializableGeeCollectionsTestRefaction* self,
                                                            const gchar* value);
static gchar* serializable_gee_collections_test_refaction_real_get_map_primary_key (GXmlSerializableMapDualKey* base);
static const gchar* serializable_gee_collections_test_refaction_get_manufacturer (SerializableGeeCollectionsTestRefaction* self);
static gchar* serializable_gee_collections_test_refaction_real_get_map_secondary_key (GXmlSerializableMapDualKey* base);
static const gchar* serializable_gee_collections_test_refaction_get_model (SerializableGeeCollectionsTestRefaction* self);
static gchar* serializable_gee_collections_test_refaction_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_collections_test_refaction_real_to_string (GXmlSerializableObjectModel* base);
static gboolean serializable_gee_collections_test_refaction_real_get_enable_unknown_serializable_property (GXmlSerializableObjectModel* base);
static void serializable_gee_collections_test_refaction_real_init_containers (GXmlSerializableContainer* base);
static SerializableGeeCollectionsTestSpaceShipCollection* serializable_gee_collections_test_space_ship_collection_new (void);
static SerializableGeeCollectionsTestSpaceShipCollection* serializable_gee_collections_test_space_ship_collection_construct (GType object_type);
static void serializable_gee_collections_test_refaction_set_spaceships (SerializableGeeCollectionsTestRefaction* self,
                                                                 SerializableGeeCollectionsTestSpaceShipCollection* value);
static SerializableGeeCollectionsTestRefaction* serializable_gee_collections_test_refaction_new (void);
static SerializableGeeCollectionsTestRefaction* serializable_gee_collections_test_refaction_construct (GType object_type);
static SerializableGeeCollectionsTestRefactionCollection* serializable_gee_collections_test_refaction_collection_new (void);
static SerializableGeeCollectionsTestRefactionCollection* serializable_gee_collections_test_refaction_collection_construct (GType object_type);
static void serializable_gee_collections_test_refaction_finalize (GObject * obj);
static void _vala_serializable_gee_collections_test_refaction_get_property (GObject * object,
                                                                     guint property_id,
                                                                     GValue * value,
                                                                     GParamSpec * pspec);
static void _vala_serializable_gee_collections_test_refaction_set_property (GObject * object,
                                                                     guint property_id,
                                                                     const GValue * value,
                                                                     GParamSpec * pspec);
static SerializableGeeCollectionsTestSpaceShip* serializable_gee_collections_test_space_ship_new_named (const gchar* manufacturer,
                                                                                                 const gchar* model);
static SerializableGeeCollectionsTestSpaceShip* serializable_gee_collections_test_space_ship_construct_named (GType object_type,
                                                                                                       const gchar* manufacturer,
                                                                                                       const gchar* model);
static void serializable_gee_collections_test_space_ship_set_manufacturer (SerializableGeeCollectionsTestSpaceShip* self,
                                                                    const gchar* value);
static void serializable_gee_collections_test_space_ship_set_model (SerializableGeeCollectionsTestSpaceShip* self,
                                                             const gchar* value);
static gchar* serializable_gee_collections_test_space_ship_real_get_map_primary_key (GXmlSerializableMapDualKey* base);
static gchar* serializable_gee_collections_test_space_ship_real_get_map_secondary_key (GXmlSerializableMapDualKey* base);
static const gchar* serializable_gee_collections_test_space_ship_get_model (SerializableGeeCollectionsTestSpaceShip* self);
static gchar* serializable_gee_collections_test_space_ship_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_collections_test_space_ship_real_to_string (GXmlSerializableObjectModel* base);
static gboolean serializable_gee_collections_test_space_ship_real_get_enable_unknown_serializable_property (GXmlSerializableObjectModel* base);
static void serializable_gee_collections_test_space_ship_real_init_containers (GXmlSerializableContainer* base);
static void serializable_gee_collections_test_space_ship_set_spaces (SerializableGeeCollectionsTestSpaceShip* self,
                                                              SerializableGeeCollectionsTestSpaceCollection* value);
static SerializableGeeCollectionsTestSpaceShip* serializable_gee_collections_test_space_ship_new (void);
static SerializableGeeCollectionsTestSpaceShip* serializable_gee_collections_test_space_ship_construct (GType object_type);
static void serializable_gee_collections_test_space_ship_finalize (GObject * obj);
static void _vala_serializable_gee_collections_test_space_ship_get_property (GObject * object,
                                                                      guint property_id,
                                                                      GValue * value,
                                                                      GParamSpec * pspec);
static void _vala_serializable_gee_collections_test_space_ship_set_property (GObject * object,
                                                                      guint property_id,
                                                                      const GValue * value,
                                                                      GParamSpec * pspec);
static gchar* serializable_gee_collections_test_charge_zone_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_collections_test_charge_zone_real_to_string (GXmlSerializableObjectModel* base);
static const gchar* serializable_gee_collections_test_charge_zone_get_name (SerializableGeeCollectionsTestChargeZone* self);
static void serializable_gee_collections_test_charge_zone_real_init_containers (GXmlSerializableContainer* base);
static void serializable_gee_collections_test_charge_zone_set_spaceships (SerializableGeeCollectionsTestChargeZone* self,
                                                                   SerializableGeeCollectionsTestSpaceShipCollection* value);
static SerializableGeeCollectionsTestChargeZone* serializable_gee_collections_test_charge_zone_new (void);
static SerializableGeeCollectionsTestChargeZone* serializable_gee_collections_test_charge_zone_construct (GType object_type);
static void serializable_gee_collections_test_charge_zone_set_name (SerializableGeeCollectionsTestChargeZone* self,
                                                             const gchar* value);
static void serializable_gee_collections_test_charge_zone_finalize (GObject * obj);
static void _vala_serializable_gee_collections_test_charge_zone_get_property (GObject * object,
                                                                       guint property_id,
                                                                       GValue * value,
                                                                       GParamSpec * pspec);
static void _vala_serializable_gee_collections_test_charge_zone_set_property (GObject * object,
                                                                       guint property_id,
                                                                       const GValue * value,
                                                                       GParamSpec * pspec);
static gchar* serializable_gee_collections_test_storage_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_collections_test_storage_real_to_string (GXmlSerializableObjectModel* base);
static const gchar* serializable_gee_collections_test_storage_get_name (SerializableGeeCollectionsTestStorage* self);
static void serializable_gee_collections_test_storage_real_init_containers (GXmlSerializableContainer* base);
static void serializable_gee_collections_test_storage_set_refactions (SerializableGeeCollectionsTestStorage* self,
                                                               SerializableGeeCollectionsTestRefactionCollection* value);
static SerializableGeeCollectionsTestStorage* serializable_gee_collections_test_storage_new (void);
static SerializableGeeCollectionsTestStorage* serializable_gee_collections_test_storage_construct (GType object_type);
static void serializable_gee_collections_test_storage_set_name (SerializableGeeCollectionsTestStorage* self,
                                                         const gchar* value);
static void serializable_gee_collections_test_storage_finalize (GObject * obj);
static void _vala_serializable_gee_collections_test_storage_get_property (GObject * object,
                                                                   guint property_id,
                                                                   GValue * value,
                                                                   GParamSpec * pspec);
static void _vala_serializable_gee_collections_test_storage_set_property (GObject * object,
                                                                   guint property_id,
                                                                   const GValue * value,
                                                                   GParamSpec * pspec);
static gchar* serializable_gee_collections_test_space_base_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_collections_test_space_base_real_to_string (GXmlSerializableObjectModel* base);
static void serializable_gee_collections_test_space_base_set_name (SerializableGeeCollectionsTestSpaceBase* self,
                                                            const gchar* value);
static void serializable_gee_collections_test_space_base_set_charge_zone (SerializableGeeCollectionsTestSpaceBase* self,
                                                                   SerializableGeeCollectionsTestChargeZone* value);
static void serializable_gee_collections_test_space_base_set_storage (SerializableGeeCollectionsTestSpaceBase* self,
                                                               SerializableGeeCollectionsTestStorage* value);
static void serializable_gee_collections_test_space_base_finalize (GObject * obj);
static void _vala_serializable_gee_collections_test_space_base_get_property (GObject * object,
                                                                      guint property_id,
                                                                      GValue * value,
                                                                      GParamSpec * pspec);
static void _vala_serializable_gee_collections_test_space_base_set_property (GObject * object,
                                                                      guint property_id,
                                                                      const GValue * value,
                                                                      GParamSpec * pspec);
static GType serializable_gee_collections_test_ball_fill_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static gchar* serializable_gee_collections_test_ball_fill_real_to_string (GXmlSerializableObjectModel* base);
static const gchar* serializable_gee_collections_test_ball_fill_get_name (SerializableGeeCollectionsTestBallFill* self);
static gchar* serializable_gee_collections_test_ball_fill_real_node_name (GXmlSerializableObjectModel* base);
static gboolean serializable_gee_collections_test_ball_fill_real_serialize_use_xml_node_value (GXmlSerializableObjectModel* base);
static SerializableGeeCollectionsTestBallFill* serializable_gee_collections_test_ball_fill_new (void);
static SerializableGeeCollectionsTestBallFill* serializable_gee_collections_test_ball_fill_construct (GType object_type);
static void serializable_gee_collections_test_ball_fill_set_name (SerializableGeeCollectionsTestBallFill* self,
                                                           const gchar* value);
static void serializable_gee_collections_test_ball_fill_finalize (GObject * obj);
static void _vala_serializable_gee_collections_test_ball_fill_get_property (GObject * object,
                                                                     guint property_id,
                                                                     GValue * value,
                                                                     GParamSpec * pspec);
static void _vala_serializable_gee_collections_test_ball_fill_set_property (GObject * object,
                                                                     guint property_id,
                                                                     const GValue * value,
                                                                     GParamSpec * pspec);
static gchar* serializable_gee_collections_test_ball_real_to_string (GXmlSerializableObjectModel* base);
static const gchar* serializable_gee_collections_test_ball_get_name (SerializableGeeCollectionsTestBall* self);
static gchar* serializable_gee_collections_test_ball_real_node_name (GXmlSerializableObjectModel* base);
static void serializable_gee_collections_test_ball_set_name (SerializableGeeCollectionsTestBall* self,
                                                      const gchar* value);
static SerializableGeeCollectionsTestBallFill* serializable_gee_collections_test_ball_get_ballfill (SerializableGeeCollectionsTestBall* self);
static void serializable_gee_collections_test_ball_set_ballfill (SerializableGeeCollectionsTestBall* self,
                                                          SerializableGeeCollectionsTestBallFill* value);
static gboolean serializable_gee_collections_test_ball_array_real_deserialize_proceed (GXmlSerializableArrayList* base);
static SerializableGeeCollectionsTestBallArray* serializable_gee_collections_test_ball_array_new (void);
static SerializableGeeCollectionsTestBallArray* serializable_gee_collections_test_ball_array_construct (GType object_type);
static void serializable_gee_collections_test_ball_finalize (GObject * obj);
static void _vala_serializable_gee_collections_test_ball_get_property (GObject * object,
                                                                guint property_id,
                                                                GValue * value,
                                                                GParamSpec * pspec);
static void _vala_serializable_gee_collections_test_ball_set_property (GObject * object,
                                                                guint property_id,
                                                                const GValue * value,
                                                                GParamSpec * pspec);
static gchar* serializable_gee_collections_test_small_bag_real_to_string (GXmlSerializableObjectModel* base);
static const gchar* serializable_gee_collections_test_small_bag_get_name (SerializableGeeCollectionsTestSmallBag* self);
static gchar* serializable_gee_collections_test_small_bag_real_node_name (GXmlSerializableObjectModel* base);
static void serializable_gee_collections_test_small_bag_set_name (SerializableGeeCollectionsTestSmallBag* self,
                                                           const gchar* value);
static void serializable_gee_collections_test_small_bag_set_balls (SerializableGeeCollectionsTestSmallBag* self,
                                                            SerializableGeeCollectionsTestBallArray* value);
static gboolean serializable_gee_collections_test_small_bag_array_real_deserialize_proceed (GXmlSerializableArrayList* base);
static SerializableGeeCollectionsTestSmallBagArray* serializable_gee_collections_test_small_bag_array_new (void);
static SerializableGeeCollectionsTestSmallBagArray* serializable_gee_collections_test_small_bag_array_construct (GType object_type);
static void serializable_gee_collections_test_small_bag_finalize (GObject * obj);
static void _vala_serializable_gee_collections_test_small_bag_get_property (GObject * object,
                                                                     guint property_id,
                                                                     GValue * value,
                                                                     GParamSpec * pspec);
static void _vala_serializable_gee_collections_test_small_bag_set_property (GObject * object,
                                                                     guint property_id,
                                                                     const GValue * value,
                                                                     GParamSpec * pspec);
static gchar* serializable_gee_collections_test_big_bag_real_to_string (GXmlSerializableObjectModel* base);
static const gchar* serializable_gee_collections_test_big_bag_get_name (SerializableGeeCollectionsTestBigBag* self);
static gchar* serializable_gee_collections_test_big_bag_real_node_name (GXmlSerializableObjectModel* base);
static void serializable_gee_collections_test_big_bag_set_name (SerializableGeeCollectionsTestBigBag* self,
                                                         const gchar* value);
static void serializable_gee_collections_test_big_bag_set_bags (SerializableGeeCollectionsTestBigBag* self,
                                                         SerializableGeeCollectionsTestSmallBagArray* value);
static void serializable_gee_collections_test_big_bag_finalize (GObject * obj);
static void _vala_serializable_gee_collections_test_big_bag_get_property (GObject * object,
                                                                   guint property_id,
                                                                   GValue * value,
                                                                   GParamSpec * pspec);
static void _vala_serializable_gee_collections_test_big_bag_set_property (GObject * object,
                                                                   guint property_id,
                                                                   const GValue * value,
                                                                   GParamSpec * pspec);

static gpointer
_g_object_ref0 (gpointer self)
{
#line 246 "SerializableGeeCollectionsTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 1079 "SerializableGeeCollectionsTest.c"
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result = NULL;
#line 1516 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1517 "glib-2.0.vapi"
	result = self;
#line 1517 "glib-2.0.vapi"
	return result;
#line 1092 "SerializableGeeCollectionsTest.c"
}

static void
__lambda319_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		SerializableGeeCollectionsTestSpaceBase* b = NULL;
		SerializableGeeCollectionsTestSpaceBase* _tmp1_;
		SerializableGeeCollectionsTestSpaceBase* _tmp2_;
		GXmlGDocument* _tmp3_;
		SerializableGeeCollectionsTestSpaceBase* _tmp4_;
		SerializableGeeCollectionsTestStorage* _tmp5_;
		SerializableGeeCollectionsTestStorage* _tmp6_;
		SerializableGeeCollectionsTestStorage* storage = NULL;
		SerializableGeeCollectionsTestSpaceBase* _tmp13_;
		SerializableGeeCollectionsTestStorage* _tmp14_;
		SerializableGeeCollectionsTestStorage* _tmp15_;
		SerializableGeeCollectionsTestStorage* _tmp16_;
		SerializableGeeCollectionsTestRefactionCollection* _tmp17_;
		SerializableGeeCollectionsTestRefactionCollection* _tmp18_;
		SerializableGeeCollectionsTestRefactionCollection* _tmp25_;
		SerializableGeeCollectionsTestRefactionCollection* _tmp26_;
		gint _tmp27_;
		gint _tmp28_;
		SerializableGeeCollectionsTestRefaction* refaction = NULL;
		SerializableGeeCollectionsTestRefactionCollection* _tmp41_;
		SerializableGeeCollectionsTestRefactionCollection* _tmp42_;
		gpointer _tmp43_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp50_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp51_;
		gint _tmp52_;
		gint _tmp53_;
		SerializableGeeCollectionsTestSpaceShip* ship1 = NULL;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp66_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp67_;
		gpointer _tmp68_;
		SerializableGeeCollectionsTestSpaceShip* ship2 = NULL;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp75_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp76_;
		gpointer _tmp77_;
		SerializableGeeCollectionsTestSpaceBase* _tmp84_;
		SerializableGeeCollectionsTestChargeZone* _tmp85_;
		SerializableGeeCollectionsTestChargeZone* _tmp86_;
		SerializableGeeCollectionsTestChargeZone* charge = NULL;
		SerializableGeeCollectionsTestSpaceBase* _tmp93_;
		SerializableGeeCollectionsTestChargeZone* _tmp94_;
		SerializableGeeCollectionsTestChargeZone* _tmp95_;
		SerializableGeeCollectionsTestChargeZone* _tmp96_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp97_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp98_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp105_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp106_;
		gint _tmp107_;
		gint _tmp108_;
		SerializableGeeCollectionsTestSpaceShip* ship = NULL;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp121_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp122_;
		gpointer _tmp123_;
		SerializableGeeCollectionsTestSpaceCollection* _tmp130_;
		SerializableGeeCollectionsTestSpaceCollection* _tmp131_;
		gint _tmp132_;
		gint _tmp133_;
		SerializableGeeCollectionsTestSpace* space = NULL;
		SerializableGeeCollectionsTestSpaceCollection* _tmp146_;
		SerializableGeeCollectionsTestSpaceCollection* _tmp147_;
		gpointer _tmp148_;
		SerializableGeeCollectionsTestPlanetCollection* _tmp155_;
		SerializableGeeCollectionsTestPlanetCollection* _tmp156_;
		gint _tmp157_;
		gint _tmp158_;
		SerializableGeeCollectionsTestPlanet* earth = NULL;
		SerializableGeeCollectionsTestPlanetCollection* _tmp171_;
		SerializableGeeCollectionsTestPlanetCollection* _tmp172_;
		gpointer _tmp173_;
		SerializableGeeCollectionsTestPlanet* platon = NULL;
		SerializableGeeCollectionsTestPlanetCollection* _tmp180_;
		SerializableGeeCollectionsTestPlanetCollection* _tmp181_;
		gpointer _tmp182_;
#line 222 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"<base name=\"AlphaOne\" >\n" \
"  <chargezone name=\"A1-1\">\n" \
"    <ship manufacturer=\"MacToy\" model=\"A1234\">\n" \
"      <space name=\"Alpha Centaury\">\n" \
"        <planet name=\"Earth\" />\n" \
"        <planet name=\"Platon\" />\n" \
"      </space>\n" \
"    </ship>\n" \
"  </chargezone>\n" \
"  <storage name=\"B4-A4\">\n" \
"    <refaction manufacturer=\"MacToy\" model=\"Fly045\">\n" \
"      <ship manufacturer=\"MacToy\" model=\"A1234\" />\n" \
"      <ship manufacturer=\"MegaTrench\" model=\"G045-1\" />\n" \
"    </refaction>\n" \
"  </storage>\n" \
"</base>", 0, &_inner_error0_);
#line 222 "SerializableGeeCollectionsTest.vala"
		doc = _tmp0_;
#line 222 "SerializableGeeCollectionsTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1180 "SerializableGeeCollectionsTest.c"
			goto __catch369_g_error;
		}
#line 239 "SerializableGeeCollectionsTest.vala"
		_tmp1_ = serializable_gee_collections_test_space_base_new ();
#line 239 "SerializableGeeCollectionsTest.vala"
		b = _tmp1_;
#line 240 "SerializableGeeCollectionsTest.vala"
		_tmp2_ = b;
#line 240 "SerializableGeeCollectionsTest.vala"
		_tmp3_ = doc;
#line 240 "SerializableGeeCollectionsTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 240 "SerializableGeeCollectionsTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 240 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (b);
#line 240 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (doc);
#line 1199 "SerializableGeeCollectionsTest.c"
			goto __catch369_g_error;
		}
#line 242 "SerializableGeeCollectionsTest.vala"
		_tmp4_ = b;
#line 242 "SerializableGeeCollectionsTest.vala"
		_tmp5_ = serializable_gee_collections_test_space_base_get_storage (_tmp4_);
#line 242 "SerializableGeeCollectionsTest.vala"
		_tmp6_ = _tmp5_;
#line 242 "SerializableGeeCollectionsTest.vala"
		if (_tmp6_ == NULL) {
#line 1210 "SerializableGeeCollectionsTest.c"
			FILE* _tmp7_;
			GXmlGDocument* _tmp8_;
			gchar* _tmp9_;
			gchar* _tmp10_;
			gchar* _tmp11_;
			gchar* _tmp12_;
#line 243 "SerializableGeeCollectionsTest.vala"
			_tmp7_ = stdout;
#line 243 "SerializableGeeCollectionsTest.vala"
			_tmp8_ = doc;
#line 243 "SerializableGeeCollectionsTest.vala"
			_tmp9_ = gxml_gnode_to_string ((GXmlGNode*) _tmp8_);
#line 243 "SerializableGeeCollectionsTest.vala"
			_tmp10_ = _tmp9_;
#line 243 "SerializableGeeCollectionsTest.vala"
			_tmp11_ = g_strconcat ("ERROR: no storage exists:\n", _tmp10_, "\n", NULL);
#line 243 "SerializableGeeCollectionsTest.vala"
			_tmp12_ = _tmp11_;
#line 243 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp7_, "%s", _tmp12_);
#line 243 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp12_);
#line 243 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp10_);
#line 244 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 1237 "SerializableGeeCollectionsTest.c"
		}
#line 246 "SerializableGeeCollectionsTest.vala"
		_tmp13_ = b;
#line 246 "SerializableGeeCollectionsTest.vala"
		_tmp14_ = serializable_gee_collections_test_space_base_get_storage (_tmp13_);
#line 246 "SerializableGeeCollectionsTest.vala"
		_tmp15_ = _tmp14_;
#line 246 "SerializableGeeCollectionsTest.vala"
		_tmp16_ = _g_object_ref0 (_tmp15_);
#line 246 "SerializableGeeCollectionsTest.vala"
		storage = _tmp16_;
#line 247 "SerializableGeeCollectionsTest.vala"
		_tmp17_ = serializable_gee_collections_test_storage_get_refactions (storage);
#line 247 "SerializableGeeCollectionsTest.vala"
		_tmp18_ = _tmp17_;
#line 247 "SerializableGeeCollectionsTest.vala"
		if (_tmp18_ == NULL) {
#line 1255 "SerializableGeeCollectionsTest.c"
			FILE* _tmp19_;
			GXmlGDocument* _tmp20_;
			gchar* _tmp21_;
			gchar* _tmp22_;
			gchar* _tmp23_;
			gchar* _tmp24_;
#line 248 "SerializableGeeCollectionsTest.vala"
			_tmp19_ = stdout;
#line 248 "SerializableGeeCollectionsTest.vala"
			_tmp20_ = doc;
#line 248 "SerializableGeeCollectionsTest.vala"
			_tmp21_ = gxml_gnode_to_string ((GXmlGNode*) _tmp20_);
#line 248 "SerializableGeeCollectionsTest.vala"
			_tmp22_ = _tmp21_;
#line 248 "SerializableGeeCollectionsTest.vala"
			_tmp23_ = g_strconcat ("ERROR: no refactions exists:\n", _tmp22_, "\n", NULL);
#line 248 "SerializableGeeCollectionsTest.vala"
			_tmp24_ = _tmp23_;
#line 248 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp19_, "%s", _tmp24_);
#line 248 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp24_);
#line 248 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp22_);
#line 249 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 1282 "SerializableGeeCollectionsTest.c"
		}
#line 251 "SerializableGeeCollectionsTest.vala"
		_tmp25_ = serializable_gee_collections_test_storage_get_refactions (storage);
#line 251 "SerializableGeeCollectionsTest.vala"
		_tmp26_ = _tmp25_;
#line 251 "SerializableGeeCollectionsTest.vala"
		_tmp27_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp26_);
#line 251 "SerializableGeeCollectionsTest.vala"
		_tmp28_ = _tmp27_;
#line 251 "SerializableGeeCollectionsTest.vala"
		if (_tmp28_ != 1) {
#line 1294 "SerializableGeeCollectionsTest.c"
			FILE* _tmp29_;
			SerializableGeeCollectionsTestRefactionCollection* _tmp30_;
			SerializableGeeCollectionsTestRefactionCollection* _tmp31_;
			gint _tmp32_;
			gint _tmp33_;
			gchar* _tmp34_;
			gchar* _tmp35_;
			GXmlGDocument* _tmp36_;
			gchar* _tmp37_;
			gchar* _tmp38_;
			gchar* _tmp39_;
			gchar* _tmp40_;
#line 252 "SerializableGeeCollectionsTest.vala"
			_tmp29_ = stdout;
#line 252 "SerializableGeeCollectionsTest.vala"
			_tmp30_ = serializable_gee_collections_test_storage_get_refactions (storage);
#line 252 "SerializableGeeCollectionsTest.vala"
			_tmp31_ = _tmp30_;
#line 252 "SerializableGeeCollectionsTest.vala"
			_tmp32_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp31_);
#line 252 "SerializableGeeCollectionsTest.vala"
			_tmp33_ = _tmp32_;
#line 252 "SerializableGeeCollectionsTest.vala"
			_tmp34_ = g_strdup_printf ("%i", _tmp33_);
#line 252 "SerializableGeeCollectionsTest.vala"
			_tmp35_ = _tmp34_;
#line 252 "SerializableGeeCollectionsTest.vala"
			_tmp36_ = doc;
#line 252 "SerializableGeeCollectionsTest.vala"
			_tmp37_ = gxml_gnode_to_string ((GXmlGNode*) _tmp36_);
#line 252 "SerializableGeeCollectionsTest.vala"
			_tmp38_ = _tmp37_;
#line 252 "SerializableGeeCollectionsTest.vala"
			_tmp39_ = g_strconcat ("ERROR: Storage: incorrect size must be 1 got : ", _tmp35_, "\n", _tmp38_, "\n", NULL);
#line 252 "SerializableGeeCollectionsTest.vala"
			_tmp40_ = _tmp39_;
#line 252 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp29_, "%s", _tmp40_);
#line 252 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp40_);
#line 252 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp38_);
#line 252 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp35_);
#line 253 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 1341 "SerializableGeeCollectionsTest.c"
		}
#line 255 "SerializableGeeCollectionsTest.vala"
		_tmp41_ = serializable_gee_collections_test_storage_get_refactions (storage);
#line 255 "SerializableGeeCollectionsTest.vala"
		_tmp42_ = _tmp41_;
#line 255 "SerializableGeeCollectionsTest.vala"
		_tmp43_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp42_, "MacToy", "Fly045");
#line 255 "SerializableGeeCollectionsTest.vala"
		refaction = (SerializableGeeCollectionsTestRefaction*) _tmp43_;
#line 256 "SerializableGeeCollectionsTest.vala"
		if (refaction == NULL) {
#line 1353 "SerializableGeeCollectionsTest.c"
			FILE* _tmp44_;
			GXmlGDocument* _tmp45_;
			gchar* _tmp46_;
			gchar* _tmp47_;
			gchar* _tmp48_;
			gchar* _tmp49_;
#line 257 "SerializableGeeCollectionsTest.vala"
			_tmp44_ = stdout;
#line 257 "SerializableGeeCollectionsTest.vala"
			_tmp45_ = doc;
#line 257 "SerializableGeeCollectionsTest.vala"
			_tmp46_ = gxml_gnode_to_string ((GXmlGNode*) _tmp45_);
#line 257 "SerializableGeeCollectionsTest.vala"
			_tmp47_ = _tmp46_;
#line 257 "SerializableGeeCollectionsTest.vala"
			_tmp48_ = g_strconcat ("ERROR: no refaction MacToy / Fly045 exists:\n", _tmp47_, "\n", NULL);
#line 257 "SerializableGeeCollectionsTest.vala"
			_tmp49_ = _tmp48_;
#line 257 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp44_, "%s", _tmp49_);
#line 257 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp49_);
#line 257 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp47_);
#line 258 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 1380 "SerializableGeeCollectionsTest.c"
		}
#line 260 "SerializableGeeCollectionsTest.vala"
		_tmp50_ = serializable_gee_collections_test_refaction_get_spaceships (refaction);
#line 260 "SerializableGeeCollectionsTest.vala"
		_tmp51_ = _tmp50_;
#line 260 "SerializableGeeCollectionsTest.vala"
		_tmp52_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp51_);
#line 260 "SerializableGeeCollectionsTest.vala"
		_tmp53_ = _tmp52_;
#line 260 "SerializableGeeCollectionsTest.vala"
		if (_tmp53_ != 2) {
#line 1392 "SerializableGeeCollectionsTest.c"
			FILE* _tmp54_;
			SerializableGeeCollectionsTestSpaceShipCollection* _tmp55_;
			SerializableGeeCollectionsTestSpaceShipCollection* _tmp56_;
			gint _tmp57_;
			gint _tmp58_;
			gchar* _tmp59_;
			gchar* _tmp60_;
			GXmlGDocument* _tmp61_;
			gchar* _tmp62_;
			gchar* _tmp63_;
			gchar* _tmp64_;
			gchar* _tmp65_;
#line 261 "SerializableGeeCollectionsTest.vala"
			_tmp54_ = stdout;
#line 261 "SerializableGeeCollectionsTest.vala"
			_tmp55_ = serializable_gee_collections_test_refaction_get_spaceships (refaction);
#line 261 "SerializableGeeCollectionsTest.vala"
			_tmp56_ = _tmp55_;
#line 261 "SerializableGeeCollectionsTest.vala"
			_tmp57_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp56_);
#line 261 "SerializableGeeCollectionsTest.vala"
			_tmp58_ = _tmp57_;
#line 261 "SerializableGeeCollectionsTest.vala"
			_tmp59_ = g_strdup_printf ("%i", _tmp58_);
#line 261 "SerializableGeeCollectionsTest.vala"
			_tmp60_ = _tmp59_;
#line 261 "SerializableGeeCollectionsTest.vala"
			_tmp61_ = doc;
#line 261 "SerializableGeeCollectionsTest.vala"
			_tmp62_ = gxml_gnode_to_string ((GXmlGNode*) _tmp61_);
#line 261 "SerializableGeeCollectionsTest.vala"
			_tmp63_ = _tmp62_;
#line 261 "SerializableGeeCollectionsTest.vala"
			_tmp64_ = g_strconcat ("ERROR: Refaction: incorrect size must be 2 got : ", _tmp60_, "\n", _tmp63_, "\n", NULL);
#line 261 "SerializableGeeCollectionsTest.vala"
			_tmp65_ = _tmp64_;
#line 261 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp54_, "%s", _tmp65_);
#line 261 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp65_);
#line 261 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp63_);
#line 261 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp60_);
#line 262 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 1439 "SerializableGeeCollectionsTest.c"
		}
#line 264 "SerializableGeeCollectionsTest.vala"
		_tmp66_ = serializable_gee_collections_test_refaction_get_spaceships (refaction);
#line 264 "SerializableGeeCollectionsTest.vala"
		_tmp67_ = _tmp66_;
#line 264 "SerializableGeeCollectionsTest.vala"
		_tmp68_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp67_, "MacToy", "A1234");
#line 264 "SerializableGeeCollectionsTest.vala"
		ship1 = (SerializableGeeCollectionsTestSpaceShip*) _tmp68_;
#line 265 "SerializableGeeCollectionsTest.vala"
		if (ship1 == NULL) {
#line 1451 "SerializableGeeCollectionsTest.c"
			FILE* _tmp69_;
			GXmlGDocument* _tmp70_;
			gchar* _tmp71_;
			gchar* _tmp72_;
			gchar* _tmp73_;
			gchar* _tmp74_;
#line 266 "SerializableGeeCollectionsTest.vala"
			_tmp69_ = stdout;
#line 266 "SerializableGeeCollectionsTest.vala"
			_tmp70_ = doc;
#line 266 "SerializableGeeCollectionsTest.vala"
			_tmp71_ = gxml_gnode_to_string ((GXmlGNode*) _tmp70_);
#line 266 "SerializableGeeCollectionsTest.vala"
			_tmp72_ = _tmp71_;
#line 266 "SerializableGeeCollectionsTest.vala"
			_tmp73_ = g_strconcat ("ERROR: no refaction for Ship MacToy / A1234 exists:\n", _tmp72_, "\n", NULL);
#line 266 "SerializableGeeCollectionsTest.vala"
			_tmp74_ = _tmp73_;
#line 266 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp69_, "%s", _tmp74_);
#line 266 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp74_);
#line 266 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp72_);
#line 267 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 1478 "SerializableGeeCollectionsTest.c"
		}
#line 269 "SerializableGeeCollectionsTest.vala"
		_tmp75_ = serializable_gee_collections_test_refaction_get_spaceships (refaction);
#line 269 "SerializableGeeCollectionsTest.vala"
		_tmp76_ = _tmp75_;
#line 269 "SerializableGeeCollectionsTest.vala"
		_tmp77_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp76_, "MegaTrench", "G045-1");
#line 269 "SerializableGeeCollectionsTest.vala"
		ship2 = (SerializableGeeCollectionsTestSpaceShip*) _tmp77_;
#line 270 "SerializableGeeCollectionsTest.vala"
		if (ship2 == NULL) {
#line 1490 "SerializableGeeCollectionsTest.c"
			FILE* _tmp78_;
			GXmlGDocument* _tmp79_;
			gchar* _tmp80_;
			gchar* _tmp81_;
			gchar* _tmp82_;
			gchar* _tmp83_;
#line 271 "SerializableGeeCollectionsTest.vala"
			_tmp78_ = stdout;
#line 271 "SerializableGeeCollectionsTest.vala"
			_tmp79_ = doc;
#line 271 "SerializableGeeCollectionsTest.vala"
			_tmp80_ = gxml_gnode_to_string ((GXmlGNode*) _tmp79_);
#line 271 "SerializableGeeCollectionsTest.vala"
			_tmp81_ = _tmp80_;
#line 271 "SerializableGeeCollectionsTest.vala"
			_tmp82_ = g_strconcat ("ERROR: no refaction for Ship MegaTrench / G045-1 exists:\n", _tmp81_, "\n", NULL);
#line 271 "SerializableGeeCollectionsTest.vala"
			_tmp83_ = _tmp82_;
#line 271 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp78_, "%s", _tmp83_);
#line 271 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp83_);
#line 271 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp81_);
#line 272 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 1517 "SerializableGeeCollectionsTest.c"
		}
#line 275 "SerializableGeeCollectionsTest.vala"
		_tmp84_ = b;
#line 275 "SerializableGeeCollectionsTest.vala"
		_tmp85_ = serializable_gee_collections_test_space_base_get_charge_zone (_tmp84_);
#line 275 "SerializableGeeCollectionsTest.vala"
		_tmp86_ = _tmp85_;
#line 275 "SerializableGeeCollectionsTest.vala"
		if (_tmp86_ == NULL) {
#line 1527 "SerializableGeeCollectionsTest.c"
			FILE* _tmp87_;
			GXmlGDocument* _tmp88_;
			gchar* _tmp89_;
			gchar* _tmp90_;
			gchar* _tmp91_;
			gchar* _tmp92_;
#line 276 "SerializableGeeCollectionsTest.vala"
			_tmp87_ = stdout;
#line 276 "SerializableGeeCollectionsTest.vala"
			_tmp88_ = doc;
#line 276 "SerializableGeeCollectionsTest.vala"
			_tmp89_ = gxml_gnode_to_string ((GXmlGNode*) _tmp88_);
#line 276 "SerializableGeeCollectionsTest.vala"
			_tmp90_ = _tmp89_;
#line 276 "SerializableGeeCollectionsTest.vala"
			_tmp91_ = g_strconcat ("ERROR: no charge_zone exists:\n", _tmp90_, "\n", NULL);
#line 276 "SerializableGeeCollectionsTest.vala"
			_tmp92_ = _tmp91_;
#line 276 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp87_, "%s", _tmp92_);
#line 276 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp92_);
#line 276 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp90_);
#line 277 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 1554 "SerializableGeeCollectionsTest.c"
		}
#line 279 "SerializableGeeCollectionsTest.vala"
		_tmp93_ = b;
#line 279 "SerializableGeeCollectionsTest.vala"
		_tmp94_ = serializable_gee_collections_test_space_base_get_charge_zone (_tmp93_);
#line 279 "SerializableGeeCollectionsTest.vala"
		_tmp95_ = _tmp94_;
#line 279 "SerializableGeeCollectionsTest.vala"
		_tmp96_ = _g_object_ref0 (_tmp95_);
#line 279 "SerializableGeeCollectionsTest.vala"
		charge = _tmp96_;
#line 280 "SerializableGeeCollectionsTest.vala"
		_tmp97_ = serializable_gee_collections_test_charge_zone_get_spaceships (charge);
#line 280 "SerializableGeeCollectionsTest.vala"
		_tmp98_ = _tmp97_;
#line 280 "SerializableGeeCollectionsTest.vala"
		if (_tmp98_ == NULL) {
#line 1572 "SerializableGeeCollectionsTest.c"
			FILE* _tmp99_;
			GXmlGDocument* _tmp100_;
			gchar* _tmp101_;
			gchar* _tmp102_;
			gchar* _tmp103_;
			gchar* _tmp104_;
#line 281 "SerializableGeeCollectionsTest.vala"
			_tmp99_ = stdout;
#line 281 "SerializableGeeCollectionsTest.vala"
			_tmp100_ = doc;
#line 281 "SerializableGeeCollectionsTest.vala"
			_tmp101_ = gxml_gnode_to_string ((GXmlGNode*) _tmp100_);
#line 281 "SerializableGeeCollectionsTest.vala"
			_tmp102_ = _tmp101_;
#line 281 "SerializableGeeCollectionsTest.vala"
			_tmp103_ = g_strconcat ("ERROR: no spaceships exists:\n", _tmp102_, "\n", NULL);
#line 281 "SerializableGeeCollectionsTest.vala"
			_tmp104_ = _tmp103_;
#line 281 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp99_, "%s", _tmp104_);
#line 281 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp104_);
#line 281 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp102_);
#line 282 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 1599 "SerializableGeeCollectionsTest.c"
		}
#line 284 "SerializableGeeCollectionsTest.vala"
		_tmp105_ = serializable_gee_collections_test_charge_zone_get_spaceships (charge);
#line 284 "SerializableGeeCollectionsTest.vala"
		_tmp106_ = _tmp105_;
#line 284 "SerializableGeeCollectionsTest.vala"
		_tmp107_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp106_);
#line 284 "SerializableGeeCollectionsTest.vala"
		_tmp108_ = _tmp107_;
#line 284 "SerializableGeeCollectionsTest.vala"
		if (_tmp108_ != 1) {
#line 1611 "SerializableGeeCollectionsTest.c"
			FILE* _tmp109_;
			SerializableGeeCollectionsTestSpaceShipCollection* _tmp110_;
			SerializableGeeCollectionsTestSpaceShipCollection* _tmp111_;
			gint _tmp112_;
			gint _tmp113_;
			gchar* _tmp114_;
			gchar* _tmp115_;
			GXmlGDocument* _tmp116_;
			gchar* _tmp117_;
			gchar* _tmp118_;
			gchar* _tmp119_;
			gchar* _tmp120_;
#line 285 "SerializableGeeCollectionsTest.vala"
			_tmp109_ = stdout;
#line 285 "SerializableGeeCollectionsTest.vala"
			_tmp110_ = serializable_gee_collections_test_charge_zone_get_spaceships (charge);
#line 285 "SerializableGeeCollectionsTest.vala"
			_tmp111_ = _tmp110_;
#line 285 "SerializableGeeCollectionsTest.vala"
			_tmp112_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp111_);
#line 285 "SerializableGeeCollectionsTest.vala"
			_tmp113_ = _tmp112_;
#line 285 "SerializableGeeCollectionsTest.vala"
			_tmp114_ = g_strdup_printf ("%i", _tmp113_);
#line 285 "SerializableGeeCollectionsTest.vala"
			_tmp115_ = _tmp114_;
#line 285 "SerializableGeeCollectionsTest.vala"
			_tmp116_ = doc;
#line 285 "SerializableGeeCollectionsTest.vala"
			_tmp117_ = gxml_gnode_to_string ((GXmlGNode*) _tmp116_);
#line 285 "SerializableGeeCollectionsTest.vala"
			_tmp118_ = _tmp117_;
#line 285 "SerializableGeeCollectionsTest.vala"
			_tmp119_ = g_strconcat ("ERROR: SpaceShips: incorrect size must be 1 got: ", _tmp115_, "\n", _tmp118_, "\n", NULL);
#line 285 "SerializableGeeCollectionsTest.vala"
			_tmp120_ = _tmp119_;
#line 285 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp109_, "%s", _tmp120_);
#line 285 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp120_);
#line 285 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp118_);
#line 285 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp115_);
#line 286 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 1658 "SerializableGeeCollectionsTest.c"
		}
#line 288 "SerializableGeeCollectionsTest.vala"
		_tmp121_ = serializable_gee_collections_test_charge_zone_get_spaceships (charge);
#line 288 "SerializableGeeCollectionsTest.vala"
		_tmp122_ = _tmp121_;
#line 288 "SerializableGeeCollectionsTest.vala"
		_tmp123_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp122_, "MacToy", "A1234");
#line 288 "SerializableGeeCollectionsTest.vala"
		ship = (SerializableGeeCollectionsTestSpaceShip*) _tmp123_;
#line 289 "SerializableGeeCollectionsTest.vala"
		if (ship == NULL) {
#line 1670 "SerializableGeeCollectionsTest.c"
			FILE* _tmp124_;
			GXmlGDocument* _tmp125_;
			gchar* _tmp126_;
			gchar* _tmp127_;
			gchar* _tmp128_;
			gchar* _tmp129_;
#line 290 "SerializableGeeCollectionsTest.vala"
			_tmp124_ = stdout;
#line 290 "SerializableGeeCollectionsTest.vala"
			_tmp125_ = doc;
#line 290 "SerializableGeeCollectionsTest.vala"
			_tmp126_ = gxml_gnode_to_string ((GXmlGNode*) _tmp125_);
#line 290 "SerializableGeeCollectionsTest.vala"
			_tmp127_ = _tmp126_;
#line 290 "SerializableGeeCollectionsTest.vala"
			_tmp128_ = g_strconcat ("ERROR: Ship MacToy/A1234 not found:\n", _tmp127_, "\n", NULL);
#line 290 "SerializableGeeCollectionsTest.vala"
			_tmp129_ = _tmp128_;
#line 290 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp124_, "%s", _tmp129_);
#line 290 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp129_);
#line 290 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp127_);
#line 291 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 1697 "SerializableGeeCollectionsTest.c"
		}
#line 293 "SerializableGeeCollectionsTest.vala"
		_tmp130_ = serializable_gee_collections_test_space_ship_get_spaces (ship);
#line 293 "SerializableGeeCollectionsTest.vala"
		_tmp131_ = _tmp130_;
#line 293 "SerializableGeeCollectionsTest.vala"
		_tmp132_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp131_);
#line 293 "SerializableGeeCollectionsTest.vala"
		_tmp133_ = _tmp132_;
#line 293 "SerializableGeeCollectionsTest.vala"
		if (_tmp133_ != 1) {
#line 1709 "SerializableGeeCollectionsTest.c"
			FILE* _tmp134_;
			SerializableGeeCollectionsTestSpaceCollection* _tmp135_;
			SerializableGeeCollectionsTestSpaceCollection* _tmp136_;
			gint _tmp137_;
			gint _tmp138_;
			gchar* _tmp139_;
			gchar* _tmp140_;
			GXmlGDocument* _tmp141_;
			gchar* _tmp142_;
			gchar* _tmp143_;
			gchar* _tmp144_;
			gchar* _tmp145_;
#line 294 "SerializableGeeCollectionsTest.vala"
			_tmp134_ = stdout;
#line 294 "SerializableGeeCollectionsTest.vala"
			_tmp135_ = serializable_gee_collections_test_space_ship_get_spaces (ship);
#line 294 "SerializableGeeCollectionsTest.vala"
			_tmp136_ = _tmp135_;
#line 294 "SerializableGeeCollectionsTest.vala"
			_tmp137_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp136_);
#line 294 "SerializableGeeCollectionsTest.vala"
			_tmp138_ = _tmp137_;
#line 294 "SerializableGeeCollectionsTest.vala"
			_tmp139_ = g_strdup_printf ("%i", _tmp138_);
#line 294 "SerializableGeeCollectionsTest.vala"
			_tmp140_ = _tmp139_;
#line 294 "SerializableGeeCollectionsTest.vala"
			_tmp141_ = doc;
#line 294 "SerializableGeeCollectionsTest.vala"
			_tmp142_ = gxml_gnode_to_string ((GXmlGNode*) _tmp141_);
#line 294 "SerializableGeeCollectionsTest.vala"
			_tmp143_ = _tmp142_;
#line 294 "SerializableGeeCollectionsTest.vala"
			_tmp144_ = g_strconcat ("ERROR: Ship: incorrect size must be 1 got : ", _tmp140_, "\n", _tmp143_, "\n", NULL);
#line 294 "SerializableGeeCollectionsTest.vala"
			_tmp145_ = _tmp144_;
#line 294 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp134_, "%s", _tmp145_);
#line 294 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp145_);
#line 294 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp143_);
#line 294 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp140_);
#line 295 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 1756 "SerializableGeeCollectionsTest.c"
		}
#line 297 "SerializableGeeCollectionsTest.vala"
		_tmp146_ = serializable_gee_collections_test_space_ship_get_spaces (ship);
#line 297 "SerializableGeeCollectionsTest.vala"
		_tmp147_ = _tmp146_;
#line 297 "SerializableGeeCollectionsTest.vala"
		_tmp148_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp147_, "Alpha Centaury");
#line 297 "SerializableGeeCollectionsTest.vala"
		space = (SerializableGeeCollectionsTestSpace*) _tmp148_;
#line 298 "SerializableGeeCollectionsTest.vala"
		if (space == NULL) {
#line 1768 "SerializableGeeCollectionsTest.c"
			FILE* _tmp149_;
			GXmlGDocument* _tmp150_;
			gchar* _tmp151_;
			gchar* _tmp152_;
			gchar* _tmp153_;
			gchar* _tmp154_;
#line 299 "SerializableGeeCollectionsTest.vala"
			_tmp149_ = stdout;
#line 299 "SerializableGeeCollectionsTest.vala"
			_tmp150_ = doc;
#line 299 "SerializableGeeCollectionsTest.vala"
			_tmp151_ = gxml_gnode_to_string ((GXmlGNode*) _tmp150_);
#line 299 "SerializableGeeCollectionsTest.vala"
			_tmp152_ = _tmp151_;
#line 299 "SerializableGeeCollectionsTest.vala"
			_tmp153_ = g_strconcat ("ERROR: Space Alpha Centaury not found:\n", _tmp152_, "\n", NULL);
#line 299 "SerializableGeeCollectionsTest.vala"
			_tmp154_ = _tmp153_;
#line 299 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp149_, "%s", _tmp154_);
#line 299 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp154_);
#line 299 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp152_);
#line 300 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 1795 "SerializableGeeCollectionsTest.c"
		}
#line 302 "SerializableGeeCollectionsTest.vala"
		_tmp155_ = serializable_gee_collections_test_space_get_planets (space);
#line 302 "SerializableGeeCollectionsTest.vala"
		_tmp156_ = _tmp155_;
#line 302 "SerializableGeeCollectionsTest.vala"
		_tmp157_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp156_);
#line 302 "SerializableGeeCollectionsTest.vala"
		_tmp158_ = _tmp157_;
#line 302 "SerializableGeeCollectionsTest.vala"
		if (_tmp158_ != 2) {
#line 1807 "SerializableGeeCollectionsTest.c"
			FILE* _tmp159_;
			SerializableGeeCollectionsTestPlanetCollection* _tmp160_;
			SerializableGeeCollectionsTestPlanetCollection* _tmp161_;
			gint _tmp162_;
			gint _tmp163_;
			gchar* _tmp164_;
			gchar* _tmp165_;
			GXmlGDocument* _tmp166_;
			gchar* _tmp167_;
			gchar* _tmp168_;
			gchar* _tmp169_;
			gchar* _tmp170_;
#line 303 "SerializableGeeCollectionsTest.vala"
			_tmp159_ = stdout;
#line 303 "SerializableGeeCollectionsTest.vala"
			_tmp160_ = serializable_gee_collections_test_space_get_planets (space);
#line 303 "SerializableGeeCollectionsTest.vala"
			_tmp161_ = _tmp160_;
#line 303 "SerializableGeeCollectionsTest.vala"
			_tmp162_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp161_);
#line 303 "SerializableGeeCollectionsTest.vala"
			_tmp163_ = _tmp162_;
#line 303 "SerializableGeeCollectionsTest.vala"
			_tmp164_ = g_strdup_printf ("%i", _tmp163_);
#line 303 "SerializableGeeCollectionsTest.vala"
			_tmp165_ = _tmp164_;
#line 303 "SerializableGeeCollectionsTest.vala"
			_tmp166_ = doc;
#line 303 "SerializableGeeCollectionsTest.vala"
			_tmp167_ = gxml_gnode_to_string ((GXmlGNode*) _tmp166_);
#line 303 "SerializableGeeCollectionsTest.vala"
			_tmp168_ = _tmp167_;
#line 303 "SerializableGeeCollectionsTest.vala"
			_tmp169_ = g_strconcat ("ERROR: Space size incorrect, must be 2 got:", _tmp165_, "\n", _tmp168_, "\n", NULL);
#line 303 "SerializableGeeCollectionsTest.vala"
			_tmp170_ = _tmp169_;
#line 303 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp159_, "%s", _tmp170_);
#line 303 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp170_);
#line 303 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp168_);
#line 303 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp165_);
#line 304 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 1854 "SerializableGeeCollectionsTest.c"
		}
#line 306 "SerializableGeeCollectionsTest.vala"
		_tmp171_ = serializable_gee_collections_test_space_get_planets (space);
#line 306 "SerializableGeeCollectionsTest.vala"
		_tmp172_ = _tmp171_;
#line 306 "SerializableGeeCollectionsTest.vala"
		_tmp173_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp172_, "Earth");
#line 306 "SerializableGeeCollectionsTest.vala"
		earth = (SerializableGeeCollectionsTestPlanet*) _tmp173_;
#line 307 "SerializableGeeCollectionsTest.vala"
		if (earth == NULL) {
#line 1866 "SerializableGeeCollectionsTest.c"
			FILE* _tmp174_;
			GXmlGDocument* _tmp175_;
			gchar* _tmp176_;
			gchar* _tmp177_;
			gchar* _tmp178_;
			gchar* _tmp179_;
#line 308 "SerializableGeeCollectionsTest.vala"
			_tmp174_ = stdout;
#line 308 "SerializableGeeCollectionsTest.vala"
			_tmp175_ = doc;
#line 308 "SerializableGeeCollectionsTest.vala"
			_tmp176_ = gxml_gnode_to_string ((GXmlGNode*) _tmp175_);
#line 308 "SerializableGeeCollectionsTest.vala"
			_tmp177_ = _tmp176_;
#line 308 "SerializableGeeCollectionsTest.vala"
			_tmp178_ = g_strconcat ("ERROR: Planet Earth not found:\n", _tmp177_, "\n", NULL);
#line 308 "SerializableGeeCollectionsTest.vala"
			_tmp179_ = _tmp178_;
#line 308 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp174_, "%s", _tmp179_);
#line 308 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp179_);
#line 308 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp177_);
#line 309 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 1893 "SerializableGeeCollectionsTest.c"
		}
#line 311 "SerializableGeeCollectionsTest.vala"
		_tmp180_ = serializable_gee_collections_test_space_get_planets (space);
#line 311 "SerializableGeeCollectionsTest.vala"
		_tmp181_ = _tmp180_;
#line 311 "SerializableGeeCollectionsTest.vala"
		_tmp182_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp181_, "Platon");
#line 311 "SerializableGeeCollectionsTest.vala"
		platon = (SerializableGeeCollectionsTestPlanet*) _tmp182_;
#line 312 "SerializableGeeCollectionsTest.vala"
		if (platon == NULL) {
#line 1905 "SerializableGeeCollectionsTest.c"
			FILE* _tmp183_;
			GXmlGDocument* _tmp184_;
			gchar* _tmp185_;
			gchar* _tmp186_;
			gchar* _tmp187_;
			gchar* _tmp188_;
#line 313 "SerializableGeeCollectionsTest.vala"
			_tmp183_ = stdout;
#line 313 "SerializableGeeCollectionsTest.vala"
			_tmp184_ = doc;
#line 313 "SerializableGeeCollectionsTest.vala"
			_tmp185_ = gxml_gnode_to_string ((GXmlGNode*) _tmp184_);
#line 313 "SerializableGeeCollectionsTest.vala"
			_tmp186_ = _tmp185_;
#line 313 "SerializableGeeCollectionsTest.vala"
			_tmp187_ = g_strconcat ("ERROR: Planet Platon not found:\n", _tmp186_, "\n", NULL);
#line 313 "SerializableGeeCollectionsTest.vala"
			_tmp188_ = _tmp187_;
#line 313 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp183_, "%s", _tmp188_);
#line 313 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp188_);
#line 313 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp186_);
#line 314 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 1932 "SerializableGeeCollectionsTest.c"
		}
#line 221 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (platon);
#line 221 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (earth);
#line 221 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (space);
#line 221 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (ship);
#line 221 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (charge);
#line 221 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (ship2);
#line 221 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (ship1);
#line 221 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (refaction);
#line 221 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (storage);
#line 221 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (b);
#line 221 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (doc);
#line 1956 "SerializableGeeCollectionsTest.c"
	}
	goto __finally369;
	__catch369_g_error:
	{
		GError* e = NULL;
		FILE* _tmp189_;
		const gchar* _tmp190_;
		const gchar* _tmp191_;
		gchar* _tmp192_;
		gchar* _tmp193_;
#line 221 "SerializableGeeCollectionsTest.vala"
		e = _inner_error0_;
#line 221 "SerializableGeeCollectionsTest.vala"
		_inner_error0_ = NULL;
#line 318 "SerializableGeeCollectionsTest.vala"
		_tmp189_ = stdout;
#line 318 "SerializableGeeCollectionsTest.vala"
		_tmp190_ = e->message;
#line 318 "SerializableGeeCollectionsTest.vala"
		_tmp191_ = string_to_string (_tmp190_);
#line 318 "SerializableGeeCollectionsTest.vala"
		_tmp192_ = g_strconcat ("ERROR: ", _tmp191_, NULL);
#line 318 "SerializableGeeCollectionsTest.vala"
		_tmp193_ = _tmp192_;
#line 318 "SerializableGeeCollectionsTest.vala"
		fprintf (_tmp189_, "%s", _tmp193_);
#line 318 "SerializableGeeCollectionsTest.vala"
		_g_free0 (_tmp193_);
#line 319 "SerializableGeeCollectionsTest.vala"
		g_assert_not_reached ();
#line 221 "SerializableGeeCollectionsTest.vala"
		_g_error_free0 (e);
#line 1989 "SerializableGeeCollectionsTest.c"
	}
	__finally369:
#line 221 "SerializableGeeCollectionsTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 221 "SerializableGeeCollectionsTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 221 "SerializableGeeCollectionsTest.vala"
		g_clear_error (&_inner_error0_);
#line 221 "SerializableGeeCollectionsTest.vala"
		return;
#line 2000 "SerializableGeeCollectionsTest.c"
	}
}

static void
___lambda319__gtest_func (void)
{
#line 219 "SerializableGeeCollectionsTest.vala"
	__lambda319_ ();
#line 2009 "SerializableGeeCollectionsTest.c"
}

static void
__lambda320_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		SerializableGeeCollectionsTestSpaceBase* s = NULL;
		SerializableGeeCollectionsTestSpaceBase* _tmp1_;
		SerializableGeeCollectionsTestSpaceBase* _tmp2_;
		GXmlGDocument* _tmp3_;
		SerializableGeeCollectionsTestSpaceBase* _tmp4_;
		SerializableGeeCollectionsTestChargeZone* _tmp5_;
		SerializableGeeCollectionsTestChargeZone* _tmp6_;
		SerializableGeeCollectionsTestSpaceBase* _tmp8_;
		SerializableGeeCollectionsTestChargeZone* _tmp9_;
		SerializableGeeCollectionsTestChargeZone* _tmp10_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp11_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp12_;
		SerializableGeeCollectionsTestSpaceBase* _tmp14_;
		SerializableGeeCollectionsTestChargeZone* _tmp15_;
		SerializableGeeCollectionsTestChargeZone* _tmp16_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp17_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp18_;
		gint _tmp19_;
		gint _tmp20_;
		SerializableGeeCollectionsTestSpaceShip* s1 = NULL;
		SerializableGeeCollectionsTestSpaceBase* _tmp33_;
		SerializableGeeCollectionsTestChargeZone* _tmp34_;
		SerializableGeeCollectionsTestChargeZone* _tmp35_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp36_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp37_;
		gpointer _tmp38_;
		SerializableGeeCollectionsTestSpaceShip* _tmp39_;
		SerializableGeeCollectionsTestSpaceShip* _tmp41_;
		SerializableGeeCollectionsTestSpaceCollection* _tmp42_;
		SerializableGeeCollectionsTestSpaceCollection* _tmp43_;
		SerializableGeeCollectionsTestSpaceShip* _tmp45_;
		SerializableGeeCollectionsTestSpaceCollection* _tmp46_;
		SerializableGeeCollectionsTestSpaceCollection* _tmp47_;
		gint _tmp48_;
		gint _tmp49_;
		GXmlGDocument* ndoc = NULL;
		GXmlGDocument* _tmp60_;
		SerializableGeeCollectionsTestSpaceBase* _tmp61_;
		GXmlGDocument* _tmp62_;
		GXmlNode* _tmp63_;
		GXmlNode* _tmp64_;
		SerializableGeeCollectionsTestSpaceBase* ns = NULL;
		SerializableGeeCollectionsTestSpaceBase* _tmp65_;
		SerializableGeeCollectionsTestSpaceBase* _tmp66_;
		GXmlGDocument* _tmp67_;
		SerializableGeeCollectionsTestSpaceBase* _tmp68_;
		gchar* _tmp69_;
		gchar* _tmp70_;
		gchar* _tmp71_;
		gboolean _tmp72_;
		SerializableGeeCollectionsTestSpaceBase* _tmp81_;
		SerializableGeeCollectionsTestChargeZone* _tmp82_;
		SerializableGeeCollectionsTestChargeZone* _tmp83_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp84_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp85_;
		gint _tmp86_;
		gint _tmp87_;
		SerializableGeeCollectionsTestSpaceShip* chip = NULL;
		SerializableGeeCollectionsTestSpaceBase* _tmp123_;
		SerializableGeeCollectionsTestChargeZone* _tmp124_;
		SerializableGeeCollectionsTestChargeZone* _tmp125_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp126_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp127_;
		gpointer _tmp128_;
		SerializableGeeCollectionsTestSpaceCollection* _tmp129_;
		SerializableGeeCollectionsTestSpaceCollection* _tmp130_;
		gint _tmp131_;
		gint _tmp132_;
		GXmlGDocument* _tmp142_;
		GXmlNode* _tmp143_;
		GXmlNode* _tmp144_;
		GXmlNode* _tmp145_;
		gboolean _tmp146_;
		GXmlGDocument* _tmp148_;
		GXmlNode* _tmp149_;
		GXmlNode* _tmp150_;
		GXmlNode* _tmp151_;
		gchar* _tmp152_;
		gchar* _tmp153_;
		gchar* _tmp154_;
		gboolean _tmp155_;
		GXmlGDocument* _tmp157_;
		GXmlNode* _tmp158_;
		GXmlNode* _tmp159_;
		GXmlNode* _tmp160_;
		GeeBidirList* _tmp161_;
		GeeBidirList* _tmp162_;
		GeeBidirList* _tmp163_;
		gint _tmp164_;
		gint _tmp165_;
		gint i = 0;
#line 325 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"<base name=\"AlphaOne\" >\n" \
"  <chargezone name=\"A1-1\">\n" \
"    <ship manufacturer=\"MacToy\" model=\"A1234\">\n" \
"      <space name=\"Alpha Centaury\">\n" \
"        <planet name=\"Earth\">\n" \
"          <citizen ctype=\"Human\">1M</citizen>\n" \
"          <citizen ctype=\"Ghost\">10M</citizen>\n" \
"        </planet>\n" \
"        <planet name=\"Platon\" />\n" \
"      </space>\n" \
"      <space name=\"Galax\">\n" \
"        <planet name=\"Saminon\">\n" \
"          <citizen ctype=\"Humanes\">100M</citizen>\n" \
"          <citizen ctype=\"Jeties\">1000M</citizen>\n" \
"        </planet>\n" \
"        <planet name=\"Platon\" />\n" \
"      </space>\n" \
"    </ship>\n" \
"    <ship manufacturer=\"Memphis\" model=\"AB1\">\n" \
"      <space name=\"Alpha Centaury\">\n" \
"        <planet name=\"Earth\">\n" \
"          <citizen ctype=\"Human\">10000M</citizen>\n" \
"          <citizen ctype=\"Ghost\">100000M</citizen>\n" \
"        </planet>\n" \
"        <planet name=\"Platon\" />\n" \
"      </space>\n" \
"    </ship>\n" \
"  </chargezone>\n" \
"  <storage name=\"B4-A4\">\n" \
"    <refaction manufacturer=\"MacToy\" model=\"Fly045\">\n" \
"      <ship manufacturer=\"MacToy\" model=\"A1234\" />\n" \
"      <ship manufacturer=\"MegaTrench\" model=\"G045-1\" />\n" \
"    </refaction>\n" \
"  </storage>\n" \
"</base>", 0, &_inner_error0_);
#line 325 "SerializableGeeCollectionsTest.vala"
		doc = _tmp0_;
#line 325 "SerializableGeeCollectionsTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2116 "SerializableGeeCollectionsTest.c"
			goto __catch370_g_error;
		}
#line 361 "SerializableGeeCollectionsTest.vala"
		_tmp1_ = serializable_gee_collections_test_space_base_new ();
#line 361 "SerializableGeeCollectionsTest.vala"
		s = _tmp1_;
#line 362 "SerializableGeeCollectionsTest.vala"
		_tmp2_ = s;
#line 362 "SerializableGeeCollectionsTest.vala"
		_tmp3_ = doc;
#line 362 "SerializableGeeCollectionsTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 362 "SerializableGeeCollectionsTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 362 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (s);
#line 362 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (doc);
#line 2135 "SerializableGeeCollectionsTest.c"
			goto __catch370_g_error;
		}
#line 363 "SerializableGeeCollectionsTest.vala"
		_tmp4_ = s;
#line 363 "SerializableGeeCollectionsTest.vala"
		_tmp5_ = serializable_gee_collections_test_space_base_get_charge_zone (_tmp4_);
#line 363 "SerializableGeeCollectionsTest.vala"
		_tmp6_ = _tmp5_;
#line 363 "SerializableGeeCollectionsTest.vala"
		if (_tmp6_ == NULL) {
#line 2146 "SerializableGeeCollectionsTest.c"
			FILE* _tmp7_;
#line 364 "SerializableGeeCollectionsTest.vala"
			_tmp7_ = stdout;
#line 364 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp7_, "%s", "ERROR: (1de) No charge zone\n");
#line 365 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 2154 "SerializableGeeCollectionsTest.c"
		}
#line 367 "SerializableGeeCollectionsTest.vala"
		_tmp8_ = s;
#line 367 "SerializableGeeCollectionsTest.vala"
		_tmp9_ = serializable_gee_collections_test_space_base_get_charge_zone (_tmp8_);
#line 367 "SerializableGeeCollectionsTest.vala"
		_tmp10_ = _tmp9_;
#line 367 "SerializableGeeCollectionsTest.vala"
		_tmp11_ = serializable_gee_collections_test_charge_zone_get_spaceships (_tmp10_);
#line 367 "SerializableGeeCollectionsTest.vala"
		_tmp12_ = _tmp11_;
#line 367 "SerializableGeeCollectionsTest.vala"
		if (_tmp12_ == NULL) {
#line 2168 "SerializableGeeCollectionsTest.c"
			FILE* _tmp13_;
#line 368 "SerializableGeeCollectionsTest.vala"
			_tmp13_ = stdout;
#line 368 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp13_, "%s", "ERROR: (1de) No spaceships\n");
#line 369 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 2176 "SerializableGeeCollectionsTest.c"
		}
#line 371 "SerializableGeeCollectionsTest.vala"
		_tmp14_ = s;
#line 371 "SerializableGeeCollectionsTest.vala"
		_tmp15_ = serializable_gee_collections_test_space_base_get_charge_zone (_tmp14_);
#line 371 "SerializableGeeCollectionsTest.vala"
		_tmp16_ = _tmp15_;
#line 371 "SerializableGeeCollectionsTest.vala"
		_tmp17_ = serializable_gee_collections_test_charge_zone_get_spaceships (_tmp16_);
#line 371 "SerializableGeeCollectionsTest.vala"
		_tmp18_ = _tmp17_;
#line 371 "SerializableGeeCollectionsTest.vala"
		_tmp19_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp18_);
#line 371 "SerializableGeeCollectionsTest.vala"
		_tmp20_ = _tmp19_;
#line 371 "SerializableGeeCollectionsTest.vala"
		if (_tmp20_ != 2) {
#line 2194 "SerializableGeeCollectionsTest.c"
			FILE* _tmp21_;
			SerializableGeeCollectionsTestSpaceBase* _tmp22_;
			SerializableGeeCollectionsTestChargeZone* _tmp23_;
			SerializableGeeCollectionsTestChargeZone* _tmp24_;
			SerializableGeeCollectionsTestSpaceShipCollection* _tmp25_;
			SerializableGeeCollectionsTestSpaceShipCollection* _tmp26_;
			gint _tmp27_;
			gint _tmp28_;
			gchar* _tmp29_;
			gchar* _tmp30_;
			gchar* _tmp31_;
			gchar* _tmp32_;
#line 372 "SerializableGeeCollectionsTest.vala"
			_tmp21_ = stdout;
#line 372 "SerializableGeeCollectionsTest.vala"
			_tmp22_ = s;
#line 372 "SerializableGeeCollectionsTest.vala"
			_tmp23_ = serializable_gee_collections_test_space_base_get_charge_zone (_tmp22_);
#line 372 "SerializableGeeCollectionsTest.vala"
			_tmp24_ = _tmp23_;
#line 372 "SerializableGeeCollectionsTest.vala"
			_tmp25_ = serializable_gee_collections_test_charge_zone_get_spaceships (_tmp24_);
#line 372 "SerializableGeeCollectionsTest.vala"
			_tmp26_ = _tmp25_;
#line 372 "SerializableGeeCollectionsTest.vala"
			_tmp27_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp26_);
#line 372 "SerializableGeeCollectionsTest.vala"
			_tmp28_ = _tmp27_;
#line 372 "SerializableGeeCollectionsTest.vala"
			_tmp29_ = g_strdup_printf ("%i", _tmp28_);
#line 372 "SerializableGeeCollectionsTest.vala"
			_tmp30_ = _tmp29_;
#line 372 "SerializableGeeCollectionsTest.vala"
			_tmp31_ = g_strconcat ("ERROR: (1de) incorrect spaceships number. Expected 2, got ", _tmp30_, "\n", NULL);
#line 372 "SerializableGeeCollectionsTest.vala"
			_tmp32_ = _tmp31_;
#line 372 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp21_, "%s", _tmp32_);
#line 372 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp32_);
#line 372 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp30_);
#line 373 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 2239 "SerializableGeeCollectionsTest.c"
		}
#line 375 "SerializableGeeCollectionsTest.vala"
		_tmp33_ = s;
#line 375 "SerializableGeeCollectionsTest.vala"
		_tmp34_ = serializable_gee_collections_test_space_base_get_charge_zone (_tmp33_);
#line 375 "SerializableGeeCollectionsTest.vala"
		_tmp35_ = _tmp34_;
#line 375 "SerializableGeeCollectionsTest.vala"
		_tmp36_ = serializable_gee_collections_test_charge_zone_get_spaceships (_tmp35_);
#line 375 "SerializableGeeCollectionsTest.vala"
		_tmp37_ = _tmp36_;
#line 375 "SerializableGeeCollectionsTest.vala"
		_tmp38_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp37_, "MacToy", "A1234");
#line 375 "SerializableGeeCollectionsTest.vala"
		s1 = (SerializableGeeCollectionsTestSpaceShip*) _tmp38_;
#line 376 "SerializableGeeCollectionsTest.vala"
		_tmp39_ = s1;
#line 376 "SerializableGeeCollectionsTest.vala"
		if (_tmp39_ == NULL) {
#line 2259 "SerializableGeeCollectionsTest.c"
			FILE* _tmp40_;
#line 377 "SerializableGeeCollectionsTest.vala"
			_tmp40_ = stdout;
#line 377 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp40_, "%s", "ERROR: No spaceship MacToy/A1234 found\n");
#line 378 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 2267 "SerializableGeeCollectionsTest.c"
		}
#line 380 "SerializableGeeCollectionsTest.vala"
		_tmp41_ = s1;
#line 380 "SerializableGeeCollectionsTest.vala"
		_tmp42_ = serializable_gee_collections_test_space_ship_get_spaces (_tmp41_);
#line 380 "SerializableGeeCollectionsTest.vala"
		_tmp43_ = _tmp42_;
#line 380 "SerializableGeeCollectionsTest.vala"
		if (_tmp43_ == NULL) {
#line 2277 "SerializableGeeCollectionsTest.c"
			FILE* _tmp44_;
#line 381 "SerializableGeeCollectionsTest.vala"
			_tmp44_ = stdout;
#line 381 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp44_, "%s", "ERROR: No spaces for spaceship MacToy/A1234 found\n");
#line 382 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 2285 "SerializableGeeCollectionsTest.c"
		}
#line 384 "SerializableGeeCollectionsTest.vala"
		_tmp45_ = s1;
#line 384 "SerializableGeeCollectionsTest.vala"
		_tmp46_ = serializable_gee_collections_test_space_ship_get_spaces (_tmp45_);
#line 384 "SerializableGeeCollectionsTest.vala"
		_tmp47_ = _tmp46_;
#line 384 "SerializableGeeCollectionsTest.vala"
		_tmp48_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp47_);
#line 384 "SerializableGeeCollectionsTest.vala"
		_tmp49_ = _tmp48_;
#line 384 "SerializableGeeCollectionsTest.vala"
		if (_tmp49_ != 2) {
#line 2299 "SerializableGeeCollectionsTest.c"
			FILE* _tmp50_;
			SerializableGeeCollectionsTestSpaceShip* _tmp51_;
			SerializableGeeCollectionsTestSpaceCollection* _tmp52_;
			SerializableGeeCollectionsTestSpaceCollection* _tmp53_;
			gint _tmp54_;
			gint _tmp55_;
			gchar* _tmp56_;
			gchar* _tmp57_;
			gchar* _tmp58_;
			gchar* _tmp59_;
#line 385 "SerializableGeeCollectionsTest.vala"
			_tmp50_ = stdout;
#line 385 "SerializableGeeCollectionsTest.vala"
			_tmp51_ = s1;
#line 385 "SerializableGeeCollectionsTest.vala"
			_tmp52_ = serializable_gee_collections_test_space_ship_get_spaces (_tmp51_);
#line 385 "SerializableGeeCollectionsTest.vala"
			_tmp53_ = _tmp52_;
#line 385 "SerializableGeeCollectionsTest.vala"
			_tmp54_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp53_);
#line 385 "SerializableGeeCollectionsTest.vala"
			_tmp55_ = _tmp54_;
#line 385 "SerializableGeeCollectionsTest.vala"
			_tmp56_ = g_strdup_printf ("%i", _tmp55_);
#line 385 "SerializableGeeCollectionsTest.vala"
			_tmp57_ = _tmp56_;
#line 385 "SerializableGeeCollectionsTest.vala"
			_tmp58_ = g_strconcat ("ERROR: Incorrect spaces size for spaceship MacToy/A1234. Expected 2, g" \
"ot: ", _tmp57_, "\n", NULL);
#line 385 "SerializableGeeCollectionsTest.vala"
			_tmp59_ = _tmp58_;
#line 385 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp50_, "%s", _tmp59_);
#line 385 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp59_);
#line 385 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp57_);
#line 386 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 2338 "SerializableGeeCollectionsTest.c"
		}
#line 389 "SerializableGeeCollectionsTest.vala"
		_tmp60_ = gxml_gdocument_new ();
#line 389 "SerializableGeeCollectionsTest.vala"
		ndoc = _tmp60_;
#line 390 "SerializableGeeCollectionsTest.vala"
		_tmp61_ = s;
#line 390 "SerializableGeeCollectionsTest.vala"
		_tmp62_ = ndoc;
#line 390 "SerializableGeeCollectionsTest.vala"
		_tmp63_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp61_, (GXmlNode*) _tmp62_, &_inner_error0_);
#line 390 "SerializableGeeCollectionsTest.vala"
		_tmp64_ = _tmp63_;
#line 390 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp64_);
#line 390 "SerializableGeeCollectionsTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 390 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (ndoc);
#line 390 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (s1);
#line 390 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (s);
#line 390 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (doc);
#line 2364 "SerializableGeeCollectionsTest.c"
			goto __catch370_g_error;
		}
#line 391 "SerializableGeeCollectionsTest.vala"
		_tmp65_ = serializable_gee_collections_test_space_base_new ();
#line 391 "SerializableGeeCollectionsTest.vala"
		ns = _tmp65_;
#line 392 "SerializableGeeCollectionsTest.vala"
		_tmp66_ = ns;
#line 392 "SerializableGeeCollectionsTest.vala"
		_tmp67_ = ndoc;
#line 392 "SerializableGeeCollectionsTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp66_, (GXmlNode*) _tmp67_, &_inner_error0_);
#line 392 "SerializableGeeCollectionsTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 392 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (ns);
#line 392 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (ndoc);
#line 392 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (s1);
#line 392 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (s);
#line 392 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (doc);
#line 2389 "SerializableGeeCollectionsTest.c"
			goto __catch370_g_error;
		}
#line 393 "SerializableGeeCollectionsTest.vala"
		_tmp68_ = ns;
#line 393 "SerializableGeeCollectionsTest.vala"
		_tmp69_ = gxml_serializable_get_serialized_xml_node_value ((GXmlSerializable*) _tmp68_);
#line 393 "SerializableGeeCollectionsTest.vala"
		_tmp70_ = _tmp69_;
#line 393 "SerializableGeeCollectionsTest.vala"
		_tmp71_ = _tmp70_;
#line 393 "SerializableGeeCollectionsTest.vala"
		_tmp72_ = _tmp71_ != NULL;
#line 393 "SerializableGeeCollectionsTest.vala"
		_g_free0 (_tmp71_);
#line 393 "SerializableGeeCollectionsTest.vala"
		if (_tmp72_) {
#line 2406 "SerializableGeeCollectionsTest.c"
			FILE* _tmp73_;
			SerializableGeeCollectionsTestSpaceBase* _tmp74_;
			gchar* _tmp75_;
			gchar* _tmp76_;
			gchar* _tmp77_;
			const gchar* _tmp78_;
			gchar* _tmp79_;
			gchar* _tmp80_;
#line 394 "SerializableGeeCollectionsTest.vala"
			_tmp73_ = stdout;
#line 394 "SerializableGeeCollectionsTest.vala"
			_tmp74_ = ns;
#line 394 "SerializableGeeCollectionsTest.vala"
			_tmp75_ = gxml_serializable_get_serialized_xml_node_value ((GXmlSerializable*) _tmp74_);
#line 394 "SerializableGeeCollectionsTest.vala"
			_tmp76_ = _tmp75_;
#line 394 "SerializableGeeCollectionsTest.vala"
			_tmp77_ = _tmp76_;
#line 394 "SerializableGeeCollectionsTest.vala"
			_tmp78_ = string_to_string (_tmp77_);
#line 394 "SerializableGeeCollectionsTest.vala"
			_tmp79_ = g_strconcat ("ERROR: wrong base node content, should be '' got: '", _tmp78_, "''", NULL);
#line 394 "SerializableGeeCollectionsTest.vala"
			_tmp80_ = _tmp79_;
#line 394 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp73_, "%s", _tmp80_);
#line 394 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp80_);
#line 394 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp77_);
#line 395 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 2439 "SerializableGeeCollectionsTest.c"
		}
#line 397 "SerializableGeeCollectionsTest.vala"
		_tmp81_ = ns;
#line 397 "SerializableGeeCollectionsTest.vala"
		_tmp82_ = serializable_gee_collections_test_space_base_get_charge_zone (_tmp81_);
#line 397 "SerializableGeeCollectionsTest.vala"
		_tmp83_ = _tmp82_;
#line 397 "SerializableGeeCollectionsTest.vala"
		_tmp84_ = serializable_gee_collections_test_charge_zone_get_spaceships (_tmp83_);
#line 397 "SerializableGeeCollectionsTest.vala"
		_tmp85_ = _tmp84_;
#line 397 "SerializableGeeCollectionsTest.vala"
		_tmp86_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp85_);
#line 397 "SerializableGeeCollectionsTest.vala"
		_tmp87_ = _tmp86_;
#line 397 "SerializableGeeCollectionsTest.vala"
		if (_tmp87_ != 2) {
#line 2457 "SerializableGeeCollectionsTest.c"
			FILE* _tmp88_;
			SerializableGeeCollectionsTestSpaceBase* _tmp89_;
			SerializableGeeCollectionsTestChargeZone* _tmp90_;
			SerializableGeeCollectionsTestChargeZone* _tmp91_;
			SerializableGeeCollectionsTestSpaceShipCollection* _tmp92_;
			SerializableGeeCollectionsTestSpaceShipCollection* _tmp93_;
			gint _tmp94_;
			gint _tmp95_;
			gchar* _tmp96_;
			gchar* _tmp97_;
			gchar* _tmp98_;
			gchar* _tmp99_;
			FILE* _tmp119_;
			GXmlGDocument* _tmp120_;
			gchar* _tmp121_;
			gchar* _tmp122_;
#line 398 "SerializableGeeCollectionsTest.vala"
			_tmp88_ = stdout;
#line 398 "SerializableGeeCollectionsTest.vala"
			_tmp89_ = ns;
#line 398 "SerializableGeeCollectionsTest.vala"
			_tmp90_ = serializable_gee_collections_test_space_base_get_charge_zone (_tmp89_);
#line 398 "SerializableGeeCollectionsTest.vala"
			_tmp91_ = _tmp90_;
#line 398 "SerializableGeeCollectionsTest.vala"
			_tmp92_ = serializable_gee_collections_test_charge_zone_get_spaceships (_tmp91_);
#line 398 "SerializableGeeCollectionsTest.vala"
			_tmp93_ = _tmp92_;
#line 398 "SerializableGeeCollectionsTest.vala"
			_tmp94_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp93_);
#line 398 "SerializableGeeCollectionsTest.vala"
			_tmp95_ = _tmp94_;
#line 398 "SerializableGeeCollectionsTest.vala"
			_tmp96_ = g_strdup_printf ("%i", _tmp95_);
#line 398 "SerializableGeeCollectionsTest.vala"
			_tmp97_ = _tmp96_;
#line 398 "SerializableGeeCollectionsTest.vala"
			_tmp98_ = g_strconcat ("ERROR: wrong spaceships size. Expected 2, got: ", _tmp97_, "\n", NULL);
#line 398 "SerializableGeeCollectionsTest.vala"
			_tmp99_ = _tmp98_;
#line 398 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp88_, "%s", _tmp99_);
#line 398 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp99_);
#line 398 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp97_);
#line 2504 "SerializableGeeCollectionsTest.c"
			{
				GeeIterator* _sh_it = NULL;
				SerializableGeeCollectionsTestSpaceBase* _tmp100_;
				SerializableGeeCollectionsTestChargeZone* _tmp101_;
				SerializableGeeCollectionsTestChargeZone* _tmp102_;
				SerializableGeeCollectionsTestSpaceShipCollection* _tmp103_;
				SerializableGeeCollectionsTestSpaceShipCollection* _tmp104_;
				GeeCollection* _tmp105_;
				GeeCollection* _tmp106_;
				GeeIterator* _tmp107_;
				GeeIterator* _tmp108_;
#line 399 "SerializableGeeCollectionsTest.vala"
				_tmp100_ = ns;
#line 399 "SerializableGeeCollectionsTest.vala"
				_tmp101_ = serializable_gee_collections_test_space_base_get_charge_zone (_tmp100_);
#line 399 "SerializableGeeCollectionsTest.vala"
				_tmp102_ = _tmp101_;
#line 399 "SerializableGeeCollectionsTest.vala"
				_tmp103_ = serializable_gee_collections_test_charge_zone_get_spaceships (_tmp102_);
#line 399 "SerializableGeeCollectionsTest.vala"
				_tmp104_ = _tmp103_;
#line 399 "SerializableGeeCollectionsTest.vala"
				_tmp105_ = gxml_serializable_dual_key_map_values ((GXmlSerializableDualKeyMap*) _tmp104_);
#line 399 "SerializableGeeCollectionsTest.vala"
				_tmp106_ = _tmp105_;
#line 399 "SerializableGeeCollectionsTest.vala"
				_tmp107_ = gee_iterable_iterator ((GeeIterable*) _tmp106_);
#line 399 "SerializableGeeCollectionsTest.vala"
				_tmp108_ = _tmp107_;
#line 399 "SerializableGeeCollectionsTest.vala"
				_g_object_unref0 (_tmp106_);
#line 399 "SerializableGeeCollectionsTest.vala"
				_sh_it = _tmp108_;
#line 399 "SerializableGeeCollectionsTest.vala"
				while (TRUE) {
#line 2540 "SerializableGeeCollectionsTest.c"
					GeeIterator* _tmp109_;
					SerializableGeeCollectionsTestSpaceShip* sh = NULL;
					GeeIterator* _tmp110_;
					gpointer _tmp111_;
					FILE* _tmp112_;
					SerializableGeeCollectionsTestSpaceShip* _tmp113_;
					const gchar* _tmp114_;
					const gchar* _tmp115_;
					const gchar* _tmp116_;
					gchar* _tmp117_;
					gchar* _tmp118_;
#line 399 "SerializableGeeCollectionsTest.vala"
					_tmp109_ = _sh_it;
#line 399 "SerializableGeeCollectionsTest.vala"
					if (!gee_iterator_next (_tmp109_)) {
#line 399 "SerializableGeeCollectionsTest.vala"
						break;
#line 2558 "SerializableGeeCollectionsTest.c"
					}
#line 399 "SerializableGeeCollectionsTest.vala"
					_tmp110_ = _sh_it;
#line 399 "SerializableGeeCollectionsTest.vala"
					_tmp111_ = gee_iterator_get (_tmp110_);
#line 399 "SerializableGeeCollectionsTest.vala"
					sh = (SerializableGeeCollectionsTestSpaceShip*) _tmp111_;
#line 400 "SerializableGeeCollectionsTest.vala"
					_tmp112_ = stdout;
#line 400 "SerializableGeeCollectionsTest.vala"
					_tmp113_ = sh;
#line 400 "SerializableGeeCollectionsTest.vala"
					_tmp114_ = serializable_gee_collections_test_space_ship_get_manufacturer (_tmp113_);
#line 400 "SerializableGeeCollectionsTest.vala"
					_tmp115_ = _tmp114_;
#line 400 "SerializableGeeCollectionsTest.vala"
					_tmp116_ = string_to_string (_tmp115_);
#line 400 "SerializableGeeCollectionsTest.vala"
					_tmp117_ = g_strconcat ("Ship: ", _tmp116_, "\n", NULL);
#line 400 "SerializableGeeCollectionsTest.vala"
					_tmp118_ = _tmp117_;
#line 400 "SerializableGeeCollectionsTest.vala"
					fprintf (_tmp112_, "%s", _tmp118_);
#line 400 "SerializableGeeCollectionsTest.vala"
					_g_free0 (_tmp118_);
#line 399 "SerializableGeeCollectionsTest.vala"
					_g_object_unref0 (sh);
#line 2586 "SerializableGeeCollectionsTest.c"
				}
#line 399 "SerializableGeeCollectionsTest.vala"
				_g_object_unref0 (_sh_it);
#line 2590 "SerializableGeeCollectionsTest.c"
			}
#line 402 "SerializableGeeCollectionsTest.vala"
			_tmp119_ = stdout;
#line 402 "SerializableGeeCollectionsTest.vala"
			_tmp120_ = ndoc;
#line 402 "SerializableGeeCollectionsTest.vala"
			_tmp121_ = gxml_gnode_to_string ((GXmlGNode*) _tmp120_);
#line 402 "SerializableGeeCollectionsTest.vala"
			_tmp122_ = _tmp121_;
#line 402 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp119_, "%s", _tmp122_);
#line 402 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp122_);
#line 403 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 2606 "SerializableGeeCollectionsTest.c"
		}
#line 405 "SerializableGeeCollectionsTest.vala"
		_tmp123_ = ns;
#line 405 "SerializableGeeCollectionsTest.vala"
		_tmp124_ = serializable_gee_collections_test_space_base_get_charge_zone (_tmp123_);
#line 405 "SerializableGeeCollectionsTest.vala"
		_tmp125_ = _tmp124_;
#line 405 "SerializableGeeCollectionsTest.vala"
		_tmp126_ = serializable_gee_collections_test_charge_zone_get_spaceships (_tmp125_);
#line 405 "SerializableGeeCollectionsTest.vala"
		_tmp127_ = _tmp126_;
#line 405 "SerializableGeeCollectionsTest.vala"
		_tmp128_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp127_, "MacToy", "A1234");
#line 405 "SerializableGeeCollectionsTest.vala"
		chip = (SerializableGeeCollectionsTestSpaceShip*) _tmp128_;
#line 406 "SerializableGeeCollectionsTest.vala"
		_tmp129_ = serializable_gee_collections_test_space_ship_get_spaces (chip);
#line 406 "SerializableGeeCollectionsTest.vala"
		_tmp130_ = _tmp129_;
#line 406 "SerializableGeeCollectionsTest.vala"
		_tmp131_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp130_);
#line 406 "SerializableGeeCollectionsTest.vala"
		_tmp132_ = _tmp131_;
#line 406 "SerializableGeeCollectionsTest.vala"
		if (_tmp132_ != 2) {
#line 2632 "SerializableGeeCollectionsTest.c"
			FILE* _tmp133_;
			SerializableGeeCollectionsTestSpaceCollection* _tmp134_;
			SerializableGeeCollectionsTestSpaceCollection* _tmp135_;
			gint _tmp136_;
			gint _tmp137_;
			gchar* _tmp138_;
			gchar* _tmp139_;
			gchar* _tmp140_;
			gchar* _tmp141_;
#line 407 "SerializableGeeCollectionsTest.vala"
			_tmp133_ = stdout;
#line 407 "SerializableGeeCollectionsTest.vala"
			_tmp134_ = serializable_gee_collections_test_space_ship_get_spaces (chip);
#line 407 "SerializableGeeCollectionsTest.vala"
			_tmp135_ = _tmp134_;
#line 407 "SerializableGeeCollectionsTest.vala"
			_tmp136_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp135_);
#line 407 "SerializableGeeCollectionsTest.vala"
			_tmp137_ = _tmp136_;
#line 407 "SerializableGeeCollectionsTest.vala"
			_tmp138_ = g_strdup_printf ("%i", _tmp137_);
#line 407 "SerializableGeeCollectionsTest.vala"
			_tmp139_ = _tmp138_;
#line 407 "SerializableGeeCollectionsTest.vala"
			_tmp140_ = g_strconcat ("ERROR: wrong spaces size. Expected 2, got: ", _tmp139_, NULL);
#line 407 "SerializableGeeCollectionsTest.vala"
			_tmp141_ = _tmp140_;
#line 407 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp133_, "%s", _tmp141_);
#line 407 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp141_);
#line 407 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp139_);
#line 408 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 2668 "SerializableGeeCollectionsTest.c"
		}
#line 411 "SerializableGeeCollectionsTest.vala"
		_tmp142_ = ndoc;
#line 411 "SerializableGeeCollectionsTest.vala"
		_tmp143_ = gxml_document_get_root ((GXmlDocument*) _tmp142_);
#line 411 "SerializableGeeCollectionsTest.vala"
		_tmp144_ = _tmp143_;
#line 411 "SerializableGeeCollectionsTest.vala"
		_tmp145_ = _tmp144_;
#line 411 "SerializableGeeCollectionsTest.vala"
		_tmp146_ = _tmp145_ == NULL;
#line 411 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp145_);
#line 411 "SerializableGeeCollectionsTest.vala"
		if (_tmp146_) {
#line 2684 "SerializableGeeCollectionsTest.c"
			FILE* _tmp147_;
#line 412 "SerializableGeeCollectionsTest.vala"
			_tmp147_ = stdout;
#line 412 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp147_, "ERROR: No ROOT element\n");
#line 413 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 2692 "SerializableGeeCollectionsTest.c"
		}
#line 415 "SerializableGeeCollectionsTest.vala"
		_tmp148_ = ndoc;
#line 415 "SerializableGeeCollectionsTest.vala"
		_tmp149_ = gxml_document_get_root ((GXmlDocument*) _tmp148_);
#line 415 "SerializableGeeCollectionsTest.vala"
		_tmp150_ = _tmp149_;
#line 415 "SerializableGeeCollectionsTest.vala"
		_tmp151_ = _tmp150_;
#line 415 "SerializableGeeCollectionsTest.vala"
		_tmp152_ = gxml_node_get_name (_tmp151_);
#line 415 "SerializableGeeCollectionsTest.vala"
		_tmp153_ = _tmp152_;
#line 415 "SerializableGeeCollectionsTest.vala"
		_tmp154_ = _tmp153_;
#line 415 "SerializableGeeCollectionsTest.vala"
		_tmp155_ = g_strcmp0 (_tmp154_, "base") != 0;
#line 415 "SerializableGeeCollectionsTest.vala"
		_g_free0 (_tmp154_);
#line 415 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp151_);
#line 415 "SerializableGeeCollectionsTest.vala"
		if (_tmp155_) {
#line 2716 "SerializableGeeCollectionsTest.c"
			FILE* _tmp156_;
#line 416 "SerializableGeeCollectionsTest.vala"
			_tmp156_ = stdout;
#line 416 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp156_, "ERROR: Bad ROOT name\n");
#line 417 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 2724 "SerializableGeeCollectionsTest.c"
		}
#line 419 "SerializableGeeCollectionsTest.vala"
		_tmp157_ = ndoc;
#line 419 "SerializableGeeCollectionsTest.vala"
		_tmp158_ = gxml_document_get_root ((GXmlDocument*) _tmp157_);
#line 419 "SerializableGeeCollectionsTest.vala"
		_tmp159_ = _tmp158_;
#line 419 "SerializableGeeCollectionsTest.vala"
		_tmp160_ = _tmp159_;
#line 419 "SerializableGeeCollectionsTest.vala"
		_tmp161_ = gxml_node_get_children_nodes (_tmp160_);
#line 419 "SerializableGeeCollectionsTest.vala"
		_tmp162_ = _tmp161_;
#line 419 "SerializableGeeCollectionsTest.vala"
		_tmp163_ = _tmp162_;
#line 419 "SerializableGeeCollectionsTest.vala"
		_tmp164_ = gee_collection_get_size ((GeeCollection*) _tmp163_);
#line 419 "SerializableGeeCollectionsTest.vala"
		_tmp165_ = _tmp164_;
#line 419 "SerializableGeeCollectionsTest.vala"
		_vala_assert (_tmp165_ > 0, "ndoc.root.children_nodes.size > 0");
#line 419 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp163_);
#line 419 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp160_);
#line 420 "SerializableGeeCollectionsTest.vala"
		i = 0;
#line 2752 "SerializableGeeCollectionsTest.c"
		{
			GeeBidirList* _n_list = NULL;
			GXmlGDocument* _tmp166_;
			GXmlNode* _tmp167_;
			GXmlNode* _tmp168_;
			GXmlNode* _tmp169_;
			GeeBidirList* _tmp170_;
			GeeBidirList* _tmp171_;
			GeeBidirList* _tmp172_;
			gint _n_size = 0;
			GeeBidirList* _tmp173_;
			gint _tmp174_;
			gint _tmp175_;
			gint _n_index = 0;
#line 421 "SerializableGeeCollectionsTest.vala"
			_tmp166_ = ndoc;
#line 421 "SerializableGeeCollectionsTest.vala"
			_tmp167_ = gxml_document_get_root ((GXmlDocument*) _tmp166_);
#line 421 "SerializableGeeCollectionsTest.vala"
			_tmp168_ = _tmp167_;
#line 421 "SerializableGeeCollectionsTest.vala"
			_tmp169_ = _tmp168_;
#line 421 "SerializableGeeCollectionsTest.vala"
			_tmp170_ = gxml_node_get_children_nodes (_tmp169_);
#line 421 "SerializableGeeCollectionsTest.vala"
			_tmp171_ = _tmp170_;
#line 421 "SerializableGeeCollectionsTest.vala"
			_tmp172_ = _tmp171_;
#line 421 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (_tmp169_);
#line 421 "SerializableGeeCollectionsTest.vala"
			_n_list = _tmp172_;
#line 421 "SerializableGeeCollectionsTest.vala"
			_tmp173_ = _n_list;
#line 421 "SerializableGeeCollectionsTest.vala"
			_tmp174_ = gee_collection_get_size ((GeeCollection*) _tmp173_);
#line 421 "SerializableGeeCollectionsTest.vala"
			_tmp175_ = _tmp174_;
#line 421 "SerializableGeeCollectionsTest.vala"
			_n_size = _tmp175_;
#line 421 "SerializableGeeCollectionsTest.vala"
			_n_index = -1;
#line 421 "SerializableGeeCollectionsTest.vala"
			while (TRUE) {
#line 2797 "SerializableGeeCollectionsTest.c"
				GXmlNode* n = NULL;
				GeeBidirList* _tmp176_;
				gpointer _tmp177_;
				gint _tmp178_;
				GXmlNode* _tmp179_;
				GXmlNode* _tmp185_;
				gchar* _tmp186_;
				gchar* _tmp187_;
				gchar* _tmp188_;
				gboolean _tmp189_;
#line 421 "SerializableGeeCollectionsTest.vala"
				_n_index = _n_index + 1;
#line 421 "SerializableGeeCollectionsTest.vala"
				if (!(_n_index < _n_size)) {
#line 421 "SerializableGeeCollectionsTest.vala"
					break;
#line 2814 "SerializableGeeCollectionsTest.c"
				}
#line 421 "SerializableGeeCollectionsTest.vala"
				_tmp176_ = _n_list;
#line 421 "SerializableGeeCollectionsTest.vala"
				_tmp177_ = gee_list_get ((GeeList*) _tmp176_, _n_index);
#line 421 "SerializableGeeCollectionsTest.vala"
				n = (GXmlNode*) _tmp177_;
#line 423 "SerializableGeeCollectionsTest.vala"
				_tmp178_ = i;
#line 423 "SerializableGeeCollectionsTest.vala"
				i = _tmp178_ + 1;
#line 424 "SerializableGeeCollectionsTest.vala"
				_tmp179_ = n;
#line 424 "SerializableGeeCollectionsTest.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp179_, GXML_TYPE_TEXT)) {
#line 2830 "SerializableGeeCollectionsTest.c"
					GXmlNode* _tmp180_;
					gchar* _tmp181_;
					gchar* _tmp182_;
					gchar* _tmp183_;
					gboolean _tmp184_;
#line 424 "SerializableGeeCollectionsTest.vala"
					_tmp180_ = n;
#line 424 "SerializableGeeCollectionsTest.vala"
					_tmp181_ = gxml_node_get_value (_tmp180_);
#line 424 "SerializableGeeCollectionsTest.vala"
					_tmp182_ = _tmp181_;
#line 424 "SerializableGeeCollectionsTest.vala"
					_tmp183_ = _tmp182_;
#line 424 "SerializableGeeCollectionsTest.vala"
					_tmp184_ = g_strcmp0 (_tmp183_, "") != 0;
#line 424 "SerializableGeeCollectionsTest.vala"
					_g_free0 (_tmp183_);
#line 424 "SerializableGeeCollectionsTest.vala"
					if (_tmp184_) {
#line 424 "SerializableGeeCollectionsTest.vala"
						g_assert_not_reached ();
#line 2852 "SerializableGeeCollectionsTest.c"
					}
				}
#line 425 "SerializableGeeCollectionsTest.vala"
				_tmp185_ = n;
#line 425 "SerializableGeeCollectionsTest.vala"
				_tmp186_ = gxml_node_get_name (_tmp185_);
#line 425 "SerializableGeeCollectionsTest.vala"
				_tmp187_ = _tmp186_;
#line 425 "SerializableGeeCollectionsTest.vala"
				_tmp188_ = _tmp187_;
#line 425 "SerializableGeeCollectionsTest.vala"
				_tmp189_ = g_strcmp0 (_tmp188_, "ChargeZone") == 0;
#line 425 "SerializableGeeCollectionsTest.vala"
				_g_free0 (_tmp188_);
#line 425 "SerializableGeeCollectionsTest.vala"
				if (_tmp189_) {
#line 2869 "SerializableGeeCollectionsTest.c"
					{
						GeeBidirList* _cn_list = NULL;
						GXmlNode* _tmp190_;
						GeeBidirList* _tmp191_;
						GeeBidirList* _tmp192_;
						gint _cn_size = 0;
						GeeBidirList* _tmp193_;
						gint _tmp194_;
						gint _tmp195_;
						gint _cn_index = 0;
#line 426 "SerializableGeeCollectionsTest.vala"
						_tmp190_ = n;
#line 426 "SerializableGeeCollectionsTest.vala"
						_tmp191_ = gxml_node_get_children_nodes (_tmp190_);
#line 426 "SerializableGeeCollectionsTest.vala"
						_tmp192_ = _tmp191_;
#line 426 "SerializableGeeCollectionsTest.vala"
						_cn_list = _tmp192_;
#line 426 "SerializableGeeCollectionsTest.vala"
						_tmp193_ = _cn_list;
#line 426 "SerializableGeeCollectionsTest.vala"
						_tmp194_ = gee_collection_get_size ((GeeCollection*) _tmp193_);
#line 426 "SerializableGeeCollectionsTest.vala"
						_tmp195_ = _tmp194_;
#line 426 "SerializableGeeCollectionsTest.vala"
						_cn_size = _tmp195_;
#line 426 "SerializableGeeCollectionsTest.vala"
						_cn_index = -1;
#line 426 "SerializableGeeCollectionsTest.vala"
						while (TRUE) {
#line 2900 "SerializableGeeCollectionsTest.c"
							GXmlNode* cn = NULL;
							GeeBidirList* _tmp196_;
							gpointer _tmp197_;
							GXmlNode* _tmp198_;
#line 426 "SerializableGeeCollectionsTest.vala"
							_cn_index = _cn_index + 1;
#line 426 "SerializableGeeCollectionsTest.vala"
							if (!(_cn_index < _cn_size)) {
#line 426 "SerializableGeeCollectionsTest.vala"
								break;
#line 2911 "SerializableGeeCollectionsTest.c"
							}
#line 426 "SerializableGeeCollectionsTest.vala"
							_tmp196_ = _cn_list;
#line 426 "SerializableGeeCollectionsTest.vala"
							_tmp197_ = gee_list_get ((GeeList*) _tmp196_, _cn_index);
#line 426 "SerializableGeeCollectionsTest.vala"
							cn = (GXmlNode*) _tmp197_;
#line 428 "SerializableGeeCollectionsTest.vala"
							_tmp198_ = cn;
#line 428 "SerializableGeeCollectionsTest.vala"
							if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp198_, GXML_TYPE_TEXT)) {
#line 2923 "SerializableGeeCollectionsTest.c"
								GXmlNode* _tmp199_;
								gchar* _tmp200_;
								gchar* _tmp201_;
								gchar* _tmp202_;
								gboolean _tmp203_;
#line 428 "SerializableGeeCollectionsTest.vala"
								_tmp199_ = cn;
#line 428 "SerializableGeeCollectionsTest.vala"
								_tmp200_ = gxml_node_get_value (_tmp199_);
#line 428 "SerializableGeeCollectionsTest.vala"
								_tmp201_ = _tmp200_;
#line 428 "SerializableGeeCollectionsTest.vala"
								_tmp202_ = _tmp201_;
#line 428 "SerializableGeeCollectionsTest.vala"
								_tmp203_ = g_strcmp0 (_tmp202_, "") != 0;
#line 428 "SerializableGeeCollectionsTest.vala"
								_g_free0 (_tmp202_);
#line 428 "SerializableGeeCollectionsTest.vala"
								if (_tmp203_) {
#line 428 "SerializableGeeCollectionsTest.vala"
									g_assert_not_reached ();
#line 2945 "SerializableGeeCollectionsTest.c"
								}
							}
#line 426 "SerializableGeeCollectionsTest.vala"
							_g_object_unref0 (cn);
#line 2950 "SerializableGeeCollectionsTest.c"
						}
#line 426 "SerializableGeeCollectionsTest.vala"
						_g_object_unref0 (_cn_list);
#line 2954 "SerializableGeeCollectionsTest.c"
					}
				}
#line 421 "SerializableGeeCollectionsTest.vala"
				_g_object_unref0 (n);
#line 2959 "SerializableGeeCollectionsTest.c"
			}
#line 421 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (_n_list);
#line 2963 "SerializableGeeCollectionsTest.c"
		}
#line 433 "SerializableGeeCollectionsTest.vala"
		if (i != 2) {
#line 2967 "SerializableGeeCollectionsTest.c"
			FILE* _tmp204_;
			gchar* _tmp205_;
			gchar* _tmp206_;
			gchar* _tmp207_;
			gchar* _tmp208_;
#line 434 "SerializableGeeCollectionsTest.vala"
			_tmp204_ = stdout;
#line 434 "SerializableGeeCollectionsTest.vala"
			_tmp205_ = g_strdup_printf ("%i", i);
#line 434 "SerializableGeeCollectionsTest.vala"
			_tmp206_ = _tmp205_;
#line 434 "SerializableGeeCollectionsTest.vala"
			_tmp207_ = g_strconcat ("ERROR: Bad ROOT child nodes. Expected 5, got ", _tmp206_, "\n", NULL);
#line 434 "SerializableGeeCollectionsTest.vala"
			_tmp208_ = _tmp207_;
#line 434 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp204_, "%s", _tmp208_);
#line 434 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp208_);
#line 434 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp206_);
#line 435 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 2991 "SerializableGeeCollectionsTest.c"
		}
#line 324 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (chip);
#line 324 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (ns);
#line 324 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (ndoc);
#line 324 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (s1);
#line 324 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (s);
#line 324 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (doc);
#line 3005 "SerializableGeeCollectionsTest.c"
	}
	goto __finally370;
	__catch370_g_error:
	{
		GError* e = NULL;
		FILE* _tmp209_;
		const gchar* _tmp210_;
		const gchar* _tmp211_;
		gchar* _tmp212_;
		gchar* _tmp213_;
#line 324 "SerializableGeeCollectionsTest.vala"
		e = _inner_error0_;
#line 324 "SerializableGeeCollectionsTest.vala"
		_inner_error0_ = NULL;
#line 439 "SerializableGeeCollectionsTest.vala"
		_tmp209_ = stdout;
#line 439 "SerializableGeeCollectionsTest.vala"
		_tmp210_ = e->message;
#line 439 "SerializableGeeCollectionsTest.vala"
		_tmp211_ = string_to_string (_tmp210_);
#line 439 "SerializableGeeCollectionsTest.vala"
		_tmp212_ = g_strconcat ("ERROR: ", _tmp211_, NULL);
#line 439 "SerializableGeeCollectionsTest.vala"
		_tmp213_ = _tmp212_;
#line 439 "SerializableGeeCollectionsTest.vala"
		fprintf (_tmp209_, "%s", _tmp213_);
#line 439 "SerializableGeeCollectionsTest.vala"
		_g_free0 (_tmp213_);
#line 440 "SerializableGeeCollectionsTest.vala"
		g_assert_not_reached ();
#line 324 "SerializableGeeCollectionsTest.vala"
		_g_error_free0 (e);
#line 3038 "SerializableGeeCollectionsTest.c"
	}
	__finally370:
#line 324 "SerializableGeeCollectionsTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 324 "SerializableGeeCollectionsTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 324 "SerializableGeeCollectionsTest.vala"
		g_clear_error (&_inner_error0_);
#line 324 "SerializableGeeCollectionsTest.vala"
		return;
#line 3049 "SerializableGeeCollectionsTest.c"
	}
}

static void
___lambda320__gtest_func (void)
{
#line 322 "SerializableGeeCollectionsTest.vala"
	__lambda320_ ();
#line 3058 "SerializableGeeCollectionsTest.c"
}

static void
__lambda321_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* org_doc = NULL;
		GXmlGDocument* _tmp0_;
		SerializableGeeCollectionsTestSpaceBase* s = NULL;
		SerializableGeeCollectionsTestSpaceBase* _tmp1_;
		SerializableGeeCollectionsTestSpaceBase* _tmp2_;
		GXmlGDocument* _tmp3_;
		SerializableGeeCollectionsTestSpaceBase* _tmp4_;
		SerializableGeeCollectionsTestChargeZone* _tmp5_;
		SerializableGeeCollectionsTestChargeZone* _tmp6_;
		SerializableGeeCollectionsTestSpaceBase* _tmp14_;
		SerializableGeeCollectionsTestChargeZone* _tmp15_;
		SerializableGeeCollectionsTestChargeZone* _tmp16_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp17_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp18_;
		gint _tmp19_;
		gint _tmp20_;
		SerializableGeeCollectionsTestSpaceShip* mssh = NULL;
		SerializableGeeCollectionsTestSpaceBase* _tmp33_;
		SerializableGeeCollectionsTestChargeZone* _tmp34_;
		SerializableGeeCollectionsTestChargeZone* _tmp35_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp36_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp37_;
		gpointer _tmp38_;
		SerializableGeeCollectionsTestSpaceShip* _tmp39_;
		SerializableGeeCollectionsTestSpaceBase* _tmp41_;
		SerializableGeeCollectionsTestStorage* _tmp42_;
		SerializableGeeCollectionsTestStorage* _tmp43_;
		SerializableGeeCollectionsTestSpaceShip* _tmp45_;
		SerializableGeeCollectionsTestSpaceCollection* _tmp46_;
		SerializableGeeCollectionsTestSpaceCollection* _tmp47_;
		gint _tmp48_;
		gint _tmp49_;
		SerializableGeeCollectionsTestSpaceBase* _tmp60_;
		SerializableGeeCollectionsTestStorage* _tmp61_;
		SerializableGeeCollectionsTestStorage* _tmp62_;
		SerializableGeeCollectionsTestSpaceBase* _tmp64_;
		SerializableGeeCollectionsTestStorage* _tmp65_;
		SerializableGeeCollectionsTestStorage* _tmp66_;
		SerializableGeeCollectionsTestRefactionCollection* _tmp67_;
		SerializableGeeCollectionsTestRefactionCollection* _tmp68_;
		gint _tmp69_;
		gint _tmp70_;
		SerializableGeeCollectionsTestRefaction* refaction = NULL;
		SerializableGeeCollectionsTestSpaceBase* _tmp83_;
		SerializableGeeCollectionsTestStorage* _tmp84_;
		SerializableGeeCollectionsTestStorage* _tmp85_;
		SerializableGeeCollectionsTestRefactionCollection* _tmp86_;
		SerializableGeeCollectionsTestRefactionCollection* _tmp87_;
		gpointer _tmp88_;
		SerializableGeeCollectionsTestRefaction* _tmp89_;
		GeeMap* ups = NULL;
		SerializableGeeCollectionsTestRefaction* _tmp91_;
		GeeMap* _tmp92_;
		GeeMap* _tmp93_;
		GeeMap* _tmp94_;
		GeeMap* _tmp95_;
		gint _tmp96_;
		gint _tmp97_;
		GeeCollection* uns = NULL;
		SerializableGeeCollectionsTestRefaction* _tmp98_;
		GeeCollection* _tmp99_;
		GeeCollection* _tmp100_;
		GeeCollection* _tmp101_;
		gint _tmp102_;
		gint _tmp103_;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp104_;
		SerializableGeeCollectionsTestSpaceBase* _tmp105_;
		GXmlGDocument* _tmp106_;
		GXmlNode* _tmp107_;
		GXmlNode* _tmp108_;
		GXmlGDocument* _tmp109_;
		GXmlNode* _tmp110_;
		GXmlNode* _tmp111_;
		GXmlNode* _tmp112_;
		gchar* _tmp113_;
		gchar* _tmp114_;
		gchar* _tmp115_;
		gboolean _tmp116_;
#line 446 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"<base name=\"AlphaOne\" >\n" \
"  <chargezone name=\"A1-1\">\n" \
"    <ship manufacturer=\"MacToy\" model=\"A1234\">\n" \
"      <space name=\"Alpha Centaury\">\n" \
"        <planet name=\"Earth\">\n" \
"          <citizen ctype=\"Human\">1M</citizen>\n" \
"          <citizen ctype=\"Ghost\">10M</citizen>\n" \
"        </planet>\n" \
"        <planet name=\"Galiumt\" />\n" \
"      </space>\n" \
"      <space name=\"Galax\">\n" \
"        <planet name=\"Saminon\">\n" \
"          <citizen ctype=\"Humanes\">100M</citizen>\n" \
"          <citizen ctype=\"Jeties\">1000M</citizen>\n" \
"        </planet>\n" \
"        <planet name=\"Keymanth\" />\n" \
"      </space>\n" \
"    </ship>\n" \
"    <ship manufacturer=\"Memphis\" model=\"AB1\">\n" \
"      <space name=\"Proximity\">\n" \
"        <planet name=\"Pluton\">\n" \
"          <citizen ctype=\"Ork\">10000M</citizen>\n" \
"          <citizen ctype=\"Gyk\">100000M</citizen>\n" \
"        </planet>\n" \
"        <planet name=\"Mercury\" />\n" \
"      </space>\n" \
"    </ship>\n" \
"  </chargezone>\n" \
"  <storage name=\"B4-A4\">\n" \
"    <refaction manufacturer=\"MacToy\" model=\"Fly045\">\n" \
"      <ship manufacturer=\"MacToy\" model=\"A1234\" />\n" \
"      <ship manufacturer=\"MegaTrench\" model=\"G045-1\" unknown=\"UNK" \
"NOWN ATTR\">TEST_TEXT</ship>\n" \
"      <UnknownAttribute name=\"nothing\" />\n" \
"    </refaction>\n" \
"  </storage>\n" \
"</base>", 0, &_inner_error0_);
#line 446 "SerializableGeeCollectionsTest.vala"
		org_doc = _tmp0_;
#line 446 "SerializableGeeCollectionsTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 3151 "SerializableGeeCollectionsTest.c"
			goto __catch371_g_error;
		}
#line 483 "SerializableGeeCollectionsTest.vala"
		_tmp1_ = serializable_gee_collections_test_space_base_new ();
#line 483 "SerializableGeeCollectionsTest.vala"
		s = _tmp1_;
#line 484 "SerializableGeeCollectionsTest.vala"
		_tmp2_ = s;
#line 484 "SerializableGeeCollectionsTest.vala"
		_tmp3_ = org_doc;
#line 484 "SerializableGeeCollectionsTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 484 "SerializableGeeCollectionsTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 484 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (s);
#line 484 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (org_doc);
#line 3170 "SerializableGeeCollectionsTest.c"
			goto __catch371_g_error;
		}
#line 485 "SerializableGeeCollectionsTest.vala"
		_tmp4_ = s;
#line 485 "SerializableGeeCollectionsTest.vala"
		_tmp5_ = serializable_gee_collections_test_space_base_get_charge_zone (_tmp4_);
#line 485 "SerializableGeeCollectionsTest.vala"
		_tmp6_ = _tmp5_;
#line 485 "SerializableGeeCollectionsTest.vala"
		if (_tmp6_ == NULL) {
#line 3181 "SerializableGeeCollectionsTest.c"
			FILE* _tmp7_;
			SerializableGeeCollectionsTestSpaceBase* _tmp8_;
			const gchar* _tmp9_;
			const gchar* _tmp10_;
			const gchar* _tmp11_;
			gchar* _tmp12_;
			gchar* _tmp13_;
#line 486 "SerializableGeeCollectionsTest.vala"
			_tmp7_ = stdout;
#line 486 "SerializableGeeCollectionsTest.vala"
			_tmp8_ = s;
#line 486 "SerializableGeeCollectionsTest.vala"
			_tmp9_ = serializable_gee_collections_test_space_base_get_name (_tmp8_);
#line 486 "SerializableGeeCollectionsTest.vala"
			_tmp10_ = _tmp9_;
#line 486 "SerializableGeeCollectionsTest.vala"
			_tmp11_ = string_to_string (_tmp10_);
#line 486 "SerializableGeeCollectionsTest.vala"
			_tmp12_ = g_strconcat ("ERROR: No charge Zone for ", _tmp11_, "\n", NULL);
#line 486 "SerializableGeeCollectionsTest.vala"
			_tmp13_ = _tmp12_;
#line 486 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp7_, "%s", _tmp13_);
#line 486 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp13_);
#line 487 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 3209 "SerializableGeeCollectionsTest.c"
		}
#line 489 "SerializableGeeCollectionsTest.vala"
		_tmp14_ = s;
#line 489 "SerializableGeeCollectionsTest.vala"
		_tmp15_ = serializable_gee_collections_test_space_base_get_charge_zone (_tmp14_);
#line 489 "SerializableGeeCollectionsTest.vala"
		_tmp16_ = _tmp15_;
#line 489 "SerializableGeeCollectionsTest.vala"
		_tmp17_ = serializable_gee_collections_test_charge_zone_get_spaceships (_tmp16_);
#line 489 "SerializableGeeCollectionsTest.vala"
		_tmp18_ = _tmp17_;
#line 489 "SerializableGeeCollectionsTest.vala"
		_tmp19_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp18_);
#line 489 "SerializableGeeCollectionsTest.vala"
		_tmp20_ = _tmp19_;
#line 489 "SerializableGeeCollectionsTest.vala"
		if (_tmp20_ != 2) {
#line 3227 "SerializableGeeCollectionsTest.c"
			FILE* _tmp21_;
			SerializableGeeCollectionsTestSpaceBase* _tmp22_;
			SerializableGeeCollectionsTestChargeZone* _tmp23_;
			SerializableGeeCollectionsTestChargeZone* _tmp24_;
			SerializableGeeCollectionsTestSpaceShipCollection* _tmp25_;
			SerializableGeeCollectionsTestSpaceShipCollection* _tmp26_;
			gint _tmp27_;
			gint _tmp28_;
			gchar* _tmp29_;
			gchar* _tmp30_;
			gchar* _tmp31_;
			gchar* _tmp32_;
#line 490 "SerializableGeeCollectionsTest.vala"
			_tmp21_ = stdout;
#line 490 "SerializableGeeCollectionsTest.vala"
			_tmp22_ = s;
#line 490 "SerializableGeeCollectionsTest.vala"
			_tmp23_ = serializable_gee_collections_test_space_base_get_charge_zone (_tmp22_);
#line 490 "SerializableGeeCollectionsTest.vala"
			_tmp24_ = _tmp23_;
#line 490 "SerializableGeeCollectionsTest.vala"
			_tmp25_ = serializable_gee_collections_test_charge_zone_get_spaceships (_tmp24_);
#line 490 "SerializableGeeCollectionsTest.vala"
			_tmp26_ = _tmp25_;
#line 490 "SerializableGeeCollectionsTest.vala"
			_tmp27_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp26_);
#line 490 "SerializableGeeCollectionsTest.vala"
			_tmp28_ = _tmp27_;
#line 490 "SerializableGeeCollectionsTest.vala"
			_tmp29_ = g_strdup_printf ("%i", _tmp28_);
#line 490 "SerializableGeeCollectionsTest.vala"
			_tmp30_ = _tmp29_;
#line 490 "SerializableGeeCollectionsTest.vala"
			_tmp31_ = g_strconcat ("ERROR: Bad SpaceShip size: ", _tmp30_, "\n", NULL);
#line 490 "SerializableGeeCollectionsTest.vala"
			_tmp32_ = _tmp31_;
#line 490 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp21_, "%s", _tmp32_);
#line 490 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp32_);
#line 490 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp30_);
#line 491 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 3272 "SerializableGeeCollectionsTest.c"
		}
#line 493 "SerializableGeeCollectionsTest.vala"
		_tmp33_ = s;
#line 493 "SerializableGeeCollectionsTest.vala"
		_tmp34_ = serializable_gee_collections_test_space_base_get_charge_zone (_tmp33_);
#line 493 "SerializableGeeCollectionsTest.vala"
		_tmp35_ = _tmp34_;
#line 493 "SerializableGeeCollectionsTest.vala"
		_tmp36_ = serializable_gee_collections_test_charge_zone_get_spaceships (_tmp35_);
#line 493 "SerializableGeeCollectionsTest.vala"
		_tmp37_ = _tmp36_;
#line 493 "SerializableGeeCollectionsTest.vala"
		_tmp38_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp37_, "MacToy", "A1234");
#line 493 "SerializableGeeCollectionsTest.vala"
		mssh = (SerializableGeeCollectionsTestSpaceShip*) _tmp38_;
#line 494 "SerializableGeeCollectionsTest.vala"
		_tmp39_ = mssh;
#line 494 "SerializableGeeCollectionsTest.vala"
		if (_tmp39_ == NULL) {
#line 3292 "SerializableGeeCollectionsTest.c"
			FILE* _tmp40_;
#line 495 "SerializableGeeCollectionsTest.vala"
			_tmp40_ = stdout;
#line 495 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp40_, "%s", "ERROR: No spaceship MacToy/A1234\n");
#line 496 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 3300 "SerializableGeeCollectionsTest.c"
		}
#line 499 "SerializableGeeCollectionsTest.vala"
		_tmp41_ = s;
#line 499 "SerializableGeeCollectionsTest.vala"
		_tmp42_ = serializable_gee_collections_test_space_base_get_storage (_tmp41_);
#line 499 "SerializableGeeCollectionsTest.vala"
		_tmp43_ = _tmp42_;
#line 499 "SerializableGeeCollectionsTest.vala"
		if (_tmp43_ == NULL) {
#line 3310 "SerializableGeeCollectionsTest.c"
			FILE* _tmp44_;
#line 500 "SerializableGeeCollectionsTest.vala"
			_tmp44_ = stdout;
#line 500 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp44_, "%s", "ERROR: No storage\n");
#line 501 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 3318 "SerializableGeeCollectionsTest.c"
		}
#line 503 "SerializableGeeCollectionsTest.vala"
		_tmp45_ = mssh;
#line 503 "SerializableGeeCollectionsTest.vala"
		_tmp46_ = serializable_gee_collections_test_space_ship_get_spaces (_tmp45_);
#line 503 "SerializableGeeCollectionsTest.vala"
		_tmp47_ = _tmp46_;
#line 503 "SerializableGeeCollectionsTest.vala"
		_tmp48_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp47_);
#line 503 "SerializableGeeCollectionsTest.vala"
		_tmp49_ = _tmp48_;
#line 503 "SerializableGeeCollectionsTest.vala"
		if (_tmp49_ != 2) {
#line 3332 "SerializableGeeCollectionsTest.c"
			FILE* _tmp50_;
			SerializableGeeCollectionsTestSpaceShip* _tmp51_;
			SerializableGeeCollectionsTestSpaceCollection* _tmp52_;
			SerializableGeeCollectionsTestSpaceCollection* _tmp53_;
			gint _tmp54_;
			gint _tmp55_;
			gchar* _tmp56_;
			gchar* _tmp57_;
			gchar* _tmp58_;
			gchar* _tmp59_;
#line 504 "SerializableGeeCollectionsTest.vala"
			_tmp50_ = stdout;
#line 504 "SerializableGeeCollectionsTest.vala"
			_tmp51_ = mssh;
#line 504 "SerializableGeeCollectionsTest.vala"
			_tmp52_ = serializable_gee_collections_test_space_ship_get_spaces (_tmp51_);
#line 504 "SerializableGeeCollectionsTest.vala"
			_tmp53_ = _tmp52_;
#line 504 "SerializableGeeCollectionsTest.vala"
			_tmp54_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp53_);
#line 504 "SerializableGeeCollectionsTest.vala"
			_tmp55_ = _tmp54_;
#line 504 "SerializableGeeCollectionsTest.vala"
			_tmp56_ = g_strdup_printf ("%i", _tmp55_);
#line 504 "SerializableGeeCollectionsTest.vala"
			_tmp57_ = _tmp56_;
#line 504 "SerializableGeeCollectionsTest.vala"
			_tmp58_ = g_strconcat ("ERROR: Bad spaces number for MacToy/A1234: ", _tmp57_, "\n", NULL);
#line 504 "SerializableGeeCollectionsTest.vala"
			_tmp59_ = _tmp58_;
#line 504 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp50_, "%s", _tmp59_);
#line 504 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp59_);
#line 504 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp57_);
#line 505 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 3371 "SerializableGeeCollectionsTest.c"
		}
#line 507 "SerializableGeeCollectionsTest.vala"
		_tmp60_ = s;
#line 507 "SerializableGeeCollectionsTest.vala"
		_tmp61_ = serializable_gee_collections_test_space_base_get_storage (_tmp60_);
#line 507 "SerializableGeeCollectionsTest.vala"
		_tmp62_ = _tmp61_;
#line 507 "SerializableGeeCollectionsTest.vala"
		if (_tmp62_ == NULL) {
#line 3381 "SerializableGeeCollectionsTest.c"
			FILE* _tmp63_;
#line 508 "SerializableGeeCollectionsTest.vala"
			_tmp63_ = stdout;
#line 508 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp63_, "%s", "ERROR: No storage\n");
#line 509 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 3389 "SerializableGeeCollectionsTest.c"
		}
#line 511 "SerializableGeeCollectionsTest.vala"
		_tmp64_ = s;
#line 511 "SerializableGeeCollectionsTest.vala"
		_tmp65_ = serializable_gee_collections_test_space_base_get_storage (_tmp64_);
#line 511 "SerializableGeeCollectionsTest.vala"
		_tmp66_ = _tmp65_;
#line 511 "SerializableGeeCollectionsTest.vala"
		_tmp67_ = serializable_gee_collections_test_storage_get_refactions (_tmp66_);
#line 511 "SerializableGeeCollectionsTest.vala"
		_tmp68_ = _tmp67_;
#line 511 "SerializableGeeCollectionsTest.vala"
		_tmp69_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp68_);
#line 511 "SerializableGeeCollectionsTest.vala"
		_tmp70_ = _tmp69_;
#line 511 "SerializableGeeCollectionsTest.vala"
		if (_tmp70_ != 1) {
#line 3407 "SerializableGeeCollectionsTest.c"
			FILE* _tmp71_;
			SerializableGeeCollectionsTestSpaceBase* _tmp72_;
			SerializableGeeCollectionsTestStorage* _tmp73_;
			SerializableGeeCollectionsTestStorage* _tmp74_;
			SerializableGeeCollectionsTestRefactionCollection* _tmp75_;
			SerializableGeeCollectionsTestRefactionCollection* _tmp76_;
			gint _tmp77_;
			gint _tmp78_;
			gchar* _tmp79_;
			gchar* _tmp80_;
			gchar* _tmp81_;
			gchar* _tmp82_;
#line 512 "SerializableGeeCollectionsTest.vala"
			_tmp71_ = stdout;
#line 512 "SerializableGeeCollectionsTest.vala"
			_tmp72_ = s;
#line 512 "SerializableGeeCollectionsTest.vala"
			_tmp73_ = serializable_gee_collections_test_space_base_get_storage (_tmp72_);
#line 512 "SerializableGeeCollectionsTest.vala"
			_tmp74_ = _tmp73_;
#line 512 "SerializableGeeCollectionsTest.vala"
			_tmp75_ = serializable_gee_collections_test_storage_get_refactions (_tmp74_);
#line 512 "SerializableGeeCollectionsTest.vala"
			_tmp76_ = _tmp75_;
#line 512 "SerializableGeeCollectionsTest.vala"
			_tmp77_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp76_);
#line 512 "SerializableGeeCollectionsTest.vala"
			_tmp78_ = _tmp77_;
#line 512 "SerializableGeeCollectionsTest.vala"
			_tmp79_ = g_strdup_printf ("%i", _tmp78_);
#line 512 "SerializableGeeCollectionsTest.vala"
			_tmp80_ = _tmp79_;
#line 512 "SerializableGeeCollectionsTest.vala"
			_tmp81_ = g_strconcat ("ERROR: Bad number of refactions: got ", _tmp80_, "\n", NULL);
#line 512 "SerializableGeeCollectionsTest.vala"
			_tmp82_ = _tmp81_;
#line 512 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp71_, "%s", _tmp82_);
#line 512 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp82_);
#line 512 "SerializableGeeCollectionsTest.vala"
			_g_free0 (_tmp80_);
#line 513 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 3452 "SerializableGeeCollectionsTest.c"
		}
#line 515 "SerializableGeeCollectionsTest.vala"
		_tmp83_ = s;
#line 515 "SerializableGeeCollectionsTest.vala"
		_tmp84_ = serializable_gee_collections_test_space_base_get_storage (_tmp83_);
#line 515 "SerializableGeeCollectionsTest.vala"
		_tmp85_ = _tmp84_;
#line 515 "SerializableGeeCollectionsTest.vala"
		_tmp86_ = serializable_gee_collections_test_storage_get_refactions (_tmp85_);
#line 515 "SerializableGeeCollectionsTest.vala"
		_tmp87_ = _tmp86_;
#line 515 "SerializableGeeCollectionsTest.vala"
		_tmp88_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp87_, "MacToy", "Fly045");
#line 515 "SerializableGeeCollectionsTest.vala"
		refaction = (SerializableGeeCollectionsTestRefaction*) _tmp88_;
#line 516 "SerializableGeeCollectionsTest.vala"
		_tmp89_ = refaction;
#line 516 "SerializableGeeCollectionsTest.vala"
		if (_tmp89_ == NULL) {
#line 3472 "SerializableGeeCollectionsTest.c"
			FILE* _tmp90_;
#line 517 "SerializableGeeCollectionsTest.vala"
			_tmp90_ = stdout;
#line 517 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp90_, "%s", "ERROR: No Refaction MacToy/Fly045 found!\n");
#line 518 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 3480 "SerializableGeeCollectionsTest.c"
		}
#line 520 "SerializableGeeCollectionsTest.vala"
		_tmp91_ = refaction;
#line 520 "SerializableGeeCollectionsTest.vala"
		_tmp92_ = gxml_serializable_get_unknown_serializable_properties ((GXmlSerializable*) _tmp91_);
#line 520 "SerializableGeeCollectionsTest.vala"
		_tmp93_ = _tmp92_;
#line 520 "SerializableGeeCollectionsTest.vala"
		ups = _tmp93_;
#line 521 "SerializableGeeCollectionsTest.vala"
		_tmp94_ = ups;
#line 521 "SerializableGeeCollectionsTest.vala"
		_vala_assert (_tmp94_ != NULL, "ups != null");
#line 522 "SerializableGeeCollectionsTest.vala"
		_tmp95_ = ups;
#line 522 "SerializableGeeCollectionsTest.vala"
		_tmp96_ = gee_map_get_size (_tmp95_);
#line 522 "SerializableGeeCollectionsTest.vala"
		_tmp97_ = _tmp96_;
#line 522 "SerializableGeeCollectionsTest.vala"
		_vala_assert (_tmp97_ == 0, "ups.size == 0");
#line 523 "SerializableGeeCollectionsTest.vala"
		_tmp98_ = refaction;
#line 523 "SerializableGeeCollectionsTest.vala"
		_tmp99_ = gxml_serializable_get_unknown_serializable_nodes ((GXmlSerializable*) _tmp98_);
#line 523 "SerializableGeeCollectionsTest.vala"
		_tmp100_ = _tmp99_;
#line 523 "SerializableGeeCollectionsTest.vala"
		uns = _tmp100_;
#line 530 "SerializableGeeCollectionsTest.vala"
		_tmp101_ = uns;
#line 530 "SerializableGeeCollectionsTest.vala"
		_tmp102_ = gee_collection_get_size (_tmp101_);
#line 530 "SerializableGeeCollectionsTest.vala"
		_tmp103_ = _tmp102_;
#line 530 "SerializableGeeCollectionsTest.vala"
		_vala_assert (_tmp103_ == 5, "uns.size == 5");
#line 531 "SerializableGeeCollectionsTest.vala"
		_tmp104_ = gxml_gdocument_new ();
#line 531 "SerializableGeeCollectionsTest.vala"
		doc = _tmp104_;
#line 532 "SerializableGeeCollectionsTest.vala"
		_tmp105_ = s;
#line 532 "SerializableGeeCollectionsTest.vala"
		_tmp106_ = doc;
#line 532 "SerializableGeeCollectionsTest.vala"
		_tmp107_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp105_, (GXmlNode*) _tmp106_, &_inner_error0_);
#line 532 "SerializableGeeCollectionsTest.vala"
		_tmp108_ = _tmp107_;
#line 532 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp108_);
#line 532 "SerializableGeeCollectionsTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 532 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (doc);
#line 532 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (uns);
#line 532 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (ups);
#line 532 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (refaction);
#line 532 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (mssh);
#line 532 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (s);
#line 532 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (org_doc);
#line 3548 "SerializableGeeCollectionsTest.c"
			goto __catch371_g_error;
		}
#line 533 "SerializableGeeCollectionsTest.vala"
		_tmp109_ = doc;
#line 533 "SerializableGeeCollectionsTest.vala"
		_tmp110_ = gxml_document_get_root ((GXmlDocument*) _tmp109_);
#line 533 "SerializableGeeCollectionsTest.vala"
		_tmp111_ = _tmp110_;
#line 533 "SerializableGeeCollectionsTest.vala"
		_tmp112_ = _tmp111_;
#line 533 "SerializableGeeCollectionsTest.vala"
		_tmp113_ = gxml_node_get_name (_tmp112_);
#line 533 "SerializableGeeCollectionsTest.vala"
		_tmp114_ = _tmp113_;
#line 533 "SerializableGeeCollectionsTest.vala"
		_tmp115_ = _tmp114_;
#line 533 "SerializableGeeCollectionsTest.vala"
		_tmp116_ = g_strcmp0 (_tmp115_, "base") != 0;
#line 533 "SerializableGeeCollectionsTest.vala"
		_g_free0 (_tmp115_);
#line 533 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp112_);
#line 533 "SerializableGeeCollectionsTest.vala"
		if (_tmp116_) {
#line 3573 "SerializableGeeCollectionsTest.c"
			FILE* _tmp117_;
#line 534 "SerializableGeeCollectionsTest.vala"
			_tmp117_ = stdout;
#line 534 "SerializableGeeCollectionsTest.vala"
			fprintf (_tmp117_, "%s", "ERROR: bad root node name\n");
#line 535 "SerializableGeeCollectionsTest.vala"
			g_assert_not_reached ();
#line 3581 "SerializableGeeCollectionsTest.c"
		}
		{
			GeeBidirList* _n_list = NULL;
			GXmlGDocument* _tmp118_;
			GXmlNode* _tmp119_;
			GXmlNode* _tmp120_;
			GXmlNode* _tmp121_;
			GeeBidirList* _tmp122_;
			GeeBidirList* _tmp123_;
			GeeBidirList* _tmp124_;
			gint _n_size = 0;
			GeeBidirList* _tmp125_;
			gint _tmp126_;
			gint _tmp127_;
			gint _n_index = 0;
#line 538 "SerializableGeeCollectionsTest.vala"
			_tmp118_ = doc;
#line 538 "SerializableGeeCollectionsTest.vala"
			_tmp119_ = gxml_document_get_root ((GXmlDocument*) _tmp118_);
#line 538 "SerializableGeeCollectionsTest.vala"
			_tmp120_ = _tmp119_;
#line 538 "SerializableGeeCollectionsTest.vala"
			_tmp121_ = _tmp120_;
#line 538 "SerializableGeeCollectionsTest.vala"
			_tmp122_ = gxml_node_get_children_nodes (_tmp121_);
#line 538 "SerializableGeeCollectionsTest.vala"
			_tmp123_ = _tmp122_;
#line 538 "SerializableGeeCollectionsTest.vala"
			_tmp124_ = _tmp123_;
#line 538 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (_tmp121_);
#line 538 "SerializableGeeCollectionsTest.vala"
			_n_list = _tmp124_;
#line 538 "SerializableGeeCollectionsTest.vala"
			_tmp125_ = _n_list;
#line 538 "SerializableGeeCollectionsTest.vala"
			_tmp126_ = gee_collection_get_size ((GeeCollection*) _tmp125_);
#line 538 "SerializableGeeCollectionsTest.vala"
			_tmp127_ = _tmp126_;
#line 538 "SerializableGeeCollectionsTest.vala"
			_n_size = _tmp127_;
#line 538 "SerializableGeeCollectionsTest.vala"
			_n_index = -1;
#line 538 "SerializableGeeCollectionsTest.vala"
			while (TRUE) {
#line 3627 "SerializableGeeCollectionsTest.c"
				GXmlNode* n = NULL;
				GeeBidirList* _tmp128_;
				gpointer _tmp129_;
				GXmlNode* _tmp130_;
				GXmlNode* _tmp241_;
#line 538 "SerializableGeeCollectionsTest.vala"
				_n_index = _n_index + 1;
#line 538 "SerializableGeeCollectionsTest.vala"
				if (!(_n_index < _n_size)) {
#line 538 "SerializableGeeCollectionsTest.vala"
					break;
#line 3639 "SerializableGeeCollectionsTest.c"
				}
#line 538 "SerializableGeeCollectionsTest.vala"
				_tmp128_ = _n_list;
#line 538 "SerializableGeeCollectionsTest.vala"
				_tmp129_ = gee_list_get ((GeeList*) _tmp128_, _n_index);
#line 538 "SerializableGeeCollectionsTest.vala"
				n = (GXmlNode*) _tmp129_;
#line 539 "SerializableGeeCollectionsTest.vala"
				_tmp130_ = n;
#line 539 "SerializableGeeCollectionsTest.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp130_, GXML_TYPE_GELEMENT)) {
#line 3651 "SerializableGeeCollectionsTest.c"
					GXmlNode* _tmp131_;
					gchar* _tmp132_;
					gchar* _tmp133_;
					gchar* _tmp134_;
					gboolean _tmp135_;
					GXmlNode* _tmp136_;
					gchar* _tmp137_;
					gchar* _tmp138_;
					gchar* _tmp139_;
					gboolean _tmp140_;
#line 540 "SerializableGeeCollectionsTest.vala"
					_tmp131_ = n;
#line 540 "SerializableGeeCollectionsTest.vala"
					_tmp132_ = gxml_node_get_name (_tmp131_);
#line 540 "SerializableGeeCollectionsTest.vala"
					_tmp133_ = _tmp132_;
#line 540 "SerializableGeeCollectionsTest.vala"
					_tmp134_ = _tmp133_;
#line 540 "SerializableGeeCollectionsTest.vala"
					_tmp135_ = g_strcmp0 (_tmp134_, "ChargeZone") == 0;
#line 540 "SerializableGeeCollectionsTest.vala"
					_g_free0 (_tmp134_);
#line 540 "SerializableGeeCollectionsTest.vala"
					if (_tmp135_) {
#line 3676 "SerializableGeeCollectionsTest.c"
					}
#line 543 "SerializableGeeCollectionsTest.vala"
					_tmp136_ = n;
#line 543 "SerializableGeeCollectionsTest.vala"
					_tmp137_ = gxml_node_get_name (_tmp136_);
#line 543 "SerializableGeeCollectionsTest.vala"
					_tmp138_ = _tmp137_;
#line 543 "SerializableGeeCollectionsTest.vala"
					_tmp139_ = _tmp138_;
#line 543 "SerializableGeeCollectionsTest.vala"
					_tmp140_ = g_strcmp0 (_tmp139_, "storage") == 0;
#line 543 "SerializableGeeCollectionsTest.vala"
					_g_free0 (_tmp139_);
#line 543 "SerializableGeeCollectionsTest.vala"
					if (_tmp140_) {
#line 3692 "SerializableGeeCollectionsTest.c"
						gboolean unkfound = FALSE;
						gboolean tfound = FALSE;
						gboolean attrfound = FALSE;
#line 544 "SerializableGeeCollectionsTest.vala"
						unkfound = FALSE;
#line 545 "SerializableGeeCollectionsTest.vala"
						tfound = FALSE;
#line 546 "SerializableGeeCollectionsTest.vala"
						attrfound = FALSE;
#line 3702 "SerializableGeeCollectionsTest.c"
						{
							GeeBidirList* _sn_list = NULL;
							GXmlNode* _tmp141_;
							GeeBidirList* _tmp142_;
							GeeBidirList* _tmp143_;
							gint _sn_size = 0;
							GeeBidirList* _tmp144_;
							gint _tmp145_;
							gint _tmp146_;
							gint _sn_index = 0;
#line 547 "SerializableGeeCollectionsTest.vala"
							_tmp141_ = n;
#line 547 "SerializableGeeCollectionsTest.vala"
							_tmp142_ = gxml_node_get_children_nodes (_tmp141_);
#line 547 "SerializableGeeCollectionsTest.vala"
							_tmp143_ = _tmp142_;
#line 547 "SerializableGeeCollectionsTest.vala"
							_sn_list = _tmp143_;
#line 547 "SerializableGeeCollectionsTest.vala"
							_tmp144_ = _sn_list;
#line 547 "SerializableGeeCollectionsTest.vala"
							_tmp145_ = gee_collection_get_size ((GeeCollection*) _tmp144_);
#line 547 "SerializableGeeCollectionsTest.vala"
							_tmp146_ = _tmp145_;
#line 547 "SerializableGeeCollectionsTest.vala"
							_sn_size = _tmp146_;
#line 547 "SerializableGeeCollectionsTest.vala"
							_sn_index = -1;
#line 547 "SerializableGeeCollectionsTest.vala"
							while (TRUE) {
#line 3733 "SerializableGeeCollectionsTest.c"
								GXmlNode* sn = NULL;
								GeeBidirList* _tmp147_;
								gpointer _tmp148_;
								GXmlNode* _tmp149_;
#line 547 "SerializableGeeCollectionsTest.vala"
								_sn_index = _sn_index + 1;
#line 547 "SerializableGeeCollectionsTest.vala"
								if (!(_sn_index < _sn_size)) {
#line 547 "SerializableGeeCollectionsTest.vala"
									break;
#line 3744 "SerializableGeeCollectionsTest.c"
								}
#line 547 "SerializableGeeCollectionsTest.vala"
								_tmp147_ = _sn_list;
#line 547 "SerializableGeeCollectionsTest.vala"
								_tmp148_ = gee_list_get ((GeeList*) _tmp147_, _sn_index);
#line 547 "SerializableGeeCollectionsTest.vala"
								sn = (GXmlNode*) _tmp148_;
#line 548 "SerializableGeeCollectionsTest.vala"
								_tmp149_ = sn;
#line 548 "SerializableGeeCollectionsTest.vala"
								if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp149_, GXML_TYPE_GELEMENT)) {
#line 3756 "SerializableGeeCollectionsTest.c"
									GXmlNode* _tmp150_;
									gchar* _tmp151_;
									gchar* _tmp152_;
									gchar* _tmp153_;
									gboolean _tmp154_;
#line 549 "SerializableGeeCollectionsTest.vala"
									_tmp150_ = sn;
#line 549 "SerializableGeeCollectionsTest.vala"
									_tmp151_ = gxml_node_get_name (_tmp150_);
#line 549 "SerializableGeeCollectionsTest.vala"
									_tmp152_ = _tmp151_;
#line 549 "SerializableGeeCollectionsTest.vala"
									_tmp153_ = _tmp152_;
#line 549 "SerializableGeeCollectionsTest.vala"
									_tmp154_ = g_strcmp0 (_tmp153_, "refaction") == 0;
#line 549 "SerializableGeeCollectionsTest.vala"
									_g_free0 (_tmp153_);
#line 549 "SerializableGeeCollectionsTest.vala"
									if (_tmp154_) {
#line 3776 "SerializableGeeCollectionsTest.c"
										{
											GeeBidirList* _rn_list = NULL;
											GXmlNode* _tmp155_;
											GeeBidirList* _tmp156_;
											GeeBidirList* _tmp157_;
											gint _rn_size = 0;
											GeeBidirList* _tmp158_;
											gint _tmp159_;
											gint _tmp160_;
											gint _rn_index = 0;
#line 550 "SerializableGeeCollectionsTest.vala"
											_tmp155_ = sn;
#line 550 "SerializableGeeCollectionsTest.vala"
											_tmp156_ = gxml_node_get_children_nodes (_tmp155_);
#line 550 "SerializableGeeCollectionsTest.vala"
											_tmp157_ = _tmp156_;
#line 550 "SerializableGeeCollectionsTest.vala"
											_rn_list = _tmp157_;
#line 550 "SerializableGeeCollectionsTest.vala"
											_tmp158_ = _rn_list;
#line 550 "SerializableGeeCollectionsTest.vala"
											_tmp159_ = gee_collection_get_size ((GeeCollection*) _tmp158_);
#line 550 "SerializableGeeCollectionsTest.vala"
											_tmp160_ = _tmp159_;
#line 550 "SerializableGeeCollectionsTest.vala"
											_rn_size = _tmp160_;
#line 550 "SerializableGeeCollectionsTest.vala"
											_rn_index = -1;
#line 550 "SerializableGeeCollectionsTest.vala"
											while (TRUE) {
#line 3807 "SerializableGeeCollectionsTest.c"
												GXmlNode* rn = NULL;
												GeeBidirList* _tmp161_;
												gpointer _tmp162_;
												GXmlNode* _tmp163_;
#line 550 "SerializableGeeCollectionsTest.vala"
												_rn_index = _rn_index + 1;
#line 550 "SerializableGeeCollectionsTest.vala"
												if (!(_rn_index < _rn_size)) {
#line 550 "SerializableGeeCollectionsTest.vala"
													break;
#line 3818 "SerializableGeeCollectionsTest.c"
												}
#line 550 "SerializableGeeCollectionsTest.vala"
												_tmp161_ = _rn_list;
#line 550 "SerializableGeeCollectionsTest.vala"
												_tmp162_ = gee_list_get ((GeeList*) _tmp161_, _rn_index);
#line 550 "SerializableGeeCollectionsTest.vala"
												rn = (GXmlNode*) _tmp162_;
#line 551 "SerializableGeeCollectionsTest.vala"
												_tmp163_ = rn;
#line 551 "SerializableGeeCollectionsTest.vala"
												if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp163_, GXML_TYPE_GELEMENT)) {
#line 3830 "SerializableGeeCollectionsTest.c"
													GXmlNode* _tmp164_;
													gchar* _tmp165_;
													gchar* _tmp166_;
													gchar* _tmp167_;
													gboolean _tmp168_;
													GXmlNode* _tmp216_;
													gchar* _tmp217_;
													gchar* _tmp218_;
													gchar* _tmp219_;
													gboolean _tmp220_;
#line 553 "SerializableGeeCollectionsTest.vala"
													_tmp164_ = rn;
#line 553 "SerializableGeeCollectionsTest.vala"
													_tmp165_ = gxml_node_get_name (_tmp164_);
#line 553 "SerializableGeeCollectionsTest.vala"
													_tmp166_ = _tmp165_;
#line 553 "SerializableGeeCollectionsTest.vala"
													_tmp167_ = _tmp166_;
#line 553 "SerializableGeeCollectionsTest.vala"
													_tmp168_ = g_strcmp0 (_tmp167_, "ship") == 0;
#line 553 "SerializableGeeCollectionsTest.vala"
													_g_free0 (_tmp167_);
#line 553 "SerializableGeeCollectionsTest.vala"
													if (_tmp168_) {
#line 3855 "SerializableGeeCollectionsTest.c"
														GXmlNode* atr = NULL;
														GXmlNode* _tmp169_;
														GXmlNode* _tmp170_;
														GXmlNode* _tmp171_;
														GXmlNode* _tmp173_;
														gchar* _tmp174_;
														gchar* _tmp175_;
														gchar* _tmp176_;
														gboolean _tmp177_;
#line 554 "SerializableGeeCollectionsTest.vala"
														_tmp169_ = rn;
#line 554 "SerializableGeeCollectionsTest.vala"
														_tmp170_ = gxml_element_get_attr ((GXmlElement*) G_TYPE_CHECK_INSTANCE_CAST (_tmp169_, GXML_TYPE_GELEMENT, GXmlGElement), "manufacturer");
#line 554 "SerializableGeeCollectionsTest.vala"
														atr = _tmp170_;
#line 555 "SerializableGeeCollectionsTest.vala"
														_tmp171_ = atr;
#line 555 "SerializableGeeCollectionsTest.vala"
														if (_tmp171_ == NULL) {
#line 3875 "SerializableGeeCollectionsTest.c"
															FILE* _tmp172_;
#line 556 "SerializableGeeCollectionsTest.vala"
															_tmp172_ = stdout;
#line 556 "SerializableGeeCollectionsTest.vala"
															fprintf (_tmp172_, "%s", "ERROR: No attribute manufacturer for Ship\n");
#line 557 "SerializableGeeCollectionsTest.vala"
															g_assert_not_reached ();
#line 3883 "SerializableGeeCollectionsTest.c"
														}
#line 559 "SerializableGeeCollectionsTest.vala"
														_tmp173_ = atr;
#line 559 "SerializableGeeCollectionsTest.vala"
														_tmp174_ = gxml_node_get_value (_tmp173_);
#line 559 "SerializableGeeCollectionsTest.vala"
														_tmp175_ = _tmp174_;
#line 559 "SerializableGeeCollectionsTest.vala"
														_tmp176_ = _tmp175_;
#line 559 "SerializableGeeCollectionsTest.vala"
														_tmp177_ = g_strcmp0 (_tmp176_, "MegaTrench") == 0;
#line 559 "SerializableGeeCollectionsTest.vala"
														_g_free0 (_tmp176_);
#line 559 "SerializableGeeCollectionsTest.vala"
														if (_tmp177_) {
#line 3899 "SerializableGeeCollectionsTest.c"
															GXmlNode* shanattr = NULL;
															GXmlNode* _tmp178_;
															GXmlNode* _tmp179_;
															GXmlNode* _tmp180_;
#line 560 "SerializableGeeCollectionsTest.vala"
															_tmp178_ = rn;
#line 560 "SerializableGeeCollectionsTest.vala"
															_tmp179_ = gxml_element_get_attr ((GXmlElement*) G_TYPE_CHECK_INSTANCE_CAST (_tmp178_, GXML_TYPE_GELEMENT, GXmlGElement), "unknown");
#line 560 "SerializableGeeCollectionsTest.vala"
															shanattr = _tmp179_;
#line 561 "SerializableGeeCollectionsTest.vala"
															_tmp180_ = shanattr;
#line 561 "SerializableGeeCollectionsTest.vala"
															if (_tmp180_ != NULL) {
#line 3914 "SerializableGeeCollectionsTest.c"
																GXmlNode* _tmp181_;
																gchar* _tmp182_;
																gchar* _tmp183_;
																gchar* _tmp184_;
																gboolean _tmp185_;
#line 562 "SerializableGeeCollectionsTest.vala"
																attrfound = TRUE;
#line 563 "SerializableGeeCollectionsTest.vala"
																_tmp181_ = shanattr;
#line 563 "SerializableGeeCollectionsTest.vala"
																_tmp182_ = gxml_node_get_value (_tmp181_);
#line 563 "SerializableGeeCollectionsTest.vala"
																_tmp183_ = _tmp182_;
#line 563 "SerializableGeeCollectionsTest.vala"
																_tmp184_ = _tmp183_;
#line 563 "SerializableGeeCollectionsTest.vala"
																_tmp185_ = g_strcmp0 (_tmp184_, "UNKNOWN ATTR") != 0;
#line 563 "SerializableGeeCollectionsTest.vala"
																_g_free0 (_tmp184_);
#line 563 "SerializableGeeCollectionsTest.vala"
																if (_tmp185_) {
#line 3936 "SerializableGeeCollectionsTest.c"
																	FILE* _tmp186_;
																	GXmlNode* _tmp187_;
																	gchar* _tmp188_;
																	gchar* _tmp189_;
																	gchar* _tmp190_;
																	const gchar* _tmp191_;
																	gchar* _tmp192_;
																	gchar* _tmp193_;
#line 564 "SerializableGeeCollectionsTest.vala"
																	_tmp186_ = stdout;
#line 564 "SerializableGeeCollectionsTest.vala"
																	_tmp187_ = shanattr;
#line 564 "SerializableGeeCollectionsTest.vala"
																	_tmp188_ = gxml_node_get_value (_tmp187_);
#line 564 "SerializableGeeCollectionsTest.vala"
																	_tmp189_ = _tmp188_;
#line 564 "SerializableGeeCollectionsTest.vala"
																	_tmp190_ = _tmp189_;
#line 564 "SerializableGeeCollectionsTest.vala"
																	_tmp191_ = string_to_string (_tmp190_);
#line 564 "SerializableGeeCollectionsTest.vala"
																	_tmp192_ = g_strconcat ("ERROR: Invalid Text Node Value for ship MegaTrench: ", _tmp191_, "\n", NULL);
#line 564 "SerializableGeeCollectionsTest.vala"
																	_tmp193_ = _tmp192_;
#line 564 "SerializableGeeCollectionsTest.vala"
																	fprintf (_tmp186_, "%s", _tmp193_);
#line 564 "SerializableGeeCollectionsTest.vala"
																	_g_free0 (_tmp193_);
#line 564 "SerializableGeeCollectionsTest.vala"
																	_g_free0 (_tmp190_);
#line 565 "SerializableGeeCollectionsTest.vala"
																	g_assert_not_reached ();
#line 3969 "SerializableGeeCollectionsTest.c"
																}
															}
															{
																GeeBidirList* _shn_list = NULL;
																GXmlNode* _tmp194_;
																GeeBidirList* _tmp195_;
																GeeBidirList* _tmp196_;
																gint _shn_size = 0;
																GeeBidirList* _tmp197_;
																gint _tmp198_;
																gint _tmp199_;
																gint _shn_index = 0;
#line 568 "SerializableGeeCollectionsTest.vala"
																_tmp194_ = rn;
#line 568 "SerializableGeeCollectionsTest.vala"
																_tmp195_ = gxml_node_get_children_nodes (_tmp194_);
#line 568 "SerializableGeeCollectionsTest.vala"
																_tmp196_ = _tmp195_;
#line 568 "SerializableGeeCollectionsTest.vala"
																_shn_list = _tmp196_;
#line 568 "SerializableGeeCollectionsTest.vala"
																_tmp197_ = _shn_list;
#line 568 "SerializableGeeCollectionsTest.vala"
																_tmp198_ = gee_collection_get_size ((GeeCollection*) _tmp197_);
#line 568 "SerializableGeeCollectionsTest.vala"
																_tmp199_ = _tmp198_;
#line 568 "SerializableGeeCollectionsTest.vala"
																_shn_size = _tmp199_;
#line 568 "SerializableGeeCollectionsTest.vala"
																_shn_index = -1;
#line 568 "SerializableGeeCollectionsTest.vala"
																while (TRUE) {
#line 4002 "SerializableGeeCollectionsTest.c"
																	GXmlNode* shn = NULL;
																	GeeBidirList* _tmp200_;
																	gpointer _tmp201_;
																	GXmlNode* _tmp202_;
#line 568 "SerializableGeeCollectionsTest.vala"
																	_shn_index = _shn_index + 1;
#line 568 "SerializableGeeCollectionsTest.vala"
																	if (!(_shn_index < _shn_size)) {
#line 568 "SerializableGeeCollectionsTest.vala"
																		break;
#line 4013 "SerializableGeeCollectionsTest.c"
																	}
#line 568 "SerializableGeeCollectionsTest.vala"
																	_tmp200_ = _shn_list;
#line 568 "SerializableGeeCollectionsTest.vala"
																	_tmp201_ = gee_list_get ((GeeList*) _tmp200_, _shn_index);
#line 568 "SerializableGeeCollectionsTest.vala"
																	shn = (GXmlNode*) _tmp201_;
#line 570 "SerializableGeeCollectionsTest.vala"
																	_tmp202_ = shn;
#line 570 "SerializableGeeCollectionsTest.vala"
																	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp202_, GXML_TYPE_TEXT)) {
#line 4025 "SerializableGeeCollectionsTest.c"
																		GXmlNode* _tmp203_;
																		gchar* _tmp204_;
																		gchar* _tmp205_;
																		gchar* _tmp206_;
																		gboolean _tmp207_;
#line 571 "SerializableGeeCollectionsTest.vala"
																		tfound = TRUE;
#line 572 "SerializableGeeCollectionsTest.vala"
																		_tmp203_ = shn;
#line 572 "SerializableGeeCollectionsTest.vala"
																		_tmp204_ = gxml_node_get_value (_tmp203_);
#line 572 "SerializableGeeCollectionsTest.vala"
																		_tmp205_ = _tmp204_;
#line 572 "SerializableGeeCollectionsTest.vala"
																		_tmp206_ = _tmp205_;
#line 572 "SerializableGeeCollectionsTest.vala"
																		_tmp207_ = g_strcmp0 (_tmp206_, "TEST_TEXT") != 0;
#line 572 "SerializableGeeCollectionsTest.vala"
																		_g_free0 (_tmp206_);
#line 572 "SerializableGeeCollectionsTest.vala"
																		if (_tmp207_) {
#line 4047 "SerializableGeeCollectionsTest.c"
																			FILE* _tmp208_;
																			GXmlNode* _tmp209_;
																			gchar* _tmp210_;
																			gchar* _tmp211_;
																			gchar* _tmp212_;
																			const gchar* _tmp213_;
																			gchar* _tmp214_;
																			gchar* _tmp215_;
#line 573 "SerializableGeeCollectionsTest.vala"
																			_tmp208_ = stdout;
#line 573 "SerializableGeeCollectionsTest.vala"
																			_tmp209_ = shn;
#line 573 "SerializableGeeCollectionsTest.vala"
																			_tmp210_ = gxml_node_get_value (_tmp209_);
#line 573 "SerializableGeeCollectionsTest.vala"
																			_tmp211_ = _tmp210_;
#line 573 "SerializableGeeCollectionsTest.vala"
																			_tmp212_ = _tmp211_;
#line 573 "SerializableGeeCollectionsTest.vala"
																			_tmp213_ = string_to_string (_tmp212_);
#line 573 "SerializableGeeCollectionsTest.vala"
																			_tmp214_ = g_strconcat ("ERROR: Invalid Text Node Value for ship MegaTrench: ", _tmp213_, "\n", NULL);
#line 573 "SerializableGeeCollectionsTest.vala"
																			_tmp215_ = _tmp214_;
#line 573 "SerializableGeeCollectionsTest.vala"
																			fprintf (_tmp208_, "%s", _tmp215_);
#line 573 "SerializableGeeCollectionsTest.vala"
																			_g_free0 (_tmp215_);
#line 573 "SerializableGeeCollectionsTest.vala"
																			_g_free0 (_tmp212_);
#line 574 "SerializableGeeCollectionsTest.vala"
																			g_assert_not_reached ();
#line 4080 "SerializableGeeCollectionsTest.c"
																		}
																	}
#line 568 "SerializableGeeCollectionsTest.vala"
																	_g_object_unref0 (shn);
#line 4085 "SerializableGeeCollectionsTest.c"
																}
#line 568 "SerializableGeeCollectionsTest.vala"
																_g_object_unref0 (_shn_list);
#line 4089 "SerializableGeeCollectionsTest.c"
															}
#line 559 "SerializableGeeCollectionsTest.vala"
															_g_object_unref0 (shanattr);
#line 4093 "SerializableGeeCollectionsTest.c"
														}
#line 553 "SerializableGeeCollectionsTest.vala"
														_g_object_unref0 (atr);
#line 4097 "SerializableGeeCollectionsTest.c"
													}
#line 580 "SerializableGeeCollectionsTest.vala"
													_tmp216_ = rn;
#line 580 "SerializableGeeCollectionsTest.vala"
													_tmp217_ = gxml_node_get_name (_tmp216_);
#line 580 "SerializableGeeCollectionsTest.vala"
													_tmp218_ = _tmp217_;
#line 580 "SerializableGeeCollectionsTest.vala"
													_tmp219_ = _tmp218_;
#line 580 "SerializableGeeCollectionsTest.vala"
													_tmp220_ = g_strcmp0 (_tmp219_, "UnknownAttribute") == 0;
#line 580 "SerializableGeeCollectionsTest.vala"
													_g_free0 (_tmp219_);
#line 580 "SerializableGeeCollectionsTest.vala"
													if (_tmp220_) {
#line 4113 "SerializableGeeCollectionsTest.c"
														GXmlNode* nattr = NULL;
														GXmlNode* _tmp221_;
														GXmlNode* _tmp222_;
														GXmlNode* _tmp223_;
														GXmlNode* _tmp225_;
														gchar* _tmp226_;
														gchar* _tmp227_;
														gchar* _tmp228_;
														gboolean _tmp229_;
#line 581 "SerializableGeeCollectionsTest.vala"
														unkfound = TRUE;
#line 582 "SerializableGeeCollectionsTest.vala"
														_tmp221_ = rn;
#line 582 "SerializableGeeCollectionsTest.vala"
														_tmp222_ = gxml_element_get_attr ((GXmlElement*) G_TYPE_CHECK_INSTANCE_CAST (_tmp221_, GXML_TYPE_GELEMENT, GXmlGElement), "name");
#line 582 "SerializableGeeCollectionsTest.vala"
														nattr = _tmp222_;
#line 583 "SerializableGeeCollectionsTest.vala"
														_tmp223_ = nattr;
#line 583 "SerializableGeeCollectionsTest.vala"
														if (_tmp223_ == NULL) {
#line 4135 "SerializableGeeCollectionsTest.c"
															FILE* _tmp224_;
#line 584 "SerializableGeeCollectionsTest.vala"
															_tmp224_ = stdout;
#line 584 "SerializableGeeCollectionsTest.vala"
															fprintf (_tmp224_, "%s", "ERROR: No Unknown Attribute Node with attribute name\n");
#line 585 "SerializableGeeCollectionsTest.vala"
															g_assert_not_reached ();
#line 4143 "SerializableGeeCollectionsTest.c"
														}
#line 587 "SerializableGeeCollectionsTest.vala"
														_tmp225_ = nattr;
#line 587 "SerializableGeeCollectionsTest.vala"
														_tmp226_ = gxml_node_get_value (_tmp225_);
#line 587 "SerializableGeeCollectionsTest.vala"
														_tmp227_ = _tmp226_;
#line 587 "SerializableGeeCollectionsTest.vala"
														_tmp228_ = _tmp227_;
#line 587 "SerializableGeeCollectionsTest.vala"
														_tmp229_ = g_strcmp0 (_tmp228_, "nothing") != 0;
#line 587 "SerializableGeeCollectionsTest.vala"
														_g_free0 (_tmp228_);
#line 587 "SerializableGeeCollectionsTest.vala"
														if (_tmp229_) {
#line 4159 "SerializableGeeCollectionsTest.c"
															FILE* _tmp230_;
															GXmlNode* _tmp231_;
															gchar* _tmp232_;
															gchar* _tmp233_;
															gchar* _tmp234_;
															const gchar* _tmp235_;
															gchar* _tmp236_;
															gchar* _tmp237_;
#line 588 "SerializableGeeCollectionsTest.vala"
															_tmp230_ = stdout;
#line 588 "SerializableGeeCollectionsTest.vala"
															_tmp231_ = nattr;
#line 588 "SerializableGeeCollectionsTest.vala"
															_tmp232_ = gxml_node_get_value (_tmp231_);
#line 588 "SerializableGeeCollectionsTest.vala"
															_tmp233_ = _tmp232_;
#line 588 "SerializableGeeCollectionsTest.vala"
															_tmp234_ = _tmp233_;
#line 588 "SerializableGeeCollectionsTest.vala"
															_tmp235_ = string_to_string (_tmp234_);
#line 588 "SerializableGeeCollectionsTest.vala"
															_tmp236_ = g_strconcat ("ERROR: Invalid unknown attribute node's attribute name value: found ", _tmp235_, "\n", NULL);
#line 588 "SerializableGeeCollectionsTest.vala"
															_tmp237_ = _tmp236_;
#line 588 "SerializableGeeCollectionsTest.vala"
															fprintf (_tmp230_, "%s", _tmp237_);
#line 588 "SerializableGeeCollectionsTest.vala"
															_g_free0 (_tmp237_);
#line 588 "SerializableGeeCollectionsTest.vala"
															_g_free0 (_tmp234_);
#line 589 "SerializableGeeCollectionsTest.vala"
															g_assert_not_reached ();
#line 4192 "SerializableGeeCollectionsTest.c"
														}
#line 580 "SerializableGeeCollectionsTest.vala"
														_g_object_unref0 (nattr);
#line 4196 "SerializableGeeCollectionsTest.c"
													}
												}
#line 550 "SerializableGeeCollectionsTest.vala"
												_g_object_unref0 (rn);
#line 4201 "SerializableGeeCollectionsTest.c"
											}
#line 550 "SerializableGeeCollectionsTest.vala"
											_g_object_unref0 (_rn_list);
#line 4205 "SerializableGeeCollectionsTest.c"
										}
									}
								}
#line 547 "SerializableGeeCollectionsTest.vala"
								_g_object_unref0 (sn);
#line 4211 "SerializableGeeCollectionsTest.c"
							}
#line 547 "SerializableGeeCollectionsTest.vala"
							_g_object_unref0 (_sn_list);
#line 4215 "SerializableGeeCollectionsTest.c"
						}
#line 597 "SerializableGeeCollectionsTest.vala"
						if (!attrfound) {
#line 4219 "SerializableGeeCollectionsTest.c"
							FILE* _tmp238_;
#line 598 "SerializableGeeCollectionsTest.vala"
							_tmp238_ = stdout;
#line 598 "SerializableGeeCollectionsTest.vala"
							fprintf (_tmp238_, "%s", "ERROR: No Unknown AttributeText found for ship MegaTrench\n");
#line 599 "SerializableGeeCollectionsTest.vala"
							g_assert_not_reached ();
#line 4227 "SerializableGeeCollectionsTest.c"
						}
#line 601 "SerializableGeeCollectionsTest.vala"
						if (!tfound) {
#line 4231 "SerializableGeeCollectionsTest.c"
							FILE* _tmp239_;
#line 602 "SerializableGeeCollectionsTest.vala"
							_tmp239_ = stdout;
#line 602 "SerializableGeeCollectionsTest.vala"
							fprintf (_tmp239_, "%s", "ERROR: No Text Node Value found for ship MegaTrench\n");
#line 603 "SerializableGeeCollectionsTest.vala"
							g_assert_not_reached ();
#line 4239 "SerializableGeeCollectionsTest.c"
						}
#line 605 "SerializableGeeCollectionsTest.vala"
						if (!unkfound) {
#line 4243 "SerializableGeeCollectionsTest.c"
							FILE* _tmp240_;
#line 606 "SerializableGeeCollectionsTest.vala"
							_tmp240_ = stdout;
#line 606 "SerializableGeeCollectionsTest.vala"
							fprintf (_tmp240_, "%s", "ERROR: No Unknown Attribute Node found for storage\n");
#line 607 "SerializableGeeCollectionsTest.vala"
							g_assert_not_reached ();
#line 4251 "SerializableGeeCollectionsTest.c"
						}
					}
				}
#line 611 "SerializableGeeCollectionsTest.vala"
				_tmp241_ = n;
#line 611 "SerializableGeeCollectionsTest.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp241_, GXML_TYPE_TEXT)) {
#line 4259 "SerializableGeeCollectionsTest.c"
					FILE* _tmp242_;
					GXmlNode* _tmp243_;
					gchar* _tmp244_;
					gchar* _tmp245_;
					gchar* _tmp246_;
					const gchar* _tmp247_;
					gchar* _tmp248_;
					gchar* _tmp249_;
#line 612 "SerializableGeeCollectionsTest.vala"
					_tmp242_ = stdout;
#line 612 "SerializableGeeCollectionsTest.vala"
					_tmp243_ = n;
#line 612 "SerializableGeeCollectionsTest.vala"
					_tmp244_ = gxml_node_get_value (_tmp243_);
#line 612 "SerializableGeeCollectionsTest.vala"
					_tmp245_ = _tmp244_;
#line 612 "SerializableGeeCollectionsTest.vala"
					_tmp246_ = _tmp245_;
#line 612 "SerializableGeeCollectionsTest.vala"
					_tmp247_ = string_to_string (_tmp246_);
#line 612 "SerializableGeeCollectionsTest.vala"
					_tmp248_ = g_strconcat ("ROOT NODE VALUE: '", _tmp247_, "'\n", NULL);
#line 612 "SerializableGeeCollectionsTest.vala"
					_tmp249_ = _tmp248_;
#line 612 "SerializableGeeCollectionsTest.vala"
					fprintf (_tmp242_, "%s", _tmp249_);
#line 612 "SerializableGeeCollectionsTest.vala"
					_g_free0 (_tmp249_);
#line 612 "SerializableGeeCollectionsTest.vala"
					_g_free0 (_tmp246_);
#line 4290 "SerializableGeeCollectionsTest.c"
				}
#line 538 "SerializableGeeCollectionsTest.vala"
				_g_object_unref0 (n);
#line 4294 "SerializableGeeCollectionsTest.c"
			}
#line 538 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (_n_list);
#line 4298 "SerializableGeeCollectionsTest.c"
		}
#line 445 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (doc);
#line 445 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (uns);
#line 445 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (ups);
#line 445 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (refaction);
#line 445 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (mssh);
#line 445 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (s);
#line 445 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (org_doc);
#line 4314 "SerializableGeeCollectionsTest.c"
	}
	goto __finally371;
	__catch371_g_error:
	{
		GError* e = NULL;
		FILE* _tmp250_;
		const gchar* _tmp251_;
		const gchar* _tmp252_;
		gchar* _tmp253_;
		gchar* _tmp254_;
#line 445 "SerializableGeeCollectionsTest.vala"
		e = _inner_error0_;
#line 445 "SerializableGeeCollectionsTest.vala"
		_inner_error0_ = NULL;
#line 617 "SerializableGeeCollectionsTest.vala"
		_tmp250_ = stdout;
#line 617 "SerializableGeeCollectionsTest.vala"
		_tmp251_ = e->message;
#line 617 "SerializableGeeCollectionsTest.vala"
		_tmp252_ = string_to_string (_tmp251_);
#line 617 "SerializableGeeCollectionsTest.vala"
		_tmp253_ = g_strconcat ("ERROR: ", _tmp252_, NULL);
#line 617 "SerializableGeeCollectionsTest.vala"
		_tmp254_ = _tmp253_;
#line 617 "SerializableGeeCollectionsTest.vala"
		fprintf (_tmp250_, "%s", _tmp254_);
#line 617 "SerializableGeeCollectionsTest.vala"
		_g_free0 (_tmp254_);
#line 618 "SerializableGeeCollectionsTest.vala"
		g_assert_not_reached ();
#line 445 "SerializableGeeCollectionsTest.vala"
		_g_error_free0 (e);
#line 4347 "SerializableGeeCollectionsTest.c"
	}
	__finally371:
#line 445 "SerializableGeeCollectionsTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 445 "SerializableGeeCollectionsTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 445 "SerializableGeeCollectionsTest.vala"
		g_clear_error (&_inner_error0_);
#line 445 "SerializableGeeCollectionsTest.vala"
		return;
#line 4358 "SerializableGeeCollectionsTest.c"
	}
}

static void
___lambda321__gtest_func (void)
{
#line 443 "SerializableGeeCollectionsTest.vala"
	__lambda321_ ();
#line 4367 "SerializableGeeCollectionsTest.c"
}

static void
__lambda322_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		SerializableGeeCollectionsTestBigBag* bag = NULL;
		SerializableGeeCollectionsTestBigBag* _tmp0_;
		SerializableGeeCollectionsTestBigBag* _tmp1_;
		SerializableGeeCollectionsTestSmallBagArray* _tmp2_;
		SerializableGeeCollectionsTestSmallBagArray* _tmp3_;
		SerializableGeeCollectionsTestBigBag* _tmp26_;
		SerializableGeeCollectionsTestSmallBagArray* _tmp27_;
		SerializableGeeCollectionsTestSmallBagArray* _tmp28_;
		gint _tmp29_;
		gint _tmp30_;
		GXmlTDocument* d = NULL;
		GXmlTDocument* _tmp31_;
		SerializableGeeCollectionsTestBigBag* _tmp32_;
		GXmlTDocument* _tmp33_;
		GXmlNode* _tmp34_;
		GXmlNode* _tmp35_;
		GXmlTDocument* _tmp36_;
		GXmlNode* _tmp37_;
		GXmlNode* _tmp38_;
		GXmlNode* _tmp39_;
		GXmlTDocument* _tmp40_;
		GXmlNode* _tmp41_;
		GXmlNode* _tmp42_;
		GXmlNode* _tmp43_;
		gchar* _tmp44_;
		gchar* _tmp45_;
		gchar* _tmp46_;
		GXmlTDocument* _tmp47_;
		GXmlNode* _tmp48_;
		GXmlNode* _tmp49_;
		GXmlNode* _tmp50_;
		GeeBidirList* _tmp51_;
		GeeBidirList* _tmp52_;
		GeeBidirList* _tmp53_;
		gint _tmp54_;
		gint _tmp55_;
		GXmlTDocument* _tmp56_;
		GXmlNode* _tmp57_;
		GXmlNode* _tmp58_;
		GXmlNode* _tmp59_;
		GeeBidirList* _tmp60_;
		GeeBidirList* _tmp61_;
		GeeBidirList* _tmp62_;
		gpointer _tmp63_;
		GXmlNode* _tmp64_;
		gchar* _tmp65_;
		gchar* _tmp66_;
		gchar* _tmp67_;
		GXmlTDocument* _tmp68_;
		GXmlNode* _tmp69_;
		GXmlNode* _tmp70_;
		GXmlNode* _tmp71_;
		GeeBidirList* _tmp72_;
		GeeBidirList* _tmp73_;
		GeeBidirList* _tmp74_;
		gpointer _tmp75_;
		GXmlNode* _tmp76_;
		GeeBidirList* _tmp77_;
		GeeBidirList* _tmp78_;
		GeeBidirList* _tmp79_;
		gint _tmp80_;
		gint _tmp81_;
		GXmlTDocument* _tmp82_;
		GXmlNode* _tmp83_;
		GXmlNode* _tmp84_;
		GXmlNode* _tmp85_;
		GeeBidirList* _tmp86_;
		GeeBidirList* _tmp87_;
		GeeBidirList* _tmp88_;
		gpointer _tmp89_;
		GXmlNode* _tmp90_;
		GeeBidirList* _tmp91_;
		GeeBidirList* _tmp92_;
		GeeBidirList* _tmp93_;
		gpointer _tmp94_;
		GXmlNode* _tmp95_;
		gchar* _tmp96_;
		gchar* _tmp97_;
		gchar* _tmp98_;
		SerializableGeeCollectionsTestBigBag* bag2 = NULL;
		SerializableGeeCollectionsTestBigBag* _tmp99_;
		SerializableGeeCollectionsTestBigBag* _tmp100_;
		GXmlTDocument* _tmp101_;
		SerializableGeeCollectionsTestBigBag* _tmp102_;
		SerializableGeeCollectionsTestSmallBagArray* _tmp103_;
		SerializableGeeCollectionsTestSmallBagArray* _tmp104_;
		gint _tmp105_;
		gint _tmp106_;
		GXmlTDocument* d2 = NULL;
		GXmlTDocument* _tmp107_;
		SerializableGeeCollectionsTestBigBag* _tmp108_;
		GXmlTDocument* _tmp109_;
		GXmlNode* _tmp110_;
		GXmlNode* _tmp111_;
		GXmlTDocument* _tmp112_;
		GXmlNode* _tmp113_;
		GXmlNode* _tmp114_;
		GXmlNode* _tmp115_;
		GXmlTDocument* _tmp116_;
		GXmlNode* _tmp117_;
		GXmlNode* _tmp118_;
		GXmlNode* _tmp119_;
		gchar* _tmp120_;
		gchar* _tmp121_;
		gchar* _tmp122_;
		GXmlTDocument* _tmp123_;
		GXmlNode* _tmp124_;
		GXmlNode* _tmp125_;
		GXmlNode* _tmp126_;
		GeeBidirList* _tmp127_;
		GeeBidirList* _tmp128_;
		GeeBidirList* _tmp129_;
		gint _tmp130_;
		gint _tmp131_;
		GXmlTDocument* _tmp132_;
		GXmlNode* _tmp133_;
		GXmlNode* _tmp134_;
		GXmlNode* _tmp135_;
		GeeBidirList* _tmp136_;
		GeeBidirList* _tmp137_;
		GeeBidirList* _tmp138_;
		gpointer _tmp139_;
		GXmlNode* _tmp140_;
		gchar* _tmp141_;
		gchar* _tmp142_;
		gchar* _tmp143_;
		GXmlTDocument* _tmp144_;
		GXmlNode* _tmp145_;
		GXmlNode* _tmp146_;
		GXmlNode* _tmp147_;
		GeeBidirList* _tmp148_;
		GeeBidirList* _tmp149_;
		GeeBidirList* _tmp150_;
		gpointer _tmp151_;
		GXmlNode* _tmp152_;
		GeeBidirList* _tmp153_;
		GeeBidirList* _tmp154_;
		GeeBidirList* _tmp155_;
		gint _tmp156_;
		gint _tmp157_;
		GXmlTDocument* _tmp158_;
		GXmlNode* _tmp159_;
		GXmlNode* _tmp160_;
		GXmlNode* _tmp161_;
		GeeBidirList* _tmp162_;
		GeeBidirList* _tmp163_;
		GeeBidirList* _tmp164_;
		gpointer _tmp165_;
		GXmlNode* _tmp166_;
		GeeBidirList* _tmp167_;
		GeeBidirList* _tmp168_;
		GeeBidirList* _tmp169_;
		gpointer _tmp170_;
		GXmlNode* _tmp171_;
		gchar* _tmp172_;
		gchar* _tmp173_;
		gchar* _tmp174_;
#line 625 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = serializable_gee_collections_test_big_bag_new ();
#line 625 "SerializableGeeCollectionsTest.vala"
		bag = _tmp0_;
#line 626 "SerializableGeeCollectionsTest.vala"
		_tmp1_ = bag;
#line 626 "SerializableGeeCollectionsTest.vala"
		_tmp2_ = serializable_gee_collections_test_big_bag_get_bags (_tmp1_);
#line 626 "SerializableGeeCollectionsTest.vala"
		_tmp3_ = _tmp2_;
#line 626 "SerializableGeeCollectionsTest.vala"
		_vala_assert (_tmp3_ != NULL, "bag.bags != null");
#line 4544 "SerializableGeeCollectionsTest.c"
		{
			gint i = 0;
#line 627 "SerializableGeeCollectionsTest.vala"
			i = 0;
#line 4549 "SerializableGeeCollectionsTest.c"
			{
				gboolean _tmp4_ = FALSE;
#line 627 "SerializableGeeCollectionsTest.vala"
				_tmp4_ = TRUE;
#line 627 "SerializableGeeCollectionsTest.vala"
				while (TRUE) {
#line 4556 "SerializableGeeCollectionsTest.c"
					SerializableGeeCollectionsTestSmallBag* sbag = NULL;
					SerializableGeeCollectionsTestSmallBag* _tmp6_;
					SerializableGeeCollectionsTestSmallBag* _tmp7_;
					SerializableGeeCollectionsTestBallArray* _tmp8_;
					SerializableGeeCollectionsTestBallArray* _tmp9_;
					SerializableGeeCollectionsTestSmallBag* _tmp17_;
					SerializableGeeCollectionsTestBallArray* _tmp18_;
					SerializableGeeCollectionsTestBallArray* _tmp19_;
					gint _tmp20_;
					gint _tmp21_;
					SerializableGeeCollectionsTestBigBag* _tmp22_;
					SerializableGeeCollectionsTestSmallBagArray* _tmp23_;
					SerializableGeeCollectionsTestSmallBagArray* _tmp24_;
					SerializableGeeCollectionsTestSmallBag* _tmp25_;
#line 627 "SerializableGeeCollectionsTest.vala"
					if (!_tmp4_) {
#line 4573 "SerializableGeeCollectionsTest.c"
						gint _tmp5_;
#line 627 "SerializableGeeCollectionsTest.vala"
						_tmp5_ = i;
#line 627 "SerializableGeeCollectionsTest.vala"
						i = _tmp5_ + 1;
#line 4579 "SerializableGeeCollectionsTest.c"
					}
#line 627 "SerializableGeeCollectionsTest.vala"
					_tmp4_ = FALSE;
#line 627 "SerializableGeeCollectionsTest.vala"
					if (!(i < 2)) {
#line 627 "SerializableGeeCollectionsTest.vala"
						break;
#line 4587 "SerializableGeeCollectionsTest.c"
					}
#line 628 "SerializableGeeCollectionsTest.vala"
					_tmp6_ = serializable_gee_collections_test_small_bag_new ();
#line 628 "SerializableGeeCollectionsTest.vala"
					sbag = _tmp6_;
#line 629 "SerializableGeeCollectionsTest.vala"
					_tmp7_ = sbag;
#line 629 "SerializableGeeCollectionsTest.vala"
					_tmp8_ = serializable_gee_collections_test_small_bag_get_balls (_tmp7_);
#line 629 "SerializableGeeCollectionsTest.vala"
					_tmp9_ = _tmp8_;
#line 629 "SerializableGeeCollectionsTest.vala"
					_vala_assert (_tmp9_ != NULL, "sbag.balls != null");
#line 4601 "SerializableGeeCollectionsTest.c"
					{
						gint j = 0;
#line 630 "SerializableGeeCollectionsTest.vala"
						j = 0;
#line 4606 "SerializableGeeCollectionsTest.c"
						{
							gboolean _tmp10_ = FALSE;
#line 630 "SerializableGeeCollectionsTest.vala"
							_tmp10_ = TRUE;
#line 630 "SerializableGeeCollectionsTest.vala"
							while (TRUE) {
#line 4613 "SerializableGeeCollectionsTest.c"
								SerializableGeeCollectionsTestBall* b = NULL;
								SerializableGeeCollectionsTestBall* _tmp12_;
								SerializableGeeCollectionsTestSmallBag* _tmp13_;
								SerializableGeeCollectionsTestBallArray* _tmp14_;
								SerializableGeeCollectionsTestBallArray* _tmp15_;
								SerializableGeeCollectionsTestBall* _tmp16_;
#line 630 "SerializableGeeCollectionsTest.vala"
								if (!_tmp10_) {
#line 4622 "SerializableGeeCollectionsTest.c"
									gint _tmp11_;
#line 630 "SerializableGeeCollectionsTest.vala"
									_tmp11_ = j;
#line 630 "SerializableGeeCollectionsTest.vala"
									j = _tmp11_ + 1;
#line 4628 "SerializableGeeCollectionsTest.c"
								}
#line 630 "SerializableGeeCollectionsTest.vala"
								_tmp10_ = FALSE;
#line 630 "SerializableGeeCollectionsTest.vala"
								if (!(j < 2)) {
#line 630 "SerializableGeeCollectionsTest.vala"
									break;
#line 4636 "SerializableGeeCollectionsTest.c"
								}
#line 631 "SerializableGeeCollectionsTest.vala"
								_tmp12_ = serializable_gee_collections_test_ball_new ();
#line 631 "SerializableGeeCollectionsTest.vala"
								b = _tmp12_;
#line 632 "SerializableGeeCollectionsTest.vala"
								_tmp13_ = sbag;
#line 632 "SerializableGeeCollectionsTest.vala"
								_tmp14_ = serializable_gee_collections_test_small_bag_get_balls (_tmp13_);
#line 632 "SerializableGeeCollectionsTest.vala"
								_tmp15_ = _tmp14_;
#line 632 "SerializableGeeCollectionsTest.vala"
								_tmp16_ = b;
#line 632 "SerializableGeeCollectionsTest.vala"
								gee_abstract_collection_add ((GeeAbstractCollection*) _tmp15_, _tmp16_);
#line 630 "SerializableGeeCollectionsTest.vala"
								_g_object_unref0 (b);
#line 4654 "SerializableGeeCollectionsTest.c"
							}
						}
					}
#line 634 "SerializableGeeCollectionsTest.vala"
					_tmp17_ = sbag;
#line 634 "SerializableGeeCollectionsTest.vala"
					_tmp18_ = serializable_gee_collections_test_small_bag_get_balls (_tmp17_);
#line 634 "SerializableGeeCollectionsTest.vala"
					_tmp19_ = _tmp18_;
#line 634 "SerializableGeeCollectionsTest.vala"
					_tmp20_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp19_);
#line 634 "SerializableGeeCollectionsTest.vala"
					_tmp21_ = _tmp20_;
#line 634 "SerializableGeeCollectionsTest.vala"
					_vala_assert (_tmp21_ == 2, "sbag.balls.size == 2");
#line 635 "SerializableGeeCollectionsTest.vala"
					_tmp22_ = bag;
#line 635 "SerializableGeeCollectionsTest.vala"
					_tmp23_ = serializable_gee_collections_test_big_bag_get_bags (_tmp22_);
#line 635 "SerializableGeeCollectionsTest.vala"
					_tmp24_ = _tmp23_;
#line 635 "SerializableGeeCollectionsTest.vala"
					_tmp25_ = sbag;
#line 635 "SerializableGeeCollectionsTest.vala"
					gee_abstract_collection_add ((GeeAbstractCollection*) _tmp24_, _tmp25_);
#line 627 "SerializableGeeCollectionsTest.vala"
					_g_object_unref0 (sbag);
#line 4682 "SerializableGeeCollectionsTest.c"
				}
			}
		}
#line 637 "SerializableGeeCollectionsTest.vala"
		_tmp26_ = bag;
#line 637 "SerializableGeeCollectionsTest.vala"
		_tmp27_ = serializable_gee_collections_test_big_bag_get_bags (_tmp26_);
#line 637 "SerializableGeeCollectionsTest.vala"
		_tmp28_ = _tmp27_;
#line 637 "SerializableGeeCollectionsTest.vala"
		_tmp29_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp28_);
#line 637 "SerializableGeeCollectionsTest.vala"
		_tmp30_ = _tmp29_;
#line 637 "SerializableGeeCollectionsTest.vala"
		_vala_assert (_tmp30_ == 2, "bag.bags.size == 2");
#line 639 "SerializableGeeCollectionsTest.vala"
		_tmp31_ = gxml_tdocument_new ();
#line 639 "SerializableGeeCollectionsTest.vala"
		d = _tmp31_;
#line 640 "SerializableGeeCollectionsTest.vala"
		_tmp32_ = bag;
#line 640 "SerializableGeeCollectionsTest.vala"
		_tmp33_ = d;
#line 640 "SerializableGeeCollectionsTest.vala"
		_tmp34_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp32_, (GXmlNode*) _tmp33_, &_inner_error0_);
#line 640 "SerializableGeeCollectionsTest.vala"
		_tmp35_ = _tmp34_;
#line 640 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp35_);
#line 640 "SerializableGeeCollectionsTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 640 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (d);
#line 640 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (bag);
#line 4718 "SerializableGeeCollectionsTest.c"
			goto __catch372_g_error;
		}
#line 641 "SerializableGeeCollectionsTest.vala"
		_tmp36_ = d;
#line 641 "SerializableGeeCollectionsTest.vala"
		_tmp37_ = gxml_document_get_root ((GXmlDocument*) _tmp36_);
#line 641 "SerializableGeeCollectionsTest.vala"
		_tmp38_ = _tmp37_;
#line 641 "SerializableGeeCollectionsTest.vala"
		_tmp39_ = _tmp38_;
#line 641 "SerializableGeeCollectionsTest.vala"
		_vala_assert (_tmp39_ != NULL, "d.root != null");
#line 641 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp39_);
#line 642 "SerializableGeeCollectionsTest.vala"
		_tmp40_ = d;
#line 642 "SerializableGeeCollectionsTest.vala"
		_tmp41_ = gxml_document_get_root ((GXmlDocument*) _tmp40_);
#line 642 "SerializableGeeCollectionsTest.vala"
		_tmp42_ = _tmp41_;
#line 642 "SerializableGeeCollectionsTest.vala"
		_tmp43_ = _tmp42_;
#line 642 "SerializableGeeCollectionsTest.vala"
		_tmp44_ = gxml_node_get_name (_tmp43_);
#line 642 "SerializableGeeCollectionsTest.vala"
		_tmp45_ = _tmp44_;
#line 642 "SerializableGeeCollectionsTest.vala"
		_tmp46_ = _tmp45_;
#line 642 "SerializableGeeCollectionsTest.vala"
		_vala_assert (g_strcmp0 (_tmp46_, "BigBag") == 0, "d.root.name == \"BigBag\"");
#line 642 "SerializableGeeCollectionsTest.vala"
		_g_free0 (_tmp46_);
#line 642 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp43_);
#line 643 "SerializableGeeCollectionsTest.vala"
		_tmp47_ = d;
#line 643 "SerializableGeeCollectionsTest.vala"
		_tmp48_ = gxml_document_get_root ((GXmlDocument*) _tmp47_);
#line 643 "SerializableGeeCollectionsTest.vala"
		_tmp49_ = _tmp48_;
#line 643 "SerializableGeeCollectionsTest.vala"
		_tmp50_ = _tmp49_;
#line 643 "SerializableGeeCollectionsTest.vala"
		_tmp51_ = gxml_node_get_children_nodes (_tmp50_);
#line 643 "SerializableGeeCollectionsTest.vala"
		_tmp52_ = _tmp51_;
#line 643 "SerializableGeeCollectionsTest.vala"
		_tmp53_ = _tmp52_;
#line 643 "SerializableGeeCollectionsTest.vala"
		_tmp54_ = gee_collection_get_size ((GeeCollection*) _tmp53_);
#line 643 "SerializableGeeCollectionsTest.vala"
		_tmp55_ = _tmp54_;
#line 643 "SerializableGeeCollectionsTest.vala"
		_vala_assert (_tmp55_ == 2, "d.root.children_nodes.size == 2");
#line 643 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp53_);
#line 643 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp50_);
#line 644 "SerializableGeeCollectionsTest.vala"
		_tmp56_ = d;
#line 644 "SerializableGeeCollectionsTest.vala"
		_tmp57_ = gxml_document_get_root ((GXmlDocument*) _tmp56_);
#line 644 "SerializableGeeCollectionsTest.vala"
		_tmp58_ = _tmp57_;
#line 644 "SerializableGeeCollectionsTest.vala"
		_tmp59_ = _tmp58_;
#line 644 "SerializableGeeCollectionsTest.vala"
		_tmp60_ = gxml_node_get_children_nodes (_tmp59_);
#line 644 "SerializableGeeCollectionsTest.vala"
		_tmp61_ = _tmp60_;
#line 644 "SerializableGeeCollectionsTest.vala"
		_tmp62_ = _tmp61_;
#line 644 "SerializableGeeCollectionsTest.vala"
		_tmp63_ = gee_list_get ((GeeList*) _tmp62_, 0);
#line 644 "SerializableGeeCollectionsTest.vala"
		_tmp64_ = (GXmlNode*) _tmp63_;
#line 644 "SerializableGeeCollectionsTest.vala"
		_tmp65_ = gxml_node_get_name (_tmp64_);
#line 644 "SerializableGeeCollectionsTest.vala"
		_tmp66_ = _tmp65_;
#line 644 "SerializableGeeCollectionsTest.vala"
		_tmp67_ = _tmp66_;
#line 644 "SerializableGeeCollectionsTest.vala"
		_vala_assert (g_strcmp0 (_tmp67_, "SmallBag") == 0, "d.root.children_nodes[0].name == \"SmallBag\"");
#line 644 "SerializableGeeCollectionsTest.vala"
		_g_free0 (_tmp67_);
#line 644 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp64_);
#line 644 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp62_);
#line 644 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp59_);
#line 645 "SerializableGeeCollectionsTest.vala"
		_tmp68_ = d;
#line 645 "SerializableGeeCollectionsTest.vala"
		_tmp69_ = gxml_document_get_root ((GXmlDocument*) _tmp68_);
#line 645 "SerializableGeeCollectionsTest.vala"
		_tmp70_ = _tmp69_;
#line 645 "SerializableGeeCollectionsTest.vala"
		_tmp71_ = _tmp70_;
#line 645 "SerializableGeeCollectionsTest.vala"
		_tmp72_ = gxml_node_get_children_nodes (_tmp71_);
#line 645 "SerializableGeeCollectionsTest.vala"
		_tmp73_ = _tmp72_;
#line 645 "SerializableGeeCollectionsTest.vala"
		_tmp74_ = _tmp73_;
#line 645 "SerializableGeeCollectionsTest.vala"
		_tmp75_ = gee_list_get ((GeeList*) _tmp74_, 0);
#line 645 "SerializableGeeCollectionsTest.vala"
		_tmp76_ = (GXmlNode*) _tmp75_;
#line 645 "SerializableGeeCollectionsTest.vala"
		_tmp77_ = gxml_node_get_children_nodes (_tmp76_);
#line 645 "SerializableGeeCollectionsTest.vala"
		_tmp78_ = _tmp77_;
#line 645 "SerializableGeeCollectionsTest.vala"
		_tmp79_ = _tmp78_;
#line 645 "SerializableGeeCollectionsTest.vala"
		_tmp80_ = gee_collection_get_size ((GeeCollection*) _tmp79_);
#line 645 "SerializableGeeCollectionsTest.vala"
		_tmp81_ = _tmp80_;
#line 645 "SerializableGeeCollectionsTest.vala"
		_vala_assert (_tmp81_ == 2, "d.root.children_nodes[0].children_nodes.size == 2");
#line 645 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp79_);
#line 645 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp76_);
#line 645 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp74_);
#line 645 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp71_);
#line 646 "SerializableGeeCollectionsTest.vala"
		_tmp82_ = d;
#line 646 "SerializableGeeCollectionsTest.vala"
		_tmp83_ = gxml_document_get_root ((GXmlDocument*) _tmp82_);
#line 646 "SerializableGeeCollectionsTest.vala"
		_tmp84_ = _tmp83_;
#line 646 "SerializableGeeCollectionsTest.vala"
		_tmp85_ = _tmp84_;
#line 646 "SerializableGeeCollectionsTest.vala"
		_tmp86_ = gxml_node_get_children_nodes (_tmp85_);
#line 646 "SerializableGeeCollectionsTest.vala"
		_tmp87_ = _tmp86_;
#line 646 "SerializableGeeCollectionsTest.vala"
		_tmp88_ = _tmp87_;
#line 646 "SerializableGeeCollectionsTest.vala"
		_tmp89_ = gee_list_get ((GeeList*) _tmp88_, 0);
#line 646 "SerializableGeeCollectionsTest.vala"
		_tmp90_ = (GXmlNode*) _tmp89_;
#line 646 "SerializableGeeCollectionsTest.vala"
		_tmp91_ = gxml_node_get_children_nodes (_tmp90_);
#line 646 "SerializableGeeCollectionsTest.vala"
		_tmp92_ = _tmp91_;
#line 646 "SerializableGeeCollectionsTest.vala"
		_tmp93_ = _tmp92_;
#line 646 "SerializableGeeCollectionsTest.vala"
		_tmp94_ = gee_list_get ((GeeList*) _tmp93_, 0);
#line 646 "SerializableGeeCollectionsTest.vala"
		_tmp95_ = (GXmlNode*) _tmp94_;
#line 646 "SerializableGeeCollectionsTest.vala"
		_tmp96_ = gxml_node_get_name (_tmp95_);
#line 646 "SerializableGeeCollectionsTest.vala"
		_tmp97_ = _tmp96_;
#line 646 "SerializableGeeCollectionsTest.vala"
		_tmp98_ = _tmp97_;
#line 646 "SerializableGeeCollectionsTest.vala"
		_vala_assert (g_strcmp0 (_tmp98_, "Ball") == 0, "d.root.children_nodes[0].children_nodes[0].name == \"Ball\"");
#line 646 "SerializableGeeCollectionsTest.vala"
		_g_free0 (_tmp98_);
#line 646 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp95_);
#line 646 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp93_);
#line 646 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp90_);
#line 646 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp88_);
#line 646 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp85_);
#line 648 "SerializableGeeCollectionsTest.vala"
		_tmp99_ = serializable_gee_collections_test_big_bag_new ();
#line 648 "SerializableGeeCollectionsTest.vala"
		bag2 = _tmp99_;
#line 649 "SerializableGeeCollectionsTest.vala"
		_tmp100_ = bag2;
#line 649 "SerializableGeeCollectionsTest.vala"
		_tmp101_ = d;
#line 649 "SerializableGeeCollectionsTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp100_, (GXmlNode*) _tmp101_, &_inner_error0_);
#line 649 "SerializableGeeCollectionsTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 649 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (bag2);
#line 649 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (d);
#line 649 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (bag);
#line 4915 "SerializableGeeCollectionsTest.c"
			goto __catch372_g_error;
		}
#line 650 "SerializableGeeCollectionsTest.vala"
		_tmp102_ = bag2;
#line 650 "SerializableGeeCollectionsTest.vala"
		_tmp103_ = serializable_gee_collections_test_big_bag_get_bags (_tmp102_);
#line 650 "SerializableGeeCollectionsTest.vala"
		_tmp104_ = _tmp103_;
#line 650 "SerializableGeeCollectionsTest.vala"
		_tmp105_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp104_);
#line 650 "SerializableGeeCollectionsTest.vala"
		_tmp106_ = _tmp105_;
#line 650 "SerializableGeeCollectionsTest.vala"
		_vala_assert (_tmp106_ == 0, "bag2.bags.size == 0");
#line 652 "SerializableGeeCollectionsTest.vala"
		_tmp107_ = gxml_tdocument_new ();
#line 652 "SerializableGeeCollectionsTest.vala"
		d2 = _tmp107_;
#line 653 "SerializableGeeCollectionsTest.vala"
		_tmp108_ = bag2;
#line 653 "SerializableGeeCollectionsTest.vala"
		_tmp109_ = d2;
#line 653 "SerializableGeeCollectionsTest.vala"
		_tmp110_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp108_, (GXmlNode*) _tmp109_, &_inner_error0_);
#line 653 "SerializableGeeCollectionsTest.vala"
		_tmp111_ = _tmp110_;
#line 653 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp111_);
#line 653 "SerializableGeeCollectionsTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 653 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (d2);
#line 653 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (bag2);
#line 653 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (d);
#line 653 "SerializableGeeCollectionsTest.vala"
			_g_object_unref0 (bag);
#line 4954 "SerializableGeeCollectionsTest.c"
			goto __catch372_g_error;
		}
#line 654 "SerializableGeeCollectionsTest.vala"
		_tmp112_ = d2;
#line 654 "SerializableGeeCollectionsTest.vala"
		_tmp113_ = gxml_document_get_root ((GXmlDocument*) _tmp112_);
#line 654 "SerializableGeeCollectionsTest.vala"
		_tmp114_ = _tmp113_;
#line 654 "SerializableGeeCollectionsTest.vala"
		_tmp115_ = _tmp114_;
#line 654 "SerializableGeeCollectionsTest.vala"
		_vala_assert (_tmp115_ != NULL, "d2.root != null");
#line 654 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp115_);
#line 655 "SerializableGeeCollectionsTest.vala"
		_tmp116_ = d2;
#line 655 "SerializableGeeCollectionsTest.vala"
		_tmp117_ = gxml_document_get_root ((GXmlDocument*) _tmp116_);
#line 655 "SerializableGeeCollectionsTest.vala"
		_tmp118_ = _tmp117_;
#line 655 "SerializableGeeCollectionsTest.vala"
		_tmp119_ = _tmp118_;
#line 655 "SerializableGeeCollectionsTest.vala"
		_tmp120_ = gxml_node_get_name (_tmp119_);
#line 655 "SerializableGeeCollectionsTest.vala"
		_tmp121_ = _tmp120_;
#line 655 "SerializableGeeCollectionsTest.vala"
		_tmp122_ = _tmp121_;
#line 655 "SerializableGeeCollectionsTest.vala"
		_vala_assert (g_strcmp0 (_tmp122_, "BigBag") == 0, "d2.root.name == \"BigBag\"");
#line 655 "SerializableGeeCollectionsTest.vala"
		_g_free0 (_tmp122_);
#line 655 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp119_);
#line 656 "SerializableGeeCollectionsTest.vala"
		_tmp123_ = d2;
#line 656 "SerializableGeeCollectionsTest.vala"
		_tmp124_ = gxml_document_get_root ((GXmlDocument*) _tmp123_);
#line 656 "SerializableGeeCollectionsTest.vala"
		_tmp125_ = _tmp124_;
#line 656 "SerializableGeeCollectionsTest.vala"
		_tmp126_ = _tmp125_;
#line 656 "SerializableGeeCollectionsTest.vala"
		_tmp127_ = gxml_node_get_children_nodes (_tmp126_);
#line 656 "SerializableGeeCollectionsTest.vala"
		_tmp128_ = _tmp127_;
#line 656 "SerializableGeeCollectionsTest.vala"
		_tmp129_ = _tmp128_;
#line 656 "SerializableGeeCollectionsTest.vala"
		_tmp130_ = gee_collection_get_size ((GeeCollection*) _tmp129_);
#line 656 "SerializableGeeCollectionsTest.vala"
		_tmp131_ = _tmp130_;
#line 656 "SerializableGeeCollectionsTest.vala"
		_vala_assert (_tmp131_ == 2, "d2.root.children_nodes.size == 2");
#line 656 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp129_);
#line 656 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp126_);
#line 657 "SerializableGeeCollectionsTest.vala"
		_tmp132_ = d2;
#line 657 "SerializableGeeCollectionsTest.vala"
		_tmp133_ = gxml_document_get_root ((GXmlDocument*) _tmp132_);
#line 657 "SerializableGeeCollectionsTest.vala"
		_tmp134_ = _tmp133_;
#line 657 "SerializableGeeCollectionsTest.vala"
		_tmp135_ = _tmp134_;
#line 657 "SerializableGeeCollectionsTest.vala"
		_tmp136_ = gxml_node_get_children_nodes (_tmp135_);
#line 657 "SerializableGeeCollectionsTest.vala"
		_tmp137_ = _tmp136_;
#line 657 "SerializableGeeCollectionsTest.vala"
		_tmp138_ = _tmp137_;
#line 657 "SerializableGeeCollectionsTest.vala"
		_tmp139_ = gee_list_get ((GeeList*) _tmp138_, 0);
#line 657 "SerializableGeeCollectionsTest.vala"
		_tmp140_ = (GXmlNode*) _tmp139_;
#line 657 "SerializableGeeCollectionsTest.vala"
		_tmp141_ = gxml_node_get_name (_tmp140_);
#line 657 "SerializableGeeCollectionsTest.vala"
		_tmp142_ = _tmp141_;
#line 657 "SerializableGeeCollectionsTest.vala"
		_tmp143_ = _tmp142_;
#line 657 "SerializableGeeCollectionsTest.vala"
		_vala_assert (g_strcmp0 (_tmp143_, "SmallBag") == 0, "d2.root.children_nodes[0].name == \"SmallBag\"");
#line 657 "SerializableGeeCollectionsTest.vala"
		_g_free0 (_tmp143_);
#line 657 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp140_);
#line 657 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp138_);
#line 657 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp135_);
#line 658 "SerializableGeeCollectionsTest.vala"
		_tmp144_ = d2;
#line 658 "SerializableGeeCollectionsTest.vala"
		_tmp145_ = gxml_document_get_root ((GXmlDocument*) _tmp144_);
#line 658 "SerializableGeeCollectionsTest.vala"
		_tmp146_ = _tmp145_;
#line 658 "SerializableGeeCollectionsTest.vala"
		_tmp147_ = _tmp146_;
#line 658 "SerializableGeeCollectionsTest.vala"
		_tmp148_ = gxml_node_get_children_nodes (_tmp147_);
#line 658 "SerializableGeeCollectionsTest.vala"
		_tmp149_ = _tmp148_;
#line 658 "SerializableGeeCollectionsTest.vala"
		_tmp150_ = _tmp149_;
#line 658 "SerializableGeeCollectionsTest.vala"
		_tmp151_ = gee_list_get ((GeeList*) _tmp150_, 0);
#line 658 "SerializableGeeCollectionsTest.vala"
		_tmp152_ = (GXmlNode*) _tmp151_;
#line 658 "SerializableGeeCollectionsTest.vala"
		_tmp153_ = gxml_node_get_children_nodes (_tmp152_);
#line 658 "SerializableGeeCollectionsTest.vala"
		_tmp154_ = _tmp153_;
#line 658 "SerializableGeeCollectionsTest.vala"
		_tmp155_ = _tmp154_;
#line 658 "SerializableGeeCollectionsTest.vala"
		_tmp156_ = gee_collection_get_size ((GeeCollection*) _tmp155_);
#line 658 "SerializableGeeCollectionsTest.vala"
		_tmp157_ = _tmp156_;
#line 658 "SerializableGeeCollectionsTest.vala"
		_vala_assert (_tmp157_ == 2, "d2.root.children_nodes[0].children_nodes.size == 2");
#line 658 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp155_);
#line 658 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp152_);
#line 658 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp150_);
#line 658 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp147_);
#line 659 "SerializableGeeCollectionsTest.vala"
		_tmp158_ = d2;
#line 659 "SerializableGeeCollectionsTest.vala"
		_tmp159_ = gxml_document_get_root ((GXmlDocument*) _tmp158_);
#line 659 "SerializableGeeCollectionsTest.vala"
		_tmp160_ = _tmp159_;
#line 659 "SerializableGeeCollectionsTest.vala"
		_tmp161_ = _tmp160_;
#line 659 "SerializableGeeCollectionsTest.vala"
		_tmp162_ = gxml_node_get_children_nodes (_tmp161_);
#line 659 "SerializableGeeCollectionsTest.vala"
		_tmp163_ = _tmp162_;
#line 659 "SerializableGeeCollectionsTest.vala"
		_tmp164_ = _tmp163_;
#line 659 "SerializableGeeCollectionsTest.vala"
		_tmp165_ = gee_list_get ((GeeList*) _tmp164_, 0);
#line 659 "SerializableGeeCollectionsTest.vala"
		_tmp166_ = (GXmlNode*) _tmp165_;
#line 659 "SerializableGeeCollectionsTest.vala"
		_tmp167_ = gxml_node_get_children_nodes (_tmp166_);
#line 659 "SerializableGeeCollectionsTest.vala"
		_tmp168_ = _tmp167_;
#line 659 "SerializableGeeCollectionsTest.vala"
		_tmp169_ = _tmp168_;
#line 659 "SerializableGeeCollectionsTest.vala"
		_tmp170_ = gee_list_get ((GeeList*) _tmp169_, 0);
#line 659 "SerializableGeeCollectionsTest.vala"
		_tmp171_ = (GXmlNode*) _tmp170_;
#line 659 "SerializableGeeCollectionsTest.vala"
		_tmp172_ = gxml_node_get_name (_tmp171_);
#line 659 "SerializableGeeCollectionsTest.vala"
		_tmp173_ = _tmp172_;
#line 659 "SerializableGeeCollectionsTest.vala"
		_tmp174_ = _tmp173_;
#line 659 "SerializableGeeCollectionsTest.vala"
		_vala_assert (g_strcmp0 (_tmp174_, "Ball") == 0, "d2.root.children_nodes[0].children_nodes[0].name == \"Ball\"");
#line 659 "SerializableGeeCollectionsTest.vala"
		_g_free0 (_tmp174_);
#line 659 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp171_);
#line 659 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp169_);
#line 659 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp166_);
#line 659 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp164_);
#line 659 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp161_);
#line 623 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (d2);
#line 623 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (bag2);
#line 623 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (d);
#line 623 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (bag);
#line 5141 "SerializableGeeCollectionsTest.c"
	}
	goto __finally372;
	__catch372_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp175_;
		gchar* _tmp176_;
		gchar* _tmp177_;
#line 623 "SerializableGeeCollectionsTest.vala"
		e = _inner_error0_;
#line 623 "SerializableGeeCollectionsTest.vala"
		_inner_error0_ = NULL;
#line 661 "SerializableGeeCollectionsTest.vala"
		_tmp175_ = e->message;
#line 661 "SerializableGeeCollectionsTest.vala"
		_tmp176_ = g_strconcat ("ERROR: ", _tmp175_, NULL);
#line 661 "SerializableGeeCollectionsTest.vala"
		_tmp177_ = _tmp176_;
#line 661 "SerializableGeeCollectionsTest.vala"
		g_message ("SerializableGeeCollectionsTest.vala:661: %s", _tmp177_);
#line 661 "SerializableGeeCollectionsTest.vala"
		_g_free0 (_tmp177_);
#line 662 "SerializableGeeCollectionsTest.vala"
		g_assert_not_reached ();
#line 623 "SerializableGeeCollectionsTest.vala"
		_g_error_free0 (e);
#line 5168 "SerializableGeeCollectionsTest.c"
	}
	__finally372:
#line 623 "SerializableGeeCollectionsTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 623 "SerializableGeeCollectionsTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 623 "SerializableGeeCollectionsTest.vala"
		g_clear_error (&_inner_error0_);
#line 623 "SerializableGeeCollectionsTest.vala"
		return;
#line 5179 "SerializableGeeCollectionsTest.c"
	}
}

static void
___lambda322__gtest_func (void)
{
#line 621 "SerializableGeeCollectionsTest.vala"
	__lambda322_ ();
#line 5188 "SerializableGeeCollectionsTest.c"
}

void
serializable_gee_collections_test_add_tests (void)
{
#line 219 "SerializableGeeCollectionsTest.vala"
	g_test_add_func ("/gxml/serializable/convined_gee_containers/deserialize", ___lambda319__gtest_func);
#line 322 "SerializableGeeCollectionsTest.vala"
	g_test_add_func ("/gxml/serializable/convined_gee_containers/de-se-deserialize", ___lambda320__gtest_func);
#line 443 "SerializableGeeCollectionsTest.vala"
	g_test_add_func ("/gxml/serializable/convined_gee_containers/se-deserialize-unknowns", ___lambda321__gtest_func);
#line 621 "SerializableGeeCollectionsTest.vala"
	g_test_add_func ("/gxml/serializable/containers/post-deserialization/serialize", ___lambda322__gtest_func);
#line 5202 "SerializableGeeCollectionsTest.c"
}

SerializableGeeCollectionsTest*
serializable_gee_collections_test_construct (GType object_type)
{
	SerializableGeeCollectionsTest* self = NULL;
#line 30 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTest*) gxml_test_construct (object_type);
#line 30 "SerializableGeeCollectionsTest.vala"
	return self;
#line 5213 "SerializableGeeCollectionsTest.c"
}

SerializableGeeCollectionsTest*
serializable_gee_collections_test_new (void)
{
#line 30 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_construct (TYPE_SERIALIZABLE_GEE_COLLECTIONS_TEST);
#line 5221 "SerializableGeeCollectionsTest.c"
}

static inline gpointer
serializable_gee_collections_test_citizen_get_instance_private (SerializableGeeCollectionsTestCitizen* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeCollectionsTestCitizen_private_offset);
}

static gboolean
serializable_gee_collections_test_citizen_real_serialize_use_xml_node_value (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestCitizen * self;
	gboolean result = FALSE;
#line 36 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestCitizen*) base;
#line 36 "SerializableGeeCollectionsTest.vala"
	result = TRUE;
#line 36 "SerializableGeeCollectionsTest.vala"
	return result;
#line 5241 "SerializableGeeCollectionsTest.c"
}

static gchar*
serializable_gee_collections_test_citizen_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestCitizen * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
#line 37 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestCitizen*) base;
#line 37 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_ctype;
#line 37 "SerializableGeeCollectionsTest.vala"
	_tmp1_ = string_to_string (_tmp0_);
#line 37 "SerializableGeeCollectionsTest.vala"
	_tmp2_ = g_strconcat ("Citizen: ", _tmp1_, NULL);
#line 37 "SerializableGeeCollectionsTest.vala"
	result = _tmp2_;
#line 37 "SerializableGeeCollectionsTest.vala"
	return result;
#line 5264 "SerializableGeeCollectionsTest.c"
}

static gchar*
serializable_gee_collections_test_citizen_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestCitizen * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 38 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestCitizen*) base;
#line 38 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = g_strdup ("citizen");
#line 38 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 38 "SerializableGeeCollectionsTest.vala"
	return result;
#line 5281 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestCitizen*
serializable_gee_collections_test_citizen_construct (GType object_type)
{
	SerializableGeeCollectionsTestCitizen * self = NULL;
#line 32 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestCitizen*) gxml_serializable_object_model_construct (object_type);
#line 32 "SerializableGeeCollectionsTest.vala"
	return self;
#line 5292 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestCitizen*
serializable_gee_collections_test_citizen_new (void)
{
#line 32 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_citizen_construct (SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_CITIZEN);
#line 5300 "SerializableGeeCollectionsTest.c"
}

static const gchar*
serializable_gee_collections_test_citizen_get_ctype (SerializableGeeCollectionsTestCitizen* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 34 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 34 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_ctype;
#line 34 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 34 "SerializableGeeCollectionsTest.vala"
	return result;
#line 5316 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_citizen_set_ctype (SerializableGeeCollectionsTestCitizen* self,
                                                     const gchar* value)
{
#line 34 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 34 "SerializableGeeCollectionsTest.vala"
	if (g_strcmp0 (value, serializable_gee_collections_test_citizen_get_ctype (self)) != 0) {
#line 5327 "SerializableGeeCollectionsTest.c"
		gchar* _tmp0_;
#line 34 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = g_strdup (value);
#line 34 "SerializableGeeCollectionsTest.vala"
		_g_free0 (self->priv->_ctype);
#line 34 "SerializableGeeCollectionsTest.vala"
		self->priv->_ctype = _tmp0_;
#line 34 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_citizen_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_CTYPE_PROPERTY]);
#line 5337 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestCitizenArray*
serializable_gee_collections_test_citizen_array_construct (GType object_type)
{
	SerializableGeeCollectionsTestCitizenArray * self = NULL;
#line 40 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestCitizenArray*) gxml_serializable_array_list_construct (object_type, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_CITIZEN, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 40 "SerializableGeeCollectionsTest.vala"
	return self;
#line 5349 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestCitizenArray*
serializable_gee_collections_test_citizen_array_new (void)
{
#line 40 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_citizen_array_construct (SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_TYPE_ARRAY);
#line 5357 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_citizen_array_class_init (SerializableGeeCollectionsTestCitizenArrayClass * klass,
                                                            gpointer klass_data)
{
#line 40 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_citizen_array_parent_class = g_type_class_peek_parent (klass);
#line 5366 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_citizen_array_instance_init (SerializableGeeCollectionsTestCitizenArray * self,
                                                               gpointer klass)
{
}

GType
serializable_gee_collections_test_citizen_array_get_type (void)
{
	static volatile gsize serializable_gee_collections_test_citizen_array_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_test_citizen_array_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTestCitizenArrayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_test_citizen_array_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTestCitizenArray), 0, (GInstanceInitFunc) serializable_gee_collections_test_citizen_array_instance_init, NULL };
		GType serializable_gee_collections_test_citizen_array_type_id;
		serializable_gee_collections_test_citizen_array_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_ARRAY_LIST, "SerializableGeeCollectionsTestCitizenArray", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_collections_test_citizen_array_type_id__volatile, serializable_gee_collections_test_citizen_array_type_id);
	}
	return serializable_gee_collections_test_citizen_array_type_id__volatile;
}

static void
serializable_gee_collections_test_citizen_class_init (SerializableGeeCollectionsTestCitizenClass * klass,
                                                      gpointer klass_data)
{
#line 32 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_citizen_parent_class = g_type_class_peek_parent (klass);
#line 32 "SerializableGeeCollectionsTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeCollectionsTestCitizen_private_offset);
#line 32 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->serialize_use_xml_node_value = (gboolean (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_citizen_real_serialize_use_xml_node_value;
#line 32 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_citizen_real_to_string;
#line 32 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_citizen_real_node_name;
#line 32 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_collections_test_citizen_get_property;
#line 32 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_collections_test_citizen_set_property;
#line 32 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_collections_test_citizen_finalize;
#line 32 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_CTYPE_PROPERTY, serializable_gee_collections_test_citizen_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_CTYPE_PROPERTY] = g_param_spec_string ("ctype", "ctype", "ctype", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5410 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_citizen_instance_init (SerializableGeeCollectionsTestCitizen * self,
                                                         gpointer klass)
{
#line 32 "SerializableGeeCollectionsTest.vala"
	self->priv = serializable_gee_collections_test_citizen_get_instance_private (self);
#line 5419 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_citizen_finalize (GObject * obj)
{
	SerializableGeeCollectionsTestCitizen * self;
#line 32 "SerializableGeeCollectionsTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_CITIZEN, SerializableGeeCollectionsTestCitizen);
#line 34 "SerializableGeeCollectionsTest.vala"
	_g_free0 (self->priv->_ctype);
#line 32 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (serializable_gee_collections_test_citizen_parent_class)->finalize (obj);
#line 5432 "SerializableGeeCollectionsTest.c"
}

static GType
serializable_gee_collections_test_citizen_get_type (void)
{
	static volatile gsize serializable_gee_collections_test_citizen_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_test_citizen_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTestCitizenClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_test_citizen_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTestCitizen), 0, (GInstanceInitFunc) serializable_gee_collections_test_citizen_instance_init, NULL };
		GType serializable_gee_collections_test_citizen_type_id;
		serializable_gee_collections_test_citizen_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeCollectionsTestCitizen", &g_define_type_info, 0);
		SerializableGeeCollectionsTestCitizen_private_offset = g_type_add_instance_private (serializable_gee_collections_test_citizen_type_id, sizeof (SerializableGeeCollectionsTestCitizenPrivate));
		g_once_init_leave (&serializable_gee_collections_test_citizen_type_id__volatile, serializable_gee_collections_test_citizen_type_id);
	}
	return serializable_gee_collections_test_citizen_type_id__volatile;
}

static void
_vala_serializable_gee_collections_test_citizen_get_property (GObject * object,
                                                              guint property_id,
                                                              GValue * value,
                                                              GParamSpec * pspec)
{
	SerializableGeeCollectionsTestCitizen * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_CITIZEN, SerializableGeeCollectionsTestCitizen);
#line 32 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 32 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_CTYPE_PROPERTY:
#line 32 "SerializableGeeCollectionsTest.vala"
		g_value_set_string (value, serializable_gee_collections_test_citizen_get_ctype (self));
#line 32 "SerializableGeeCollectionsTest.vala"
		break;
#line 5465 "SerializableGeeCollectionsTest.c"
		default:
#line 32 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 32 "SerializableGeeCollectionsTest.vala"
		break;
#line 5471 "SerializableGeeCollectionsTest.c"
	}
}

static void
_vala_serializable_gee_collections_test_citizen_set_property (GObject * object,
                                                              guint property_id,
                                                              const GValue * value,
                                                              GParamSpec * pspec)
{
	SerializableGeeCollectionsTestCitizen * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_CITIZEN, SerializableGeeCollectionsTestCitizen);
#line 32 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 32 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_CTYPE_PROPERTY:
#line 32 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_citizen_set_ctype (self, g_value_get_string (value));
#line 32 "SerializableGeeCollectionsTest.vala"
		break;
#line 5491 "SerializableGeeCollectionsTest.c"
		default:
#line 32 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 32 "SerializableGeeCollectionsTest.vala"
		break;
#line 5497 "SerializableGeeCollectionsTest.c"
	}
}

static inline gpointer
serializable_gee_collections_test_asteroid_get_instance_private (SerializableGeeCollectionsTestAsteroid* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeCollectionsTestAsteroid_private_offset);
}

static SerializableGeeCollectionsTestAsteroid*
serializable_gee_collections_test_asteroid_construct_with_size (GType object_type,
                                                                gint size)
{
	SerializableGeeCollectionsTestAsteroid * self = NULL;
#line 45 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestAsteroid*) gxml_serializable_object_model_construct (object_type);
#line 45 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_asteroid_set_size (self, size);
#line 45 "SerializableGeeCollectionsTest.vala"
	return self;
#line 5518 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestAsteroid*
serializable_gee_collections_test_asteroid_new_with_size (gint size)
{
#line 45 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_asteroid_construct_with_size (SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_ASTEROID, size);
#line 5526 "SerializableGeeCollectionsTest.c"
}

static gchar*
serializable_gee_collections_test_asteroid_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestAsteroid * self;
	gchar* result = NULL;
	gint _tmp0_;
	gchar* _tmp1_;
#line 46 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestAsteroid*) base;
#line 46 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_size;
#line 46 "SerializableGeeCollectionsTest.vala"
	_tmp1_ = g_strdup_printf ("%i", _tmp0_);
#line 46 "SerializableGeeCollectionsTest.vala"
	result = _tmp1_;
#line 46 "SerializableGeeCollectionsTest.vala"
	return result;
#line 5546 "SerializableGeeCollectionsTest.c"
}

static gchar*
serializable_gee_collections_test_asteroid_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestAsteroid * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 47 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestAsteroid*) base;
#line 47 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = g_strdup ("asteroid");
#line 47 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 47 "SerializableGeeCollectionsTest.vala"
	return result;
#line 5563 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestAsteroid*
serializable_gee_collections_test_asteroid_construct (GType object_type)
{
	SerializableGeeCollectionsTestAsteroid * self = NULL;
#line 42 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestAsteroid*) gxml_serializable_object_model_construct (object_type);
#line 42 "SerializableGeeCollectionsTest.vala"
	return self;
#line 5574 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestAsteroid*
serializable_gee_collections_test_asteroid_new (void)
{
#line 42 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_asteroid_construct (SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_ASTEROID);
#line 5582 "SerializableGeeCollectionsTest.c"
}

static gint
serializable_gee_collections_test_asteroid_get_size (SerializableGeeCollectionsTestAsteroid* self)
{
	gint result;
#line 44 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 44 "SerializableGeeCollectionsTest.vala"
	result = self->priv->_size;
#line 44 "SerializableGeeCollectionsTest.vala"
	return result;
#line 5595 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_asteroid_set_size (SerializableGeeCollectionsTestAsteroid* self,
                                                     gint value)
{
#line 44 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 44 "SerializableGeeCollectionsTest.vala"
	if (serializable_gee_collections_test_asteroid_get_size (self) != value) {
#line 44 "SerializableGeeCollectionsTest.vala"
		self->priv->_size = value;
#line 44 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_asteroid_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_SIZE_PROPERTY]);
#line 5610 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestAsteroidArray*
serializable_gee_collections_test_asteroid_array_construct (GType object_type)
{
	SerializableGeeCollectionsTestAsteroidArray * self = NULL;
#line 49 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestAsteroidArray*) gxml_serializable_array_list_construct (object_type, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_ASTEROID, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 49 "SerializableGeeCollectionsTest.vala"
	return self;
#line 5622 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestAsteroidArray*
serializable_gee_collections_test_asteroid_array_new (void)
{
#line 49 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_asteroid_array_construct (SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_TYPE_ARRAY);
#line 5630 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_asteroid_array_class_init (SerializableGeeCollectionsTestAsteroidArrayClass * klass,
                                                             gpointer klass_data)
{
#line 49 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_asteroid_array_parent_class = g_type_class_peek_parent (klass);
#line 5639 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_asteroid_array_instance_init (SerializableGeeCollectionsTestAsteroidArray * self,
                                                                gpointer klass)
{
}

GType
serializable_gee_collections_test_asteroid_array_get_type (void)
{
	static volatile gsize serializable_gee_collections_test_asteroid_array_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_test_asteroid_array_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTestAsteroidArrayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_test_asteroid_array_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTestAsteroidArray), 0, (GInstanceInitFunc) serializable_gee_collections_test_asteroid_array_instance_init, NULL };
		GType serializable_gee_collections_test_asteroid_array_type_id;
		serializable_gee_collections_test_asteroid_array_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_ARRAY_LIST, "SerializableGeeCollectionsTestAsteroidArray", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_collections_test_asteroid_array_type_id__volatile, serializable_gee_collections_test_asteroid_array_type_id);
	}
	return serializable_gee_collections_test_asteroid_array_type_id__volatile;
}

static void
serializable_gee_collections_test_asteroid_class_init (SerializableGeeCollectionsTestAsteroidClass * klass,
                                                       gpointer klass_data)
{
#line 42 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_asteroid_parent_class = g_type_class_peek_parent (klass);
#line 42 "SerializableGeeCollectionsTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeCollectionsTestAsteroid_private_offset);
#line 42 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_asteroid_real_to_string;
#line 42 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_asteroid_real_node_name;
#line 42 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_collections_test_asteroid_get_property;
#line 42 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_collections_test_asteroid_set_property;
#line 42 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_collections_test_asteroid_finalize;
#line 42 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_SIZE_PROPERTY, serializable_gee_collections_test_asteroid_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_SIZE_PROPERTY] = g_param_spec_int ("size", "size", "size", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5681 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_asteroid_instance_init (SerializableGeeCollectionsTestAsteroid * self,
                                                          gpointer klass)
{
#line 42 "SerializableGeeCollectionsTest.vala"
	self->priv = serializable_gee_collections_test_asteroid_get_instance_private (self);
#line 5690 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_asteroid_finalize (GObject * obj)
{
	SerializableGeeCollectionsTestAsteroid * self;
#line 42 "SerializableGeeCollectionsTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_ASTEROID, SerializableGeeCollectionsTestAsteroid);
#line 42 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (serializable_gee_collections_test_asteroid_parent_class)->finalize (obj);
#line 5701 "SerializableGeeCollectionsTest.c"
}

static GType
serializable_gee_collections_test_asteroid_get_type (void)
{
	static volatile gsize serializable_gee_collections_test_asteroid_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_test_asteroid_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTestAsteroidClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_test_asteroid_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTestAsteroid), 0, (GInstanceInitFunc) serializable_gee_collections_test_asteroid_instance_init, NULL };
		GType serializable_gee_collections_test_asteroid_type_id;
		serializable_gee_collections_test_asteroid_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeCollectionsTestAsteroid", &g_define_type_info, 0);
		SerializableGeeCollectionsTestAsteroid_private_offset = g_type_add_instance_private (serializable_gee_collections_test_asteroid_type_id, sizeof (SerializableGeeCollectionsTestAsteroidPrivate));
		g_once_init_leave (&serializable_gee_collections_test_asteroid_type_id__volatile, serializable_gee_collections_test_asteroid_type_id);
	}
	return serializable_gee_collections_test_asteroid_type_id__volatile;
}

static void
_vala_serializable_gee_collections_test_asteroid_get_property (GObject * object,
                                                               guint property_id,
                                                               GValue * value,
                                                               GParamSpec * pspec)
{
	SerializableGeeCollectionsTestAsteroid * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_ASTEROID, SerializableGeeCollectionsTestAsteroid);
#line 42 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 42 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_SIZE_PROPERTY:
#line 42 "SerializableGeeCollectionsTest.vala"
		g_value_set_int (value, serializable_gee_collections_test_asteroid_get_size (self));
#line 42 "SerializableGeeCollectionsTest.vala"
		break;
#line 5734 "SerializableGeeCollectionsTest.c"
		default:
#line 42 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 42 "SerializableGeeCollectionsTest.vala"
		break;
#line 5740 "SerializableGeeCollectionsTest.c"
	}
}

static void
_vala_serializable_gee_collections_test_asteroid_set_property (GObject * object,
                                                               guint property_id,
                                                               const GValue * value,
                                                               GParamSpec * pspec)
{
	SerializableGeeCollectionsTestAsteroid * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_ASTEROID, SerializableGeeCollectionsTestAsteroid);
#line 42 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 42 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_SIZE_PROPERTY:
#line 42 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_asteroid_set_size (self, g_value_get_int (value));
#line 42 "SerializableGeeCollectionsTest.vala"
		break;
#line 5760 "SerializableGeeCollectionsTest.c"
		default:
#line 42 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 42 "SerializableGeeCollectionsTest.vala"
		break;
#line 5766 "SerializableGeeCollectionsTest.c"
	}
}

static inline gpointer
serializable_gee_collections_test_planet_get_instance_private (SerializableGeeCollectionsTestPlanet* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeCollectionsTestPlanet_private_offset);
}

static gchar*
serializable_gee_collections_test_planet_real_get_map_key (GXmlSerializableMapKey* base)
{
	SerializableGeeCollectionsTestPlanet * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 53 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestPlanet*) base;
#line 53 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_name;
#line 53 "SerializableGeeCollectionsTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 53 "SerializableGeeCollectionsTest.vala"
	result = _tmp1_;
#line 53 "SerializableGeeCollectionsTest.vala"
	return result;
#line 5793 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestPlanet*
serializable_gee_collections_test_planet_construct_named (GType object_type,
                                                          const gchar* name)
{
	SerializableGeeCollectionsTestPlanet * self = NULL;
#line 56 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 56 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestPlanet*) gxml_serializable_container_construct (object_type);
#line 56 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_planet_set_name (self, name);
#line 56 "SerializableGeeCollectionsTest.vala"
	return self;
#line 5809 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestPlanet*
serializable_gee_collections_test_planet_new_named (const gchar* name)
{
#line 56 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_planet_construct_named (SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_PLANET, name);
#line 5817 "SerializableGeeCollectionsTest.c"
}

static gchar*
serializable_gee_collections_test_planet_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestPlanet * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 57 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestPlanet*) base;
#line 57 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = g_strdup ("planet");
#line 57 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 57 "SerializableGeeCollectionsTest.vala"
	return result;
#line 5834 "SerializableGeeCollectionsTest.c"
}

static gchar*
serializable_gee_collections_test_planet_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestPlanet * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 58 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestPlanet*) base;
#line 58 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_name;
#line 58 "SerializableGeeCollectionsTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 58 "SerializableGeeCollectionsTest.vala"
	result = _tmp1_;
#line 58 "SerializableGeeCollectionsTest.vala"
	return result;
#line 5854 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_planet_real_init_containers (GXmlSerializableContainer* base)
{
	SerializableGeeCollectionsTestPlanet * self;
	SerializableGeeCollectionsTestCitizenArray* _tmp0_;
#line 60 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestPlanet*) base;
#line 62 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_citizens;
#line 62 "SerializableGeeCollectionsTest.vala"
	if (_tmp0_ == NULL) {
#line 5868 "SerializableGeeCollectionsTest.c"
		SerializableGeeCollectionsTestCitizenArray* _tmp1_;
		SerializableGeeCollectionsTestCitizenArray* _tmp2_;
#line 63 "SerializableGeeCollectionsTest.vala"
		_tmp1_ = serializable_gee_collections_test_citizen_array_new ();
#line 63 "SerializableGeeCollectionsTest.vala"
		_tmp2_ = _tmp1_;
#line 63 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_planet_set_citizens (self, _tmp2_);
#line 63 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp2_);
#line 5879 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestPlanet*
serializable_gee_collections_test_planet_construct (GType object_type)
{
	SerializableGeeCollectionsTestPlanet * self = NULL;
#line 51 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestPlanet*) gxml_serializable_container_construct (object_type);
#line 51 "SerializableGeeCollectionsTest.vala"
	return self;
#line 5891 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestPlanet*
serializable_gee_collections_test_planet_new (void)
{
#line 51 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_planet_construct (SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_PLANET);
#line 5899 "SerializableGeeCollectionsTest.c"
}

static const gchar*
serializable_gee_collections_test_planet_get_name (SerializableGeeCollectionsTestPlanet* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 54 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 54 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_name;
#line 54 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 54 "SerializableGeeCollectionsTest.vala"
	return result;
#line 5915 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_planet_set_name (SerializableGeeCollectionsTestPlanet* self,
                                                   const gchar* value)
{
#line 54 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 54 "SerializableGeeCollectionsTest.vala"
	if (g_strcmp0 (value, serializable_gee_collections_test_planet_get_name (self)) != 0) {
#line 5926 "SerializableGeeCollectionsTest.c"
		gchar* _tmp0_;
#line 54 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = g_strdup (value);
#line 54 "SerializableGeeCollectionsTest.vala"
		_g_free0 (self->priv->_name);
#line 54 "SerializableGeeCollectionsTest.vala"
		self->priv->_name = _tmp0_;
#line 54 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_planet_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_NAME_PROPERTY]);
#line 5936 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestCitizenArray*
serializable_gee_collections_test_planet_get_citizens (SerializableGeeCollectionsTestPlanet* self)
{
	SerializableGeeCollectionsTestCitizenArray* result;
	SerializableGeeCollectionsTestCitizenArray* _tmp0_;
#line 55 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 55 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_citizens;
#line 55 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 55 "SerializableGeeCollectionsTest.vala"
	return result;
#line 5953 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_planet_set_citizens (SerializableGeeCollectionsTestPlanet* self,
                                                       SerializableGeeCollectionsTestCitizenArray* value)
{
#line 55 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 55 "SerializableGeeCollectionsTest.vala"
	if (serializable_gee_collections_test_planet_get_citizens (self) != value) {
#line 5964 "SerializableGeeCollectionsTest.c"
		SerializableGeeCollectionsTestCitizenArray* _tmp0_;
#line 55 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 55 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (self->priv->_citizens);
#line 55 "SerializableGeeCollectionsTest.vala"
		self->priv->_citizens = _tmp0_;
#line 55 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_planet_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_CITIZENS_PROPERTY]);
#line 5974 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestPlanetCollection*
serializable_gee_collections_test_planet_collection_construct (GType object_type)
{
	SerializableGeeCollectionsTestPlanetCollection * self = NULL;
#line 66 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestPlanetCollection*) gxml_serializable_tree_map_construct (object_type, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_PLANET, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 66 "SerializableGeeCollectionsTest.vala"
	return self;
#line 5986 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestPlanetCollection*
serializable_gee_collections_test_planet_collection_new (void)
{
#line 66 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_planet_collection_construct (SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_TYPE_COLLECTION);
#line 5994 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_planet_collection_class_init (SerializableGeeCollectionsTestPlanetCollectionClass * klass,
                                                                gpointer klass_data)
{
#line 66 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_planet_collection_parent_class = g_type_class_peek_parent (klass);
#line 6003 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_planet_collection_instance_init (SerializableGeeCollectionsTestPlanetCollection * self,
                                                                   gpointer klass)
{
}

GType
serializable_gee_collections_test_planet_collection_get_type (void)
{
	static volatile gsize serializable_gee_collections_test_planet_collection_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_test_planet_collection_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTestPlanetCollectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_test_planet_collection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTestPlanetCollection), 0, (GInstanceInitFunc) serializable_gee_collections_test_planet_collection_instance_init, NULL };
		GType serializable_gee_collections_test_planet_collection_type_id;
		serializable_gee_collections_test_planet_collection_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_TREE_MAP, "SerializableGeeCollectionsTestPlanetCollection", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_collections_test_planet_collection_type_id__volatile, serializable_gee_collections_test_planet_collection_type_id);
	}
	return serializable_gee_collections_test_planet_collection_type_id__volatile;
}

static void
serializable_gee_collections_test_planet_class_init (SerializableGeeCollectionsTestPlanetClass * klass,
                                                     gpointer klass_data)
{
#line 51 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_planet_parent_class = g_type_class_peek_parent (klass);
#line 51 "SerializableGeeCollectionsTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeCollectionsTestPlanet_private_offset);
#line 51 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_planet_real_node_name;
#line 51 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_planet_real_to_string;
#line 51 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableContainerClass *) klass)->init_containers = (void (*) (GXmlSerializableContainer*)) serializable_gee_collections_test_planet_real_init_containers;
#line 51 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_collections_test_planet_get_property;
#line 51 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_collections_test_planet_set_property;
#line 51 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_collections_test_planet_finalize;
#line 51 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_NAME_PROPERTY, serializable_gee_collections_test_planet_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 51 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_CITIZENS_PROPERTY, serializable_gee_collections_test_planet_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_CITIZENS_PROPERTY] = g_param_spec_object ("citizens", "citizens", "citizens", SERIALIZABLE_GEE_COLLECTIONS_TEST_CITIZEN_TYPE_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6049 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_planet_gxml_serializable_map_key_interface_init (GXmlSerializableMapKeyIface * iface,
                                                                                   gpointer iface_data)
{
#line 51 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_planet_gxml_serializable_map_key_parent_iface = g_type_interface_peek_parent (iface);
#line 51 "SerializableGeeCollectionsTest.vala"
	iface->get_map_key = (gpointer (*) (GXmlSerializableMapKey*)) serializable_gee_collections_test_planet_real_get_map_key;
#line 6060 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_planet_instance_init (SerializableGeeCollectionsTestPlanet * self,
                                                        gpointer klass)
{
#line 51 "SerializableGeeCollectionsTest.vala"
	self->priv = serializable_gee_collections_test_planet_get_instance_private (self);
#line 6069 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_planet_finalize (GObject * obj)
{
	SerializableGeeCollectionsTestPlanet * self;
#line 51 "SerializableGeeCollectionsTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_PLANET, SerializableGeeCollectionsTestPlanet);
#line 54 "SerializableGeeCollectionsTest.vala"
	_g_free0 (self->priv->_name);
#line 55 "SerializableGeeCollectionsTest.vala"
	_g_object_unref0 (self->priv->_citizens);
#line 51 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (serializable_gee_collections_test_planet_parent_class)->finalize (obj);
#line 6084 "SerializableGeeCollectionsTest.c"
}

static GType
serializable_gee_collections_test_planet_get_type (void)
{
	static volatile gsize serializable_gee_collections_test_planet_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_test_planet_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTestPlanetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_test_planet_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTestPlanet), 0, (GInstanceInitFunc) serializable_gee_collections_test_planet_instance_init, NULL };
		static const GInterfaceInfo gxml_serializable_map_key_info = { (GInterfaceInitFunc) serializable_gee_collections_test_planet_gxml_serializable_map_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType serializable_gee_collections_test_planet_type_id;
		serializable_gee_collections_test_planet_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_CONTAINER, "SerializableGeeCollectionsTestPlanet", &g_define_type_info, 0);
		g_type_add_interface_static (serializable_gee_collections_test_planet_type_id, GXML_TYPE_SERIALIZABLE_MAP_KEY, &gxml_serializable_map_key_info);
		SerializableGeeCollectionsTestPlanet_private_offset = g_type_add_instance_private (serializable_gee_collections_test_planet_type_id, sizeof (SerializableGeeCollectionsTestPlanetPrivate));
		g_once_init_leave (&serializable_gee_collections_test_planet_type_id__volatile, serializable_gee_collections_test_planet_type_id);
	}
	return serializable_gee_collections_test_planet_type_id__volatile;
}

static void
_vala_serializable_gee_collections_test_planet_get_property (GObject * object,
                                                             guint property_id,
                                                             GValue * value,
                                                             GParamSpec * pspec)
{
	SerializableGeeCollectionsTestPlanet * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_PLANET, SerializableGeeCollectionsTestPlanet);
#line 51 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 51 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_NAME_PROPERTY:
#line 51 "SerializableGeeCollectionsTest.vala"
		g_value_set_string (value, serializable_gee_collections_test_planet_get_name (self));
#line 51 "SerializableGeeCollectionsTest.vala"
		break;
#line 51 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_CITIZENS_PROPERTY:
#line 51 "SerializableGeeCollectionsTest.vala"
		g_value_set_object (value, serializable_gee_collections_test_planet_get_citizens (self));
#line 51 "SerializableGeeCollectionsTest.vala"
		break;
#line 6125 "SerializableGeeCollectionsTest.c"
		default:
#line 51 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 51 "SerializableGeeCollectionsTest.vala"
		break;
#line 6131 "SerializableGeeCollectionsTest.c"
	}
}

static void
_vala_serializable_gee_collections_test_planet_set_property (GObject * object,
                                                             guint property_id,
                                                             const GValue * value,
                                                             GParamSpec * pspec)
{
	SerializableGeeCollectionsTestPlanet * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_PLANET, SerializableGeeCollectionsTestPlanet);
#line 51 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 51 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_NAME_PROPERTY:
#line 51 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_planet_set_name (self, g_value_get_string (value));
#line 51 "SerializableGeeCollectionsTest.vala"
		break;
#line 51 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_CITIZENS_PROPERTY:
#line 51 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_planet_set_citizens (self, g_value_get_object (value));
#line 51 "SerializableGeeCollectionsTest.vala"
		break;
#line 6157 "SerializableGeeCollectionsTest.c"
		default:
#line 51 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 51 "SerializableGeeCollectionsTest.vala"
		break;
#line 6163 "SerializableGeeCollectionsTest.c"
	}
}

static inline gpointer
serializable_gee_collections_test_space_get_instance_private (SerializableGeeCollectionsTestSpace* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeCollectionsTestSpace_private_offset);
}

static gchar*
serializable_gee_collections_test_space_real_get_map_key (GXmlSerializableMapKey* base)
{
	SerializableGeeCollectionsTestSpace * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 70 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSpace*) base;
#line 70 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_name;
#line 70 "SerializableGeeCollectionsTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 70 "SerializableGeeCollectionsTest.vala"
	result = _tmp1_;
#line 70 "SerializableGeeCollectionsTest.vala"
	return result;
#line 6190 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestSpace*
serializable_gee_collections_test_space_construct_named (GType object_type,
                                                         const gchar* name)
{
	SerializableGeeCollectionsTestSpace * self = NULL;
#line 75 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 75 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSpace*) gxml_serializable_container_construct (object_type);
#line 75 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_space_set_name (self, name);
#line 75 "SerializableGeeCollectionsTest.vala"
	return self;
#line 6206 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestSpace*
serializable_gee_collections_test_space_new_named (const gchar* name)
{
#line 75 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_space_construct_named (SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE, name);
#line 6214 "SerializableGeeCollectionsTest.c"
}

static gchar*
serializable_gee_collections_test_space_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestSpace * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 77 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSpace*) base;
#line 77 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = g_strdup ("space");
#line 77 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 77 "SerializableGeeCollectionsTest.vala"
	return result;
#line 6231 "SerializableGeeCollectionsTest.c"
}

static gchar*
serializable_gee_collections_test_space_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestSpace * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 78 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSpace*) base;
#line 78 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_name;
#line 78 "SerializableGeeCollectionsTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 78 "SerializableGeeCollectionsTest.vala"
	result = _tmp1_;
#line 78 "SerializableGeeCollectionsTest.vala"
	return result;
#line 6251 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_space_real_init_containers (GXmlSerializableContainer* base)
{
	SerializableGeeCollectionsTestSpace * self;
	SerializableGeeCollectionsTestAsteroidArray* _tmp0_;
	SerializableGeeCollectionsTestPlanetCollection* _tmp3_;
#line 79 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSpace*) base;
#line 81 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_asteroids;
#line 81 "SerializableGeeCollectionsTest.vala"
	if (_tmp0_ == NULL) {
#line 6266 "SerializableGeeCollectionsTest.c"
		SerializableGeeCollectionsTestAsteroidArray* _tmp1_;
		SerializableGeeCollectionsTestAsteroidArray* _tmp2_;
#line 82 "SerializableGeeCollectionsTest.vala"
		_tmp1_ = serializable_gee_collections_test_asteroid_array_new ();
#line 82 "SerializableGeeCollectionsTest.vala"
		_tmp2_ = _tmp1_;
#line 82 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_space_set_asteroids (self, _tmp2_);
#line 82 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp2_);
#line 6277 "SerializableGeeCollectionsTest.c"
	}
#line 83 "SerializableGeeCollectionsTest.vala"
	_tmp3_ = self->priv->_planets;
#line 83 "SerializableGeeCollectionsTest.vala"
	if (_tmp3_ == NULL) {
#line 6283 "SerializableGeeCollectionsTest.c"
		SerializableGeeCollectionsTestPlanetCollection* _tmp4_;
		SerializableGeeCollectionsTestPlanetCollection* _tmp5_;
#line 84 "SerializableGeeCollectionsTest.vala"
		_tmp4_ = serializable_gee_collections_test_planet_collection_new ();
#line 84 "SerializableGeeCollectionsTest.vala"
		_tmp5_ = _tmp4_;
#line 84 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_space_set_planets (self, _tmp5_);
#line 84 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp5_);
#line 6294 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestSpace*
serializable_gee_collections_test_space_construct (GType object_type)
{
	SerializableGeeCollectionsTestSpace * self = NULL;
#line 68 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSpace*) gxml_serializable_container_construct (object_type);
#line 68 "SerializableGeeCollectionsTest.vala"
	return self;
#line 6306 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestSpace*
serializable_gee_collections_test_space_new (void)
{
#line 68 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_space_construct (SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE);
#line 6314 "SerializableGeeCollectionsTest.c"
}

static const gchar*
serializable_gee_collections_test_space_get_name (SerializableGeeCollectionsTestSpace* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 71 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 71 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_name;
#line 71 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 71 "SerializableGeeCollectionsTest.vala"
	return result;
#line 6330 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_space_set_name (SerializableGeeCollectionsTestSpace* self,
                                                  const gchar* value)
{
#line 71 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 71 "SerializableGeeCollectionsTest.vala"
	if (g_strcmp0 (value, serializable_gee_collections_test_space_get_name (self)) != 0) {
#line 6341 "SerializableGeeCollectionsTest.c"
		gchar* _tmp0_;
#line 71 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = g_strdup (value);
#line 71 "SerializableGeeCollectionsTest.vala"
		_g_free0 (self->priv->_name);
#line 71 "SerializableGeeCollectionsTest.vala"
		self->priv->_name = _tmp0_;
#line 71 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_space_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_NAME_PROPERTY]);
#line 6351 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestPlanetCollection*
serializable_gee_collections_test_space_get_planets (SerializableGeeCollectionsTestSpace* self)
{
	SerializableGeeCollectionsTestPlanetCollection* result;
	SerializableGeeCollectionsTestPlanetCollection* _tmp0_;
#line 72 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 72 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_planets;
#line 72 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 72 "SerializableGeeCollectionsTest.vala"
	return result;
#line 6368 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_space_set_planets (SerializableGeeCollectionsTestSpace* self,
                                                     SerializableGeeCollectionsTestPlanetCollection* value)
{
#line 72 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 72 "SerializableGeeCollectionsTest.vala"
	if (serializable_gee_collections_test_space_get_planets (self) != value) {
#line 6379 "SerializableGeeCollectionsTest.c"
		SerializableGeeCollectionsTestPlanetCollection* _tmp0_;
#line 72 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 72 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (self->priv->_planets);
#line 72 "SerializableGeeCollectionsTest.vala"
		self->priv->_planets = _tmp0_;
#line 72 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_space_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_PLANETS_PROPERTY]);
#line 6389 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestAsteroidArray*
serializable_gee_collections_test_space_get_asteroids (SerializableGeeCollectionsTestSpace* self)
{
	SerializableGeeCollectionsTestAsteroidArray* result;
	SerializableGeeCollectionsTestAsteroidArray* _tmp0_;
#line 73 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 73 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_asteroids;
#line 73 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 73 "SerializableGeeCollectionsTest.vala"
	return result;
#line 6406 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_space_set_asteroids (SerializableGeeCollectionsTestSpace* self,
                                                       SerializableGeeCollectionsTestAsteroidArray* value)
{
#line 73 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 73 "SerializableGeeCollectionsTest.vala"
	if (serializable_gee_collections_test_space_get_asteroids (self) != value) {
#line 6417 "SerializableGeeCollectionsTest.c"
		SerializableGeeCollectionsTestAsteroidArray* _tmp0_;
#line 73 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 73 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (self->priv->_asteroids);
#line 73 "SerializableGeeCollectionsTest.vala"
		self->priv->_asteroids = _tmp0_;
#line 73 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_space_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_ASTEROIDS_PROPERTY]);
#line 6427 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestSpaceCollection*
serializable_gee_collections_test_space_collection_construct (GType object_type)
{
	SerializableGeeCollectionsTestSpaceCollection * self = NULL;
#line 86 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSpaceCollection*) gxml_serializable_tree_map_construct (object_type, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 86 "SerializableGeeCollectionsTest.vala"
	return self;
#line 6439 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestSpaceCollection*
serializable_gee_collections_test_space_collection_new (void)
{
#line 86 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_space_collection_construct (SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_TYPE_COLLECTION);
#line 6447 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_space_collection_class_init (SerializableGeeCollectionsTestSpaceCollectionClass * klass,
                                                               gpointer klass_data)
{
#line 86 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_space_collection_parent_class = g_type_class_peek_parent (klass);
#line 6456 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_space_collection_instance_init (SerializableGeeCollectionsTestSpaceCollection * self,
                                                                  gpointer klass)
{
}

GType
serializable_gee_collections_test_space_collection_get_type (void)
{
	static volatile gsize serializable_gee_collections_test_space_collection_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_test_space_collection_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTestSpaceCollectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_test_space_collection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTestSpaceCollection), 0, (GInstanceInitFunc) serializable_gee_collections_test_space_collection_instance_init, NULL };
		GType serializable_gee_collections_test_space_collection_type_id;
		serializable_gee_collections_test_space_collection_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_TREE_MAP, "SerializableGeeCollectionsTestSpaceCollection", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_collections_test_space_collection_type_id__volatile, serializable_gee_collections_test_space_collection_type_id);
	}
	return serializable_gee_collections_test_space_collection_type_id__volatile;
}

static void
serializable_gee_collections_test_space_class_init (SerializableGeeCollectionsTestSpaceClass * klass,
                                                    gpointer klass_data)
{
#line 68 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_space_parent_class = g_type_class_peek_parent (klass);
#line 68 "SerializableGeeCollectionsTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeCollectionsTestSpace_private_offset);
#line 68 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_space_real_node_name;
#line 68 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_space_real_to_string;
#line 68 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableContainerClass *) klass)->init_containers = (void (*) (GXmlSerializableContainer*)) serializable_gee_collections_test_space_real_init_containers;
#line 68 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_collections_test_space_get_property;
#line 68 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_collections_test_space_set_property;
#line 68 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_collections_test_space_finalize;
#line 68 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_NAME_PROPERTY, serializable_gee_collections_test_space_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 68 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_PLANETS_PROPERTY, serializable_gee_collections_test_space_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_PLANETS_PROPERTY] = g_param_spec_object ("planets", "planets", "planets", SERIALIZABLE_GEE_COLLECTIONS_TEST_PLANET_TYPE_COLLECTION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 68 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_ASTEROIDS_PROPERTY, serializable_gee_collections_test_space_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_ASTEROIDS_PROPERTY] = g_param_spec_object ("asteroids", "asteroids", "asteroids", SERIALIZABLE_GEE_COLLECTIONS_TEST_ASTEROID_TYPE_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6504 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_space_gxml_serializable_map_key_interface_init (GXmlSerializableMapKeyIface * iface,
                                                                                  gpointer iface_data)
{
#line 68 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_space_gxml_serializable_map_key_parent_iface = g_type_interface_peek_parent (iface);
#line 68 "SerializableGeeCollectionsTest.vala"
	iface->get_map_key = (gpointer (*) (GXmlSerializableMapKey*)) serializable_gee_collections_test_space_real_get_map_key;
#line 6515 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_space_instance_init (SerializableGeeCollectionsTestSpace * self,
                                                       gpointer klass)
{
#line 68 "SerializableGeeCollectionsTest.vala"
	self->priv = serializable_gee_collections_test_space_get_instance_private (self);
#line 6524 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_space_finalize (GObject * obj)
{
	SerializableGeeCollectionsTestSpace * self;
#line 68 "SerializableGeeCollectionsTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE, SerializableGeeCollectionsTestSpace);
#line 71 "SerializableGeeCollectionsTest.vala"
	_g_free0 (self->priv->_name);
#line 72 "SerializableGeeCollectionsTest.vala"
	_g_object_unref0 (self->priv->_planets);
#line 73 "SerializableGeeCollectionsTest.vala"
	_g_object_unref0 (self->priv->_asteroids);
#line 68 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (serializable_gee_collections_test_space_parent_class)->finalize (obj);
#line 6541 "SerializableGeeCollectionsTest.c"
}

static GType
serializable_gee_collections_test_space_get_type (void)
{
	static volatile gsize serializable_gee_collections_test_space_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_test_space_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTestSpaceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_test_space_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTestSpace), 0, (GInstanceInitFunc) serializable_gee_collections_test_space_instance_init, NULL };
		static const GInterfaceInfo gxml_serializable_map_key_info = { (GInterfaceInitFunc) serializable_gee_collections_test_space_gxml_serializable_map_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType serializable_gee_collections_test_space_type_id;
		serializable_gee_collections_test_space_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_CONTAINER, "SerializableGeeCollectionsTestSpace", &g_define_type_info, 0);
		g_type_add_interface_static (serializable_gee_collections_test_space_type_id, GXML_TYPE_SERIALIZABLE_MAP_KEY, &gxml_serializable_map_key_info);
		SerializableGeeCollectionsTestSpace_private_offset = g_type_add_instance_private (serializable_gee_collections_test_space_type_id, sizeof (SerializableGeeCollectionsTestSpacePrivate));
		g_once_init_leave (&serializable_gee_collections_test_space_type_id__volatile, serializable_gee_collections_test_space_type_id);
	}
	return serializable_gee_collections_test_space_type_id__volatile;
}

static void
_vala_serializable_gee_collections_test_space_get_property (GObject * object,
                                                            guint property_id,
                                                            GValue * value,
                                                            GParamSpec * pspec)
{
	SerializableGeeCollectionsTestSpace * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE, SerializableGeeCollectionsTestSpace);
#line 68 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 68 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_NAME_PROPERTY:
#line 68 "SerializableGeeCollectionsTest.vala"
		g_value_set_string (value, serializable_gee_collections_test_space_get_name (self));
#line 68 "SerializableGeeCollectionsTest.vala"
		break;
#line 68 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_PLANETS_PROPERTY:
#line 68 "SerializableGeeCollectionsTest.vala"
		g_value_set_object (value, serializable_gee_collections_test_space_get_planets (self));
#line 68 "SerializableGeeCollectionsTest.vala"
		break;
#line 68 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_ASTEROIDS_PROPERTY:
#line 68 "SerializableGeeCollectionsTest.vala"
		g_value_set_object (value, serializable_gee_collections_test_space_get_asteroids (self));
#line 68 "SerializableGeeCollectionsTest.vala"
		break;
#line 6588 "SerializableGeeCollectionsTest.c"
		default:
#line 68 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 68 "SerializableGeeCollectionsTest.vala"
		break;
#line 6594 "SerializableGeeCollectionsTest.c"
	}
}

static void
_vala_serializable_gee_collections_test_space_set_property (GObject * object,
                                                            guint property_id,
                                                            const GValue * value,
                                                            GParamSpec * pspec)
{
	SerializableGeeCollectionsTestSpace * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE, SerializableGeeCollectionsTestSpace);
#line 68 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 68 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_NAME_PROPERTY:
#line 68 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_space_set_name (self, g_value_get_string (value));
#line 68 "SerializableGeeCollectionsTest.vala"
		break;
#line 68 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_PLANETS_PROPERTY:
#line 68 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_space_set_planets (self, g_value_get_object (value));
#line 68 "SerializableGeeCollectionsTest.vala"
		break;
#line 68 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_ASTEROIDS_PROPERTY:
#line 68 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_space_set_asteroids (self, g_value_get_object (value));
#line 68 "SerializableGeeCollectionsTest.vala"
		break;
#line 6626 "SerializableGeeCollectionsTest.c"
		default:
#line 68 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 68 "SerializableGeeCollectionsTest.vala"
		break;
#line 6632 "SerializableGeeCollectionsTest.c"
	}
}

static inline gpointer
serializable_gee_collections_test_refaction_get_instance_private (SerializableGeeCollectionsTestRefaction* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeCollectionsTestRefaction_private_offset);
}

static SerializableGeeCollectionsTestRefaction*
serializable_gee_collections_test_refaction_construct_named (GType object_type,
                                                             const gchar* manufacturer,
                                                             const gchar* model)
{
	SerializableGeeCollectionsTestRefaction * self = NULL;
#line 94 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (manufacturer != NULL, NULL);
#line 94 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (model != NULL, NULL);
#line 94 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestRefaction*) gxml_serializable_container_construct (object_type);
#line 96 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_refaction_set_manufacturer (self, manufacturer);
#line 97 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_refaction_set_model (self, model);
#line 94 "SerializableGeeCollectionsTest.vala"
	return self;
#line 6660 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestRefaction*
serializable_gee_collections_test_refaction_new_named (const gchar* manufacturer,
                                                       const gchar* model)
{
#line 94 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_refaction_construct_named (SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_REFACTION, manufacturer, model);
#line 6669 "SerializableGeeCollectionsTest.c"
}

static gchar*
serializable_gee_collections_test_refaction_real_get_map_primary_key (GXmlSerializableMapDualKey* base)
{
	SerializableGeeCollectionsTestRefaction * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 100 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestRefaction*) base;
#line 100 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_manufacturer;
#line 100 "SerializableGeeCollectionsTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 100 "SerializableGeeCollectionsTest.vala"
	result = _tmp1_;
#line 100 "SerializableGeeCollectionsTest.vala"
	return result;
#line 6689 "SerializableGeeCollectionsTest.c"
}

static gchar*
serializable_gee_collections_test_refaction_real_get_map_secondary_key (GXmlSerializableMapDualKey* base)
{
	SerializableGeeCollectionsTestRefaction * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 101 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestRefaction*) base;
#line 101 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_model;
#line 101 "SerializableGeeCollectionsTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 101 "SerializableGeeCollectionsTest.vala"
	result = _tmp1_;
#line 101 "SerializableGeeCollectionsTest.vala"
	return result;
#line 6709 "SerializableGeeCollectionsTest.c"
}

static gchar*
serializable_gee_collections_test_refaction_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestRefaction * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 103 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestRefaction*) base;
#line 103 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = g_strdup ("refaction");
#line 103 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 103 "SerializableGeeCollectionsTest.vala"
	return result;
#line 6726 "SerializableGeeCollectionsTest.c"
}

static gchar*
serializable_gee_collections_test_refaction_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestRefaction * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 104 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestRefaction*) base;
#line 104 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_model;
#line 104 "SerializableGeeCollectionsTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 104 "SerializableGeeCollectionsTest.vala"
	result = _tmp1_;
#line 104 "SerializableGeeCollectionsTest.vala"
	return result;
#line 6746 "SerializableGeeCollectionsTest.c"
}

static gboolean
serializable_gee_collections_test_refaction_real_get_enable_unknown_serializable_property (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestRefaction * self;
	gboolean result = FALSE;
#line 105 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestRefaction*) base;
#line 105 "SerializableGeeCollectionsTest.vala"
	result = TRUE;
#line 105 "SerializableGeeCollectionsTest.vala"
	return result;
#line 6760 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_refaction_real_init_containers (GXmlSerializableContainer* base)
{
	SerializableGeeCollectionsTestRefaction * self;
	SerializableGeeCollectionsTestSpaceShipCollection* _tmp0_;
#line 107 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestRefaction*) base;
#line 109 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_spaceships;
#line 109 "SerializableGeeCollectionsTest.vala"
	if (_tmp0_ == NULL) {
#line 6774 "SerializableGeeCollectionsTest.c"
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp1_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp2_;
#line 110 "SerializableGeeCollectionsTest.vala"
		_tmp1_ = serializable_gee_collections_test_space_ship_collection_new ();
#line 110 "SerializableGeeCollectionsTest.vala"
		_tmp2_ = _tmp1_;
#line 110 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_refaction_set_spaceships (self, _tmp2_);
#line 110 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp2_);
#line 6785 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestRefaction*
serializable_gee_collections_test_refaction_construct (GType object_type)
{
	SerializableGeeCollectionsTestRefaction * self = NULL;
#line 88 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestRefaction*) gxml_serializable_container_construct (object_type);
#line 88 "SerializableGeeCollectionsTest.vala"
	return self;
#line 6797 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestRefaction*
serializable_gee_collections_test_refaction_new (void)
{
#line 88 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_refaction_construct (SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_REFACTION);
#line 6805 "SerializableGeeCollectionsTest.c"
}

static const gchar*
serializable_gee_collections_test_refaction_get_model (SerializableGeeCollectionsTestRefaction* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 90 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 90 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_model;
#line 90 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 90 "SerializableGeeCollectionsTest.vala"
	return result;
#line 6821 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_refaction_set_model (SerializableGeeCollectionsTestRefaction* self,
                                                       const gchar* value)
{
#line 90 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 90 "SerializableGeeCollectionsTest.vala"
	if (g_strcmp0 (value, serializable_gee_collections_test_refaction_get_model (self)) != 0) {
#line 6832 "SerializableGeeCollectionsTest.c"
		gchar* _tmp0_;
#line 90 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = g_strdup (value);
#line 90 "SerializableGeeCollectionsTest.vala"
		_g_free0 (self->priv->_model);
#line 90 "SerializableGeeCollectionsTest.vala"
		self->priv->_model = _tmp0_;
#line 90 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_refaction_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_MODEL_PROPERTY]);
#line 6842 "SerializableGeeCollectionsTest.c"
	}
}

static const gchar*
serializable_gee_collections_test_refaction_get_manufacturer (SerializableGeeCollectionsTestRefaction* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 91 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 91 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_manufacturer;
#line 91 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 91 "SerializableGeeCollectionsTest.vala"
	return result;
#line 6859 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_refaction_set_manufacturer (SerializableGeeCollectionsTestRefaction* self,
                                                              const gchar* value)
{
#line 91 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 91 "SerializableGeeCollectionsTest.vala"
	if (g_strcmp0 (value, serializable_gee_collections_test_refaction_get_manufacturer (self)) != 0) {
#line 6870 "SerializableGeeCollectionsTest.c"
		gchar* _tmp0_;
#line 91 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = g_strdup (value);
#line 91 "SerializableGeeCollectionsTest.vala"
		_g_free0 (self->priv->_manufacturer);
#line 91 "SerializableGeeCollectionsTest.vala"
		self->priv->_manufacturer = _tmp0_;
#line 91 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_refaction_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_MANUFACTURER_PROPERTY]);
#line 6880 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestSpaceShipCollection*
serializable_gee_collections_test_refaction_get_spaceships (SerializableGeeCollectionsTestRefaction* self)
{
	SerializableGeeCollectionsTestSpaceShipCollection* result;
	SerializableGeeCollectionsTestSpaceShipCollection* _tmp0_;
#line 92 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 92 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_spaceships;
#line 92 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 92 "SerializableGeeCollectionsTest.vala"
	return result;
#line 6897 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_refaction_set_spaceships (SerializableGeeCollectionsTestRefaction* self,
                                                            SerializableGeeCollectionsTestSpaceShipCollection* value)
{
#line 92 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 92 "SerializableGeeCollectionsTest.vala"
	if (serializable_gee_collections_test_refaction_get_spaceships (self) != value) {
#line 6908 "SerializableGeeCollectionsTest.c"
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp0_;
#line 92 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 92 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (self->priv->_spaceships);
#line 92 "SerializableGeeCollectionsTest.vala"
		self->priv->_spaceships = _tmp0_;
#line 92 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_refaction_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_SPACESHIPS_PROPERTY]);
#line 6918 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestRefactionCollection*
serializable_gee_collections_test_refaction_collection_construct (GType object_type)
{
	SerializableGeeCollectionsTestRefactionCollection * self = NULL;
#line 113 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestRefactionCollection*) gxml_serializable_dual_key_map_construct (object_type, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_REFACTION, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 113 "SerializableGeeCollectionsTest.vala"
	return self;
#line 6930 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestRefactionCollection*
serializable_gee_collections_test_refaction_collection_new (void)
{
#line 113 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_refaction_collection_construct (SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_TYPE_COLLECTION);
#line 6938 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_refaction_collection_class_init (SerializableGeeCollectionsTestRefactionCollectionClass * klass,
                                                                   gpointer klass_data)
{
#line 113 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_refaction_collection_parent_class = g_type_class_peek_parent (klass);
#line 6947 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_refaction_collection_instance_init (SerializableGeeCollectionsTestRefactionCollection * self,
                                                                      gpointer klass)
{
}

GType
serializable_gee_collections_test_refaction_collection_get_type (void)
{
	static volatile gsize serializable_gee_collections_test_refaction_collection_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_test_refaction_collection_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTestRefactionCollectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_test_refaction_collection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTestRefactionCollection), 0, (GInstanceInitFunc) serializable_gee_collections_test_refaction_collection_instance_init, NULL };
		GType serializable_gee_collections_test_refaction_collection_type_id;
		serializable_gee_collections_test_refaction_collection_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_DUAL_KEY_MAP, "SerializableGeeCollectionsTestRefactionCollection", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_collections_test_refaction_collection_type_id__volatile, serializable_gee_collections_test_refaction_collection_type_id);
	}
	return serializable_gee_collections_test_refaction_collection_type_id__volatile;
}

static void
serializable_gee_collections_test_refaction_class_init (SerializableGeeCollectionsTestRefactionClass * klass,
                                                        gpointer klass_data)
{
#line 88 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_refaction_parent_class = g_type_class_peek_parent (klass);
#line 88 "SerializableGeeCollectionsTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeCollectionsTestRefaction_private_offset);
#line 88 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_refaction_real_node_name;
#line 88 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_refaction_real_to_string;
#line 88 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->get_enable_unknown_serializable_property = (gboolean (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_refaction_real_get_enable_unknown_serializable_property;
#line 88 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableContainerClass *) klass)->init_containers = (void (*) (GXmlSerializableContainer*)) serializable_gee_collections_test_refaction_real_init_containers;
#line 88 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_collections_test_refaction_get_property;
#line 88 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_collections_test_refaction_set_property;
#line 88 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_collections_test_refaction_finalize;
#line 88 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_MODEL_PROPERTY, serializable_gee_collections_test_refaction_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_MODEL_PROPERTY] = g_param_spec_string ("model", "model", "model", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 88 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_MANUFACTURER_PROPERTY, serializable_gee_collections_test_refaction_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_MANUFACTURER_PROPERTY] = g_param_spec_string ("manufacturer", "manufacturer", "manufacturer", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 88 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_SPACESHIPS_PROPERTY, serializable_gee_collections_test_refaction_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_SPACESHIPS_PROPERTY] = g_param_spec_object ("spaceships", "spaceships", "spaceships", SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_TYPE_COLLECTION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6997 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_refaction_gxml_serializable_map_dual_key_interface_init (GXmlSerializableMapDualKeyIface * iface,
                                                                                           gpointer iface_data)
{
#line 88 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_refaction_gxml_serializable_map_dual_key_parent_iface = g_type_interface_peek_parent (iface);
#line 88 "SerializableGeeCollectionsTest.vala"
	iface->get_map_primary_key = (gpointer (*) (GXmlSerializableMapDualKey*)) serializable_gee_collections_test_refaction_real_get_map_primary_key;
#line 88 "SerializableGeeCollectionsTest.vala"
	iface->get_map_secondary_key = (gpointer (*) (GXmlSerializableMapDualKey*)) serializable_gee_collections_test_refaction_real_get_map_secondary_key;
#line 7010 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_refaction_instance_init (SerializableGeeCollectionsTestRefaction * self,
                                                           gpointer klass)
{
#line 88 "SerializableGeeCollectionsTest.vala"
	self->priv = serializable_gee_collections_test_refaction_get_instance_private (self);
#line 7019 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_refaction_finalize (GObject * obj)
{
	SerializableGeeCollectionsTestRefaction * self;
#line 88 "SerializableGeeCollectionsTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_REFACTION, SerializableGeeCollectionsTestRefaction);
#line 90 "SerializableGeeCollectionsTest.vala"
	_g_free0 (self->priv->_model);
#line 91 "SerializableGeeCollectionsTest.vala"
	_g_free0 (self->priv->_manufacturer);
#line 92 "SerializableGeeCollectionsTest.vala"
	_g_object_unref0 (self->priv->_spaceships);
#line 88 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (serializable_gee_collections_test_refaction_parent_class)->finalize (obj);
#line 7036 "SerializableGeeCollectionsTest.c"
}

static GType
serializable_gee_collections_test_refaction_get_type (void)
{
	static volatile gsize serializable_gee_collections_test_refaction_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_test_refaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTestRefactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_test_refaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTestRefaction), 0, (GInstanceInitFunc) serializable_gee_collections_test_refaction_instance_init, NULL };
		static const GInterfaceInfo gxml_serializable_map_dual_key_info = { (GInterfaceInitFunc) serializable_gee_collections_test_refaction_gxml_serializable_map_dual_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType serializable_gee_collections_test_refaction_type_id;
		serializable_gee_collections_test_refaction_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_CONTAINER, "SerializableGeeCollectionsTestRefaction", &g_define_type_info, 0);
		g_type_add_interface_static (serializable_gee_collections_test_refaction_type_id, GXML_TYPE_SERIALIZABLE_MAP_DUAL_KEY, &gxml_serializable_map_dual_key_info);
		SerializableGeeCollectionsTestRefaction_private_offset = g_type_add_instance_private (serializable_gee_collections_test_refaction_type_id, sizeof (SerializableGeeCollectionsTestRefactionPrivate));
		g_once_init_leave (&serializable_gee_collections_test_refaction_type_id__volatile, serializable_gee_collections_test_refaction_type_id);
	}
	return serializable_gee_collections_test_refaction_type_id__volatile;
}

static void
_vala_serializable_gee_collections_test_refaction_get_property (GObject * object,
                                                                guint property_id,
                                                                GValue * value,
                                                                GParamSpec * pspec)
{
	SerializableGeeCollectionsTestRefaction * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_REFACTION, SerializableGeeCollectionsTestRefaction);
#line 88 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 88 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_MODEL_PROPERTY:
#line 88 "SerializableGeeCollectionsTest.vala"
		g_value_set_string (value, serializable_gee_collections_test_refaction_get_model (self));
#line 88 "SerializableGeeCollectionsTest.vala"
		break;
#line 88 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_MANUFACTURER_PROPERTY:
#line 88 "SerializableGeeCollectionsTest.vala"
		g_value_set_string (value, serializable_gee_collections_test_refaction_get_manufacturer (self));
#line 88 "SerializableGeeCollectionsTest.vala"
		break;
#line 88 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_SPACESHIPS_PROPERTY:
#line 88 "SerializableGeeCollectionsTest.vala"
		g_value_set_object (value, serializable_gee_collections_test_refaction_get_spaceships (self));
#line 88 "SerializableGeeCollectionsTest.vala"
		break;
#line 7083 "SerializableGeeCollectionsTest.c"
		default:
#line 88 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 88 "SerializableGeeCollectionsTest.vala"
		break;
#line 7089 "SerializableGeeCollectionsTest.c"
	}
}

static void
_vala_serializable_gee_collections_test_refaction_set_property (GObject * object,
                                                                guint property_id,
                                                                const GValue * value,
                                                                GParamSpec * pspec)
{
	SerializableGeeCollectionsTestRefaction * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_REFACTION, SerializableGeeCollectionsTestRefaction);
#line 88 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 88 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_MODEL_PROPERTY:
#line 88 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_refaction_set_model (self, g_value_get_string (value));
#line 88 "SerializableGeeCollectionsTest.vala"
		break;
#line 88 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_MANUFACTURER_PROPERTY:
#line 88 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_refaction_set_manufacturer (self, g_value_get_string (value));
#line 88 "SerializableGeeCollectionsTest.vala"
		break;
#line 88 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_SPACESHIPS_PROPERTY:
#line 88 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_refaction_set_spaceships (self, g_value_get_object (value));
#line 88 "SerializableGeeCollectionsTest.vala"
		break;
#line 7121 "SerializableGeeCollectionsTest.c"
		default:
#line 88 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 88 "SerializableGeeCollectionsTest.vala"
		break;
#line 7127 "SerializableGeeCollectionsTest.c"
	}
}

static inline gpointer
serializable_gee_collections_test_space_ship_get_instance_private (SerializableGeeCollectionsTestSpaceShip* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeCollectionsTestSpaceShip_private_offset);
}

static SerializableGeeCollectionsTestSpaceShip*
serializable_gee_collections_test_space_ship_construct_named (GType object_type,
                                                              const gchar* manufacturer,
                                                              const gchar* model)
{
	SerializableGeeCollectionsTestSpaceShip * self = NULL;
#line 121 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (manufacturer != NULL, NULL);
#line 121 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (model != NULL, NULL);
#line 121 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSpaceShip*) gxml_serializable_container_construct (object_type);
#line 123 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_space_ship_set_manufacturer (self, manufacturer);
#line 124 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_space_ship_set_model (self, model);
#line 121 "SerializableGeeCollectionsTest.vala"
	return self;
#line 7155 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestSpaceShip*
serializable_gee_collections_test_space_ship_new_named (const gchar* manufacturer,
                                                        const gchar* model)
{
#line 121 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_space_ship_construct_named (SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE_SHIP, manufacturer, model);
#line 7164 "SerializableGeeCollectionsTest.c"
}

static gchar*
serializable_gee_collections_test_space_ship_real_get_map_primary_key (GXmlSerializableMapDualKey* base)
{
	SerializableGeeCollectionsTestSpaceShip * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 127 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSpaceShip*) base;
#line 127 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_manufacturer;
#line 127 "SerializableGeeCollectionsTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 127 "SerializableGeeCollectionsTest.vala"
	result = _tmp1_;
#line 127 "SerializableGeeCollectionsTest.vala"
	return result;
#line 7184 "SerializableGeeCollectionsTest.c"
}

static gchar*
serializable_gee_collections_test_space_ship_real_get_map_secondary_key (GXmlSerializableMapDualKey* base)
{
	SerializableGeeCollectionsTestSpaceShip * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 128 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSpaceShip*) base;
#line 128 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_model;
#line 128 "SerializableGeeCollectionsTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 128 "SerializableGeeCollectionsTest.vala"
	result = _tmp1_;
#line 128 "SerializableGeeCollectionsTest.vala"
	return result;
#line 7204 "SerializableGeeCollectionsTest.c"
}

static gchar*
serializable_gee_collections_test_space_ship_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestSpaceShip * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 130 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSpaceShip*) base;
#line 130 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = g_strdup ("ship");
#line 130 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 130 "SerializableGeeCollectionsTest.vala"
	return result;
#line 7221 "SerializableGeeCollectionsTest.c"
}

static gchar*
serializable_gee_collections_test_space_ship_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestSpaceShip * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 131 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSpaceShip*) base;
#line 131 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_model;
#line 131 "SerializableGeeCollectionsTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 131 "SerializableGeeCollectionsTest.vala"
	result = _tmp1_;
#line 131 "SerializableGeeCollectionsTest.vala"
	return result;
#line 7241 "SerializableGeeCollectionsTest.c"
}

static gboolean
serializable_gee_collections_test_space_ship_real_get_enable_unknown_serializable_property (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestSpaceShip * self;
	gboolean result = FALSE;
#line 132 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSpaceShip*) base;
#line 132 "SerializableGeeCollectionsTest.vala"
	result = TRUE;
#line 132 "SerializableGeeCollectionsTest.vala"
	return result;
#line 7255 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_space_ship_real_init_containers (GXmlSerializableContainer* base)
{
	SerializableGeeCollectionsTestSpaceShip * self;
	SerializableGeeCollectionsTestSpaceCollection* _tmp0_;
#line 134 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSpaceShip*) base;
#line 136 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_spaces;
#line 136 "SerializableGeeCollectionsTest.vala"
	if (_tmp0_ == NULL) {
#line 7269 "SerializableGeeCollectionsTest.c"
		SerializableGeeCollectionsTestSpaceCollection* _tmp1_;
		SerializableGeeCollectionsTestSpaceCollection* _tmp2_;
#line 137 "SerializableGeeCollectionsTest.vala"
		_tmp1_ = serializable_gee_collections_test_space_collection_new ();
#line 137 "SerializableGeeCollectionsTest.vala"
		_tmp2_ = _tmp1_;
#line 137 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_space_ship_set_spaces (self, _tmp2_);
#line 137 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp2_);
#line 7280 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestSpaceShip*
serializable_gee_collections_test_space_ship_construct (GType object_type)
{
	SerializableGeeCollectionsTestSpaceShip * self = NULL;
#line 115 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSpaceShip*) gxml_serializable_container_construct (object_type);
#line 115 "SerializableGeeCollectionsTest.vala"
	return self;
#line 7292 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestSpaceShip*
serializable_gee_collections_test_space_ship_new (void)
{
#line 115 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_space_ship_construct (SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE_SHIP);
#line 7300 "SerializableGeeCollectionsTest.c"
}

static const gchar*
serializable_gee_collections_test_space_ship_get_model (SerializableGeeCollectionsTestSpaceShip* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 117 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 117 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_model;
#line 117 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 117 "SerializableGeeCollectionsTest.vala"
	return result;
#line 7316 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_space_ship_set_model (SerializableGeeCollectionsTestSpaceShip* self,
                                                        const gchar* value)
{
#line 117 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 117 "SerializableGeeCollectionsTest.vala"
	if (g_strcmp0 (value, serializable_gee_collections_test_space_ship_get_model (self)) != 0) {
#line 7327 "SerializableGeeCollectionsTest.c"
		gchar* _tmp0_;
#line 117 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = g_strdup (value);
#line 117 "SerializableGeeCollectionsTest.vala"
		_g_free0 (self->priv->_model);
#line 117 "SerializableGeeCollectionsTest.vala"
		self->priv->_model = _tmp0_;
#line 117 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_space_ship_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_MODEL_PROPERTY]);
#line 7337 "SerializableGeeCollectionsTest.c"
	}
}

static const gchar*
serializable_gee_collections_test_space_ship_get_manufacturer (SerializableGeeCollectionsTestSpaceShip* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 118 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 118 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_manufacturer;
#line 118 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 118 "SerializableGeeCollectionsTest.vala"
	return result;
#line 7354 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_space_ship_set_manufacturer (SerializableGeeCollectionsTestSpaceShip* self,
                                                               const gchar* value)
{
#line 118 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 118 "SerializableGeeCollectionsTest.vala"
	if (g_strcmp0 (value, serializable_gee_collections_test_space_ship_get_manufacturer (self)) != 0) {
#line 7365 "SerializableGeeCollectionsTest.c"
		gchar* _tmp0_;
#line 118 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = g_strdup (value);
#line 118 "SerializableGeeCollectionsTest.vala"
		_g_free0 (self->priv->_manufacturer);
#line 118 "SerializableGeeCollectionsTest.vala"
		self->priv->_manufacturer = _tmp0_;
#line 118 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_space_ship_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_MANUFACTURER_PROPERTY]);
#line 7375 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestSpaceCollection*
serializable_gee_collections_test_space_ship_get_spaces (SerializableGeeCollectionsTestSpaceShip* self)
{
	SerializableGeeCollectionsTestSpaceCollection* result;
	SerializableGeeCollectionsTestSpaceCollection* _tmp0_;
#line 119 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 119 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_spaces;
#line 119 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 119 "SerializableGeeCollectionsTest.vala"
	return result;
#line 7392 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_space_ship_set_spaces (SerializableGeeCollectionsTestSpaceShip* self,
                                                         SerializableGeeCollectionsTestSpaceCollection* value)
{
#line 119 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 119 "SerializableGeeCollectionsTest.vala"
	if (serializable_gee_collections_test_space_ship_get_spaces (self) != value) {
#line 7403 "SerializableGeeCollectionsTest.c"
		SerializableGeeCollectionsTestSpaceCollection* _tmp0_;
#line 119 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 119 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (self->priv->_spaces);
#line 119 "SerializableGeeCollectionsTest.vala"
		self->priv->_spaces = _tmp0_;
#line 119 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_space_ship_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_SPACES_PROPERTY]);
#line 7413 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestSpaceShipCollection*
serializable_gee_collections_test_space_ship_collection_construct (GType object_type)
{
	SerializableGeeCollectionsTestSpaceShipCollection * self = NULL;
#line 140 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSpaceShipCollection*) gxml_serializable_dual_key_map_construct (object_type, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE_SHIP, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 140 "SerializableGeeCollectionsTest.vala"
	return self;
#line 7425 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestSpaceShipCollection*
serializable_gee_collections_test_space_ship_collection_new (void)
{
#line 140 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_space_ship_collection_construct (SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_TYPE_COLLECTION);
#line 7433 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_space_ship_collection_class_init (SerializableGeeCollectionsTestSpaceShipCollectionClass * klass,
                                                                    gpointer klass_data)
{
#line 140 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_space_ship_collection_parent_class = g_type_class_peek_parent (klass);
#line 7442 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_space_ship_collection_instance_init (SerializableGeeCollectionsTestSpaceShipCollection * self,
                                                                       gpointer klass)
{
}

GType
serializable_gee_collections_test_space_ship_collection_get_type (void)
{
	static volatile gsize serializable_gee_collections_test_space_ship_collection_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_test_space_ship_collection_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTestSpaceShipCollectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_test_space_ship_collection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTestSpaceShipCollection), 0, (GInstanceInitFunc) serializable_gee_collections_test_space_ship_collection_instance_init, NULL };
		GType serializable_gee_collections_test_space_ship_collection_type_id;
		serializable_gee_collections_test_space_ship_collection_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_DUAL_KEY_MAP, "SerializableGeeCollectionsTestSpaceShipCollection", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_collections_test_space_ship_collection_type_id__volatile, serializable_gee_collections_test_space_ship_collection_type_id);
	}
	return serializable_gee_collections_test_space_ship_collection_type_id__volatile;
}

static void
serializable_gee_collections_test_space_ship_class_init (SerializableGeeCollectionsTestSpaceShipClass * klass,
                                                         gpointer klass_data)
{
#line 115 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_space_ship_parent_class = g_type_class_peek_parent (klass);
#line 115 "SerializableGeeCollectionsTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeCollectionsTestSpaceShip_private_offset);
#line 115 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_space_ship_real_node_name;
#line 115 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_space_ship_real_to_string;
#line 115 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->get_enable_unknown_serializable_property = (gboolean (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_space_ship_real_get_enable_unknown_serializable_property;
#line 115 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableContainerClass *) klass)->init_containers = (void (*) (GXmlSerializableContainer*)) serializable_gee_collections_test_space_ship_real_init_containers;
#line 115 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_collections_test_space_ship_get_property;
#line 115 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_collections_test_space_ship_set_property;
#line 115 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_collections_test_space_ship_finalize;
#line 115 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_MODEL_PROPERTY, serializable_gee_collections_test_space_ship_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_MODEL_PROPERTY] = g_param_spec_string ("model", "model", "model", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 115 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_MANUFACTURER_PROPERTY, serializable_gee_collections_test_space_ship_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_MANUFACTURER_PROPERTY] = g_param_spec_string ("manufacturer", "manufacturer", "manufacturer", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 115 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_SPACES_PROPERTY, serializable_gee_collections_test_space_ship_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_SPACES_PROPERTY] = g_param_spec_object ("spaces", "spaces", "spaces", SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_TYPE_COLLECTION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 7492 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_space_ship_gxml_serializable_map_dual_key_interface_init (GXmlSerializableMapDualKeyIface * iface,
                                                                                            gpointer iface_data)
{
#line 115 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_space_ship_gxml_serializable_map_dual_key_parent_iface = g_type_interface_peek_parent (iface);
#line 115 "SerializableGeeCollectionsTest.vala"
	iface->get_map_primary_key = (gpointer (*) (GXmlSerializableMapDualKey*)) serializable_gee_collections_test_space_ship_real_get_map_primary_key;
#line 115 "SerializableGeeCollectionsTest.vala"
	iface->get_map_secondary_key = (gpointer (*) (GXmlSerializableMapDualKey*)) serializable_gee_collections_test_space_ship_real_get_map_secondary_key;
#line 7505 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_space_ship_instance_init (SerializableGeeCollectionsTestSpaceShip * self,
                                                            gpointer klass)
{
#line 115 "SerializableGeeCollectionsTest.vala"
	self->priv = serializable_gee_collections_test_space_ship_get_instance_private (self);
#line 7514 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_space_ship_finalize (GObject * obj)
{
	SerializableGeeCollectionsTestSpaceShip * self;
#line 115 "SerializableGeeCollectionsTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE_SHIP, SerializableGeeCollectionsTestSpaceShip);
#line 117 "SerializableGeeCollectionsTest.vala"
	_g_free0 (self->priv->_model);
#line 118 "SerializableGeeCollectionsTest.vala"
	_g_free0 (self->priv->_manufacturer);
#line 119 "SerializableGeeCollectionsTest.vala"
	_g_object_unref0 (self->priv->_spaces);
#line 115 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (serializable_gee_collections_test_space_ship_parent_class)->finalize (obj);
#line 7531 "SerializableGeeCollectionsTest.c"
}

static GType
serializable_gee_collections_test_space_ship_get_type (void)
{
	static volatile gsize serializable_gee_collections_test_space_ship_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_test_space_ship_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTestSpaceShipClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_test_space_ship_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTestSpaceShip), 0, (GInstanceInitFunc) serializable_gee_collections_test_space_ship_instance_init, NULL };
		static const GInterfaceInfo gxml_serializable_map_dual_key_info = { (GInterfaceInitFunc) serializable_gee_collections_test_space_ship_gxml_serializable_map_dual_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType serializable_gee_collections_test_space_ship_type_id;
		serializable_gee_collections_test_space_ship_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_CONTAINER, "SerializableGeeCollectionsTestSpaceShip", &g_define_type_info, 0);
		g_type_add_interface_static (serializable_gee_collections_test_space_ship_type_id, GXML_TYPE_SERIALIZABLE_MAP_DUAL_KEY, &gxml_serializable_map_dual_key_info);
		SerializableGeeCollectionsTestSpaceShip_private_offset = g_type_add_instance_private (serializable_gee_collections_test_space_ship_type_id, sizeof (SerializableGeeCollectionsTestSpaceShipPrivate));
		g_once_init_leave (&serializable_gee_collections_test_space_ship_type_id__volatile, serializable_gee_collections_test_space_ship_type_id);
	}
	return serializable_gee_collections_test_space_ship_type_id__volatile;
}

static void
_vala_serializable_gee_collections_test_space_ship_get_property (GObject * object,
                                                                 guint property_id,
                                                                 GValue * value,
                                                                 GParamSpec * pspec)
{
	SerializableGeeCollectionsTestSpaceShip * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE_SHIP, SerializableGeeCollectionsTestSpaceShip);
#line 115 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 115 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_MODEL_PROPERTY:
#line 115 "SerializableGeeCollectionsTest.vala"
		g_value_set_string (value, serializable_gee_collections_test_space_ship_get_model (self));
#line 115 "SerializableGeeCollectionsTest.vala"
		break;
#line 115 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_MANUFACTURER_PROPERTY:
#line 115 "SerializableGeeCollectionsTest.vala"
		g_value_set_string (value, serializable_gee_collections_test_space_ship_get_manufacturer (self));
#line 115 "SerializableGeeCollectionsTest.vala"
		break;
#line 115 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_SPACES_PROPERTY:
#line 115 "SerializableGeeCollectionsTest.vala"
		g_value_set_object (value, serializable_gee_collections_test_space_ship_get_spaces (self));
#line 115 "SerializableGeeCollectionsTest.vala"
		break;
#line 7578 "SerializableGeeCollectionsTest.c"
		default:
#line 115 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 115 "SerializableGeeCollectionsTest.vala"
		break;
#line 7584 "SerializableGeeCollectionsTest.c"
	}
}

static void
_vala_serializable_gee_collections_test_space_ship_set_property (GObject * object,
                                                                 guint property_id,
                                                                 const GValue * value,
                                                                 GParamSpec * pspec)
{
	SerializableGeeCollectionsTestSpaceShip * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE_SHIP, SerializableGeeCollectionsTestSpaceShip);
#line 115 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 115 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_MODEL_PROPERTY:
#line 115 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_space_ship_set_model (self, g_value_get_string (value));
#line 115 "SerializableGeeCollectionsTest.vala"
		break;
#line 115 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_MANUFACTURER_PROPERTY:
#line 115 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_space_ship_set_manufacturer (self, g_value_get_string (value));
#line 115 "SerializableGeeCollectionsTest.vala"
		break;
#line 115 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_SPACES_PROPERTY:
#line 115 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_space_ship_set_spaces (self, g_value_get_object (value));
#line 115 "SerializableGeeCollectionsTest.vala"
		break;
#line 7616 "SerializableGeeCollectionsTest.c"
		default:
#line 115 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 115 "SerializableGeeCollectionsTest.vala"
		break;
#line 7622 "SerializableGeeCollectionsTest.c"
	}
}

static inline gpointer
serializable_gee_collections_test_charge_zone_get_instance_private (SerializableGeeCollectionsTestChargeZone* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeCollectionsTestChargeZone_private_offset);
}

static gchar*
serializable_gee_collections_test_charge_zone_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestChargeZone * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 148 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestChargeZone*) base;
#line 148 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = g_strdup ("ChargeZone");
#line 148 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 148 "SerializableGeeCollectionsTest.vala"
	return result;
#line 7646 "SerializableGeeCollectionsTest.c"
}

static gchar*
serializable_gee_collections_test_charge_zone_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestChargeZone * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 149 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestChargeZone*) base;
#line 149 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_name;
#line 149 "SerializableGeeCollectionsTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 149 "SerializableGeeCollectionsTest.vala"
	result = _tmp1_;
#line 149 "SerializableGeeCollectionsTest.vala"
	return result;
#line 7666 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_charge_zone_real_init_containers (GXmlSerializableContainer* base)
{
	SerializableGeeCollectionsTestChargeZone * self;
	SerializableGeeCollectionsTestSpaceShipCollection* _tmp0_;
#line 150 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestChargeZone*) base;
#line 152 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_spaceships;
#line 152 "SerializableGeeCollectionsTest.vala"
	if (_tmp0_ == NULL) {
#line 7680 "SerializableGeeCollectionsTest.c"
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp1_;
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp2_;
#line 153 "SerializableGeeCollectionsTest.vala"
		_tmp1_ = serializable_gee_collections_test_space_ship_collection_new ();
#line 153 "SerializableGeeCollectionsTest.vala"
		_tmp2_ = _tmp1_;
#line 153 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_charge_zone_set_spaceships (self, _tmp2_);
#line 153 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp2_);
#line 7691 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestChargeZone*
serializable_gee_collections_test_charge_zone_construct (GType object_type)
{
	SerializableGeeCollectionsTestChargeZone * self = NULL;
#line 143 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestChargeZone*) gxml_serializable_container_construct (object_type);
#line 143 "SerializableGeeCollectionsTest.vala"
	return self;
#line 7703 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestChargeZone*
serializable_gee_collections_test_charge_zone_new (void)
{
#line 143 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_charge_zone_construct (SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_CHARGE_ZONE);
#line 7711 "SerializableGeeCollectionsTest.c"
}

static const gchar*
serializable_gee_collections_test_charge_zone_get_name (SerializableGeeCollectionsTestChargeZone* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 145 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 145 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_name;
#line 145 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 145 "SerializableGeeCollectionsTest.vala"
	return result;
#line 7727 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_charge_zone_set_name (SerializableGeeCollectionsTestChargeZone* self,
                                                        const gchar* value)
{
#line 145 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 145 "SerializableGeeCollectionsTest.vala"
	if (g_strcmp0 (value, serializable_gee_collections_test_charge_zone_get_name (self)) != 0) {
#line 7738 "SerializableGeeCollectionsTest.c"
		gchar* _tmp0_;
#line 145 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = g_strdup (value);
#line 145 "SerializableGeeCollectionsTest.vala"
		_g_free0 (self->priv->_name);
#line 145 "SerializableGeeCollectionsTest.vala"
		self->priv->_name = _tmp0_;
#line 145 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_charge_zone_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_CHARGE_ZONE_NAME_PROPERTY]);
#line 7748 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestSpaceShipCollection*
serializable_gee_collections_test_charge_zone_get_spaceships (SerializableGeeCollectionsTestChargeZone* self)
{
	SerializableGeeCollectionsTestSpaceShipCollection* result;
	SerializableGeeCollectionsTestSpaceShipCollection* _tmp0_;
#line 146 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 146 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_spaceships;
#line 146 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 146 "SerializableGeeCollectionsTest.vala"
	return result;
#line 7765 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_charge_zone_set_spaceships (SerializableGeeCollectionsTestChargeZone* self,
                                                              SerializableGeeCollectionsTestSpaceShipCollection* value)
{
#line 146 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 146 "SerializableGeeCollectionsTest.vala"
	if (serializable_gee_collections_test_charge_zone_get_spaceships (self) != value) {
#line 7776 "SerializableGeeCollectionsTest.c"
		SerializableGeeCollectionsTestSpaceShipCollection* _tmp0_;
#line 146 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 146 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (self->priv->_spaceships);
#line 146 "SerializableGeeCollectionsTest.vala"
		self->priv->_spaceships = _tmp0_;
#line 146 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_charge_zone_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_CHARGE_ZONE_SPACESHIPS_PROPERTY]);
#line 7786 "SerializableGeeCollectionsTest.c"
	}
}

static void
serializable_gee_collections_test_charge_zone_class_init (SerializableGeeCollectionsTestChargeZoneClass * klass,
                                                          gpointer klass_data)
{
#line 143 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_charge_zone_parent_class = g_type_class_peek_parent (klass);
#line 143 "SerializableGeeCollectionsTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeCollectionsTestChargeZone_private_offset);
#line 143 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_charge_zone_real_node_name;
#line 143 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_charge_zone_real_to_string;
#line 143 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableContainerClass *) klass)->init_containers = (void (*) (GXmlSerializableContainer*)) serializable_gee_collections_test_charge_zone_real_init_containers;
#line 143 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_collections_test_charge_zone_get_property;
#line 143 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_collections_test_charge_zone_set_property;
#line 143 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_collections_test_charge_zone_finalize;
#line 143 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_CHARGE_ZONE_NAME_PROPERTY, serializable_gee_collections_test_charge_zone_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_CHARGE_ZONE_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 143 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_CHARGE_ZONE_SPACESHIPS_PROPERTY, serializable_gee_collections_test_charge_zone_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_CHARGE_ZONE_SPACESHIPS_PROPERTY] = g_param_spec_object ("spaceships", "spaceships", "spaceships", SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_SHIP_TYPE_COLLECTION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 7814 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_charge_zone_instance_init (SerializableGeeCollectionsTestChargeZone * self,
                                                             gpointer klass)
{
#line 143 "SerializableGeeCollectionsTest.vala"
	self->priv = serializable_gee_collections_test_charge_zone_get_instance_private (self);
#line 7823 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_charge_zone_finalize (GObject * obj)
{
	SerializableGeeCollectionsTestChargeZone * self;
#line 143 "SerializableGeeCollectionsTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_CHARGE_ZONE, SerializableGeeCollectionsTestChargeZone);
#line 145 "SerializableGeeCollectionsTest.vala"
	_g_free0 (self->priv->_name);
#line 146 "SerializableGeeCollectionsTest.vala"
	_g_object_unref0 (self->priv->_spaceships);
#line 143 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (serializable_gee_collections_test_charge_zone_parent_class)->finalize (obj);
#line 7838 "SerializableGeeCollectionsTest.c"
}

static GType
serializable_gee_collections_test_charge_zone_get_type (void)
{
	static volatile gsize serializable_gee_collections_test_charge_zone_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_test_charge_zone_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTestChargeZoneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_test_charge_zone_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTestChargeZone), 0, (GInstanceInitFunc) serializable_gee_collections_test_charge_zone_instance_init, NULL };
		GType serializable_gee_collections_test_charge_zone_type_id;
		serializable_gee_collections_test_charge_zone_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_CONTAINER, "SerializableGeeCollectionsTestChargeZone", &g_define_type_info, 0);
		SerializableGeeCollectionsTestChargeZone_private_offset = g_type_add_instance_private (serializable_gee_collections_test_charge_zone_type_id, sizeof (SerializableGeeCollectionsTestChargeZonePrivate));
		g_once_init_leave (&serializable_gee_collections_test_charge_zone_type_id__volatile, serializable_gee_collections_test_charge_zone_type_id);
	}
	return serializable_gee_collections_test_charge_zone_type_id__volatile;
}

static void
_vala_serializable_gee_collections_test_charge_zone_get_property (GObject * object,
                                                                  guint property_id,
                                                                  GValue * value,
                                                                  GParamSpec * pspec)
{
	SerializableGeeCollectionsTestChargeZone * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_CHARGE_ZONE, SerializableGeeCollectionsTestChargeZone);
#line 143 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 143 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_CHARGE_ZONE_NAME_PROPERTY:
#line 143 "SerializableGeeCollectionsTest.vala"
		g_value_set_string (value, serializable_gee_collections_test_charge_zone_get_name (self));
#line 143 "SerializableGeeCollectionsTest.vala"
		break;
#line 143 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_CHARGE_ZONE_SPACESHIPS_PROPERTY:
#line 143 "SerializableGeeCollectionsTest.vala"
		g_value_set_object (value, serializable_gee_collections_test_charge_zone_get_spaceships (self));
#line 143 "SerializableGeeCollectionsTest.vala"
		break;
#line 7877 "SerializableGeeCollectionsTest.c"
		default:
#line 143 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 143 "SerializableGeeCollectionsTest.vala"
		break;
#line 7883 "SerializableGeeCollectionsTest.c"
	}
}

static void
_vala_serializable_gee_collections_test_charge_zone_set_property (GObject * object,
                                                                  guint property_id,
                                                                  const GValue * value,
                                                                  GParamSpec * pspec)
{
	SerializableGeeCollectionsTestChargeZone * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_CHARGE_ZONE, SerializableGeeCollectionsTestChargeZone);
#line 143 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 143 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_CHARGE_ZONE_NAME_PROPERTY:
#line 143 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_charge_zone_set_name (self, g_value_get_string (value));
#line 143 "SerializableGeeCollectionsTest.vala"
		break;
#line 143 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_CHARGE_ZONE_SPACESHIPS_PROPERTY:
#line 143 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_charge_zone_set_spaceships (self, g_value_get_object (value));
#line 143 "SerializableGeeCollectionsTest.vala"
		break;
#line 7909 "SerializableGeeCollectionsTest.c"
		default:
#line 143 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 143 "SerializableGeeCollectionsTest.vala"
		break;
#line 7915 "SerializableGeeCollectionsTest.c"
	}
}

static inline gpointer
serializable_gee_collections_test_storage_get_instance_private (SerializableGeeCollectionsTestStorage* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeCollectionsTestStorage_private_offset);
}

static gchar*
serializable_gee_collections_test_storage_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestStorage * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 161 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestStorage*) base;
#line 161 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = g_strdup ("storage");
#line 161 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 161 "SerializableGeeCollectionsTest.vala"
	return result;
#line 7939 "SerializableGeeCollectionsTest.c"
}

static gchar*
serializable_gee_collections_test_storage_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestStorage * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 162 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestStorage*) base;
#line 162 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_name;
#line 162 "SerializableGeeCollectionsTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 162 "SerializableGeeCollectionsTest.vala"
	result = _tmp1_;
#line 162 "SerializableGeeCollectionsTest.vala"
	return result;
#line 7959 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_storage_real_init_containers (GXmlSerializableContainer* base)
{
	SerializableGeeCollectionsTestStorage * self;
	SerializableGeeCollectionsTestRefactionCollection* _tmp0_;
#line 163 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestStorage*) base;
#line 165 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_refactions;
#line 165 "SerializableGeeCollectionsTest.vala"
	if (_tmp0_ == NULL) {
#line 7973 "SerializableGeeCollectionsTest.c"
		SerializableGeeCollectionsTestRefactionCollection* _tmp1_;
		SerializableGeeCollectionsTestRefactionCollection* _tmp2_;
#line 166 "SerializableGeeCollectionsTest.vala"
		_tmp1_ = serializable_gee_collections_test_refaction_collection_new ();
#line 166 "SerializableGeeCollectionsTest.vala"
		_tmp2_ = _tmp1_;
#line 166 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_storage_set_refactions (self, _tmp2_);
#line 166 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (_tmp2_);
#line 7984 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestStorage*
serializable_gee_collections_test_storage_construct (GType object_type)
{
	SerializableGeeCollectionsTestStorage * self = NULL;
#line 156 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestStorage*) gxml_serializable_container_construct (object_type);
#line 156 "SerializableGeeCollectionsTest.vala"
	return self;
#line 7996 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestStorage*
serializable_gee_collections_test_storage_new (void)
{
#line 156 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_storage_construct (SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_STORAGE);
#line 8004 "SerializableGeeCollectionsTest.c"
}

static const gchar*
serializable_gee_collections_test_storage_get_name (SerializableGeeCollectionsTestStorage* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 158 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 158 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_name;
#line 158 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 158 "SerializableGeeCollectionsTest.vala"
	return result;
#line 8020 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_storage_set_name (SerializableGeeCollectionsTestStorage* self,
                                                    const gchar* value)
{
#line 158 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 158 "SerializableGeeCollectionsTest.vala"
	if (g_strcmp0 (value, serializable_gee_collections_test_storage_get_name (self)) != 0) {
#line 8031 "SerializableGeeCollectionsTest.c"
		gchar* _tmp0_;
#line 158 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = g_strdup (value);
#line 158 "SerializableGeeCollectionsTest.vala"
		_g_free0 (self->priv->_name);
#line 158 "SerializableGeeCollectionsTest.vala"
		self->priv->_name = _tmp0_;
#line 158 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_storage_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_STORAGE_NAME_PROPERTY]);
#line 8041 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestRefactionCollection*
serializable_gee_collections_test_storage_get_refactions (SerializableGeeCollectionsTestStorage* self)
{
	SerializableGeeCollectionsTestRefactionCollection* result;
	SerializableGeeCollectionsTestRefactionCollection* _tmp0_;
#line 159 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 159 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_refactions;
#line 159 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 159 "SerializableGeeCollectionsTest.vala"
	return result;
#line 8058 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_storage_set_refactions (SerializableGeeCollectionsTestStorage* self,
                                                          SerializableGeeCollectionsTestRefactionCollection* value)
{
#line 159 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 159 "SerializableGeeCollectionsTest.vala"
	if (serializable_gee_collections_test_storage_get_refactions (self) != value) {
#line 8069 "SerializableGeeCollectionsTest.c"
		SerializableGeeCollectionsTestRefactionCollection* _tmp0_;
#line 159 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 159 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (self->priv->_refactions);
#line 159 "SerializableGeeCollectionsTest.vala"
		self->priv->_refactions = _tmp0_;
#line 159 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_storage_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_STORAGE_REFACTIONS_PROPERTY]);
#line 8079 "SerializableGeeCollectionsTest.c"
	}
}

static void
serializable_gee_collections_test_storage_class_init (SerializableGeeCollectionsTestStorageClass * klass,
                                                      gpointer klass_data)
{
#line 156 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_storage_parent_class = g_type_class_peek_parent (klass);
#line 156 "SerializableGeeCollectionsTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeCollectionsTestStorage_private_offset);
#line 156 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_storage_real_node_name;
#line 156 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_storage_real_to_string;
#line 156 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableContainerClass *) klass)->init_containers = (void (*) (GXmlSerializableContainer*)) serializable_gee_collections_test_storage_real_init_containers;
#line 156 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_collections_test_storage_get_property;
#line 156 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_collections_test_storage_set_property;
#line 156 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_collections_test_storage_finalize;
#line 156 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_STORAGE_NAME_PROPERTY, serializable_gee_collections_test_storage_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_STORAGE_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 156 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_STORAGE_REFACTIONS_PROPERTY, serializable_gee_collections_test_storage_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_STORAGE_REFACTIONS_PROPERTY] = g_param_spec_object ("refactions", "refactions", "refactions", SERIALIZABLE_GEE_COLLECTIONS_TEST_REFACTION_TYPE_COLLECTION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 8107 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_storage_instance_init (SerializableGeeCollectionsTestStorage * self,
                                                         gpointer klass)
{
#line 156 "SerializableGeeCollectionsTest.vala"
	self->priv = serializable_gee_collections_test_storage_get_instance_private (self);
#line 8116 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_storage_finalize (GObject * obj)
{
	SerializableGeeCollectionsTestStorage * self;
#line 156 "SerializableGeeCollectionsTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_STORAGE, SerializableGeeCollectionsTestStorage);
#line 158 "SerializableGeeCollectionsTest.vala"
	_g_free0 (self->priv->_name);
#line 159 "SerializableGeeCollectionsTest.vala"
	_g_object_unref0 (self->priv->_refactions);
#line 156 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (serializable_gee_collections_test_storage_parent_class)->finalize (obj);
#line 8131 "SerializableGeeCollectionsTest.c"
}

static GType
serializable_gee_collections_test_storage_get_type (void)
{
	static volatile gsize serializable_gee_collections_test_storage_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_test_storage_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTestStorageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_test_storage_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTestStorage), 0, (GInstanceInitFunc) serializable_gee_collections_test_storage_instance_init, NULL };
		GType serializable_gee_collections_test_storage_type_id;
		serializable_gee_collections_test_storage_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_CONTAINER, "SerializableGeeCollectionsTestStorage", &g_define_type_info, 0);
		SerializableGeeCollectionsTestStorage_private_offset = g_type_add_instance_private (serializable_gee_collections_test_storage_type_id, sizeof (SerializableGeeCollectionsTestStoragePrivate));
		g_once_init_leave (&serializable_gee_collections_test_storage_type_id__volatile, serializable_gee_collections_test_storage_type_id);
	}
	return serializable_gee_collections_test_storage_type_id__volatile;
}

static void
_vala_serializable_gee_collections_test_storage_get_property (GObject * object,
                                                              guint property_id,
                                                              GValue * value,
                                                              GParamSpec * pspec)
{
	SerializableGeeCollectionsTestStorage * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_STORAGE, SerializableGeeCollectionsTestStorage);
#line 156 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 156 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_STORAGE_NAME_PROPERTY:
#line 156 "SerializableGeeCollectionsTest.vala"
		g_value_set_string (value, serializable_gee_collections_test_storage_get_name (self));
#line 156 "SerializableGeeCollectionsTest.vala"
		break;
#line 156 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_STORAGE_REFACTIONS_PROPERTY:
#line 156 "SerializableGeeCollectionsTest.vala"
		g_value_set_object (value, serializable_gee_collections_test_storage_get_refactions (self));
#line 156 "SerializableGeeCollectionsTest.vala"
		break;
#line 8170 "SerializableGeeCollectionsTest.c"
		default:
#line 156 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 156 "SerializableGeeCollectionsTest.vala"
		break;
#line 8176 "SerializableGeeCollectionsTest.c"
	}
}

static void
_vala_serializable_gee_collections_test_storage_set_property (GObject * object,
                                                              guint property_id,
                                                              const GValue * value,
                                                              GParamSpec * pspec)
{
	SerializableGeeCollectionsTestStorage * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_STORAGE, SerializableGeeCollectionsTestStorage);
#line 156 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 156 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_STORAGE_NAME_PROPERTY:
#line 156 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_storage_set_name (self, g_value_get_string (value));
#line 156 "SerializableGeeCollectionsTest.vala"
		break;
#line 156 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_STORAGE_REFACTIONS_PROPERTY:
#line 156 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_storage_set_refactions (self, g_value_get_object (value));
#line 156 "SerializableGeeCollectionsTest.vala"
		break;
#line 8202 "SerializableGeeCollectionsTest.c"
		default:
#line 156 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 156 "SerializableGeeCollectionsTest.vala"
		break;
#line 8208 "SerializableGeeCollectionsTest.c"
	}
}

static inline gpointer
serializable_gee_collections_test_space_base_get_instance_private (SerializableGeeCollectionsTestSpaceBase* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeCollectionsTestSpaceBase_private_offset);
}

static gchar*
serializable_gee_collections_test_space_base_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestSpaceBase * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 175 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSpaceBase*) base;
#line 175 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = g_strdup ("base");
#line 175 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 175 "SerializableGeeCollectionsTest.vala"
	return result;
#line 8232 "SerializableGeeCollectionsTest.c"
}

static gchar*
serializable_gee_collections_test_space_base_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestSpaceBase * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 176 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSpaceBase*) base;
#line 176 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_name;
#line 176 "SerializableGeeCollectionsTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 176 "SerializableGeeCollectionsTest.vala"
	result = _tmp1_;
#line 176 "SerializableGeeCollectionsTest.vala"
	return result;
#line 8252 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestSpaceBase*
serializable_gee_collections_test_space_base_construct (GType object_type)
{
	SerializableGeeCollectionsTestSpaceBase * self = NULL;
#line 170 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSpaceBase*) gxml_serializable_object_model_construct (object_type);
#line 170 "SerializableGeeCollectionsTest.vala"
	return self;
#line 8263 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestSpaceBase*
serializable_gee_collections_test_space_base_new (void)
{
#line 170 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_space_base_construct (SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE_BASE);
#line 8271 "SerializableGeeCollectionsTest.c"
}

static const gchar*
serializable_gee_collections_test_space_base_get_name (SerializableGeeCollectionsTestSpaceBase* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 172 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 172 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_name;
#line 172 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 172 "SerializableGeeCollectionsTest.vala"
	return result;
#line 8287 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_space_base_set_name (SerializableGeeCollectionsTestSpaceBase* self,
                                                       const gchar* value)
{
#line 172 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 172 "SerializableGeeCollectionsTest.vala"
	if (g_strcmp0 (value, serializable_gee_collections_test_space_base_get_name (self)) != 0) {
#line 8298 "SerializableGeeCollectionsTest.c"
		gchar* _tmp0_;
#line 172 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = g_strdup (value);
#line 172 "SerializableGeeCollectionsTest.vala"
		_g_free0 (self->priv->_name);
#line 172 "SerializableGeeCollectionsTest.vala"
		self->priv->_name = _tmp0_;
#line 172 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_space_base_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE_NAME_PROPERTY]);
#line 8308 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestChargeZone*
serializable_gee_collections_test_space_base_get_charge_zone (SerializableGeeCollectionsTestSpaceBase* self)
{
	SerializableGeeCollectionsTestChargeZone* result;
	SerializableGeeCollectionsTestChargeZone* _tmp0_;
#line 173 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 173 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_charge_zone;
#line 173 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 173 "SerializableGeeCollectionsTest.vala"
	return result;
#line 8325 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_space_base_set_charge_zone (SerializableGeeCollectionsTestSpaceBase* self,
                                                              SerializableGeeCollectionsTestChargeZone* value)
{
#line 173 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 173 "SerializableGeeCollectionsTest.vala"
	if (serializable_gee_collections_test_space_base_get_charge_zone (self) != value) {
#line 8336 "SerializableGeeCollectionsTest.c"
		SerializableGeeCollectionsTestChargeZone* _tmp0_;
#line 173 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 173 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (self->priv->_charge_zone);
#line 173 "SerializableGeeCollectionsTest.vala"
		self->priv->_charge_zone = _tmp0_;
#line 173 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_space_base_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE_CHARGE_ZONE_PROPERTY]);
#line 8346 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestStorage*
serializable_gee_collections_test_space_base_get_storage (SerializableGeeCollectionsTestSpaceBase* self)
{
	SerializableGeeCollectionsTestStorage* result;
	SerializableGeeCollectionsTestStorage* _tmp0_;
#line 174 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 174 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_storage;
#line 174 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 174 "SerializableGeeCollectionsTest.vala"
	return result;
#line 8363 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_space_base_set_storage (SerializableGeeCollectionsTestSpaceBase* self,
                                                          SerializableGeeCollectionsTestStorage* value)
{
#line 174 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 174 "SerializableGeeCollectionsTest.vala"
	if (serializable_gee_collections_test_space_base_get_storage (self) != value) {
#line 8374 "SerializableGeeCollectionsTest.c"
		SerializableGeeCollectionsTestStorage* _tmp0_;
#line 174 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 174 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (self->priv->_storage);
#line 174 "SerializableGeeCollectionsTest.vala"
		self->priv->_storage = _tmp0_;
#line 174 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_space_base_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE_STORAGE_PROPERTY]);
#line 8384 "SerializableGeeCollectionsTest.c"
	}
}

static void
serializable_gee_collections_test_space_base_class_init (SerializableGeeCollectionsTestSpaceBaseClass * klass,
                                                         gpointer klass_data)
{
#line 170 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_space_base_parent_class = g_type_class_peek_parent (klass);
#line 170 "SerializableGeeCollectionsTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeCollectionsTestSpaceBase_private_offset);
#line 170 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_space_base_real_node_name;
#line 170 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_space_base_real_to_string;
#line 170 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_collections_test_space_base_get_property;
#line 170 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_collections_test_space_base_set_property;
#line 170 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_collections_test_space_base_finalize;
#line 170 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE_NAME_PROPERTY, serializable_gee_collections_test_space_base_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 170 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE_CHARGE_ZONE_PROPERTY, serializable_gee_collections_test_space_base_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE_CHARGE_ZONE_PROPERTY] = g_param_spec_object ("charge-zone", "charge-zone", "charge-zone", SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_CHARGE_ZONE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 170 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE_STORAGE_PROPERTY, serializable_gee_collections_test_space_base_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE_STORAGE_PROPERTY] = g_param_spec_object ("storage", "storage", "storage", SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_STORAGE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 8412 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_space_base_instance_init (SerializableGeeCollectionsTestSpaceBase * self,
                                                            gpointer klass)
{
#line 170 "SerializableGeeCollectionsTest.vala"
	self->priv = serializable_gee_collections_test_space_base_get_instance_private (self);
#line 8421 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_space_base_finalize (GObject * obj)
{
	SerializableGeeCollectionsTestSpaceBase * self;
#line 170 "SerializableGeeCollectionsTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE_BASE, SerializableGeeCollectionsTestSpaceBase);
#line 172 "SerializableGeeCollectionsTest.vala"
	_g_free0 (self->priv->_name);
#line 173 "SerializableGeeCollectionsTest.vala"
	_g_object_unref0 (self->priv->_charge_zone);
#line 174 "SerializableGeeCollectionsTest.vala"
	_g_object_unref0 (self->priv->_storage);
#line 170 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (serializable_gee_collections_test_space_base_parent_class)->finalize (obj);
#line 8438 "SerializableGeeCollectionsTest.c"
}

static GType
serializable_gee_collections_test_space_base_get_type (void)
{
	static volatile gsize serializable_gee_collections_test_space_base_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_test_space_base_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTestSpaceBaseClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_test_space_base_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTestSpaceBase), 0, (GInstanceInitFunc) serializable_gee_collections_test_space_base_instance_init, NULL };
		GType serializable_gee_collections_test_space_base_type_id;
		serializable_gee_collections_test_space_base_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeCollectionsTestSpaceBase", &g_define_type_info, 0);
		SerializableGeeCollectionsTestSpaceBase_private_offset = g_type_add_instance_private (serializable_gee_collections_test_space_base_type_id, sizeof (SerializableGeeCollectionsTestSpaceBasePrivate));
		g_once_init_leave (&serializable_gee_collections_test_space_base_type_id__volatile, serializable_gee_collections_test_space_base_type_id);
	}
	return serializable_gee_collections_test_space_base_type_id__volatile;
}

static void
_vala_serializable_gee_collections_test_space_base_get_property (GObject * object,
                                                                 guint property_id,
                                                                 GValue * value,
                                                                 GParamSpec * pspec)
{
	SerializableGeeCollectionsTestSpaceBase * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE_BASE, SerializableGeeCollectionsTestSpaceBase);
#line 170 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 170 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE_NAME_PROPERTY:
#line 170 "SerializableGeeCollectionsTest.vala"
		g_value_set_string (value, serializable_gee_collections_test_space_base_get_name (self));
#line 170 "SerializableGeeCollectionsTest.vala"
		break;
#line 170 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE_CHARGE_ZONE_PROPERTY:
#line 170 "SerializableGeeCollectionsTest.vala"
		g_value_set_object (value, serializable_gee_collections_test_space_base_get_charge_zone (self));
#line 170 "SerializableGeeCollectionsTest.vala"
		break;
#line 170 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE_STORAGE_PROPERTY:
#line 170 "SerializableGeeCollectionsTest.vala"
		g_value_set_object (value, serializable_gee_collections_test_space_base_get_storage (self));
#line 170 "SerializableGeeCollectionsTest.vala"
		break;
#line 8483 "SerializableGeeCollectionsTest.c"
		default:
#line 170 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 170 "SerializableGeeCollectionsTest.vala"
		break;
#line 8489 "SerializableGeeCollectionsTest.c"
	}
}

static void
_vala_serializable_gee_collections_test_space_base_set_property (GObject * object,
                                                                 guint property_id,
                                                                 const GValue * value,
                                                                 GParamSpec * pspec)
{
	SerializableGeeCollectionsTestSpaceBase * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SPACE_BASE, SerializableGeeCollectionsTestSpaceBase);
#line 170 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 170 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE_NAME_PROPERTY:
#line 170 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_space_base_set_name (self, g_value_get_string (value));
#line 170 "SerializableGeeCollectionsTest.vala"
		break;
#line 170 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE_CHARGE_ZONE_PROPERTY:
#line 170 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_space_base_set_charge_zone (self, g_value_get_object (value));
#line 170 "SerializableGeeCollectionsTest.vala"
		break;
#line 170 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_SPACE_BASE_STORAGE_PROPERTY:
#line 170 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_space_base_set_storage (self, g_value_get_object (value));
#line 170 "SerializableGeeCollectionsTest.vala"
		break;
#line 8521 "SerializableGeeCollectionsTest.c"
		default:
#line 170 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 170 "SerializableGeeCollectionsTest.vala"
		break;
#line 8527 "SerializableGeeCollectionsTest.c"
	}
}

static inline gpointer
serializable_gee_collections_test_ball_fill_get_instance_private (SerializableGeeCollectionsTestBallFill* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeCollectionsTestBallFill_private_offset);
}

static gchar*
serializable_gee_collections_test_ball_fill_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestBallFill * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 182 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestBallFill*) base;
#line 182 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_name;
#line 182 "SerializableGeeCollectionsTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 182 "SerializableGeeCollectionsTest.vala"
	result = _tmp1_;
#line 182 "SerializableGeeCollectionsTest.vala"
	return result;
#line 8554 "SerializableGeeCollectionsTest.c"
}

static gchar*
serializable_gee_collections_test_ball_fill_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestBallFill * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 183 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestBallFill*) base;
#line 183 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = g_strdup ("BallFill");
#line 183 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 183 "SerializableGeeCollectionsTest.vala"
	return result;
#line 8571 "SerializableGeeCollectionsTest.c"
}

static gboolean
serializable_gee_collections_test_ball_fill_real_serialize_use_xml_node_value (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestBallFill * self;
	gboolean result = FALSE;
#line 184 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestBallFill*) base;
#line 184 "SerializableGeeCollectionsTest.vala"
	result = TRUE;
#line 184 "SerializableGeeCollectionsTest.vala"
	return result;
#line 8585 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestBallFill*
serializable_gee_collections_test_ball_fill_construct (GType object_type)
{
	SerializableGeeCollectionsTestBallFill * self = NULL;
#line 179 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestBallFill*) gxml_serializable_object_model_construct (object_type);
#line 179 "SerializableGeeCollectionsTest.vala"
	return self;
#line 8596 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestBallFill*
serializable_gee_collections_test_ball_fill_new (void)
{
#line 179 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_ball_fill_construct (SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BALL_FILL);
#line 8604 "SerializableGeeCollectionsTest.c"
}

static const gchar*
serializable_gee_collections_test_ball_fill_get_name (SerializableGeeCollectionsTestBallFill* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 181 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 181 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_name;
#line 181 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 181 "SerializableGeeCollectionsTest.vala"
	return result;
#line 8620 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_ball_fill_set_name (SerializableGeeCollectionsTestBallFill* self,
                                                      const gchar* value)
{
#line 181 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 181 "SerializableGeeCollectionsTest.vala"
	if (g_strcmp0 (value, serializable_gee_collections_test_ball_fill_get_name (self)) != 0) {
#line 8631 "SerializableGeeCollectionsTest.c"
		gchar* _tmp0_;
#line 181 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = g_strdup (value);
#line 181 "SerializableGeeCollectionsTest.vala"
		_g_free0 (self->priv->_name);
#line 181 "SerializableGeeCollectionsTest.vala"
		self->priv->_name = _tmp0_;
#line 181 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_ball_fill_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_FILL_NAME_PROPERTY]);
#line 8641 "SerializableGeeCollectionsTest.c"
	}
}

static void
serializable_gee_collections_test_ball_fill_class_init (SerializableGeeCollectionsTestBallFillClass * klass,
                                                        gpointer klass_data)
{
#line 179 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_ball_fill_parent_class = g_type_class_peek_parent (klass);
#line 179 "SerializableGeeCollectionsTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeCollectionsTestBallFill_private_offset);
#line 179 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_ball_fill_real_to_string;
#line 179 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_ball_fill_real_node_name;
#line 179 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->serialize_use_xml_node_value = (gboolean (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_ball_fill_real_serialize_use_xml_node_value;
#line 179 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_collections_test_ball_fill_get_property;
#line 179 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_collections_test_ball_fill_set_property;
#line 179 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_collections_test_ball_fill_finalize;
#line 179 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_FILL_NAME_PROPERTY, serializable_gee_collections_test_ball_fill_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_FILL_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 8667 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_ball_fill_instance_init (SerializableGeeCollectionsTestBallFill * self,
                                                           gpointer klass)
{
	gchar* _tmp0_;
#line 179 "SerializableGeeCollectionsTest.vala"
	self->priv = serializable_gee_collections_test_ball_fill_get_instance_private (self);
#line 181 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = g_strdup ("Fill");
#line 181 "SerializableGeeCollectionsTest.vala"
	self->priv->_name = _tmp0_;
#line 8681 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_ball_fill_finalize (GObject * obj)
{
	SerializableGeeCollectionsTestBallFill * self;
#line 179 "SerializableGeeCollectionsTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BALL_FILL, SerializableGeeCollectionsTestBallFill);
#line 181 "SerializableGeeCollectionsTest.vala"
	_g_free0 (self->priv->_name);
#line 179 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (serializable_gee_collections_test_ball_fill_parent_class)->finalize (obj);
#line 8694 "SerializableGeeCollectionsTest.c"
}

static GType
serializable_gee_collections_test_ball_fill_get_type (void)
{
	static volatile gsize serializable_gee_collections_test_ball_fill_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_test_ball_fill_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTestBallFillClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_test_ball_fill_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTestBallFill), 0, (GInstanceInitFunc) serializable_gee_collections_test_ball_fill_instance_init, NULL };
		GType serializable_gee_collections_test_ball_fill_type_id;
		serializable_gee_collections_test_ball_fill_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeCollectionsTestBallFill", &g_define_type_info, 0);
		SerializableGeeCollectionsTestBallFill_private_offset = g_type_add_instance_private (serializable_gee_collections_test_ball_fill_type_id, sizeof (SerializableGeeCollectionsTestBallFillPrivate));
		g_once_init_leave (&serializable_gee_collections_test_ball_fill_type_id__volatile, serializable_gee_collections_test_ball_fill_type_id);
	}
	return serializable_gee_collections_test_ball_fill_type_id__volatile;
}

static void
_vala_serializable_gee_collections_test_ball_fill_get_property (GObject * object,
                                                                guint property_id,
                                                                GValue * value,
                                                                GParamSpec * pspec)
{
	SerializableGeeCollectionsTestBallFill * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BALL_FILL, SerializableGeeCollectionsTestBallFill);
#line 179 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 179 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_FILL_NAME_PROPERTY:
#line 179 "SerializableGeeCollectionsTest.vala"
		g_value_set_string (value, serializable_gee_collections_test_ball_fill_get_name (self));
#line 179 "SerializableGeeCollectionsTest.vala"
		break;
#line 8727 "SerializableGeeCollectionsTest.c"
		default:
#line 179 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 179 "SerializableGeeCollectionsTest.vala"
		break;
#line 8733 "SerializableGeeCollectionsTest.c"
	}
}

static void
_vala_serializable_gee_collections_test_ball_fill_set_property (GObject * object,
                                                                guint property_id,
                                                                const GValue * value,
                                                                GParamSpec * pspec)
{
	SerializableGeeCollectionsTestBallFill * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BALL_FILL, SerializableGeeCollectionsTestBallFill);
#line 179 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 179 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_FILL_NAME_PROPERTY:
#line 179 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_ball_fill_set_name (self, g_value_get_string (value));
#line 179 "SerializableGeeCollectionsTest.vala"
		break;
#line 8753 "SerializableGeeCollectionsTest.c"
		default:
#line 179 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 179 "SerializableGeeCollectionsTest.vala"
		break;
#line 8759 "SerializableGeeCollectionsTest.c"
	}
}

static inline gpointer
serializable_gee_collections_test_ball_get_instance_private (SerializableGeeCollectionsTestBall* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeCollectionsTestBall_private_offset);
}

static gchar*
serializable_gee_collections_test_ball_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestBall * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 191 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestBall*) base;
#line 191 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_name;
#line 191 "SerializableGeeCollectionsTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 191 "SerializableGeeCollectionsTest.vala"
	result = _tmp1_;
#line 191 "SerializableGeeCollectionsTest.vala"
	return result;
#line 8786 "SerializableGeeCollectionsTest.c"
}

static gchar*
serializable_gee_collections_test_ball_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestBall * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 192 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestBall*) base;
#line 192 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = g_strdup ("Ball");
#line 192 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 192 "SerializableGeeCollectionsTest.vala"
	return result;
#line 8803 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestBall*
serializable_gee_collections_test_ball_construct (GType object_type)
{
	SerializableGeeCollectionsTestBall * self = NULL;
#line 187 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestBall*) gxml_serializable_object_model_construct (object_type);
#line 187 "SerializableGeeCollectionsTest.vala"
	return self;
#line 8814 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestBall*
serializable_gee_collections_test_ball_new (void)
{
#line 187 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_ball_construct (SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BALL);
#line 8822 "SerializableGeeCollectionsTest.c"
}

static const gchar*
serializable_gee_collections_test_ball_get_name (SerializableGeeCollectionsTestBall* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 189 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 189 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_name;
#line 189 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 189 "SerializableGeeCollectionsTest.vala"
	return result;
#line 8838 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_ball_set_name (SerializableGeeCollectionsTestBall* self,
                                                 const gchar* value)
{
#line 189 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 189 "SerializableGeeCollectionsTest.vala"
	if (g_strcmp0 (value, serializable_gee_collections_test_ball_get_name (self)) != 0) {
#line 8849 "SerializableGeeCollectionsTest.c"
		gchar* _tmp0_;
#line 189 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = g_strdup (value);
#line 189 "SerializableGeeCollectionsTest.vala"
		_g_free0 (self->priv->_name);
#line 189 "SerializableGeeCollectionsTest.vala"
		self->priv->_name = _tmp0_;
#line 189 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_ball_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_NAME_PROPERTY]);
#line 8859 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestBallFill*
serializable_gee_collections_test_ball_get_ballfill (SerializableGeeCollectionsTestBall* self)
{
	SerializableGeeCollectionsTestBallFill* result;
	SerializableGeeCollectionsTestBallFill* _tmp0_;
#line 190 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 190 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_ballfill;
#line 190 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 190 "SerializableGeeCollectionsTest.vala"
	return result;
#line 8876 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_ball_set_ballfill (SerializableGeeCollectionsTestBall* self,
                                                     SerializableGeeCollectionsTestBallFill* value)
{
#line 190 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 190 "SerializableGeeCollectionsTest.vala"
	if (serializable_gee_collections_test_ball_get_ballfill (self) != value) {
#line 8887 "SerializableGeeCollectionsTest.c"
		SerializableGeeCollectionsTestBallFill* _tmp0_;
#line 190 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 190 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (self->priv->_ballfill);
#line 190 "SerializableGeeCollectionsTest.vala"
		self->priv->_ballfill = _tmp0_;
#line 190 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_ball_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_BALLFILL_PROPERTY]);
#line 8897 "SerializableGeeCollectionsTest.c"
	}
}

static gboolean
serializable_gee_collections_test_ball_array_real_deserialize_proceed (GXmlSerializableArrayList* base)
{
	SerializableGeeCollectionsTestBallArray * self;
	gboolean result = FALSE;
#line 194 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestBallArray*) base;
#line 194 "SerializableGeeCollectionsTest.vala"
	result = FALSE;
#line 194 "SerializableGeeCollectionsTest.vala"
	return result;
#line 8912 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestBallArray*
serializable_gee_collections_test_ball_array_construct (GType object_type)
{
	SerializableGeeCollectionsTestBallArray * self = NULL;
#line 193 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestBallArray*) gxml_serializable_array_list_construct (object_type, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BALL, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 193 "SerializableGeeCollectionsTest.vala"
	return self;
#line 8923 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestBallArray*
serializable_gee_collections_test_ball_array_new (void)
{
#line 193 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_ball_array_construct (SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_TYPE_ARRAY);
#line 8931 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_ball_array_class_init (SerializableGeeCollectionsTestBallArrayClass * klass,
                                                         gpointer klass_data)
{
#line 193 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_ball_array_parent_class = g_type_class_peek_parent (klass);
#line 193 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableArrayListClass *) klass)->deserialize_proceed = (gboolean (*) (GXmlSerializableArrayList*)) serializable_gee_collections_test_ball_array_real_deserialize_proceed;
#line 8942 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_ball_array_instance_init (SerializableGeeCollectionsTestBallArray * self,
                                                            gpointer klass)
{
}

GType
serializable_gee_collections_test_ball_array_get_type (void)
{
	static volatile gsize serializable_gee_collections_test_ball_array_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_test_ball_array_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTestBallArrayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_test_ball_array_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTestBallArray), 0, (GInstanceInitFunc) serializable_gee_collections_test_ball_array_instance_init, NULL };
		GType serializable_gee_collections_test_ball_array_type_id;
		serializable_gee_collections_test_ball_array_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_ARRAY_LIST, "SerializableGeeCollectionsTestBallArray", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_collections_test_ball_array_type_id__volatile, serializable_gee_collections_test_ball_array_type_id);
	}
	return serializable_gee_collections_test_ball_array_type_id__volatile;
}

static void
serializable_gee_collections_test_ball_class_init (SerializableGeeCollectionsTestBallClass * klass,
                                                   gpointer klass_data)
{
#line 187 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_ball_parent_class = g_type_class_peek_parent (klass);
#line 187 "SerializableGeeCollectionsTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeCollectionsTestBall_private_offset);
#line 187 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_ball_real_to_string;
#line 187 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_ball_real_node_name;
#line 187 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_collections_test_ball_get_property;
#line 187 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_collections_test_ball_set_property;
#line 187 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_collections_test_ball_finalize;
#line 187 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_NAME_PROPERTY, serializable_gee_collections_test_ball_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 187 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_BALLFILL_PROPERTY, serializable_gee_collections_test_ball_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_BALLFILL_PROPERTY] = g_param_spec_object ("ballfill", "ballfill", "ballfill", SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BALL_FILL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 8986 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_ball_instance_init (SerializableGeeCollectionsTestBall * self,
                                                      gpointer klass)
{
	gchar* _tmp0_;
#line 187 "SerializableGeeCollectionsTest.vala"
	self->priv = serializable_gee_collections_test_ball_get_instance_private (self);
#line 189 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = g_strdup ("Ball");
#line 189 "SerializableGeeCollectionsTest.vala"
	self->priv->_name = _tmp0_;
#line 9000 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_ball_finalize (GObject * obj)
{
	SerializableGeeCollectionsTestBall * self;
#line 187 "SerializableGeeCollectionsTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BALL, SerializableGeeCollectionsTestBall);
#line 189 "SerializableGeeCollectionsTest.vala"
	_g_free0 (self->priv->_name);
#line 190 "SerializableGeeCollectionsTest.vala"
	_g_object_unref0 (self->priv->_ballfill);
#line 187 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (serializable_gee_collections_test_ball_parent_class)->finalize (obj);
#line 9015 "SerializableGeeCollectionsTest.c"
}

static GType
serializable_gee_collections_test_ball_get_type (void)
{
	static volatile gsize serializable_gee_collections_test_ball_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_test_ball_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTestBallClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_test_ball_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTestBall), 0, (GInstanceInitFunc) serializable_gee_collections_test_ball_instance_init, NULL };
		GType serializable_gee_collections_test_ball_type_id;
		serializable_gee_collections_test_ball_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeCollectionsTestBall", &g_define_type_info, 0);
		SerializableGeeCollectionsTestBall_private_offset = g_type_add_instance_private (serializable_gee_collections_test_ball_type_id, sizeof (SerializableGeeCollectionsTestBallPrivate));
		g_once_init_leave (&serializable_gee_collections_test_ball_type_id__volatile, serializable_gee_collections_test_ball_type_id);
	}
	return serializable_gee_collections_test_ball_type_id__volatile;
}

static void
_vala_serializable_gee_collections_test_ball_get_property (GObject * object,
                                                           guint property_id,
                                                           GValue * value,
                                                           GParamSpec * pspec)
{
	SerializableGeeCollectionsTestBall * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BALL, SerializableGeeCollectionsTestBall);
#line 187 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 187 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_NAME_PROPERTY:
#line 187 "SerializableGeeCollectionsTest.vala"
		g_value_set_string (value, serializable_gee_collections_test_ball_get_name (self));
#line 187 "SerializableGeeCollectionsTest.vala"
		break;
#line 187 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_BALLFILL_PROPERTY:
#line 187 "SerializableGeeCollectionsTest.vala"
		g_value_set_object (value, serializable_gee_collections_test_ball_get_ballfill (self));
#line 187 "SerializableGeeCollectionsTest.vala"
		break;
#line 9054 "SerializableGeeCollectionsTest.c"
		default:
#line 187 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 187 "SerializableGeeCollectionsTest.vala"
		break;
#line 9060 "SerializableGeeCollectionsTest.c"
	}
}

static void
_vala_serializable_gee_collections_test_ball_set_property (GObject * object,
                                                           guint property_id,
                                                           const GValue * value,
                                                           GParamSpec * pspec)
{
	SerializableGeeCollectionsTestBall * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BALL, SerializableGeeCollectionsTestBall);
#line 187 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 187 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_NAME_PROPERTY:
#line 187 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_ball_set_name (self, g_value_get_string (value));
#line 187 "SerializableGeeCollectionsTest.vala"
		break;
#line 187 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_BALLFILL_PROPERTY:
#line 187 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_ball_set_ballfill (self, g_value_get_object (value));
#line 187 "SerializableGeeCollectionsTest.vala"
		break;
#line 9086 "SerializableGeeCollectionsTest.c"
		default:
#line 187 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 187 "SerializableGeeCollectionsTest.vala"
		break;
#line 9092 "SerializableGeeCollectionsTest.c"
	}
}

static inline gpointer
serializable_gee_collections_test_small_bag_get_instance_private (SerializableGeeCollectionsTestSmallBag* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeCollectionsTestSmallBag_private_offset);
}

static gchar*
serializable_gee_collections_test_small_bag_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestSmallBag * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 202 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSmallBag*) base;
#line 202 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_name;
#line 202 "SerializableGeeCollectionsTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 202 "SerializableGeeCollectionsTest.vala"
	result = _tmp1_;
#line 202 "SerializableGeeCollectionsTest.vala"
	return result;
#line 9119 "SerializableGeeCollectionsTest.c"
}

static gchar*
serializable_gee_collections_test_small_bag_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestSmallBag * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 203 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSmallBag*) base;
#line 203 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = g_strdup ("SmallBag");
#line 203 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 203 "SerializableGeeCollectionsTest.vala"
	return result;
#line 9136 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestSmallBag*
serializable_gee_collections_test_small_bag_construct (GType object_type)
{
	SerializableGeeCollectionsTestSmallBag * self = NULL;
#line 198 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSmallBag*) gxml_serializable_object_model_construct (object_type);
#line 198 "SerializableGeeCollectionsTest.vala"
	return self;
#line 9147 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestSmallBag*
serializable_gee_collections_test_small_bag_new (void)
{
#line 198 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_small_bag_construct (SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SMALL_BAG);
#line 9155 "SerializableGeeCollectionsTest.c"
}

static const gchar*
serializable_gee_collections_test_small_bag_get_name (SerializableGeeCollectionsTestSmallBag* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 200 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 200 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_name;
#line 200 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 200 "SerializableGeeCollectionsTest.vala"
	return result;
#line 9171 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_small_bag_set_name (SerializableGeeCollectionsTestSmallBag* self,
                                                      const gchar* value)
{
#line 200 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 200 "SerializableGeeCollectionsTest.vala"
	if (g_strcmp0 (value, serializable_gee_collections_test_small_bag_get_name (self)) != 0) {
#line 9182 "SerializableGeeCollectionsTest.c"
		gchar* _tmp0_;
#line 200 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = g_strdup (value);
#line 200 "SerializableGeeCollectionsTest.vala"
		_g_free0 (self->priv->_name);
#line 200 "SerializableGeeCollectionsTest.vala"
		self->priv->_name = _tmp0_;
#line 200 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_small_bag_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_NAME_PROPERTY]);
#line 9192 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestBallArray*
serializable_gee_collections_test_small_bag_get_balls (SerializableGeeCollectionsTestSmallBag* self)
{
	SerializableGeeCollectionsTestBallArray* result;
	SerializableGeeCollectionsTestBallArray* _tmp0_;
#line 201 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 201 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_balls;
#line 201 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 201 "SerializableGeeCollectionsTest.vala"
	return result;
#line 9209 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_small_bag_set_balls (SerializableGeeCollectionsTestSmallBag* self,
                                                       SerializableGeeCollectionsTestBallArray* value)
{
#line 201 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 201 "SerializableGeeCollectionsTest.vala"
	if (serializable_gee_collections_test_small_bag_get_balls (self) != value) {
#line 9220 "SerializableGeeCollectionsTest.c"
		SerializableGeeCollectionsTestBallArray* _tmp0_;
#line 201 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 201 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (self->priv->_balls);
#line 201 "SerializableGeeCollectionsTest.vala"
		self->priv->_balls = _tmp0_;
#line 201 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_small_bag_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_BALLS_PROPERTY]);
#line 9230 "SerializableGeeCollectionsTest.c"
	}
}

static gboolean
serializable_gee_collections_test_small_bag_array_real_deserialize_proceed (GXmlSerializableArrayList* base)
{
	SerializableGeeCollectionsTestSmallBagArray * self;
	gboolean result = FALSE;
#line 205 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSmallBagArray*) base;
#line 205 "SerializableGeeCollectionsTest.vala"
	result = FALSE;
#line 205 "SerializableGeeCollectionsTest.vala"
	return result;
#line 9245 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestSmallBagArray*
serializable_gee_collections_test_small_bag_array_construct (GType object_type)
{
	SerializableGeeCollectionsTestSmallBagArray * self = NULL;
#line 204 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestSmallBagArray*) gxml_serializable_array_list_construct (object_type, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SMALL_BAG, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 204 "SerializableGeeCollectionsTest.vala"
	return self;
#line 9256 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestSmallBagArray*
serializable_gee_collections_test_small_bag_array_new (void)
{
#line 204 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_small_bag_array_construct (SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_TYPE_ARRAY);
#line 9264 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_small_bag_array_class_init (SerializableGeeCollectionsTestSmallBagArrayClass * klass,
                                                              gpointer klass_data)
{
#line 204 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_small_bag_array_parent_class = g_type_class_peek_parent (klass);
#line 204 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableArrayListClass *) klass)->deserialize_proceed = (gboolean (*) (GXmlSerializableArrayList*)) serializable_gee_collections_test_small_bag_array_real_deserialize_proceed;
#line 9275 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_small_bag_array_instance_init (SerializableGeeCollectionsTestSmallBagArray * self,
                                                                 gpointer klass)
{
}

GType
serializable_gee_collections_test_small_bag_array_get_type (void)
{
	static volatile gsize serializable_gee_collections_test_small_bag_array_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_test_small_bag_array_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTestSmallBagArrayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_test_small_bag_array_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTestSmallBagArray), 0, (GInstanceInitFunc) serializable_gee_collections_test_small_bag_array_instance_init, NULL };
		GType serializable_gee_collections_test_small_bag_array_type_id;
		serializable_gee_collections_test_small_bag_array_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_ARRAY_LIST, "SerializableGeeCollectionsTestSmallBagArray", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_collections_test_small_bag_array_type_id__volatile, serializable_gee_collections_test_small_bag_array_type_id);
	}
	return serializable_gee_collections_test_small_bag_array_type_id__volatile;
}

static void
serializable_gee_collections_test_small_bag_class_init (SerializableGeeCollectionsTestSmallBagClass * klass,
                                                        gpointer klass_data)
{
#line 198 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_small_bag_parent_class = g_type_class_peek_parent (klass);
#line 198 "SerializableGeeCollectionsTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeCollectionsTestSmallBag_private_offset);
#line 198 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_small_bag_real_to_string;
#line 198 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_small_bag_real_node_name;
#line 198 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_collections_test_small_bag_get_property;
#line 198 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_collections_test_small_bag_set_property;
#line 198 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_collections_test_small_bag_finalize;
#line 198 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_NAME_PROPERTY, serializable_gee_collections_test_small_bag_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 198 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_BALLS_PROPERTY, serializable_gee_collections_test_small_bag_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_BALLS_PROPERTY] = g_param_spec_object ("balls", "balls", "balls", SERIALIZABLE_GEE_COLLECTIONS_TEST_BALL_TYPE_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 9319 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_small_bag_instance_init (SerializableGeeCollectionsTestSmallBag * self,
                                                           gpointer klass)
{
	gchar* _tmp0_;
	SerializableGeeCollectionsTestBallArray* _tmp1_;
#line 198 "SerializableGeeCollectionsTest.vala"
	self->priv = serializable_gee_collections_test_small_bag_get_instance_private (self);
#line 200 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = g_strdup ("SmallBag");
#line 200 "SerializableGeeCollectionsTest.vala"
	self->priv->_name = _tmp0_;
#line 201 "SerializableGeeCollectionsTest.vala"
	_tmp1_ = serializable_gee_collections_test_ball_array_new ();
#line 201 "SerializableGeeCollectionsTest.vala"
	self->priv->_balls = _tmp1_;
#line 9338 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_small_bag_finalize (GObject * obj)
{
	SerializableGeeCollectionsTestSmallBag * self;
#line 198 "SerializableGeeCollectionsTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SMALL_BAG, SerializableGeeCollectionsTestSmallBag);
#line 200 "SerializableGeeCollectionsTest.vala"
	_g_free0 (self->priv->_name);
#line 201 "SerializableGeeCollectionsTest.vala"
	_g_object_unref0 (self->priv->_balls);
#line 198 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (serializable_gee_collections_test_small_bag_parent_class)->finalize (obj);
#line 9353 "SerializableGeeCollectionsTest.c"
}

static GType
serializable_gee_collections_test_small_bag_get_type (void)
{
	static volatile gsize serializable_gee_collections_test_small_bag_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_test_small_bag_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTestSmallBagClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_test_small_bag_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTestSmallBag), 0, (GInstanceInitFunc) serializable_gee_collections_test_small_bag_instance_init, NULL };
		GType serializable_gee_collections_test_small_bag_type_id;
		serializable_gee_collections_test_small_bag_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeCollectionsTestSmallBag", &g_define_type_info, 0);
		SerializableGeeCollectionsTestSmallBag_private_offset = g_type_add_instance_private (serializable_gee_collections_test_small_bag_type_id, sizeof (SerializableGeeCollectionsTestSmallBagPrivate));
		g_once_init_leave (&serializable_gee_collections_test_small_bag_type_id__volatile, serializable_gee_collections_test_small_bag_type_id);
	}
	return serializable_gee_collections_test_small_bag_type_id__volatile;
}

static void
_vala_serializable_gee_collections_test_small_bag_get_property (GObject * object,
                                                                guint property_id,
                                                                GValue * value,
                                                                GParamSpec * pspec)
{
	SerializableGeeCollectionsTestSmallBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SMALL_BAG, SerializableGeeCollectionsTestSmallBag);
#line 198 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 198 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_NAME_PROPERTY:
#line 198 "SerializableGeeCollectionsTest.vala"
		g_value_set_string (value, serializable_gee_collections_test_small_bag_get_name (self));
#line 198 "SerializableGeeCollectionsTest.vala"
		break;
#line 198 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_BALLS_PROPERTY:
#line 198 "SerializableGeeCollectionsTest.vala"
		g_value_set_object (value, serializable_gee_collections_test_small_bag_get_balls (self));
#line 198 "SerializableGeeCollectionsTest.vala"
		break;
#line 9392 "SerializableGeeCollectionsTest.c"
		default:
#line 198 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 198 "SerializableGeeCollectionsTest.vala"
		break;
#line 9398 "SerializableGeeCollectionsTest.c"
	}
}

static void
_vala_serializable_gee_collections_test_small_bag_set_property (GObject * object,
                                                                guint property_id,
                                                                const GValue * value,
                                                                GParamSpec * pspec)
{
	SerializableGeeCollectionsTestSmallBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_SMALL_BAG, SerializableGeeCollectionsTestSmallBag);
#line 198 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 198 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_NAME_PROPERTY:
#line 198 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_small_bag_set_name (self, g_value_get_string (value));
#line 198 "SerializableGeeCollectionsTest.vala"
		break;
#line 198 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_BALLS_PROPERTY:
#line 198 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_small_bag_set_balls (self, g_value_get_object (value));
#line 198 "SerializableGeeCollectionsTest.vala"
		break;
#line 9424 "SerializableGeeCollectionsTest.c"
		default:
#line 198 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 198 "SerializableGeeCollectionsTest.vala"
		break;
#line 9430 "SerializableGeeCollectionsTest.c"
	}
}

static inline gpointer
serializable_gee_collections_test_big_bag_get_instance_private (SerializableGeeCollectionsTestBigBag* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeCollectionsTestBigBag_private_offset);
}

static gchar*
serializable_gee_collections_test_big_bag_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestBigBag * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 213 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestBigBag*) base;
#line 213 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_name;
#line 213 "SerializableGeeCollectionsTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 213 "SerializableGeeCollectionsTest.vala"
	result = _tmp1_;
#line 213 "SerializableGeeCollectionsTest.vala"
	return result;
#line 9457 "SerializableGeeCollectionsTest.c"
}

static gchar*
serializable_gee_collections_test_big_bag_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTestBigBag * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 214 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestBigBag*) base;
#line 214 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = g_strdup ("BigBag");
#line 214 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 214 "SerializableGeeCollectionsTest.vala"
	return result;
#line 9474 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestBigBag*
serializable_gee_collections_test_big_bag_construct (GType object_type)
{
	SerializableGeeCollectionsTestBigBag * self = NULL;
#line 209 "SerializableGeeCollectionsTest.vala"
	self = (SerializableGeeCollectionsTestBigBag*) gxml_serializable_object_model_construct (object_type);
#line 209 "SerializableGeeCollectionsTest.vala"
	return self;
#line 9485 "SerializableGeeCollectionsTest.c"
}

static SerializableGeeCollectionsTestBigBag*
serializable_gee_collections_test_big_bag_new (void)
{
#line 209 "SerializableGeeCollectionsTest.vala"
	return serializable_gee_collections_test_big_bag_construct (SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BIG_BAG);
#line 9493 "SerializableGeeCollectionsTest.c"
}

static const gchar*
serializable_gee_collections_test_big_bag_get_name (SerializableGeeCollectionsTestBigBag* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 211 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 211 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_name;
#line 211 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 211 "SerializableGeeCollectionsTest.vala"
	return result;
#line 9509 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_big_bag_set_name (SerializableGeeCollectionsTestBigBag* self,
                                                    const gchar* value)
{
#line 211 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 211 "SerializableGeeCollectionsTest.vala"
	if (g_strcmp0 (value, serializable_gee_collections_test_big_bag_get_name (self)) != 0) {
#line 9520 "SerializableGeeCollectionsTest.c"
		gchar* _tmp0_;
#line 211 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = g_strdup (value);
#line 211 "SerializableGeeCollectionsTest.vala"
		_g_free0 (self->priv->_name);
#line 211 "SerializableGeeCollectionsTest.vala"
		self->priv->_name = _tmp0_;
#line 211 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_big_bag_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_BIG_BAG_NAME_PROPERTY]);
#line 9530 "SerializableGeeCollectionsTest.c"
	}
}

static SerializableGeeCollectionsTestSmallBagArray*
serializable_gee_collections_test_big_bag_get_bags (SerializableGeeCollectionsTestBigBag* self)
{
	SerializableGeeCollectionsTestSmallBagArray* result;
	SerializableGeeCollectionsTestSmallBagArray* _tmp0_;
#line 212 "SerializableGeeCollectionsTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 212 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = self->priv->_bags;
#line 212 "SerializableGeeCollectionsTest.vala"
	result = _tmp0_;
#line 212 "SerializableGeeCollectionsTest.vala"
	return result;
#line 9547 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_big_bag_set_bags (SerializableGeeCollectionsTestBigBag* self,
                                                    SerializableGeeCollectionsTestSmallBagArray* value)
{
#line 212 "SerializableGeeCollectionsTest.vala"
	g_return_if_fail (self != NULL);
#line 212 "SerializableGeeCollectionsTest.vala"
	if (serializable_gee_collections_test_big_bag_get_bags (self) != value) {
#line 9558 "SerializableGeeCollectionsTest.c"
		SerializableGeeCollectionsTestSmallBagArray* _tmp0_;
#line 212 "SerializableGeeCollectionsTest.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 212 "SerializableGeeCollectionsTest.vala"
		_g_object_unref0 (self->priv->_bags);
#line 212 "SerializableGeeCollectionsTest.vala"
		self->priv->_bags = _tmp0_;
#line 212 "SerializableGeeCollectionsTest.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_test_big_bag_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_BIG_BAG_BAGS_PROPERTY]);
#line 9568 "SerializableGeeCollectionsTest.c"
	}
}

static void
serializable_gee_collections_test_big_bag_class_init (SerializableGeeCollectionsTestBigBagClass * klass,
                                                      gpointer klass_data)
{
#line 209 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_big_bag_parent_class = g_type_class_peek_parent (klass);
#line 209 "SerializableGeeCollectionsTest.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeCollectionsTestBigBag_private_offset);
#line 209 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_big_bag_real_to_string;
#line 209 "SerializableGeeCollectionsTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_test_big_bag_real_node_name;
#line 209 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_collections_test_big_bag_get_property;
#line 209 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_collections_test_big_bag_set_property;
#line 209 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_collections_test_big_bag_finalize;
#line 209 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_BIG_BAG_NAME_PROPERTY, serializable_gee_collections_test_big_bag_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_BIG_BAG_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 209 "SerializableGeeCollectionsTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TEST_BIG_BAG_BAGS_PROPERTY, serializable_gee_collections_test_big_bag_properties[SERIALIZABLE_GEE_COLLECTIONS_TEST_BIG_BAG_BAGS_PROPERTY] = g_param_spec_object ("bags", "bags", "bags", SERIALIZABLE_GEE_COLLECTIONS_TEST_SMALL_BAG_TYPE_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 9594 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_big_bag_instance_init (SerializableGeeCollectionsTestBigBag * self,
                                                         gpointer klass)
{
	gchar* _tmp0_;
	SerializableGeeCollectionsTestSmallBagArray* _tmp1_;
#line 209 "SerializableGeeCollectionsTest.vala"
	self->priv = serializable_gee_collections_test_big_bag_get_instance_private (self);
#line 211 "SerializableGeeCollectionsTest.vala"
	_tmp0_ = g_strdup ("ball");
#line 211 "SerializableGeeCollectionsTest.vala"
	self->priv->_name = _tmp0_;
#line 212 "SerializableGeeCollectionsTest.vala"
	_tmp1_ = serializable_gee_collections_test_small_bag_array_new ();
#line 212 "SerializableGeeCollectionsTest.vala"
	self->priv->_bags = _tmp1_;
#line 9613 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_big_bag_finalize (GObject * obj)
{
	SerializableGeeCollectionsTestBigBag * self;
#line 209 "SerializableGeeCollectionsTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BIG_BAG, SerializableGeeCollectionsTestBigBag);
#line 211 "SerializableGeeCollectionsTest.vala"
	_g_free0 (self->priv->_name);
#line 212 "SerializableGeeCollectionsTest.vala"
	_g_object_unref0 (self->priv->_bags);
#line 209 "SerializableGeeCollectionsTest.vala"
	G_OBJECT_CLASS (serializable_gee_collections_test_big_bag_parent_class)->finalize (obj);
#line 9628 "SerializableGeeCollectionsTest.c"
}

static GType
serializable_gee_collections_test_big_bag_get_type (void)
{
	static volatile gsize serializable_gee_collections_test_big_bag_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_test_big_bag_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTestBigBagClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_test_big_bag_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTestBigBag), 0, (GInstanceInitFunc) serializable_gee_collections_test_big_bag_instance_init, NULL };
		GType serializable_gee_collections_test_big_bag_type_id;
		serializable_gee_collections_test_big_bag_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeCollectionsTestBigBag", &g_define_type_info, 0);
		SerializableGeeCollectionsTestBigBag_private_offset = g_type_add_instance_private (serializable_gee_collections_test_big_bag_type_id, sizeof (SerializableGeeCollectionsTestBigBagPrivate));
		g_once_init_leave (&serializable_gee_collections_test_big_bag_type_id__volatile, serializable_gee_collections_test_big_bag_type_id);
	}
	return serializable_gee_collections_test_big_bag_type_id__volatile;
}

static void
_vala_serializable_gee_collections_test_big_bag_get_property (GObject * object,
                                                              guint property_id,
                                                              GValue * value,
                                                              GParamSpec * pspec)
{
	SerializableGeeCollectionsTestBigBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BIG_BAG, SerializableGeeCollectionsTestBigBag);
#line 209 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 209 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_BIG_BAG_NAME_PROPERTY:
#line 209 "SerializableGeeCollectionsTest.vala"
		g_value_set_string (value, serializable_gee_collections_test_big_bag_get_name (self));
#line 209 "SerializableGeeCollectionsTest.vala"
		break;
#line 209 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_BIG_BAG_BAGS_PROPERTY:
#line 209 "SerializableGeeCollectionsTest.vala"
		g_value_set_object (value, serializable_gee_collections_test_big_bag_get_bags (self));
#line 209 "SerializableGeeCollectionsTest.vala"
		break;
#line 9667 "SerializableGeeCollectionsTest.c"
		default:
#line 209 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 209 "SerializableGeeCollectionsTest.vala"
		break;
#line 9673 "SerializableGeeCollectionsTest.c"
	}
}

static void
_vala_serializable_gee_collections_test_big_bag_set_property (GObject * object,
                                                              guint property_id,
                                                              const GValue * value,
                                                              GParamSpec * pspec)
{
	SerializableGeeCollectionsTestBigBag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TEST_TYPE_BIG_BAG, SerializableGeeCollectionsTestBigBag);
#line 209 "SerializableGeeCollectionsTest.vala"
	switch (property_id) {
#line 209 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_BIG_BAG_NAME_PROPERTY:
#line 209 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_big_bag_set_name (self, g_value_get_string (value));
#line 209 "SerializableGeeCollectionsTest.vala"
		break;
#line 209 "SerializableGeeCollectionsTest.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TEST_BIG_BAG_BAGS_PROPERTY:
#line 209 "SerializableGeeCollectionsTest.vala"
		serializable_gee_collections_test_big_bag_set_bags (self, g_value_get_object (value));
#line 209 "SerializableGeeCollectionsTest.vala"
		break;
#line 9699 "SerializableGeeCollectionsTest.c"
		default:
#line 209 "SerializableGeeCollectionsTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 209 "SerializableGeeCollectionsTest.vala"
		break;
#line 9705 "SerializableGeeCollectionsTest.c"
	}
}

static void
serializable_gee_collections_test_class_init (SerializableGeeCollectionsTestClass * klass,
                                              gpointer klass_data)
{
#line 30 "SerializableGeeCollectionsTest.vala"
	serializable_gee_collections_test_parent_class = g_type_class_peek_parent (klass);
#line 9715 "SerializableGeeCollectionsTest.c"
}

static void
serializable_gee_collections_test_instance_init (SerializableGeeCollectionsTest * self,
                                                 gpointer klass)
{
}

/**
 *
 *  GXml.Serializable.GeeCollectionsTest
 *
 *  Authors:
 *
 *       Daniel Espinosa <esodan@gmail.com>
 *
 *
 *  Copyright (c) 2013-2015 Daniel Espinosa
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
GType
serializable_gee_collections_test_get_type (void)
{
	static volatile gsize serializable_gee_collections_test_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTest), 0, (GInstanceInitFunc) serializable_gee_collections_test_instance_init, NULL };
		GType serializable_gee_collections_test_type_id;
		serializable_gee_collections_test_type_id = g_type_register_static (TYPE_GXML_TEST, "SerializableGeeCollectionsTest", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_collections_test_type_id__volatile, serializable_gee_collections_test_type_id);
	}
	return serializable_gee_collections_test_type_id__volatile;
}

