/* SerializableGeeCollections-TDocument-Test.c generated by valac 0.44.3, the Vala compiler
 * generated from SerializableGeeCollections-TDocument-Test.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */

#include <glib-object.h>
#include <glib.h>
#include <gxml/gxml.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <stdio.h>

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST (serializable_gee_collections_tdocument_test_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST, SerializableGeeCollectionsTDocumentTest))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST, SerializableGeeCollectionsTDocumentTestClass))
#define IS_SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST))
#define IS_SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST, SerializableGeeCollectionsTDocumentTestClass))

typedef struct _SerializableGeeCollectionsTDocumentTest SerializableGeeCollectionsTDocumentTest;
typedef struct _SerializableGeeCollectionsTDocumentTestClass SerializableGeeCollectionsTDocumentTestClass;
typedef struct _SerializableGeeCollectionsTDocumentTestPrivate SerializableGeeCollectionsTDocumentTestPrivate;

#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE_BASE (serializable_gee_collections_tdocument_test_space_base_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE_BASE, SerializableGeeCollectionsTDocumentTestSpaceBase))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE_BASE, SerializableGeeCollectionsTDocumentTestSpaceBaseClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_IS_SPACE_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE_BASE))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_IS_SPACE_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE_BASE))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE_BASE, SerializableGeeCollectionsTDocumentTestSpaceBaseClass))

typedef struct _SerializableGeeCollectionsTDocumentTestSpaceBase SerializableGeeCollectionsTDocumentTestSpaceBase;
typedef struct _SerializableGeeCollectionsTDocumentTestSpaceBaseClass SerializableGeeCollectionsTDocumentTestSpaceBaseClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_CHARGE_ZONE (serializable_gee_collections_tdocument_test_charge_zone_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CHARGE_ZONE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_CHARGE_ZONE, SerializableGeeCollectionsTDocumentTestChargeZone))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CHARGE_ZONE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_CHARGE_ZONE, SerializableGeeCollectionsTDocumentTestChargeZoneClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_IS_CHARGE_ZONE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_CHARGE_ZONE))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_IS_CHARGE_ZONE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_CHARGE_ZONE))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CHARGE_ZONE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_CHARGE_ZONE, SerializableGeeCollectionsTDocumentTestChargeZoneClass))

typedef struct _SerializableGeeCollectionsTDocumentTestChargeZone SerializableGeeCollectionsTDocumentTestChargeZone;
typedef struct _SerializableGeeCollectionsTDocumentTestChargeZoneClass SerializableGeeCollectionsTDocumentTestChargeZoneClass;

#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_TYPE_COLLECTION (serializable_gee_collections_tdocument_test_space_ship_collection_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_TYPE_COLLECTION, SerializableGeeCollectionsTDocumentTestSpaceShipCollection))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_TYPE_COLLECTION, SerializableGeeCollectionsTDocumentTestSpaceShipCollectionClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_TYPE_COLLECTION))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_TYPE_COLLECTION))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_TYPE_COLLECTION, SerializableGeeCollectionsTDocumentTestSpaceShipCollectionClass))

typedef struct _SerializableGeeCollectionsTDocumentTestSpaceShipCollection SerializableGeeCollectionsTDocumentTestSpaceShipCollection;
typedef struct _SerializableGeeCollectionsTDocumentTestSpaceShipCollectionClass SerializableGeeCollectionsTDocumentTestSpaceShipCollectionClass;

#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE_SHIP (serializable_gee_collections_tdocument_test_space_ship_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE_SHIP, SerializableGeeCollectionsTDocumentTestSpaceShip))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE_SHIP, SerializableGeeCollectionsTDocumentTestSpaceShipClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_IS_SPACE_SHIP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE_SHIP))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_IS_SPACE_SHIP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE_SHIP))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE_SHIP, SerializableGeeCollectionsTDocumentTestSpaceShipClass))

typedef struct _SerializableGeeCollectionsTDocumentTestSpaceShip SerializableGeeCollectionsTDocumentTestSpaceShip;
typedef struct _SerializableGeeCollectionsTDocumentTestSpaceShipClass SerializableGeeCollectionsTDocumentTestSpaceShipClass;

#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_TYPE_COLLECTION (serializable_gee_collections_tdocument_test_space_collection_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_TYPE_COLLECTION, SerializableGeeCollectionsTDocumentTestSpaceCollection))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_TYPE_COLLECTION, SerializableGeeCollectionsTDocumentTestSpaceCollectionClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_TYPE_COLLECTION))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_TYPE_COLLECTION))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_TYPE_COLLECTION, SerializableGeeCollectionsTDocumentTestSpaceCollectionClass))

typedef struct _SerializableGeeCollectionsTDocumentTestSpaceCollection SerializableGeeCollectionsTDocumentTestSpaceCollection;
typedef struct _SerializableGeeCollectionsTDocumentTestSpaceCollectionClass SerializableGeeCollectionsTDocumentTestSpaceCollectionClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_STORAGE (serializable_gee_collections_tdocument_test_storage_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_STORAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_STORAGE, SerializableGeeCollectionsTDocumentTestStorage))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_STORAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_STORAGE, SerializableGeeCollectionsTDocumentTestStorageClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_IS_STORAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_STORAGE))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_IS_STORAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_STORAGE))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_STORAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_STORAGE, SerializableGeeCollectionsTDocumentTestStorageClass))

typedef struct _SerializableGeeCollectionsTDocumentTestStorage SerializableGeeCollectionsTDocumentTestStorage;
typedef struct _SerializableGeeCollectionsTDocumentTestStorageClass SerializableGeeCollectionsTDocumentTestStorageClass;

#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_TYPE_COLLECTION (serializable_gee_collections_tdocument_test_refaction_collection_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_TYPE_COLLECTION, SerializableGeeCollectionsTDocumentTestRefactionCollection))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_TYPE_COLLECTION, SerializableGeeCollectionsTDocumentTestRefactionCollectionClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_TYPE_COLLECTION))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_TYPE_COLLECTION))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_TYPE_COLLECTION, SerializableGeeCollectionsTDocumentTestRefactionCollectionClass))

typedef struct _SerializableGeeCollectionsTDocumentTestRefactionCollection SerializableGeeCollectionsTDocumentTestRefactionCollection;
typedef struct _SerializableGeeCollectionsTDocumentTestRefactionCollectionClass SerializableGeeCollectionsTDocumentTestRefactionCollectionClass;

#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_REFACTION (serializable_gee_collections_tdocument_test_refaction_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_REFACTION, SerializableGeeCollectionsTDocumentTestRefaction))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_REFACTION, SerializableGeeCollectionsTDocumentTestRefactionClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_IS_REFACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_REFACTION))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_IS_REFACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_REFACTION))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_REFACTION, SerializableGeeCollectionsTDocumentTestRefactionClass))

typedef struct _SerializableGeeCollectionsTDocumentTestRefaction SerializableGeeCollectionsTDocumentTestRefaction;
typedef struct _SerializableGeeCollectionsTDocumentTestRefactionClass SerializableGeeCollectionsTDocumentTestRefactionClass;

#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_CITIZEN (serializable_gee_collections_tdocument_test_citizen_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_CITIZEN, SerializableGeeCollectionsTDocumentTestCitizen))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_CITIZEN, SerializableGeeCollectionsTDocumentTestCitizenClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_IS_CITIZEN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_CITIZEN))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_IS_CITIZEN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_CITIZEN))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_CITIZEN, SerializableGeeCollectionsTDocumentTestCitizenClass))

typedef struct _SerializableGeeCollectionsTDocumentTestCitizen SerializableGeeCollectionsTDocumentTestCitizen;
typedef struct _SerializableGeeCollectionsTDocumentTestCitizenClass SerializableGeeCollectionsTDocumentTestCitizenClass;
typedef struct _SerializableGeeCollectionsTDocumentTestCitizenPrivate SerializableGeeCollectionsTDocumentTestCitizenPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_CTYPE_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_tdocument_test_citizen_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_NUM_PROPERTIES];

#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_TYPE_ARRAY (serializable_gee_collections_tdocument_test_citizen_array_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_TYPE_ARRAY, SerializableGeeCollectionsTDocumentTestCitizenArray))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_TYPE_ARRAY, SerializableGeeCollectionsTDocumentTestCitizenArrayClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_IS_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_TYPE_ARRAY))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_IS_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_TYPE_ARRAY))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_ARRAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_TYPE_ARRAY, SerializableGeeCollectionsTDocumentTestCitizenArrayClass))

typedef struct _SerializableGeeCollectionsTDocumentTestCitizenArray SerializableGeeCollectionsTDocumentTestCitizenArray;
typedef struct _SerializableGeeCollectionsTDocumentTestCitizenArrayClass SerializableGeeCollectionsTDocumentTestCitizenArrayClass;
typedef struct _SerializableGeeCollectionsTDocumentTestCitizenArrayPrivate SerializableGeeCollectionsTDocumentTestCitizenArrayPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_ARRAY_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_ARRAY_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_tdocument_test_citizen_array_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_ARRAY_NUM_PROPERTIES];

#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_ASTEROID (serializable_gee_collections_tdocument_test_asteroid_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_ASTEROID, SerializableGeeCollectionsTDocumentTestAsteroid))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_ASTEROID, SerializableGeeCollectionsTDocumentTestAsteroidClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_IS_ASTEROID(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_ASTEROID))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_IS_ASTEROID_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_ASTEROID))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_ASTEROID, SerializableGeeCollectionsTDocumentTestAsteroidClass))

typedef struct _SerializableGeeCollectionsTDocumentTestAsteroid SerializableGeeCollectionsTDocumentTestAsteroid;
typedef struct _SerializableGeeCollectionsTDocumentTestAsteroidClass SerializableGeeCollectionsTDocumentTestAsteroidClass;
typedef struct _SerializableGeeCollectionsTDocumentTestAsteroidPrivate SerializableGeeCollectionsTDocumentTestAsteroidPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_SIZE_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_tdocument_test_asteroid_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_NUM_PROPERTIES];

#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_TYPE_ARRAY (serializable_gee_collections_tdocument_test_asteroid_array_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_TYPE_ARRAY, SerializableGeeCollectionsTDocumentTestAsteroidArray))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_TYPE_ARRAY, SerializableGeeCollectionsTDocumentTestAsteroidArrayClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_IS_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_TYPE_ARRAY))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_IS_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_TYPE_ARRAY))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_ARRAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_TYPE_ARRAY, SerializableGeeCollectionsTDocumentTestAsteroidArrayClass))

typedef struct _SerializableGeeCollectionsTDocumentTestAsteroidArray SerializableGeeCollectionsTDocumentTestAsteroidArray;
typedef struct _SerializableGeeCollectionsTDocumentTestAsteroidArrayClass SerializableGeeCollectionsTDocumentTestAsteroidArrayClass;
typedef struct _SerializableGeeCollectionsTDocumentTestAsteroidArrayPrivate SerializableGeeCollectionsTDocumentTestAsteroidArrayPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_ARRAY_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_ARRAY_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_tdocument_test_asteroid_array_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_ARRAY_NUM_PROPERTIES];

#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_PLANET (serializable_gee_collections_tdocument_test_planet_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_PLANET, SerializableGeeCollectionsTDocumentTestPlanet))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_PLANET, SerializableGeeCollectionsTDocumentTestPlanetClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_IS_PLANET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_PLANET))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_IS_PLANET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_PLANET))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_PLANET, SerializableGeeCollectionsTDocumentTestPlanetClass))

typedef struct _SerializableGeeCollectionsTDocumentTestPlanet SerializableGeeCollectionsTDocumentTestPlanet;
typedef struct _SerializableGeeCollectionsTDocumentTestPlanetClass SerializableGeeCollectionsTDocumentTestPlanetClass;
typedef struct _SerializableGeeCollectionsTDocumentTestPlanetPrivate SerializableGeeCollectionsTDocumentTestPlanetPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_NAME_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_CITIZENS_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_tdocument_test_planet_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_NUM_PROPERTIES];

#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_TYPE_COLLECTION (serializable_gee_collections_tdocument_test_planet_collection_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_TYPE_COLLECTION, SerializableGeeCollectionsTDocumentTestPlanetCollection))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_TYPE_COLLECTION, SerializableGeeCollectionsTDocumentTestPlanetCollectionClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_TYPE_COLLECTION))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_TYPE_COLLECTION))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_TYPE_COLLECTION, SerializableGeeCollectionsTDocumentTestPlanetCollectionClass))

typedef struct _SerializableGeeCollectionsTDocumentTestPlanetCollection SerializableGeeCollectionsTDocumentTestPlanetCollection;
typedef struct _SerializableGeeCollectionsTDocumentTestPlanetCollectionClass SerializableGeeCollectionsTDocumentTestPlanetCollectionClass;
typedef struct _SerializableGeeCollectionsTDocumentTestPlanetCollectionPrivate SerializableGeeCollectionsTDocumentTestPlanetCollectionPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_COLLECTION_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_COLLECTION_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_tdocument_test_planet_collection_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_COLLECTION_NUM_PROPERTIES];

#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE (serializable_gee_collections_tdocument_test_space_get_type ())
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE, SerializableGeeCollectionsTDocumentTestSpace))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE, SerializableGeeCollectionsTDocumentTestSpaceClass))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_IS_SPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_IS_SPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE))
#define SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE, SerializableGeeCollectionsTDocumentTestSpaceClass))

typedef struct _SerializableGeeCollectionsTDocumentTestSpace SerializableGeeCollectionsTDocumentTestSpace;
typedef struct _SerializableGeeCollectionsTDocumentTestSpaceClass SerializableGeeCollectionsTDocumentTestSpaceClass;
typedef struct _SerializableGeeCollectionsTDocumentTestSpacePrivate SerializableGeeCollectionsTDocumentTestSpacePrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_NAME_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_PLANETS_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_ASTEROIDS_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_tdocument_test_space_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTDocumentTestSpaceCollectionPrivate SerializableGeeCollectionsTDocumentTestSpaceCollectionPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_COLLECTION_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_COLLECTION_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_tdocument_test_space_collection_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_COLLECTION_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTDocumentTestRefactionPrivate SerializableGeeCollectionsTDocumentTestRefactionPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_MODEL_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_MANUFACTURER_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_SPACESHIPS_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_tdocument_test_refaction_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTDocumentTestRefactionCollectionPrivate SerializableGeeCollectionsTDocumentTestRefactionCollectionPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_COLLECTION_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_COLLECTION_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_tdocument_test_refaction_collection_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_COLLECTION_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTDocumentTestSpaceShipPrivate SerializableGeeCollectionsTDocumentTestSpaceShipPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_MODEL_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_MANUFACTURER_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_SPACES_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_tdocument_test_space_ship_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTDocumentTestSpaceShipCollectionPrivate SerializableGeeCollectionsTDocumentTestSpaceShipCollectionPrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_COLLECTION_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_COLLECTION_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_tdocument_test_space_ship_collection_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_COLLECTION_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTDocumentTestChargeZonePrivate SerializableGeeCollectionsTDocumentTestChargeZonePrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CHARGE_ZONE_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CHARGE_ZONE_NAME_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CHARGE_ZONE_SPACESHIPS_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CHARGE_ZONE_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_tdocument_test_charge_zone_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CHARGE_ZONE_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTDocumentTestStoragePrivate SerializableGeeCollectionsTDocumentTestStoragePrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_STORAGE_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_STORAGE_NAME_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_STORAGE_REFACTIONS_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_STORAGE_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_tdocument_test_storage_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_STORAGE_NUM_PROPERTIES];
typedef struct _SerializableGeeCollectionsTDocumentTestSpaceBasePrivate SerializableGeeCollectionsTDocumentTestSpaceBasePrivate;
enum  {
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE_0_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE_NAME_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE_CHARGE_ZONE_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE_STORAGE_PROPERTY,
	SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE_NUM_PROPERTIES
};
static GParamSpec* serializable_gee_collections_tdocument_test_space_base_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE_NUM_PROPERTIES];
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _SerializableGeeCollectionsTDocumentTest {
	GXmlTest parent_instance;
	SerializableGeeCollectionsTDocumentTestPrivate * priv;
};

struct _SerializableGeeCollectionsTDocumentTestClass {
	GXmlTestClass parent_class;
};

struct _SerializableGeeCollectionsTDocumentTestCitizen {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeCollectionsTDocumentTestCitizenPrivate * priv;
};

struct _SerializableGeeCollectionsTDocumentTestCitizenClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeCollectionsTDocumentTestCitizenPrivate {
	gchar* _ctype;
};

struct _SerializableGeeCollectionsTDocumentTestCitizenArray {
	GXmlSerializableArrayList parent_instance;
	SerializableGeeCollectionsTDocumentTestCitizenArrayPrivate * priv;
};

struct _SerializableGeeCollectionsTDocumentTestCitizenArrayClass {
	GXmlSerializableArrayListClass parent_class;
};

struct _SerializableGeeCollectionsTDocumentTestAsteroid {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeCollectionsTDocumentTestAsteroidPrivate * priv;
};

struct _SerializableGeeCollectionsTDocumentTestAsteroidClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeCollectionsTDocumentTestAsteroidPrivate {
	gint _size;
};

struct _SerializableGeeCollectionsTDocumentTestAsteroidArray {
	GXmlSerializableArrayList parent_instance;
	SerializableGeeCollectionsTDocumentTestAsteroidArrayPrivate * priv;
};

struct _SerializableGeeCollectionsTDocumentTestAsteroidArrayClass {
	GXmlSerializableArrayListClass parent_class;
};

struct _SerializableGeeCollectionsTDocumentTestPlanet {
	GXmlSerializableContainer parent_instance;
	SerializableGeeCollectionsTDocumentTestPlanetPrivate * priv;
};

struct _SerializableGeeCollectionsTDocumentTestPlanetClass {
	GXmlSerializableContainerClass parent_class;
};

struct _SerializableGeeCollectionsTDocumentTestPlanetPrivate {
	gchar* _name;
	SerializableGeeCollectionsTDocumentTestCitizenArray* _citizens;
};

struct _SerializableGeeCollectionsTDocumentTestPlanetCollection {
	GXmlSerializableTreeMap parent_instance;
	SerializableGeeCollectionsTDocumentTestPlanetCollectionPrivate * priv;
};

struct _SerializableGeeCollectionsTDocumentTestPlanetCollectionClass {
	GXmlSerializableTreeMapClass parent_class;
};

struct _SerializableGeeCollectionsTDocumentTestSpace {
	GXmlSerializableContainer parent_instance;
	SerializableGeeCollectionsTDocumentTestSpacePrivate * priv;
};

struct _SerializableGeeCollectionsTDocumentTestSpaceClass {
	GXmlSerializableContainerClass parent_class;
};

struct _SerializableGeeCollectionsTDocumentTestSpacePrivate {
	gchar* _name;
	SerializableGeeCollectionsTDocumentTestPlanetCollection* _planets;
	SerializableGeeCollectionsTDocumentTestAsteroidArray* _asteroids;
};

struct _SerializableGeeCollectionsTDocumentTestSpaceCollection {
	GXmlSerializableTreeMap parent_instance;
	SerializableGeeCollectionsTDocumentTestSpaceCollectionPrivate * priv;
};

struct _SerializableGeeCollectionsTDocumentTestSpaceCollectionClass {
	GXmlSerializableTreeMapClass parent_class;
};

struct _SerializableGeeCollectionsTDocumentTestRefaction {
	GXmlSerializableContainer parent_instance;
	SerializableGeeCollectionsTDocumentTestRefactionPrivate * priv;
};

struct _SerializableGeeCollectionsTDocumentTestRefactionClass {
	GXmlSerializableContainerClass parent_class;
};

struct _SerializableGeeCollectionsTDocumentTestRefactionPrivate {
	gchar* _model;
	gchar* _manufacturer;
	SerializableGeeCollectionsTDocumentTestSpaceShipCollection* _spaceships;
};

struct _SerializableGeeCollectionsTDocumentTestRefactionCollection {
	GXmlSerializableDualKeyMap parent_instance;
	SerializableGeeCollectionsTDocumentTestRefactionCollectionPrivate * priv;
};

struct _SerializableGeeCollectionsTDocumentTestRefactionCollectionClass {
	GXmlSerializableDualKeyMapClass parent_class;
};

struct _SerializableGeeCollectionsTDocumentTestSpaceShip {
	GXmlSerializableContainer parent_instance;
	SerializableGeeCollectionsTDocumentTestSpaceShipPrivate * priv;
};

struct _SerializableGeeCollectionsTDocumentTestSpaceShipClass {
	GXmlSerializableContainerClass parent_class;
};

struct _SerializableGeeCollectionsTDocumentTestSpaceShipPrivate {
	gchar* _model;
	gchar* _manufacturer;
	SerializableGeeCollectionsTDocumentTestSpaceCollection* _spaces;
};

struct _SerializableGeeCollectionsTDocumentTestSpaceShipCollection {
	GXmlSerializableDualKeyMap parent_instance;
	SerializableGeeCollectionsTDocumentTestSpaceShipCollectionPrivate * priv;
};

struct _SerializableGeeCollectionsTDocumentTestSpaceShipCollectionClass {
	GXmlSerializableDualKeyMapClass parent_class;
};

struct _SerializableGeeCollectionsTDocumentTestChargeZone {
	GXmlSerializableContainer parent_instance;
	SerializableGeeCollectionsTDocumentTestChargeZonePrivate * priv;
};

struct _SerializableGeeCollectionsTDocumentTestChargeZoneClass {
	GXmlSerializableContainerClass parent_class;
};

struct _SerializableGeeCollectionsTDocumentTestChargeZonePrivate {
	gchar* _name;
	SerializableGeeCollectionsTDocumentTestSpaceShipCollection* _spaceships;
};

struct _SerializableGeeCollectionsTDocumentTestStorage {
	GXmlSerializableContainer parent_instance;
	SerializableGeeCollectionsTDocumentTestStoragePrivate * priv;
};

struct _SerializableGeeCollectionsTDocumentTestStorageClass {
	GXmlSerializableContainerClass parent_class;
};

struct _SerializableGeeCollectionsTDocumentTestStoragePrivate {
	gchar* _name;
	SerializableGeeCollectionsTDocumentTestRefactionCollection* _refactions;
};

struct _SerializableGeeCollectionsTDocumentTestSpaceBase {
	GXmlSerializableObjectModel parent_instance;
	SerializableGeeCollectionsTDocumentTestSpaceBasePrivate * priv;
};

struct _SerializableGeeCollectionsTDocumentTestSpaceBaseClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializableGeeCollectionsTDocumentTestSpaceBasePrivate {
	gchar* _name;
	SerializableGeeCollectionsTDocumentTestChargeZone* _charge_zone;
	SerializableGeeCollectionsTDocumentTestStorage* _storage;
};

static gpointer serializable_gee_collections_tdocument_test_parent_class = NULL;
static gint SerializableGeeCollectionsTDocumentTestCitizen_private_offset;
static gpointer serializable_gee_collections_tdocument_test_citizen_parent_class = NULL;
static gpointer serializable_gee_collections_tdocument_test_citizen_array_parent_class = NULL;
static gint SerializableGeeCollectionsTDocumentTestAsteroid_private_offset;
static gpointer serializable_gee_collections_tdocument_test_asteroid_parent_class = NULL;
static gpointer serializable_gee_collections_tdocument_test_asteroid_array_parent_class = NULL;
static gint SerializableGeeCollectionsTDocumentTestPlanet_private_offset;
static gpointer serializable_gee_collections_tdocument_test_planet_parent_class = NULL;
static gpointer serializable_gee_collections_tdocument_test_planet_collection_parent_class = NULL;
static GXmlSerializableMapKeyIface * serializable_gee_collections_tdocument_test_planet_gxml_serializable_map_key_parent_iface = NULL;
static gint SerializableGeeCollectionsTDocumentTestSpace_private_offset;
static gpointer serializable_gee_collections_tdocument_test_space_parent_class = NULL;
static gpointer serializable_gee_collections_tdocument_test_space_collection_parent_class = NULL;
static GXmlSerializableMapKeyIface * serializable_gee_collections_tdocument_test_space_gxml_serializable_map_key_parent_iface = NULL;
static gint SerializableGeeCollectionsTDocumentTestRefaction_private_offset;
static gpointer serializable_gee_collections_tdocument_test_refaction_parent_class = NULL;
static gpointer serializable_gee_collections_tdocument_test_refaction_collection_parent_class = NULL;
static GXmlSerializableMapDualKeyIface * serializable_gee_collections_tdocument_test_refaction_gxml_serializable_map_dual_key_parent_iface = NULL;
static gint SerializableGeeCollectionsTDocumentTestSpaceShip_private_offset;
static gpointer serializable_gee_collections_tdocument_test_space_ship_parent_class = NULL;
static gpointer serializable_gee_collections_tdocument_test_space_ship_collection_parent_class = NULL;
static GXmlSerializableMapDualKeyIface * serializable_gee_collections_tdocument_test_space_ship_gxml_serializable_map_dual_key_parent_iface = NULL;
static gint SerializableGeeCollectionsTDocumentTestChargeZone_private_offset;
static gpointer serializable_gee_collections_tdocument_test_charge_zone_parent_class = NULL;
static gint SerializableGeeCollectionsTDocumentTestStorage_private_offset;
static gpointer serializable_gee_collections_tdocument_test_storage_parent_class = NULL;
static gint SerializableGeeCollectionsTDocumentTestSpaceBase_private_offset;
static gpointer serializable_gee_collections_tdocument_test_space_base_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType serializable_gee_collections_tdocument_test_get_type (void) G_GNUC_CONST;
void serializable_gee_collections_tdocument_test_add_tests (void);
static void __lambda323_ (void);
static GType serializable_gee_collections_tdocument_test_space_base_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeCollectionsTDocumentTestSpaceBase* serializable_gee_collections_tdocument_test_space_base_new (void);
static SerializableGeeCollectionsTDocumentTestSpaceBase* serializable_gee_collections_tdocument_test_space_base_construct (GType object_type);
static GType serializable_gee_collections_tdocument_test_charge_zone_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeCollectionsTDocumentTestChargeZone* serializable_gee_collections_tdocument_test_space_base_get_charge_zone (SerializableGeeCollectionsTDocumentTestSpaceBase* self);
GType serializable_gee_collections_tdocument_test_space_ship_collection_get_type (void) G_GNUC_CONST;
static SerializableGeeCollectionsTDocumentTestSpaceShipCollection* serializable_gee_collections_tdocument_test_charge_zone_get_spaceships (SerializableGeeCollectionsTDocumentTestChargeZone* self);
static GType serializable_gee_collections_tdocument_test_space_ship_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
GType serializable_gee_collections_tdocument_test_space_collection_get_type (void) G_GNUC_CONST;
static SerializableGeeCollectionsTDocumentTestSpaceCollection* serializable_gee_collections_tdocument_test_space_ship_get_spaces (SerializableGeeCollectionsTDocumentTestSpaceShip* self);
static void ___lambda323__gtest_func (void);
static void __lambda324_ (void);
static GType serializable_gee_collections_tdocument_test_storage_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeCollectionsTDocumentTestStorage* serializable_gee_collections_tdocument_test_space_base_get_storage (SerializableGeeCollectionsTDocumentTestSpaceBase* self);
GType serializable_gee_collections_tdocument_test_refaction_collection_get_type (void) G_GNUC_CONST;
static SerializableGeeCollectionsTDocumentTestRefactionCollection* serializable_gee_collections_tdocument_test_storage_get_refactions (SerializableGeeCollectionsTDocumentTestStorage* self);
static GType serializable_gee_collections_tdocument_test_refaction_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static void ___lambda324__gtest_func (void);
SerializableGeeCollectionsTDocumentTest* serializable_gee_collections_tdocument_test_new (void);
SerializableGeeCollectionsTDocumentTest* serializable_gee_collections_tdocument_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static GType serializable_gee_collections_tdocument_test_citizen_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static gboolean serializable_gee_collections_tdocument_test_citizen_real_serialize_use_xml_node_value (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_collections_tdocument_test_citizen_real_to_string (GXmlSerializableObjectModel* base);
static const gchar* serializable_gee_collections_tdocument_test_citizen_get_ctype (SerializableGeeCollectionsTDocumentTestCitizen* self);
static gchar* serializable_gee_collections_tdocument_test_citizen_real_node_name (GXmlSerializableObjectModel* base);
static SerializableGeeCollectionsTDocumentTestCitizen* serializable_gee_collections_tdocument_test_citizen_new (void);
static SerializableGeeCollectionsTDocumentTestCitizen* serializable_gee_collections_tdocument_test_citizen_construct (GType object_type);
static void serializable_gee_collections_tdocument_test_citizen_set_ctype (SerializableGeeCollectionsTDocumentTestCitizen* self,
                                                                    const gchar* value);
GType serializable_gee_collections_tdocument_test_citizen_array_get_type (void) G_GNUC_CONST;
static SerializableGeeCollectionsTDocumentTestCitizenArray* serializable_gee_collections_tdocument_test_citizen_array_new (void);
static SerializableGeeCollectionsTDocumentTestCitizenArray* serializable_gee_collections_tdocument_test_citizen_array_construct (GType object_type);
static void serializable_gee_collections_tdocument_test_citizen_finalize (GObject * obj);
static void _vala_serializable_gee_collections_tdocument_test_citizen_get_property (GObject * object,
                                                                             guint property_id,
                                                                             GValue * value,
                                                                             GParamSpec * pspec);
static void _vala_serializable_gee_collections_tdocument_test_citizen_set_property (GObject * object,
                                                                             guint property_id,
                                                                             const GValue * value,
                                                                             GParamSpec * pspec);
static GType serializable_gee_collections_tdocument_test_asteroid_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static SerializableGeeCollectionsTDocumentTestAsteroid* serializable_gee_collections_tdocument_test_asteroid_new_with_size (gint size);
static SerializableGeeCollectionsTDocumentTestAsteroid* serializable_gee_collections_tdocument_test_asteroid_construct_with_size (GType object_type,
                                                                                                                           gint size);
static void serializable_gee_collections_tdocument_test_asteroid_set_size (SerializableGeeCollectionsTDocumentTestAsteroid* self,
                                                                    gint value);
static gchar* serializable_gee_collections_tdocument_test_asteroid_real_to_string (GXmlSerializableObjectModel* base);
static gint serializable_gee_collections_tdocument_test_asteroid_get_size (SerializableGeeCollectionsTDocumentTestAsteroid* self);
static gchar* serializable_gee_collections_tdocument_test_asteroid_real_node_name (GXmlSerializableObjectModel* base);
static SerializableGeeCollectionsTDocumentTestAsteroid* serializable_gee_collections_tdocument_test_asteroid_new (void);
static SerializableGeeCollectionsTDocumentTestAsteroid* serializable_gee_collections_tdocument_test_asteroid_construct (GType object_type);
GType serializable_gee_collections_tdocument_test_asteroid_array_get_type (void) G_GNUC_CONST;
static SerializableGeeCollectionsTDocumentTestAsteroidArray* serializable_gee_collections_tdocument_test_asteroid_array_new (void);
static SerializableGeeCollectionsTDocumentTestAsteroidArray* serializable_gee_collections_tdocument_test_asteroid_array_construct (GType object_type);
static void serializable_gee_collections_tdocument_test_asteroid_finalize (GObject * obj);
static void _vala_serializable_gee_collections_tdocument_test_asteroid_get_property (GObject * object,
                                                                              guint property_id,
                                                                              GValue * value,
                                                                              GParamSpec * pspec);
static void _vala_serializable_gee_collections_tdocument_test_asteroid_set_property (GObject * object,
                                                                              guint property_id,
                                                                              const GValue * value,
                                                                              GParamSpec * pspec);
static GType serializable_gee_collections_tdocument_test_planet_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static gchar* serializable_gee_collections_tdocument_test_planet_real_get_map_key (GXmlSerializableMapKey* base);
static const gchar* serializable_gee_collections_tdocument_test_planet_get_name (SerializableGeeCollectionsTDocumentTestPlanet* self);
static SerializableGeeCollectionsTDocumentTestPlanet* serializable_gee_collections_tdocument_test_planet_new_named (const gchar* name);
static SerializableGeeCollectionsTDocumentTestPlanet* serializable_gee_collections_tdocument_test_planet_construct_named (GType object_type,
                                                                                                                   const gchar* name);
static void serializable_gee_collections_tdocument_test_planet_set_name (SerializableGeeCollectionsTDocumentTestPlanet* self,
                                                                  const gchar* value);
static gchar* serializable_gee_collections_tdocument_test_planet_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_collections_tdocument_test_planet_real_to_string (GXmlSerializableObjectModel* base);
static void serializable_gee_collections_tdocument_test_planet_real_init_containers (GXmlSerializableContainer* base);
static SerializableGeeCollectionsTDocumentTestCitizenArray* serializable_gee_collections_tdocument_test_planet_get_citizens (SerializableGeeCollectionsTDocumentTestPlanet* self);
static void serializable_gee_collections_tdocument_test_planet_set_citizens (SerializableGeeCollectionsTDocumentTestPlanet* self,
                                                                      SerializableGeeCollectionsTDocumentTestCitizenArray* value);
static SerializableGeeCollectionsTDocumentTestPlanet* serializable_gee_collections_tdocument_test_planet_new (void);
static SerializableGeeCollectionsTDocumentTestPlanet* serializable_gee_collections_tdocument_test_planet_construct (GType object_type);
GType serializable_gee_collections_tdocument_test_planet_collection_get_type (void) G_GNUC_CONST;
static SerializableGeeCollectionsTDocumentTestPlanetCollection* serializable_gee_collections_tdocument_test_planet_collection_new (void);
static SerializableGeeCollectionsTDocumentTestPlanetCollection* serializable_gee_collections_tdocument_test_planet_collection_construct (GType object_type);
static void serializable_gee_collections_tdocument_test_planet_finalize (GObject * obj);
static void _vala_serializable_gee_collections_tdocument_test_planet_get_property (GObject * object,
                                                                            guint property_id,
                                                                            GValue * value,
                                                                            GParamSpec * pspec);
static void _vala_serializable_gee_collections_tdocument_test_planet_set_property (GObject * object,
                                                                            guint property_id,
                                                                            const GValue * value,
                                                                            GParamSpec * pspec);
static GType serializable_gee_collections_tdocument_test_space_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static gchar* serializable_gee_collections_tdocument_test_space_real_get_map_key (GXmlSerializableMapKey* base);
static const gchar* serializable_gee_collections_tdocument_test_space_get_name (SerializableGeeCollectionsTDocumentTestSpace* self);
static SerializableGeeCollectionsTDocumentTestSpace* serializable_gee_collections_tdocument_test_space_new_named (const gchar* name);
static SerializableGeeCollectionsTDocumentTestSpace* serializable_gee_collections_tdocument_test_space_construct_named (GType object_type,
                                                                                                                 const gchar* name);
static void serializable_gee_collections_tdocument_test_space_set_name (SerializableGeeCollectionsTDocumentTestSpace* self,
                                                                 const gchar* value);
static gchar* serializable_gee_collections_tdocument_test_space_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_collections_tdocument_test_space_real_to_string (GXmlSerializableObjectModel* base);
static void serializable_gee_collections_tdocument_test_space_real_init_containers (GXmlSerializableContainer* base);
static SerializableGeeCollectionsTDocumentTestAsteroidArray* serializable_gee_collections_tdocument_test_space_get_asteroids (SerializableGeeCollectionsTDocumentTestSpace* self);
static void serializable_gee_collections_tdocument_test_space_set_asteroids (SerializableGeeCollectionsTDocumentTestSpace* self,
                                                                      SerializableGeeCollectionsTDocumentTestAsteroidArray* value);
static SerializableGeeCollectionsTDocumentTestPlanetCollection* serializable_gee_collections_tdocument_test_space_get_planets (SerializableGeeCollectionsTDocumentTestSpace* self);
static void serializable_gee_collections_tdocument_test_space_set_planets (SerializableGeeCollectionsTDocumentTestSpace* self,
                                                                    SerializableGeeCollectionsTDocumentTestPlanetCollection* value);
static SerializableGeeCollectionsTDocumentTestSpace* serializable_gee_collections_tdocument_test_space_new (void);
static SerializableGeeCollectionsTDocumentTestSpace* serializable_gee_collections_tdocument_test_space_construct (GType object_type);
static SerializableGeeCollectionsTDocumentTestSpaceCollection* serializable_gee_collections_tdocument_test_space_collection_new (void);
static SerializableGeeCollectionsTDocumentTestSpaceCollection* serializable_gee_collections_tdocument_test_space_collection_construct (GType object_type);
static void serializable_gee_collections_tdocument_test_space_finalize (GObject * obj);
static void _vala_serializable_gee_collections_tdocument_test_space_get_property (GObject * object,
                                                                           guint property_id,
                                                                           GValue * value,
                                                                           GParamSpec * pspec);
static void _vala_serializable_gee_collections_tdocument_test_space_set_property (GObject * object,
                                                                           guint property_id,
                                                                           const GValue * value,
                                                                           GParamSpec * pspec);
static SerializableGeeCollectionsTDocumentTestRefaction* serializable_gee_collections_tdocument_test_refaction_new_named (const gchar* manufacturer,
                                                                                                                   const gchar* model);
static SerializableGeeCollectionsTDocumentTestRefaction* serializable_gee_collections_tdocument_test_refaction_construct_named (GType object_type,
                                                                                                                         const gchar* manufacturer,
                                                                                                                         const gchar* model);
static void serializable_gee_collections_tdocument_test_refaction_set_manufacturer (SerializableGeeCollectionsTDocumentTestRefaction* self,
                                                                             const gchar* value);
static void serializable_gee_collections_tdocument_test_refaction_set_model (SerializableGeeCollectionsTDocumentTestRefaction* self,
                                                                      const gchar* value);
static gchar* serializable_gee_collections_tdocument_test_refaction_real_get_map_primary_key (GXmlSerializableMapDualKey* base);
static const gchar* serializable_gee_collections_tdocument_test_refaction_get_manufacturer (SerializableGeeCollectionsTDocumentTestRefaction* self);
static gchar* serializable_gee_collections_tdocument_test_refaction_real_get_map_secondary_key (GXmlSerializableMapDualKey* base);
static const gchar* serializable_gee_collections_tdocument_test_refaction_get_model (SerializableGeeCollectionsTDocumentTestRefaction* self);
static gchar* serializable_gee_collections_tdocument_test_refaction_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_collections_tdocument_test_refaction_real_to_string (GXmlSerializableObjectModel* base);
static gboolean serializable_gee_collections_tdocument_test_refaction_real_get_enable_unknown_serializable_property (GXmlSerializableObjectModel* base);
static void serializable_gee_collections_tdocument_test_refaction_real_init_containers (GXmlSerializableContainer* base);
static SerializableGeeCollectionsTDocumentTestSpaceShipCollection* serializable_gee_collections_tdocument_test_refaction_get_spaceships (SerializableGeeCollectionsTDocumentTestRefaction* self);
static SerializableGeeCollectionsTDocumentTestSpaceShipCollection* serializable_gee_collections_tdocument_test_space_ship_collection_new (void);
static SerializableGeeCollectionsTDocumentTestSpaceShipCollection* serializable_gee_collections_tdocument_test_space_ship_collection_construct (GType object_type);
static void serializable_gee_collections_tdocument_test_refaction_set_spaceships (SerializableGeeCollectionsTDocumentTestRefaction* self,
                                                                           SerializableGeeCollectionsTDocumentTestSpaceShipCollection* value);
static SerializableGeeCollectionsTDocumentTestRefaction* serializable_gee_collections_tdocument_test_refaction_new (void);
static SerializableGeeCollectionsTDocumentTestRefaction* serializable_gee_collections_tdocument_test_refaction_construct (GType object_type);
static SerializableGeeCollectionsTDocumentTestRefactionCollection* serializable_gee_collections_tdocument_test_refaction_collection_new (void);
static SerializableGeeCollectionsTDocumentTestRefactionCollection* serializable_gee_collections_tdocument_test_refaction_collection_construct (GType object_type);
static void serializable_gee_collections_tdocument_test_refaction_finalize (GObject * obj);
static void _vala_serializable_gee_collections_tdocument_test_refaction_get_property (GObject * object,
                                                                               guint property_id,
                                                                               GValue * value,
                                                                               GParamSpec * pspec);
static void _vala_serializable_gee_collections_tdocument_test_refaction_set_property (GObject * object,
                                                                               guint property_id,
                                                                               const GValue * value,
                                                                               GParamSpec * pspec);
static SerializableGeeCollectionsTDocumentTestSpaceShip* serializable_gee_collections_tdocument_test_space_ship_new_named (const gchar* manufacturer,
                                                                                                                    const gchar* model);
static SerializableGeeCollectionsTDocumentTestSpaceShip* serializable_gee_collections_tdocument_test_space_ship_construct_named (GType object_type,
                                                                                                                          const gchar* manufacturer,
                                                                                                                          const gchar* model);
static void serializable_gee_collections_tdocument_test_space_ship_set_manufacturer (SerializableGeeCollectionsTDocumentTestSpaceShip* self,
                                                                              const gchar* value);
static void serializable_gee_collections_tdocument_test_space_ship_set_model (SerializableGeeCollectionsTDocumentTestSpaceShip* self,
                                                                       const gchar* value);
static gchar* serializable_gee_collections_tdocument_test_space_ship_real_get_map_primary_key (GXmlSerializableMapDualKey* base);
static const gchar* serializable_gee_collections_tdocument_test_space_ship_get_manufacturer (SerializableGeeCollectionsTDocumentTestSpaceShip* self);
static gchar* serializable_gee_collections_tdocument_test_space_ship_real_get_map_secondary_key (GXmlSerializableMapDualKey* base);
static const gchar* serializable_gee_collections_tdocument_test_space_ship_get_model (SerializableGeeCollectionsTDocumentTestSpaceShip* self);
static gchar* serializable_gee_collections_tdocument_test_space_ship_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_collections_tdocument_test_space_ship_real_to_string (GXmlSerializableObjectModel* base);
static gboolean serializable_gee_collections_tdocument_test_space_ship_real_get_enable_unknown_serializable_property (GXmlSerializableObjectModel* base);
static void serializable_gee_collections_tdocument_test_space_ship_real_init_containers (GXmlSerializableContainer* base);
static void serializable_gee_collections_tdocument_test_space_ship_set_spaces (SerializableGeeCollectionsTDocumentTestSpaceShip* self,
                                                                        SerializableGeeCollectionsTDocumentTestSpaceCollection* value);
static SerializableGeeCollectionsTDocumentTestSpaceShip* serializable_gee_collections_tdocument_test_space_ship_new (void);
static SerializableGeeCollectionsTDocumentTestSpaceShip* serializable_gee_collections_tdocument_test_space_ship_construct (GType object_type);
static void serializable_gee_collections_tdocument_test_space_ship_finalize (GObject * obj);
static void _vala_serializable_gee_collections_tdocument_test_space_ship_get_property (GObject * object,
                                                                                guint property_id,
                                                                                GValue * value,
                                                                                GParamSpec * pspec);
static void _vala_serializable_gee_collections_tdocument_test_space_ship_set_property (GObject * object,
                                                                                guint property_id,
                                                                                const GValue * value,
                                                                                GParamSpec * pspec);
static gchar* serializable_gee_collections_tdocument_test_charge_zone_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_collections_tdocument_test_charge_zone_real_to_string (GXmlSerializableObjectModel* base);
static const gchar* serializable_gee_collections_tdocument_test_charge_zone_get_name (SerializableGeeCollectionsTDocumentTestChargeZone* self);
static void serializable_gee_collections_tdocument_test_charge_zone_real_init_containers (GXmlSerializableContainer* base);
static void serializable_gee_collections_tdocument_test_charge_zone_set_spaceships (SerializableGeeCollectionsTDocumentTestChargeZone* self,
                                                                             SerializableGeeCollectionsTDocumentTestSpaceShipCollection* value);
static SerializableGeeCollectionsTDocumentTestChargeZone* serializable_gee_collections_tdocument_test_charge_zone_new (void);
static SerializableGeeCollectionsTDocumentTestChargeZone* serializable_gee_collections_tdocument_test_charge_zone_construct (GType object_type);
static void serializable_gee_collections_tdocument_test_charge_zone_set_name (SerializableGeeCollectionsTDocumentTestChargeZone* self,
                                                                       const gchar* value);
static void serializable_gee_collections_tdocument_test_charge_zone_finalize (GObject * obj);
static void _vala_serializable_gee_collections_tdocument_test_charge_zone_get_property (GObject * object,
                                                                                 guint property_id,
                                                                                 GValue * value,
                                                                                 GParamSpec * pspec);
static void _vala_serializable_gee_collections_tdocument_test_charge_zone_set_property (GObject * object,
                                                                                 guint property_id,
                                                                                 const GValue * value,
                                                                                 GParamSpec * pspec);
static gchar* serializable_gee_collections_tdocument_test_storage_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_collections_tdocument_test_storage_real_to_string (GXmlSerializableObjectModel* base);
static const gchar* serializable_gee_collections_tdocument_test_storage_get_name (SerializableGeeCollectionsTDocumentTestStorage* self);
static void serializable_gee_collections_tdocument_test_storage_real_init_containers (GXmlSerializableContainer* base);
static void serializable_gee_collections_tdocument_test_storage_set_refactions (SerializableGeeCollectionsTDocumentTestStorage* self,
                                                                         SerializableGeeCollectionsTDocumentTestRefactionCollection* value);
static SerializableGeeCollectionsTDocumentTestStorage* serializable_gee_collections_tdocument_test_storage_new (void);
static SerializableGeeCollectionsTDocumentTestStorage* serializable_gee_collections_tdocument_test_storage_construct (GType object_type);
static void serializable_gee_collections_tdocument_test_storage_set_name (SerializableGeeCollectionsTDocumentTestStorage* self,
                                                                   const gchar* value);
static void serializable_gee_collections_tdocument_test_storage_finalize (GObject * obj);
static void _vala_serializable_gee_collections_tdocument_test_storage_get_property (GObject * object,
                                                                             guint property_id,
                                                                             GValue * value,
                                                                             GParamSpec * pspec);
static void _vala_serializable_gee_collections_tdocument_test_storage_set_property (GObject * object,
                                                                             guint property_id,
                                                                             const GValue * value,
                                                                             GParamSpec * pspec);
static gchar* serializable_gee_collections_tdocument_test_space_base_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_gee_collections_tdocument_test_space_base_real_to_string (GXmlSerializableObjectModel* base);
static const gchar* serializable_gee_collections_tdocument_test_space_base_get_name (SerializableGeeCollectionsTDocumentTestSpaceBase* self);
static void serializable_gee_collections_tdocument_test_space_base_set_name (SerializableGeeCollectionsTDocumentTestSpaceBase* self,
                                                                      const gchar* value);
static void serializable_gee_collections_tdocument_test_space_base_set_charge_zone (SerializableGeeCollectionsTDocumentTestSpaceBase* self,
                                                                             SerializableGeeCollectionsTDocumentTestChargeZone* value);
static void serializable_gee_collections_tdocument_test_space_base_set_storage (SerializableGeeCollectionsTDocumentTestSpaceBase* self,
                                                                         SerializableGeeCollectionsTDocumentTestStorage* value);
static void serializable_gee_collections_tdocument_test_space_base_finalize (GObject * obj);
static void _vala_serializable_gee_collections_tdocument_test_space_base_get_property (GObject * object,
                                                                                guint property_id,
                                                                                GValue * value,
                                                                                GParamSpec * pspec);
static void _vala_serializable_gee_collections_tdocument_test_space_base_set_property (GObject * object,
                                                                                guint property_id,
                                                                                const GValue * value,
                                                                                GParamSpec * pspec);

static void
__lambda323_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		SerializableGeeCollectionsTDocumentTestSpaceBase* sb = NULL;
		SerializableGeeCollectionsTDocumentTestSpaceBase* _tmp1_;
		SerializableGeeCollectionsTDocumentTestSpaceBase* _tmp2_;
		GXmlGDocument* _tmp3_;
		SerializableGeeCollectionsTDocumentTestSpaceBase* _tmp4_;
		SerializableGeeCollectionsTDocumentTestChargeZone* _tmp5_;
		SerializableGeeCollectionsTDocumentTestChargeZone* _tmp6_;
		SerializableGeeCollectionsTDocumentTestSpaceBase* _tmp7_;
		SerializableGeeCollectionsTDocumentTestChargeZone* _tmp8_;
		SerializableGeeCollectionsTDocumentTestChargeZone* _tmp9_;
		SerializableGeeCollectionsTDocumentTestSpaceShipCollection* _tmp10_;
		SerializableGeeCollectionsTDocumentTestSpaceShipCollection* _tmp11_;
		SerializableGeeCollectionsTDocumentTestSpaceBase* _tmp12_;
		SerializableGeeCollectionsTDocumentTestChargeZone* _tmp13_;
		SerializableGeeCollectionsTDocumentTestChargeZone* _tmp14_;
		SerializableGeeCollectionsTDocumentTestSpaceShipCollection* _tmp15_;
		SerializableGeeCollectionsTDocumentTestSpaceShipCollection* _tmp16_;
		gint _tmp17_;
		gint _tmp18_;
		SerializableGeeCollectionsTDocumentTestSpaceShip* sbsh1 = NULL;
		SerializableGeeCollectionsTDocumentTestSpaceBase* _tmp19_;
		SerializableGeeCollectionsTDocumentTestChargeZone* _tmp20_;
		SerializableGeeCollectionsTDocumentTestChargeZone* _tmp21_;
		SerializableGeeCollectionsTDocumentTestSpaceShipCollection* _tmp22_;
		SerializableGeeCollectionsTDocumentTestSpaceShipCollection* _tmp23_;
		gpointer _tmp24_;
		SerializableGeeCollectionsTDocumentTestSpaceShip* _tmp25_;
		SerializableGeeCollectionsTDocumentTestSpaceShip* _tmp26_;
		SerializableGeeCollectionsTDocumentTestSpaceCollection* _tmp27_;
		SerializableGeeCollectionsTDocumentTestSpaceCollection* _tmp28_;
		SerializableGeeCollectionsTDocumentTestSpaceShip* _tmp29_;
		SerializableGeeCollectionsTDocumentTestSpaceCollection* _tmp30_;
		SerializableGeeCollectionsTDocumentTestSpaceCollection* _tmp31_;
		gint _tmp32_;
		gint _tmp33_;
		GXmlTDocument* ndoc = NULL;
		GXmlTDocument* _tmp34_;
		SerializableGeeCollectionsTDocumentTestSpaceBase* _tmp35_;
		GXmlTDocument* _tmp36_;
		GXmlNode* _tmp37_;
		GXmlNode* _tmp38_;
		GXmlTDocument* _tmp39_;
		GXmlNode* _tmp40_;
		GXmlNode* _tmp41_;
		GXmlNode* _tmp42_;
		GXmlTDocument* _tmp43_;
		GXmlNode* _tmp44_;
		GXmlNode* _tmp45_;
		GXmlNode* _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
		gchar* _tmp49_;
		GXmlTDocument* _tmp50_;
		GXmlNode* _tmp51_;
		GXmlNode* _tmp52_;
		GXmlNode* _tmp53_;
		GeeBidirList* _tmp54_;
		GeeBidirList* _tmp55_;
		GeeBidirList* _tmp56_;
		gint _tmp57_;
		gint _tmp58_;
		GXmlNode* cz = NULL;
		GXmlTDocument* _tmp59_;
		GXmlNode* _tmp60_;
		GXmlNode* _tmp61_;
		GXmlNode* _tmp62_;
		GeeBidirList* _tmp63_;
		GeeBidirList* _tmp64_;
		GeeBidirList* _tmp65_;
		gpointer _tmp66_;
		GXmlNode* _tmp67_;
		GXmlNode* _tmp68_;
		GXmlNode* _tmp69_;
		gchar* _tmp70_;
		gchar* _tmp71_;
		gchar* _tmp72_;
		gchar* _tmp73_;
		gchar* _tmp74_;
		GXmlNode* _tmp75_;
		GeeMap* _tmp76_;
		GeeMap* _tmp77_;
		GeeMap* _tmp78_;
		gpointer _tmp79_;
		GXmlNode* _tmp80_;
		gchar* _tmp81_;
		gchar* _tmp82_;
		gchar* _tmp83_;
		GXmlNode* _tmp84_;
		GeeBidirList* _tmp85_;
		GeeBidirList* _tmp86_;
		GeeBidirList* _tmp87_;
		gint _tmp88_;
		gint _tmp89_;
		gboolean fmactoy = FALSE;
		gboolean fmemphis = FALSE;
		GXmlNode* st = NULL;
		GXmlTDocument* _tmp621_;
		GXmlNode* _tmp622_;
		GXmlNode* _tmp623_;
		GXmlNode* _tmp624_;
		GeeBidirList* _tmp625_;
		GeeBidirList* _tmp626_;
		GeeBidirList* _tmp627_;
		gpointer _tmp628_;
		GXmlNode* _tmp629_;
		GXmlNode* _tmp630_;
		GXmlNode* _tmp631_;
		gchar* _tmp632_;
		gchar* _tmp633_;
		gchar* _tmp634_;
		gchar* _tmp635_;
		gchar* _tmp636_;
		GXmlNode* _tmp637_;
		GeeMap* _tmp638_;
		GeeMap* _tmp639_;
		GeeMap* _tmp640_;
		gpointer _tmp641_;
		GXmlNode* _tmp642_;
		gchar* _tmp643_;
		gchar* _tmp644_;
		gchar* _tmp645_;
		GXmlNode* _tmp646_;
		GeeBidirList* _tmp647_;
		GeeBidirList* _tmp648_;
		GeeBidirList* _tmp649_;
		gint _tmp650_;
		gint _tmp651_;
		gboolean fr = FALSE;
#line 182 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"<base name=\"AlphaOne\" >\n" \
"  <chargezone name=\"A1-1\">\n" \
"    <ship manufacturer=\"MacToy\" model=\"A1234\">\n" \
"      <space name=\"Alpha Centaury\">\n" \
"        <planet name=\"Earth\">\n" \
"          <citizen ctype=\"Human\">1M</citizen>\n" \
"          <citizen ctype=\"Ghost\">10M</citizen>\n" \
"        </planet>\n" \
"        <planet name=\"Platon\" />\n" \
"      </space>\n" \
"      <space name=\"Galax\">\n" \
"        <planet name=\"Saminon\">\n" \
"          <citizen ctype=\"Humanes\">100M</citizen>\n" \
"          <citizen ctype=\"Jeties\">1000M</citizen>\n" \
"        </planet>\n" \
"        <planet name=\"Platon\" />\n" \
"      </space>\n" \
"    </ship>\n" \
"    <ship manufacturer=\"Memphis\" model=\"AB1\">\n" \
"      <space name=\"Beta Centaury\">\n" \
"        <planet name=\"Tronex\">\n" \
"          <citizen ctype=\"Human\">10000M</citizen>\n" \
"          <citizen ctype=\"Cat\">100000M</citizen>\n" \
"        </planet>\n" \
"        <planet name=\"Palax\" />\n" \
"      </space>\n" \
"    </ship>\n" \
"  </chargezone>\n" \
"  <storage name=\"B4-A4\">\n" \
"    <refaction manufacturer=\"MacToy\" model=\"Fly045\">\n" \
"      <ship manufacturer=\"MacToy\" model=\"A1234\" />\n" \
"      <ship manufacturer=\"MegaTrench\" model=\"G045-1\" />\n" \
"    </refaction>\n" \
"  </storage>\n" \
"</base>", 0, &_inner_error0_);
#line 182 "SerializableGeeCollections-TDocument-Test.vala"
		doc = _tmp0_;
#line 182 "SerializableGeeCollections-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 939 "SerializableGeeCollections-TDocument-Test.c"
			goto __catch373_g_error;
		}
#line 218 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp1_ = serializable_gee_collections_tdocument_test_space_base_new ();
#line 218 "SerializableGeeCollections-TDocument-Test.vala"
		sb = _tmp1_;
#line 220 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp2_ = sb;
#line 220 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp3_ = doc;
#line 220 "SerializableGeeCollections-TDocument-Test.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 220 "SerializableGeeCollections-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 220 "SerializableGeeCollections-TDocument-Test.vala"
			_g_object_unref0 (sb);
#line 220 "SerializableGeeCollections-TDocument-Test.vala"
			_g_object_unref0 (doc);
#line 958 "SerializableGeeCollections-TDocument-Test.c"
			goto __catch373_g_error;
		}
#line 221 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp4_ = sb;
#line 221 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp5_ = serializable_gee_collections_tdocument_test_space_base_get_charge_zone (_tmp4_);
#line 221 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp6_ = _tmp5_;
#line 221 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (_tmp6_ != NULL, "sb.charge_zone != null");
#line 222 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp7_ = sb;
#line 222 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp8_ = serializable_gee_collections_tdocument_test_space_base_get_charge_zone (_tmp7_);
#line 222 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp9_ = _tmp8_;
#line 222 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp10_ = serializable_gee_collections_tdocument_test_charge_zone_get_spaceships (_tmp9_);
#line 222 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp11_ = _tmp10_;
#line 222 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (_tmp11_ != NULL, "sb.charge_zone.spaceships != null");
#line 223 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp12_ = sb;
#line 223 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp13_ = serializable_gee_collections_tdocument_test_space_base_get_charge_zone (_tmp12_);
#line 223 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp14_ = _tmp13_;
#line 223 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp15_ = serializable_gee_collections_tdocument_test_charge_zone_get_spaceships (_tmp14_);
#line 223 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp16_ = _tmp15_;
#line 223 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp17_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp16_);
#line 223 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp18_ = _tmp17_;
#line 223 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (_tmp18_ == 2, "sb.charge_zone.spaceships.size == 2");
#line 224 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp19_ = sb;
#line 224 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp20_ = serializable_gee_collections_tdocument_test_space_base_get_charge_zone (_tmp19_);
#line 224 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp21_ = _tmp20_;
#line 224 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp22_ = serializable_gee_collections_tdocument_test_charge_zone_get_spaceships (_tmp21_);
#line 224 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp23_ = _tmp22_;
#line 224 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp24_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp23_, "MacToy", "A1234");
#line 224 "SerializableGeeCollections-TDocument-Test.vala"
		sbsh1 = (SerializableGeeCollectionsTDocumentTestSpaceShip*) _tmp24_;
#line 225 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp25_ = sbsh1;
#line 225 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (_tmp25_ != NULL, "sbsh1 != null");
#line 226 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp26_ = sbsh1;
#line 226 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp27_ = serializable_gee_collections_tdocument_test_space_ship_get_spaces (_tmp26_);
#line 226 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp28_ = _tmp27_;
#line 226 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (_tmp28_ != NULL, "sbsh1.spaces != null");
#line 227 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp29_ = sbsh1;
#line 227 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp30_ = serializable_gee_collections_tdocument_test_space_ship_get_spaces (_tmp29_);
#line 227 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp31_ = _tmp30_;
#line 227 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp32_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp31_);
#line 227 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp33_ = _tmp32_;
#line 227 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (_tmp33_ == 2, "sbsh1.spaces.size == 2");
#line 229 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp34_ = gxml_tdocument_new ();
#line 229 "SerializableGeeCollections-TDocument-Test.vala"
		ndoc = _tmp34_;
#line 230 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp35_ = sb;
#line 230 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp36_ = ndoc;
#line 230 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp37_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp35_, (GXmlNode*) _tmp36_, &_inner_error0_);
#line 230 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp38_ = _tmp37_;
#line 230 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp38_);
#line 230 "SerializableGeeCollections-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 230 "SerializableGeeCollections-TDocument-Test.vala"
			_g_object_unref0 (ndoc);
#line 230 "SerializableGeeCollections-TDocument-Test.vala"
			_g_object_unref0 (sbsh1);
#line 230 "SerializableGeeCollections-TDocument-Test.vala"
			_g_object_unref0 (sb);
#line 230 "SerializableGeeCollections-TDocument-Test.vala"
			_g_object_unref0 (doc);
#line 1059 "SerializableGeeCollections-TDocument-Test.c"
			goto __catch373_g_error;
		}
#line 231 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp39_ = ndoc;
#line 231 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp40_ = gxml_document_get_root ((GXmlDocument*) _tmp39_);
#line 231 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp41_ = _tmp40_;
#line 231 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp42_ = _tmp41_;
#line 231 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (_tmp42_ != NULL, "ndoc.root != null");
#line 231 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp42_);
#line 232 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp43_ = ndoc;
#line 232 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp44_ = gxml_document_get_root ((GXmlDocument*) _tmp43_);
#line 232 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp45_ = _tmp44_;
#line 232 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp46_ = _tmp45_;
#line 232 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp47_ = gxml_node_get_name (_tmp46_);
#line 232 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp48_ = _tmp47_;
#line 232 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp49_ = _tmp48_;
#line 232 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (g_strcmp0 (_tmp49_, "base") == 0, "ndoc.root.name == \"base\"");
#line 232 "SerializableGeeCollections-TDocument-Test.vala"
		_g_free0 (_tmp49_);
#line 232 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp46_);
#line 233 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp50_ = ndoc;
#line 233 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp51_ = gxml_document_get_root ((GXmlDocument*) _tmp50_);
#line 233 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp52_ = _tmp51_;
#line 233 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp53_ = _tmp52_;
#line 233 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp54_ = gxml_node_get_children_nodes (_tmp53_);
#line 233 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp55_ = _tmp54_;
#line 233 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp56_ = _tmp55_;
#line 233 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp57_ = gee_collection_get_size ((GeeCollection*) _tmp56_);
#line 233 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp58_ = _tmp57_;
#line 233 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (_tmp58_ == 2, "ndoc.root.children_nodes.size == 2");
#line 233 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp56_);
#line 233 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp53_);
#line 234 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp59_ = ndoc;
#line 234 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp60_ = gxml_document_get_root ((GXmlDocument*) _tmp59_);
#line 234 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp61_ = _tmp60_;
#line 234 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp62_ = _tmp61_;
#line 234 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp63_ = gxml_node_get_children_nodes (_tmp62_);
#line 234 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp64_ = _tmp63_;
#line 234 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp65_ = _tmp64_;
#line 234 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp66_ = gee_list_get ((GeeList*) _tmp65_, 0);
#line 234 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp67_ = (GXmlNode*) _tmp66_;
#line 234 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp65_);
#line 234 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp62_);
#line 234 "SerializableGeeCollections-TDocument-Test.vala"
		cz = _tmp67_;
#line 235 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp68_ = cz;
#line 235 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (_tmp68_ != NULL, "cz != null");
#line 236 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp69_ = cz;
#line 236 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp70_ = gxml_node_get_name (_tmp69_);
#line 236 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp71_ = _tmp70_;
#line 236 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp72_ = _tmp71_;
#line 236 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp73_ = g_utf8_strdown (_tmp72_, (gssize) -1);
#line 236 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp74_ = _tmp73_;
#line 236 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (g_strcmp0 (_tmp74_, "chargezone") == 0, "cz.name.down () == \"chargezone\"");
#line 236 "SerializableGeeCollections-TDocument-Test.vala"
		_g_free0 (_tmp74_);
#line 236 "SerializableGeeCollections-TDocument-Test.vala"
		_g_free0 (_tmp72_);
#line 237 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp75_ = cz;
#line 237 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp76_ = gxml_node_get_attrs (_tmp75_);
#line 237 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp77_ = _tmp76_;
#line 237 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp78_ = _tmp77_;
#line 237 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp79_ = gee_map_get (_tmp78_, "name");
#line 237 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp80_ = (GXmlNode*) _tmp79_;
#line 237 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp81_ = gxml_node_get_value (_tmp80_);
#line 237 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp82_ = _tmp81_;
#line 237 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp83_ = _tmp82_;
#line 237 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (g_strcmp0 (_tmp83_, "A1-1") == 0, "cz.attrs.get (\"name\").value == \"A1-1\"");
#line 237 "SerializableGeeCollections-TDocument-Test.vala"
		_g_free0 (_tmp83_);
#line 237 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp80_);
#line 237 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp78_);
#line 238 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp84_ = cz;
#line 238 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp85_ = gxml_node_get_children_nodes (_tmp84_);
#line 238 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp86_ = _tmp85_;
#line 238 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp87_ = _tmp86_;
#line 238 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp88_ = gee_collection_get_size ((GeeCollection*) _tmp87_);
#line 238 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp89_ = _tmp88_;
#line 238 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (_tmp89_ == 2, "cz.children_nodes.size == 2");
#line 238 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp87_);
#line 239 "SerializableGeeCollections-TDocument-Test.vala"
		fmactoy = FALSE;
#line 240 "SerializableGeeCollections-TDocument-Test.vala"
		fmemphis = FALSE;
#line 1210 "SerializableGeeCollections-TDocument-Test.c"
		{
			GeeBidirList* _sh_list = NULL;
			GXmlNode* _tmp90_;
			GeeBidirList* _tmp91_;
			GeeBidirList* _tmp92_;
			gint _sh_size = 0;
			GeeBidirList* _tmp93_;
			gint _tmp94_;
			gint _tmp95_;
			gint _sh_index = 0;
#line 241 "SerializableGeeCollections-TDocument-Test.vala"
			_tmp90_ = cz;
#line 241 "SerializableGeeCollections-TDocument-Test.vala"
			_tmp91_ = gxml_node_get_children_nodes (_tmp90_);
#line 241 "SerializableGeeCollections-TDocument-Test.vala"
			_tmp92_ = _tmp91_;
#line 241 "SerializableGeeCollections-TDocument-Test.vala"
			_sh_list = _tmp92_;
#line 241 "SerializableGeeCollections-TDocument-Test.vala"
			_tmp93_ = _sh_list;
#line 241 "SerializableGeeCollections-TDocument-Test.vala"
			_tmp94_ = gee_collection_get_size ((GeeCollection*) _tmp93_);
#line 241 "SerializableGeeCollections-TDocument-Test.vala"
			_tmp95_ = _tmp94_;
#line 241 "SerializableGeeCollections-TDocument-Test.vala"
			_sh_size = _tmp95_;
#line 241 "SerializableGeeCollections-TDocument-Test.vala"
			_sh_index = -1;
#line 241 "SerializableGeeCollections-TDocument-Test.vala"
			while (TRUE) {
#line 1241 "SerializableGeeCollections-TDocument-Test.c"
				GXmlNode* sh = NULL;
				GeeBidirList* _tmp96_;
				gpointer _tmp97_;
				gboolean _tmp98_ = FALSE;
				GXmlNode* _tmp99_;
				gchar* _tmp100_;
				gchar* _tmp101_;
				gchar* _tmp102_;
				gboolean _tmp103_;
				gboolean _tmp418_ = FALSE;
				GXmlNode* _tmp419_;
				gchar* _tmp420_;
				gchar* _tmp421_;
				gchar* _tmp422_;
				gboolean _tmp423_;
#line 241 "SerializableGeeCollections-TDocument-Test.vala"
				_sh_index = _sh_index + 1;
#line 241 "SerializableGeeCollections-TDocument-Test.vala"
				if (!(_sh_index < _sh_size)) {
#line 241 "SerializableGeeCollections-TDocument-Test.vala"
					break;
#line 1263 "SerializableGeeCollections-TDocument-Test.c"
				}
#line 241 "SerializableGeeCollections-TDocument-Test.vala"
				_tmp96_ = _sh_list;
#line 241 "SerializableGeeCollections-TDocument-Test.vala"
				_tmp97_ = gee_list_get ((GeeList*) _tmp96_, _sh_index);
#line 241 "SerializableGeeCollections-TDocument-Test.vala"
				sh = (GXmlNode*) _tmp97_;
#line 242 "SerializableGeeCollections-TDocument-Test.vala"
				_tmp99_ = sh;
#line 242 "SerializableGeeCollections-TDocument-Test.vala"
				_tmp100_ = gxml_node_get_name (_tmp99_);
#line 242 "SerializableGeeCollections-TDocument-Test.vala"
				_tmp101_ = _tmp100_;
#line 242 "SerializableGeeCollections-TDocument-Test.vala"
				_tmp102_ = _tmp101_;
#line 242 "SerializableGeeCollections-TDocument-Test.vala"
				_tmp103_ = g_strcmp0 (_tmp102_, "ship") == 0;
#line 242 "SerializableGeeCollections-TDocument-Test.vala"
				_g_free0 (_tmp102_);
#line 242 "SerializableGeeCollections-TDocument-Test.vala"
				if (_tmp103_) {
#line 1285 "SerializableGeeCollections-TDocument-Test.c"
					GXmlNode* _tmp104_;
					GeeMap* _tmp105_;
					GeeMap* _tmp106_;
					GeeMap* _tmp107_;
					gpointer _tmp108_;
					GXmlNode* _tmp109_;
					gchar* _tmp110_;
					gchar* _tmp111_;
					gchar* _tmp112_;
#line 242 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp104_ = sh;
#line 242 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp105_ = gxml_node_get_attrs (_tmp104_);
#line 242 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp106_ = _tmp105_;
#line 242 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp107_ = _tmp106_;
#line 242 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp108_ = gee_map_get (_tmp107_, "manufacturer");
#line 242 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp109_ = (GXmlNode*) _tmp108_;
#line 242 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp110_ = gxml_node_get_value (_tmp109_);
#line 242 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp111_ = _tmp110_;
#line 242 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp112_ = _tmp111_;
#line 242 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp98_ = g_strcmp0 (_tmp112_, "MacToy") == 0;
#line 242 "SerializableGeeCollections-TDocument-Test.vala"
					_g_free0 (_tmp112_);
#line 242 "SerializableGeeCollections-TDocument-Test.vala"
					_g_object_unref0 (_tmp109_);
#line 242 "SerializableGeeCollections-TDocument-Test.vala"
					_g_object_unref0 (_tmp107_);
#line 1321 "SerializableGeeCollections-TDocument-Test.c"
				} else {
#line 242 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp98_ = FALSE;
#line 1325 "SerializableGeeCollections-TDocument-Test.c"
				}
#line 242 "SerializableGeeCollections-TDocument-Test.vala"
				if (_tmp98_) {
#line 1329 "SerializableGeeCollections-TDocument-Test.c"
					GXmlNode* _tmp113_;
					GeeMap* _tmp114_;
					GeeMap* _tmp115_;
					GeeMap* _tmp116_;
					gpointer _tmp117_;
					GXmlNode* _tmp118_;
					gchar* _tmp119_;
					gchar* _tmp120_;
					gchar* _tmp121_;
					GXmlNode* _tmp122_;
					GeeMap* _tmp123_;
					GeeMap* _tmp124_;
					GeeMap* _tmp125_;
					gpointer _tmp126_;
					GXmlNode* _tmp127_;
					gchar* _tmp128_;
					gchar* _tmp129_;
					gchar* _tmp130_;
					GXmlNode* _tmp131_;
					GeeBidirList* _tmp132_;
					GeeBidirList* _tmp133_;
					GeeBidirList* _tmp134_;
					gint _tmp135_;
					gint _tmp136_;
					gboolean falphac = FALSE;
					gboolean fgalax = FALSE;
#line 243 "SerializableGeeCollections-TDocument-Test.vala"
					fmactoy = TRUE;
#line 244 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp113_ = sh;
#line 244 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp114_ = gxml_node_get_attrs (_tmp113_);
#line 244 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp115_ = _tmp114_;
#line 244 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp116_ = _tmp115_;
#line 244 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp117_ = gee_map_get (_tmp116_, "manufacturer");
#line 244 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp118_ = (GXmlNode*) _tmp117_;
#line 244 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp119_ = gxml_node_get_value (_tmp118_);
#line 244 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp120_ = _tmp119_;
#line 244 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp121_ = _tmp120_;
#line 244 "SerializableGeeCollections-TDocument-Test.vala"
					_vala_assert (g_strcmp0 (_tmp121_, "MacToy") == 0, "sh.attrs.get (\"manufacturer\").value == \"MacToy\"");
#line 244 "SerializableGeeCollections-TDocument-Test.vala"
					_g_free0 (_tmp121_);
#line 244 "SerializableGeeCollections-TDocument-Test.vala"
					_g_object_unref0 (_tmp118_);
#line 244 "SerializableGeeCollections-TDocument-Test.vala"
					_g_object_unref0 (_tmp116_);
#line 245 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp122_ = sh;
#line 245 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp123_ = gxml_node_get_attrs (_tmp122_);
#line 245 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp124_ = _tmp123_;
#line 245 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp125_ = _tmp124_;
#line 245 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp126_ = gee_map_get (_tmp125_, "model");
#line 245 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp127_ = (GXmlNode*) _tmp126_;
#line 245 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp128_ = gxml_node_get_value (_tmp127_);
#line 245 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp129_ = _tmp128_;
#line 245 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp130_ = _tmp129_;
#line 245 "SerializableGeeCollections-TDocument-Test.vala"
					_vala_assert (g_strcmp0 (_tmp130_, "A1234") == 0, "sh.attrs.get (\"model\").value == \"A1234\"");
#line 245 "SerializableGeeCollections-TDocument-Test.vala"
					_g_free0 (_tmp130_);
#line 245 "SerializableGeeCollections-TDocument-Test.vala"
					_g_object_unref0 (_tmp127_);
#line 245 "SerializableGeeCollections-TDocument-Test.vala"
					_g_object_unref0 (_tmp125_);
#line 246 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp131_ = sh;
#line 246 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp132_ = gxml_node_get_children_nodes (_tmp131_);
#line 246 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp133_ = _tmp132_;
#line 246 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp134_ = _tmp133_;
#line 246 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp135_ = gee_collection_get_size ((GeeCollection*) _tmp134_);
#line 246 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp136_ = _tmp135_;
#line 246 "SerializableGeeCollections-TDocument-Test.vala"
					_vala_assert (_tmp136_ == 5, "sh.children_nodes.size == 5");
#line 246 "SerializableGeeCollections-TDocument-Test.vala"
					_g_object_unref0 (_tmp134_);
#line 247 "SerializableGeeCollections-TDocument-Test.vala"
					falphac = FALSE;
#line 248 "SerializableGeeCollections-TDocument-Test.vala"
					fgalax = FALSE;
#line 1430 "SerializableGeeCollections-TDocument-Test.c"
					{
						GeeBidirList* _s_list = NULL;
						GXmlNode* _tmp137_;
						GeeBidirList* _tmp138_;
						GeeBidirList* _tmp139_;
						gint _s_size = 0;
						GeeBidirList* _tmp140_;
						gint _tmp141_;
						gint _tmp142_;
						gint _s_index = 0;
#line 249 "SerializableGeeCollections-TDocument-Test.vala"
						_tmp137_ = sh;
#line 249 "SerializableGeeCollections-TDocument-Test.vala"
						_tmp138_ = gxml_node_get_children_nodes (_tmp137_);
#line 249 "SerializableGeeCollections-TDocument-Test.vala"
						_tmp139_ = _tmp138_;
#line 249 "SerializableGeeCollections-TDocument-Test.vala"
						_s_list = _tmp139_;
#line 249 "SerializableGeeCollections-TDocument-Test.vala"
						_tmp140_ = _s_list;
#line 249 "SerializableGeeCollections-TDocument-Test.vala"
						_tmp141_ = gee_collection_get_size ((GeeCollection*) _tmp140_);
#line 249 "SerializableGeeCollections-TDocument-Test.vala"
						_tmp142_ = _tmp141_;
#line 249 "SerializableGeeCollections-TDocument-Test.vala"
						_s_size = _tmp142_;
#line 249 "SerializableGeeCollections-TDocument-Test.vala"
						_s_index = -1;
#line 249 "SerializableGeeCollections-TDocument-Test.vala"
						while (TRUE) {
#line 1461 "SerializableGeeCollections-TDocument-Test.c"
							GXmlNode* s = NULL;
							GeeBidirList* _tmp143_;
							gpointer _tmp144_;
							gboolean _tmp145_ = FALSE;
							GXmlNode* _tmp146_;
							gchar* _tmp147_;
							gchar* _tmp148_;
							gchar* _tmp149_;
							gboolean _tmp150_;
							gboolean _tmp305_ = FALSE;
							GXmlNode* _tmp306_;
							gchar* _tmp307_;
							gchar* _tmp308_;
							gchar* _tmp309_;
							gboolean _tmp310_;
#line 249 "SerializableGeeCollections-TDocument-Test.vala"
							_s_index = _s_index + 1;
#line 249 "SerializableGeeCollections-TDocument-Test.vala"
							if (!(_s_index < _s_size)) {
#line 249 "SerializableGeeCollections-TDocument-Test.vala"
								break;
#line 1483 "SerializableGeeCollections-TDocument-Test.c"
							}
#line 249 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp143_ = _s_list;
#line 249 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp144_ = gee_list_get ((GeeList*) _tmp143_, _s_index);
#line 249 "SerializableGeeCollections-TDocument-Test.vala"
							s = (GXmlNode*) _tmp144_;
#line 250 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp146_ = s;
#line 250 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp147_ = gxml_node_get_name (_tmp146_);
#line 250 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp148_ = _tmp147_;
#line 250 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp149_ = _tmp148_;
#line 250 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp150_ = g_strcmp0 (_tmp149_, "space") == 0;
#line 250 "SerializableGeeCollections-TDocument-Test.vala"
							_g_free0 (_tmp149_);
#line 250 "SerializableGeeCollections-TDocument-Test.vala"
							if (_tmp150_) {
#line 1505 "SerializableGeeCollections-TDocument-Test.c"
								GXmlNode* _tmp151_;
								GeeMap* _tmp152_;
								GeeMap* _tmp153_;
								GeeMap* _tmp154_;
								gpointer _tmp155_;
								GXmlNode* _tmp156_;
								gchar* _tmp157_;
								gchar* _tmp158_;
								gchar* _tmp159_;
#line 250 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp151_ = s;
#line 250 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp152_ = gxml_node_get_attrs (_tmp151_);
#line 250 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp153_ = _tmp152_;
#line 250 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp154_ = _tmp153_;
#line 250 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp155_ = gee_map_get (_tmp154_, "name");
#line 250 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp156_ = (GXmlNode*) _tmp155_;
#line 250 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp157_ = gxml_node_get_value (_tmp156_);
#line 250 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp158_ = _tmp157_;
#line 250 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp159_ = _tmp158_;
#line 250 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp145_ = g_strcmp0 (_tmp159_, "Alpha Centaury") == 0;
#line 250 "SerializableGeeCollections-TDocument-Test.vala"
								_g_free0 (_tmp159_);
#line 250 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp156_);
#line 250 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp154_);
#line 1541 "SerializableGeeCollections-TDocument-Test.c"
							} else {
#line 250 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp145_ = FALSE;
#line 1545 "SerializableGeeCollections-TDocument-Test.c"
							}
#line 250 "SerializableGeeCollections-TDocument-Test.vala"
							if (_tmp145_) {
#line 1549 "SerializableGeeCollections-TDocument-Test.c"
								GXmlNode* _tmp160_;
								GeeMap* _tmp161_;
								GeeMap* _tmp162_;
								GeeMap* _tmp163_;
								gpointer _tmp164_;
								GXmlNode* _tmp165_;
								gchar* _tmp166_;
								gchar* _tmp167_;
								gchar* _tmp168_;
								GXmlNode* _tmp169_;
								GeeBidirList* _tmp170_;
								GeeBidirList* _tmp171_;
								GeeBidirList* _tmp172_;
								gint _tmp173_;
								gint _tmp174_;
								gboolean fearth = FALSE;
								gboolean fplaton = FALSE;
#line 251 "SerializableGeeCollections-TDocument-Test.vala"
								falphac = TRUE;
#line 252 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp160_ = s;
#line 252 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp161_ = gxml_node_get_attrs (_tmp160_);
#line 252 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp162_ = _tmp161_;
#line 252 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp163_ = _tmp162_;
#line 252 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp164_ = gee_map_get (_tmp163_, "name");
#line 252 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp165_ = (GXmlNode*) _tmp164_;
#line 252 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp166_ = gxml_node_get_value (_tmp165_);
#line 252 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp167_ = _tmp166_;
#line 252 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp168_ = _tmp167_;
#line 252 "SerializableGeeCollections-TDocument-Test.vala"
								_vala_assert (g_strcmp0 (_tmp168_, "Alpha Centaury") == 0, "s.attrs.get (\"name\").value == \"Alpha Centaury\"");
#line 252 "SerializableGeeCollections-TDocument-Test.vala"
								_g_free0 (_tmp168_);
#line 252 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp165_);
#line 252 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp163_);
#line 253 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp169_ = s;
#line 253 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp170_ = gxml_node_get_children_nodes (_tmp169_);
#line 253 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp171_ = _tmp170_;
#line 253 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp172_ = _tmp171_;
#line 253 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp173_ = gee_collection_get_size ((GeeCollection*) _tmp172_);
#line 253 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp174_ = _tmp173_;
#line 253 "SerializableGeeCollections-TDocument-Test.vala"
								_vala_assert (_tmp174_ == 2, "s.children_nodes.size == 2");
#line 253 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp172_);
#line 254 "SerializableGeeCollections-TDocument-Test.vala"
								fearth = FALSE;
#line 255 "SerializableGeeCollections-TDocument-Test.vala"
								fplaton = FALSE;
#line 1615 "SerializableGeeCollections-TDocument-Test.c"
								{
									GeeBidirList* _p1_list = NULL;
									GXmlNode* _tmp175_;
									GeeBidirList* _tmp176_;
									GeeBidirList* _tmp177_;
									gint _p1_size = 0;
									GeeBidirList* _tmp178_;
									gint _tmp179_;
									gint _tmp180_;
									gint _p1_index = 0;
#line 256 "SerializableGeeCollections-TDocument-Test.vala"
									_tmp175_ = s;
#line 256 "SerializableGeeCollections-TDocument-Test.vala"
									_tmp176_ = gxml_node_get_children_nodes (_tmp175_);
#line 256 "SerializableGeeCollections-TDocument-Test.vala"
									_tmp177_ = _tmp176_;
#line 256 "SerializableGeeCollections-TDocument-Test.vala"
									_p1_list = _tmp177_;
#line 256 "SerializableGeeCollections-TDocument-Test.vala"
									_tmp178_ = _p1_list;
#line 256 "SerializableGeeCollections-TDocument-Test.vala"
									_tmp179_ = gee_collection_get_size ((GeeCollection*) _tmp178_);
#line 256 "SerializableGeeCollections-TDocument-Test.vala"
									_tmp180_ = _tmp179_;
#line 256 "SerializableGeeCollections-TDocument-Test.vala"
									_p1_size = _tmp180_;
#line 256 "SerializableGeeCollections-TDocument-Test.vala"
									_p1_index = -1;
#line 256 "SerializableGeeCollections-TDocument-Test.vala"
									while (TRUE) {
#line 1646 "SerializableGeeCollections-TDocument-Test.c"
										GXmlNode* p1 = NULL;
										GeeBidirList* _tmp181_;
										gpointer _tmp182_;
										gboolean _tmp183_ = FALSE;
										GXmlNode* _tmp184_;
										gchar* _tmp185_;
										gchar* _tmp186_;
										gchar* _tmp187_;
										gboolean _tmp188_;
										gboolean _tmp271_ = FALSE;
										GXmlNode* _tmp272_;
										gchar* _tmp273_;
										gchar* _tmp274_;
										gchar* _tmp275_;
										gboolean _tmp276_;
#line 256 "SerializableGeeCollections-TDocument-Test.vala"
										_p1_index = _p1_index + 1;
#line 256 "SerializableGeeCollections-TDocument-Test.vala"
										if (!(_p1_index < _p1_size)) {
#line 256 "SerializableGeeCollections-TDocument-Test.vala"
											break;
#line 1668 "SerializableGeeCollections-TDocument-Test.c"
										}
#line 256 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp181_ = _p1_list;
#line 256 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp182_ = gee_list_get ((GeeList*) _tmp181_, _p1_index);
#line 256 "SerializableGeeCollections-TDocument-Test.vala"
										p1 = (GXmlNode*) _tmp182_;
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp184_ = p1;
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp185_ = gxml_node_get_name (_tmp184_);
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp186_ = _tmp185_;
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp187_ = _tmp186_;
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp188_ = g_strcmp0 (_tmp187_, "planet") == 0;
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
										_g_free0 (_tmp187_);
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
										if (_tmp188_) {
#line 1690 "SerializableGeeCollections-TDocument-Test.c"
											GXmlNode* _tmp189_;
											GeeMap* _tmp190_;
											GeeMap* _tmp191_;
											GeeMap* _tmp192_;
											gpointer _tmp193_;
											GXmlNode* _tmp194_;
											gchar* _tmp195_;
											gchar* _tmp196_;
											gchar* _tmp197_;
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp189_ = p1;
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp190_ = gxml_node_get_attrs (_tmp189_);
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp191_ = _tmp190_;
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp192_ = _tmp191_;
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp193_ = gee_map_get (_tmp192_, "name");
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp194_ = (GXmlNode*) _tmp193_;
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp195_ = gxml_node_get_value (_tmp194_);
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp196_ = _tmp195_;
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp197_ = _tmp196_;
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp183_ = g_strcmp0 (_tmp197_, "Earth") == 0;
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp197_);
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp194_);
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp192_);
#line 1726 "SerializableGeeCollections-TDocument-Test.c"
										} else {
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp183_ = FALSE;
#line 1730 "SerializableGeeCollections-TDocument-Test.c"
										}
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
										if (_tmp183_) {
#line 1734 "SerializableGeeCollections-TDocument-Test.c"
											GXmlNode* _tmp198_;
											gchar* _tmp199_;
											gchar* _tmp200_;
											gchar* _tmp201_;
											GXmlNode* _tmp202_;
											GeeMap* _tmp203_;
											GeeMap* _tmp204_;
											GeeMap* _tmp205_;
											gpointer _tmp206_;
											GXmlNode* _tmp207_;
											gchar* _tmp208_;
											gchar* _tmp209_;
											gchar* _tmp210_;
											GXmlNode* _tmp211_;
											GeeBidirList* _tmp212_;
											GeeBidirList* _tmp213_;
											GeeBidirList* _tmp214_;
											gint _tmp215_;
											gint _tmp216_;
											GXmlNode* c1 = NULL;
											GXmlNode* _tmp217_;
											GeeBidirList* _tmp218_;
											GeeBidirList* _tmp219_;
											GeeBidirList* _tmp220_;
											gpointer _tmp221_;
											GXmlNode* _tmp222_;
											GXmlNode* _tmp223_;
											GXmlNode* _tmp224_;
											gchar* _tmp225_;
											gchar* _tmp226_;
											gchar* _tmp227_;
											GXmlNode* _tmp228_;
											GeeMap* _tmp229_;
											GeeMap* _tmp230_;
											GeeMap* _tmp231_;
											gpointer _tmp232_;
											GXmlNode* _tmp233_;
											gchar* _tmp234_;
											gchar* _tmp235_;
											gchar* _tmp236_;
											GXmlNode* _tmp237_;
											gchar* _tmp238_;
											gchar* _tmp239_;
											gchar* _tmp240_;
											GXmlNode* _tmp241_;
											GeeBidirList* _tmp242_;
											GeeBidirList* _tmp243_;
											GeeBidirList* _tmp244_;
											gint _tmp245_;
											gint _tmp246_;
											GXmlNode* c2 = NULL;
											GXmlNode* _tmp247_;
											GeeBidirList* _tmp248_;
											GeeBidirList* _tmp249_;
											GeeBidirList* _tmp250_;
											gpointer _tmp251_;
											GXmlNode* _tmp252_;
											GXmlNode* _tmp253_;
											GXmlNode* _tmp254_;
											gchar* _tmp255_;
											gchar* _tmp256_;
											gchar* _tmp257_;
											GXmlNode* _tmp258_;
											GeeMap* _tmp259_;
											GeeMap* _tmp260_;
											GeeMap* _tmp261_;
											gpointer _tmp262_;
											GXmlNode* _tmp263_;
											gchar* _tmp264_;
											gchar* _tmp265_;
											gchar* _tmp266_;
											GXmlNode* _tmp267_;
											gchar* _tmp268_;
											gchar* _tmp269_;
											gchar* _tmp270_;
#line 258 "SerializableGeeCollections-TDocument-Test.vala"
											fearth = TRUE;
#line 259 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp198_ = p1;
#line 259 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp199_ = gxml_node_get_name (_tmp198_);
#line 259 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp200_ = _tmp199_;
#line 259 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp201_ = _tmp200_;
#line 259 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp201_, "planet") == 0, "p1.name == \"planet\"");
#line 259 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp201_);
#line 260 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp202_ = p1;
#line 260 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp203_ = gxml_node_get_attrs (_tmp202_);
#line 260 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp204_ = _tmp203_;
#line 260 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp205_ = _tmp204_;
#line 260 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp206_ = gee_map_get (_tmp205_, "name");
#line 260 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp207_ = (GXmlNode*) _tmp206_;
#line 260 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp208_ = gxml_node_get_value (_tmp207_);
#line 260 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp209_ = _tmp208_;
#line 260 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp210_ = _tmp209_;
#line 260 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp210_, "Earth") == 0, "p1.attrs.get (\"name\").value == \"Earth\"");
#line 260 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp210_);
#line 260 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp207_);
#line 260 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp205_);
#line 261 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp211_ = p1;
#line 261 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp212_ = gxml_node_get_children_nodes (_tmp211_);
#line 261 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp213_ = _tmp212_;
#line 261 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp214_ = _tmp213_;
#line 261 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp215_ = gee_collection_get_size ((GeeCollection*) _tmp214_);
#line 261 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp216_ = _tmp215_;
#line 261 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (_tmp216_ == 2, "p1.children_nodes.size == 2");
#line 261 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp214_);
#line 262 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp217_ = p1;
#line 262 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp218_ = gxml_node_get_children_nodes (_tmp217_);
#line 262 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp219_ = _tmp218_;
#line 262 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp220_ = _tmp219_;
#line 262 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp221_ = gee_list_get ((GeeList*) _tmp220_, 0);
#line 262 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp222_ = (GXmlNode*) _tmp221_;
#line 262 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp220_);
#line 262 "SerializableGeeCollections-TDocument-Test.vala"
											c1 = _tmp222_;
#line 263 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp223_ = c1;
#line 263 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (_tmp223_ != NULL, "c1 != null");
#line 264 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp224_ = c1;
#line 264 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp225_ = gxml_node_get_name (_tmp224_);
#line 264 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp226_ = _tmp225_;
#line 264 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp227_ = _tmp226_;
#line 264 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp227_, "citizen") == 0, "c1.name == \"citizen\"");
#line 264 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp227_);
#line 265 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp228_ = c1;
#line 265 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp229_ = gxml_node_get_attrs (_tmp228_);
#line 265 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp230_ = _tmp229_;
#line 265 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp231_ = _tmp230_;
#line 265 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp232_ = gee_map_get (_tmp231_, "ctype");
#line 265 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp233_ = (GXmlNode*) _tmp232_;
#line 265 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp234_ = gxml_node_get_value (_tmp233_);
#line 265 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp235_ = _tmp234_;
#line 265 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp236_ = _tmp235_;
#line 265 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp236_, "Human") == 0, "c1.attrs.get (\"ctype\").value == \"Human\"");
#line 265 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp236_);
#line 265 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp233_);
#line 265 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp231_);
#line 266 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp237_ = c1;
#line 266 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp238_ = gxml_element_get_content (G_TYPE_CHECK_INSTANCE_CAST (_tmp237_, GXML_TYPE_ELEMENT, GXmlElement));
#line 266 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp239_ = _tmp238_;
#line 266 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp240_ = _tmp239_;
#line 266 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp240_, "1M") == 0, "((Element)c1).content == \"1M\"");
#line 266 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp240_);
#line 267 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp241_ = c1;
#line 267 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp242_ = gxml_node_get_children_nodes (_tmp241_);
#line 267 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp243_ = _tmp242_;
#line 267 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp244_ = _tmp243_;
#line 267 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp245_ = gee_collection_get_size ((GeeCollection*) _tmp244_);
#line 267 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp246_ = _tmp245_;
#line 267 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (_tmp246_ == 1, "c1.children_nodes.size == 1");
#line 267 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp244_);
#line 268 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp247_ = p1;
#line 268 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp248_ = gxml_node_get_children_nodes (_tmp247_);
#line 268 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp249_ = _tmp248_;
#line 268 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp250_ = _tmp249_;
#line 268 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp251_ = gee_list_get ((GeeList*) _tmp250_, 1);
#line 268 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp252_ = (GXmlNode*) _tmp251_;
#line 268 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp250_);
#line 268 "SerializableGeeCollections-TDocument-Test.vala"
											c2 = _tmp252_;
#line 269 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp253_ = c2;
#line 269 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (_tmp253_ != NULL, "c2 != null");
#line 270 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp254_ = c2;
#line 270 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp255_ = gxml_node_get_name (_tmp254_);
#line 270 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp256_ = _tmp255_;
#line 270 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp257_ = _tmp256_;
#line 270 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp257_, "citizen") == 0, "c2.name == \"citizen\"");
#line 270 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp257_);
#line 271 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp258_ = c2;
#line 271 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp259_ = gxml_node_get_attrs (_tmp258_);
#line 271 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp260_ = _tmp259_;
#line 271 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp261_ = _tmp260_;
#line 271 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp262_ = gee_map_get (_tmp261_, "ctype");
#line 271 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp263_ = (GXmlNode*) _tmp262_;
#line 271 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp264_ = gxml_node_get_value (_tmp263_);
#line 271 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp265_ = _tmp264_;
#line 271 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp266_ = _tmp265_;
#line 271 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp266_, "Ghost") == 0, "c2.attrs.get (\"ctype\").value == \"Ghost\"");
#line 271 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp266_);
#line 271 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp263_);
#line 271 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp261_);
#line 272 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp267_ = c2;
#line 272 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp268_ = gxml_element_get_content (G_TYPE_CHECK_INSTANCE_CAST (_tmp267_, GXML_TYPE_ELEMENT, GXmlElement));
#line 272 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp269_ = _tmp268_;
#line 272 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp270_ = _tmp269_;
#line 272 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp270_, "10M") == 0, "((Element) c2).content == \"10M\"");
#line 272 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp270_);
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (c2);
#line 257 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (c1);
#line 2026 "SerializableGeeCollections-TDocument-Test.c"
										}
#line 274 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp272_ = p1;
#line 274 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp273_ = gxml_node_get_name (_tmp272_);
#line 274 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp274_ = _tmp273_;
#line 274 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp275_ = _tmp274_;
#line 274 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp276_ = g_strcmp0 (_tmp275_, "planet") == 0;
#line 274 "SerializableGeeCollections-TDocument-Test.vala"
										_g_free0 (_tmp275_);
#line 274 "SerializableGeeCollections-TDocument-Test.vala"
										if (_tmp276_) {
#line 2042 "SerializableGeeCollections-TDocument-Test.c"
											GXmlNode* _tmp277_;
											GeeMap* _tmp278_;
											GeeMap* _tmp279_;
											GeeMap* _tmp280_;
											gpointer _tmp281_;
											GXmlNode* _tmp282_;
											gchar* _tmp283_;
											gchar* _tmp284_;
											gchar* _tmp285_;
#line 274 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp277_ = p1;
#line 274 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp278_ = gxml_node_get_attrs (_tmp277_);
#line 274 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp279_ = _tmp278_;
#line 274 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp280_ = _tmp279_;
#line 274 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp281_ = gee_map_get (_tmp280_, "name");
#line 274 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp282_ = (GXmlNode*) _tmp281_;
#line 274 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp283_ = gxml_node_get_value (_tmp282_);
#line 274 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp284_ = _tmp283_;
#line 274 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp285_ = _tmp284_;
#line 274 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp271_ = g_strcmp0 (_tmp285_, "Platon") == 0;
#line 274 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp285_);
#line 274 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp282_);
#line 274 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp280_);
#line 2078 "SerializableGeeCollections-TDocument-Test.c"
										} else {
#line 274 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp271_ = FALSE;
#line 2082 "SerializableGeeCollections-TDocument-Test.c"
										}
#line 274 "SerializableGeeCollections-TDocument-Test.vala"
										if (_tmp271_) {
#line 2086 "SerializableGeeCollections-TDocument-Test.c"
											GXmlNode* _tmp286_;
											gchar* _tmp287_;
											gchar* _tmp288_;
											gchar* _tmp289_;
											GXmlNode* _tmp290_;
											GeeMap* _tmp291_;
											GeeMap* _tmp292_;
											GeeMap* _tmp293_;
											gpointer _tmp294_;
											GXmlNode* _tmp295_;
											gchar* _tmp296_;
											gchar* _tmp297_;
											gchar* _tmp298_;
											GXmlNode* _tmp299_;
											GeeBidirList* _tmp300_;
											GeeBidirList* _tmp301_;
											GeeBidirList* _tmp302_;
											gint _tmp303_;
											gint _tmp304_;
#line 275 "SerializableGeeCollections-TDocument-Test.vala"
											fplaton = TRUE;
#line 276 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp286_ = p1;
#line 276 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp287_ = gxml_node_get_name (_tmp286_);
#line 276 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp288_ = _tmp287_;
#line 276 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp289_ = _tmp288_;
#line 276 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp289_, "planet") == 0, "p1.name == \"planet\"");
#line 276 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp289_);
#line 277 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp290_ = p1;
#line 277 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp291_ = gxml_node_get_attrs (_tmp290_);
#line 277 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp292_ = _tmp291_;
#line 277 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp293_ = _tmp292_;
#line 277 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp294_ = gee_map_get (_tmp293_, "name");
#line 277 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp295_ = (GXmlNode*) _tmp294_;
#line 277 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp296_ = gxml_node_get_value (_tmp295_);
#line 277 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp297_ = _tmp296_;
#line 277 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp298_ = _tmp297_;
#line 277 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp298_, "Platon") == 0, "p1.attrs.get (\"name\").value == \"Platon\"");
#line 277 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp298_);
#line 277 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp295_);
#line 277 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp293_);
#line 278 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp299_ = p1;
#line 278 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp300_ = gxml_node_get_children_nodes (_tmp299_);
#line 278 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp301_ = _tmp300_;
#line 278 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp302_ = _tmp301_;
#line 278 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp303_ = gee_collection_get_size ((GeeCollection*) _tmp302_);
#line 278 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp304_ = _tmp303_;
#line 278 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (_tmp304_ == 0, "p1.children_nodes.size == 0");
#line 278 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp302_);
#line 2162 "SerializableGeeCollections-TDocument-Test.c"
										}
#line 256 "SerializableGeeCollections-TDocument-Test.vala"
										_g_object_unref0 (p1);
#line 2166 "SerializableGeeCollections-TDocument-Test.c"
									}
#line 256 "SerializableGeeCollections-TDocument-Test.vala"
									_g_object_unref0 (_p1_list);
#line 2170 "SerializableGeeCollections-TDocument-Test.c"
								}
#line 281 "SerializableGeeCollections-TDocument-Test.vala"
								_vala_assert (fearth, "fearth");
#line 282 "SerializableGeeCollections-TDocument-Test.vala"
								_vala_assert (fplaton, "fplaton");
#line 2176 "SerializableGeeCollections-TDocument-Test.c"
							}
#line 284 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp306_ = s;
#line 284 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp307_ = gxml_node_get_name (_tmp306_);
#line 284 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp308_ = _tmp307_;
#line 284 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp309_ = _tmp308_;
#line 284 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp310_ = g_strcmp0 (_tmp309_, "space") == 0;
#line 284 "SerializableGeeCollections-TDocument-Test.vala"
							_g_free0 (_tmp309_);
#line 284 "SerializableGeeCollections-TDocument-Test.vala"
							if (_tmp310_) {
#line 2192 "SerializableGeeCollections-TDocument-Test.c"
								GXmlNode* _tmp311_;
								GeeMap* _tmp312_;
								GeeMap* _tmp313_;
								GeeMap* _tmp314_;
								gpointer _tmp315_;
								GXmlNode* _tmp316_;
								gchar* _tmp317_;
								gchar* _tmp318_;
								gchar* _tmp319_;
#line 284 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp311_ = s;
#line 284 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp312_ = gxml_node_get_attrs (_tmp311_);
#line 284 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp313_ = _tmp312_;
#line 284 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp314_ = _tmp313_;
#line 284 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp315_ = gee_map_get (_tmp314_, "name");
#line 284 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp316_ = (GXmlNode*) _tmp315_;
#line 284 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp317_ = gxml_node_get_value (_tmp316_);
#line 284 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp318_ = _tmp317_;
#line 284 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp319_ = _tmp318_;
#line 284 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp305_ = g_strcmp0 (_tmp319_, "Galax") == 0;
#line 284 "SerializableGeeCollections-TDocument-Test.vala"
								_g_free0 (_tmp319_);
#line 284 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp316_);
#line 284 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp314_);
#line 2228 "SerializableGeeCollections-TDocument-Test.c"
							} else {
#line 284 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp305_ = FALSE;
#line 2232 "SerializableGeeCollections-TDocument-Test.c"
							}
#line 284 "SerializableGeeCollections-TDocument-Test.vala"
							if (_tmp305_) {
#line 2236 "SerializableGeeCollections-TDocument-Test.c"
								GXmlNode* _tmp320_;
								GeeMap* _tmp321_;
								GeeMap* _tmp322_;
								GeeMap* _tmp323_;
								gpointer _tmp324_;
								GXmlNode* _tmp325_;
								gchar* _tmp326_;
								gchar* _tmp327_;
								gchar* _tmp328_;
								GXmlNode* _tmp329_;
								GeeBidirList* _tmp330_;
								GeeBidirList* _tmp331_;
								GeeBidirList* _tmp332_;
								gint _tmp333_;
								gint _tmp334_;
								gboolean fsaminon = FALSE;
#line 285 "SerializableGeeCollections-TDocument-Test.vala"
								fgalax = TRUE;
#line 286 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp320_ = s;
#line 286 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp321_ = gxml_node_get_attrs (_tmp320_);
#line 286 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp322_ = _tmp321_;
#line 286 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp323_ = _tmp322_;
#line 286 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp324_ = gee_map_get (_tmp323_, "name");
#line 286 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp325_ = (GXmlNode*) _tmp324_;
#line 286 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp326_ = gxml_node_get_value (_tmp325_);
#line 286 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp327_ = _tmp326_;
#line 286 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp328_ = _tmp327_;
#line 286 "SerializableGeeCollections-TDocument-Test.vala"
								_vala_assert (g_strcmp0 (_tmp328_, "Galax") == 0, "s.attrs.get (\"name\").value == \"Galax\"");
#line 286 "SerializableGeeCollections-TDocument-Test.vala"
								_g_free0 (_tmp328_);
#line 286 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp325_);
#line 286 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp323_);
#line 287 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp329_ = s;
#line 287 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp330_ = gxml_node_get_children_nodes (_tmp329_);
#line 287 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp331_ = _tmp330_;
#line 287 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp332_ = _tmp331_;
#line 287 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp333_ = gee_collection_get_size ((GeeCollection*) _tmp332_);
#line 287 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp334_ = _tmp333_;
#line 287 "SerializableGeeCollections-TDocument-Test.vala"
								_vala_assert (_tmp334_ == 2, "s.children_nodes.size == 2");
#line 287 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp332_);
#line 288 "SerializableGeeCollections-TDocument-Test.vala"
								fsaminon = FALSE;
#line 2299 "SerializableGeeCollections-TDocument-Test.c"
								{
									GeeBidirList* _p_list = NULL;
									GXmlNode* _tmp335_;
									GeeBidirList* _tmp336_;
									GeeBidirList* _tmp337_;
									gint _p_size = 0;
									GeeBidirList* _tmp338_;
									gint _tmp339_;
									gint _tmp340_;
									gint _p_index = 0;
#line 289 "SerializableGeeCollections-TDocument-Test.vala"
									_tmp335_ = s;
#line 289 "SerializableGeeCollections-TDocument-Test.vala"
									_tmp336_ = gxml_node_get_children_nodes (_tmp335_);
#line 289 "SerializableGeeCollections-TDocument-Test.vala"
									_tmp337_ = _tmp336_;
#line 289 "SerializableGeeCollections-TDocument-Test.vala"
									_p_list = _tmp337_;
#line 289 "SerializableGeeCollections-TDocument-Test.vala"
									_tmp338_ = _p_list;
#line 289 "SerializableGeeCollections-TDocument-Test.vala"
									_tmp339_ = gee_collection_get_size ((GeeCollection*) _tmp338_);
#line 289 "SerializableGeeCollections-TDocument-Test.vala"
									_tmp340_ = _tmp339_;
#line 289 "SerializableGeeCollections-TDocument-Test.vala"
									_p_size = _tmp340_;
#line 289 "SerializableGeeCollections-TDocument-Test.vala"
									_p_index = -1;
#line 289 "SerializableGeeCollections-TDocument-Test.vala"
									while (TRUE) {
#line 2330 "SerializableGeeCollections-TDocument-Test.c"
										GXmlNode* p = NULL;
										GeeBidirList* _tmp341_;
										gpointer _tmp342_;
										gboolean _tmp343_ = FALSE;
										GXmlNode* _tmp344_;
										gchar* _tmp345_;
										gchar* _tmp346_;
										gchar* _tmp347_;
										gboolean _tmp348_;
#line 289 "SerializableGeeCollections-TDocument-Test.vala"
										_p_index = _p_index + 1;
#line 289 "SerializableGeeCollections-TDocument-Test.vala"
										if (!(_p_index < _p_size)) {
#line 289 "SerializableGeeCollections-TDocument-Test.vala"
											break;
#line 2346 "SerializableGeeCollections-TDocument-Test.c"
										}
#line 289 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp341_ = _p_list;
#line 289 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp342_ = gee_list_get ((GeeList*) _tmp341_, _p_index);
#line 289 "SerializableGeeCollections-TDocument-Test.vala"
										p = (GXmlNode*) _tmp342_;
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp344_ = p;
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp345_ = gxml_node_get_name (_tmp344_);
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp346_ = _tmp345_;
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp347_ = _tmp346_;
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp348_ = g_strcmp0 (_tmp347_, "planet") == 0;
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
										_g_free0 (_tmp347_);
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
										if (_tmp348_) {
#line 2368 "SerializableGeeCollections-TDocument-Test.c"
											GXmlNode* _tmp349_;
											GeeMap* _tmp350_;
											GeeMap* _tmp351_;
											GeeMap* _tmp352_;
											gpointer _tmp353_;
											GXmlNode* _tmp354_;
											gchar* _tmp355_;
											gchar* _tmp356_;
											gchar* _tmp357_;
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp349_ = p;
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp350_ = gxml_node_get_attrs (_tmp349_);
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp351_ = _tmp350_;
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp352_ = _tmp351_;
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp353_ = gee_map_get (_tmp352_, "name");
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp354_ = (GXmlNode*) _tmp353_;
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp355_ = gxml_node_get_value (_tmp354_);
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp356_ = _tmp355_;
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp357_ = _tmp356_;
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp343_ = g_strcmp0 (_tmp357_, "Saminon") == 0;
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp357_);
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp354_);
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp352_);
#line 2404 "SerializableGeeCollections-TDocument-Test.c"
										} else {
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp343_ = FALSE;
#line 2408 "SerializableGeeCollections-TDocument-Test.c"
										}
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
										if (_tmp343_) {
#line 2412 "SerializableGeeCollections-TDocument-Test.c"
											GXmlNode* h = NULL;
											GXmlNode* _tmp358_;
											GeeBidirList* _tmp359_;
											GeeBidirList* _tmp360_;
											GeeBidirList* _tmp361_;
											gpointer _tmp362_;
											GXmlNode* _tmp363_;
											GXmlNode* _tmp364_;
											GXmlNode* _tmp365_;
											gchar* _tmp366_;
											gchar* _tmp367_;
											gchar* _tmp368_;
											GXmlNode* _tmp369_;
											GeeMap* _tmp370_;
											GeeMap* _tmp371_;
											GeeMap* _tmp372_;
											gpointer _tmp373_;
											GXmlNode* _tmp374_;
											gchar* _tmp375_;
											gchar* _tmp376_;
											gchar* _tmp377_;
											GXmlNode* _tmp378_;
											GeeBidirList* _tmp379_;
											GeeBidirList* _tmp380_;
											GeeBidirList* _tmp381_;
											gint _tmp382_;
											gint _tmp383_;
											GXmlNode* _tmp384_;
											gchar* _tmp385_;
											gchar* _tmp386_;
											gchar* _tmp387_;
											GXmlNode* j = NULL;
											GXmlNode* _tmp388_;
											GeeBidirList* _tmp389_;
											GeeBidirList* _tmp390_;
											GeeBidirList* _tmp391_;
											gpointer _tmp392_;
											GXmlNode* _tmp393_;
											GXmlNode* _tmp394_;
											GXmlNode* _tmp395_;
											gchar* _tmp396_;
											gchar* _tmp397_;
											gchar* _tmp398_;
											GXmlNode* _tmp399_;
											GeeMap* _tmp400_;
											GeeMap* _tmp401_;
											GeeMap* _tmp402_;
											gpointer _tmp403_;
											GXmlNode* _tmp404_;
											gchar* _tmp405_;
											gchar* _tmp406_;
											gchar* _tmp407_;
											GXmlNode* _tmp408_;
											GeeBidirList* _tmp409_;
											GeeBidirList* _tmp410_;
											GeeBidirList* _tmp411_;
											gint _tmp412_;
											gint _tmp413_;
											GXmlNode* _tmp414_;
											gchar* _tmp415_;
											gchar* _tmp416_;
											gchar* _tmp417_;
#line 291 "SerializableGeeCollections-TDocument-Test.vala"
											fsaminon = TRUE;
#line 292 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp358_ = p;
#line 292 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp359_ = gxml_node_get_children_nodes (_tmp358_);
#line 292 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp360_ = _tmp359_;
#line 292 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp361_ = _tmp360_;
#line 292 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp362_ = gee_list_get ((GeeList*) _tmp361_, 0);
#line 292 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp363_ = (GXmlNode*) _tmp362_;
#line 292 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp361_);
#line 292 "SerializableGeeCollections-TDocument-Test.vala"
											h = _tmp363_;
#line 293 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp364_ = h;
#line 293 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (_tmp364_ != NULL, "h != null");
#line 294 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp365_ = h;
#line 294 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp366_ = gxml_node_get_name (_tmp365_);
#line 294 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp367_ = _tmp366_;
#line 294 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp368_ = _tmp367_;
#line 294 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp368_, "citizen") == 0, "h.name == \"citizen\"");
#line 294 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp368_);
#line 295 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp369_ = h;
#line 295 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp370_ = gxml_node_get_attrs (_tmp369_);
#line 295 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp371_ = _tmp370_;
#line 295 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp372_ = _tmp371_;
#line 295 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp373_ = gee_map_get (_tmp372_, "ctype");
#line 295 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp374_ = (GXmlNode*) _tmp373_;
#line 295 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp375_ = gxml_node_get_value (_tmp374_);
#line 295 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp376_ = _tmp375_;
#line 295 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp377_ = _tmp376_;
#line 295 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp377_, "Humanes") == 0, "h.attrs.get (\"ctype\").value == \"Humanes\"");
#line 295 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp377_);
#line 295 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp374_);
#line 295 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp372_);
#line 296 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp378_ = h;
#line 296 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp379_ = gxml_node_get_children_nodes (_tmp378_);
#line 296 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp380_ = _tmp379_;
#line 296 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp381_ = _tmp380_;
#line 296 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp382_ = gee_collection_get_size ((GeeCollection*) _tmp381_);
#line 296 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp383_ = _tmp382_;
#line 296 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (_tmp383_ == 1, "h.children_nodes.size == 1");
#line 296 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp381_);
#line 297 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp384_ = h;
#line 297 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp385_ = gxml_element_get_content (G_TYPE_CHECK_INSTANCE_CAST (_tmp384_, GXML_TYPE_ELEMENT, GXmlElement));
#line 297 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp386_ = _tmp385_;
#line 297 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp387_ = _tmp386_;
#line 297 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp387_, "100M") == 0, "((Element) h).content == \"100M\"");
#line 297 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp387_);
#line 298 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp388_ = p;
#line 298 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp389_ = gxml_node_get_children_nodes (_tmp388_);
#line 298 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp390_ = _tmp389_;
#line 298 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp391_ = _tmp390_;
#line 298 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp392_ = gee_list_get ((GeeList*) _tmp391_, 1);
#line 298 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp393_ = (GXmlNode*) _tmp392_;
#line 298 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp391_);
#line 298 "SerializableGeeCollections-TDocument-Test.vala"
											j = _tmp393_;
#line 299 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp394_ = j;
#line 299 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (_tmp394_ != NULL, "j != null");
#line 300 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp395_ = j;
#line 300 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp396_ = gxml_node_get_name (_tmp395_);
#line 300 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp397_ = _tmp396_;
#line 300 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp398_ = _tmp397_;
#line 300 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp398_, "citizen") == 0, "j.name == \"citizen\"");
#line 300 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp398_);
#line 301 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp399_ = j;
#line 301 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp400_ = gxml_node_get_attrs (_tmp399_);
#line 301 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp401_ = _tmp400_;
#line 301 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp402_ = _tmp401_;
#line 301 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp403_ = gee_map_get (_tmp402_, "ctype");
#line 301 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp404_ = (GXmlNode*) _tmp403_;
#line 301 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp405_ = gxml_node_get_value (_tmp404_);
#line 301 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp406_ = _tmp405_;
#line 301 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp407_ = _tmp406_;
#line 301 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp407_, "Jeties") == 0, "j.attrs.get (\"ctype\").value == \"Jeties\"");
#line 301 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp407_);
#line 301 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp404_);
#line 301 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp402_);
#line 302 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp408_ = j;
#line 302 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp409_ = gxml_node_get_children_nodes (_tmp408_);
#line 302 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp410_ = _tmp409_;
#line 302 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp411_ = _tmp410_;
#line 302 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp412_ = gee_collection_get_size ((GeeCollection*) _tmp411_);
#line 302 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp413_ = _tmp412_;
#line 302 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (_tmp413_ == 1, "j.children_nodes.size == 1");
#line 302 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp411_);
#line 303 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp414_ = j;
#line 303 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp415_ = gxml_element_get_content (G_TYPE_CHECK_INSTANCE_CAST (_tmp414_, GXML_TYPE_ELEMENT, GXmlElement));
#line 303 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp416_ = _tmp415_;
#line 303 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp417_ = _tmp416_;
#line 303 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp417_, "1000M") == 0, "((Element) j).content == \"1000M\"");
#line 303 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp417_);
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (j);
#line 290 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (h);
#line 2653 "SerializableGeeCollections-TDocument-Test.c"
										}
#line 289 "SerializableGeeCollections-TDocument-Test.vala"
										_g_object_unref0 (p);
#line 2657 "SerializableGeeCollections-TDocument-Test.c"
									}
#line 289 "SerializableGeeCollections-TDocument-Test.vala"
									_g_object_unref0 (_p_list);
#line 2661 "SerializableGeeCollections-TDocument-Test.c"
								}
#line 306 "SerializableGeeCollections-TDocument-Test.vala"
								_vala_assert (fsaminon, "fsaminon");
#line 2665 "SerializableGeeCollections-TDocument-Test.c"
							}
#line 249 "SerializableGeeCollections-TDocument-Test.vala"
							_g_object_unref0 (s);
#line 2669 "SerializableGeeCollections-TDocument-Test.c"
						}
#line 249 "SerializableGeeCollections-TDocument-Test.vala"
						_g_object_unref0 (_s_list);
#line 2673 "SerializableGeeCollections-TDocument-Test.c"
					}
#line 309 "SerializableGeeCollections-TDocument-Test.vala"
					_vala_assert (falphac, "falphac");
#line 2677 "SerializableGeeCollections-TDocument-Test.c"
				}
#line 311 "SerializableGeeCollections-TDocument-Test.vala"
				_tmp419_ = sh;
#line 311 "SerializableGeeCollections-TDocument-Test.vala"
				_tmp420_ = gxml_node_get_name (_tmp419_);
#line 311 "SerializableGeeCollections-TDocument-Test.vala"
				_tmp421_ = _tmp420_;
#line 311 "SerializableGeeCollections-TDocument-Test.vala"
				_tmp422_ = _tmp421_;
#line 311 "SerializableGeeCollections-TDocument-Test.vala"
				_tmp423_ = g_strcmp0 (_tmp422_, "ship") == 0;
#line 311 "SerializableGeeCollections-TDocument-Test.vala"
				_g_free0 (_tmp422_);
#line 311 "SerializableGeeCollections-TDocument-Test.vala"
				if (_tmp423_) {
#line 2693 "SerializableGeeCollections-TDocument-Test.c"
					GXmlNode* _tmp424_;
					GeeMap* _tmp425_;
					GeeMap* _tmp426_;
					GeeMap* _tmp427_;
					gpointer _tmp428_;
					GXmlNode* _tmp429_;
					gchar* _tmp430_;
					gchar* _tmp431_;
					gchar* _tmp432_;
#line 311 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp424_ = sh;
#line 311 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp425_ = gxml_node_get_attrs (_tmp424_);
#line 311 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp426_ = _tmp425_;
#line 311 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp427_ = _tmp426_;
#line 311 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp428_ = gee_map_get (_tmp427_, "manufacturer");
#line 311 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp429_ = (GXmlNode*) _tmp428_;
#line 311 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp430_ = gxml_node_get_value (_tmp429_);
#line 311 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp431_ = _tmp430_;
#line 311 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp432_ = _tmp431_;
#line 311 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp418_ = g_strcmp0 (_tmp432_, "Memphis") == 0;
#line 311 "SerializableGeeCollections-TDocument-Test.vala"
					_g_free0 (_tmp432_);
#line 311 "SerializableGeeCollections-TDocument-Test.vala"
					_g_object_unref0 (_tmp429_);
#line 311 "SerializableGeeCollections-TDocument-Test.vala"
					_g_object_unref0 (_tmp427_);
#line 2729 "SerializableGeeCollections-TDocument-Test.c"
				} else {
#line 311 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp418_ = FALSE;
#line 2733 "SerializableGeeCollections-TDocument-Test.c"
				}
#line 311 "SerializableGeeCollections-TDocument-Test.vala"
				if (_tmp418_) {
#line 2737 "SerializableGeeCollections-TDocument-Test.c"
					GXmlNode* _tmp433_;
					gchar* _tmp434_;
					gchar* _tmp435_;
					gchar* _tmp436_;
					GXmlNode* _tmp437_;
					GeeMap* _tmp438_;
					GeeMap* _tmp439_;
					GeeMap* _tmp440_;
					gpointer _tmp441_;
					GXmlNode* _tmp442_;
					gchar* _tmp443_;
					gchar* _tmp444_;
					gchar* _tmp445_;
					GXmlNode* _tmp446_;
					GeeMap* _tmp447_;
					GeeMap* _tmp448_;
					GeeMap* _tmp449_;
					gpointer _tmp450_;
					GXmlNode* _tmp451_;
					gchar* _tmp452_;
					gchar* _tmp453_;
					gchar* _tmp454_;
					GXmlNode* _tmp455_;
					GeeBidirList* _tmp456_;
					GeeBidirList* _tmp457_;
					GeeBidirList* _tmp458_;
					gint _tmp459_;
					gint _tmp460_;
					gboolean fbetac = FALSE;
#line 312 "SerializableGeeCollections-TDocument-Test.vala"
					fmemphis = TRUE;
#line 313 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp433_ = sh;
#line 313 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp434_ = gxml_node_get_name (_tmp433_);
#line 313 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp435_ = _tmp434_;
#line 313 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp436_ = _tmp435_;
#line 313 "SerializableGeeCollections-TDocument-Test.vala"
					_vala_assert (g_strcmp0 (_tmp436_, "ship") == 0, "sh.name == \"ship\"");
#line 313 "SerializableGeeCollections-TDocument-Test.vala"
					_g_free0 (_tmp436_);
#line 314 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp437_ = sh;
#line 314 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp438_ = gxml_node_get_attrs (_tmp437_);
#line 314 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp439_ = _tmp438_;
#line 314 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp440_ = _tmp439_;
#line 314 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp441_ = gee_map_get (_tmp440_, "manufacturer");
#line 314 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp442_ = (GXmlNode*) _tmp441_;
#line 314 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp443_ = gxml_node_get_value (_tmp442_);
#line 314 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp444_ = _tmp443_;
#line 314 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp445_ = _tmp444_;
#line 314 "SerializableGeeCollections-TDocument-Test.vala"
					_vala_assert (g_strcmp0 (_tmp445_, "Memphis") == 0, "sh.attrs.get (\"manufacturer\").value == \"Memphis\"");
#line 314 "SerializableGeeCollections-TDocument-Test.vala"
					_g_free0 (_tmp445_);
#line 314 "SerializableGeeCollections-TDocument-Test.vala"
					_g_object_unref0 (_tmp442_);
#line 314 "SerializableGeeCollections-TDocument-Test.vala"
					_g_object_unref0 (_tmp440_);
#line 315 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp446_ = sh;
#line 315 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp447_ = gxml_node_get_attrs (_tmp446_);
#line 315 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp448_ = _tmp447_;
#line 315 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp449_ = _tmp448_;
#line 315 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp450_ = gee_map_get (_tmp449_, "model");
#line 315 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp451_ = (GXmlNode*) _tmp450_;
#line 315 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp452_ = gxml_node_get_value (_tmp451_);
#line 315 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp453_ = _tmp452_;
#line 315 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp454_ = _tmp453_;
#line 315 "SerializableGeeCollections-TDocument-Test.vala"
					_vala_assert (g_strcmp0 (_tmp454_, "AB1") == 0, "sh.attrs.get (\"model\").value == \"AB1\"");
#line 315 "SerializableGeeCollections-TDocument-Test.vala"
					_g_free0 (_tmp454_);
#line 315 "SerializableGeeCollections-TDocument-Test.vala"
					_g_object_unref0 (_tmp451_);
#line 315 "SerializableGeeCollections-TDocument-Test.vala"
					_g_object_unref0 (_tmp449_);
#line 316 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp455_ = sh;
#line 316 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp456_ = gxml_node_get_children_nodes (_tmp455_);
#line 316 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp457_ = _tmp456_;
#line 316 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp458_ = _tmp457_;
#line 316 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp459_ = gee_collection_get_size ((GeeCollection*) _tmp458_);
#line 316 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp460_ = _tmp459_;
#line 316 "SerializableGeeCollections-TDocument-Test.vala"
					_vala_assert (_tmp460_ == 3, "sh.children_nodes.size == 3");
#line 316 "SerializableGeeCollections-TDocument-Test.vala"
					_g_object_unref0 (_tmp458_);
#line 317 "SerializableGeeCollections-TDocument-Test.vala"
					fbetac = FALSE;
#line 2851 "SerializableGeeCollections-TDocument-Test.c"
					{
						GeeBidirList* _s_list = NULL;
						GXmlNode* _tmp461_;
						GeeBidirList* _tmp462_;
						GeeBidirList* _tmp463_;
						gint _s_size = 0;
						GeeBidirList* _tmp464_;
						gint _tmp465_;
						gint _tmp466_;
						gint _s_index = 0;
#line 318 "SerializableGeeCollections-TDocument-Test.vala"
						_tmp461_ = sh;
#line 318 "SerializableGeeCollections-TDocument-Test.vala"
						_tmp462_ = gxml_node_get_children_nodes (_tmp461_);
#line 318 "SerializableGeeCollections-TDocument-Test.vala"
						_tmp463_ = _tmp462_;
#line 318 "SerializableGeeCollections-TDocument-Test.vala"
						_s_list = _tmp463_;
#line 318 "SerializableGeeCollections-TDocument-Test.vala"
						_tmp464_ = _s_list;
#line 318 "SerializableGeeCollections-TDocument-Test.vala"
						_tmp465_ = gee_collection_get_size ((GeeCollection*) _tmp464_);
#line 318 "SerializableGeeCollections-TDocument-Test.vala"
						_tmp466_ = _tmp465_;
#line 318 "SerializableGeeCollections-TDocument-Test.vala"
						_s_size = _tmp466_;
#line 318 "SerializableGeeCollections-TDocument-Test.vala"
						_s_index = -1;
#line 318 "SerializableGeeCollections-TDocument-Test.vala"
						while (TRUE) {
#line 2882 "SerializableGeeCollections-TDocument-Test.c"
							GXmlNode* s = NULL;
							GeeBidirList* _tmp467_;
							gpointer _tmp468_;
							gboolean _tmp469_ = FALSE;
							GXmlNode* _tmp470_;
							gchar* _tmp471_;
							gchar* _tmp472_;
							gchar* _tmp473_;
							gboolean _tmp474_;
#line 318 "SerializableGeeCollections-TDocument-Test.vala"
							_s_index = _s_index + 1;
#line 318 "SerializableGeeCollections-TDocument-Test.vala"
							if (!(_s_index < _s_size)) {
#line 318 "SerializableGeeCollections-TDocument-Test.vala"
								break;
#line 2898 "SerializableGeeCollections-TDocument-Test.c"
							}
#line 318 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp467_ = _s_list;
#line 318 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp468_ = gee_list_get ((GeeList*) _tmp467_, _s_index);
#line 318 "SerializableGeeCollections-TDocument-Test.vala"
							s = (GXmlNode*) _tmp468_;
#line 319 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp470_ = s;
#line 319 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp471_ = gxml_node_get_name (_tmp470_);
#line 319 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp472_ = _tmp471_;
#line 319 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp473_ = _tmp472_;
#line 319 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp474_ = g_strcmp0 (_tmp473_, "space") == 0;
#line 319 "SerializableGeeCollections-TDocument-Test.vala"
							_g_free0 (_tmp473_);
#line 319 "SerializableGeeCollections-TDocument-Test.vala"
							if (_tmp474_) {
#line 2920 "SerializableGeeCollections-TDocument-Test.c"
								GXmlNode* _tmp475_;
								GeeMap* _tmp476_;
								GeeMap* _tmp477_;
								GeeMap* _tmp478_;
								gpointer _tmp479_;
								GXmlNode* _tmp480_;
								gchar* _tmp481_;
								gchar* _tmp482_;
								gchar* _tmp483_;
#line 319 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp475_ = s;
#line 319 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp476_ = gxml_node_get_attrs (_tmp475_);
#line 319 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp477_ = _tmp476_;
#line 319 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp478_ = _tmp477_;
#line 319 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp479_ = gee_map_get (_tmp478_, "name");
#line 319 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp480_ = (GXmlNode*) _tmp479_;
#line 319 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp481_ = gxml_node_get_value (_tmp480_);
#line 319 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp482_ = _tmp481_;
#line 319 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp483_ = _tmp482_;
#line 319 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp469_ = g_strcmp0 (_tmp483_, "Beta Centaury") == 0;
#line 319 "SerializableGeeCollections-TDocument-Test.vala"
								_g_free0 (_tmp483_);
#line 319 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp480_);
#line 319 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp478_);
#line 2956 "SerializableGeeCollections-TDocument-Test.c"
							} else {
#line 319 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp469_ = FALSE;
#line 2960 "SerializableGeeCollections-TDocument-Test.c"
							}
#line 319 "SerializableGeeCollections-TDocument-Test.vala"
							if (_tmp469_) {
#line 2964 "SerializableGeeCollections-TDocument-Test.c"
								GXmlNode* _tmp484_;
								GeeMap* _tmp485_;
								GeeMap* _tmp486_;
								GeeMap* _tmp487_;
								gpointer _tmp488_;
								GXmlNode* _tmp489_;
								gchar* _tmp490_;
								gchar* _tmp491_;
								gchar* _tmp492_;
								GXmlNode* _tmp493_;
								GeeBidirList* _tmp494_;
								GeeBidirList* _tmp495_;
								GeeBidirList* _tmp496_;
								gint _tmp497_;
								gint _tmp498_;
								gboolean ftronex = FALSE;
								gboolean fpalax = FALSE;
#line 320 "SerializableGeeCollections-TDocument-Test.vala"
								fbetac = TRUE;
#line 321 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp484_ = s;
#line 321 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp485_ = gxml_node_get_attrs (_tmp484_);
#line 321 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp486_ = _tmp485_;
#line 321 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp487_ = _tmp486_;
#line 321 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp488_ = gee_map_get (_tmp487_, "name");
#line 321 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp489_ = (GXmlNode*) _tmp488_;
#line 321 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp490_ = gxml_node_get_value (_tmp489_);
#line 321 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp491_ = _tmp490_;
#line 321 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp492_ = _tmp491_;
#line 321 "SerializableGeeCollections-TDocument-Test.vala"
								_vala_assert (g_strcmp0 (_tmp492_, "Beta Centaury") == 0, "s.attrs.get (\"name\").value == \"Beta Centaury\"");
#line 321 "SerializableGeeCollections-TDocument-Test.vala"
								_g_free0 (_tmp492_);
#line 321 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp489_);
#line 321 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp487_);
#line 322 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp493_ = s;
#line 322 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp494_ = gxml_node_get_children_nodes (_tmp493_);
#line 322 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp495_ = _tmp494_;
#line 322 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp496_ = _tmp495_;
#line 322 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp497_ = gee_collection_get_size ((GeeCollection*) _tmp496_);
#line 322 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp498_ = _tmp497_;
#line 322 "SerializableGeeCollections-TDocument-Test.vala"
								_vala_assert (_tmp498_ == 2, "s.children_nodes.size == 2");
#line 322 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp496_);
#line 323 "SerializableGeeCollections-TDocument-Test.vala"
								ftronex = FALSE;
#line 324 "SerializableGeeCollections-TDocument-Test.vala"
								fpalax = FALSE;
#line 3030 "SerializableGeeCollections-TDocument-Test.c"
								{
									GeeBidirList* _p_list = NULL;
									GXmlNode* _tmp499_;
									GeeBidirList* _tmp500_;
									GeeBidirList* _tmp501_;
									gint _p_size = 0;
									GeeBidirList* _tmp502_;
									gint _tmp503_;
									gint _tmp504_;
									gint _p_index = 0;
#line 325 "SerializableGeeCollections-TDocument-Test.vala"
									_tmp499_ = s;
#line 325 "SerializableGeeCollections-TDocument-Test.vala"
									_tmp500_ = gxml_node_get_children_nodes (_tmp499_);
#line 325 "SerializableGeeCollections-TDocument-Test.vala"
									_tmp501_ = _tmp500_;
#line 325 "SerializableGeeCollections-TDocument-Test.vala"
									_p_list = _tmp501_;
#line 325 "SerializableGeeCollections-TDocument-Test.vala"
									_tmp502_ = _p_list;
#line 325 "SerializableGeeCollections-TDocument-Test.vala"
									_tmp503_ = gee_collection_get_size ((GeeCollection*) _tmp502_);
#line 325 "SerializableGeeCollections-TDocument-Test.vala"
									_tmp504_ = _tmp503_;
#line 325 "SerializableGeeCollections-TDocument-Test.vala"
									_p_size = _tmp504_;
#line 325 "SerializableGeeCollections-TDocument-Test.vala"
									_p_index = -1;
#line 325 "SerializableGeeCollections-TDocument-Test.vala"
									while (TRUE) {
#line 3061 "SerializableGeeCollections-TDocument-Test.c"
										GXmlNode* p = NULL;
										GeeBidirList* _tmp505_;
										gpointer _tmp506_;
										gboolean _tmp507_ = FALSE;
										GXmlNode* _tmp508_;
										gchar* _tmp509_;
										gchar* _tmp510_;
										gchar* _tmp511_;
										gboolean _tmp512_;
										gboolean _tmp587_ = FALSE;
										GXmlNode* _tmp588_;
										gchar* _tmp589_;
										gchar* _tmp590_;
										gchar* _tmp591_;
										gboolean _tmp592_;
#line 325 "SerializableGeeCollections-TDocument-Test.vala"
										_p_index = _p_index + 1;
#line 325 "SerializableGeeCollections-TDocument-Test.vala"
										if (!(_p_index < _p_size)) {
#line 325 "SerializableGeeCollections-TDocument-Test.vala"
											break;
#line 3083 "SerializableGeeCollections-TDocument-Test.c"
										}
#line 325 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp505_ = _p_list;
#line 325 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp506_ = gee_list_get ((GeeList*) _tmp505_, _p_index);
#line 325 "SerializableGeeCollections-TDocument-Test.vala"
										p = (GXmlNode*) _tmp506_;
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp508_ = p;
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp509_ = gxml_node_get_name (_tmp508_);
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp510_ = _tmp509_;
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp511_ = _tmp510_;
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp512_ = g_strcmp0 (_tmp511_, "planet") == 0;
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
										_g_free0 (_tmp511_);
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
										if (_tmp512_) {
#line 3105 "SerializableGeeCollections-TDocument-Test.c"
											GXmlNode* _tmp513_;
											GeeMap* _tmp514_;
											GeeMap* _tmp515_;
											GeeMap* _tmp516_;
											gpointer _tmp517_;
											GXmlNode* _tmp518_;
											gchar* _tmp519_;
											gchar* _tmp520_;
											gchar* _tmp521_;
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp513_ = p;
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp514_ = gxml_node_get_attrs (_tmp513_);
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp515_ = _tmp514_;
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp516_ = _tmp515_;
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp517_ = gee_map_get (_tmp516_, "name");
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp518_ = (GXmlNode*) _tmp517_;
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp519_ = gxml_node_get_value (_tmp518_);
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp520_ = _tmp519_;
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp521_ = _tmp520_;
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp507_ = g_strcmp0 (_tmp521_, "Tronex") == 0;
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp521_);
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp518_);
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp516_);
#line 3141 "SerializableGeeCollections-TDocument-Test.c"
										} else {
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp507_ = FALSE;
#line 3145 "SerializableGeeCollections-TDocument-Test.c"
										}
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
										if (_tmp507_) {
#line 3149 "SerializableGeeCollections-TDocument-Test.c"
											GXmlNode* _tmp522_;
											gchar* _tmp523_;
											gchar* _tmp524_;
											gchar* _tmp525_;
											GXmlNode* _tmp526_;
											GeeMap* _tmp527_;
											GeeMap* _tmp528_;
											GeeMap* _tmp529_;
											gpointer _tmp530_;
											GXmlNode* _tmp531_;
											gchar* _tmp532_;
											gchar* _tmp533_;
											gchar* _tmp534_;
											GXmlNode* _tmp535_;
											GeeBidirList* _tmp536_;
											GeeBidirList* _tmp537_;
											GeeBidirList* _tmp538_;
											gint _tmp539_;
											gint _tmp540_;
											GXmlNode* cp = NULL;
											GXmlNode* _tmp541_;
											GeeBidirList* _tmp542_;
											GeeBidirList* _tmp543_;
											GeeBidirList* _tmp544_;
											gpointer _tmp545_;
											GXmlNode* _tmp546_;
											GXmlNode* _tmp547_;
											gchar* _tmp548_;
											gchar* _tmp549_;
											gchar* _tmp550_;
											GXmlNode* _tmp551_;
											GeeMap* _tmp552_;
											GeeMap* _tmp553_;
											GeeMap* _tmp554_;
											gpointer _tmp555_;
											GXmlNode* _tmp556_;
											gchar* _tmp557_;
											gchar* _tmp558_;
											gchar* _tmp559_;
											GXmlNode* _tmp560_;
											gchar* _tmp561_;
											gchar* _tmp562_;
											gchar* _tmp563_;
											GXmlNode* cp2 = NULL;
											GXmlNode* _tmp564_;
											GeeBidirList* _tmp565_;
											GeeBidirList* _tmp566_;
											GeeBidirList* _tmp567_;
											gpointer _tmp568_;
											GXmlNode* _tmp569_;
											GXmlNode* _tmp570_;
											gchar* _tmp571_;
											gchar* _tmp572_;
											gchar* _tmp573_;
											GXmlNode* _tmp574_;
											GeeMap* _tmp575_;
											GeeMap* _tmp576_;
											GeeMap* _tmp577_;
											gpointer _tmp578_;
											GXmlNode* _tmp579_;
											gchar* _tmp580_;
											gchar* _tmp581_;
											gchar* _tmp582_;
											GXmlNode* _tmp583_;
											gchar* _tmp584_;
											gchar* _tmp585_;
											gchar* _tmp586_;
#line 327 "SerializableGeeCollections-TDocument-Test.vala"
											ftronex = TRUE;
#line 328 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp522_ = p;
#line 328 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp523_ = gxml_node_get_name (_tmp522_);
#line 328 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp524_ = _tmp523_;
#line 328 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp525_ = _tmp524_;
#line 328 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp525_, "planet") == 0, "p.name == \"planet\"");
#line 328 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp525_);
#line 329 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp526_ = p;
#line 329 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp527_ = gxml_node_get_attrs (_tmp526_);
#line 329 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp528_ = _tmp527_;
#line 329 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp529_ = _tmp528_;
#line 329 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp530_ = gee_map_get (_tmp529_, "name");
#line 329 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp531_ = (GXmlNode*) _tmp530_;
#line 329 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp532_ = gxml_node_get_value (_tmp531_);
#line 329 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp533_ = _tmp532_;
#line 329 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp534_ = _tmp533_;
#line 329 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp534_, "Tronex") == 0, "p.attrs.get (\"name\").value == \"Tronex\"");
#line 329 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp534_);
#line 329 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp531_);
#line 329 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp529_);
#line 330 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp535_ = p;
#line 330 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp536_ = gxml_node_get_children_nodes (_tmp535_);
#line 330 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp537_ = _tmp536_;
#line 330 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp538_ = _tmp537_;
#line 330 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp539_ = gee_collection_get_size ((GeeCollection*) _tmp538_);
#line 330 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp540_ = _tmp539_;
#line 330 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (_tmp540_ == 2, "p.children_nodes.size == 2");
#line 330 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp538_);
#line 331 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp541_ = p;
#line 331 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp542_ = gxml_node_get_children_nodes (_tmp541_);
#line 331 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp543_ = _tmp542_;
#line 331 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp544_ = _tmp543_;
#line 331 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp545_ = gee_list_get ((GeeList*) _tmp544_, 0);
#line 331 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp546_ = (GXmlNode*) _tmp545_;
#line 331 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp544_);
#line 331 "SerializableGeeCollections-TDocument-Test.vala"
											cp = _tmp546_;
#line 332 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp547_ = cp;
#line 332 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp548_ = gxml_node_get_name (_tmp547_);
#line 332 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp549_ = _tmp548_;
#line 332 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp550_ = _tmp549_;
#line 332 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp550_, "citizen") == 0, "cp.name == \"citizen\"");
#line 332 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp550_);
#line 333 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp551_ = cp;
#line 333 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp552_ = gxml_node_get_attrs (_tmp551_);
#line 333 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp553_ = _tmp552_;
#line 333 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp554_ = _tmp553_;
#line 333 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp555_ = gee_map_get (_tmp554_, "ctype");
#line 333 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp556_ = (GXmlNode*) _tmp555_;
#line 333 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp557_ = gxml_node_get_value (_tmp556_);
#line 333 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp558_ = _tmp557_;
#line 333 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp559_ = _tmp558_;
#line 333 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp559_, "Human") == 0, "cp.attrs.get (\"ctype\").value == \"Human\"");
#line 333 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp559_);
#line 333 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp556_);
#line 333 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp554_);
#line 334 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp560_ = cp;
#line 334 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp561_ = gxml_element_get_content (G_TYPE_CHECK_INSTANCE_CAST (_tmp560_, GXML_TYPE_ELEMENT, GXmlElement));
#line 334 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp562_ = _tmp561_;
#line 334 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp563_ = _tmp562_;
#line 334 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp563_, "10000M") == 0, "((Element)cp).content == \"10000M\"");
#line 334 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp563_);
#line 335 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp564_ = p;
#line 335 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp565_ = gxml_node_get_children_nodes (_tmp564_);
#line 335 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp566_ = _tmp565_;
#line 335 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp567_ = _tmp566_;
#line 335 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp568_ = gee_list_get ((GeeList*) _tmp567_, 1);
#line 335 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp569_ = (GXmlNode*) _tmp568_;
#line 335 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp567_);
#line 335 "SerializableGeeCollections-TDocument-Test.vala"
											cp2 = _tmp569_;
#line 336 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp570_ = cp2;
#line 336 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp571_ = gxml_node_get_name (_tmp570_);
#line 336 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp572_ = _tmp571_;
#line 336 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp573_ = _tmp572_;
#line 336 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp573_, "citizen") == 0, "cp2.name == \"citizen\"");
#line 336 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp573_);
#line 337 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp574_ = cp2;
#line 337 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp575_ = gxml_node_get_attrs (_tmp574_);
#line 337 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp576_ = _tmp575_;
#line 337 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp577_ = _tmp576_;
#line 337 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp578_ = gee_map_get (_tmp577_, "ctype");
#line 337 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp579_ = (GXmlNode*) _tmp578_;
#line 337 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp580_ = gxml_node_get_value (_tmp579_);
#line 337 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp581_ = _tmp580_;
#line 337 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp582_ = _tmp581_;
#line 337 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp582_, "Cat") == 0, "cp2.attrs.get (\"ctype\").value == \"Cat\"");
#line 337 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp582_);
#line 337 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp579_);
#line 337 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp577_);
#line 338 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp583_ = cp2;
#line 338 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp584_ = gxml_element_get_content (G_TYPE_CHECK_INSTANCE_CAST (_tmp583_, GXML_TYPE_ELEMENT, GXmlElement));
#line 338 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp585_ = _tmp584_;
#line 338 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp586_ = _tmp585_;
#line 338 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp586_, "100000M") == 0, "((Element)cp2).content == \"100000M\"");
#line 338 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp586_);
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (cp2);
#line 326 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (cp);
#line 3409 "SerializableGeeCollections-TDocument-Test.c"
										}
#line 340 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp588_ = p;
#line 340 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp589_ = gxml_node_get_name (_tmp588_);
#line 340 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp590_ = _tmp589_;
#line 340 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp591_ = _tmp590_;
#line 340 "SerializableGeeCollections-TDocument-Test.vala"
										_tmp592_ = g_strcmp0 (_tmp591_, "planet") == 0;
#line 340 "SerializableGeeCollections-TDocument-Test.vala"
										_g_free0 (_tmp591_);
#line 340 "SerializableGeeCollections-TDocument-Test.vala"
										if (_tmp592_) {
#line 3425 "SerializableGeeCollections-TDocument-Test.c"
											GXmlNode* _tmp593_;
											GeeMap* _tmp594_;
											GeeMap* _tmp595_;
											GeeMap* _tmp596_;
											gpointer _tmp597_;
											GXmlNode* _tmp598_;
											gchar* _tmp599_;
											gchar* _tmp600_;
											gchar* _tmp601_;
#line 340 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp593_ = p;
#line 340 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp594_ = gxml_node_get_attrs (_tmp593_);
#line 340 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp595_ = _tmp594_;
#line 340 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp596_ = _tmp595_;
#line 340 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp597_ = gee_map_get (_tmp596_, "name");
#line 340 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp598_ = (GXmlNode*) _tmp597_;
#line 340 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp599_ = gxml_node_get_value (_tmp598_);
#line 340 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp600_ = _tmp599_;
#line 340 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp601_ = _tmp600_;
#line 340 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp587_ = g_strcmp0 (_tmp601_, "Palax") == 0;
#line 340 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp601_);
#line 340 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp598_);
#line 340 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp596_);
#line 3461 "SerializableGeeCollections-TDocument-Test.c"
										} else {
#line 340 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp587_ = FALSE;
#line 3465 "SerializableGeeCollections-TDocument-Test.c"
										}
#line 340 "SerializableGeeCollections-TDocument-Test.vala"
										if (_tmp587_) {
#line 3469 "SerializableGeeCollections-TDocument-Test.c"
											GXmlNode* _tmp602_;
											gchar* _tmp603_;
											gchar* _tmp604_;
											gchar* _tmp605_;
											GXmlNode* _tmp606_;
											GeeMap* _tmp607_;
											GeeMap* _tmp608_;
											GeeMap* _tmp609_;
											gpointer _tmp610_;
											GXmlNode* _tmp611_;
											gchar* _tmp612_;
											gchar* _tmp613_;
											gchar* _tmp614_;
											GXmlNode* _tmp615_;
											GeeBidirList* _tmp616_;
											GeeBidirList* _tmp617_;
											GeeBidirList* _tmp618_;
											gint _tmp619_;
											gint _tmp620_;
#line 341 "SerializableGeeCollections-TDocument-Test.vala"
											fpalax = TRUE;
#line 342 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp602_ = p;
#line 342 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp603_ = gxml_node_get_name (_tmp602_);
#line 342 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp604_ = _tmp603_;
#line 342 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp605_ = _tmp604_;
#line 342 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp605_, "planet") == 0, "p.name == \"planet\"");
#line 342 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp605_);
#line 343 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp606_ = p;
#line 343 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp607_ = gxml_node_get_attrs (_tmp606_);
#line 343 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp608_ = _tmp607_;
#line 343 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp609_ = _tmp608_;
#line 343 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp610_ = gee_map_get (_tmp609_, "name");
#line 343 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp611_ = (GXmlNode*) _tmp610_;
#line 343 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp612_ = gxml_node_get_value (_tmp611_);
#line 343 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp613_ = _tmp612_;
#line 343 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp614_ = _tmp613_;
#line 343 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (g_strcmp0 (_tmp614_, "Palax") == 0, "p.attrs.get (\"name\").value == \"Palax\"");
#line 343 "SerializableGeeCollections-TDocument-Test.vala"
											_g_free0 (_tmp614_);
#line 343 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp611_);
#line 343 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp609_);
#line 344 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp615_ = p;
#line 344 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp616_ = gxml_node_get_children_nodes (_tmp615_);
#line 344 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp617_ = _tmp616_;
#line 344 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp618_ = _tmp617_;
#line 344 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp619_ = gee_collection_get_size ((GeeCollection*) _tmp618_);
#line 344 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp620_ = _tmp619_;
#line 344 "SerializableGeeCollections-TDocument-Test.vala"
											_vala_assert (_tmp620_ == 0, "p.children_nodes.size == 0");
#line 344 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_tmp618_);
#line 3545 "SerializableGeeCollections-TDocument-Test.c"
										}
#line 325 "SerializableGeeCollections-TDocument-Test.vala"
										_g_object_unref0 (p);
#line 3549 "SerializableGeeCollections-TDocument-Test.c"
									}
#line 325 "SerializableGeeCollections-TDocument-Test.vala"
									_g_object_unref0 (_p_list);
#line 3553 "SerializableGeeCollections-TDocument-Test.c"
								}
#line 347 "SerializableGeeCollections-TDocument-Test.vala"
								_vala_assert (ftronex, "ftronex");
#line 348 "SerializableGeeCollections-TDocument-Test.vala"
								_vala_assert (fpalax, "fpalax");
#line 3559 "SerializableGeeCollections-TDocument-Test.c"
							}
#line 350 "SerializableGeeCollections-TDocument-Test.vala"
							_vala_assert (fbetac, "fbetac");
#line 318 "SerializableGeeCollections-TDocument-Test.vala"
							_g_object_unref0 (s);
#line 3565 "SerializableGeeCollections-TDocument-Test.c"
						}
#line 318 "SerializableGeeCollections-TDocument-Test.vala"
						_g_object_unref0 (_s_list);
#line 3569 "SerializableGeeCollections-TDocument-Test.c"
					}
				}
#line 241 "SerializableGeeCollections-TDocument-Test.vala"
				_g_object_unref0 (sh);
#line 3574 "SerializableGeeCollections-TDocument-Test.c"
			}
#line 241 "SerializableGeeCollections-TDocument-Test.vala"
			_g_object_unref0 (_sh_list);
#line 3578 "SerializableGeeCollections-TDocument-Test.c"
		}
#line 354 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (fmactoy, "fmactoy");
#line 355 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (fmemphis, "fmemphis");
#line 356 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp621_ = ndoc;
#line 356 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp622_ = gxml_document_get_root ((GXmlDocument*) _tmp621_);
#line 356 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp623_ = _tmp622_;
#line 356 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp624_ = _tmp623_;
#line 356 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp625_ = gxml_node_get_children_nodes (_tmp624_);
#line 356 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp626_ = _tmp625_;
#line 356 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp627_ = _tmp626_;
#line 356 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp628_ = gee_list_get ((GeeList*) _tmp627_, 1);
#line 356 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp629_ = (GXmlNode*) _tmp628_;
#line 356 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp627_);
#line 356 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp624_);
#line 356 "SerializableGeeCollections-TDocument-Test.vala"
		st = _tmp629_;
#line 357 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp630_ = st;
#line 357 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (_tmp630_ != NULL, "st != null");
#line 358 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp631_ = st;
#line 358 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp632_ = gxml_node_get_name (_tmp631_);
#line 358 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp633_ = _tmp632_;
#line 358 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp634_ = _tmp633_;
#line 358 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp635_ = g_utf8_strdown (_tmp634_, (gssize) -1);
#line 358 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp636_ = _tmp635_;
#line 358 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (g_strcmp0 (_tmp636_, "storage") == 0, "st.name.down () == \"storage\"");
#line 358 "SerializableGeeCollections-TDocument-Test.vala"
		_g_free0 (_tmp636_);
#line 358 "SerializableGeeCollections-TDocument-Test.vala"
		_g_free0 (_tmp634_);
#line 359 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp637_ = st;
#line 359 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp638_ = gxml_node_get_attrs (_tmp637_);
#line 359 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp639_ = _tmp638_;
#line 359 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp640_ = _tmp639_;
#line 359 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp641_ = gee_map_get (_tmp640_, "name");
#line 359 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp642_ = (GXmlNode*) _tmp641_;
#line 359 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp643_ = gxml_node_get_value (_tmp642_);
#line 359 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp644_ = _tmp643_;
#line 359 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp645_ = _tmp644_;
#line 359 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (g_strcmp0 (_tmp645_, "B4-A4") == 0, "st.attrs.get (\"name\").value == \"B4-A4\"");
#line 359 "SerializableGeeCollections-TDocument-Test.vala"
		_g_free0 (_tmp645_);
#line 359 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp642_);
#line 359 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp640_);
#line 360 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp646_ = st;
#line 360 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp647_ = gxml_node_get_children_nodes (_tmp646_);
#line 360 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp648_ = _tmp647_;
#line 360 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp649_ = _tmp648_;
#line 360 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp650_ = gee_collection_get_size ((GeeCollection*) _tmp649_);
#line 360 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp651_ = _tmp650_;
#line 360 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (_tmp651_ == 1, "st.children_nodes.size == 1");
#line 360 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp649_);
#line 361 "SerializableGeeCollections-TDocument-Test.vala"
		fr = FALSE;
#line 3674 "SerializableGeeCollections-TDocument-Test.c"
		{
			GeeBidirList* _r_list = NULL;
			GXmlNode* _tmp652_;
			GeeBidirList* _tmp653_;
			GeeBidirList* _tmp654_;
			gint _r_size = 0;
			GeeBidirList* _tmp655_;
			gint _tmp656_;
			gint _tmp657_;
			gint _r_index = 0;
#line 362 "SerializableGeeCollections-TDocument-Test.vala"
			_tmp652_ = st;
#line 362 "SerializableGeeCollections-TDocument-Test.vala"
			_tmp653_ = gxml_node_get_children_nodes (_tmp652_);
#line 362 "SerializableGeeCollections-TDocument-Test.vala"
			_tmp654_ = _tmp653_;
#line 362 "SerializableGeeCollections-TDocument-Test.vala"
			_r_list = _tmp654_;
#line 362 "SerializableGeeCollections-TDocument-Test.vala"
			_tmp655_ = _r_list;
#line 362 "SerializableGeeCollections-TDocument-Test.vala"
			_tmp656_ = gee_collection_get_size ((GeeCollection*) _tmp655_);
#line 362 "SerializableGeeCollections-TDocument-Test.vala"
			_tmp657_ = _tmp656_;
#line 362 "SerializableGeeCollections-TDocument-Test.vala"
			_r_size = _tmp657_;
#line 362 "SerializableGeeCollections-TDocument-Test.vala"
			_r_index = -1;
#line 362 "SerializableGeeCollections-TDocument-Test.vala"
			while (TRUE) {
#line 3705 "SerializableGeeCollections-TDocument-Test.c"
				GXmlNode* r = NULL;
				GeeBidirList* _tmp658_;
				gpointer _tmp659_;
				gboolean _tmp660_ = FALSE;
				GXmlNode* _tmp661_;
				gchar* _tmp662_;
				gchar* _tmp663_;
				gchar* _tmp664_;
				gboolean _tmp665_;
#line 362 "SerializableGeeCollections-TDocument-Test.vala"
				_r_index = _r_index + 1;
#line 362 "SerializableGeeCollections-TDocument-Test.vala"
				if (!(_r_index < _r_size)) {
#line 362 "SerializableGeeCollections-TDocument-Test.vala"
					break;
#line 3721 "SerializableGeeCollections-TDocument-Test.c"
				}
#line 362 "SerializableGeeCollections-TDocument-Test.vala"
				_tmp658_ = _r_list;
#line 362 "SerializableGeeCollections-TDocument-Test.vala"
				_tmp659_ = gee_list_get ((GeeList*) _tmp658_, _r_index);
#line 362 "SerializableGeeCollections-TDocument-Test.vala"
				r = (GXmlNode*) _tmp659_;
#line 363 "SerializableGeeCollections-TDocument-Test.vala"
				_tmp661_ = r;
#line 363 "SerializableGeeCollections-TDocument-Test.vala"
				_tmp662_ = gxml_node_get_name (_tmp661_);
#line 363 "SerializableGeeCollections-TDocument-Test.vala"
				_tmp663_ = _tmp662_;
#line 363 "SerializableGeeCollections-TDocument-Test.vala"
				_tmp664_ = _tmp663_;
#line 363 "SerializableGeeCollections-TDocument-Test.vala"
				_tmp665_ = g_strcmp0 (_tmp664_, "refaction") == 0;
#line 363 "SerializableGeeCollections-TDocument-Test.vala"
				_g_free0 (_tmp664_);
#line 363 "SerializableGeeCollections-TDocument-Test.vala"
				if (_tmp665_) {
#line 3743 "SerializableGeeCollections-TDocument-Test.c"
					GXmlNode* _tmp666_;
					GeeMap* _tmp667_;
					GeeMap* _tmp668_;
					GeeMap* _tmp669_;
					gpointer _tmp670_;
					GXmlNode* _tmp671_;
					gchar* _tmp672_;
					gchar* _tmp673_;
					gchar* _tmp674_;
#line 363 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp666_ = r;
#line 363 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp667_ = gxml_node_get_attrs (_tmp666_);
#line 363 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp668_ = _tmp667_;
#line 363 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp669_ = _tmp668_;
#line 363 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp670_ = gee_map_get (_tmp669_, "manufacturer");
#line 363 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp671_ = (GXmlNode*) _tmp670_;
#line 363 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp672_ = gxml_node_get_value (_tmp671_);
#line 363 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp673_ = _tmp672_;
#line 363 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp674_ = _tmp673_;
#line 363 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp660_ = g_strcmp0 (_tmp674_, "MacToy") == 0;
#line 363 "SerializableGeeCollections-TDocument-Test.vala"
					_g_free0 (_tmp674_);
#line 363 "SerializableGeeCollections-TDocument-Test.vala"
					_g_object_unref0 (_tmp671_);
#line 363 "SerializableGeeCollections-TDocument-Test.vala"
					_g_object_unref0 (_tmp669_);
#line 3779 "SerializableGeeCollections-TDocument-Test.c"
				} else {
#line 363 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp660_ = FALSE;
#line 3783 "SerializableGeeCollections-TDocument-Test.c"
				}
#line 363 "SerializableGeeCollections-TDocument-Test.vala"
				if (_tmp660_) {
#line 3787 "SerializableGeeCollections-TDocument-Test.c"
					GXmlNode* _tmp675_;
					gchar* _tmp676_;
					gchar* _tmp677_;
					gchar* _tmp678_;
					GXmlNode* _tmp679_;
					GeeMap* _tmp680_;
					GeeMap* _tmp681_;
					GeeMap* _tmp682_;
					gpointer _tmp683_;
					GXmlNode* _tmp684_;
					gchar* _tmp685_;
					gchar* _tmp686_;
					gchar* _tmp687_;
					GXmlNode* _tmp688_;
					GeeMap* _tmp689_;
					GeeMap* _tmp690_;
					GeeMap* _tmp691_;
					gpointer _tmp692_;
					GXmlNode* _tmp693_;
					gchar* _tmp694_;
					gchar* _tmp695_;
					gchar* _tmp696_;
					GXmlNode* _tmp697_;
					GeeBidirList* _tmp698_;
					GeeBidirList* _tmp699_;
					GeeBidirList* _tmp700_;
					gint _tmp701_;
					gint _tmp702_;
					gboolean frmactoy = FALSE;
					gboolean frmega = FALSE;
#line 364 "SerializableGeeCollections-TDocument-Test.vala"
					fr = TRUE;
#line 365 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp675_ = r;
#line 365 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp676_ = gxml_node_get_name (_tmp675_);
#line 365 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp677_ = _tmp676_;
#line 365 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp678_ = _tmp677_;
#line 365 "SerializableGeeCollections-TDocument-Test.vala"
					_vala_assert (g_strcmp0 (_tmp678_, "refaction") == 0, "r.name == \"refaction\"");
#line 365 "SerializableGeeCollections-TDocument-Test.vala"
					_g_free0 (_tmp678_);
#line 366 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp679_ = r;
#line 366 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp680_ = gxml_node_get_attrs (_tmp679_);
#line 366 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp681_ = _tmp680_;
#line 366 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp682_ = _tmp681_;
#line 366 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp683_ = gee_map_get (_tmp682_, "manufacturer");
#line 366 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp684_ = (GXmlNode*) _tmp683_;
#line 366 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp685_ = gxml_node_get_value (_tmp684_);
#line 366 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp686_ = _tmp685_;
#line 366 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp687_ = _tmp686_;
#line 366 "SerializableGeeCollections-TDocument-Test.vala"
					_vala_assert (g_strcmp0 (_tmp687_, "MacToy") == 0, "r.attrs.get (\"manufacturer\").value == \"MacToy\"");
#line 366 "SerializableGeeCollections-TDocument-Test.vala"
					_g_free0 (_tmp687_);
#line 366 "SerializableGeeCollections-TDocument-Test.vala"
					_g_object_unref0 (_tmp684_);
#line 366 "SerializableGeeCollections-TDocument-Test.vala"
					_g_object_unref0 (_tmp682_);
#line 367 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp688_ = r;
#line 367 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp689_ = gxml_node_get_attrs (_tmp688_);
#line 367 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp690_ = _tmp689_;
#line 367 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp691_ = _tmp690_;
#line 367 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp692_ = gee_map_get (_tmp691_, "model");
#line 367 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp693_ = (GXmlNode*) _tmp692_;
#line 367 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp694_ = gxml_node_get_value (_tmp693_);
#line 367 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp695_ = _tmp694_;
#line 367 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp696_ = _tmp695_;
#line 367 "SerializableGeeCollections-TDocument-Test.vala"
					_vala_assert (g_strcmp0 (_tmp696_, "Fly045") == 0, "r.attrs.get (\"model\").value == \"Fly045\"");
#line 367 "SerializableGeeCollections-TDocument-Test.vala"
					_g_free0 (_tmp696_);
#line 367 "SerializableGeeCollections-TDocument-Test.vala"
					_g_object_unref0 (_tmp693_);
#line 367 "SerializableGeeCollections-TDocument-Test.vala"
					_g_object_unref0 (_tmp691_);
#line 368 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp697_ = r;
#line 368 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp698_ = gxml_node_get_children_nodes (_tmp697_);
#line 368 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp699_ = _tmp698_;
#line 368 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp700_ = _tmp699_;
#line 368 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp701_ = gee_collection_get_size ((GeeCollection*) _tmp700_);
#line 368 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp702_ = _tmp701_;
#line 368 "SerializableGeeCollections-TDocument-Test.vala"
					_vala_assert (_tmp702_ == 5, "r.children_nodes.size == 5");
#line 368 "SerializableGeeCollections-TDocument-Test.vala"
					_g_object_unref0 (_tmp700_);
#line 369 "SerializableGeeCollections-TDocument-Test.vala"
					frmactoy = FALSE;
#line 370 "SerializableGeeCollections-TDocument-Test.vala"
					frmega = FALSE;
#line 3904 "SerializableGeeCollections-TDocument-Test.c"
					{
						GeeBidirList* _rsh_list = NULL;
						GXmlNode* _tmp703_;
						GeeBidirList* _tmp704_;
						GeeBidirList* _tmp705_;
						gint _rsh_size = 0;
						GeeBidirList* _tmp706_;
						gint _tmp707_;
						gint _tmp708_;
						gint _rsh_index = 0;
#line 371 "SerializableGeeCollections-TDocument-Test.vala"
						_tmp703_ = r;
#line 371 "SerializableGeeCollections-TDocument-Test.vala"
						_tmp704_ = gxml_node_get_children_nodes (_tmp703_);
#line 371 "SerializableGeeCollections-TDocument-Test.vala"
						_tmp705_ = _tmp704_;
#line 371 "SerializableGeeCollections-TDocument-Test.vala"
						_rsh_list = _tmp705_;
#line 371 "SerializableGeeCollections-TDocument-Test.vala"
						_tmp706_ = _rsh_list;
#line 371 "SerializableGeeCollections-TDocument-Test.vala"
						_tmp707_ = gee_collection_get_size ((GeeCollection*) _tmp706_);
#line 371 "SerializableGeeCollections-TDocument-Test.vala"
						_tmp708_ = _tmp707_;
#line 371 "SerializableGeeCollections-TDocument-Test.vala"
						_rsh_size = _tmp708_;
#line 371 "SerializableGeeCollections-TDocument-Test.vala"
						_rsh_index = -1;
#line 371 "SerializableGeeCollections-TDocument-Test.vala"
						while (TRUE) {
#line 3935 "SerializableGeeCollections-TDocument-Test.c"
							GXmlNode* rsh = NULL;
							GeeBidirList* _tmp709_;
							gpointer _tmp710_;
							gboolean _tmp711_ = FALSE;
							GXmlNode* _tmp712_;
							gchar* _tmp713_;
							gchar* _tmp714_;
							gchar* _tmp715_;
							gboolean _tmp716_;
							gboolean _tmp750_ = FALSE;
							GXmlNode* _tmp751_;
							gchar* _tmp752_;
							gchar* _tmp753_;
							gchar* _tmp754_;
							gboolean _tmp755_;
#line 371 "SerializableGeeCollections-TDocument-Test.vala"
							_rsh_index = _rsh_index + 1;
#line 371 "SerializableGeeCollections-TDocument-Test.vala"
							if (!(_rsh_index < _rsh_size)) {
#line 371 "SerializableGeeCollections-TDocument-Test.vala"
								break;
#line 3957 "SerializableGeeCollections-TDocument-Test.c"
							}
#line 371 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp709_ = _rsh_list;
#line 371 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp710_ = gee_list_get ((GeeList*) _tmp709_, _rsh_index);
#line 371 "SerializableGeeCollections-TDocument-Test.vala"
							rsh = (GXmlNode*) _tmp710_;
#line 372 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp712_ = rsh;
#line 372 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp713_ = gxml_node_get_name (_tmp712_);
#line 372 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp714_ = _tmp713_;
#line 372 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp715_ = _tmp714_;
#line 372 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp716_ = g_strcmp0 (_tmp715_, "ship") == 0;
#line 372 "SerializableGeeCollections-TDocument-Test.vala"
							_g_free0 (_tmp715_);
#line 372 "SerializableGeeCollections-TDocument-Test.vala"
							if (_tmp716_) {
#line 3979 "SerializableGeeCollections-TDocument-Test.c"
								GXmlNode* _tmp717_;
								GeeMap* _tmp718_;
								GeeMap* _tmp719_;
								GeeMap* _tmp720_;
								gpointer _tmp721_;
								GXmlNode* _tmp722_;
								gchar* _tmp723_;
								gchar* _tmp724_;
								gchar* _tmp725_;
#line 372 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp717_ = rsh;
#line 372 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp718_ = gxml_node_get_attrs (_tmp717_);
#line 372 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp719_ = _tmp718_;
#line 372 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp720_ = _tmp719_;
#line 372 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp721_ = gee_map_get (_tmp720_, "manufacturer");
#line 372 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp722_ = (GXmlNode*) _tmp721_;
#line 372 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp723_ = gxml_node_get_value (_tmp722_);
#line 372 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp724_ = _tmp723_;
#line 372 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp725_ = _tmp724_;
#line 372 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp711_ = g_strcmp0 (_tmp725_, "MacToy") == 0;
#line 372 "SerializableGeeCollections-TDocument-Test.vala"
								_g_free0 (_tmp725_);
#line 372 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp722_);
#line 372 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp720_);
#line 4015 "SerializableGeeCollections-TDocument-Test.c"
							} else {
#line 372 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp711_ = FALSE;
#line 4019 "SerializableGeeCollections-TDocument-Test.c"
							}
#line 372 "SerializableGeeCollections-TDocument-Test.vala"
							if (_tmp711_) {
#line 4023 "SerializableGeeCollections-TDocument-Test.c"
								GXmlNode* _tmp726_;
								GeeMap* _tmp727_;
								GeeMap* _tmp728_;
								GeeMap* _tmp729_;
								gpointer _tmp730_;
								GXmlNode* _tmp731_;
								gchar* _tmp732_;
								gchar* _tmp733_;
								gchar* _tmp734_;
								GXmlNode* _tmp735_;
								GeeMap* _tmp736_;
								GeeMap* _tmp737_;
								GeeMap* _tmp738_;
								gpointer _tmp739_;
								GXmlNode* _tmp740_;
								gchar* _tmp741_;
								gchar* _tmp742_;
								gchar* _tmp743_;
								GXmlNode* _tmp744_;
								GeeBidirList* _tmp745_;
								GeeBidirList* _tmp746_;
								GeeBidirList* _tmp747_;
								gint _tmp748_;
								gint _tmp749_;
#line 373 "SerializableGeeCollections-TDocument-Test.vala"
								frmactoy = TRUE;
#line 374 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp726_ = rsh;
#line 374 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp727_ = gxml_node_get_attrs (_tmp726_);
#line 374 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp728_ = _tmp727_;
#line 374 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp729_ = _tmp728_;
#line 374 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp730_ = gee_map_get (_tmp729_, "manufacturer");
#line 374 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp731_ = (GXmlNode*) _tmp730_;
#line 374 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp732_ = gxml_node_get_value (_tmp731_);
#line 374 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp733_ = _tmp732_;
#line 374 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp734_ = _tmp733_;
#line 374 "SerializableGeeCollections-TDocument-Test.vala"
								_vala_assert (g_strcmp0 (_tmp734_, "MacToy") == 0, "rsh.attrs.get (\"manufacturer\").value == \"MacToy\"");
#line 374 "SerializableGeeCollections-TDocument-Test.vala"
								_g_free0 (_tmp734_);
#line 374 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp731_);
#line 374 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp729_);
#line 375 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp735_ = rsh;
#line 375 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp736_ = gxml_node_get_attrs (_tmp735_);
#line 375 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp737_ = _tmp736_;
#line 375 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp738_ = _tmp737_;
#line 375 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp739_ = gee_map_get (_tmp738_, "model");
#line 375 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp740_ = (GXmlNode*) _tmp739_;
#line 375 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp741_ = gxml_node_get_value (_tmp740_);
#line 375 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp742_ = _tmp741_;
#line 375 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp743_ = _tmp742_;
#line 375 "SerializableGeeCollections-TDocument-Test.vala"
								_vala_assert (g_strcmp0 (_tmp743_, "A1234") == 0, "rsh.attrs.get (\"model\").value == \"A1234\"");
#line 375 "SerializableGeeCollections-TDocument-Test.vala"
								_g_free0 (_tmp743_);
#line 375 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp740_);
#line 375 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp738_);
#line 376 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp744_ = rsh;
#line 376 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp745_ = gxml_node_get_children_nodes (_tmp744_);
#line 376 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp746_ = _tmp745_;
#line 376 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp747_ = _tmp746_;
#line 376 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp748_ = gee_collection_get_size ((GeeCollection*) _tmp747_);
#line 376 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp749_ = _tmp748_;
#line 376 "SerializableGeeCollections-TDocument-Test.vala"
								_vala_assert (_tmp749_ == 0, "rsh.children_nodes.size == 0");
#line 376 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp747_);
#line 4118 "SerializableGeeCollections-TDocument-Test.c"
							}
#line 378 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp751_ = rsh;
#line 378 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp752_ = gxml_node_get_name (_tmp751_);
#line 378 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp753_ = _tmp752_;
#line 378 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp754_ = _tmp753_;
#line 378 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp755_ = g_strcmp0 (_tmp754_, "ship") == 0;
#line 378 "SerializableGeeCollections-TDocument-Test.vala"
							_g_free0 (_tmp754_);
#line 378 "SerializableGeeCollections-TDocument-Test.vala"
							if (_tmp755_) {
#line 4134 "SerializableGeeCollections-TDocument-Test.c"
								GXmlNode* _tmp756_;
								GeeMap* _tmp757_;
								GeeMap* _tmp758_;
								GeeMap* _tmp759_;
								gpointer _tmp760_;
								GXmlNode* _tmp761_;
								gchar* _tmp762_;
								gchar* _tmp763_;
								gchar* _tmp764_;
#line 378 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp756_ = rsh;
#line 378 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp757_ = gxml_node_get_attrs (_tmp756_);
#line 378 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp758_ = _tmp757_;
#line 378 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp759_ = _tmp758_;
#line 378 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp760_ = gee_map_get (_tmp759_, "manufacturer");
#line 378 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp761_ = (GXmlNode*) _tmp760_;
#line 378 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp762_ = gxml_node_get_value (_tmp761_);
#line 378 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp763_ = _tmp762_;
#line 378 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp764_ = _tmp763_;
#line 378 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp750_ = g_strcmp0 (_tmp764_, "MegaTrench") == 0;
#line 378 "SerializableGeeCollections-TDocument-Test.vala"
								_g_free0 (_tmp764_);
#line 378 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp761_);
#line 378 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp759_);
#line 4170 "SerializableGeeCollections-TDocument-Test.c"
							} else {
#line 378 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp750_ = FALSE;
#line 4174 "SerializableGeeCollections-TDocument-Test.c"
							}
#line 378 "SerializableGeeCollections-TDocument-Test.vala"
							if (_tmp750_) {
#line 4178 "SerializableGeeCollections-TDocument-Test.c"
								GXmlNode* _tmp765_;
								GeeMap* _tmp766_;
								GeeMap* _tmp767_;
								GeeMap* _tmp768_;
								gpointer _tmp769_;
								GXmlNode* _tmp770_;
								gchar* _tmp771_;
								gchar* _tmp772_;
								gchar* _tmp773_;
								GXmlNode* _tmp774_;
								GeeMap* _tmp775_;
								GeeMap* _tmp776_;
								GeeMap* _tmp777_;
								gpointer _tmp778_;
								GXmlNode* _tmp779_;
								gchar* _tmp780_;
								gchar* _tmp781_;
								gchar* _tmp782_;
								GXmlNode* _tmp783_;
								GeeBidirList* _tmp784_;
								GeeBidirList* _tmp785_;
								GeeBidirList* _tmp786_;
								gint _tmp787_;
								gint _tmp788_;
#line 379 "SerializableGeeCollections-TDocument-Test.vala"
								frmega = TRUE;
#line 380 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp765_ = rsh;
#line 380 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp766_ = gxml_node_get_attrs (_tmp765_);
#line 380 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp767_ = _tmp766_;
#line 380 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp768_ = _tmp767_;
#line 380 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp769_ = gee_map_get (_tmp768_, "manufacturer");
#line 380 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp770_ = (GXmlNode*) _tmp769_;
#line 380 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp771_ = gxml_node_get_value (_tmp770_);
#line 380 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp772_ = _tmp771_;
#line 380 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp773_ = _tmp772_;
#line 380 "SerializableGeeCollections-TDocument-Test.vala"
								_vala_assert (g_strcmp0 (_tmp773_, "MegaTrench") == 0, "rsh.attrs.get (\"manufacturer\").value == \"MegaTrench\"");
#line 380 "SerializableGeeCollections-TDocument-Test.vala"
								_g_free0 (_tmp773_);
#line 380 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp770_);
#line 380 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp768_);
#line 381 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp774_ = rsh;
#line 381 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp775_ = gxml_node_get_attrs (_tmp774_);
#line 381 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp776_ = _tmp775_;
#line 381 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp777_ = _tmp776_;
#line 381 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp778_ = gee_map_get (_tmp777_, "model");
#line 381 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp779_ = (GXmlNode*) _tmp778_;
#line 381 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp780_ = gxml_node_get_value (_tmp779_);
#line 381 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp781_ = _tmp780_;
#line 381 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp782_ = _tmp781_;
#line 381 "SerializableGeeCollections-TDocument-Test.vala"
								_vala_assert (g_strcmp0 (_tmp782_, "G045-1") == 0, "rsh.attrs.get (\"model\").value == \"G045-1\"");
#line 381 "SerializableGeeCollections-TDocument-Test.vala"
								_g_free0 (_tmp782_);
#line 381 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp779_);
#line 381 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp777_);
#line 382 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp783_ = rsh;
#line 382 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp784_ = gxml_node_get_children_nodes (_tmp783_);
#line 382 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp785_ = _tmp784_;
#line 382 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp786_ = _tmp785_;
#line 382 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp787_ = gee_collection_get_size ((GeeCollection*) _tmp786_);
#line 382 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp788_ = _tmp787_;
#line 382 "SerializableGeeCollections-TDocument-Test.vala"
								_vala_assert (_tmp788_ == 0, "rsh.children_nodes.size == 0");
#line 382 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (_tmp786_);
#line 4273 "SerializableGeeCollections-TDocument-Test.c"
							}
#line 371 "SerializableGeeCollections-TDocument-Test.vala"
							_g_object_unref0 (rsh);
#line 4277 "SerializableGeeCollections-TDocument-Test.c"
						}
#line 371 "SerializableGeeCollections-TDocument-Test.vala"
						_g_object_unref0 (_rsh_list);
#line 4281 "SerializableGeeCollections-TDocument-Test.c"
					}
#line 385 "SerializableGeeCollections-TDocument-Test.vala"
					_vala_assert (frmactoy, "frmactoy");
#line 386 "SerializableGeeCollections-TDocument-Test.vala"
					_vala_assert (frmega, "frmega");
#line 4287 "SerializableGeeCollections-TDocument-Test.c"
				}
#line 362 "SerializableGeeCollections-TDocument-Test.vala"
				_g_object_unref0 (r);
#line 4291 "SerializableGeeCollections-TDocument-Test.c"
			}
#line 362 "SerializableGeeCollections-TDocument-Test.vala"
			_g_object_unref0 (_r_list);
#line 4295 "SerializableGeeCollections-TDocument-Test.c"
		}
#line 389 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (fr, "fr");
#line 181 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (st);
#line 181 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (cz);
#line 181 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (ndoc);
#line 181 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (sbsh1);
#line 181 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (sb);
#line 181 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (doc);
#line 4311 "SerializableGeeCollections-TDocument-Test.c"
	}
	goto __finally373;
	__catch373_g_error:
	{
		GError* e = NULL;
#line 181 "SerializableGeeCollections-TDocument-Test.vala"
		e = _inner_error0_;
#line 181 "SerializableGeeCollections-TDocument-Test.vala"
		_inner_error0_ = NULL;
#line 399 "SerializableGeeCollections-TDocument-Test.vala"
		g_assert_not_reached ();
#line 181 "SerializableGeeCollections-TDocument-Test.vala"
		_g_error_free0 (e);
#line 4325 "SerializableGeeCollections-TDocument-Test.c"
	}
	__finally373:
#line 181 "SerializableGeeCollections-TDocument-Test.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 181 "SerializableGeeCollections-TDocument-Test.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 181 "SerializableGeeCollections-TDocument-Test.vala"
		g_clear_error (&_inner_error0_);
#line 181 "SerializableGeeCollections-TDocument-Test.vala"
		return;
#line 4336 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static void
___lambda323__gtest_func (void)
{
#line 179 "SerializableGeeCollections-TDocument-Test.vala"
	__lambda323_ ();
#line 4345 "SerializableGeeCollections-TDocument-Test.c"
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result = NULL;
#line 1516 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1517 "glib-2.0.vapi"
	result = self;
#line 1517 "glib-2.0.vapi"
	return result;
#line 4358 "SerializableGeeCollections-TDocument-Test.c"
}

static void
__lambda324_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* org_doc = NULL;
		GXmlGDocument* _tmp0_;
		SerializableGeeCollectionsTDocumentTestSpaceBase* s = NULL;
		SerializableGeeCollectionsTDocumentTestSpaceBase* _tmp1_;
		SerializableGeeCollectionsTDocumentTestSpaceBase* _tmp2_;
		GXmlGDocument* _tmp3_;
		SerializableGeeCollectionsTDocumentTestSpaceBase* _tmp4_;
		SerializableGeeCollectionsTDocumentTestChargeZone* _tmp5_;
		SerializableGeeCollectionsTDocumentTestChargeZone* _tmp6_;
		SerializableGeeCollectionsTDocumentTestSpaceBase* _tmp7_;
		SerializableGeeCollectionsTDocumentTestChargeZone* _tmp8_;
		SerializableGeeCollectionsTDocumentTestChargeZone* _tmp9_;
		SerializableGeeCollectionsTDocumentTestSpaceShipCollection* _tmp10_;
		SerializableGeeCollectionsTDocumentTestSpaceShipCollection* _tmp11_;
		gint _tmp12_;
		gint _tmp13_;
		SerializableGeeCollectionsTDocumentTestSpaceShip* mssh = NULL;
		SerializableGeeCollectionsTDocumentTestSpaceBase* _tmp14_;
		SerializableGeeCollectionsTDocumentTestChargeZone* _tmp15_;
		SerializableGeeCollectionsTDocumentTestChargeZone* _tmp16_;
		SerializableGeeCollectionsTDocumentTestSpaceShipCollection* _tmp17_;
		SerializableGeeCollectionsTDocumentTestSpaceShipCollection* _tmp18_;
		gpointer _tmp19_;
		SerializableGeeCollectionsTDocumentTestSpaceShip* _tmp20_;
		SerializableGeeCollectionsTDocumentTestSpaceBase* _tmp21_;
		SerializableGeeCollectionsTDocumentTestStorage* _tmp22_;
		SerializableGeeCollectionsTDocumentTestStorage* _tmp23_;
		SerializableGeeCollectionsTDocumentTestSpaceShip* _tmp24_;
		SerializableGeeCollectionsTDocumentTestSpaceCollection* _tmp25_;
		SerializableGeeCollectionsTDocumentTestSpaceCollection* _tmp26_;
		gint _tmp27_;
		gint _tmp28_;
		SerializableGeeCollectionsTDocumentTestSpaceBase* _tmp29_;
		SerializableGeeCollectionsTDocumentTestStorage* _tmp30_;
		SerializableGeeCollectionsTDocumentTestStorage* _tmp31_;
		SerializableGeeCollectionsTDocumentTestSpaceBase* _tmp32_;
		SerializableGeeCollectionsTDocumentTestStorage* _tmp33_;
		SerializableGeeCollectionsTDocumentTestStorage* _tmp34_;
		SerializableGeeCollectionsTDocumentTestRefactionCollection* _tmp35_;
		SerializableGeeCollectionsTDocumentTestRefactionCollection* _tmp36_;
		gint _tmp37_;
		gint _tmp38_;
		SerializableGeeCollectionsTDocumentTestRefaction* refaction = NULL;
		SerializableGeeCollectionsTDocumentTestSpaceBase* _tmp39_;
		SerializableGeeCollectionsTDocumentTestStorage* _tmp40_;
		SerializableGeeCollectionsTDocumentTestStorage* _tmp41_;
		SerializableGeeCollectionsTDocumentTestRefactionCollection* _tmp42_;
		SerializableGeeCollectionsTDocumentTestRefactionCollection* _tmp43_;
		gpointer _tmp44_;
		SerializableGeeCollectionsTDocumentTestRefaction* _tmp45_;
		SerializableGeeCollectionsTDocumentTestRefaction* _tmp46_;
		GeeMap* _tmp47_;
		GeeMap* _tmp48_;
		GeeMap* _tmp49_;
		SerializableGeeCollectionsTDocumentTestRefaction* _tmp50_;
		GeeMap* _tmp51_;
		GeeMap* _tmp52_;
		GeeMap* _tmp53_;
		gint _tmp54_;
		gint _tmp55_;
		SerializableGeeCollectionsTDocumentTestRefaction* _tmp56_;
		GeeCollection* _tmp57_;
		GeeCollection* _tmp58_;
		GeeCollection* _tmp59_;
		gint _tmp60_;
		gint _tmp61_;
		GXmlTDocument* doc = NULL;
		GXmlTDocument* _tmp62_;
		SerializableGeeCollectionsTDocumentTestSpaceBase* _tmp63_;
		GXmlTDocument* _tmp64_;
		GXmlNode* _tmp65_;
		GXmlNode* _tmp66_;
		GXmlTDocument* _tmp67_;
		GXmlNode* _tmp68_;
		GXmlNode* _tmp69_;
		GXmlNode* _tmp70_;
		gchar* _tmp71_;
		gchar* _tmp72_;
		gchar* _tmp73_;
#line 406 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"<base name=\"AlphaOne\" >\n" \
"  <chargezone name=\"A1-1\">\n" \
"    <ship manufacturer=\"MacToy\" model=\"A1234\">\n" \
"      <space name=\"Alpha Centaury\">\n" \
"        <planet name=\"Earth\">\n" \
"          <citizen ctype=\"Human\">1M</citizen>\n" \
"          <citizen ctype=\"Ghost\">10M</citizen>\n" \
"        </planet>\n" \
"        <planet name=\"Galiumt\" />\n" \
"      </space>\n" \
"      <space name=\"Galax\">\n" \
"        <planet name=\"Saminon\">\n" \
"          <citizen ctype=\"Humanes\">100M</citizen>\n" \
"          <citizen ctype=\"Jeties\">1000M</citizen>\n" \
"        </planet>\n" \
"        <planet name=\"Keymanth\" />\n" \
"      </space>\n" \
"    </ship>\n" \
"    <ship manufacturer=\"Memphis\" model=\"AB1\">\n" \
"      <space name=\"Proximity\">\n" \
"        <planet name=\"Pluton\">\n" \
"          <citizen ctype=\"Ork\">10000M</citizen>\n" \
"          <citizen ctype=\"Gyk\">100000M</citizen>\n" \
"        </planet>\n" \
"        <planet name=\"Mercury\" />\n" \
"      </space>\n" \
"    </ship>\n" \
"  </chargezone>\n" \
"  <storage name=\"B4-A4\">\n" \
"    <refaction manufacturer=\"MacToy\" model=\"Fly045\">\n" \
"      <ship manufacturer=\"MacToy\" model=\"A1234\" />\n" \
"      <ship manufacturer=\"MegaTrench\" model=\"G045-1\" unknown=\"UNK" \
"NOWN ATTR\">TEST_TEXT</ship>\n" \
"      <UnknownAttribute name=\"nothing\" />\n" \
"    </refaction>\n" \
"  </storage>\n" \
"</base>", 0, &_inner_error0_);
#line 406 "SerializableGeeCollections-TDocument-Test.vala"
		org_doc = _tmp0_;
#line 406 "SerializableGeeCollections-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 4451 "SerializableGeeCollections-TDocument-Test.c"
			goto __catch374_g_error;
		}
#line 443 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp1_ = serializable_gee_collections_tdocument_test_space_base_new ();
#line 443 "SerializableGeeCollections-TDocument-Test.vala"
		s = _tmp1_;
#line 444 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp2_ = s;
#line 444 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp3_ = org_doc;
#line 444 "SerializableGeeCollections-TDocument-Test.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error0_);
#line 444 "SerializableGeeCollections-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 444 "SerializableGeeCollections-TDocument-Test.vala"
			_g_object_unref0 (s);
#line 444 "SerializableGeeCollections-TDocument-Test.vala"
			_g_object_unref0 (org_doc);
#line 4470 "SerializableGeeCollections-TDocument-Test.c"
			goto __catch374_g_error;
		}
#line 445 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp4_ = s;
#line 445 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp5_ = serializable_gee_collections_tdocument_test_space_base_get_charge_zone (_tmp4_);
#line 445 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp6_ = _tmp5_;
#line 445 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (_tmp6_ != NULL, "s.charge_zone != null");
#line 446 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp7_ = s;
#line 446 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp8_ = serializable_gee_collections_tdocument_test_space_base_get_charge_zone (_tmp7_);
#line 446 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp9_ = _tmp8_;
#line 446 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp10_ = serializable_gee_collections_tdocument_test_charge_zone_get_spaceships (_tmp9_);
#line 446 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp11_ = _tmp10_;
#line 446 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp12_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp11_);
#line 446 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp13_ = _tmp12_;
#line 446 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (_tmp13_ == 2, "s.charge_zone.spaceships.size == 2");
#line 447 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp14_ = s;
#line 447 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp15_ = serializable_gee_collections_tdocument_test_space_base_get_charge_zone (_tmp14_);
#line 447 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp16_ = _tmp15_;
#line 447 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp17_ = serializable_gee_collections_tdocument_test_charge_zone_get_spaceships (_tmp16_);
#line 447 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp18_ = _tmp17_;
#line 447 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp19_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp18_, "MacToy", "A1234");
#line 447 "SerializableGeeCollections-TDocument-Test.vala"
		mssh = (SerializableGeeCollectionsTDocumentTestSpaceShip*) _tmp19_;
#line 448 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp20_ = mssh;
#line 448 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (_tmp20_ != NULL, "mssh != null");
#line 450 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp21_ = s;
#line 450 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp22_ = serializable_gee_collections_tdocument_test_space_base_get_storage (_tmp21_);
#line 450 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp23_ = _tmp22_;
#line 450 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (_tmp23_ != NULL, "s.storage != null");
#line 451 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp24_ = mssh;
#line 451 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp25_ = serializable_gee_collections_tdocument_test_space_ship_get_spaces (_tmp24_);
#line 451 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp26_ = _tmp25_;
#line 451 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp27_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp26_);
#line 451 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp28_ = _tmp27_;
#line 451 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (_tmp28_ == 2, "mssh.spaces.size == 2");
#line 452 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp29_ = s;
#line 452 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp30_ = serializable_gee_collections_tdocument_test_space_base_get_storage (_tmp29_);
#line 452 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp31_ = _tmp30_;
#line 452 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (_tmp31_ != NULL, "s.storage != null");
#line 453 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp32_ = s;
#line 453 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp33_ = serializable_gee_collections_tdocument_test_space_base_get_storage (_tmp32_);
#line 453 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp34_ = _tmp33_;
#line 453 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp35_ = serializable_gee_collections_tdocument_test_storage_get_refactions (_tmp34_);
#line 453 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp36_ = _tmp35_;
#line 453 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp37_ = gxml_serializable_dual_key_map_get_size ((GXmlSerializableDualKeyMap*) _tmp36_);
#line 453 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp38_ = _tmp37_;
#line 453 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (_tmp38_ == 1, "s.storage.refactions.size == 1");
#line 454 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp39_ = s;
#line 454 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp40_ = serializable_gee_collections_tdocument_test_space_base_get_storage (_tmp39_);
#line 454 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp41_ = _tmp40_;
#line 454 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp42_ = serializable_gee_collections_tdocument_test_storage_get_refactions (_tmp41_);
#line 454 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp43_ = _tmp42_;
#line 454 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp44_ = gxml_serializable_dual_key_map_get ((GXmlSerializableDualKeyMap*) _tmp43_, "MacToy", "Fly045");
#line 454 "SerializableGeeCollections-TDocument-Test.vala"
		refaction = (SerializableGeeCollectionsTDocumentTestRefaction*) _tmp44_;
#line 455 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp45_ = refaction;
#line 455 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (_tmp45_ != NULL, "refaction != null");
#line 456 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp46_ = refaction;
#line 456 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp47_ = gxml_serializable_get_unknown_serializable_properties ((GXmlSerializable*) _tmp46_);
#line 456 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp48_ = _tmp47_;
#line 456 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp49_ = _tmp48_;
#line 456 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (_tmp49_ != NULL, "refaction.unknown_serializable_properties != null");
#line 456 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp49_);
#line 457 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp50_ = refaction;
#line 457 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp51_ = gxml_serializable_get_unknown_serializable_properties ((GXmlSerializable*) _tmp50_);
#line 457 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp52_ = _tmp51_;
#line 457 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp53_ = _tmp52_;
#line 457 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp54_ = gee_map_get_size (_tmp53_);
#line 457 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp55_ = _tmp54_;
#line 457 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (_tmp55_ == 0, "refaction.unknown_serializable_properties.size == 0");
#line 457 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp53_);
#line 458 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp56_ = refaction;
#line 458 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp57_ = gxml_serializable_get_unknown_serializable_nodes ((GXmlSerializable*) _tmp56_);
#line 458 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp58_ = _tmp57_;
#line 458 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp59_ = _tmp58_;
#line 458 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp60_ = gee_collection_get_size (_tmp59_);
#line 458 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp61_ = _tmp60_;
#line 458 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (_tmp61_ == 5, "refaction.unknown_serializable_nodes.size == 5");
#line 458 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp59_);
#line 459 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp62_ = gxml_tdocument_new ();
#line 459 "SerializableGeeCollections-TDocument-Test.vala"
		doc = _tmp62_;
#line 460 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp63_ = s;
#line 460 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp64_ = doc;
#line 460 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp65_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp63_, (GXmlNode*) _tmp64_, &_inner_error0_);
#line 460 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp66_ = _tmp65_;
#line 460 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp66_);
#line 460 "SerializableGeeCollections-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 460 "SerializableGeeCollections-TDocument-Test.vala"
			_g_object_unref0 (doc);
#line 460 "SerializableGeeCollections-TDocument-Test.vala"
			_g_object_unref0 (refaction);
#line 460 "SerializableGeeCollections-TDocument-Test.vala"
			_g_object_unref0 (mssh);
#line 460 "SerializableGeeCollections-TDocument-Test.vala"
			_g_object_unref0 (s);
#line 460 "SerializableGeeCollections-TDocument-Test.vala"
			_g_object_unref0 (org_doc);
#line 4647 "SerializableGeeCollections-TDocument-Test.c"
			goto __catch374_g_error;
		}
#line 461 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp67_ = doc;
#line 461 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp68_ = gxml_document_get_root ((GXmlDocument*) _tmp67_);
#line 461 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp69_ = _tmp68_;
#line 461 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp70_ = _tmp69_;
#line 461 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp71_ = gxml_node_get_name (_tmp70_);
#line 461 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp72_ = _tmp71_;
#line 461 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp73_ = _tmp72_;
#line 461 "SerializableGeeCollections-TDocument-Test.vala"
		_vala_assert (g_strcmp0 (_tmp73_, "base") == 0, "doc.root.name == \"base\"");
#line 461 "SerializableGeeCollections-TDocument-Test.vala"
		_g_free0 (_tmp73_);
#line 461 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp70_);
#line 4670 "SerializableGeeCollections-TDocument-Test.c"
		{
			GeeBidirList* _n_list = NULL;
			GXmlTDocument* _tmp74_;
			GXmlNode* _tmp75_;
			GXmlNode* _tmp76_;
			GXmlNode* _tmp77_;
			GeeBidirList* _tmp78_;
			GeeBidirList* _tmp79_;
			GeeBidirList* _tmp80_;
			gint _n_size = 0;
			GeeBidirList* _tmp81_;
			gint _tmp82_;
			gint _tmp83_;
			gint _n_index = 0;
#line 463 "SerializableGeeCollections-TDocument-Test.vala"
			_tmp74_ = doc;
#line 463 "SerializableGeeCollections-TDocument-Test.vala"
			_tmp75_ = gxml_document_get_root ((GXmlDocument*) _tmp74_);
#line 463 "SerializableGeeCollections-TDocument-Test.vala"
			_tmp76_ = _tmp75_;
#line 463 "SerializableGeeCollections-TDocument-Test.vala"
			_tmp77_ = _tmp76_;
#line 463 "SerializableGeeCollections-TDocument-Test.vala"
			_tmp78_ = gxml_node_get_children_nodes (_tmp77_);
#line 463 "SerializableGeeCollections-TDocument-Test.vala"
			_tmp79_ = _tmp78_;
#line 463 "SerializableGeeCollections-TDocument-Test.vala"
			_tmp80_ = _tmp79_;
#line 463 "SerializableGeeCollections-TDocument-Test.vala"
			_g_object_unref0 (_tmp77_);
#line 463 "SerializableGeeCollections-TDocument-Test.vala"
			_n_list = _tmp80_;
#line 463 "SerializableGeeCollections-TDocument-Test.vala"
			_tmp81_ = _n_list;
#line 463 "SerializableGeeCollections-TDocument-Test.vala"
			_tmp82_ = gee_collection_get_size ((GeeCollection*) _tmp81_);
#line 463 "SerializableGeeCollections-TDocument-Test.vala"
			_tmp83_ = _tmp82_;
#line 463 "SerializableGeeCollections-TDocument-Test.vala"
			_n_size = _tmp83_;
#line 463 "SerializableGeeCollections-TDocument-Test.vala"
			_n_index = -1;
#line 463 "SerializableGeeCollections-TDocument-Test.vala"
			while (TRUE) {
#line 4715 "SerializableGeeCollections-TDocument-Test.c"
				GXmlNode* n = NULL;
				GeeBidirList* _tmp84_;
				gpointer _tmp85_;
				GXmlNode* _tmp86_;
				GXmlNode* _tmp177_;
#line 463 "SerializableGeeCollections-TDocument-Test.vala"
				_n_index = _n_index + 1;
#line 463 "SerializableGeeCollections-TDocument-Test.vala"
				if (!(_n_index < _n_size)) {
#line 463 "SerializableGeeCollections-TDocument-Test.vala"
					break;
#line 4727 "SerializableGeeCollections-TDocument-Test.c"
				}
#line 463 "SerializableGeeCollections-TDocument-Test.vala"
				_tmp84_ = _n_list;
#line 463 "SerializableGeeCollections-TDocument-Test.vala"
				_tmp85_ = gee_list_get ((GeeList*) _tmp84_, _n_index);
#line 463 "SerializableGeeCollections-TDocument-Test.vala"
				n = (GXmlNode*) _tmp85_;
#line 464 "SerializableGeeCollections-TDocument-Test.vala"
				_tmp86_ = n;
#line 464 "SerializableGeeCollections-TDocument-Test.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp86_, GXML_TYPE_ELEMENT)) {
#line 4739 "SerializableGeeCollections-TDocument-Test.c"
					GXmlNode* _tmp87_;
					gchar* _tmp88_;
					gchar* _tmp89_;
					gchar* _tmp90_;
					gboolean _tmp91_;
					GXmlNode* _tmp92_;
					gchar* _tmp93_;
					gchar* _tmp94_;
					gchar* _tmp95_;
					gboolean _tmp96_;
#line 465 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp87_ = n;
#line 465 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp88_ = gxml_node_get_name (_tmp87_);
#line 465 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp89_ = _tmp88_;
#line 465 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp90_ = _tmp89_;
#line 465 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp91_ = g_strcmp0 (_tmp90_, "ChargeZone") == 0;
#line 465 "SerializableGeeCollections-TDocument-Test.vala"
					_g_free0 (_tmp90_);
#line 465 "SerializableGeeCollections-TDocument-Test.vala"
					if (_tmp91_) {
#line 4764 "SerializableGeeCollections-TDocument-Test.c"
					}
#line 468 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp92_ = n;
#line 468 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp93_ = gxml_node_get_name (_tmp92_);
#line 468 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp94_ = _tmp93_;
#line 468 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp95_ = _tmp94_;
#line 468 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp96_ = g_strcmp0 (_tmp95_, "storage") == 0;
#line 468 "SerializableGeeCollections-TDocument-Test.vala"
					_g_free0 (_tmp95_);
#line 468 "SerializableGeeCollections-TDocument-Test.vala"
					if (_tmp96_) {
#line 4780 "SerializableGeeCollections-TDocument-Test.c"
						gboolean unkfound = FALSE;
						gboolean tfound = FALSE;
						gboolean attrfound = FALSE;
#line 469 "SerializableGeeCollections-TDocument-Test.vala"
						unkfound = FALSE;
#line 470 "SerializableGeeCollections-TDocument-Test.vala"
						tfound = FALSE;
#line 471 "SerializableGeeCollections-TDocument-Test.vala"
						attrfound = FALSE;
#line 4790 "SerializableGeeCollections-TDocument-Test.c"
						{
							GeeBidirList* _sn_list = NULL;
							GXmlNode* _tmp97_;
							GeeBidirList* _tmp98_;
							GeeBidirList* _tmp99_;
							gint _sn_size = 0;
							GeeBidirList* _tmp100_;
							gint _tmp101_;
							gint _tmp102_;
							gint _sn_index = 0;
#line 472 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp97_ = n;
#line 472 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp98_ = gxml_node_get_children_nodes (_tmp97_);
#line 472 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp99_ = _tmp98_;
#line 472 "SerializableGeeCollections-TDocument-Test.vala"
							_sn_list = _tmp99_;
#line 472 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp100_ = _sn_list;
#line 472 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp101_ = gee_collection_get_size ((GeeCollection*) _tmp100_);
#line 472 "SerializableGeeCollections-TDocument-Test.vala"
							_tmp102_ = _tmp101_;
#line 472 "SerializableGeeCollections-TDocument-Test.vala"
							_sn_size = _tmp102_;
#line 472 "SerializableGeeCollections-TDocument-Test.vala"
							_sn_index = -1;
#line 472 "SerializableGeeCollections-TDocument-Test.vala"
							while (TRUE) {
#line 4821 "SerializableGeeCollections-TDocument-Test.c"
								GXmlNode* sn = NULL;
								GeeBidirList* _tmp103_;
								gpointer _tmp104_;
								GXmlNode* _tmp105_;
#line 472 "SerializableGeeCollections-TDocument-Test.vala"
								_sn_index = _sn_index + 1;
#line 472 "SerializableGeeCollections-TDocument-Test.vala"
								if (!(_sn_index < _sn_size)) {
#line 472 "SerializableGeeCollections-TDocument-Test.vala"
									break;
#line 4832 "SerializableGeeCollections-TDocument-Test.c"
								}
#line 472 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp103_ = _sn_list;
#line 472 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp104_ = gee_list_get ((GeeList*) _tmp103_, _sn_index);
#line 472 "SerializableGeeCollections-TDocument-Test.vala"
								sn = (GXmlNode*) _tmp104_;
#line 473 "SerializableGeeCollections-TDocument-Test.vala"
								_tmp105_ = sn;
#line 473 "SerializableGeeCollections-TDocument-Test.vala"
								if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp105_, GXML_TYPE_ELEMENT)) {
#line 4844 "SerializableGeeCollections-TDocument-Test.c"
									GXmlNode* _tmp106_;
									gchar* _tmp107_;
									gchar* _tmp108_;
									gchar* _tmp109_;
									gboolean _tmp110_;
#line 474 "SerializableGeeCollections-TDocument-Test.vala"
									_tmp106_ = sn;
#line 474 "SerializableGeeCollections-TDocument-Test.vala"
									_tmp107_ = gxml_node_get_name (_tmp106_);
#line 474 "SerializableGeeCollections-TDocument-Test.vala"
									_tmp108_ = _tmp107_;
#line 474 "SerializableGeeCollections-TDocument-Test.vala"
									_tmp109_ = _tmp108_;
#line 474 "SerializableGeeCollections-TDocument-Test.vala"
									_tmp110_ = g_strcmp0 (_tmp109_, "refaction") == 0;
#line 474 "SerializableGeeCollections-TDocument-Test.vala"
									_g_free0 (_tmp109_);
#line 474 "SerializableGeeCollections-TDocument-Test.vala"
									if (_tmp110_) {
#line 4864 "SerializableGeeCollections-TDocument-Test.c"
										{
											GeeBidirList* _rn_list = NULL;
											GXmlNode* _tmp111_;
											GeeBidirList* _tmp112_;
											GeeBidirList* _tmp113_;
											gint _rn_size = 0;
											GeeBidirList* _tmp114_;
											gint _tmp115_;
											gint _tmp116_;
											gint _rn_index = 0;
#line 475 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp111_ = sn;
#line 475 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp112_ = gxml_node_get_children_nodes (_tmp111_);
#line 475 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp113_ = _tmp112_;
#line 475 "SerializableGeeCollections-TDocument-Test.vala"
											_rn_list = _tmp113_;
#line 475 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp114_ = _rn_list;
#line 475 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp115_ = gee_collection_get_size ((GeeCollection*) _tmp114_);
#line 475 "SerializableGeeCollections-TDocument-Test.vala"
											_tmp116_ = _tmp115_;
#line 475 "SerializableGeeCollections-TDocument-Test.vala"
											_rn_size = _tmp116_;
#line 475 "SerializableGeeCollections-TDocument-Test.vala"
											_rn_index = -1;
#line 475 "SerializableGeeCollections-TDocument-Test.vala"
											while (TRUE) {
#line 4895 "SerializableGeeCollections-TDocument-Test.c"
												GXmlNode* rn = NULL;
												GeeBidirList* _tmp117_;
												gpointer _tmp118_;
												GXmlNode* _tmp119_;
#line 475 "SerializableGeeCollections-TDocument-Test.vala"
												_rn_index = _rn_index + 1;
#line 475 "SerializableGeeCollections-TDocument-Test.vala"
												if (!(_rn_index < _rn_size)) {
#line 475 "SerializableGeeCollections-TDocument-Test.vala"
													break;
#line 4906 "SerializableGeeCollections-TDocument-Test.c"
												}
#line 475 "SerializableGeeCollections-TDocument-Test.vala"
												_tmp117_ = _rn_list;
#line 475 "SerializableGeeCollections-TDocument-Test.vala"
												_tmp118_ = gee_list_get ((GeeList*) _tmp117_, _rn_index);
#line 475 "SerializableGeeCollections-TDocument-Test.vala"
												rn = (GXmlNode*) _tmp118_;
#line 476 "SerializableGeeCollections-TDocument-Test.vala"
												_tmp119_ = rn;
#line 476 "SerializableGeeCollections-TDocument-Test.vala"
												if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp119_, GXML_TYPE_ELEMENT)) {
#line 4918 "SerializableGeeCollections-TDocument-Test.c"
													GXmlNode* _tmp120_;
													gchar* _tmp121_;
													gchar* _tmp122_;
													gchar* _tmp123_;
													gboolean _tmp124_;
													GXmlNode* _tmp161_;
													gchar* _tmp162_;
													gchar* _tmp163_;
													gchar* _tmp164_;
													gboolean _tmp165_;
#line 478 "SerializableGeeCollections-TDocument-Test.vala"
													_tmp120_ = rn;
#line 478 "SerializableGeeCollections-TDocument-Test.vala"
													_tmp121_ = gxml_node_get_name (_tmp120_);
#line 478 "SerializableGeeCollections-TDocument-Test.vala"
													_tmp122_ = _tmp121_;
#line 478 "SerializableGeeCollections-TDocument-Test.vala"
													_tmp123_ = _tmp122_;
#line 478 "SerializableGeeCollections-TDocument-Test.vala"
													_tmp124_ = g_strcmp0 (_tmp123_, "ship") == 0;
#line 478 "SerializableGeeCollections-TDocument-Test.vala"
													_g_free0 (_tmp123_);
#line 478 "SerializableGeeCollections-TDocument-Test.vala"
													if (_tmp124_) {
#line 4943 "SerializableGeeCollections-TDocument-Test.c"
														GXmlNode* atr = NULL;
														GXmlNode* _tmp125_;
														GeeMap* _tmp126_;
														GeeMap* _tmp127_;
														GeeMap* _tmp128_;
														gpointer _tmp129_;
														GXmlNode* _tmp130_;
														GXmlNode* _tmp131_;
														GXmlNode* _tmp132_;
														gchar* _tmp133_;
														gchar* _tmp134_;
														gchar* _tmp135_;
														gboolean _tmp136_;
#line 479 "SerializableGeeCollections-TDocument-Test.vala"
														_tmp125_ = rn;
#line 479 "SerializableGeeCollections-TDocument-Test.vala"
														_tmp126_ = gxml_node_get_attrs (_tmp125_);
#line 479 "SerializableGeeCollections-TDocument-Test.vala"
														_tmp127_ = _tmp126_;
#line 479 "SerializableGeeCollections-TDocument-Test.vala"
														_tmp128_ = _tmp127_;
#line 479 "SerializableGeeCollections-TDocument-Test.vala"
														_tmp129_ = gee_map_get (_tmp128_, "manufacturer");
#line 479 "SerializableGeeCollections-TDocument-Test.vala"
														_tmp130_ = (GXmlNode*) _tmp129_;
#line 479 "SerializableGeeCollections-TDocument-Test.vala"
														_g_object_unref0 (_tmp128_);
#line 479 "SerializableGeeCollections-TDocument-Test.vala"
														atr = _tmp130_;
#line 480 "SerializableGeeCollections-TDocument-Test.vala"
														_tmp131_ = atr;
#line 480 "SerializableGeeCollections-TDocument-Test.vala"
														_vala_assert (_tmp131_ != NULL, "atr != null");
#line 481 "SerializableGeeCollections-TDocument-Test.vala"
														_tmp132_ = atr;
#line 481 "SerializableGeeCollections-TDocument-Test.vala"
														_tmp133_ = gxml_node_get_value (_tmp132_);
#line 481 "SerializableGeeCollections-TDocument-Test.vala"
														_tmp134_ = _tmp133_;
#line 481 "SerializableGeeCollections-TDocument-Test.vala"
														_tmp135_ = _tmp134_;
#line 481 "SerializableGeeCollections-TDocument-Test.vala"
														_tmp136_ = g_strcmp0 (_tmp135_, "MegaTrench") == 0;
#line 481 "SerializableGeeCollections-TDocument-Test.vala"
														_g_free0 (_tmp135_);
#line 481 "SerializableGeeCollections-TDocument-Test.vala"
														if (_tmp136_) {
#line 4991 "SerializableGeeCollections-TDocument-Test.c"
															GXmlNode* shanattr = NULL;
															GXmlNode* _tmp137_;
															GeeMap* _tmp138_;
															GeeMap* _tmp139_;
															GeeMap* _tmp140_;
															gpointer _tmp141_;
															GXmlNode* _tmp142_;
															GXmlNode* _tmp143_;
#line 482 "SerializableGeeCollections-TDocument-Test.vala"
															_tmp137_ = rn;
#line 482 "SerializableGeeCollections-TDocument-Test.vala"
															_tmp138_ = gxml_node_get_attrs (_tmp137_);
#line 482 "SerializableGeeCollections-TDocument-Test.vala"
															_tmp139_ = _tmp138_;
#line 482 "SerializableGeeCollections-TDocument-Test.vala"
															_tmp140_ = _tmp139_;
#line 482 "SerializableGeeCollections-TDocument-Test.vala"
															_tmp141_ = gee_map_get (_tmp140_, "unknown");
#line 482 "SerializableGeeCollections-TDocument-Test.vala"
															_tmp142_ = (GXmlNode*) _tmp141_;
#line 482 "SerializableGeeCollections-TDocument-Test.vala"
															_g_object_unref0 (_tmp140_);
#line 482 "SerializableGeeCollections-TDocument-Test.vala"
															shanattr = _tmp142_;
#line 483 "SerializableGeeCollections-TDocument-Test.vala"
															_tmp143_ = shanattr;
#line 483 "SerializableGeeCollections-TDocument-Test.vala"
															if (_tmp143_ != NULL) {
#line 5020 "SerializableGeeCollections-TDocument-Test.c"
																GXmlNode* _tmp144_;
																gchar* _tmp145_;
																gchar* _tmp146_;
																gchar* _tmp147_;
#line 484 "SerializableGeeCollections-TDocument-Test.vala"
																attrfound = TRUE;
#line 485 "SerializableGeeCollections-TDocument-Test.vala"
																_tmp144_ = shanattr;
#line 485 "SerializableGeeCollections-TDocument-Test.vala"
																_tmp145_ = gxml_node_get_value (_tmp144_);
#line 485 "SerializableGeeCollections-TDocument-Test.vala"
																_tmp146_ = _tmp145_;
#line 485 "SerializableGeeCollections-TDocument-Test.vala"
																_tmp147_ = _tmp146_;
#line 485 "SerializableGeeCollections-TDocument-Test.vala"
																_vala_assert (g_strcmp0 (_tmp147_, "UNKNOWN ATTR") == 0, "shanattr.value == \"UNKNOWN ATTR\"");
#line 485 "SerializableGeeCollections-TDocument-Test.vala"
																_g_free0 (_tmp147_);
#line 5039 "SerializableGeeCollections-TDocument-Test.c"
															}
															{
																GeeBidirList* _shn_list = NULL;
																GXmlNode* _tmp148_;
																GeeBidirList* _tmp149_;
																GeeBidirList* _tmp150_;
																gint _shn_size = 0;
																GeeBidirList* _tmp151_;
																gint _tmp152_;
																gint _tmp153_;
																gint _shn_index = 0;
#line 487 "SerializableGeeCollections-TDocument-Test.vala"
																_tmp148_ = rn;
#line 487 "SerializableGeeCollections-TDocument-Test.vala"
																_tmp149_ = gxml_node_get_children_nodes (_tmp148_);
#line 487 "SerializableGeeCollections-TDocument-Test.vala"
																_tmp150_ = _tmp149_;
#line 487 "SerializableGeeCollections-TDocument-Test.vala"
																_shn_list = _tmp150_;
#line 487 "SerializableGeeCollections-TDocument-Test.vala"
																_tmp151_ = _shn_list;
#line 487 "SerializableGeeCollections-TDocument-Test.vala"
																_tmp152_ = gee_collection_get_size ((GeeCollection*) _tmp151_);
#line 487 "SerializableGeeCollections-TDocument-Test.vala"
																_tmp153_ = _tmp152_;
#line 487 "SerializableGeeCollections-TDocument-Test.vala"
																_shn_size = _tmp153_;
#line 487 "SerializableGeeCollections-TDocument-Test.vala"
																_shn_index = -1;
#line 487 "SerializableGeeCollections-TDocument-Test.vala"
																while (TRUE) {
#line 5071 "SerializableGeeCollections-TDocument-Test.c"
																	GXmlNode* shn = NULL;
																	GeeBidirList* _tmp154_;
																	gpointer _tmp155_;
																	GXmlNode* _tmp156_;
#line 487 "SerializableGeeCollections-TDocument-Test.vala"
																	_shn_index = _shn_index + 1;
#line 487 "SerializableGeeCollections-TDocument-Test.vala"
																	if (!(_shn_index < _shn_size)) {
#line 487 "SerializableGeeCollections-TDocument-Test.vala"
																		break;
#line 5082 "SerializableGeeCollections-TDocument-Test.c"
																	}
#line 487 "SerializableGeeCollections-TDocument-Test.vala"
																	_tmp154_ = _shn_list;
#line 487 "SerializableGeeCollections-TDocument-Test.vala"
																	_tmp155_ = gee_list_get ((GeeList*) _tmp154_, _shn_index);
#line 487 "SerializableGeeCollections-TDocument-Test.vala"
																	shn = (GXmlNode*) _tmp155_;
#line 489 "SerializableGeeCollections-TDocument-Test.vala"
																	_tmp156_ = shn;
#line 489 "SerializableGeeCollections-TDocument-Test.vala"
																	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp156_, GXML_TYPE_TEXT)) {
#line 5094 "SerializableGeeCollections-TDocument-Test.c"
																		GXmlNode* _tmp157_;
																		gchar* _tmp158_;
																		gchar* _tmp159_;
																		gchar* _tmp160_;
#line 490 "SerializableGeeCollections-TDocument-Test.vala"
																		tfound = TRUE;
#line 491 "SerializableGeeCollections-TDocument-Test.vala"
																		_tmp157_ = shn;
#line 491 "SerializableGeeCollections-TDocument-Test.vala"
																		_tmp158_ = gxml_node_get_value (_tmp157_);
#line 491 "SerializableGeeCollections-TDocument-Test.vala"
																		_tmp159_ = _tmp158_;
#line 491 "SerializableGeeCollections-TDocument-Test.vala"
																		_tmp160_ = _tmp159_;
#line 491 "SerializableGeeCollections-TDocument-Test.vala"
																		_vala_assert (g_strcmp0 (_tmp160_, "TEST_TEXT") == 0, "shn.value == \"TEST_TEXT\"");
#line 491 "SerializableGeeCollections-TDocument-Test.vala"
																		_g_free0 (_tmp160_);
#line 5113 "SerializableGeeCollections-TDocument-Test.c"
																	}
#line 487 "SerializableGeeCollections-TDocument-Test.vala"
																	_g_object_unref0 (shn);
#line 5117 "SerializableGeeCollections-TDocument-Test.c"
																}
#line 487 "SerializableGeeCollections-TDocument-Test.vala"
																_g_object_unref0 (_shn_list);
#line 5121 "SerializableGeeCollections-TDocument-Test.c"
															}
#line 481 "SerializableGeeCollections-TDocument-Test.vala"
															_g_object_unref0 (shanattr);
#line 5125 "SerializableGeeCollections-TDocument-Test.c"
														}
#line 478 "SerializableGeeCollections-TDocument-Test.vala"
														_g_object_unref0 (atr);
#line 5129 "SerializableGeeCollections-TDocument-Test.c"
													}
#line 496 "SerializableGeeCollections-TDocument-Test.vala"
													_tmp161_ = rn;
#line 496 "SerializableGeeCollections-TDocument-Test.vala"
													_tmp162_ = gxml_node_get_name (_tmp161_);
#line 496 "SerializableGeeCollections-TDocument-Test.vala"
													_tmp163_ = _tmp162_;
#line 496 "SerializableGeeCollections-TDocument-Test.vala"
													_tmp164_ = _tmp163_;
#line 496 "SerializableGeeCollections-TDocument-Test.vala"
													_tmp165_ = g_strcmp0 (_tmp164_, "UnknownAttribute") == 0;
#line 496 "SerializableGeeCollections-TDocument-Test.vala"
													_g_free0 (_tmp164_);
#line 496 "SerializableGeeCollections-TDocument-Test.vala"
													if (_tmp165_) {
#line 5145 "SerializableGeeCollections-TDocument-Test.c"
														GXmlNode* nattr = NULL;
														GXmlNode* _tmp166_;
														GeeMap* _tmp167_;
														GeeMap* _tmp168_;
														GeeMap* _tmp169_;
														gpointer _tmp170_;
														GXmlNode* _tmp171_;
														GXmlNode* _tmp172_;
														GXmlNode* _tmp173_;
														gchar* _tmp174_;
														gchar* _tmp175_;
														gchar* _tmp176_;
#line 497 "SerializableGeeCollections-TDocument-Test.vala"
														unkfound = TRUE;
#line 498 "SerializableGeeCollections-TDocument-Test.vala"
														_tmp166_ = rn;
#line 498 "SerializableGeeCollections-TDocument-Test.vala"
														_tmp167_ = gxml_node_get_attrs (_tmp166_);
#line 498 "SerializableGeeCollections-TDocument-Test.vala"
														_tmp168_ = _tmp167_;
#line 498 "SerializableGeeCollections-TDocument-Test.vala"
														_tmp169_ = _tmp168_;
#line 498 "SerializableGeeCollections-TDocument-Test.vala"
														_tmp170_ = gee_map_get (_tmp169_, "name");
#line 498 "SerializableGeeCollections-TDocument-Test.vala"
														_tmp171_ = (GXmlNode*) _tmp170_;
#line 498 "SerializableGeeCollections-TDocument-Test.vala"
														_g_object_unref0 (_tmp169_);
#line 498 "SerializableGeeCollections-TDocument-Test.vala"
														nattr = _tmp171_;
#line 499 "SerializableGeeCollections-TDocument-Test.vala"
														_tmp172_ = nattr;
#line 499 "SerializableGeeCollections-TDocument-Test.vala"
														_vala_assert (_tmp172_ != NULL, "nattr != null");
#line 500 "SerializableGeeCollections-TDocument-Test.vala"
														_tmp173_ = nattr;
#line 500 "SerializableGeeCollections-TDocument-Test.vala"
														_tmp174_ = gxml_node_get_value (_tmp173_);
#line 500 "SerializableGeeCollections-TDocument-Test.vala"
														_tmp175_ = _tmp174_;
#line 500 "SerializableGeeCollections-TDocument-Test.vala"
														_tmp176_ = _tmp175_;
#line 500 "SerializableGeeCollections-TDocument-Test.vala"
														_vala_assert (g_strcmp0 (_tmp176_, "nothing") == 0, "nattr.value == \"nothing\"");
#line 500 "SerializableGeeCollections-TDocument-Test.vala"
														_g_free0 (_tmp176_);
#line 496 "SerializableGeeCollections-TDocument-Test.vala"
														_g_object_unref0 (nattr);
#line 5194 "SerializableGeeCollections-TDocument-Test.c"
													}
												}
#line 475 "SerializableGeeCollections-TDocument-Test.vala"
												_g_object_unref0 (rn);
#line 5199 "SerializableGeeCollections-TDocument-Test.c"
											}
#line 475 "SerializableGeeCollections-TDocument-Test.vala"
											_g_object_unref0 (_rn_list);
#line 5203 "SerializableGeeCollections-TDocument-Test.c"
										}
									}
								}
#line 472 "SerializableGeeCollections-TDocument-Test.vala"
								_g_object_unref0 (sn);
#line 5209 "SerializableGeeCollections-TDocument-Test.c"
							}
#line 472 "SerializableGeeCollections-TDocument-Test.vala"
							_g_object_unref0 (_sn_list);
#line 5213 "SerializableGeeCollections-TDocument-Test.c"
						}
#line 507 "SerializableGeeCollections-TDocument-Test.vala"
						_vala_assert (attrfound, "attrfound");
#line 508 "SerializableGeeCollections-TDocument-Test.vala"
						_vala_assert (tfound, "tfound");
#line 509 "SerializableGeeCollections-TDocument-Test.vala"
						_vala_assert (unkfound, "unkfound");
#line 5221 "SerializableGeeCollections-TDocument-Test.c"
					}
				}
#line 512 "SerializableGeeCollections-TDocument-Test.vala"
				_tmp177_ = n;
#line 512 "SerializableGeeCollections-TDocument-Test.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp177_, GXML_TYPE_TEXT)) {
#line 5228 "SerializableGeeCollections-TDocument-Test.c"
					FILE* _tmp178_;
					GXmlNode* _tmp179_;
					gchar* _tmp180_;
					gchar* _tmp181_;
					gchar* _tmp182_;
					const gchar* _tmp183_;
					gchar* _tmp184_;
					gchar* _tmp185_;
#line 513 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp178_ = stdout;
#line 513 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp179_ = n;
#line 513 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp180_ = gxml_node_get_value (_tmp179_);
#line 513 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp181_ = _tmp180_;
#line 513 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp182_ = _tmp181_;
#line 513 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp183_ = string_to_string (_tmp182_);
#line 513 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp184_ = g_strconcat ("ROOT NODE VALUE: '", _tmp183_, "'\n", NULL);
#line 513 "SerializableGeeCollections-TDocument-Test.vala"
					_tmp185_ = _tmp184_;
#line 513 "SerializableGeeCollections-TDocument-Test.vala"
					fprintf (_tmp178_, "%s", _tmp185_);
#line 513 "SerializableGeeCollections-TDocument-Test.vala"
					_g_free0 (_tmp185_);
#line 513 "SerializableGeeCollections-TDocument-Test.vala"
					_g_free0 (_tmp182_);
#line 5259 "SerializableGeeCollections-TDocument-Test.c"
				}
#line 463 "SerializableGeeCollections-TDocument-Test.vala"
				_g_object_unref0 (n);
#line 5263 "SerializableGeeCollections-TDocument-Test.c"
			}
#line 463 "SerializableGeeCollections-TDocument-Test.vala"
			_g_object_unref0 (_n_list);
#line 5267 "SerializableGeeCollections-TDocument-Test.c"
		}
#line 404 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (doc);
#line 404 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (refaction);
#line 404 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (mssh);
#line 404 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (s);
#line 404 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (org_doc);
#line 5279 "SerializableGeeCollections-TDocument-Test.c"
	}
	goto __finally374;
	__catch374_g_error:
	{
		GError* e = NULL;
		FILE* _tmp186_;
		const gchar* _tmp187_;
		const gchar* _tmp188_;
		gchar* _tmp189_;
		gchar* _tmp190_;
#line 404 "SerializableGeeCollections-TDocument-Test.vala"
		e = _inner_error0_;
#line 404 "SerializableGeeCollections-TDocument-Test.vala"
		_inner_error0_ = NULL;
#line 518 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp186_ = stdout;
#line 518 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp187_ = e->message;
#line 518 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp188_ = string_to_string (_tmp187_);
#line 518 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp189_ = g_strconcat ("ERROR: ", _tmp188_, NULL);
#line 518 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp190_ = _tmp189_;
#line 518 "SerializableGeeCollections-TDocument-Test.vala"
		fprintf (_tmp186_, "%s", _tmp190_);
#line 518 "SerializableGeeCollections-TDocument-Test.vala"
		_g_free0 (_tmp190_);
#line 519 "SerializableGeeCollections-TDocument-Test.vala"
		g_assert_not_reached ();
#line 404 "SerializableGeeCollections-TDocument-Test.vala"
		_g_error_free0 (e);
#line 5312 "SerializableGeeCollections-TDocument-Test.c"
	}
	__finally374:
#line 404 "SerializableGeeCollections-TDocument-Test.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 404 "SerializableGeeCollections-TDocument-Test.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 404 "SerializableGeeCollections-TDocument-Test.vala"
		g_clear_error (&_inner_error0_);
#line 404 "SerializableGeeCollections-TDocument-Test.vala"
		return;
#line 5323 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static void
___lambda324__gtest_func (void)
{
#line 402 "SerializableGeeCollections-TDocument-Test.vala"
	__lambda324_ ();
#line 5332 "SerializableGeeCollections-TDocument-Test.c"
}

void
serializable_gee_collections_tdocument_test_add_tests (void)
{
#line 179 "SerializableGeeCollections-TDocument-Test.vala"
	g_test_add_func ("/gxml/tw/serializable/convined_gee_containers/de-se-deserialize", ___lambda323__gtest_func);
#line 402 "SerializableGeeCollections-TDocument-Test.vala"
	g_test_add_func ("/gxml/tw/serializable/convined_gee_containers/se-deserialize-unknowns", ___lambda324__gtest_func);
#line 5342 "SerializableGeeCollections-TDocument-Test.c"
}

SerializableGeeCollectionsTDocumentTest*
serializable_gee_collections_tdocument_test_construct (GType object_type)
{
	SerializableGeeCollectionsTDocumentTest* self = NULL;
#line 29 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTest*) gxml_test_construct (object_type);
#line 29 "SerializableGeeCollections-TDocument-Test.vala"
	return self;
#line 5353 "SerializableGeeCollections-TDocument-Test.c"
}

SerializableGeeCollectionsTDocumentTest*
serializable_gee_collections_tdocument_test_new (void)
{
#line 29 "SerializableGeeCollections-TDocument-Test.vala"
	return serializable_gee_collections_tdocument_test_construct (TYPE_SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST);
#line 5361 "SerializableGeeCollections-TDocument-Test.c"
}

static inline gpointer
serializable_gee_collections_tdocument_test_citizen_get_instance_private (SerializableGeeCollectionsTDocumentTestCitizen* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeCollectionsTDocumentTestCitizen_private_offset);
}

static gboolean
serializable_gee_collections_tdocument_test_citizen_real_serialize_use_xml_node_value (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTDocumentTestCitizen * self;
	gboolean result = FALSE;
#line 34 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestCitizen*) base;
#line 34 "SerializableGeeCollections-TDocument-Test.vala"
	result = TRUE;
#line 34 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 5381 "SerializableGeeCollections-TDocument-Test.c"
}

static gchar*
serializable_gee_collections_tdocument_test_citizen_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTDocumentTestCitizen * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
#line 35 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestCitizen*) base;
#line 35 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_ctype;
#line 35 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp1_ = string_to_string (_tmp0_);
#line 35 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp2_ = g_strconcat ("Citizen: ", _tmp1_, NULL);
#line 35 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp2_;
#line 35 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 5404 "SerializableGeeCollections-TDocument-Test.c"
}

static gchar*
serializable_gee_collections_tdocument_test_citizen_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTDocumentTestCitizen * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 36 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestCitizen*) base;
#line 36 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = g_strdup ("citizen");
#line 36 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 36 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 5421 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestCitizen*
serializable_gee_collections_tdocument_test_citizen_construct (GType object_type)
{
	SerializableGeeCollectionsTDocumentTestCitizen * self = NULL;
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestCitizen*) gxml_serializable_object_model_construct (object_type);
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
	return self;
#line 5432 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestCitizen*
serializable_gee_collections_tdocument_test_citizen_new (void)
{
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
	return serializable_gee_collections_tdocument_test_citizen_construct (SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_CITIZEN);
#line 5440 "SerializableGeeCollections-TDocument-Test.c"
}

static const gchar*
serializable_gee_collections_tdocument_test_citizen_get_ctype (SerializableGeeCollectionsTDocumentTestCitizen* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 33 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 33 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_ctype;
#line 33 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 33 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 5456 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_citizen_set_ctype (SerializableGeeCollectionsTDocumentTestCitizen* self,
                                                               const gchar* value)
{
#line 33 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_if_fail (self != NULL);
#line 33 "SerializableGeeCollections-TDocument-Test.vala"
	if (g_strcmp0 (value, serializable_gee_collections_tdocument_test_citizen_get_ctype (self)) != 0) {
#line 5467 "SerializableGeeCollections-TDocument-Test.c"
		gchar* _tmp0_;
#line 33 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp0_ = g_strdup (value);
#line 33 "SerializableGeeCollections-TDocument-Test.vala"
		_g_free0 (self->priv->_ctype);
#line 33 "SerializableGeeCollections-TDocument-Test.vala"
		self->priv->_ctype = _tmp0_;
#line 33 "SerializableGeeCollections-TDocument-Test.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_tdocument_test_citizen_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_CTYPE_PROPERTY]);
#line 5477 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static SerializableGeeCollectionsTDocumentTestCitizenArray*
serializable_gee_collections_tdocument_test_citizen_array_construct (GType object_type)
{
	SerializableGeeCollectionsTDocumentTestCitizenArray * self = NULL;
#line 38 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestCitizenArray*) gxml_serializable_array_list_construct (object_type, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_CITIZEN, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 38 "SerializableGeeCollections-TDocument-Test.vala"
	return self;
#line 5489 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestCitizenArray*
serializable_gee_collections_tdocument_test_citizen_array_new (void)
{
#line 38 "SerializableGeeCollections-TDocument-Test.vala"
	return serializable_gee_collections_tdocument_test_citizen_array_construct (SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_TYPE_ARRAY);
#line 5497 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_citizen_array_class_init (SerializableGeeCollectionsTDocumentTestCitizenArrayClass * klass,
                                                                      gpointer klass_data)
{
#line 38 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_citizen_array_parent_class = g_type_class_peek_parent (klass);
#line 5506 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_citizen_array_instance_init (SerializableGeeCollectionsTDocumentTestCitizenArray * self,
                                                                         gpointer klass)
{
}

GType
serializable_gee_collections_tdocument_test_citizen_array_get_type (void)
{
	static volatile gsize serializable_gee_collections_tdocument_test_citizen_array_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_tdocument_test_citizen_array_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTDocumentTestCitizenArrayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_tdocument_test_citizen_array_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTDocumentTestCitizenArray), 0, (GInstanceInitFunc) serializable_gee_collections_tdocument_test_citizen_array_instance_init, NULL };
		GType serializable_gee_collections_tdocument_test_citizen_array_type_id;
		serializable_gee_collections_tdocument_test_citizen_array_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_ARRAY_LIST, "SerializableGeeCollectionsTDocumentTestCitizenArray", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_collections_tdocument_test_citizen_array_type_id__volatile, serializable_gee_collections_tdocument_test_citizen_array_type_id);
	}
	return serializable_gee_collections_tdocument_test_citizen_array_type_id__volatile;
}

static void
serializable_gee_collections_tdocument_test_citizen_class_init (SerializableGeeCollectionsTDocumentTestCitizenClass * klass,
                                                                gpointer klass_data)
{
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_citizen_parent_class = g_type_class_peek_parent (klass);
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeCollectionsTDocumentTestCitizen_private_offset);
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableObjectModelClass *) klass)->serialize_use_xml_node_value = (gboolean (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_tdocument_test_citizen_real_serialize_use_xml_node_value;
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_tdocument_test_citizen_real_to_string;
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_tdocument_test_citizen_real_node_name;
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_collections_tdocument_test_citizen_get_property;
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_collections_tdocument_test_citizen_set_property;
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_collections_tdocument_test_citizen_finalize;
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_CTYPE_PROPERTY, serializable_gee_collections_tdocument_test_citizen_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_CTYPE_PROPERTY] = g_param_spec_string ("ctype", "ctype", "ctype", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5550 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_citizen_instance_init (SerializableGeeCollectionsTDocumentTestCitizen * self,
                                                                   gpointer klass)
{
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
	self->priv = serializable_gee_collections_tdocument_test_citizen_get_instance_private (self);
#line 5559 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_citizen_finalize (GObject * obj)
{
	SerializableGeeCollectionsTDocumentTestCitizen * self;
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_CITIZEN, SerializableGeeCollectionsTDocumentTestCitizen);
#line 33 "SerializableGeeCollections-TDocument-Test.vala"
	_g_free0 (self->priv->_ctype);
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (serializable_gee_collections_tdocument_test_citizen_parent_class)->finalize (obj);
#line 5572 "SerializableGeeCollections-TDocument-Test.c"
}

static GType
serializable_gee_collections_tdocument_test_citizen_get_type (void)
{
	static volatile gsize serializable_gee_collections_tdocument_test_citizen_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_tdocument_test_citizen_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTDocumentTestCitizenClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_tdocument_test_citizen_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTDocumentTestCitizen), 0, (GInstanceInitFunc) serializable_gee_collections_tdocument_test_citizen_instance_init, NULL };
		GType serializable_gee_collections_tdocument_test_citizen_type_id;
		serializable_gee_collections_tdocument_test_citizen_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeCollectionsTDocumentTestCitizen", &g_define_type_info, 0);
		SerializableGeeCollectionsTDocumentTestCitizen_private_offset = g_type_add_instance_private (serializable_gee_collections_tdocument_test_citizen_type_id, sizeof (SerializableGeeCollectionsTDocumentTestCitizenPrivate));
		g_once_init_leave (&serializable_gee_collections_tdocument_test_citizen_type_id__volatile, serializable_gee_collections_tdocument_test_citizen_type_id);
	}
	return serializable_gee_collections_tdocument_test_citizen_type_id__volatile;
}

static void
_vala_serializable_gee_collections_tdocument_test_citizen_get_property (GObject * object,
                                                                        guint property_id,
                                                                        GValue * value,
                                                                        GParamSpec * pspec)
{
	SerializableGeeCollectionsTDocumentTestCitizen * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_CITIZEN, SerializableGeeCollectionsTDocumentTestCitizen);
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
	switch (property_id) {
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_CTYPE_PROPERTY:
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
		g_value_set_string (value, serializable_gee_collections_tdocument_test_citizen_get_ctype (self));
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 5605 "SerializableGeeCollections-TDocument-Test.c"
		default:
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 5611 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static void
_vala_serializable_gee_collections_tdocument_test_citizen_set_property (GObject * object,
                                                                        guint property_id,
                                                                        const GValue * value,
                                                                        GParamSpec * pspec)
{
	SerializableGeeCollectionsTDocumentTestCitizen * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_CITIZEN, SerializableGeeCollectionsTDocumentTestCitizen);
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
	switch (property_id) {
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_CTYPE_PROPERTY:
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_citizen_set_ctype (self, g_value_get_string (value));
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 5631 "SerializableGeeCollections-TDocument-Test.c"
		default:
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 31 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 5637 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static inline gpointer
serializable_gee_collections_tdocument_test_asteroid_get_instance_private (SerializableGeeCollectionsTDocumentTestAsteroid* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeCollectionsTDocumentTestAsteroid_private_offset);
}

static SerializableGeeCollectionsTDocumentTestAsteroid*
serializable_gee_collections_tdocument_test_asteroid_construct_with_size (GType object_type,
                                                                          gint size)
{
	SerializableGeeCollectionsTDocumentTestAsteroid * self = NULL;
#line 43 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestAsteroid*) gxml_serializable_object_model_construct (object_type);
#line 43 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_asteroid_set_size (self, size);
#line 43 "SerializableGeeCollections-TDocument-Test.vala"
	return self;
#line 5658 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestAsteroid*
serializable_gee_collections_tdocument_test_asteroid_new_with_size (gint size)
{
#line 43 "SerializableGeeCollections-TDocument-Test.vala"
	return serializable_gee_collections_tdocument_test_asteroid_construct_with_size (SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_ASTEROID, size);
#line 5666 "SerializableGeeCollections-TDocument-Test.c"
}

static gchar*
serializable_gee_collections_tdocument_test_asteroid_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTDocumentTestAsteroid * self;
	gchar* result = NULL;
	gint _tmp0_;
	gchar* _tmp1_;
#line 44 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestAsteroid*) base;
#line 44 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_size;
#line 44 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp1_ = g_strdup_printf ("%i", _tmp0_);
#line 44 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp1_;
#line 44 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 5686 "SerializableGeeCollections-TDocument-Test.c"
}

static gchar*
serializable_gee_collections_tdocument_test_asteroid_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTDocumentTestAsteroid * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 45 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestAsteroid*) base;
#line 45 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = g_strdup ("asteroid");
#line 45 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 45 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 5703 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestAsteroid*
serializable_gee_collections_tdocument_test_asteroid_construct (GType object_type)
{
	SerializableGeeCollectionsTDocumentTestAsteroid * self = NULL;
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestAsteroid*) gxml_serializable_object_model_construct (object_type);
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
	return self;
#line 5714 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestAsteroid*
serializable_gee_collections_tdocument_test_asteroid_new (void)
{
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
	return serializable_gee_collections_tdocument_test_asteroid_construct (SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_ASTEROID);
#line 5722 "SerializableGeeCollections-TDocument-Test.c"
}

static gint
serializable_gee_collections_tdocument_test_asteroid_get_size (SerializableGeeCollectionsTDocumentTestAsteroid* self)
{
	gint result;
#line 42 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 42 "SerializableGeeCollections-TDocument-Test.vala"
	result = self->priv->_size;
#line 42 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 5735 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_asteroid_set_size (SerializableGeeCollectionsTDocumentTestAsteroid* self,
                                                               gint value)
{
#line 42 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_if_fail (self != NULL);
#line 42 "SerializableGeeCollections-TDocument-Test.vala"
	if (serializable_gee_collections_tdocument_test_asteroid_get_size (self) != value) {
#line 42 "SerializableGeeCollections-TDocument-Test.vala"
		self->priv->_size = value;
#line 42 "SerializableGeeCollections-TDocument-Test.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_tdocument_test_asteroid_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_SIZE_PROPERTY]);
#line 5750 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static SerializableGeeCollectionsTDocumentTestAsteroidArray*
serializable_gee_collections_tdocument_test_asteroid_array_construct (GType object_type)
{
	SerializableGeeCollectionsTDocumentTestAsteroidArray * self = NULL;
#line 47 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestAsteroidArray*) gxml_serializable_array_list_construct (object_type, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_ASTEROID, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 47 "SerializableGeeCollections-TDocument-Test.vala"
	return self;
#line 5762 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestAsteroidArray*
serializable_gee_collections_tdocument_test_asteroid_array_new (void)
{
#line 47 "SerializableGeeCollections-TDocument-Test.vala"
	return serializable_gee_collections_tdocument_test_asteroid_array_construct (SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_TYPE_ARRAY);
#line 5770 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_asteroid_array_class_init (SerializableGeeCollectionsTDocumentTestAsteroidArrayClass * klass,
                                                                       gpointer klass_data)
{
#line 47 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_asteroid_array_parent_class = g_type_class_peek_parent (klass);
#line 5779 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_asteroid_array_instance_init (SerializableGeeCollectionsTDocumentTestAsteroidArray * self,
                                                                          gpointer klass)
{
}

GType
serializable_gee_collections_tdocument_test_asteroid_array_get_type (void)
{
	static volatile gsize serializable_gee_collections_tdocument_test_asteroid_array_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_tdocument_test_asteroid_array_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTDocumentTestAsteroidArrayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_tdocument_test_asteroid_array_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTDocumentTestAsteroidArray), 0, (GInstanceInitFunc) serializable_gee_collections_tdocument_test_asteroid_array_instance_init, NULL };
		GType serializable_gee_collections_tdocument_test_asteroid_array_type_id;
		serializable_gee_collections_tdocument_test_asteroid_array_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_ARRAY_LIST, "SerializableGeeCollectionsTDocumentTestAsteroidArray", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_collections_tdocument_test_asteroid_array_type_id__volatile, serializable_gee_collections_tdocument_test_asteroid_array_type_id);
	}
	return serializable_gee_collections_tdocument_test_asteroid_array_type_id__volatile;
}

static void
serializable_gee_collections_tdocument_test_asteroid_class_init (SerializableGeeCollectionsTDocumentTestAsteroidClass * klass,
                                                                 gpointer klass_data)
{
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_asteroid_parent_class = g_type_class_peek_parent (klass);
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeCollectionsTDocumentTestAsteroid_private_offset);
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_tdocument_test_asteroid_real_to_string;
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_tdocument_test_asteroid_real_node_name;
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_collections_tdocument_test_asteroid_get_property;
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_collections_tdocument_test_asteroid_set_property;
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_collections_tdocument_test_asteroid_finalize;
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_SIZE_PROPERTY, serializable_gee_collections_tdocument_test_asteroid_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_SIZE_PROPERTY] = g_param_spec_int ("size", "size", "size", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5821 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_asteroid_instance_init (SerializableGeeCollectionsTDocumentTestAsteroid * self,
                                                                    gpointer klass)
{
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
	self->priv = serializable_gee_collections_tdocument_test_asteroid_get_instance_private (self);
#line 5830 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_asteroid_finalize (GObject * obj)
{
	SerializableGeeCollectionsTDocumentTestAsteroid * self;
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_ASTEROID, SerializableGeeCollectionsTDocumentTestAsteroid);
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (serializable_gee_collections_tdocument_test_asteroid_parent_class)->finalize (obj);
#line 5841 "SerializableGeeCollections-TDocument-Test.c"
}

static GType
serializable_gee_collections_tdocument_test_asteroid_get_type (void)
{
	static volatile gsize serializable_gee_collections_tdocument_test_asteroid_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_tdocument_test_asteroid_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTDocumentTestAsteroidClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_tdocument_test_asteroid_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTDocumentTestAsteroid), 0, (GInstanceInitFunc) serializable_gee_collections_tdocument_test_asteroid_instance_init, NULL };
		GType serializable_gee_collections_tdocument_test_asteroid_type_id;
		serializable_gee_collections_tdocument_test_asteroid_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeCollectionsTDocumentTestAsteroid", &g_define_type_info, 0);
		SerializableGeeCollectionsTDocumentTestAsteroid_private_offset = g_type_add_instance_private (serializable_gee_collections_tdocument_test_asteroid_type_id, sizeof (SerializableGeeCollectionsTDocumentTestAsteroidPrivate));
		g_once_init_leave (&serializable_gee_collections_tdocument_test_asteroid_type_id__volatile, serializable_gee_collections_tdocument_test_asteroid_type_id);
	}
	return serializable_gee_collections_tdocument_test_asteroid_type_id__volatile;
}

static void
_vala_serializable_gee_collections_tdocument_test_asteroid_get_property (GObject * object,
                                                                         guint property_id,
                                                                         GValue * value,
                                                                         GParamSpec * pspec)
{
	SerializableGeeCollectionsTDocumentTestAsteroid * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_ASTEROID, SerializableGeeCollectionsTDocumentTestAsteroid);
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
	switch (property_id) {
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_SIZE_PROPERTY:
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
		g_value_set_int (value, serializable_gee_collections_tdocument_test_asteroid_get_size (self));
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 5874 "SerializableGeeCollections-TDocument-Test.c"
		default:
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 5880 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static void
_vala_serializable_gee_collections_tdocument_test_asteroid_set_property (GObject * object,
                                                                         guint property_id,
                                                                         const GValue * value,
                                                                         GParamSpec * pspec)
{
	SerializableGeeCollectionsTDocumentTestAsteroid * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_ASTEROID, SerializableGeeCollectionsTDocumentTestAsteroid);
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
	switch (property_id) {
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_SIZE_PROPERTY:
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_asteroid_set_size (self, g_value_get_int (value));
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 5900 "SerializableGeeCollections-TDocument-Test.c"
		default:
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 40 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 5906 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static inline gpointer
serializable_gee_collections_tdocument_test_planet_get_instance_private (SerializableGeeCollectionsTDocumentTestPlanet* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeCollectionsTDocumentTestPlanet_private_offset);
}

static gchar*
serializable_gee_collections_tdocument_test_planet_real_get_map_key (GXmlSerializableMapKey* base)
{
	SerializableGeeCollectionsTDocumentTestPlanet * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 51 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestPlanet*) base;
#line 51 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_name;
#line 51 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 51 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp1_;
#line 51 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 5933 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestPlanet*
serializable_gee_collections_tdocument_test_planet_construct_named (GType object_type,
                                                                    const gchar* name)
{
	SerializableGeeCollectionsTDocumentTestPlanet * self = NULL;
#line 54 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 54 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestPlanet*) gxml_serializable_container_construct (object_type);
#line 54 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_planet_set_name (self, name);
#line 54 "SerializableGeeCollections-TDocument-Test.vala"
	return self;
#line 5949 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestPlanet*
serializable_gee_collections_tdocument_test_planet_new_named (const gchar* name)
{
#line 54 "SerializableGeeCollections-TDocument-Test.vala"
	return serializable_gee_collections_tdocument_test_planet_construct_named (SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_PLANET, name);
#line 5957 "SerializableGeeCollections-TDocument-Test.c"
}

static gchar*
serializable_gee_collections_tdocument_test_planet_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTDocumentTestPlanet * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 55 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestPlanet*) base;
#line 55 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = g_strdup ("planet");
#line 55 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 55 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 5974 "SerializableGeeCollections-TDocument-Test.c"
}

static gchar*
serializable_gee_collections_tdocument_test_planet_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTDocumentTestPlanet * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 56 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestPlanet*) base;
#line 56 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_name;
#line 56 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 56 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp1_;
#line 56 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 5994 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_planet_real_init_containers (GXmlSerializableContainer* base)
{
	SerializableGeeCollectionsTDocumentTestPlanet * self;
	SerializableGeeCollectionsTDocumentTestCitizenArray* _tmp0_;
#line 58 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestPlanet*) base;
#line 60 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_citizens;
#line 60 "SerializableGeeCollections-TDocument-Test.vala"
	if (_tmp0_ == NULL) {
#line 6008 "SerializableGeeCollections-TDocument-Test.c"
		SerializableGeeCollectionsTDocumentTestCitizenArray* _tmp1_;
		SerializableGeeCollectionsTDocumentTestCitizenArray* _tmp2_;
#line 61 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp1_ = serializable_gee_collections_tdocument_test_citizen_array_new ();
#line 61 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp2_ = _tmp1_;
#line 61 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_planet_set_citizens (self, _tmp2_);
#line 61 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp2_);
#line 6019 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static SerializableGeeCollectionsTDocumentTestPlanet*
serializable_gee_collections_tdocument_test_planet_construct (GType object_type)
{
	SerializableGeeCollectionsTDocumentTestPlanet * self = NULL;
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestPlanet*) gxml_serializable_container_construct (object_type);
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
	return self;
#line 6031 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestPlanet*
serializable_gee_collections_tdocument_test_planet_new (void)
{
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
	return serializable_gee_collections_tdocument_test_planet_construct (SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_PLANET);
#line 6039 "SerializableGeeCollections-TDocument-Test.c"
}

static const gchar*
serializable_gee_collections_tdocument_test_planet_get_name (SerializableGeeCollectionsTDocumentTestPlanet* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 52 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 52 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_name;
#line 52 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 52 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 6055 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_planet_set_name (SerializableGeeCollectionsTDocumentTestPlanet* self,
                                                             const gchar* value)
{
#line 52 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_if_fail (self != NULL);
#line 52 "SerializableGeeCollections-TDocument-Test.vala"
	if (g_strcmp0 (value, serializable_gee_collections_tdocument_test_planet_get_name (self)) != 0) {
#line 6066 "SerializableGeeCollections-TDocument-Test.c"
		gchar* _tmp0_;
#line 52 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp0_ = g_strdup (value);
#line 52 "SerializableGeeCollections-TDocument-Test.vala"
		_g_free0 (self->priv->_name);
#line 52 "SerializableGeeCollections-TDocument-Test.vala"
		self->priv->_name = _tmp0_;
#line 52 "SerializableGeeCollections-TDocument-Test.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_tdocument_test_planet_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_NAME_PROPERTY]);
#line 6076 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static SerializableGeeCollectionsTDocumentTestCitizenArray*
serializable_gee_collections_tdocument_test_planet_get_citizens (SerializableGeeCollectionsTDocumentTestPlanet* self)
{
	SerializableGeeCollectionsTDocumentTestCitizenArray* result;
	SerializableGeeCollectionsTDocumentTestCitizenArray* _tmp0_;
#line 53 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 53 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_citizens;
#line 53 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 53 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 6093 "SerializableGeeCollections-TDocument-Test.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 53 "SerializableGeeCollections-TDocument-Test.vala"
	return self ? g_object_ref (self) : NULL;
#line 6101 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_planet_set_citizens (SerializableGeeCollectionsTDocumentTestPlanet* self,
                                                                 SerializableGeeCollectionsTDocumentTestCitizenArray* value)
{
#line 53 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_if_fail (self != NULL);
#line 53 "SerializableGeeCollections-TDocument-Test.vala"
	if (serializable_gee_collections_tdocument_test_planet_get_citizens (self) != value) {
#line 6112 "SerializableGeeCollections-TDocument-Test.c"
		SerializableGeeCollectionsTDocumentTestCitizenArray* _tmp0_;
#line 53 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 53 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (self->priv->_citizens);
#line 53 "SerializableGeeCollections-TDocument-Test.vala"
		self->priv->_citizens = _tmp0_;
#line 53 "SerializableGeeCollections-TDocument-Test.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_tdocument_test_planet_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_CITIZENS_PROPERTY]);
#line 6122 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static SerializableGeeCollectionsTDocumentTestPlanetCollection*
serializable_gee_collections_tdocument_test_planet_collection_construct (GType object_type)
{
	SerializableGeeCollectionsTDocumentTestPlanetCollection * self = NULL;
#line 64 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestPlanetCollection*) gxml_serializable_tree_map_construct (object_type, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_PLANET, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 64 "SerializableGeeCollections-TDocument-Test.vala"
	return self;
#line 6134 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestPlanetCollection*
serializable_gee_collections_tdocument_test_planet_collection_new (void)
{
#line 64 "SerializableGeeCollections-TDocument-Test.vala"
	return serializable_gee_collections_tdocument_test_planet_collection_construct (SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_TYPE_COLLECTION);
#line 6142 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_planet_collection_class_init (SerializableGeeCollectionsTDocumentTestPlanetCollectionClass * klass,
                                                                          gpointer klass_data)
{
#line 64 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_planet_collection_parent_class = g_type_class_peek_parent (klass);
#line 6151 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_planet_collection_instance_init (SerializableGeeCollectionsTDocumentTestPlanetCollection * self,
                                                                             gpointer klass)
{
}

GType
serializable_gee_collections_tdocument_test_planet_collection_get_type (void)
{
	static volatile gsize serializable_gee_collections_tdocument_test_planet_collection_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_tdocument_test_planet_collection_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTDocumentTestPlanetCollectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_tdocument_test_planet_collection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTDocumentTestPlanetCollection), 0, (GInstanceInitFunc) serializable_gee_collections_tdocument_test_planet_collection_instance_init, NULL };
		GType serializable_gee_collections_tdocument_test_planet_collection_type_id;
		serializable_gee_collections_tdocument_test_planet_collection_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_TREE_MAP, "SerializableGeeCollectionsTDocumentTestPlanetCollection", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_collections_tdocument_test_planet_collection_type_id__volatile, serializable_gee_collections_tdocument_test_planet_collection_type_id);
	}
	return serializable_gee_collections_tdocument_test_planet_collection_type_id__volatile;
}

static void
serializable_gee_collections_tdocument_test_planet_class_init (SerializableGeeCollectionsTDocumentTestPlanetClass * klass,
                                                               gpointer klass_data)
{
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_planet_parent_class = g_type_class_peek_parent (klass);
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeCollectionsTDocumentTestPlanet_private_offset);
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_tdocument_test_planet_real_node_name;
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_tdocument_test_planet_real_to_string;
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableContainerClass *) klass)->init_containers = (void (*) (GXmlSerializableContainer*)) serializable_gee_collections_tdocument_test_planet_real_init_containers;
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_collections_tdocument_test_planet_get_property;
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_collections_tdocument_test_planet_set_property;
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_collections_tdocument_test_planet_finalize;
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_NAME_PROPERTY, serializable_gee_collections_tdocument_test_planet_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_CITIZENS_PROPERTY, serializable_gee_collections_tdocument_test_planet_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_CITIZENS_PROPERTY] = g_param_spec_object ("citizens", "citizens", "citizens", SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CITIZEN_TYPE_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6197 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_planet_gxml_serializable_map_key_interface_init (GXmlSerializableMapKeyIface * iface,
                                                                                             gpointer iface_data)
{
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_planet_gxml_serializable_map_key_parent_iface = g_type_interface_peek_parent (iface);
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
	iface->get_map_key = (gpointer (*) (GXmlSerializableMapKey*)) serializable_gee_collections_tdocument_test_planet_real_get_map_key;
#line 6208 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_planet_instance_init (SerializableGeeCollectionsTDocumentTestPlanet * self,
                                                                  gpointer klass)
{
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
	self->priv = serializable_gee_collections_tdocument_test_planet_get_instance_private (self);
#line 6217 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_planet_finalize (GObject * obj)
{
	SerializableGeeCollectionsTDocumentTestPlanet * self;
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_PLANET, SerializableGeeCollectionsTDocumentTestPlanet);
#line 52 "SerializableGeeCollections-TDocument-Test.vala"
	_g_free0 (self->priv->_name);
#line 53 "SerializableGeeCollections-TDocument-Test.vala"
	_g_object_unref0 (self->priv->_citizens);
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (serializable_gee_collections_tdocument_test_planet_parent_class)->finalize (obj);
#line 6232 "SerializableGeeCollections-TDocument-Test.c"
}

static GType
serializable_gee_collections_tdocument_test_planet_get_type (void)
{
	static volatile gsize serializable_gee_collections_tdocument_test_planet_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_tdocument_test_planet_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTDocumentTestPlanetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_tdocument_test_planet_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTDocumentTestPlanet), 0, (GInstanceInitFunc) serializable_gee_collections_tdocument_test_planet_instance_init, NULL };
		static const GInterfaceInfo gxml_serializable_map_key_info = { (GInterfaceInitFunc) serializable_gee_collections_tdocument_test_planet_gxml_serializable_map_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType serializable_gee_collections_tdocument_test_planet_type_id;
		serializable_gee_collections_tdocument_test_planet_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_CONTAINER, "SerializableGeeCollectionsTDocumentTestPlanet", &g_define_type_info, 0);
		g_type_add_interface_static (serializable_gee_collections_tdocument_test_planet_type_id, GXML_TYPE_SERIALIZABLE_MAP_KEY, &gxml_serializable_map_key_info);
		SerializableGeeCollectionsTDocumentTestPlanet_private_offset = g_type_add_instance_private (serializable_gee_collections_tdocument_test_planet_type_id, sizeof (SerializableGeeCollectionsTDocumentTestPlanetPrivate));
		g_once_init_leave (&serializable_gee_collections_tdocument_test_planet_type_id__volatile, serializable_gee_collections_tdocument_test_planet_type_id);
	}
	return serializable_gee_collections_tdocument_test_planet_type_id__volatile;
}

static void
_vala_serializable_gee_collections_tdocument_test_planet_get_property (GObject * object,
                                                                       guint property_id,
                                                                       GValue * value,
                                                                       GParamSpec * pspec)
{
	SerializableGeeCollectionsTDocumentTestPlanet * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_PLANET, SerializableGeeCollectionsTDocumentTestPlanet);
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
	switch (property_id) {
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_NAME_PROPERTY:
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
		g_value_set_string (value, serializable_gee_collections_tdocument_test_planet_get_name (self));
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_CITIZENS_PROPERTY:
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
		g_value_set_object (value, serializable_gee_collections_tdocument_test_planet_get_citizens (self));
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 6273 "SerializableGeeCollections-TDocument-Test.c"
		default:
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 6279 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static void
_vala_serializable_gee_collections_tdocument_test_planet_set_property (GObject * object,
                                                                       guint property_id,
                                                                       const GValue * value,
                                                                       GParamSpec * pspec)
{
	SerializableGeeCollectionsTDocumentTestPlanet * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_PLANET, SerializableGeeCollectionsTDocumentTestPlanet);
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
	switch (property_id) {
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_NAME_PROPERTY:
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_planet_set_name (self, g_value_get_string (value));
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_CITIZENS_PROPERTY:
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_planet_set_citizens (self, g_value_get_object (value));
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 6305 "SerializableGeeCollections-TDocument-Test.c"
		default:
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 49 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 6311 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static inline gpointer
serializable_gee_collections_tdocument_test_space_get_instance_private (SerializableGeeCollectionsTDocumentTestSpace* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeCollectionsTDocumentTestSpace_private_offset);
}

static gchar*
serializable_gee_collections_tdocument_test_space_real_get_map_key (GXmlSerializableMapKey* base)
{
	SerializableGeeCollectionsTDocumentTestSpace * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 68 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestSpace*) base;
#line 68 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_name;
#line 68 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 68 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp1_;
#line 68 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 6338 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestSpace*
serializable_gee_collections_tdocument_test_space_construct_named (GType object_type,
                                                                   const gchar* name)
{
	SerializableGeeCollectionsTDocumentTestSpace * self = NULL;
#line 73 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 73 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestSpace*) gxml_serializable_container_construct (object_type);
#line 73 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_space_set_name (self, name);
#line 73 "SerializableGeeCollections-TDocument-Test.vala"
	return self;
#line 6354 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestSpace*
serializable_gee_collections_tdocument_test_space_new_named (const gchar* name)
{
#line 73 "SerializableGeeCollections-TDocument-Test.vala"
	return serializable_gee_collections_tdocument_test_space_construct_named (SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE, name);
#line 6362 "SerializableGeeCollections-TDocument-Test.c"
}

static gchar*
serializable_gee_collections_tdocument_test_space_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTDocumentTestSpace * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 75 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestSpace*) base;
#line 75 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = g_strdup ("space");
#line 75 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 75 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 6379 "SerializableGeeCollections-TDocument-Test.c"
}

static gchar*
serializable_gee_collections_tdocument_test_space_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTDocumentTestSpace * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 76 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestSpace*) base;
#line 76 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_name;
#line 76 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 76 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp1_;
#line 76 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 6399 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_space_real_init_containers (GXmlSerializableContainer* base)
{
	SerializableGeeCollectionsTDocumentTestSpace * self;
	SerializableGeeCollectionsTDocumentTestAsteroidArray* _tmp0_;
	SerializableGeeCollectionsTDocumentTestPlanetCollection* _tmp3_;
#line 77 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestSpace*) base;
#line 79 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_asteroids;
#line 79 "SerializableGeeCollections-TDocument-Test.vala"
	if (_tmp0_ == NULL) {
#line 6414 "SerializableGeeCollections-TDocument-Test.c"
		SerializableGeeCollectionsTDocumentTestAsteroidArray* _tmp1_;
		SerializableGeeCollectionsTDocumentTestAsteroidArray* _tmp2_;
#line 80 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp1_ = serializable_gee_collections_tdocument_test_asteroid_array_new ();
#line 80 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp2_ = _tmp1_;
#line 80 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_space_set_asteroids (self, _tmp2_);
#line 80 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp2_);
#line 6425 "SerializableGeeCollections-TDocument-Test.c"
	}
#line 81 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp3_ = self->priv->_planets;
#line 81 "SerializableGeeCollections-TDocument-Test.vala"
	if (_tmp3_ == NULL) {
#line 6431 "SerializableGeeCollections-TDocument-Test.c"
		SerializableGeeCollectionsTDocumentTestPlanetCollection* _tmp4_;
		SerializableGeeCollectionsTDocumentTestPlanetCollection* _tmp5_;
#line 82 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp4_ = serializable_gee_collections_tdocument_test_planet_collection_new ();
#line 82 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp5_ = _tmp4_;
#line 82 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_space_set_planets (self, _tmp5_);
#line 82 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp5_);
#line 6442 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static SerializableGeeCollectionsTDocumentTestSpace*
serializable_gee_collections_tdocument_test_space_construct (GType object_type)
{
	SerializableGeeCollectionsTDocumentTestSpace * self = NULL;
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestSpace*) gxml_serializable_container_construct (object_type);
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
	return self;
#line 6454 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestSpace*
serializable_gee_collections_tdocument_test_space_new (void)
{
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
	return serializable_gee_collections_tdocument_test_space_construct (SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE);
#line 6462 "SerializableGeeCollections-TDocument-Test.c"
}

static const gchar*
serializable_gee_collections_tdocument_test_space_get_name (SerializableGeeCollectionsTDocumentTestSpace* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 69 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 69 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_name;
#line 69 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 69 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 6478 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_space_set_name (SerializableGeeCollectionsTDocumentTestSpace* self,
                                                            const gchar* value)
{
#line 69 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_if_fail (self != NULL);
#line 69 "SerializableGeeCollections-TDocument-Test.vala"
	if (g_strcmp0 (value, serializable_gee_collections_tdocument_test_space_get_name (self)) != 0) {
#line 6489 "SerializableGeeCollections-TDocument-Test.c"
		gchar* _tmp0_;
#line 69 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp0_ = g_strdup (value);
#line 69 "SerializableGeeCollections-TDocument-Test.vala"
		_g_free0 (self->priv->_name);
#line 69 "SerializableGeeCollections-TDocument-Test.vala"
		self->priv->_name = _tmp0_;
#line 69 "SerializableGeeCollections-TDocument-Test.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_tdocument_test_space_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_NAME_PROPERTY]);
#line 6499 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static SerializableGeeCollectionsTDocumentTestPlanetCollection*
serializable_gee_collections_tdocument_test_space_get_planets (SerializableGeeCollectionsTDocumentTestSpace* self)
{
	SerializableGeeCollectionsTDocumentTestPlanetCollection* result;
	SerializableGeeCollectionsTDocumentTestPlanetCollection* _tmp0_;
#line 70 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 70 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_planets;
#line 70 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 70 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 6516 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_space_set_planets (SerializableGeeCollectionsTDocumentTestSpace* self,
                                                               SerializableGeeCollectionsTDocumentTestPlanetCollection* value)
{
#line 70 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_if_fail (self != NULL);
#line 70 "SerializableGeeCollections-TDocument-Test.vala"
	if (serializable_gee_collections_tdocument_test_space_get_planets (self) != value) {
#line 6527 "SerializableGeeCollections-TDocument-Test.c"
		SerializableGeeCollectionsTDocumentTestPlanetCollection* _tmp0_;
#line 70 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 70 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (self->priv->_planets);
#line 70 "SerializableGeeCollections-TDocument-Test.vala"
		self->priv->_planets = _tmp0_;
#line 70 "SerializableGeeCollections-TDocument-Test.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_tdocument_test_space_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_PLANETS_PROPERTY]);
#line 6537 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static SerializableGeeCollectionsTDocumentTestAsteroidArray*
serializable_gee_collections_tdocument_test_space_get_asteroids (SerializableGeeCollectionsTDocumentTestSpace* self)
{
	SerializableGeeCollectionsTDocumentTestAsteroidArray* result;
	SerializableGeeCollectionsTDocumentTestAsteroidArray* _tmp0_;
#line 71 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 71 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_asteroids;
#line 71 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 71 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 6554 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_space_set_asteroids (SerializableGeeCollectionsTDocumentTestSpace* self,
                                                                 SerializableGeeCollectionsTDocumentTestAsteroidArray* value)
{
#line 71 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_if_fail (self != NULL);
#line 71 "SerializableGeeCollections-TDocument-Test.vala"
	if (serializable_gee_collections_tdocument_test_space_get_asteroids (self) != value) {
#line 6565 "SerializableGeeCollections-TDocument-Test.c"
		SerializableGeeCollectionsTDocumentTestAsteroidArray* _tmp0_;
#line 71 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 71 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (self->priv->_asteroids);
#line 71 "SerializableGeeCollections-TDocument-Test.vala"
		self->priv->_asteroids = _tmp0_;
#line 71 "SerializableGeeCollections-TDocument-Test.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_tdocument_test_space_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_ASTEROIDS_PROPERTY]);
#line 6575 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static SerializableGeeCollectionsTDocumentTestSpaceCollection*
serializable_gee_collections_tdocument_test_space_collection_construct (GType object_type)
{
	SerializableGeeCollectionsTDocumentTestSpaceCollection * self = NULL;
#line 84 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestSpaceCollection*) gxml_serializable_tree_map_construct (object_type, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 84 "SerializableGeeCollections-TDocument-Test.vala"
	return self;
#line 6587 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestSpaceCollection*
serializable_gee_collections_tdocument_test_space_collection_new (void)
{
#line 84 "SerializableGeeCollections-TDocument-Test.vala"
	return serializable_gee_collections_tdocument_test_space_collection_construct (SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_TYPE_COLLECTION);
#line 6595 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_space_collection_class_init (SerializableGeeCollectionsTDocumentTestSpaceCollectionClass * klass,
                                                                         gpointer klass_data)
{
#line 84 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_space_collection_parent_class = g_type_class_peek_parent (klass);
#line 6604 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_space_collection_instance_init (SerializableGeeCollectionsTDocumentTestSpaceCollection * self,
                                                                            gpointer klass)
{
}

GType
serializable_gee_collections_tdocument_test_space_collection_get_type (void)
{
	static volatile gsize serializable_gee_collections_tdocument_test_space_collection_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_tdocument_test_space_collection_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTDocumentTestSpaceCollectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_tdocument_test_space_collection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTDocumentTestSpaceCollection), 0, (GInstanceInitFunc) serializable_gee_collections_tdocument_test_space_collection_instance_init, NULL };
		GType serializable_gee_collections_tdocument_test_space_collection_type_id;
		serializable_gee_collections_tdocument_test_space_collection_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_TREE_MAP, "SerializableGeeCollectionsTDocumentTestSpaceCollection", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_collections_tdocument_test_space_collection_type_id__volatile, serializable_gee_collections_tdocument_test_space_collection_type_id);
	}
	return serializable_gee_collections_tdocument_test_space_collection_type_id__volatile;
}

static void
serializable_gee_collections_tdocument_test_space_class_init (SerializableGeeCollectionsTDocumentTestSpaceClass * klass,
                                                              gpointer klass_data)
{
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_space_parent_class = g_type_class_peek_parent (klass);
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeCollectionsTDocumentTestSpace_private_offset);
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_tdocument_test_space_real_node_name;
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_tdocument_test_space_real_to_string;
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableContainerClass *) klass)->init_containers = (void (*) (GXmlSerializableContainer*)) serializable_gee_collections_tdocument_test_space_real_init_containers;
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_collections_tdocument_test_space_get_property;
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_collections_tdocument_test_space_set_property;
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_collections_tdocument_test_space_finalize;
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_NAME_PROPERTY, serializable_gee_collections_tdocument_test_space_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_PLANETS_PROPERTY, serializable_gee_collections_tdocument_test_space_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_PLANETS_PROPERTY] = g_param_spec_object ("planets", "planets", "planets", SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_PLANET_TYPE_COLLECTION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_ASTEROIDS_PROPERTY, serializable_gee_collections_tdocument_test_space_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_ASTEROIDS_PROPERTY] = g_param_spec_object ("asteroids", "asteroids", "asteroids", SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_ASTEROID_TYPE_ARRAY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6652 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_space_gxml_serializable_map_key_interface_init (GXmlSerializableMapKeyIface * iface,
                                                                                            gpointer iface_data)
{
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_space_gxml_serializable_map_key_parent_iface = g_type_interface_peek_parent (iface);
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
	iface->get_map_key = (gpointer (*) (GXmlSerializableMapKey*)) serializable_gee_collections_tdocument_test_space_real_get_map_key;
#line 6663 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_space_instance_init (SerializableGeeCollectionsTDocumentTestSpace * self,
                                                                 gpointer klass)
{
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
	self->priv = serializable_gee_collections_tdocument_test_space_get_instance_private (self);
#line 6672 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_space_finalize (GObject * obj)
{
	SerializableGeeCollectionsTDocumentTestSpace * self;
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE, SerializableGeeCollectionsTDocumentTestSpace);
#line 69 "SerializableGeeCollections-TDocument-Test.vala"
	_g_free0 (self->priv->_name);
#line 70 "SerializableGeeCollections-TDocument-Test.vala"
	_g_object_unref0 (self->priv->_planets);
#line 71 "SerializableGeeCollections-TDocument-Test.vala"
	_g_object_unref0 (self->priv->_asteroids);
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (serializable_gee_collections_tdocument_test_space_parent_class)->finalize (obj);
#line 6689 "SerializableGeeCollections-TDocument-Test.c"
}

static GType
serializable_gee_collections_tdocument_test_space_get_type (void)
{
	static volatile gsize serializable_gee_collections_tdocument_test_space_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_tdocument_test_space_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTDocumentTestSpaceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_tdocument_test_space_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTDocumentTestSpace), 0, (GInstanceInitFunc) serializable_gee_collections_tdocument_test_space_instance_init, NULL };
		static const GInterfaceInfo gxml_serializable_map_key_info = { (GInterfaceInitFunc) serializable_gee_collections_tdocument_test_space_gxml_serializable_map_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType serializable_gee_collections_tdocument_test_space_type_id;
		serializable_gee_collections_tdocument_test_space_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_CONTAINER, "SerializableGeeCollectionsTDocumentTestSpace", &g_define_type_info, 0);
		g_type_add_interface_static (serializable_gee_collections_tdocument_test_space_type_id, GXML_TYPE_SERIALIZABLE_MAP_KEY, &gxml_serializable_map_key_info);
		SerializableGeeCollectionsTDocumentTestSpace_private_offset = g_type_add_instance_private (serializable_gee_collections_tdocument_test_space_type_id, sizeof (SerializableGeeCollectionsTDocumentTestSpacePrivate));
		g_once_init_leave (&serializable_gee_collections_tdocument_test_space_type_id__volatile, serializable_gee_collections_tdocument_test_space_type_id);
	}
	return serializable_gee_collections_tdocument_test_space_type_id__volatile;
}

static void
_vala_serializable_gee_collections_tdocument_test_space_get_property (GObject * object,
                                                                      guint property_id,
                                                                      GValue * value,
                                                                      GParamSpec * pspec)
{
	SerializableGeeCollectionsTDocumentTestSpace * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE, SerializableGeeCollectionsTDocumentTestSpace);
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
	switch (property_id) {
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_NAME_PROPERTY:
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
		g_value_set_string (value, serializable_gee_collections_tdocument_test_space_get_name (self));
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_PLANETS_PROPERTY:
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
		g_value_set_object (value, serializable_gee_collections_tdocument_test_space_get_planets (self));
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_ASTEROIDS_PROPERTY:
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
		g_value_set_object (value, serializable_gee_collections_tdocument_test_space_get_asteroids (self));
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 6736 "SerializableGeeCollections-TDocument-Test.c"
		default:
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 6742 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static void
_vala_serializable_gee_collections_tdocument_test_space_set_property (GObject * object,
                                                                      guint property_id,
                                                                      const GValue * value,
                                                                      GParamSpec * pspec)
{
	SerializableGeeCollectionsTDocumentTestSpace * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE, SerializableGeeCollectionsTDocumentTestSpace);
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
	switch (property_id) {
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_NAME_PROPERTY:
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_space_set_name (self, g_value_get_string (value));
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_PLANETS_PROPERTY:
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_space_set_planets (self, g_value_get_object (value));
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_ASTEROIDS_PROPERTY:
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_space_set_asteroids (self, g_value_get_object (value));
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 6774 "SerializableGeeCollections-TDocument-Test.c"
		default:
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 66 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 6780 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static inline gpointer
serializable_gee_collections_tdocument_test_refaction_get_instance_private (SerializableGeeCollectionsTDocumentTestRefaction* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeCollectionsTDocumentTestRefaction_private_offset);
}

static SerializableGeeCollectionsTDocumentTestRefaction*
serializable_gee_collections_tdocument_test_refaction_construct_named (GType object_type,
                                                                       const gchar* manufacturer,
                                                                       const gchar* model)
{
	SerializableGeeCollectionsTDocumentTestRefaction * self = NULL;
#line 92 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (manufacturer != NULL, NULL);
#line 92 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (model != NULL, NULL);
#line 92 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestRefaction*) gxml_serializable_container_construct (object_type);
#line 94 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_refaction_set_manufacturer (self, manufacturer);
#line 95 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_refaction_set_model (self, model);
#line 92 "SerializableGeeCollections-TDocument-Test.vala"
	return self;
#line 6808 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestRefaction*
serializable_gee_collections_tdocument_test_refaction_new_named (const gchar* manufacturer,
                                                                 const gchar* model)
{
#line 92 "SerializableGeeCollections-TDocument-Test.vala"
	return serializable_gee_collections_tdocument_test_refaction_construct_named (SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_REFACTION, manufacturer, model);
#line 6817 "SerializableGeeCollections-TDocument-Test.c"
}

static gchar*
serializable_gee_collections_tdocument_test_refaction_real_get_map_primary_key (GXmlSerializableMapDualKey* base)
{
	SerializableGeeCollectionsTDocumentTestRefaction * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 98 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestRefaction*) base;
#line 98 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_manufacturer;
#line 98 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 98 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp1_;
#line 98 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 6837 "SerializableGeeCollections-TDocument-Test.c"
}

static gchar*
serializable_gee_collections_tdocument_test_refaction_real_get_map_secondary_key (GXmlSerializableMapDualKey* base)
{
	SerializableGeeCollectionsTDocumentTestRefaction * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 99 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestRefaction*) base;
#line 99 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_model;
#line 99 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 99 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp1_;
#line 99 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 6857 "SerializableGeeCollections-TDocument-Test.c"
}

static gchar*
serializable_gee_collections_tdocument_test_refaction_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTDocumentTestRefaction * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 101 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestRefaction*) base;
#line 101 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = g_strdup ("refaction");
#line 101 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 101 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 6874 "SerializableGeeCollections-TDocument-Test.c"
}

static gchar*
serializable_gee_collections_tdocument_test_refaction_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTDocumentTestRefaction * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 102 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestRefaction*) base;
#line 102 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_model;
#line 102 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 102 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp1_;
#line 102 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 6894 "SerializableGeeCollections-TDocument-Test.c"
}

static gboolean
serializable_gee_collections_tdocument_test_refaction_real_get_enable_unknown_serializable_property (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTDocumentTestRefaction * self;
	gboolean result = FALSE;
#line 103 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestRefaction*) base;
#line 103 "SerializableGeeCollections-TDocument-Test.vala"
	result = TRUE;
#line 103 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 6908 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_refaction_real_init_containers (GXmlSerializableContainer* base)
{
	SerializableGeeCollectionsTDocumentTestRefaction * self;
	SerializableGeeCollectionsTDocumentTestSpaceShipCollection* _tmp0_;
#line 105 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestRefaction*) base;
#line 107 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_spaceships;
#line 107 "SerializableGeeCollections-TDocument-Test.vala"
	if (_tmp0_ == NULL) {
#line 6922 "SerializableGeeCollections-TDocument-Test.c"
		SerializableGeeCollectionsTDocumentTestSpaceShipCollection* _tmp1_;
		SerializableGeeCollectionsTDocumentTestSpaceShipCollection* _tmp2_;
#line 108 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp1_ = serializable_gee_collections_tdocument_test_space_ship_collection_new ();
#line 108 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp2_ = _tmp1_;
#line 108 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_refaction_set_spaceships (self, _tmp2_);
#line 108 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp2_);
#line 6933 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static SerializableGeeCollectionsTDocumentTestRefaction*
serializable_gee_collections_tdocument_test_refaction_construct (GType object_type)
{
	SerializableGeeCollectionsTDocumentTestRefaction * self = NULL;
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestRefaction*) gxml_serializable_container_construct (object_type);
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
	return self;
#line 6945 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestRefaction*
serializable_gee_collections_tdocument_test_refaction_new (void)
{
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
	return serializable_gee_collections_tdocument_test_refaction_construct (SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_REFACTION);
#line 6953 "SerializableGeeCollections-TDocument-Test.c"
}

static const gchar*
serializable_gee_collections_tdocument_test_refaction_get_model (SerializableGeeCollectionsTDocumentTestRefaction* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 88 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 88 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_model;
#line 88 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 88 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 6969 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_refaction_set_model (SerializableGeeCollectionsTDocumentTestRefaction* self,
                                                                 const gchar* value)
{
#line 88 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_if_fail (self != NULL);
#line 88 "SerializableGeeCollections-TDocument-Test.vala"
	if (g_strcmp0 (value, serializable_gee_collections_tdocument_test_refaction_get_model (self)) != 0) {
#line 6980 "SerializableGeeCollections-TDocument-Test.c"
		gchar* _tmp0_;
#line 88 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp0_ = g_strdup (value);
#line 88 "SerializableGeeCollections-TDocument-Test.vala"
		_g_free0 (self->priv->_model);
#line 88 "SerializableGeeCollections-TDocument-Test.vala"
		self->priv->_model = _tmp0_;
#line 88 "SerializableGeeCollections-TDocument-Test.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_tdocument_test_refaction_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_MODEL_PROPERTY]);
#line 6990 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static const gchar*
serializable_gee_collections_tdocument_test_refaction_get_manufacturer (SerializableGeeCollectionsTDocumentTestRefaction* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 89 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 89 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_manufacturer;
#line 89 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 89 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 7007 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_refaction_set_manufacturer (SerializableGeeCollectionsTDocumentTestRefaction* self,
                                                                        const gchar* value)
{
#line 89 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_if_fail (self != NULL);
#line 89 "SerializableGeeCollections-TDocument-Test.vala"
	if (g_strcmp0 (value, serializable_gee_collections_tdocument_test_refaction_get_manufacturer (self)) != 0) {
#line 7018 "SerializableGeeCollections-TDocument-Test.c"
		gchar* _tmp0_;
#line 89 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp0_ = g_strdup (value);
#line 89 "SerializableGeeCollections-TDocument-Test.vala"
		_g_free0 (self->priv->_manufacturer);
#line 89 "SerializableGeeCollections-TDocument-Test.vala"
		self->priv->_manufacturer = _tmp0_;
#line 89 "SerializableGeeCollections-TDocument-Test.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_tdocument_test_refaction_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_MANUFACTURER_PROPERTY]);
#line 7028 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static SerializableGeeCollectionsTDocumentTestSpaceShipCollection*
serializable_gee_collections_tdocument_test_refaction_get_spaceships (SerializableGeeCollectionsTDocumentTestRefaction* self)
{
	SerializableGeeCollectionsTDocumentTestSpaceShipCollection* result;
	SerializableGeeCollectionsTDocumentTestSpaceShipCollection* _tmp0_;
#line 90 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 90 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_spaceships;
#line 90 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 90 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 7045 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_refaction_set_spaceships (SerializableGeeCollectionsTDocumentTestRefaction* self,
                                                                      SerializableGeeCollectionsTDocumentTestSpaceShipCollection* value)
{
#line 90 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_if_fail (self != NULL);
#line 90 "SerializableGeeCollections-TDocument-Test.vala"
	if (serializable_gee_collections_tdocument_test_refaction_get_spaceships (self) != value) {
#line 7056 "SerializableGeeCollections-TDocument-Test.c"
		SerializableGeeCollectionsTDocumentTestSpaceShipCollection* _tmp0_;
#line 90 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 90 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (self->priv->_spaceships);
#line 90 "SerializableGeeCollections-TDocument-Test.vala"
		self->priv->_spaceships = _tmp0_;
#line 90 "SerializableGeeCollections-TDocument-Test.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_tdocument_test_refaction_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_SPACESHIPS_PROPERTY]);
#line 7066 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static SerializableGeeCollectionsTDocumentTestRefactionCollection*
serializable_gee_collections_tdocument_test_refaction_collection_construct (GType object_type)
{
	SerializableGeeCollectionsTDocumentTestRefactionCollection * self = NULL;
#line 111 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestRefactionCollection*) gxml_serializable_dual_key_map_construct (object_type, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_REFACTION, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 111 "SerializableGeeCollections-TDocument-Test.vala"
	return self;
#line 7078 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestRefactionCollection*
serializable_gee_collections_tdocument_test_refaction_collection_new (void)
{
#line 111 "SerializableGeeCollections-TDocument-Test.vala"
	return serializable_gee_collections_tdocument_test_refaction_collection_construct (SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_TYPE_COLLECTION);
#line 7086 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_refaction_collection_class_init (SerializableGeeCollectionsTDocumentTestRefactionCollectionClass * klass,
                                                                             gpointer klass_data)
{
#line 111 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_refaction_collection_parent_class = g_type_class_peek_parent (klass);
#line 7095 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_refaction_collection_instance_init (SerializableGeeCollectionsTDocumentTestRefactionCollection * self,
                                                                                gpointer klass)
{
}

GType
serializable_gee_collections_tdocument_test_refaction_collection_get_type (void)
{
	static volatile gsize serializable_gee_collections_tdocument_test_refaction_collection_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_tdocument_test_refaction_collection_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTDocumentTestRefactionCollectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_tdocument_test_refaction_collection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTDocumentTestRefactionCollection), 0, (GInstanceInitFunc) serializable_gee_collections_tdocument_test_refaction_collection_instance_init, NULL };
		GType serializable_gee_collections_tdocument_test_refaction_collection_type_id;
		serializable_gee_collections_tdocument_test_refaction_collection_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_DUAL_KEY_MAP, "SerializableGeeCollectionsTDocumentTestRefactionCollection", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_collections_tdocument_test_refaction_collection_type_id__volatile, serializable_gee_collections_tdocument_test_refaction_collection_type_id);
	}
	return serializable_gee_collections_tdocument_test_refaction_collection_type_id__volatile;
}

static void
serializable_gee_collections_tdocument_test_refaction_class_init (SerializableGeeCollectionsTDocumentTestRefactionClass * klass,
                                                                  gpointer klass_data)
{
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_refaction_parent_class = g_type_class_peek_parent (klass);
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeCollectionsTDocumentTestRefaction_private_offset);
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_tdocument_test_refaction_real_node_name;
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_tdocument_test_refaction_real_to_string;
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableObjectModelClass *) klass)->get_enable_unknown_serializable_property = (gboolean (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_tdocument_test_refaction_real_get_enable_unknown_serializable_property;
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableContainerClass *) klass)->init_containers = (void (*) (GXmlSerializableContainer*)) serializable_gee_collections_tdocument_test_refaction_real_init_containers;
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_collections_tdocument_test_refaction_get_property;
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_collections_tdocument_test_refaction_set_property;
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_collections_tdocument_test_refaction_finalize;
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_MODEL_PROPERTY, serializable_gee_collections_tdocument_test_refaction_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_MODEL_PROPERTY] = g_param_spec_string ("model", "model", "model", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_MANUFACTURER_PROPERTY, serializable_gee_collections_tdocument_test_refaction_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_MANUFACTURER_PROPERTY] = g_param_spec_string ("manufacturer", "manufacturer", "manufacturer", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_SPACESHIPS_PROPERTY, serializable_gee_collections_tdocument_test_refaction_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_SPACESHIPS_PROPERTY] = g_param_spec_object ("spaceships", "spaceships", "spaceships", SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_TYPE_COLLECTION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 7145 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_refaction_gxml_serializable_map_dual_key_interface_init (GXmlSerializableMapDualKeyIface * iface,
                                                                                                     gpointer iface_data)
{
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_refaction_gxml_serializable_map_dual_key_parent_iface = g_type_interface_peek_parent (iface);
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
	iface->get_map_primary_key = (gpointer (*) (GXmlSerializableMapDualKey*)) serializable_gee_collections_tdocument_test_refaction_real_get_map_primary_key;
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
	iface->get_map_secondary_key = (gpointer (*) (GXmlSerializableMapDualKey*)) serializable_gee_collections_tdocument_test_refaction_real_get_map_secondary_key;
#line 7158 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_refaction_instance_init (SerializableGeeCollectionsTDocumentTestRefaction * self,
                                                                     gpointer klass)
{
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
	self->priv = serializable_gee_collections_tdocument_test_refaction_get_instance_private (self);
#line 7167 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_refaction_finalize (GObject * obj)
{
	SerializableGeeCollectionsTDocumentTestRefaction * self;
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_REFACTION, SerializableGeeCollectionsTDocumentTestRefaction);
#line 88 "SerializableGeeCollections-TDocument-Test.vala"
	_g_free0 (self->priv->_model);
#line 89 "SerializableGeeCollections-TDocument-Test.vala"
	_g_free0 (self->priv->_manufacturer);
#line 90 "SerializableGeeCollections-TDocument-Test.vala"
	_g_object_unref0 (self->priv->_spaceships);
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (serializable_gee_collections_tdocument_test_refaction_parent_class)->finalize (obj);
#line 7184 "SerializableGeeCollections-TDocument-Test.c"
}

static GType
serializable_gee_collections_tdocument_test_refaction_get_type (void)
{
	static volatile gsize serializable_gee_collections_tdocument_test_refaction_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_tdocument_test_refaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTDocumentTestRefactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_tdocument_test_refaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTDocumentTestRefaction), 0, (GInstanceInitFunc) serializable_gee_collections_tdocument_test_refaction_instance_init, NULL };
		static const GInterfaceInfo gxml_serializable_map_dual_key_info = { (GInterfaceInitFunc) serializable_gee_collections_tdocument_test_refaction_gxml_serializable_map_dual_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType serializable_gee_collections_tdocument_test_refaction_type_id;
		serializable_gee_collections_tdocument_test_refaction_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_CONTAINER, "SerializableGeeCollectionsTDocumentTestRefaction", &g_define_type_info, 0);
		g_type_add_interface_static (serializable_gee_collections_tdocument_test_refaction_type_id, GXML_TYPE_SERIALIZABLE_MAP_DUAL_KEY, &gxml_serializable_map_dual_key_info);
		SerializableGeeCollectionsTDocumentTestRefaction_private_offset = g_type_add_instance_private (serializable_gee_collections_tdocument_test_refaction_type_id, sizeof (SerializableGeeCollectionsTDocumentTestRefactionPrivate));
		g_once_init_leave (&serializable_gee_collections_tdocument_test_refaction_type_id__volatile, serializable_gee_collections_tdocument_test_refaction_type_id);
	}
	return serializable_gee_collections_tdocument_test_refaction_type_id__volatile;
}

static void
_vala_serializable_gee_collections_tdocument_test_refaction_get_property (GObject * object,
                                                                          guint property_id,
                                                                          GValue * value,
                                                                          GParamSpec * pspec)
{
	SerializableGeeCollectionsTDocumentTestRefaction * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_REFACTION, SerializableGeeCollectionsTDocumentTestRefaction);
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
	switch (property_id) {
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_MODEL_PROPERTY:
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
		g_value_set_string (value, serializable_gee_collections_tdocument_test_refaction_get_model (self));
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_MANUFACTURER_PROPERTY:
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
		g_value_set_string (value, serializable_gee_collections_tdocument_test_refaction_get_manufacturer (self));
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_SPACESHIPS_PROPERTY:
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
		g_value_set_object (value, serializable_gee_collections_tdocument_test_refaction_get_spaceships (self));
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 7231 "SerializableGeeCollections-TDocument-Test.c"
		default:
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 7237 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static void
_vala_serializable_gee_collections_tdocument_test_refaction_set_property (GObject * object,
                                                                          guint property_id,
                                                                          const GValue * value,
                                                                          GParamSpec * pspec)
{
	SerializableGeeCollectionsTDocumentTestRefaction * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_REFACTION, SerializableGeeCollectionsTDocumentTestRefaction);
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
	switch (property_id) {
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_MODEL_PROPERTY:
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_refaction_set_model (self, g_value_get_string (value));
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_MANUFACTURER_PROPERTY:
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_refaction_set_manufacturer (self, g_value_get_string (value));
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_SPACESHIPS_PROPERTY:
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_refaction_set_spaceships (self, g_value_get_object (value));
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 7269 "SerializableGeeCollections-TDocument-Test.c"
		default:
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 86 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 7275 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static inline gpointer
serializable_gee_collections_tdocument_test_space_ship_get_instance_private (SerializableGeeCollectionsTDocumentTestSpaceShip* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeCollectionsTDocumentTestSpaceShip_private_offset);
}

static SerializableGeeCollectionsTDocumentTestSpaceShip*
serializable_gee_collections_tdocument_test_space_ship_construct_named (GType object_type,
                                                                        const gchar* manufacturer,
                                                                        const gchar* model)
{
	SerializableGeeCollectionsTDocumentTestSpaceShip * self = NULL;
#line 119 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (manufacturer != NULL, NULL);
#line 119 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (model != NULL, NULL);
#line 119 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestSpaceShip*) gxml_serializable_container_construct (object_type);
#line 121 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_space_ship_set_manufacturer (self, manufacturer);
#line 122 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_space_ship_set_model (self, model);
#line 119 "SerializableGeeCollections-TDocument-Test.vala"
	return self;
#line 7303 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestSpaceShip*
serializable_gee_collections_tdocument_test_space_ship_new_named (const gchar* manufacturer,
                                                                  const gchar* model)
{
#line 119 "SerializableGeeCollections-TDocument-Test.vala"
	return serializable_gee_collections_tdocument_test_space_ship_construct_named (SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE_SHIP, manufacturer, model);
#line 7312 "SerializableGeeCollections-TDocument-Test.c"
}

static gchar*
serializable_gee_collections_tdocument_test_space_ship_real_get_map_primary_key (GXmlSerializableMapDualKey* base)
{
	SerializableGeeCollectionsTDocumentTestSpaceShip * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 125 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestSpaceShip*) base;
#line 125 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_manufacturer;
#line 125 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 125 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp1_;
#line 125 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 7332 "SerializableGeeCollections-TDocument-Test.c"
}

static gchar*
serializable_gee_collections_tdocument_test_space_ship_real_get_map_secondary_key (GXmlSerializableMapDualKey* base)
{
	SerializableGeeCollectionsTDocumentTestSpaceShip * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 126 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestSpaceShip*) base;
#line 126 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_model;
#line 126 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 126 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp1_;
#line 126 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 7352 "SerializableGeeCollections-TDocument-Test.c"
}

static gchar*
serializable_gee_collections_tdocument_test_space_ship_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTDocumentTestSpaceShip * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 128 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestSpaceShip*) base;
#line 128 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = g_strdup ("ship");
#line 128 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 128 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 7369 "SerializableGeeCollections-TDocument-Test.c"
}

static gchar*
serializable_gee_collections_tdocument_test_space_ship_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTDocumentTestSpaceShip * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 129 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestSpaceShip*) base;
#line 129 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_model;
#line 129 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 129 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp1_;
#line 129 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 7389 "SerializableGeeCollections-TDocument-Test.c"
}

static gboolean
serializable_gee_collections_tdocument_test_space_ship_real_get_enable_unknown_serializable_property (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTDocumentTestSpaceShip * self;
	gboolean result = FALSE;
#line 130 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestSpaceShip*) base;
#line 130 "SerializableGeeCollections-TDocument-Test.vala"
	result = TRUE;
#line 130 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 7403 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_space_ship_real_init_containers (GXmlSerializableContainer* base)
{
	SerializableGeeCollectionsTDocumentTestSpaceShip * self;
	SerializableGeeCollectionsTDocumentTestSpaceCollection* _tmp0_;
#line 132 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestSpaceShip*) base;
#line 134 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_spaces;
#line 134 "SerializableGeeCollections-TDocument-Test.vala"
	if (_tmp0_ == NULL) {
#line 7417 "SerializableGeeCollections-TDocument-Test.c"
		SerializableGeeCollectionsTDocumentTestSpaceCollection* _tmp1_;
		SerializableGeeCollectionsTDocumentTestSpaceCollection* _tmp2_;
#line 135 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp1_ = serializable_gee_collections_tdocument_test_space_collection_new ();
#line 135 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp2_ = _tmp1_;
#line 135 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_space_ship_set_spaces (self, _tmp2_);
#line 135 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp2_);
#line 7428 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static SerializableGeeCollectionsTDocumentTestSpaceShip*
serializable_gee_collections_tdocument_test_space_ship_construct (GType object_type)
{
	SerializableGeeCollectionsTDocumentTestSpaceShip * self = NULL;
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestSpaceShip*) gxml_serializable_container_construct (object_type);
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
	return self;
#line 7440 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestSpaceShip*
serializable_gee_collections_tdocument_test_space_ship_new (void)
{
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
	return serializable_gee_collections_tdocument_test_space_ship_construct (SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE_SHIP);
#line 7448 "SerializableGeeCollections-TDocument-Test.c"
}

static const gchar*
serializable_gee_collections_tdocument_test_space_ship_get_model (SerializableGeeCollectionsTDocumentTestSpaceShip* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 115 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 115 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_model;
#line 115 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 115 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 7464 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_space_ship_set_model (SerializableGeeCollectionsTDocumentTestSpaceShip* self,
                                                                  const gchar* value)
{
#line 115 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_if_fail (self != NULL);
#line 115 "SerializableGeeCollections-TDocument-Test.vala"
	if (g_strcmp0 (value, serializable_gee_collections_tdocument_test_space_ship_get_model (self)) != 0) {
#line 7475 "SerializableGeeCollections-TDocument-Test.c"
		gchar* _tmp0_;
#line 115 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp0_ = g_strdup (value);
#line 115 "SerializableGeeCollections-TDocument-Test.vala"
		_g_free0 (self->priv->_model);
#line 115 "SerializableGeeCollections-TDocument-Test.vala"
		self->priv->_model = _tmp0_;
#line 115 "SerializableGeeCollections-TDocument-Test.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_tdocument_test_space_ship_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_MODEL_PROPERTY]);
#line 7485 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static const gchar*
serializable_gee_collections_tdocument_test_space_ship_get_manufacturer (SerializableGeeCollectionsTDocumentTestSpaceShip* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 116 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 116 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_manufacturer;
#line 116 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 116 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 7502 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_space_ship_set_manufacturer (SerializableGeeCollectionsTDocumentTestSpaceShip* self,
                                                                         const gchar* value)
{
#line 116 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_if_fail (self != NULL);
#line 116 "SerializableGeeCollections-TDocument-Test.vala"
	if (g_strcmp0 (value, serializable_gee_collections_tdocument_test_space_ship_get_manufacturer (self)) != 0) {
#line 7513 "SerializableGeeCollections-TDocument-Test.c"
		gchar* _tmp0_;
#line 116 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp0_ = g_strdup (value);
#line 116 "SerializableGeeCollections-TDocument-Test.vala"
		_g_free0 (self->priv->_manufacturer);
#line 116 "SerializableGeeCollections-TDocument-Test.vala"
		self->priv->_manufacturer = _tmp0_;
#line 116 "SerializableGeeCollections-TDocument-Test.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_tdocument_test_space_ship_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_MANUFACTURER_PROPERTY]);
#line 7523 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static SerializableGeeCollectionsTDocumentTestSpaceCollection*
serializable_gee_collections_tdocument_test_space_ship_get_spaces (SerializableGeeCollectionsTDocumentTestSpaceShip* self)
{
	SerializableGeeCollectionsTDocumentTestSpaceCollection* result;
	SerializableGeeCollectionsTDocumentTestSpaceCollection* _tmp0_;
#line 117 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 117 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_spaces;
#line 117 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 117 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 7540 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_space_ship_set_spaces (SerializableGeeCollectionsTDocumentTestSpaceShip* self,
                                                                   SerializableGeeCollectionsTDocumentTestSpaceCollection* value)
{
#line 117 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_if_fail (self != NULL);
#line 117 "SerializableGeeCollections-TDocument-Test.vala"
	if (serializable_gee_collections_tdocument_test_space_ship_get_spaces (self) != value) {
#line 7551 "SerializableGeeCollections-TDocument-Test.c"
		SerializableGeeCollectionsTDocumentTestSpaceCollection* _tmp0_;
#line 117 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 117 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (self->priv->_spaces);
#line 117 "SerializableGeeCollections-TDocument-Test.vala"
		self->priv->_spaces = _tmp0_;
#line 117 "SerializableGeeCollections-TDocument-Test.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_tdocument_test_space_ship_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_SPACES_PROPERTY]);
#line 7561 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static SerializableGeeCollectionsTDocumentTestSpaceShipCollection*
serializable_gee_collections_tdocument_test_space_ship_collection_construct (GType object_type)
{
	SerializableGeeCollectionsTDocumentTestSpaceShipCollection * self = NULL;
#line 138 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestSpaceShipCollection*) gxml_serializable_dual_key_map_construct (object_type, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE_SHIP, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref);
#line 138 "SerializableGeeCollections-TDocument-Test.vala"
	return self;
#line 7573 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestSpaceShipCollection*
serializable_gee_collections_tdocument_test_space_ship_collection_new (void)
{
#line 138 "SerializableGeeCollections-TDocument-Test.vala"
	return serializable_gee_collections_tdocument_test_space_ship_collection_construct (SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_TYPE_COLLECTION);
#line 7581 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_space_ship_collection_class_init (SerializableGeeCollectionsTDocumentTestSpaceShipCollectionClass * klass,
                                                                              gpointer klass_data)
{
#line 138 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_space_ship_collection_parent_class = g_type_class_peek_parent (klass);
#line 7590 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_space_ship_collection_instance_init (SerializableGeeCollectionsTDocumentTestSpaceShipCollection * self,
                                                                                 gpointer klass)
{
}

GType
serializable_gee_collections_tdocument_test_space_ship_collection_get_type (void)
{
	static volatile gsize serializable_gee_collections_tdocument_test_space_ship_collection_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_tdocument_test_space_ship_collection_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTDocumentTestSpaceShipCollectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_tdocument_test_space_ship_collection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTDocumentTestSpaceShipCollection), 0, (GInstanceInitFunc) serializable_gee_collections_tdocument_test_space_ship_collection_instance_init, NULL };
		GType serializable_gee_collections_tdocument_test_space_ship_collection_type_id;
		serializable_gee_collections_tdocument_test_space_ship_collection_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_DUAL_KEY_MAP, "SerializableGeeCollectionsTDocumentTestSpaceShipCollection", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_collections_tdocument_test_space_ship_collection_type_id__volatile, serializable_gee_collections_tdocument_test_space_ship_collection_type_id);
	}
	return serializable_gee_collections_tdocument_test_space_ship_collection_type_id__volatile;
}

static void
serializable_gee_collections_tdocument_test_space_ship_class_init (SerializableGeeCollectionsTDocumentTestSpaceShipClass * klass,
                                                                   gpointer klass_data)
{
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_space_ship_parent_class = g_type_class_peek_parent (klass);
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeCollectionsTDocumentTestSpaceShip_private_offset);
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_tdocument_test_space_ship_real_node_name;
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_tdocument_test_space_ship_real_to_string;
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableObjectModelClass *) klass)->get_enable_unknown_serializable_property = (gboolean (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_tdocument_test_space_ship_real_get_enable_unknown_serializable_property;
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableContainerClass *) klass)->init_containers = (void (*) (GXmlSerializableContainer*)) serializable_gee_collections_tdocument_test_space_ship_real_init_containers;
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_collections_tdocument_test_space_ship_get_property;
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_collections_tdocument_test_space_ship_set_property;
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_collections_tdocument_test_space_ship_finalize;
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_MODEL_PROPERTY, serializable_gee_collections_tdocument_test_space_ship_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_MODEL_PROPERTY] = g_param_spec_string ("model", "model", "model", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_MANUFACTURER_PROPERTY, serializable_gee_collections_tdocument_test_space_ship_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_MANUFACTURER_PROPERTY] = g_param_spec_string ("manufacturer", "manufacturer", "manufacturer", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_SPACES_PROPERTY, serializable_gee_collections_tdocument_test_space_ship_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_SPACES_PROPERTY] = g_param_spec_object ("spaces", "spaces", "spaces", SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_TYPE_COLLECTION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 7640 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_space_ship_gxml_serializable_map_dual_key_interface_init (GXmlSerializableMapDualKeyIface * iface,
                                                                                                      gpointer iface_data)
{
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_space_ship_gxml_serializable_map_dual_key_parent_iface = g_type_interface_peek_parent (iface);
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
	iface->get_map_primary_key = (gpointer (*) (GXmlSerializableMapDualKey*)) serializable_gee_collections_tdocument_test_space_ship_real_get_map_primary_key;
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
	iface->get_map_secondary_key = (gpointer (*) (GXmlSerializableMapDualKey*)) serializable_gee_collections_tdocument_test_space_ship_real_get_map_secondary_key;
#line 7653 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_space_ship_instance_init (SerializableGeeCollectionsTDocumentTestSpaceShip * self,
                                                                      gpointer klass)
{
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
	self->priv = serializable_gee_collections_tdocument_test_space_ship_get_instance_private (self);
#line 7662 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_space_ship_finalize (GObject * obj)
{
	SerializableGeeCollectionsTDocumentTestSpaceShip * self;
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE_SHIP, SerializableGeeCollectionsTDocumentTestSpaceShip);
#line 115 "SerializableGeeCollections-TDocument-Test.vala"
	_g_free0 (self->priv->_model);
#line 116 "SerializableGeeCollections-TDocument-Test.vala"
	_g_free0 (self->priv->_manufacturer);
#line 117 "SerializableGeeCollections-TDocument-Test.vala"
	_g_object_unref0 (self->priv->_spaces);
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (serializable_gee_collections_tdocument_test_space_ship_parent_class)->finalize (obj);
#line 7679 "SerializableGeeCollections-TDocument-Test.c"
}

static GType
serializable_gee_collections_tdocument_test_space_ship_get_type (void)
{
	static volatile gsize serializable_gee_collections_tdocument_test_space_ship_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_tdocument_test_space_ship_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTDocumentTestSpaceShipClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_tdocument_test_space_ship_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTDocumentTestSpaceShip), 0, (GInstanceInitFunc) serializable_gee_collections_tdocument_test_space_ship_instance_init, NULL };
		static const GInterfaceInfo gxml_serializable_map_dual_key_info = { (GInterfaceInitFunc) serializable_gee_collections_tdocument_test_space_ship_gxml_serializable_map_dual_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType serializable_gee_collections_tdocument_test_space_ship_type_id;
		serializable_gee_collections_tdocument_test_space_ship_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_CONTAINER, "SerializableGeeCollectionsTDocumentTestSpaceShip", &g_define_type_info, 0);
		g_type_add_interface_static (serializable_gee_collections_tdocument_test_space_ship_type_id, GXML_TYPE_SERIALIZABLE_MAP_DUAL_KEY, &gxml_serializable_map_dual_key_info);
		SerializableGeeCollectionsTDocumentTestSpaceShip_private_offset = g_type_add_instance_private (serializable_gee_collections_tdocument_test_space_ship_type_id, sizeof (SerializableGeeCollectionsTDocumentTestSpaceShipPrivate));
		g_once_init_leave (&serializable_gee_collections_tdocument_test_space_ship_type_id__volatile, serializable_gee_collections_tdocument_test_space_ship_type_id);
	}
	return serializable_gee_collections_tdocument_test_space_ship_type_id__volatile;
}

static void
_vala_serializable_gee_collections_tdocument_test_space_ship_get_property (GObject * object,
                                                                           guint property_id,
                                                                           GValue * value,
                                                                           GParamSpec * pspec)
{
	SerializableGeeCollectionsTDocumentTestSpaceShip * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE_SHIP, SerializableGeeCollectionsTDocumentTestSpaceShip);
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
	switch (property_id) {
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_MODEL_PROPERTY:
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
		g_value_set_string (value, serializable_gee_collections_tdocument_test_space_ship_get_model (self));
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_MANUFACTURER_PROPERTY:
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
		g_value_set_string (value, serializable_gee_collections_tdocument_test_space_ship_get_manufacturer (self));
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_SPACES_PROPERTY:
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
		g_value_set_object (value, serializable_gee_collections_tdocument_test_space_ship_get_spaces (self));
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 7726 "SerializableGeeCollections-TDocument-Test.c"
		default:
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 7732 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static void
_vala_serializable_gee_collections_tdocument_test_space_ship_set_property (GObject * object,
                                                                           guint property_id,
                                                                           const GValue * value,
                                                                           GParamSpec * pspec)
{
	SerializableGeeCollectionsTDocumentTestSpaceShip * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE_SHIP, SerializableGeeCollectionsTDocumentTestSpaceShip);
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
	switch (property_id) {
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_MODEL_PROPERTY:
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_space_ship_set_model (self, g_value_get_string (value));
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_MANUFACTURER_PROPERTY:
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_space_ship_set_manufacturer (self, g_value_get_string (value));
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_SPACES_PROPERTY:
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_space_ship_set_spaces (self, g_value_get_object (value));
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 7764 "SerializableGeeCollections-TDocument-Test.c"
		default:
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 113 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 7770 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static inline gpointer
serializable_gee_collections_tdocument_test_charge_zone_get_instance_private (SerializableGeeCollectionsTDocumentTestChargeZone* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeCollectionsTDocumentTestChargeZone_private_offset);
}

static gchar*
serializable_gee_collections_tdocument_test_charge_zone_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTDocumentTestChargeZone * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 146 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestChargeZone*) base;
#line 146 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = g_strdup ("ChargeZone");
#line 146 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 146 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 7794 "SerializableGeeCollections-TDocument-Test.c"
}

static gchar*
serializable_gee_collections_tdocument_test_charge_zone_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTDocumentTestChargeZone * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 147 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestChargeZone*) base;
#line 147 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_name;
#line 147 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 147 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp1_;
#line 147 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 7814 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_charge_zone_real_init_containers (GXmlSerializableContainer* base)
{
	SerializableGeeCollectionsTDocumentTestChargeZone * self;
	SerializableGeeCollectionsTDocumentTestSpaceShipCollection* _tmp0_;
#line 148 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestChargeZone*) base;
#line 150 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_spaceships;
#line 150 "SerializableGeeCollections-TDocument-Test.vala"
	if (_tmp0_ == NULL) {
#line 7828 "SerializableGeeCollections-TDocument-Test.c"
		SerializableGeeCollectionsTDocumentTestSpaceShipCollection* _tmp1_;
		SerializableGeeCollectionsTDocumentTestSpaceShipCollection* _tmp2_;
#line 151 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp1_ = serializable_gee_collections_tdocument_test_space_ship_collection_new ();
#line 151 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp2_ = _tmp1_;
#line 151 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_charge_zone_set_spaceships (self, _tmp2_);
#line 151 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp2_);
#line 7839 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static SerializableGeeCollectionsTDocumentTestChargeZone*
serializable_gee_collections_tdocument_test_charge_zone_construct (GType object_type)
{
	SerializableGeeCollectionsTDocumentTestChargeZone * self = NULL;
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestChargeZone*) gxml_serializable_container_construct (object_type);
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
	return self;
#line 7851 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestChargeZone*
serializable_gee_collections_tdocument_test_charge_zone_new (void)
{
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
	return serializable_gee_collections_tdocument_test_charge_zone_construct (SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_CHARGE_ZONE);
#line 7859 "SerializableGeeCollections-TDocument-Test.c"
}

static const gchar*
serializable_gee_collections_tdocument_test_charge_zone_get_name (SerializableGeeCollectionsTDocumentTestChargeZone* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 143 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 143 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_name;
#line 143 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 143 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 7875 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_charge_zone_set_name (SerializableGeeCollectionsTDocumentTestChargeZone* self,
                                                                  const gchar* value)
{
#line 143 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_if_fail (self != NULL);
#line 143 "SerializableGeeCollections-TDocument-Test.vala"
	if (g_strcmp0 (value, serializable_gee_collections_tdocument_test_charge_zone_get_name (self)) != 0) {
#line 7886 "SerializableGeeCollections-TDocument-Test.c"
		gchar* _tmp0_;
#line 143 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp0_ = g_strdup (value);
#line 143 "SerializableGeeCollections-TDocument-Test.vala"
		_g_free0 (self->priv->_name);
#line 143 "SerializableGeeCollections-TDocument-Test.vala"
		self->priv->_name = _tmp0_;
#line 143 "SerializableGeeCollections-TDocument-Test.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_tdocument_test_charge_zone_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CHARGE_ZONE_NAME_PROPERTY]);
#line 7896 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static SerializableGeeCollectionsTDocumentTestSpaceShipCollection*
serializable_gee_collections_tdocument_test_charge_zone_get_spaceships (SerializableGeeCollectionsTDocumentTestChargeZone* self)
{
	SerializableGeeCollectionsTDocumentTestSpaceShipCollection* result;
	SerializableGeeCollectionsTDocumentTestSpaceShipCollection* _tmp0_;
#line 144 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 144 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_spaceships;
#line 144 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 144 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 7913 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_charge_zone_set_spaceships (SerializableGeeCollectionsTDocumentTestChargeZone* self,
                                                                        SerializableGeeCollectionsTDocumentTestSpaceShipCollection* value)
{
#line 144 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_if_fail (self != NULL);
#line 144 "SerializableGeeCollections-TDocument-Test.vala"
	if (serializable_gee_collections_tdocument_test_charge_zone_get_spaceships (self) != value) {
#line 7924 "SerializableGeeCollections-TDocument-Test.c"
		SerializableGeeCollectionsTDocumentTestSpaceShipCollection* _tmp0_;
#line 144 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 144 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (self->priv->_spaceships);
#line 144 "SerializableGeeCollections-TDocument-Test.vala"
		self->priv->_spaceships = _tmp0_;
#line 144 "SerializableGeeCollections-TDocument-Test.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_tdocument_test_charge_zone_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CHARGE_ZONE_SPACESHIPS_PROPERTY]);
#line 7934 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static void
serializable_gee_collections_tdocument_test_charge_zone_class_init (SerializableGeeCollectionsTDocumentTestChargeZoneClass * klass,
                                                                    gpointer klass_data)
{
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_charge_zone_parent_class = g_type_class_peek_parent (klass);
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeCollectionsTDocumentTestChargeZone_private_offset);
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_tdocument_test_charge_zone_real_node_name;
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_tdocument_test_charge_zone_real_to_string;
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableContainerClass *) klass)->init_containers = (void (*) (GXmlSerializableContainer*)) serializable_gee_collections_tdocument_test_charge_zone_real_init_containers;
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_collections_tdocument_test_charge_zone_get_property;
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_collections_tdocument_test_charge_zone_set_property;
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_collections_tdocument_test_charge_zone_finalize;
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CHARGE_ZONE_NAME_PROPERTY, serializable_gee_collections_tdocument_test_charge_zone_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CHARGE_ZONE_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CHARGE_ZONE_SPACESHIPS_PROPERTY, serializable_gee_collections_tdocument_test_charge_zone_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CHARGE_ZONE_SPACESHIPS_PROPERTY] = g_param_spec_object ("spaceships", "spaceships", "spaceships", SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_SHIP_TYPE_COLLECTION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 7962 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_charge_zone_instance_init (SerializableGeeCollectionsTDocumentTestChargeZone * self,
                                                                       gpointer klass)
{
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
	self->priv = serializable_gee_collections_tdocument_test_charge_zone_get_instance_private (self);
#line 7971 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_charge_zone_finalize (GObject * obj)
{
	SerializableGeeCollectionsTDocumentTestChargeZone * self;
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_CHARGE_ZONE, SerializableGeeCollectionsTDocumentTestChargeZone);
#line 143 "SerializableGeeCollections-TDocument-Test.vala"
	_g_free0 (self->priv->_name);
#line 144 "SerializableGeeCollections-TDocument-Test.vala"
	_g_object_unref0 (self->priv->_spaceships);
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (serializable_gee_collections_tdocument_test_charge_zone_parent_class)->finalize (obj);
#line 7986 "SerializableGeeCollections-TDocument-Test.c"
}

static GType
serializable_gee_collections_tdocument_test_charge_zone_get_type (void)
{
	static volatile gsize serializable_gee_collections_tdocument_test_charge_zone_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_tdocument_test_charge_zone_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTDocumentTestChargeZoneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_tdocument_test_charge_zone_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTDocumentTestChargeZone), 0, (GInstanceInitFunc) serializable_gee_collections_tdocument_test_charge_zone_instance_init, NULL };
		GType serializable_gee_collections_tdocument_test_charge_zone_type_id;
		serializable_gee_collections_tdocument_test_charge_zone_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_CONTAINER, "SerializableGeeCollectionsTDocumentTestChargeZone", &g_define_type_info, 0);
		SerializableGeeCollectionsTDocumentTestChargeZone_private_offset = g_type_add_instance_private (serializable_gee_collections_tdocument_test_charge_zone_type_id, sizeof (SerializableGeeCollectionsTDocumentTestChargeZonePrivate));
		g_once_init_leave (&serializable_gee_collections_tdocument_test_charge_zone_type_id__volatile, serializable_gee_collections_tdocument_test_charge_zone_type_id);
	}
	return serializable_gee_collections_tdocument_test_charge_zone_type_id__volatile;
}

static void
_vala_serializable_gee_collections_tdocument_test_charge_zone_get_property (GObject * object,
                                                                            guint property_id,
                                                                            GValue * value,
                                                                            GParamSpec * pspec)
{
	SerializableGeeCollectionsTDocumentTestChargeZone * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_CHARGE_ZONE, SerializableGeeCollectionsTDocumentTestChargeZone);
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
	switch (property_id) {
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CHARGE_ZONE_NAME_PROPERTY:
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
		g_value_set_string (value, serializable_gee_collections_tdocument_test_charge_zone_get_name (self));
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CHARGE_ZONE_SPACESHIPS_PROPERTY:
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
		g_value_set_object (value, serializable_gee_collections_tdocument_test_charge_zone_get_spaceships (self));
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 8025 "SerializableGeeCollections-TDocument-Test.c"
		default:
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 8031 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static void
_vala_serializable_gee_collections_tdocument_test_charge_zone_set_property (GObject * object,
                                                                            guint property_id,
                                                                            const GValue * value,
                                                                            GParamSpec * pspec)
{
	SerializableGeeCollectionsTDocumentTestChargeZone * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_CHARGE_ZONE, SerializableGeeCollectionsTDocumentTestChargeZone);
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
	switch (property_id) {
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CHARGE_ZONE_NAME_PROPERTY:
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_charge_zone_set_name (self, g_value_get_string (value));
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_CHARGE_ZONE_SPACESHIPS_PROPERTY:
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_charge_zone_set_spaceships (self, g_value_get_object (value));
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 8057 "SerializableGeeCollections-TDocument-Test.c"
		default:
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 141 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 8063 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static inline gpointer
serializable_gee_collections_tdocument_test_storage_get_instance_private (SerializableGeeCollectionsTDocumentTestStorage* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeCollectionsTDocumentTestStorage_private_offset);
}

static gchar*
serializable_gee_collections_tdocument_test_storage_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTDocumentTestStorage * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 159 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestStorage*) base;
#line 159 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = g_strdup ("storage");
#line 159 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 159 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 8087 "SerializableGeeCollections-TDocument-Test.c"
}

static gchar*
serializable_gee_collections_tdocument_test_storage_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTDocumentTestStorage * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 160 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestStorage*) base;
#line 160 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_name;
#line 160 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 160 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp1_;
#line 160 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 8107 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_storage_real_init_containers (GXmlSerializableContainer* base)
{
	SerializableGeeCollectionsTDocumentTestStorage * self;
	SerializableGeeCollectionsTDocumentTestRefactionCollection* _tmp0_;
#line 161 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestStorage*) base;
#line 163 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_refactions;
#line 163 "SerializableGeeCollections-TDocument-Test.vala"
	if (_tmp0_ == NULL) {
#line 8121 "SerializableGeeCollections-TDocument-Test.c"
		SerializableGeeCollectionsTDocumentTestRefactionCollection* _tmp1_;
		SerializableGeeCollectionsTDocumentTestRefactionCollection* _tmp2_;
#line 164 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp1_ = serializable_gee_collections_tdocument_test_refaction_collection_new ();
#line 164 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp2_ = _tmp1_;
#line 164 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_storage_set_refactions (self, _tmp2_);
#line 164 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (_tmp2_);
#line 8132 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static SerializableGeeCollectionsTDocumentTestStorage*
serializable_gee_collections_tdocument_test_storage_construct (GType object_type)
{
	SerializableGeeCollectionsTDocumentTestStorage * self = NULL;
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestStorage*) gxml_serializable_container_construct (object_type);
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
	return self;
#line 8144 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestStorage*
serializable_gee_collections_tdocument_test_storage_new (void)
{
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
	return serializable_gee_collections_tdocument_test_storage_construct (SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_STORAGE);
#line 8152 "SerializableGeeCollections-TDocument-Test.c"
}

static const gchar*
serializable_gee_collections_tdocument_test_storage_get_name (SerializableGeeCollectionsTDocumentTestStorage* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 156 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 156 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_name;
#line 156 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 156 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 8168 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_storage_set_name (SerializableGeeCollectionsTDocumentTestStorage* self,
                                                              const gchar* value)
{
#line 156 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_if_fail (self != NULL);
#line 156 "SerializableGeeCollections-TDocument-Test.vala"
	if (g_strcmp0 (value, serializable_gee_collections_tdocument_test_storage_get_name (self)) != 0) {
#line 8179 "SerializableGeeCollections-TDocument-Test.c"
		gchar* _tmp0_;
#line 156 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp0_ = g_strdup (value);
#line 156 "SerializableGeeCollections-TDocument-Test.vala"
		_g_free0 (self->priv->_name);
#line 156 "SerializableGeeCollections-TDocument-Test.vala"
		self->priv->_name = _tmp0_;
#line 156 "SerializableGeeCollections-TDocument-Test.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_tdocument_test_storage_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_STORAGE_NAME_PROPERTY]);
#line 8189 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static SerializableGeeCollectionsTDocumentTestRefactionCollection*
serializable_gee_collections_tdocument_test_storage_get_refactions (SerializableGeeCollectionsTDocumentTestStorage* self)
{
	SerializableGeeCollectionsTDocumentTestRefactionCollection* result;
	SerializableGeeCollectionsTDocumentTestRefactionCollection* _tmp0_;
#line 157 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 157 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_refactions;
#line 157 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 157 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 8206 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_storage_set_refactions (SerializableGeeCollectionsTDocumentTestStorage* self,
                                                                    SerializableGeeCollectionsTDocumentTestRefactionCollection* value)
{
#line 157 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_if_fail (self != NULL);
#line 157 "SerializableGeeCollections-TDocument-Test.vala"
	if (serializable_gee_collections_tdocument_test_storage_get_refactions (self) != value) {
#line 8217 "SerializableGeeCollections-TDocument-Test.c"
		SerializableGeeCollectionsTDocumentTestRefactionCollection* _tmp0_;
#line 157 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 157 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (self->priv->_refactions);
#line 157 "SerializableGeeCollections-TDocument-Test.vala"
		self->priv->_refactions = _tmp0_;
#line 157 "SerializableGeeCollections-TDocument-Test.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_tdocument_test_storage_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_STORAGE_REFACTIONS_PROPERTY]);
#line 8227 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static void
serializable_gee_collections_tdocument_test_storage_class_init (SerializableGeeCollectionsTDocumentTestStorageClass * klass,
                                                                gpointer klass_data)
{
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_storage_parent_class = g_type_class_peek_parent (klass);
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeCollectionsTDocumentTestStorage_private_offset);
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_tdocument_test_storage_real_node_name;
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_tdocument_test_storage_real_to_string;
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableContainerClass *) klass)->init_containers = (void (*) (GXmlSerializableContainer*)) serializable_gee_collections_tdocument_test_storage_real_init_containers;
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_collections_tdocument_test_storage_get_property;
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_collections_tdocument_test_storage_set_property;
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_collections_tdocument_test_storage_finalize;
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_STORAGE_NAME_PROPERTY, serializable_gee_collections_tdocument_test_storage_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_STORAGE_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_STORAGE_REFACTIONS_PROPERTY, serializable_gee_collections_tdocument_test_storage_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_STORAGE_REFACTIONS_PROPERTY] = g_param_spec_object ("refactions", "refactions", "refactions", SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_REFACTION_TYPE_COLLECTION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 8255 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_storage_instance_init (SerializableGeeCollectionsTDocumentTestStorage * self,
                                                                   gpointer klass)
{
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
	self->priv = serializable_gee_collections_tdocument_test_storage_get_instance_private (self);
#line 8264 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_storage_finalize (GObject * obj)
{
	SerializableGeeCollectionsTDocumentTestStorage * self;
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_STORAGE, SerializableGeeCollectionsTDocumentTestStorage);
#line 156 "SerializableGeeCollections-TDocument-Test.vala"
	_g_free0 (self->priv->_name);
#line 157 "SerializableGeeCollections-TDocument-Test.vala"
	_g_object_unref0 (self->priv->_refactions);
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (serializable_gee_collections_tdocument_test_storage_parent_class)->finalize (obj);
#line 8279 "SerializableGeeCollections-TDocument-Test.c"
}

static GType
serializable_gee_collections_tdocument_test_storage_get_type (void)
{
	static volatile gsize serializable_gee_collections_tdocument_test_storage_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_tdocument_test_storage_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTDocumentTestStorageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_tdocument_test_storage_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTDocumentTestStorage), 0, (GInstanceInitFunc) serializable_gee_collections_tdocument_test_storage_instance_init, NULL };
		GType serializable_gee_collections_tdocument_test_storage_type_id;
		serializable_gee_collections_tdocument_test_storage_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_CONTAINER, "SerializableGeeCollectionsTDocumentTestStorage", &g_define_type_info, 0);
		SerializableGeeCollectionsTDocumentTestStorage_private_offset = g_type_add_instance_private (serializable_gee_collections_tdocument_test_storage_type_id, sizeof (SerializableGeeCollectionsTDocumentTestStoragePrivate));
		g_once_init_leave (&serializable_gee_collections_tdocument_test_storage_type_id__volatile, serializable_gee_collections_tdocument_test_storage_type_id);
	}
	return serializable_gee_collections_tdocument_test_storage_type_id__volatile;
}

static void
_vala_serializable_gee_collections_tdocument_test_storage_get_property (GObject * object,
                                                                        guint property_id,
                                                                        GValue * value,
                                                                        GParamSpec * pspec)
{
	SerializableGeeCollectionsTDocumentTestStorage * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_STORAGE, SerializableGeeCollectionsTDocumentTestStorage);
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
	switch (property_id) {
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_STORAGE_NAME_PROPERTY:
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
		g_value_set_string (value, serializable_gee_collections_tdocument_test_storage_get_name (self));
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_STORAGE_REFACTIONS_PROPERTY:
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
		g_value_set_object (value, serializable_gee_collections_tdocument_test_storage_get_refactions (self));
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 8318 "SerializableGeeCollections-TDocument-Test.c"
		default:
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 8324 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static void
_vala_serializable_gee_collections_tdocument_test_storage_set_property (GObject * object,
                                                                        guint property_id,
                                                                        const GValue * value,
                                                                        GParamSpec * pspec)
{
	SerializableGeeCollectionsTDocumentTestStorage * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_STORAGE, SerializableGeeCollectionsTDocumentTestStorage);
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
	switch (property_id) {
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_STORAGE_NAME_PROPERTY:
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_storage_set_name (self, g_value_get_string (value));
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_STORAGE_REFACTIONS_PROPERTY:
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_storage_set_refactions (self, g_value_get_object (value));
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 8350 "SerializableGeeCollections-TDocument-Test.c"
		default:
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 154 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 8356 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static inline gpointer
serializable_gee_collections_tdocument_test_space_base_get_instance_private (SerializableGeeCollectionsTDocumentTestSpaceBase* self)
{
	return G_STRUCT_MEMBER_P (self, SerializableGeeCollectionsTDocumentTestSpaceBase_private_offset);
}

static gchar*
serializable_gee_collections_tdocument_test_space_base_real_node_name (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTDocumentTestSpaceBase * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 173 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestSpaceBase*) base;
#line 173 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = g_strdup ("base");
#line 173 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 173 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 8380 "SerializableGeeCollections-TDocument-Test.c"
}

static gchar*
serializable_gee_collections_tdocument_test_space_base_real_to_string (GXmlSerializableObjectModel* base)
{
	SerializableGeeCollectionsTDocumentTestSpaceBase * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 174 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestSpaceBase*) base;
#line 174 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_name;
#line 174 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 174 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp1_;
#line 174 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 8400 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestSpaceBase*
serializable_gee_collections_tdocument_test_space_base_construct (GType object_type)
{
	SerializableGeeCollectionsTDocumentTestSpaceBase * self = NULL;
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
	self = (SerializableGeeCollectionsTDocumentTestSpaceBase*) gxml_serializable_object_model_construct (object_type);
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
	return self;
#line 8411 "SerializableGeeCollections-TDocument-Test.c"
}

static SerializableGeeCollectionsTDocumentTestSpaceBase*
serializable_gee_collections_tdocument_test_space_base_new (void)
{
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
	return serializable_gee_collections_tdocument_test_space_base_construct (SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE_BASE);
#line 8419 "SerializableGeeCollections-TDocument-Test.c"
}

static const gchar*
serializable_gee_collections_tdocument_test_space_base_get_name (SerializableGeeCollectionsTDocumentTestSpaceBase* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 170 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 170 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_name;
#line 170 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 170 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 8435 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_space_base_set_name (SerializableGeeCollectionsTDocumentTestSpaceBase* self,
                                                                 const gchar* value)
{
#line 170 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_if_fail (self != NULL);
#line 170 "SerializableGeeCollections-TDocument-Test.vala"
	if (g_strcmp0 (value, serializable_gee_collections_tdocument_test_space_base_get_name (self)) != 0) {
#line 8446 "SerializableGeeCollections-TDocument-Test.c"
		gchar* _tmp0_;
#line 170 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp0_ = g_strdup (value);
#line 170 "SerializableGeeCollections-TDocument-Test.vala"
		_g_free0 (self->priv->_name);
#line 170 "SerializableGeeCollections-TDocument-Test.vala"
		self->priv->_name = _tmp0_;
#line 170 "SerializableGeeCollections-TDocument-Test.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_tdocument_test_space_base_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE_NAME_PROPERTY]);
#line 8456 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static SerializableGeeCollectionsTDocumentTestChargeZone*
serializable_gee_collections_tdocument_test_space_base_get_charge_zone (SerializableGeeCollectionsTDocumentTestSpaceBase* self)
{
	SerializableGeeCollectionsTDocumentTestChargeZone* result;
	SerializableGeeCollectionsTDocumentTestChargeZone* _tmp0_;
#line 171 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 171 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_charge_zone;
#line 171 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 171 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 8473 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_space_base_set_charge_zone (SerializableGeeCollectionsTDocumentTestSpaceBase* self,
                                                                        SerializableGeeCollectionsTDocumentTestChargeZone* value)
{
#line 171 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_if_fail (self != NULL);
#line 171 "SerializableGeeCollections-TDocument-Test.vala"
	if (serializable_gee_collections_tdocument_test_space_base_get_charge_zone (self) != value) {
#line 8484 "SerializableGeeCollections-TDocument-Test.c"
		SerializableGeeCollectionsTDocumentTestChargeZone* _tmp0_;
#line 171 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 171 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (self->priv->_charge_zone);
#line 171 "SerializableGeeCollections-TDocument-Test.vala"
		self->priv->_charge_zone = _tmp0_;
#line 171 "SerializableGeeCollections-TDocument-Test.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_tdocument_test_space_base_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE_CHARGE_ZONE_PROPERTY]);
#line 8494 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static SerializableGeeCollectionsTDocumentTestStorage*
serializable_gee_collections_tdocument_test_space_base_get_storage (SerializableGeeCollectionsTDocumentTestSpaceBase* self)
{
	SerializableGeeCollectionsTDocumentTestStorage* result;
	SerializableGeeCollectionsTDocumentTestStorage* _tmp0_;
#line 172 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 172 "SerializableGeeCollections-TDocument-Test.vala"
	_tmp0_ = self->priv->_storage;
#line 172 "SerializableGeeCollections-TDocument-Test.vala"
	result = _tmp0_;
#line 172 "SerializableGeeCollections-TDocument-Test.vala"
	return result;
#line 8511 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_space_base_set_storage (SerializableGeeCollectionsTDocumentTestSpaceBase* self,
                                                                    SerializableGeeCollectionsTDocumentTestStorage* value)
{
#line 172 "SerializableGeeCollections-TDocument-Test.vala"
	g_return_if_fail (self != NULL);
#line 172 "SerializableGeeCollections-TDocument-Test.vala"
	if (serializable_gee_collections_tdocument_test_space_base_get_storage (self) != value) {
#line 8522 "SerializableGeeCollections-TDocument-Test.c"
		SerializableGeeCollectionsTDocumentTestStorage* _tmp0_;
#line 172 "SerializableGeeCollections-TDocument-Test.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 172 "SerializableGeeCollections-TDocument-Test.vala"
		_g_object_unref0 (self->priv->_storage);
#line 172 "SerializableGeeCollections-TDocument-Test.vala"
		self->priv->_storage = _tmp0_;
#line 172 "SerializableGeeCollections-TDocument-Test.vala"
		g_object_notify_by_pspec ((GObject *) self, serializable_gee_collections_tdocument_test_space_base_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE_STORAGE_PROPERTY]);
#line 8532 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static void
serializable_gee_collections_tdocument_test_space_base_class_init (SerializableGeeCollectionsTDocumentTestSpaceBaseClass * klass,
                                                                   gpointer klass_data)
{
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_space_base_parent_class = g_type_class_peek_parent (klass);
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
	g_type_class_adjust_private_offset (klass, &SerializableGeeCollectionsTDocumentTestSpaceBase_private_offset);
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_tdocument_test_space_base_real_node_name;
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*) (GXmlSerializableObjectModel*)) serializable_gee_collections_tdocument_test_space_base_real_to_string;
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_gee_collections_tdocument_test_space_base_get_property;
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_gee_collections_tdocument_test_space_base_set_property;
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_gee_collections_tdocument_test_space_base_finalize;
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE_NAME_PROPERTY, serializable_gee_collections_tdocument_test_space_base_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE_CHARGE_ZONE_PROPERTY, serializable_gee_collections_tdocument_test_space_base_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE_CHARGE_ZONE_PROPERTY] = g_param_spec_object ("charge-zone", "charge-zone", "charge-zone", SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_CHARGE_ZONE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE_STORAGE_PROPERTY, serializable_gee_collections_tdocument_test_space_base_properties[SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE_STORAGE_PROPERTY] = g_param_spec_object ("storage", "storage", "storage", SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_STORAGE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 8560 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_space_base_instance_init (SerializableGeeCollectionsTDocumentTestSpaceBase * self,
                                                                      gpointer klass)
{
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
	self->priv = serializable_gee_collections_tdocument_test_space_base_get_instance_private (self);
#line 8569 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_space_base_finalize (GObject * obj)
{
	SerializableGeeCollectionsTDocumentTestSpaceBase * self;
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE_BASE, SerializableGeeCollectionsTDocumentTestSpaceBase);
#line 170 "SerializableGeeCollections-TDocument-Test.vala"
	_g_free0 (self->priv->_name);
#line 171 "SerializableGeeCollections-TDocument-Test.vala"
	_g_object_unref0 (self->priv->_charge_zone);
#line 172 "SerializableGeeCollections-TDocument-Test.vala"
	_g_object_unref0 (self->priv->_storage);
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
	G_OBJECT_CLASS (serializable_gee_collections_tdocument_test_space_base_parent_class)->finalize (obj);
#line 8586 "SerializableGeeCollections-TDocument-Test.c"
}

static GType
serializable_gee_collections_tdocument_test_space_base_get_type (void)
{
	static volatile gsize serializable_gee_collections_tdocument_test_space_base_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_tdocument_test_space_base_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTDocumentTestSpaceBaseClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_tdocument_test_space_base_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTDocumentTestSpaceBase), 0, (GInstanceInitFunc) serializable_gee_collections_tdocument_test_space_base_instance_init, NULL };
		GType serializable_gee_collections_tdocument_test_space_base_type_id;
		serializable_gee_collections_tdocument_test_space_base_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializableGeeCollectionsTDocumentTestSpaceBase", &g_define_type_info, 0);
		SerializableGeeCollectionsTDocumentTestSpaceBase_private_offset = g_type_add_instance_private (serializable_gee_collections_tdocument_test_space_base_type_id, sizeof (SerializableGeeCollectionsTDocumentTestSpaceBasePrivate));
		g_once_init_leave (&serializable_gee_collections_tdocument_test_space_base_type_id__volatile, serializable_gee_collections_tdocument_test_space_base_type_id);
	}
	return serializable_gee_collections_tdocument_test_space_base_type_id__volatile;
}

static void
_vala_serializable_gee_collections_tdocument_test_space_base_get_property (GObject * object,
                                                                           guint property_id,
                                                                           GValue * value,
                                                                           GParamSpec * pspec)
{
	SerializableGeeCollectionsTDocumentTestSpaceBase * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE_BASE, SerializableGeeCollectionsTDocumentTestSpaceBase);
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
	switch (property_id) {
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE_NAME_PROPERTY:
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
		g_value_set_string (value, serializable_gee_collections_tdocument_test_space_base_get_name (self));
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE_CHARGE_ZONE_PROPERTY:
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
		g_value_set_object (value, serializable_gee_collections_tdocument_test_space_base_get_charge_zone (self));
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE_STORAGE_PROPERTY:
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
		g_value_set_object (value, serializable_gee_collections_tdocument_test_space_base_get_storage (self));
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 8631 "SerializableGeeCollections-TDocument-Test.c"
		default:
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 8637 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static void
_vala_serializable_gee_collections_tdocument_test_space_base_set_property (GObject * object,
                                                                           guint property_id,
                                                                           const GValue * value,
                                                                           GParamSpec * pspec)
{
	SerializableGeeCollectionsTDocumentTestSpaceBase * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_TYPE_SPACE_BASE, SerializableGeeCollectionsTDocumentTestSpaceBase);
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
	switch (property_id) {
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE_NAME_PROPERTY:
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_space_base_set_name (self, g_value_get_string (value));
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE_CHARGE_ZONE_PROPERTY:
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_space_base_set_charge_zone (self, g_value_get_object (value));
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
		case SERIALIZABLE_GEE_COLLECTIONS_TDOCUMENT_TEST_SPACE_BASE_STORAGE_PROPERTY:
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
		serializable_gee_collections_tdocument_test_space_base_set_storage (self, g_value_get_object (value));
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 8669 "SerializableGeeCollections-TDocument-Test.c"
		default:
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 168 "SerializableGeeCollections-TDocument-Test.vala"
		break;
#line 8675 "SerializableGeeCollections-TDocument-Test.c"
	}
}

static void
serializable_gee_collections_tdocument_test_class_init (SerializableGeeCollectionsTDocumentTestClass * klass,
                                                        gpointer klass_data)
{
#line 29 "SerializableGeeCollections-TDocument-Test.vala"
	serializable_gee_collections_tdocument_test_parent_class = g_type_class_peek_parent (klass);
#line 8685 "SerializableGeeCollections-TDocument-Test.c"
}

static void
serializable_gee_collections_tdocument_test_instance_init (SerializableGeeCollectionsTDocumentTest * self,
                                                           gpointer klass)
{
}

/**
 *
 *  GXml.Serializable.GeeCollectionsTest
 *
 *  Authors:
 *
 *       Daniel Espinosa <esodan@gmail.com>
 *
 *
 *  Copyright (c) 2013-2015 Daniel Espinosa
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
GType
serializable_gee_collections_tdocument_test_get_type (void)
{
	static volatile gsize serializable_gee_collections_tdocument_test_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_gee_collections_tdocument_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableGeeCollectionsTDocumentTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_gee_collections_tdocument_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableGeeCollectionsTDocumentTest), 0, (GInstanceInitFunc) serializable_gee_collections_tdocument_test_instance_init, NULL };
		GType serializable_gee_collections_tdocument_test_type_id;
		serializable_gee_collections_tdocument_test_type_id = g_type_register_static (TYPE_GXML_TEST, "SerializableGeeCollectionsTDocumentTest", &g_define_type_info, 0);
		g_once_init_leave (&serializable_gee_collections_tdocument_test_type_id__volatile, serializable_gee_collections_tdocument_test_type_id);
	}
	return serializable_gee_collections_tdocument_test_type_id__volatile;
}

